"""Module providing graphs available from STRING.

References
----------
Please cite:

```bib
@article{szklarczyk2019string,
    title={STRING v11: protein--protein association networks with increased coverage, supporting functional discovery in genome-wide experimental datasets},
    author={Szklarczyk, Damian and Gable, Annika L and Lyon, David and Junge, Alexander and Wyder, Stefan and Huerta-Cepas, Jaime and Simonovic, Milan and Doncheva, Nadezhda T and Morris, John H and Bork, Peer and others},
    journal={Nucleic acids research},
    volume={47},
    number={D1},
    pages={D607--D613},
    year={2019},
    publisher={Oxford University Press}
}
```
"""
from ensmallen import Graph  # pylint: disable=import-error
from .automatic_graph_retrieval import AutomaticallyRetrievedGraph

def SynechocystisSpPcc7509(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC7509 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechocystisSpPcc7509", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "927677.protein.sequences.v11.5.fa",
		        "enrichment_path": "927677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927677.protein.info.v11.5.txt",
		        "node_list_path": "927677.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesPrasinopilosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces prasinopilosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPrasinopilosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67344.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67344.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67344.clusters.proteins.v11.5.txt",
		        "sequence_path": "67344.protein.sequences.v11.5.fa",
		        "enrichment_path": "67344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67344.protein.info.v11.5.txt",
		        "node_list_path": "67344.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67344.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PoeciliaLatipinnaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Poecilia latipinna Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PoeciliaLatipinnaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "48699.clusters.info.v11.5.txt",
		        "cluster_tree_path": "48699.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "48699.clusters.proteins.v11.5.txt",
		        "sequence_path": "48699.protein.sequences.v11.5.fa",
		        "enrichment_path": "48699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48699.protein.info.v11.5.txt",
		        "node_list_path": "48699.cluster.nodes.v11.5.txt",
		        "edge_list_path": "48699.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAbscessusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium abscessus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAbscessusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36809.clusters.proteins.v11.5.txt",
		        "sequence_path": "36809.protein.sequences.v11.5.fa",
		        "enrichment_path": "36809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36809.protein.info.v11.5.txt",
		        "node_list_path": "36809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LampropediaHyalinaDsm16112Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lampropedia hyalina DSM 16112 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LampropediaHyalinaDsm16112Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122156.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122156.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122156.protein.info.v11.5.txt",
		        "node_list_path": "1122156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterCalcoaceticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter calcoaceticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterCalcoaceticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "871585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "871585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "871585.clusters.proteins.v11.5.txt",
		        "sequence_path": "871585.protein.sequences.v11.5.fa",
		        "enrichment_path": "871585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871585.protein.info.v11.5.txt",
		        "node_list_path": "871585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "871585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudozymaHubeiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma hubeiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudozymaHubeiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "327079.protein.sequences.v11.5.fa",
		        "enrichment_path": "327079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "327079.protein.info.v11.5.txt",
		        "node_list_path": "327079.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumWg36(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium WG36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumWg36", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229485.protein.info.v11.5.txt",
		        "node_list_path": "1229485.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalegentibacterSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930251.protein.info.v11.5.txt",
		        "node_list_path": "1930251.protein.complete.v11.5.txt"
		    }
		]
    )()

def DialisterInvisusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dialister invisus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterInvisusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "592028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "592028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "592028.clusters.proteins.v11.5.txt",
		        "sequence_path": "592028.protein.sequences.v11.5.fa",
		        "enrichment_path": "592028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592028.protein.info.v11.5.txt",
		        "node_list_path": "592028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "592028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaAmikacinitoleransNbrc108937Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia amikacinitolerans NBRC 108937 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAmikacinitoleransNbrc108937Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379680.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379680.protein.info.v11.5.txt",
		        "node_list_path": "1379680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronolimnobiusInnermongolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronolimnobius innermongolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronolimnobiusInnermongolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227499.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227499.protein.info.v11.5.txt",
		        "node_list_path": "1227499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpYr460(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR460 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpYr460", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500290.protein.info.v11.5.txt",
		        "node_list_path": "1500290.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaCuniculi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella cuniculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaCuniculi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34061.protein.sequences.v11.5.fa",
		        "enrichment_path": "34061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34061.protein.info.v11.5.txt",
		        "node_list_path": "34061.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacterium13220cm2648(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_2_20CM_2_64_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacterium13220cm2648", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805369.protein.info.v11.5.txt",
		        "node_list_path": "1805369.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumMcbrellneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium mcbrellneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumMcbrellneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585530.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585530.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585530.clusters.proteins.v11.5.txt",
		        "sequence_path": "585530.protein.sequences.v11.5.fa",
		        "enrichment_path": "585530.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585530.protein.info.v11.5.txt",
		        "node_list_path": "585530.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585530.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaPneumoniaeAr39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae AR39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaPneumoniaeAr39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "115711.clusters.info.v11.5.txt",
		        "cluster_tree_path": "115711.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "115711.clusters.proteins.v11.5.txt",
		        "sequence_path": "115711.protein.sequences.v11.5.fa",
		        "enrichment_path": "115711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115711.protein.info.v11.5.txt",
		        "node_list_path": "115711.cluster.nodes.v11.5.txt",
		        "edge_list_path": "115711.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasMediaWs(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas media WS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasMediaWs", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208104.protein.info.v11.5.txt",
		        "node_list_path": "1208104.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalococcoidesMccartyiCbdb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi CBDB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalococcoidesMccartyiCbdb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "255470.clusters.info.v11.5.txt",
		        "cluster_tree_path": "255470.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "255470.clusters.proteins.v11.5.txt",
		        "sequence_path": "255470.protein.sequences.v11.5.fa",
		        "enrichment_path": "255470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "255470.protein.info.v11.5.txt",
		        "node_list_path": "255470.cluster.nodes.v11.5.txt",
		        "edge_list_path": "255470.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusHarenaeDsm16969(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus harenae DSM 16969 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusHarenaeDsm16969", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122920.protein.info.v11.5.txt",
		        "node_list_path": "1122920.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusTrypoxylicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus trypoxylicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusTrypoxylicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "519424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "519424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "519424.clusters.proteins.v11.5.txt",
		        "sequence_path": "519424.protein.sequences.v11.5.fa",
		        "enrichment_path": "519424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519424.protein.info.v11.5.txt",
		        "node_list_path": "519424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "519424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumGa0077525Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077525 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumGa0077525Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752222.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752222.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752222.protein.info.v11.5.txt",
		        "node_list_path": "1752222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumSg813Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium SG8_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumSg813Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703398.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703398.protein.info.v11.5.txt",
		        "node_list_path": "1703398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaAsterYellows(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma aster yellows graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaAsterYellows", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "322098.protein.sequences.v11.0.fa",
		        "enrichment_path": "322098.protein.enrichment.terms.v11.0.txt",
		        "info_path": "322098.protein.info.v11.0.txt",
		        "node_list_path": "322098.protein.complete.v11.0.txt"
		    }
		]
    )()

def MarineBacteriumAo1CCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return marine bacterium AO1-C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineBacteriumAo1CCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1905359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1905359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1905359.clusters.proteins.v11.5.txt",
		        "sequence_path": "1905359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1905359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1905359.protein.info.v11.5.txt",
		        "node_list_path": "1905359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1905359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpFukuswis1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. FUKUSWIS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpFukuswis1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379701.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379701.protein.info.v11.5.txt",
		        "node_list_path": "1379701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3713Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_37_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3713Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801750.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801750.protein.info.v11.5.txt",
		        "node_list_path": "1801750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacterium6411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 64-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacterium6411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895709.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895709.protein.info.v11.5.txt",
		        "node_list_path": "1895709.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSp112(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 1_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSp112", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566278.protein.info.v11.5.txt",
		        "node_list_path": "1566278.protein.complete.v11.5.txt"
		    }
		]
    )()

def BiomphalariaGlabrata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Biomphalaria glabrata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BiomphalariaGlabrata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6526.protein.sequences.v11.5.fa",
		        "enrichment_path": "6526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6526.protein.info.v11.5.txt",
		        "node_list_path": "6526.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSomerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas somerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSomerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122975.protein.info.v11.5.txt",
		        "node_list_path": "1122975.protein.complete.v11.5.txt"
		    }
		]
    )()

def PichiaMembranifaciensNrrlY2026(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pichia membranifaciens NRRL Y-2026 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PichiaMembranifaciensNrrlY2026", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "763406.protein.sequences.v11.5.fa",
		        "enrichment_path": "763406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "763406.protein.info.v11.5.txt",
		        "node_list_path": "763406.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumPhyllostachyos(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium phyllostachyos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumPhyllostachyos", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582672.protein.sequences.v11.5.fa",
		        "enrichment_path": "582672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582672.protein.info.v11.5.txt",
		        "node_list_path": "582672.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpKle1280Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. KLE1280 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpKle1280Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "997829.clusters.info.v11.5.txt",
		        "cluster_tree_path": "997829.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "997829.clusters.proteins.v11.5.txt",
		        "sequence_path": "997829.protein.sequences.v11.5.fa",
		        "enrichment_path": "997829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997829.protein.info.v11.5.txt",
		        "node_list_path": "997829.cluster.nodes.v11.5.txt",
		        "edge_list_path": "997829.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeobacterGallaeciensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter gallaeciensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterGallaeciensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423144.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423144.protein.info.v11.5.txt",
		        "node_list_path": "1423144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErysipelotrichaceaeBacteriumNk3d112(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium NK3D112 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelotrichaceaeBacteriumNk3d112", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "877415.protein.sequences.v11.5.fa",
		        "enrichment_path": "877415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877415.protein.info.v11.5.txt",
		        "node_list_path": "877415.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSubtilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSubtilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "224308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "224308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "224308.clusters.proteins.v11.5.txt",
		        "sequence_path": "224308.protein.sequences.v11.5.fa",
		        "enrichment_path": "224308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224308.protein.info.v11.5.txt",
		        "node_list_path": "224308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "224308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EmergenciaTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Emergencia timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmergenciaTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776384.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776384.protein.info.v11.5.txt",
		        "node_list_path": "1776384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CardiniumEndosymbiontCbtq1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cardinium endosymbiont cBtQ1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CardiniumEndosymbiontCbtq1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354314.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354314.protein.info.v11.5.txt",
		        "node_list_path": "1354314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyxococcusFulvus124b02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus fulvus 124B02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcusFulvus124b02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1334629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1334629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1334629.clusters.proteins.v11.5.txt",
		        "sequence_path": "1334629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1334629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1334629.protein.info.v11.5.txt",
		        "node_list_path": "1334629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1334629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumFallax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium fallax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumFallax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1793.protein.info.v11.5.txt",
		        "node_list_path": "1793.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAlbusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAlbusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67257.clusters.proteins.v11.5.txt",
		        "sequence_path": "67257.protein.sequences.v11.5.fa",
		        "enrichment_path": "67257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67257.protein.info.v11.5.txt",
		        "node_list_path": "67257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaGinsengiterrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengiterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaGinsengiterrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1462993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462993.protein.info.v11.5.txt",
		        "node_list_path": "1462993.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporolactobacillusInulinusCasdCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus inulinus CASD Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolactobacillusInulinusCasdCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1069536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1069536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1069536.clusters.proteins.v11.5.txt",
		        "sequence_path": "1069536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069536.protein.info.v11.5.txt",
		        "node_list_path": "1069536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1069536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromohalobacterJaponicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chromohalobacter japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromohalobacterJaponicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "223900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "223900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "223900.clusters.proteins.v11.5.txt",
		        "sequence_path": "223900.protein.sequences.v11.5.fa",
		        "enrichment_path": "223900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223900.protein.info.v11.5.txt",
		        "node_list_path": "223900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "223900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PodosporaAnserinaSMatCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Podospora anserina S mat+ Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PodosporaAnserinaSMatCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "515849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "515849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "515849.clusters.proteins.v11.5.txt",
		        "sequence_path": "515849.protein.sequences.v11.5.fa",
		        "enrichment_path": "515849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515849.protein.info.v11.5.txt",
		        "node_list_path": "515849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "515849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusDucreyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus ducreyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusDucreyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "233412.protein.sequences.v11.5.fa",
		        "enrichment_path": "233412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "233412.protein.info.v11.5.txt",
		        "node_list_path": "233412.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterAquaticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter aquaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterAquaticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354303.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354303.protein.info.v11.5.txt",
		        "node_list_path": "1354303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHtcc1062Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC1062 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHtcc1062Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "335992.clusters.info.v11.5.txt",
		        "cluster_tree_path": "335992.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "335992.clusters.proteins.v11.5.txt",
		        "sequence_path": "335992.protein.sequences.v11.5.fa",
		        "enrichment_path": "335992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335992.protein.info.v11.5.txt",
		        "node_list_path": "335992.cluster.nodes.v11.5.txt",
		        "edge_list_path": "335992.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalispirochaetaAmericana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalispirochaeta americana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalispirochaetaAmericana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "159291.protein.sequences.v11.5.fa",
		        "enrichment_path": "159291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "159291.protein.info.v11.5.txt",
		        "node_list_path": "159291.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharibacillusKuerlensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharibacillus kuerlensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharibacillusKuerlensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123226.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123226.protein.info.v11.5.txt",
		        "node_list_path": "1123226.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStreptomycesMassiliensisAp10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Streptomyces massiliensis AP10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStreptomycesMassiliensisAp10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211820.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211820.protein.info.v11.5.txt",
		        "node_list_path": "1211820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaAestuarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaAestuarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "327095.protein.sequences.v11.5.fa",
		        "enrichment_path": "327095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "327095.protein.info.v11.5.txt",
		        "node_list_path": "327095.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4132Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_41_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4132Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797789.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797789.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797789.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797789.protein.info.v11.5.txt",
		        "node_list_path": "1797789.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797789.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg19ftCombo5516Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_19FT_COMBO_55_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg19ftCombo5516Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797669.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797669.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797669.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797669.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797669.protein.info.v11.5.txt",
		        "node_list_path": "1797669.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797669.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AggregatibacterActinomycetemcomitans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterActinomycetemcomitans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "714.protein.sequences.v11.5.fa",
		        "enrichment_path": "714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "714.protein.info.v11.5.txt",
		        "node_list_path": "714.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchangiumSpCbG35(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archangium sp. Cb G35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchangiumSpCbG35", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1920190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920190.protein.info.v11.5.txt",
		        "node_list_path": "1920190.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusYonginensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus yonginensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusYonginensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1462996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462996.protein.info.v11.5.txt",
		        "node_list_path": "1462996.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifoxya2Full4719Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYA2_FULL_47_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxya2Full4719Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797994.protein.info.v11.5.txt",
		        "node_list_path": "1797994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParvibaculumLavamentivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parvibaculum lavamentivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvibaculumLavamentivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "402881.protein.sequences.v11.5.fa",
		        "enrichment_path": "402881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402881.protein.info.v11.5.txt",
		        "node_list_path": "402881.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmadillidiumVulgareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Armadillidium vulgare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmadillidiumVulgareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13347.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13347.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13347.clusters.proteins.v11.5.txt",
		        "sequence_path": "13347.protein.sequences.v11.5.fa",
		        "enrichment_path": "13347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13347.protein.info.v11.5.txt",
		        "node_list_path": "13347.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13347.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpTcm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. TCM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpTcm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "453246.protein.sequences.v11.5.fa",
		        "enrichment_path": "453246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "453246.protein.info.v11.5.txt",
		        "node_list_path": "453246.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTremblayaPrincepsPcvalCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tremblaya princeps PCVAL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTremblayaPrincepsPcvalCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1053648.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1053648.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1053648.clusters.proteins.v11.5.txt",
		        "sequence_path": "1053648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1053648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1053648.protein.info.v11.5.txt",
		        "node_list_path": "1053648.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1053648.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusArlettaeCvd059(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus arlettae CVD059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusArlettaeCvd059", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1212545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1212545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1212545.protein.info.v11.5.txt",
		        "node_list_path": "1212545.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotignumBalticumDsm7044(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotignum balticum DSM 7044 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotignumBalticumDsm7044", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304886.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304886.protein.info.v11.5.txt",
		        "node_list_path": "1304886.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumMeliloti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium meliloti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumMeliloti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266834.protein.sequences.v11.5.fa",
		        "enrichment_path": "266834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266834.protein.info.v11.5.txt",
		        "node_list_path": "266834.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaSpCnq490(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. CNQ490 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaSpCnq490", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1137271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137271.protein.info.v11.5.txt",
		        "node_list_path": "1137271.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp3211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp3211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1964449.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1964449.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1964449.clusters.proteins.v11.5.txt",
		        "sequence_path": "1964449.protein.sequences.v11.5.fa",
		        "enrichment_path": "1964449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1964449.protein.info.v11.5.txt",
		        "node_list_path": "1964449.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1964449.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerminiimonasArsenicoxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herminiimonas arsenicoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerminiimonasArsenicoxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "204773.protein.sequences.v11.5.fa",
		        "enrichment_path": "204773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "204773.protein.info.v11.5.txt",
		        "node_list_path": "204773.protein.complete.v11.5.txt"
		    }
		]
    )()

def KazachstaniaAfricanaCbs2517(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania africana CBS 2517 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KazachstaniaAfricanaCbs2517", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071382.protein.info.v11.5.txt",
		        "node_list_path": "1071382.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumPasteurianumDsm525Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum DSM525 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPasteurianumDsm525Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262449.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262449.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262449.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262449.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262449.protein.info.v11.5.txt",
		        "node_list_path": "1262449.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262449.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumMultivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum multivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumMultivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150621.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150621.protein.info.v11.5.txt",
		        "node_list_path": "1150621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag433(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:433 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag433", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262806.protein.info.v11.5.txt",
		        "node_list_path": "1262806.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusKodakarensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus kodakarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusKodakarensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69014.clusters.proteins.v11.5.txt",
		        "sequence_path": "69014.protein.sequences.v11.5.fa",
		        "enrichment_path": "69014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69014.protein.info.v11.5.txt",
		        "node_list_path": "69014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusHaemolyticusM21621Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M21621 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusHaemolyticusM21621Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1028805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1028805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1028805.clusters.proteins.v11.5.txt",
		        "sequence_path": "1028805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028805.protein.info.v11.5.txt",
		        "node_list_path": "1028805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1028805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylibiumSpNzgCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylibium sp. NZG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylibiumSpNzgCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1686064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1686064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1686064.clusters.proteins.v11.5.txt",
		        "sequence_path": "1686064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686064.protein.info.v11.5.txt",
		        "node_list_path": "1686064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1686064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcusVoltae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus voltae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusVoltae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "456320.protein.sequences.v11.5.fa",
		        "enrichment_path": "456320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "456320.protein.info.v11.5.txt",
		        "node_list_path": "456320.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermosiphoAtlanticusDsm15807(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermosipho atlanticus DSM 15807 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosiphoAtlanticusDsm15807", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123380.protein.info.v11.5.txt",
		        "node_list_path": "1123380.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiastellaKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Niastella koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiastellaKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "700598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "700598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "700598.clusters.proteins.v11.5.txt",
		        "sequence_path": "700598.protein.sequences.v11.5.fa",
		        "enrichment_path": "700598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "700598.protein.info.v11.5.txt",
		        "node_list_path": "700598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "700598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloplanusNatansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloplanus natans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloplanusNatansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926690.clusters.proteins.v11.5.txt",
		        "sequence_path": "926690.protein.sequences.v11.5.fa",
		        "enrichment_path": "926690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926690.protein.info.v11.5.txt",
		        "node_list_path": "926690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusMellis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mellis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMellis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218508.protein.info.v11.5.txt",
		        "node_list_path": "1218508.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerostipesSp494a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerostipes sp. 494a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerostipesSp494a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1261636.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261636.protein.info.v11.5.txt",
		        "node_list_path": "1261636.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaDaqingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena daqingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaDaqingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "588898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "588898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "588898.clusters.proteins.v11.5.txt",
		        "sequence_path": "588898.protein.sequences.v11.5.fa",
		        "enrichment_path": "588898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588898.protein.info.v11.5.txt",
		        "node_list_path": "588898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "588898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidaminococcusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidaminococcus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminococcusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852375.protein.info.v11.5.txt",
		        "node_list_path": "1852375.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseivirgaEchinicomitansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseivirga echinicomitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivirgaEchinicomitansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "296218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "296218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "296218.clusters.proteins.v11.5.txt",
		        "sequence_path": "296218.protein.sequences.v11.5.fa",
		        "enrichment_path": "296218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "296218.protein.info.v11.5.txt",
		        "node_list_path": "296218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "296218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifoxyb1Full3916(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYB1_FULL_39_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyb1Full3916", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801803.protein.info.v11.5.txt",
		        "node_list_path": "1801803.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioParadoxusArh1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio paradoxus ARh 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioParadoxusArh1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "713585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "713585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "713585.clusters.proteins.v11.5.txt",
		        "sequence_path": "713585.protein.sequences.v11.5.fa",
		        "enrichment_path": "713585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713585.protein.info.v11.5.txt",
		        "node_list_path": "713585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "713585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasResinovoransDsm21078(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas resinovorans DSM21078 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasResinovoransDsm21078", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123020.protein.info.v11.5.txt",
		        "node_list_path": "1123020.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816696.protein.info.v11.5.txt",
		        "node_list_path": "1816696.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosalsumZhilinaeDsm4017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosalsum zhilinae DSM 4017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosalsumZhilinaeDsm4017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679901.protein.sequences.v11.5.fa",
		        "enrichment_path": "679901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679901.protein.info.v11.5.txt",
		        "node_list_path": "679901.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusRossiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rossiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusRossiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1114972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1114972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1114972.clusters.proteins.v11.5.txt",
		        "sequence_path": "1114972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114972.protein.info.v11.5.txt",
		        "node_list_path": "1114972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1114972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GloeomargaritaLithophoraAlchichicaD10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gloeomargarita lithophora Alchichica-D10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeomargaritaLithophoraAlchichicaD10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1188229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1188229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1188229.clusters.proteins.v11.5.txt",
		        "sequence_path": "1188229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188229.protein.info.v11.5.txt",
		        "node_list_path": "1188229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1188229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactonifactorLongoviformisDsm17459(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactonifactor longoviformis DSM 17459 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactonifactorLongoviformisDsm17459", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122155.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122155.protein.info.v11.5.txt",
		        "node_list_path": "1122155.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpAsf356Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ASF356 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpAsf356Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "97138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "97138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "97138.clusters.proteins.v11.5.txt",
		        "sequence_path": "97138.protein.sequences.v11.5.fa",
		        "enrichment_path": "97138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97138.protein.info.v11.5.txt",
		        "node_list_path": "97138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "97138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc3862(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC3862 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc3862", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217705.protein.info.v11.5.txt",
		        "node_list_path": "1217705.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifcsplowo201Full6413Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO2_01_FULL_64_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201Full6413Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797948.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797948.protein.info.v11.5.txt",
		        "node_list_path": "1797948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf24387(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_43_87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf24387", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619086.protein.info.v11.5.txt",
		        "node_list_path": "1619086.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacterAestuariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterAestuariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "453582.clusters.info.v11.5.txt",
		        "cluster_tree_path": "453582.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "453582.clusters.proteins.v11.5.txt",
		        "sequence_path": "453582.protein.sequences.v11.5.fa",
		        "enrichment_path": "453582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "453582.protein.info.v11.5.txt",
		        "node_list_path": "453582.cluster.nodes.v11.5.txt",
		        "edge_list_path": "453582.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HenriciellaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Henriciella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HenriciellaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121949.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121949.protein.info.v11.5.txt",
		        "node_list_path": "1121949.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasSacchari(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasSacchari", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56458.protein.sequences.v11.5.fa",
		        "enrichment_path": "56458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56458.protein.info.v11.5.txt",
		        "node_list_path": "56458.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumKashiwanohensePv202(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium kashiwanohense PV20-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumKashiwanohensePv202", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1447716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1447716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1447716.protein.info.v11.5.txt",
		        "node_list_path": "1447716.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaJiangxiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia jiangxiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaJiangxiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206731.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206731.protein.info.v11.5.txt",
		        "node_list_path": "1206731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasDaejeonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas daejeonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasDaejeonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "659018.protein.sequences.v11.5.fa",
		        "enrichment_path": "659018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "659018.protein.info.v11.5.txt",
		        "node_list_path": "659018.protein.complete.v11.5.txt"
		    }
		]
    )()

def AdvenellaKashmirensisW13003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Advenella kashmirensis W13003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AdvenellaKashmirensisW13003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1424334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1424334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1424334.clusters.proteins.v11.5.txt",
		        "sequence_path": "1424334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1424334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1424334.protein.info.v11.5.txt",
		        "node_list_path": "1424334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1424334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumRifcsphigho201Full6617Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RIFCSPHIGHO2_01_FULL_66_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumRifcsphigho201Full6617Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801712.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801712.protein.info.v11.5.txt",
		        "node_list_path": "1801712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusSpS5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. S5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusSpS5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1462527.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1462527.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1462527.clusters.proteins.v11.5.txt",
		        "sequence_path": "1462527.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462527.protein.info.v11.5.txt",
		        "node_list_path": "1462527.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1462527.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DethiosulfatibacterAminovoransDsm17477(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dethiosulfatibacter aminovorans DSM 17477 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DethiosulfatibacterAminovoransDsm17477", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121476.protein.info.v11.5.txt",
		        "node_list_path": "1121476.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterSpRm16704Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM16704 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSpRm16704Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500960.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500960.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500960.protein.info.v11.5.txt",
		        "node_list_path": "1500960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrapisisporaPhaffii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora phaffii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrapisisporaPhaffii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "113608.protein.sequences.v11.5.fa",
		        "enrichment_path": "113608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113608.protein.info.v11.5.txt",
		        "node_list_path": "113608.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusMeridiei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus meridiei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusMeridiei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "768704.protein.sequences.v11.5.fa",
		        "enrichment_path": "768704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768704.protein.info.v11.5.txt",
		        "node_list_path": "768704.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaKristensenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia kristensenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaKristensenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28152.protein.sequences.v11.5.fa",
		        "enrichment_path": "28152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28152.protein.info.v11.5.txt",
		        "node_list_path": "28152.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaHalifaxensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella halifaxensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaHalifaxensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "458817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "458817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "458817.clusters.proteins.v11.5.txt",
		        "sequence_path": "458817.protein.sequences.v11.5.fa",
		        "enrichment_path": "458817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "458817.protein.info.v11.5.txt",
		        "node_list_path": "458817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "458817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloplasmaContractileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloplasma contractile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloplasmaContractileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033810.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033810.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033810.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033810.protein.info.v11.5.txt",
		        "node_list_path": "1033810.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033810.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesHordeovulnerisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces hordeovulneris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesHordeovulnerisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52770.clusters.proteins.v11.5.txt",
		        "sequence_path": "52770.protein.sequences.v11.5.fa",
		        "enrichment_path": "52770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52770.protein.info.v11.5.txt",
		        "node_list_path": "52770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerosporobacterMobilisDsm15930Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerosporobacter mobilis DSM 15930 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerosporobacterMobilisDsm15930Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120996.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120996.protein.info.v11.5.txt",
		        "node_list_path": "1120996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSp520p1No423Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 520P1 No. 423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSp520p1No423Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1690037.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1690037.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1690037.clusters.proteins.v11.5.txt",
		        "sequence_path": "1690037.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690037.protein.info.v11.5.txt",
		        "node_list_path": "1690037.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1690037.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpJceCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJceCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461580.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461580.protein.info.v11.5.txt",
		        "node_list_path": "1461580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpHgh0039(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. HGH0039 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpHgh0039", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1078505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078505.protein.info.v11.5.txt",
		        "node_list_path": "1078505.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusSpFs40622Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus sp. FS40622 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusSpFs40622Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644281.clusters.proteins.v11.5.txt",
		        "sequence_path": "644281.protein.sequences.v11.5.fa",
		        "enrichment_path": "644281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644281.protein.info.v11.5.txt",
		        "node_list_path": "644281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSp1315(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 13-15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSp1315", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761891.protein.info.v11.5.txt",
		        "node_list_path": "1761891.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraTerpstraeSerovarHualinStrLt1133Atcc700639Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira terpstrae serovar Hualin str. LT 11-33 ATCC 700639 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraTerpstraeSerovarHualinStrLt1133Atcc700639Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1257025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1257025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1257025.clusters.proteins.v11.5.txt",
		        "sequence_path": "1257025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1257025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1257025.protein.info.v11.5.txt",
		        "node_list_path": "1257025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1257025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumPolymorphum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum polymorphum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumPolymorphum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "393480.protein.sequences.v11.5.fa",
		        "enrichment_path": "393480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393480.protein.info.v11.5.txt",
		        "node_list_path": "393480.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumOceanicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium oceanicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumOceanicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1670800.protein.sequences.v11.5.fa",
		        "enrichment_path": "1670800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1670800.protein.info.v11.5.txt",
		        "node_list_path": "1670800.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesGaoshouyiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces gaoshouyii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesGaoshouyiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1960083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1960083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1960083.clusters.proteins.v11.5.txt",
		        "sequence_path": "1960083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1960083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1960083.protein.info.v11.5.txt",
		        "node_list_path": "1960083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1960083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterSpBisph1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter sp. Bisph1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterSpBisph1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1274399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1274399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1274399.clusters.proteins.v11.5.txt",
		        "sequence_path": "1274399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274399.protein.info.v11.5.txt",
		        "node_list_path": "1274399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1274399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpPamc26561(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. PAMC 26561 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpPamc26561", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1795043.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795043.protein.info.v11.5.txt",
		        "node_list_path": "1795043.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterDokdonensisDsw74(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter dokdonensis DSW-74 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterDokdonensisDsw74", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1300349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300349.protein.info.v11.5.txt",
		        "node_list_path": "1300349.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaCatarrhalisBbh18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella catarrhalis BBH18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaCatarrhalisBbh18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236608.protein.info.v11.5.txt",
		        "node_list_path": "1236608.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpKnhs205(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs205 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpKnhs205", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449050.protein.info.v11.5.txt",
		        "node_list_path": "1449050.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpPamc26561Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. PAMC 26561 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpPamc26561Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1795043.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1795043.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1795043.clusters.proteins.v11.5.txt",
		        "sequence_path": "1795043.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795043.protein.info.v11.5.txt",
		        "node_list_path": "1795043.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1795043.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioOrientalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioOrientalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675816.protein.sequences.v11.5.fa",
		        "enrichment_path": "675816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675816.protein.info.v11.5.txt",
		        "node_list_path": "675816.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusRusselliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus russellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusRusselliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "215200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "215200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "215200.clusters.proteins.v11.5.txt",
		        "sequence_path": "215200.protein.sequences.v11.5.fa",
		        "enrichment_path": "215200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215200.protein.info.v11.5.txt",
		        "node_list_path": "215200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "215200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevundimonasBacteroides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas bacteroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasBacteroides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121124.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121124.protein.info.v11.5.txt",
		        "node_list_path": "1121124.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaAnanatisLmg20103(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea ananatis LMG20103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaAnanatisLmg20103", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "706191.protein.sequences.v11.5.fa",
		        "enrichment_path": "706191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706191.protein.info.v11.5.txt",
		        "node_list_path": "706191.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzospirillumLipoferum4bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum lipoferum 4B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumLipoferum4bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "862719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "862719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "862719.clusters.proteins.v11.5.txt",
		        "sequence_path": "862719.protein.sequences.v11.5.fa",
		        "enrichment_path": "862719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862719.protein.info.v11.5.txt",
		        "node_list_path": "862719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "862719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UstilagoHordeiUh48574Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ustilago hordei Uh4857-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UstilagoHordeiUh48574Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1128400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1128400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1128400.clusters.proteins.v11.5.txt",
		        "sequence_path": "1128400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128400.protein.info.v11.5.txt",
		        "node_list_path": "1128400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1128400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiAtcc8739Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli ATCC8739 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiAtcc8739Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "481805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "481805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "481805.clusters.proteins.v11.5.txt",
		        "sequence_path": "481805.protein.sequences.v11.5.fa",
		        "enrichment_path": "481805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481805.protein.info.v11.5.txt",
		        "node_list_path": "481805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "481805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaSenegalensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSenegalensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "929794.clusters.info.v11.5.txt",
		        "cluster_tree_path": "929794.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "929794.clusters.proteins.v11.5.txt",
		        "sequence_path": "929794.protein.sequences.v11.5.fa",
		        "enrichment_path": "929794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929794.protein.info.v11.5.txt",
		        "node_list_path": "929794.cluster.nodes.v11.5.txt",
		        "edge_list_path": "929794.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZhongshaniaAliphaticivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zhongshania aliphaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZhongshaniaAliphaticivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1470434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470434.protein.info.v11.5.txt",
		        "node_list_path": "1470434.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaNautarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella nautarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaNautarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45070.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45070.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45070.clusters.proteins.v11.5.txt",
		        "sequence_path": "45070.protein.sequences.v11.5.fa",
		        "enrichment_path": "45070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45070.protein.info.v11.5.txt",
		        "node_list_path": "45070.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45070.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaGranulomatisDsm19156Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia granulomatis DSM 19156 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaGranulomatisDsm19156Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122190.protein.info.v11.5.txt",
		        "node_list_path": "1122190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ScophthalmusMaximusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scophthalmus maximus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScophthalmusMaximusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52904.clusters.proteins.v11.5.txt",
		        "sequence_path": "52904.protein.sequences.v11.5.fa",
		        "enrichment_path": "52904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52904.protein.info.v11.5.txt",
		        "node_list_path": "52904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusWulumuqiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus wulumuqiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusWulumuqiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1567107.protein.sequences.v11.5.fa",
		        "enrichment_path": "1567107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1567107.protein.info.v11.5.txt",
		        "node_list_path": "1567107.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterLutaoensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter lutaoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterLutaoensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "135739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "135739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "135739.clusters.proteins.v11.5.txt",
		        "sequence_path": "135739.protein.sequences.v11.5.fa",
		        "enrichment_path": "135739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "135739.protein.info.v11.5.txt",
		        "node_list_path": "135739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "135739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlebsiellaQuasipneumoniaeSubspSimilipneumoniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella quasipneumoniae subsp. similipneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaQuasipneumoniaeSubspSimilipneumoniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463164.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463164.protein.info.v11.5.txt",
		        "node_list_path": "1463164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaSpScn7327Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. SCN 73-27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaSpScn7327Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660132.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660132.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660132.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660132.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660132.protein.info.v11.5.txt",
		        "node_list_path": "1660132.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660132.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPactum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces pactum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPactum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68249.protein.sequences.v11.5.fa",
		        "enrichment_path": "68249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68249.protein.info.v11.5.txt",
		        "node_list_path": "68249.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPenetransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma penetrans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPenetransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272633.clusters.proteins.v11.5.txt",
		        "sequence_path": "272633.protein.sequences.v11.5.fa",
		        "enrichment_path": "272633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272633.protein.info.v11.5.txt",
		        "node_list_path": "272633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaSpCag380Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:380 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSpCag380Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262946.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262946.protein.info.v11.5.txt",
		        "node_list_path": "1262946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpP2bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. P2b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpP2bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1938741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1938741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1938741.clusters.proteins.v11.5.txt",
		        "sequence_path": "1938741.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938741.protein.info.v11.5.txt",
		        "node_list_path": "1938741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1938741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpRoot418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. Root418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpRoot418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736532.protein.info.v11.5.txt",
		        "node_list_path": "1736532.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusParabrevisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus parabrevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParabrevisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267003.protein.info.v11.5.txt",
		        "node_list_path": "1267003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetallosphaeraHakonensisJcm8857Dsm7519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metallosphaera hakonensis JCM 8857 DSM 7519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetallosphaeraHakonensisJcm8857Dsm7519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293036.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293036.protein.info.v11.5.txt",
		        "node_list_path": "1293036.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioXiamenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioXiamenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "861298.clusters.info.v11.5.txt",
		        "cluster_tree_path": "861298.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "861298.clusters.proteins.v11.5.txt",
		        "sequence_path": "861298.protein.sequences.v11.5.fa",
		        "enrichment_path": "861298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861298.protein.info.v11.5.txt",
		        "node_list_path": "861298.cluster.nodes.v11.5.txt",
		        "edge_list_path": "861298.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0330(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0330", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "653386.protein.sequences.v11.5.fa",
		        "enrichment_path": "653386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "653386.protein.info.v11.5.txt",
		        "node_list_path": "653386.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifcsphigho212Full6320(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPHIGHO2_12_FULL_63_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifcsphigho212Full6320", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797558.protein.info.v11.5.txt",
		        "node_list_path": "1797558.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloquadratumWalsbyiJ07hqw1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi J07HQW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloquadratumWalsbyiJ07hqw1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1238424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1238424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1238424.clusters.proteins.v11.5.txt",
		        "sequence_path": "1238424.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238424.protein.info.v11.5.txt",
		        "node_list_path": "1238424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1238424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSiamensisKctc13613(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus siamensis KCTC 13613 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSiamensisKctc13613", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1177185.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177185.protein.info.v11.5.txt",
		        "node_list_path": "1177185.protein.complete.v11.5.txt"
		    }
		]
    )()

def RathayibacterSpLeaf296(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rathayibacter sp. Leaf296 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RathayibacterSpLeaf296", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736327.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736327.protein.info.v11.5.txt",
		        "node_list_path": "1736327.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSp99(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. 99 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSp99", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163419.protein.info.v11.5.txt",
		        "node_list_path": "1163419.protein.complete.v11.5.txt"
		    }
		]
    )()

def AliivibrioSalmonicida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aliivibrio salmonicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliivibrioSalmonicida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316275.protein.sequences.v11.5.fa",
		        "enrichment_path": "316275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316275.protein.info.v11.5.txt",
		        "node_list_path": "316275.protein.complete.v11.5.txt"
		    }
		]
    )()

def HippeaSpKm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hippea sp. KM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HippeaSpKm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "944481.protein.sequences.v11.5.fa",
		        "enrichment_path": "944481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944481.protein.info.v11.5.txt",
		        "node_list_path": "944481.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKomeilibacteriaBacteriumRifoxyc2Full4512Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFOXYC2_FULL_45_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifoxyc2Full4512Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798556.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798556.protein.info.v11.5.txt",
		        "node_list_path": "1798556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesTuricensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces turicensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesTuricensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883077.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883077.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883077.clusters.proteins.v11.5.txt",
		        "sequence_path": "883077.protein.sequences.v11.5.fa",
		        "enrichment_path": "883077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883077.protein.info.v11.5.txt",
		        "node_list_path": "883077.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883077.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumCaseiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium casei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumCaseiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229781.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229781.protein.info.v11.5.txt",
		        "node_list_path": "1229781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollinsellaSp609Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collinsella sp. 60_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaSp609Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896993.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896993.protein.info.v11.5.txt",
		        "node_list_path": "1896993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumChkci006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium CHKCI006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumChkci006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1780379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780379.protein.info.v11.5.txt",
		        "node_list_path": "1780379.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisSalinaYim90010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis salina YIM 90010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisSalinaYim90010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246485.protein.info.v11.5.txt",
		        "node_list_path": "1246485.protein.complete.v11.5.txt"
		    }
		]
    )()

def FluviicolaTaffensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fluviicola taffensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FluviicolaTaffensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "755732.protein.sequences.v11.5.fa",
		        "enrichment_path": "755732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "755732.protein.info.v11.5.txt",
		        "node_list_path": "755732.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumGwb24920Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWB2_49_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumGwb24920Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797612.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797612.protein.info.v11.5.txt",
		        "node_list_path": "1797612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TheropithecusGeladaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Theropithecus gelada Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheropithecusGeladaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9565.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9565.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9565.clusters.proteins.v11.5.txt",
		        "sequence_path": "9565.protein.sequences.v11.5.fa",
		        "enrichment_path": "9565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9565.protein.info.v11.5.txt",
		        "node_list_path": "9565.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9565.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumGwc25713Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWC2_57_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumGwc25713Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801697.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801697.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801697.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801697.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801697.protein.info.v11.5.txt",
		        "node_list_path": "1801697.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801697.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusHermanniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus hermanniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusHermanniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "249189.protein.sequences.v11.5.fa",
		        "enrichment_path": "249189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "249189.protein.info.v11.5.txt",
		        "node_list_path": "249189.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConiophoraPuteana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coniophora puteana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConiophoraPuteana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "80637.protein.sequences.v11.5.fa",
		        "enrichment_path": "80637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80637.protein.info.v11.5.txt",
		        "node_list_path": "80637.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillibacterSpPc13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. PC13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSpPc13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855299.protein.info.v11.5.txt",
		        "node_list_path": "1855299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpC04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. C04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpC04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945857.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945857.protein.info.v11.5.txt",
		        "node_list_path": "1945857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSp142(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. 142 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSp142", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235790.protein.info.v11.5.txt",
		        "node_list_path": "1235790.protein.complete.v11.5.txt"
		    }
		]
    )()

def LabrenziaAggregataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Labrenzia aggregata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrenziaAggregataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "384765.clusters.info.v11.5.txt",
		        "cluster_tree_path": "384765.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "384765.clusters.proteins.v11.5.txt",
		        "sequence_path": "384765.protein.sequences.v11.5.fa",
		        "enrichment_path": "384765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "384765.protein.info.v11.5.txt",
		        "node_list_path": "384765.cluster.nodes.v11.5.txt",
		        "edge_list_path": "384765.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKullabergensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kullabergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKullabergensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218493.protein.info.v11.5.txt",
		        "node_list_path": "1218493.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAc2029Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAc2029Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1458462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1458462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1458462.clusters.proteins.v11.5.txt",
		        "sequence_path": "1458462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458462.protein.info.v11.5.txt",
		        "node_list_path": "1458462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1458462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoanaerobacterStomatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoanaerobacter stomatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoanaerobacterStomatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "796937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "796937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "796937.clusters.proteins.v11.5.txt",
		        "sequence_path": "796937.protein.sequences.v11.5.fa",
		        "enrichment_path": "796937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796937.protein.info.v11.5.txt",
		        "node_list_path": "796937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "796937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsUnilateralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps unilateralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsUnilateralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "268505.protein.sequences.v11.5.fa",
		        "enrichment_path": "268505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "268505.protein.info.v11.5.txt",
		        "node_list_path": "268505.protein.complete.v11.5.txt"
		    }
		]
    )()

def RiemerellaAnatipestifer(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Riemerella anatipestifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RiemerellaAnatipestifer", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "992406.protein.sequences.v11.5.fa",
		        "enrichment_path": "992406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "992406.protein.info.v11.5.txt",
		        "node_list_path": "992406.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumDentium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium dentium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumDentium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "401473.protein.sequences.v11.5.fa",
		        "enrichment_path": "401473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "401473.protein.info.v11.5.txt",
		        "node_list_path": "401473.protein.complete.v11.5.txt"
		    }
		]
    )()

def BeauveriaBassianaD15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Beauveria bassiana D1-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeauveriaBassianaD15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1245745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245745.protein.info.v11.5.txt",
		        "node_list_path": "1245745.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumRifoxyb1Full4712Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFOXYB1_FULL_47_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifoxyb1Full4712Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797264.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797264.protein.info.v11.5.txt",
		        "node_list_path": "1797264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrnithinibacillusContaminansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ornithinibacillus contaminans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithinibacillusContaminansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "694055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "694055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "694055.clusters.proteins.v11.5.txt",
		        "sequence_path": "694055.protein.sequences.v11.5.fa",
		        "enrichment_path": "694055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694055.protein.info.v11.5.txt",
		        "node_list_path": "694055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "694055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioMytiliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio mytili Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioMytiliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "50718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "50718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "50718.clusters.proteins.v11.5.txt",
		        "sequence_path": "50718.protein.sequences.v11.5.fa",
		        "enrichment_path": "50718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50718.protein.info.v11.5.txt",
		        "node_list_path": "50718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "50718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumRbg134610(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RBG_13_46_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumRbg134610", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801961.protein.info.v11.5.txt",
		        "node_list_path": "1801961.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaNativaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichinella nativa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaNativaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6335.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6335.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6335.clusters.proteins.v11.5.txt",
		        "sequence_path": "6335.protein.sequences.v11.5.fa",
		        "enrichment_path": "6335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6335.protein.info.v11.5.txt",
		        "node_list_path": "6335.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6335.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrinaliumEpipsammumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crinalium epipsammum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrinaliumEpipsammumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173022.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173022.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173022.protein.info.v11.5.txt",
		        "node_list_path": "1173022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaFlavescensSk114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria flavescens SK114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaFlavescensSk114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596320.protein.sequences.v11.5.fa",
		        "enrichment_path": "596320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596320.protein.info.v11.5.txt",
		        "node_list_path": "596320.protein.complete.v11.5.txt"
		    }
		]
    )()

def BaudoiniaCompniacensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Baudoinia compniacensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BaudoiniaCompniacensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "430998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "430998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "430998.clusters.proteins.v11.5.txt",
		        "sequence_path": "430998.protein.sequences.v11.5.fa",
		        "enrichment_path": "430998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "430998.protein.info.v11.5.txt",
		        "node_list_path": "430998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "430998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf399(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf399 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf399", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736364.protein.info.v11.5.txt",
		        "node_list_path": "1736364.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumGwe23210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWE2_32_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumGwe23210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797681.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797681.protein.info.v11.5.txt",
		        "node_list_path": "1797681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterPylori26695(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori 26695 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterPylori26695", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "85962.protein.sequences.v11.5.fa",
		        "enrichment_path": "85962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85962.protein.info.v11.5.txt",
		        "node_list_path": "85962.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterSp1485e(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. 1485E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSp1485e", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1244531.protein.sequences.v11.5.fa",
		        "enrichment_path": "1244531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1244531.protein.info.v11.5.txt",
		        "node_list_path": "1244531.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolinellaSuccinogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolinella succinogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolinellaSuccinogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "273121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "273121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "273121.clusters.proteins.v11.5.txt",
		        "sequence_path": "273121.protein.sequences.v11.5.fa",
		        "enrichment_path": "273121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273121.protein.info.v11.5.txt",
		        "node_list_path": "273121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "273121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAuris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma auris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAuris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1188233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188233.protein.info.v11.5.txt",
		        "node_list_path": "1188233.protein.complete.v11.5.txt"
		    }
		]
    )()

def NesterenkoniaSpAn1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. AN1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesterenkoniaSpAn1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "652017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "652017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "652017.clusters.proteins.v11.5.txt",
		        "sequence_path": "652017.protein.sequences.v11.5.fa",
		        "enrichment_path": "652017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "652017.protein.info.v11.5.txt",
		        "node_list_path": "652017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "652017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsplowo202Full5710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO2_02_FULL_57_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo202Full5710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798299.protein.info.v11.5.txt",
		        "node_list_path": "1798299.protein.complete.v11.5.txt"
		    }
		]
    )()

def GalerinaMarginataCbs33988Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Galerina marginata CBS 339.88 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GalerinaMarginataCbs33988Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "685588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "685588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "685588.clusters.proteins.v11.5.txt",
		        "sequence_path": "685588.protein.sequences.v11.5.fa",
		        "enrichment_path": "685588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "685588.protein.info.v11.5.txt",
		        "node_list_path": "685588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "685588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaSg(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Sg graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaSg", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "198804.protein.sequences.v11.5.fa",
		        "enrichment_path": "198804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198804.protein.info.v11.5.txt",
		        "node_list_path": "198804.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumGuttoideum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum guttoideum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumGuttoideum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298920.protein.info.v11.5.txt",
		        "node_list_path": "1298920.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalocynthiibacterArcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halocynthiibacter arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalocynthiibacterArcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1579316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579316.protein.info.v11.5.txt",
		        "node_list_path": "1579316.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumTibeticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium tibeticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumTibeticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "501024.protein.sequences.v11.5.fa",
		        "enrichment_path": "501024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "501024.protein.info.v11.5.txt",
		        "node_list_path": "501024.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerticilliumNonalfalfae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verticillium nonalfalfae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerticilliumNonalfalfae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1051616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051616.protein.info.v11.5.txt",
		        "node_list_path": "1051616.protein.complete.v11.5.txt"
		    }
		]
    )()

def BalaenopteraAcutorostrataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Balaenoptera acutorostrata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BalaenopteraAcutorostrataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9767.clusters.proteins.v11.5.txt",
		        "sequence_path": "9767.protein.sequences.v11.5.fa",
		        "enrichment_path": "9767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9767.protein.info.v11.5.txt",
		        "node_list_path": "9767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag1193Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1193 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag1193Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262771.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262771.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262771.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262771.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262771.protein.info.v11.5.txt",
		        "node_list_path": "1262771.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262771.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumNrl2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium NRL2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumNrl2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1862950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1862950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1862950.clusters.proteins.v11.5.txt",
		        "sequence_path": "1862950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1862950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1862950.protein.info.v11.5.txt",
		        "node_list_path": "1862950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1862950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsphigho202Full5223(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_52_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full5223", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802274.protein.info.v11.5.txt",
		        "node_list_path": "1802274.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusCanintestiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus canintestini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusCanintestiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "317010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "317010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "317010.clusters.proteins.v11.5.txt",
		        "sequence_path": "317010.protein.sequences.v11.5.fa",
		        "enrichment_path": "317010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317010.protein.info.v11.5.txt",
		        "node_list_path": "317010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "317010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSpNdb2meth4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. NDB2Meth4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSpNdb2meth4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1892846.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1892846.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1892846.clusters.proteins.v11.5.txt",
		        "sequence_path": "1892846.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892846.protein.info.v11.5.txt",
		        "node_list_path": "1892846.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1892846.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpRoot335(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. Root335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpRoot335", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736517.protein.info.v11.5.txt",
		        "node_list_path": "1736517.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumRubensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium rubens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumRubensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1108849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1108849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1108849.clusters.proteins.v11.5.txt",
		        "sequence_path": "1108849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1108849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1108849.protein.info.v11.5.txt",
		        "node_list_path": "1108849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1108849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PneumocystisJiroveciiRu7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii RU7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PneumocystisJiroveciiRu7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408657.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408657.protein.info.v11.5.txt",
		        "node_list_path": "1408657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LottiaGigantea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lottia gigantea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LottiaGigantea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "225164.protein.sequences.v11.5.fa",
		        "enrichment_path": "225164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225164.protein.info.v11.5.txt",
		        "node_list_path": "225164.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeokomagataeaThailandicaNbrc106555Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neokomagataea thailandica NBRC 106555 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeokomagataeaThailandicaNbrc106555Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223520.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223520.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223520.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223520.protein.info.v11.5.txt",
		        "node_list_path": "1223520.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223520.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobiformaLacisalsiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobiforma lacisalsi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobiformaLacisalsiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "358396.clusters.info.v11.5.txt",
		        "cluster_tree_path": "358396.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "358396.clusters.proteins.v11.5.txt",
		        "sequence_path": "358396.protein.sequences.v11.5.fa",
		        "enrichment_path": "358396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "358396.protein.info.v11.5.txt",
		        "node_list_path": "358396.cluster.nodes.v11.5.txt",
		        "edge_list_path": "358396.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PersicobacterSpJzb09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Persicobacter sp. JZB09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PersicobacterSpJzb09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1085624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1085624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1085624.protein.info.v11.5.txt",
		        "node_list_path": "1085624.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurvibacterSpGwa264110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter sp. GWA2_64_110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurvibacterSpGwa264110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797747.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797747.protein.info.v11.5.txt",
		        "node_list_path": "1797747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaMojavensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila mojavensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaMojavensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7230.clusters.proteins.v11.5.txt",
		        "sequence_path": "7230.protein.sequences.v11.5.fa",
		        "enrichment_path": "7230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7230.protein.info.v11.5.txt",
		        "node_list_path": "7230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpJs666Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. JS666 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpJs666Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "296591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "296591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "296591.clusters.proteins.v11.5.txt",
		        "sequence_path": "296591.protein.sequences.v11.5.fa",
		        "enrichment_path": "296591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "296591.protein.info.v11.5.txt",
		        "node_list_path": "296591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "296591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwe24214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWE2_42_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwe24214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618952.protein.info.v11.5.txt",
		        "node_list_path": "1618952.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerorhabdusFurcosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerorhabdus furcosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerorhabdusFurcosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118967.protein.sequences.v11.5.fa",
		        "enrichment_path": "118967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118967.protein.info.v11.5.txt",
		        "node_list_path": "118967.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaHarenaeNbrc108248Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia harenae NBRC 108248 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaHarenaeNbrc108248Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210074.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210074.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210074.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210074.protein.info.v11.5.txt",
		        "node_list_path": "1210074.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210074.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAdlerbacteriaBacteriumRifcsphigho202Full5217(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPHIGHO2_02_FULL_52_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsphigho202Full5217", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797240.protein.info.v11.5.txt",
		        "node_list_path": "1797240.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumLeiognathiLrivu41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi lrivu41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumLeiognathiLrivu41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1248232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1248232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1248232.clusters.proteins.v11.5.txt",
		        "sequence_path": "1248232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1248232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1248232.protein.info.v11.5.txt",
		        "node_list_path": "1248232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1248232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobisporaSpAtccPta5024Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbispora sp. ATCC PTA-5024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobisporaSpAtccPta5024Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316330.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316330.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316330.clusters.proteins.v11.5.txt",
		        "sequence_path": "316330.protein.sequences.v11.5.fa",
		        "enrichment_path": "316330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316330.protein.info.v11.5.txt",
		        "node_list_path": "316330.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316330.protein.cluster.v11.5.txt"
		    }
		]
    )()

def Sar86ClusterBacteriumSar86aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium SAR86A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar86ClusterBacteriumSar86aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123866.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123866.protein.info.v11.5.txt",
		        "node_list_path": "1123866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesHarbinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces harbinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesHarbinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1176198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1176198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1176198.protein.info.v11.5.txt",
		        "node_list_path": "1176198.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfomicrobiumApsheronumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium apsheronum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfomicrobiumApsheronumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52560.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52560.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52560.clusters.proteins.v11.5.txt",
		        "sequence_path": "52560.protein.sequences.v11.5.fa",
		        "enrichment_path": "52560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52560.protein.info.v11.5.txt",
		        "node_list_path": "52560.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52560.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpMadar(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. MADAR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpMadar", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1074889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1074889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1074889.protein.info.v11.5.txt",
		        "node_list_path": "1074889.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureimonasAltamirensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas altamirensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasAltamirensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "370622.protein.sequences.v11.5.fa",
		        "enrichment_path": "370622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "370622.protein.info.v11.5.txt",
		        "node_list_path": "370622.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumSpRac02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. RAC02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumSpRac02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1842534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842534.protein.info.v11.5.txt",
		        "node_list_path": "1842534.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixibacteriaBacteriumSm23732Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_73_2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm23732Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703426.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703426.protein.info.v11.5.txt",
		        "node_list_path": "1703426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfitobacteriumChlororespiransDsm11544(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium chlororespirans DSM 11544 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitobacteriumChlororespiransDsm11544", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121395.protein.info.v11.5.txt",
		        "node_list_path": "1121395.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParameciumTetraureliaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paramecium tetraurelia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParameciumTetraureliaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5888.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5888.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5888.clusters.proteins.v11.5.txt",
		        "sequence_path": "5888.protein.sequences.v11.5.fa",
		        "enrichment_path": "5888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5888.protein.info.v11.5.txt",
		        "node_list_path": "5888.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5888.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpGa0074129(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Ga0074129 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpGa0074129", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752219.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752219.protein.info.v11.5.txt",
		        "node_list_path": "1752219.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumGlacieiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium glaciei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumGlacieiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1685010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1685010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1685010.clusters.proteins.v11.5.txt",
		        "sequence_path": "1685010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685010.protein.info.v11.5.txt",
		        "node_list_path": "1685010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1685010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcticibacterEurypsychrophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcticibacter eurypsychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcticibacterEurypsychrophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434752.protein.info.v11.5.txt",
		        "node_list_path": "1434752.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc5600(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 5600 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc5600", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1960940.protein.sequences.v11.5.fa",
		        "enrichment_path": "1960940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1960940.protein.info.v11.5.txt",
		        "node_list_path": "1960940.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSonorensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sonorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSonorensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1274524.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274524.protein.info.v11.5.txt",
		        "node_list_path": "1274524.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusChristensenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus christensenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusChristensenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "87541.protein.sequences.v11.5.fa",
		        "enrichment_path": "87541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "87541.protein.info.v11.5.txt",
		        "node_list_path": "87541.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpHr7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. HR7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpHr7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1509403.protein.sequences.v11.5.fa",
		        "enrichment_path": "1509403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1509403.protein.info.v11.5.txt",
		        "node_list_path": "1509403.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaProteobacteriumKb13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return beta proteobacterium KB13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaProteobacteriumKb13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314607.protein.sequences.v11.5.fa",
		        "enrichment_path": "314607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314607.protein.info.v11.5.txt",
		        "node_list_path": "314607.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasCorrugataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas corrugata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCorrugataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1316927.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1316927.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1316927.clusters.proteins.v11.5.txt",
		        "sequence_path": "1316927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1316927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1316927.protein.info.v11.5.txt",
		        "node_list_path": "1316927.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1316927.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumProteolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium proteolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumProteolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1903952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903952.protein.info.v11.5.txt",
		        "node_list_path": "1903952.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag485(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:485 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag485", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262927.protein.info.v11.5.txt",
		        "node_list_path": "1262927.protein.complete.v11.5.txt"
		    }
		]
    )()

def FictibacillusArsenicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fictibacillus arsenicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FictibacillusArsenicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "255247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "255247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "255247.clusters.proteins.v11.5.txt",
		        "sequence_path": "255247.protein.sequences.v11.5.fa",
		        "enrichment_path": "255247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "255247.protein.info.v11.5.txt",
		        "node_list_path": "255247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "255247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasSp25b141Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. 25B141 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSp25b141Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280946.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280946.protein.info.v11.5.txt",
		        "node_list_path": "1280946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PetrimonasMucosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Petrimonas mucosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PetrimonasMucosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1642646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1642646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1642646.protein.info.v11.5.txt",
		        "node_list_path": "1642646.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSp172e8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. 172E8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSp172e8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1535287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1535287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1535287.protein.info.v11.5.txt",
		        "node_list_path": "1535287.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassilibacteriumSenegalenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilibacterium senegalense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassilibacteriumSenegalenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1632858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1632858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1632858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1632858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1632858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1632858.protein.info.v11.5.txt",
		        "node_list_path": "1632858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1632858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhocaeicolaAbscessusCcug55929Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phocaeicola abscessus CCUG 55929 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhocaeicolaAbscessusCcug55929Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1204719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1204719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1204719.clusters.proteins.v11.5.txt",
		        "sequence_path": "1204719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1204719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1204719.protein.info.v11.5.txt",
		        "node_list_path": "1204719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1204719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GallionellaCapsiferriformansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallionella capsiferriformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallionellaCapsiferriformansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "395494.clusters.info.v11.5.txt",
		        "cluster_tree_path": "395494.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "395494.clusters.proteins.v11.5.txt",
		        "sequence_path": "395494.protein.sequences.v11.5.fa",
		        "enrichment_path": "395494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395494.protein.info.v11.5.txt",
		        "node_list_path": "395494.cluster.nodes.v11.5.txt",
		        "edge_list_path": "395494.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSymbiosumWal14673Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium symbiosum WAL14673 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSymbiosumWal14673Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742741.clusters.proteins.v11.5.txt",
		        "sequence_path": "742741.protein.sequences.v11.5.fa",
		        "enrichment_path": "742741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742741.protein.info.v11.5.txt",
		        "node_list_path": "742741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasPhenolica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas phenolica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasPhenolica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "161398.protein.sequences.v11.5.fa",
		        "enrichment_path": "161398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161398.protein.info.v11.5.txt",
		        "node_list_path": "161398.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalisediminibacteriumHaloalkalitolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salisediminibacterium haloalkalitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalisediminibacteriumHaloalkalitolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1464123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1464123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1464123.protein.info.v11.5.txt",
		        "node_list_path": "1464123.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpOv259Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. OV259 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpOv259Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500286.protein.info.v11.5.txt",
		        "node_list_path": "1500286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaHermsiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia hermsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaHermsiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314723.clusters.proteins.v11.5.txt",
		        "sequence_path": "314723.protein.sequences.v11.5.fa",
		        "enrichment_path": "314723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314723.protein.info.v11.5.txt",
		        "node_list_path": "314723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoriobacteriaceaeBacteriumBv3ac1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium BV3Ac1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacteriaceaeBacteriumBv3ac1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111135.protein.info.v11.5.txt",
		        "node_list_path": "1111135.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4281Fw2241Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4281 (FW-2241) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4281Fw2241Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420906.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420906.protein.info.v11.5.txt",
		        "node_list_path": "1420906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag571Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:571 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag571Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262822.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262822.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262822.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262822.protein.info.v11.5.txt",
		        "node_list_path": "1262822.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262822.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RudanellaLutea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rudanella lutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RudanellaLutea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089547.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089547.protein.info.v11.5.txt",
		        "node_list_path": "1089547.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusIctaluriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus ictaluri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusIctaluriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "764299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "764299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "764299.clusters.proteins.v11.5.txt",
		        "sequence_path": "764299.protein.sequences.v11.5.fa",
		        "enrichment_path": "764299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "764299.protein.info.v11.5.txt",
		        "node_list_path": "764299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "764299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesViolaceoruber(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces violaceoruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesViolaceoruber", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935.protein.info.v11.5.txt",
		        "node_list_path": "1935.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusKyotonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus kyotonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusKyotonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398843.protein.sequences.v11.5.fa",
		        "enrichment_path": "398843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398843.protein.info.v11.5.txt",
		        "node_list_path": "398843.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophilalesBacteriumMbrsf5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophilales bacterium MBRSF5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilalesBacteriumMbrsf5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1623448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1623448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1623448.protein.info.v11.5.txt",
		        "node_list_path": "1623448.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloferaxElongansAtccBaa1513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloferax elongans ATCC BAA-1513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloferaxElongansAtccBaa1513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230453.protein.info.v11.5.txt",
		        "node_list_path": "1230453.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusPseudoaviumNbrc100491Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus pseudoavium NBRC 100491 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusPseudoaviumNbrc100491Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218092.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218092.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218092.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218092.protein.info.v11.5.txt",
		        "node_list_path": "1218092.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218092.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonadalesBacteriumRifoxya1Full6910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium RIFOXYA1_FULL_69_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonadalesBacteriumRifoxya1Full6910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802656.protein.info.v11.5.txt",
		        "node_list_path": "1802656.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanothrixThermoacetophilaPtCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothrix thermoacetophila PT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothrixThermoacetophilaPtCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349307.clusters.proteins.v11.5.txt",
		        "sequence_path": "349307.protein.sequences.v11.5.fa",
		        "enrichment_path": "349307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349307.protein.info.v11.5.txt",
		        "node_list_path": "349307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureimonasSpLeaf427Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf427 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpLeaf427Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736375.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736375.protein.info.v11.5.txt",
		        "node_list_path": "1736375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoclostridiumDifficile630(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoclostridium difficile 630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoclostridiumDifficile630", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272563.protein.sequences.v11.5.fa",
		        "enrichment_path": "272563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272563.protein.info.v11.5.txt",
		        "node_list_path": "272563.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumSpAb2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. AB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumSpAb2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1484479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1484479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1484479.clusters.proteins.v11.5.txt",
		        "sequence_path": "1484479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484479.protein.info.v11.5.txt",
		        "node_list_path": "1484479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1484479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FerroglobusPlacidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferroglobus placidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerroglobusPlacidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "589924.clusters.info.v11.5.txt",
		        "cluster_tree_path": "589924.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "589924.clusters.proteins.v11.5.txt",
		        "sequence_path": "589924.protein.sequences.v11.5.fa",
		        "enrichment_path": "589924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "589924.protein.info.v11.5.txt",
		        "node_list_path": "589924.cluster.nodes.v11.5.txt",
		        "edge_list_path": "589924.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwd24019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWD2_40_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwd24019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618595.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618595.protein.info.v11.5.txt",
		        "node_list_path": "1618595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentzeaAlbida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentzea albida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentzeaAlbida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "65499.protein.sequences.v11.5.fa",
		        "enrichment_path": "65499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65499.protein.info.v11.5.txt",
		        "node_list_path": "65499.protein.complete.v11.5.txt"
		    }
		]
    )()

def LinumUsitatissimum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Linum usitatissimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LinumUsitatissimum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4006.protein.sequences.v11.5.fa",
		        "enrichment_path": "4006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4006.protein.info.v11.5.txt",
		        "node_list_path": "4006.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychromonasIngrahamiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas ingrahamii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychromonasIngrahamiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "357804.clusters.info.v11.5.txt",
		        "cluster_tree_path": "357804.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "357804.clusters.proteins.v11.5.txt",
		        "sequence_path": "357804.protein.sequences.v11.5.fa",
		        "enrichment_path": "357804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357804.protein.info.v11.5.txt",
		        "node_list_path": "357804.cluster.nodes.v11.5.txt",
		        "edge_list_path": "357804.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharopolysporaSpinosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharopolyspora spinosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharopolysporaSpinosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "994479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "994479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "994479.clusters.proteins.v11.5.txt",
		        "sequence_path": "994479.protein.sequences.v11.5.fa",
		        "enrichment_path": "994479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "994479.protein.info.v11.5.txt",
		        "node_list_path": "994479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "994479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoanaerobacterStomatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoanaerobacter stomatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoanaerobacterStomatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "796937.protein.sequences.v11.5.fa",
		        "enrichment_path": "796937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796937.protein.info.v11.5.txt",
		        "node_list_path": "796937.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoplanesUtahensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes utahensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesUtahensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1869.clusters.proteins.v11.5.txt",
		        "sequence_path": "1869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1869.protein.info.v11.5.txt",
		        "node_list_path": "1869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaOchraceaF0287Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea F0287 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaOchraceaF0287Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "873517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "873517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "873517.clusters.proteins.v11.5.txt",
		        "sequence_path": "873517.protein.sequences.v11.5.fa",
		        "enrichment_path": "873517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "873517.protein.info.v11.5.txt",
		        "node_list_path": "873517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "873517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLm7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. LM7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLm7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1938607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1938607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1938607.clusters.proteins.v11.5.txt",
		        "sequence_path": "1938607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938607.protein.info.v11.5.txt",
		        "node_list_path": "1938607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1938607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraSpB5022(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira sp. B5-022 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraSpB5022", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1242992.protein.sequences.v11.5.fa",
		        "enrichment_path": "1242992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1242992.protein.info.v11.5.txt",
		        "node_list_path": "1242992.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrococcalesBacterium7313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 73-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcalesBacterium7313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895791.protein.info.v11.5.txt",
		        "node_list_path": "1895791.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaSpMt41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia sp. MT41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaSpMt41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "58049.protein.sequences.v11.5.fa",
		        "enrichment_path": "58049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58049.protein.info.v11.5.txt",
		        "node_list_path": "58049.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusAlveiDsm29(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alvei DSM 29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusAlveiDsm29", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206781.protein.info.v11.5.txt",
		        "node_list_path": "1206781.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterEnclensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter enclensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterEnclensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "993070.protein.sequences.v11.5.fa",
		        "enrichment_path": "993070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "993070.protein.info.v11.5.txt",
		        "node_list_path": "993070.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifoxya1Full4018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYA1_FULL_40_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxya1Full4018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802532.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802532.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802532.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802532.protein.info.v11.5.txt",
		        "node_list_path": "1802532.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802532.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesViolaceoruberCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces violaceoruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesViolaceoruberCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935.protein.info.v11.5.txt",
		        "node_list_path": "1935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthromitusSpSfbmousenl(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBmouseNL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthromitusSpSfbmousenl", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1508644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1508644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1508644.protein.info.v11.5.txt",
		        "node_list_path": "1508644.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiIai1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli IAI1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiIai1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585034.protein.sequences.v11.5.fa",
		        "enrichment_path": "585034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585034.protein.info.v11.5.txt",
		        "node_list_path": "585034.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacteriumLuteolumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacterium luteolum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacteriumLuteolumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "440168.clusters.info.v11.5.txt",
		        "cluster_tree_path": "440168.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "440168.clusters.proteins.v11.5.txt",
		        "sequence_path": "440168.protein.sequences.v11.5.fa",
		        "enrichment_path": "440168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "440168.protein.info.v11.5.txt",
		        "node_list_path": "440168.cluster.nodes.v11.5.txt",
		        "edge_list_path": "440168.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonlabensSpongiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens spongiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensSpongiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "331648.clusters.info.v11.5.txt",
		        "cluster_tree_path": "331648.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "331648.clusters.proteins.v11.5.txt",
		        "sequence_path": "331648.protein.sequences.v11.5.fa",
		        "enrichment_path": "331648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331648.protein.info.v11.5.txt",
		        "node_list_path": "331648.cluster.nodes.v11.5.txt",
		        "edge_list_path": "331648.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpIbvhs2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. IBVHS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpIbvhs2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1985170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1985170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1985170.protein.info.v11.5.txt",
		        "node_list_path": "1985170.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpJcb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. JCB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpJcb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1414719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414719.protein.info.v11.5.txt",
		        "node_list_path": "1414719.protein.complete.v11.5.txt"
		    }
		]
    )()

def MooreaProducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moorea producens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MooreaProducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "489825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "489825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "489825.clusters.proteins.v11.5.txt",
		        "sequence_path": "489825.protein.sequences.v11.5.fa",
		        "enrichment_path": "489825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "489825.protein.info.v11.5.txt",
		        "node_list_path": "489825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "489825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacteriumCg1024015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_40_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805284.protein.info.v11.5.txt",
		        "node_list_path": "1805284.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasMacleodii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas macleodii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasMacleodii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28108.protein.sequences.v11.5.fa",
		        "enrichment_path": "28108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28108.protein.info.v11.5.txt",
		        "node_list_path": "28108.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicosporidiumSpAtcc50920Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicosporidium sp. ATCC 50920 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicosporidiumSpAtcc50920Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1291522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1291522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1291522.clusters.proteins.v11.5.txt",
		        "sequence_path": "1291522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291522.protein.info.v11.5.txt",
		        "node_list_path": "1291522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1291522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AotusNancymaaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aotus nancymaae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AotusNancymaaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37293.clusters.proteins.v11.5.txt",
		        "sequence_path": "37293.protein.sequences.v11.5.fa",
		        "enrichment_path": "37293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37293.protein.info.v11.5.txt",
		        "node_list_path": "37293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedClostridiumSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Clostridium sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedClostridiumSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59620.clusters.proteins.v11.5.txt",
		        "sequence_path": "59620.protein.sequences.v11.5.fa",
		        "enrichment_path": "59620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59620.protein.info.v11.5.txt",
		        "node_list_path": "59620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusAlbus8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus albus 8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusAlbus8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246199.protein.sequences.v11.5.fa",
		        "enrichment_path": "246199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246199.protein.info.v11.5.txt",
		        "node_list_path": "246199.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumGw2011Gwe24668(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_46_68 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24668", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618994.protein.info.v11.5.txt",
		        "node_list_path": "1618994.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSpMebic08052(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. MEBiC08052 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpMebic08052", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761910.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761910.protein.info.v11.5.txt",
		        "node_list_path": "1761910.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPseudogenitalium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pseudogenitalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPseudogenitalium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525264.protein.sequences.v11.5.fa",
		        "enrichment_path": "525264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525264.protein.info.v11.5.txt",
		        "node_list_path": "525264.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaMycoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma mycoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaMycoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272632.clusters.proteins.v11.5.txt",
		        "sequence_path": "272632.protein.sequences.v11.5.fa",
		        "enrichment_path": "272632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272632.protein.info.v11.5.txt",
		        "node_list_path": "272632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MizuhopectenYessoensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mizuhopecten yessoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MizuhopectenYessoensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6573.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6573.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6573.clusters.proteins.v11.5.txt",
		        "sequence_path": "6573.protein.sequences.v11.5.fa",
		        "enrichment_path": "6573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6573.protein.info.v11.5.txt",
		        "node_list_path": "6573.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6573.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrobacterRodentium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter rodentium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterRodentium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "637910.protein.sequences.v11.5.fa",
		        "enrichment_path": "637910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637910.protein.info.v11.5.txt",
		        "node_list_path": "637910.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumAeronauticumDsm10349(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum aeronauticum DSM 10349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumAeronauticumDsm10349", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121421.protein.info.v11.5.txt",
		        "node_list_path": "1121421.protein.complete.v11.5.txt"
		    }
		]
    )()

def AscobolusImmersusRn42(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ascobolus immersus RN42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AscobolusImmersusRn42", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1160509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160509.protein.info.v11.5.txt",
		        "node_list_path": "1160509.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaJiangningensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga jiangningensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaJiangningensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1419482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1419482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1419482.protein.info.v11.5.txt",
		        "node_list_path": "1419482.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillibacterSpEr4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. ER4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSpEr4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1519439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519439.protein.info.v11.5.txt",
		        "node_list_path": "1519439.protein.complete.v11.5.txt"
		    }
		]
    )()

def RheinheimeraPacifica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraPacifica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "173990.protein.sequences.v11.5.fa",
		        "enrichment_path": "173990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "173990.protein.info.v11.5.txt",
		        "node_list_path": "173990.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3715(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_37_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3715", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802036.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802036.protein.info.v11.5.txt",
		        "node_list_path": "1802036.protein.complete.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterTroitsensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter troitsensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterTroitsensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "292222.protein.sequences.v11.5.fa",
		        "enrichment_path": "292222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292222.protein.info.v11.5.txt",
		        "node_list_path": "292222.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSpOk626(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. ok626 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpOk626", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761882.protein.info.v11.5.txt",
		        "node_list_path": "1761882.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNealsonbacteriaBacteriumRifcsplowo201Full4332Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFCSPLOWO2_01_FULL_43_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifcsplowo201Full4332Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801672.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801672.protein.info.v11.5.txt",
		        "node_list_path": "1801672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirosomaRadiotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma radiotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaRadiotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379870.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379870.protein.info.v11.5.txt",
		        "node_list_path": "1379870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastococcusSpDsm46786Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 46786 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusSpDsm46786Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798227.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798227.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798227.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798227.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798227.protein.info.v11.5.txt",
		        "node_list_path": "1798227.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798227.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaSenegalensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSenegalensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "929794.protein.sequences.v11.5.fa",
		        "enrichment_path": "929794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929794.protein.info.v11.5.txt",
		        "node_list_path": "929794.protein.complete.v11.5.txt"
		    }
		]
    )()

def DissulfuribacterThermophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dissulfuribacter thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DissulfuribacterThermophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1156395.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1156395.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1156395.clusters.proteins.v11.5.txt",
		        "sequence_path": "1156395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156395.protein.info.v11.5.txt",
		        "node_list_path": "1156395.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1156395.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PestalotiopsisFiciW1061Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pestalotiopsis fici W106-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PestalotiopsisFiciW1061Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229662.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229662.protein.info.v11.5.txt",
		        "node_list_path": "1229662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacillusFlagellatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacillus flagellatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacillusFlagellatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "265072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "265072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "265072.clusters.proteins.v11.5.txt",
		        "sequence_path": "265072.protein.sequences.v11.5.fa",
		        "enrichment_path": "265072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265072.protein.info.v11.5.txt",
		        "node_list_path": "265072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "265072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaRickettsiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia rickettsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaRickettsiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "452659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "452659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "452659.clusters.proteins.v11.5.txt",
		        "sequence_path": "452659.protein.sequences.v11.5.fa",
		        "enrichment_path": "452659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452659.protein.info.v11.5.txt",
		        "node_list_path": "452659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "452659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumXenophagumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium xenophagum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumXenophagumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1192759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1192759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1192759.clusters.proteins.v11.5.txt",
		        "sequence_path": "1192759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192759.protein.info.v11.5.txt",
		        "node_list_path": "1192759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1192759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasGingivicanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gingivicanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasGingivicanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266762.clusters.proteins.v11.5.txt",
		        "sequence_path": "266762.protein.sequences.v11.5.fa",
		        "enrichment_path": "266762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266762.protein.info.v11.5.txt",
		        "node_list_path": "266762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldisericumSpCg2303611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldisericum sp. CG2_30_36_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldisericumSpCg2303611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805053.protein.info.v11.5.txt",
		        "node_list_path": "1805053.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4113bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_02_FULL_41_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4113bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798409.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798409.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798409.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798409.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798409.protein.info.v11.5.txt",
		        "node_list_path": "1798409.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798409.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmobacterNectariphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmobacter nectariphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmobacterNectariphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121271.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121271.protein.info.v11.5.txt",
		        "node_list_path": "1121271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBouvetii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter bouvetii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBouvetii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120925.protein.info.v11.5.txt",
		        "node_list_path": "1120925.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCuracoiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces curacoi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCuracoiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "146536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "146536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "146536.clusters.proteins.v11.5.txt",
		        "sequence_path": "146536.protein.sequences.v11.5.fa",
		        "enrichment_path": "146536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146536.protein.info.v11.5.txt",
		        "node_list_path": "146536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "146536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaAnanassaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila ananassae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaAnanassaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7217.clusters.proteins.v11.5.txt",
		        "sequence_path": "7217.protein.sequences.v11.5.fa",
		        "enrichment_path": "7217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7217.protein.info.v11.5.txt",
		        "node_list_path": "7217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBifidumPrl2010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum PRL2010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBifidumPrl2010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "702459.protein.sequences.v11.5.fa",
		        "enrichment_path": "702459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702459.protein.info.v11.5.txt",
		        "node_list_path": "702459.protein.complete.v11.5.txt"
		    }
		]
    )()

def HeterocephalusGlaberCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Heterocephalus glaber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeterocephalusGlaberCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10181.clusters.proteins.v11.5.txt",
		        "sequence_path": "10181.protein.sequences.v11.5.fa",
		        "enrichment_path": "10181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10181.protein.info.v11.5.txt",
		        "node_list_path": "10181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PediococcusDamnosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus damnosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusDamnosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "51663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "51663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "51663.clusters.proteins.v11.5.txt",
		        "sequence_path": "51663.protein.sequences.v11.5.fa",
		        "enrichment_path": "51663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51663.protein.info.v11.5.txt",
		        "node_list_path": "51663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "51663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedAcidilobusSpCisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Acidilobus sp. CIS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedAcidilobusSpCisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410574.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410574.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410574.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410574.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410574.protein.info.v11.5.txt",
		        "node_list_path": "1410574.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410574.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterShowaeCc57c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter showae CC57C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterShowaeCc57c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1073353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073353.protein.info.v11.5.txt",
		        "node_list_path": "1073353.protein.complete.v11.5.txt"
		    }
		]
    )()

def KineococcusRadiotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kineococcus radiotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KineococcusRadiotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266940.protein.sequences.v11.5.fa",
		        "enrichment_path": "266940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266940.protein.info.v11.5.txt",
		        "node_list_path": "266940.protein.complete.v11.5.txt"
		    }
		]
    )()

def BellilineaCaldifistulaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bellilinea caldifistulae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BellilineaCaldifistulaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "360411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "360411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "360411.clusters.proteins.v11.5.txt",
		        "sequence_path": "360411.protein.sequences.v11.5.fa",
		        "enrichment_path": "360411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360411.protein.info.v11.5.txt",
		        "node_list_path": "360411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "360411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiothrixEikelboomii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix eikelboomii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiothrixEikelboomii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "92487.protein.sequences.v11.5.fa",
		        "enrichment_path": "92487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92487.protein.info.v11.5.txt",
		        "node_list_path": "92487.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoolittleaEndobiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doolittlea endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoolittleaEndobiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1778262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1778262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1778262.clusters.proteins.v11.5.txt",
		        "sequence_path": "1778262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1778262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1778262.protein.info.v11.5.txt",
		        "node_list_path": "1778262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1778262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfovibrioSpN1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio sp. N1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfovibrioSpN1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871110.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871110.protein.info.v11.5.txt",
		        "node_list_path": "1871110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumGorillae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium gorillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumGorillae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231063.protein.info.v11.5.txt",
		        "node_list_path": "1231063.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesGraevenitziiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces graevenitzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesGraevenitziiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "435830.clusters.info.v11.5.txt",
		        "cluster_tree_path": "435830.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "435830.clusters.proteins.v11.5.txt",
		        "sequence_path": "435830.protein.sequences.v11.5.fa",
		        "enrichment_path": "435830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435830.protein.info.v11.5.txt",
		        "node_list_path": "435830.cluster.nodes.v11.5.txt",
		        "edge_list_path": "435830.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSp05ny08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 05NY08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSp05ny08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1622149.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1622149.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1622149.clusters.proteins.v11.5.txt",
		        "sequence_path": "1622149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622149.protein.info.v11.5.txt",
		        "node_list_path": "1622149.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1622149.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillibacterValericigenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter valericigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterValericigenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "693746.protein.sequences.v11.5.fa",
		        "enrichment_path": "693746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693746.protein.info.v11.5.txt",
		        "node_list_path": "693746.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusGastricusPs3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gastricus PS3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGastricusPs3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144300.protein.info.v11.5.txt",
		        "node_list_path": "1144300.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaGlobuliformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina globuliformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaGlobuliformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "676202.protein.sequences.v11.5.fa",
		        "enrichment_path": "676202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "676202.protein.info.v11.5.txt",
		        "node_list_path": "676202.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanisphaeraPsychrotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanisphaera psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanisphaeraPsychrotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1414654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414654.protein.info.v11.5.txt",
		        "node_list_path": "1414654.protein.complete.v11.5.txt"
		    }
		]
    )()

def NonomuraeaCandida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea candida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaCandida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "359159.protein.sequences.v11.5.fa",
		        "enrichment_path": "359159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "359159.protein.info.v11.5.txt",
		        "node_list_path": "359159.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumGw2011Gwb24517(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_45_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24517", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618388.protein.info.v11.5.txt",
		        "node_list_path": "1618388.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaSpBmg111209(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia sp. BMG111209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSpBmg111209", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1160137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160137.protein.info.v11.5.txt",
		        "node_list_path": "1160137.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinospirillumAlkaliphilumDsm21637Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinospirillum alkaliphilum DSM 21637 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinospirillumAlkaliphilumDsm21637Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122209.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122209.protein.info.v11.5.txt",
		        "node_list_path": "1122209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpRoot444d2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Root444D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpRoot444d2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736538.protein.info.v11.5.txt",
		        "node_list_path": "1736538.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusJensenii272chnCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii 272CHN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusJensenii272chnCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575606.clusters.proteins.v11.5.txt",
		        "sequence_path": "575606.protein.sequences.v11.5.fa",
		        "enrichment_path": "575606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575606.protein.info.v11.5.txt",
		        "node_list_path": "575606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc13817(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_38_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc13817", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618896.protein.info.v11.5.txt",
		        "node_list_path": "1618896.protein.complete.v11.5.txt"
		    }
		]
    )()

def JeotgalibacaDankookensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalibaca dankookensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalibacaDankookensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "708126.protein.sequences.v11.5.fa",
		        "enrichment_path": "708126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "708126.protein.info.v11.5.txt",
		        "node_list_path": "708126.protein.complete.v11.5.txt"
		    }
		]
    )()

def SandaracinusAmylolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sandaracinus amylolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SandaracinusAmylolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "927083.protein.sequences.v11.5.fa",
		        "enrichment_path": "927083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927083.protein.info.v11.5.txt",
		        "node_list_path": "927083.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterSpClo3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. CLO-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSpClo3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "211.clusters.info.v11.5.txt",
		        "cluster_tree_path": "211.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "211.clusters.proteins.v11.5.txt",
		        "sequence_path": "211.protein.sequences.v11.5.fa",
		        "enrichment_path": "211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211.protein.info.v11.5.txt",
		        "node_list_path": "211.cluster.nodes.v11.5.txt",
		        "edge_list_path": "211.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAlgidusDsm15638(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus algidus DSM 15638 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAlgidusDsm15638", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423719.protein.info.v11.5.txt",
		        "node_list_path": "1423719.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumGlutamicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium glutamicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumGlutamicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "196627.protein.sequences.v11.5.fa",
		        "enrichment_path": "196627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "196627.protein.info.v11.5.txt",
		        "node_list_path": "196627.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClavibacterMichiganensisNcppb382(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis NCPPB382 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavibacterMichiganensisNcppb382", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "443906.protein.sequences.v11.5.fa",
		        "enrichment_path": "443906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443906.protein.info.v11.5.txt",
		        "node_list_path": "443906.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpUrhb0009(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. URHB0009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpUrhb0009", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298866.protein.info.v11.5.txt",
		        "node_list_path": "1298866.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusOligofermentansDsm15707Lmg22743(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oligofermentans DSM 15707 LMG 22743 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOligofermentansDsm15707Lmg22743", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423778.protein.info.v11.5.txt",
		        "node_list_path": "1423778.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoproteusUzoniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoproteus uzoniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoproteusUzoniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999630.clusters.proteins.v11.5.txt",
		        "sequence_path": "999630.protein.sequences.v11.5.fa",
		        "enrichment_path": "999630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999630.protein.info.v11.5.txt",
		        "node_list_path": "999630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LoktanellaSp5ratimar09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella sp. 5RATIMAR09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaSp5ratimar09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1225655.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1225655.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1225655.clusters.proteins.v11.5.txt",
		        "sequence_path": "1225655.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225655.protein.info.v11.5.txt",
		        "node_list_path": "1225655.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1225655.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpEm1308Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. EM1308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpEm1308Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1492737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1492737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1492737.clusters.proteins.v11.5.txt",
		        "sequence_path": "1492737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1492737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1492737.protein.info.v11.5.txt",
		        "node_list_path": "1492737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1492737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsphigho212Full4311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_12_FULL_43_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho212Full4311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797780.protein.info.v11.5.txt",
		        "node_list_path": "1797780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MnemiopsisLeidyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mnemiopsis leidyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MnemiopsisLeidyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "27923.protein.sequences.v11.5.fa",
		        "enrichment_path": "27923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27923.protein.info.v11.5.txt",
		        "node_list_path": "27923.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho201Full3717(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_37_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3717", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798588.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798588.protein.info.v11.5.txt",
		        "node_list_path": "1798588.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaConchaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria conchae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaConchaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "981384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "981384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "981384.clusters.proteins.v11.5.txt",
		        "sequence_path": "981384.protein.sequences.v11.5.fa",
		        "enrichment_path": "981384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981384.protein.info.v11.5.txt",
		        "node_list_path": "981384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "981384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwa24315(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWA2_43_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwa24315", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618738.protein.info.v11.5.txt",
		        "node_list_path": "1618738.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermosphaeraAggregansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosphaera aggregans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosphaeraAggregansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "633148.clusters.info.v11.5.txt",
		        "cluster_tree_path": "633148.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "633148.clusters.proteins.v11.5.txt",
		        "sequence_path": "633148.protein.sequences.v11.5.fa",
		        "enrichment_path": "633148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633148.protein.info.v11.5.txt",
		        "node_list_path": "633148.cluster.nodes.v11.5.txt",
		        "edge_list_path": "633148.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassotaleaCrassostreae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassotalea crassostreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassotaleaCrassostreae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1763536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1763536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1763536.protein.info.v11.5.txt",
		        "node_list_path": "1763536.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterRhizosphaeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterRhizosphaeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "390241.clusters.info.v11.5.txt",
		        "cluster_tree_path": "390241.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "390241.clusters.proteins.v11.5.txt",
		        "sequence_path": "390241.protein.sequences.v11.5.fa",
		        "enrichment_path": "390241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390241.protein.info.v11.5.txt",
		        "node_list_path": "390241.cluster.nodes.v11.5.txt",
		        "edge_list_path": "390241.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasLitoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasLitoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "797277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "797277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "797277.clusters.proteins.v11.5.txt",
		        "sequence_path": "797277.protein.sequences.v11.5.fa",
		        "enrichment_path": "797277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797277.protein.info.v11.5.txt",
		        "node_list_path": "797277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "797277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomonasDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1538553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1538553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1538553.protein.info.v11.5.txt",
		        "node_list_path": "1538553.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacteriaceaeBacteriumLsjc7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium LSJC7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacteriaceaeBacteriumLsjc7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1224136.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224136.protein.info.v11.5.txt",
		        "node_list_path": "1224136.protein.complete.v11.5.txt"
		    }
		]
    )()

def MuricaudaZhangzhouensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Muricauda zhangzhouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuricaudaZhangzhouensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1073328.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1073328.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1073328.clusters.proteins.v11.5.txt",
		        "sequence_path": "1073328.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073328.protein.info.v11.5.txt",
		        "node_list_path": "1073328.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1073328.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DuganellaSpCf458(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. CF458 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpCf458", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884368.protein.info.v11.5.txt",
		        "node_list_path": "1884368.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinocyclocheilusGrahami(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinocyclocheilus grahami graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinocyclocheilusGrahami", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "75366.protein.sequences.v11.5.fa",
		        "enrichment_path": "75366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75366.protein.info.v11.5.txt",
		        "node_list_path": "75366.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylothermaceaeBacteriaB42Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylothermaceae bacteria B42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylothermaceaeBacteriaB42Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798802.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798802.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798802.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798802.protein.info.v11.5.txt",
		        "node_list_path": "1798802.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798802.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenimonasMalthaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas malthae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenimonasMalthaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1384054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1384054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1384054.clusters.proteins.v11.5.txt",
		        "sequence_path": "1384054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384054.protein.info.v11.5.txt",
		        "node_list_path": "1384054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1384054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaBovoculi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma bovoculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaBovoculi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743966.protein.sequences.v11.5.fa",
		        "enrichment_path": "743966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743966.protein.info.v11.5.txt",
		        "node_list_path": "743966.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwf1525Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWF1_52_5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwf1525Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618959.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618959.protein.info.v11.5.txt",
		        "node_list_path": "1618959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag582(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:582 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag582", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262997.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262997.protein.info.v11.5.txt",
		        "node_list_path": "1262997.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusFlorumDsm22689Jcm16035Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus florum DSM 22689 JCM 16035 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFlorumDsm22689Jcm16035Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423745.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423745.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423745.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423745.protein.info.v11.5.txt",
		        "node_list_path": "1423745.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423745.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonomuraeaSpAtcc55076(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea sp. ATCC 55076 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaSpAtcc55076", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1909395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1909395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1909395.protein.info.v11.5.txt",
		        "node_list_path": "1909395.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusNiameyensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus niameyensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusNiameyensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1522308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522308.protein.info.v11.5.txt",
		        "node_list_path": "1522308.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpRu37d(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. RU37D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpRu37d", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907397.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907397.protein.info.v11.5.txt",
		        "node_list_path": "1907397.protein.complete.v11.5.txt"
		    }
		]
    )()

def PararhizobiumAntarcticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pararhizobium antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PararhizobiumAntarcticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798805.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798805.protein.info.v11.5.txt",
		        "node_list_path": "1798805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HamiltosporidiumTvaerminnensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hamiltosporidium tvaerminnensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HamiltosporidiumTvaerminnensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1176355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1176355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1176355.clusters.proteins.v11.5.txt",
		        "sequence_path": "1176355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1176355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1176355.protein.info.v11.5.txt",
		        "node_list_path": "1176355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1176355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAminophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium aminophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAminophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121296.protein.info.v11.5.txt",
		        "node_list_path": "1121296.protein.complete.v11.5.txt"
		    }
		]
    )()

def EikenellaSpNml130454(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eikenella sp. NML130454 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EikenellaSpNml130454", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1795832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795832.protein.info.v11.5.txt",
		        "node_list_path": "1795832.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteiniborusSpDw1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteiniborus sp. DW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteiniborusSpDw1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1889883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889883.protein.info.v11.5.txt",
		        "node_list_path": "1889883.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrinemaSpJ72Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrinema sp. J72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrinemaSpJ72Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "406552.clusters.info.v11.5.txt",
		        "cluster_tree_path": "406552.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "406552.clusters.proteins.v11.5.txt",
		        "sequence_path": "406552.protein.sequences.v11.5.fa",
		        "enrichment_path": "406552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406552.protein.info.v11.5.txt",
		        "node_list_path": "406552.cluster.nodes.v11.5.txt",
		        "edge_list_path": "406552.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc24817(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC2_48_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc24817", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618933.protein.info.v11.5.txt",
		        "node_list_path": "1618933.protein.complete.v11.5.txt"
		    }
		]
    )()

def XylanimicrobiumPachnodaeJcm13526Nbrc107786(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xylanimicrobium pachnodae JCM 13526 NBRC 107786 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylanimicrobiumPachnodaeJcm13526Nbrc107786", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1305855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305855.protein.info.v11.5.txt",
		        "node_list_path": "1305855.protein.complete.v11.5.txt"
		    }
		]
    )()

def LewinellaCohaerensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lewinella cohaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LewinellaCohaerensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122176.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122176.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122176.protein.info.v11.5.txt",
		        "node_list_path": "1122176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichomalopsisSarcophagae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichomalopsis sarcophagae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichomalopsisSarcophagae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "543379.protein.sequences.v11.5.fa",
		        "enrichment_path": "543379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543379.protein.info.v11.5.txt",
		        "node_list_path": "543379.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacterium4128Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 41-28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacterium4128Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895706.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895706.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895706.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895706.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895706.protein.info.v11.5.txt",
		        "node_list_path": "1895706.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895706.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AdvenellaKashmirensisWt001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Advenella kashmirensis WT001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AdvenellaKashmirensisWt001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1036672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036672.protein.info.v11.5.txt",
		        "node_list_path": "1036672.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedArchaeonA07hb70Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HB70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedArchaeonA07hb70Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1412872.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1412872.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1412872.clusters.proteins.v11.5.txt",
		        "sequence_path": "1412872.protein.sequences.v11.5.fa",
		        "enrichment_path": "1412872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1412872.protein.info.v11.5.txt",
		        "node_list_path": "1412872.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1412872.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpUnc380mfsha31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. unc380mfsha3.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpUnc380mfsha31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1793723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1793723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1793723.clusters.proteins.v11.5.txt",
		        "sequence_path": "1793723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1793723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1793723.protein.info.v11.5.txt",
		        "node_list_path": "1793723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1793723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaConcitans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia concitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaConcitans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777133.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777133.protein.info.v11.5.txt",
		        "node_list_path": "1777133.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusLuciferensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus luciferensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLuciferensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "178774.protein.sequences.v11.5.fa",
		        "enrichment_path": "178774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178774.protein.info.v11.5.txt",
		        "node_list_path": "178774.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPeroris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus peroris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPeroris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888746.protein.sequences.v11.5.fa",
		        "enrichment_path": "888746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888746.protein.info.v11.5.txt",
		        "node_list_path": "888746.protein.complete.v11.5.txt"
		    }
		]
    )()

def OncorhynchusMykiss(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oncorhynchus mykiss graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OncorhynchusMykiss", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8022.protein.sequences.v11.5.fa",
		        "enrichment_path": "8022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8022.protein.info.v11.5.txt",
		        "node_list_path": "8022.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBiavatiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium biavatii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBiavatiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437608.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437608.protein.info.v11.5.txt",
		        "node_list_path": "1437608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TenacibaculumTodarodis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum todarodis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumTodarodis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1850252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850252.protein.info.v11.5.txt",
		        "node_list_path": "1850252.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaAlbensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella albensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaAlbensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122978.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122978.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122978.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122978.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122978.protein.info.v11.5.txt",
		        "node_list_path": "1122978.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122978.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioCaribbeanicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio caribbeanicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCaribbeanicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "796620.protein.sequences.v11.5.fa",
		        "enrichment_path": "796620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796620.protein.info.v11.5.txt",
		        "node_list_path": "796620.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantheraPardusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Panthera pardus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantheraPardusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9691.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9691.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9691.clusters.proteins.v11.5.txt",
		        "sequence_path": "9691.protein.sequences.v11.5.fa",
		        "enrichment_path": "9691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9691.protein.info.v11.5.txt",
		        "node_list_path": "9691.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9691.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag403Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:403 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag403Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262958.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262958.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262958.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262958.protein.info.v11.5.txt",
		        "node_list_path": "1262958.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262958.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TakifuguRubripes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Takifugu rubripes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TakifuguRubripes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "31033.protein.sequences.v11.5.fa",
		        "enrichment_path": "31033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31033.protein.info.v11.5.txt",
		        "node_list_path": "31033.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermobrachiumCelereCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermobrachium celere Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobrachiumCelereCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "941824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "941824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "941824.clusters.proteins.v11.5.txt",
		        "sequence_path": "941824.protein.sequences.v11.5.fa",
		        "enrichment_path": "941824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "941824.protein.info.v11.5.txt",
		        "node_list_path": "941824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "941824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSp113p3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. 113P3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSp113p3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "292913.protein.sequences.v11.5.fa",
		        "enrichment_path": "292913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292913.protein.info.v11.5.txt",
		        "node_list_path": "292913.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSakei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sakei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSakei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314315.protein.sequences.v11.5.fa",
		        "enrichment_path": "314315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314315.protein.info.v11.5.txt",
		        "node_list_path": "314315.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaCaprae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella caprae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaCaprae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122244.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122244.protein.info.v11.5.txt",
		        "node_list_path": "1122244.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfonauticusSp384375Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonauticus sp. 38_4375 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonauticusSp384375Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635258.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635258.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635258.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635258.protein.info.v11.5.txt",
		        "node_list_path": "1635258.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635258.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolirubrobacteralesBacterium6714Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solirubrobacterales bacterium 67-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolirubrobacteralesBacterium6714Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895832.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895832.protein.info.v11.5.txt",
		        "node_list_path": "1895832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrosporumGypseum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microsporum gypseum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrosporumGypseum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "63402.protein.sequences.v11.5.fa",
		        "enrichment_path": "63402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63402.protein.info.v11.5.txt",
		        "node_list_path": "63402.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaShahiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella shahii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaShahiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122991.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122991.protein.info.v11.5.txt",
		        "node_list_path": "1122991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinophagaSpCf118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga sp. CF118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaSpCf118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884367.protein.info.v11.5.txt",
		        "node_list_path": "1884367.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospirillumSpUnkMgs17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillum sp. UNK.MGS-17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillumSpUnkMgs17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1638782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638782.protein.info.v11.5.txt",
		        "node_list_path": "1638782.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaHisticolaF0411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella histicola F0411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaHisticolaF0411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "857291.protein.sequences.v11.5.fa",
		        "enrichment_path": "857291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857291.protein.info.v11.5.txt",
		        "node_list_path": "857291.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumGalatheaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium galatheae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumGalatheaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1654360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1654360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1654360.clusters.proteins.v11.5.txt",
		        "sequence_path": "1654360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1654360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1654360.protein.info.v11.5.txt",
		        "node_list_path": "1654360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1654360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusVeblenbacteriaBacteriumRifoxyc2Full4211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Veblenbacteria bacterium RIFOXYC2_FULL_42_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusVeblenbacteriaBacteriumRifoxyc2Full4211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802428.protein.info.v11.5.txt",
		        "node_list_path": "1802428.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensPf01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Pf01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensPf01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "205922.protein.sequences.v11.5.fa",
		        "enrichment_path": "205922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "205922.protein.info.v11.5.txt",
		        "node_list_path": "205922.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixibacteriaBacteriumSm2381Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm2381Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703428.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703428.protein.info.v11.5.txt",
		        "node_list_path": "1703428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo212Full6728Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_12_FULL_67_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212Full6728Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797503.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797503.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797503.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797503.protein.info.v11.5.txt",
		        "node_list_path": "1797503.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797503.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MelopsittacusUndulatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Melopsittacus undulatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MelopsittacusUndulatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13146.clusters.proteins.v11.5.txt",
		        "sequence_path": "13146.protein.sequences.v11.5.fa",
		        "enrichment_path": "13146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13146.protein.info.v11.5.txt",
		        "node_list_path": "13146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusJensenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusJensenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "109790.protein.sequences.v11.5.fa",
		        "enrichment_path": "109790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109790.protein.info.v11.5.txt",
		        "node_list_path": "109790.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaAmikacinitoleransNbrc108937(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia amikacinitolerans NBRC 108937 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAmikacinitoleransNbrc108937", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379680.protein.info.v11.5.txt",
		        "node_list_path": "1379680.protein.complete.v11.5.txt"
		    }
		]
    )()

def PasteurellaceaeBacteriumNi1060Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurellaceae bacterium NI1060 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaceaeBacteriumNi1060Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1679001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1679001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1679001.clusters.proteins.v11.5.txt",
		        "sequence_path": "1679001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679001.protein.info.v11.5.txt",
		        "node_list_path": "1679001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1679001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerobrancaCaliforniensisDsm14826Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobranca californiensis DSM 14826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobrancaCaliforniensisDsm14826Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120989.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120989.protein.info.v11.5.txt",
		        "node_list_path": "1120989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DickeyaZeaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya zeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaZeaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "561229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "561229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "561229.clusters.proteins.v11.5.txt",
		        "sequence_path": "561229.protein.sequences.v11.5.fa",
		        "enrichment_path": "561229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561229.protein.info.v11.5.txt",
		        "node_list_path": "561229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "561229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusRenniniDsm20253(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rennini DSM 20253 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusRenniniDsm20253", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423796.protein.info.v11.5.txt",
		        "node_list_path": "1423796.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosospiraBriensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira briensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraBriensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1266925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266925.protein.info.v11.5.txt",
		        "node_list_path": "1266925.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallionellalesBacteriumGwa254124Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_54_124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallionellalesBacteriumGwa254124Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798243.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798243.protein.info.v11.5.txt",
		        "node_list_path": "1798243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraBiflexaSerovarPatocStrainPatoc1ParisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira biflexa serovar Patoc strain Patoc 1 (Paris) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraBiflexaSerovarPatocStrainPatoc1ParisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "456481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "456481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "456481.clusters.proteins.v11.5.txt",
		        "sequence_path": "456481.protein.sequences.v11.5.fa",
		        "enrichment_path": "456481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "456481.protein.info.v11.5.txt",
		        "node_list_path": "456481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "456481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillochlorisTrichoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillochloris trichoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillochlorisTrichoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765420.clusters.proteins.v11.5.txt",
		        "sequence_path": "765420.protein.sequences.v11.5.fa",
		        "enrichment_path": "765420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765420.protein.info.v11.5.txt",
		        "node_list_path": "765420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PundamiliaNyererei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pundamilia nyererei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PundamiliaNyererei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "303518.protein.sequences.v11.5.fa",
		        "enrichment_path": "303518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "303518.protein.info.v11.5.txt",
		        "node_list_path": "303518.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacterToluenoxydansJcm15764Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter toluenoxydans JCM 15764 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterToluenoxydansJcm15764Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1294260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1294260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1294260.clusters.proteins.v11.5.txt",
		        "sequence_path": "1294260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294260.protein.info.v11.5.txt",
		        "node_list_path": "1294260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1294260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpAb308Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpAb308Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841859.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841859.protein.info.v11.5.txt",
		        "node_list_path": "1841859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaribacterAntarcticusDsm21422Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter antarcticus DSM 21422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterAntarcticusDsm21422Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122191.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122191.protein.info.v11.5.txt",
		        "node_list_path": "1122191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterPhenylpyruvicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter phenylpyruvicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterPhenylpyruvicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123034.protein.info.v11.5.txt",
		        "node_list_path": "1123034.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpLeaf180(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf180 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpLeaf180", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736289.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736289.protein.info.v11.5.txt",
		        "node_list_path": "1736289.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAgalactiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAgalactiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2110.protein.sequences.v11.5.fa",
		        "enrichment_path": "2110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2110.protein.info.v11.5.txt",
		        "node_list_path": "2110.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotogaSpMc24(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga sp. Mc24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaSpMc24", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231241.protein.info.v11.5.txt",
		        "node_list_path": "1231241.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwe13517Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_35_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe13517Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618707.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618707.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618707.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618707.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618707.protein.info.v11.5.txt",
		        "node_list_path": "1618707.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618707.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DactylosporangiumAurantiacumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dactylosporangium aurantiacum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DactylosporangiumAurantiacumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35754.clusters.proteins.v11.5.txt",
		        "sequence_path": "35754.protein.sequences.v11.5.fa",
		        "enrichment_path": "35754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35754.protein.info.v11.5.txt",
		        "node_list_path": "35754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf23272(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_32_72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf23272", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619079.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619079.protein.info.v11.5.txt",
		        "node_list_path": "1619079.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumLentocellum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium lentocellum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumLentocellum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "642492.protein.sequences.v11.5.fa",
		        "enrichment_path": "642492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "642492.protein.info.v11.5.txt",
		        "node_list_path": "642492.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaHalifaxensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella halifaxensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaHalifaxensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "458817.protein.sequences.v11.5.fa",
		        "enrichment_path": "458817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "458817.protein.info.v11.5.txt",
		        "node_list_path": "458817.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgibacterLectusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algibacter lectus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgibacterLectusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "221126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "221126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "221126.clusters.proteins.v11.5.txt",
		        "sequence_path": "221126.protein.sequences.v11.5.fa",
		        "enrichment_path": "221126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221126.protein.info.v11.5.txt",
		        "node_list_path": "221126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "221126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XylariaGrammica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xylaria grammica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylariaGrammica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "363999.protein.sequences.v11.5.fa",
		        "enrichment_path": "363999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "363999.protein.info.v11.5.txt",
		        "node_list_path": "363999.protein.complete.v11.5.txt"
		    }
		]
    )()

def CroceicoccusNaphthovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Croceicoccus naphthovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CroceicoccusNaphthovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348774.protein.info.v11.5.txt",
		        "node_list_path": "1348774.protein.complete.v11.5.txt"
		    }
		]
    )()

def KrasilnikoviellaFlava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Krasilnikoviella flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KrasilnikoviellaFlava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "526729.protein.sequences.v11.5.fa",
		        "enrichment_path": "526729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526729.protein.info.v11.5.txt",
		        "node_list_path": "526729.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807729.protein.info.v11.5.txt",
		        "node_list_path": "1807729.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusOpacusB4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus opacus B4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusOpacusB4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "632772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "632772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "632772.clusters.proteins.v11.5.txt",
		        "sequence_path": "632772.protein.sequences.v11.5.fa",
		        "enrichment_path": "632772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632772.protein.info.v11.5.txt",
		        "node_list_path": "632772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "632772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusMaricopensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus maricopensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusMaricopensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "709986.protein.sequences.v11.5.fa",
		        "enrichment_path": "709986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709986.protein.info.v11.5.txt",
		        "node_list_path": "709986.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaHalophyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora halophytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaHalophyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47864.clusters.proteins.v11.5.txt",
		        "sequence_path": "47864.protein.sequences.v11.5.fa",
		        "enrichment_path": "47864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47864.protein.info.v11.5.txt",
		        "node_list_path": "47864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag590(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:590 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag590", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262825.protein.info.v11.5.txt",
		        "node_list_path": "1262825.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwd26328Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWD2_63_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwd26328Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797937.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797937.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797937.protein.info.v11.5.txt",
		        "node_list_path": "1797937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioSpQd031(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. qd031 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpQd031", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1603038.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603038.protein.info.v11.5.txt",
		        "node_list_path": "1603038.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnsiferSojaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sojae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferSojaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "716928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "716928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "716928.clusters.proteins.v11.5.txt",
		        "sequence_path": "716928.protein.sequences.v11.5.fa",
		        "enrichment_path": "716928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "716928.protein.info.v11.5.txt",
		        "node_list_path": "716928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "716928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnh099(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNH099 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnh099", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1137269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137269.protein.info.v11.5.txt",
		        "node_list_path": "1137269.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpFp211J200Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FP211-J200 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpFp211J200Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1792309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1792309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1792309.clusters.proteins.v11.5.txt",
		        "sequence_path": "1792309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792309.protein.info.v11.5.txt",
		        "node_list_path": "1792309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1792309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpMit0701(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0701 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpMit0701", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499502.protein.info.v11.5.txt",
		        "node_list_path": "1499502.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusOpacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus opacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusOpacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37919.clusters.proteins.v11.5.txt",
		        "sequence_path": "37919.protein.sequences.v11.5.fa",
		        "enrichment_path": "37919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37919.protein.info.v11.5.txt",
		        "node_list_path": "37919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpRoot608(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Root608 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpRoot608", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736569.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736569.protein.info.v11.5.txt",
		        "node_list_path": "1736569.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumGanghwense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium ganghwense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumGanghwense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "320778.protein.sequences.v11.5.fa",
		        "enrichment_path": "320778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "320778.protein.info.v11.5.txt",
		        "node_list_path": "320778.protein.complete.v11.5.txt"
		    }
		]
    )()

def GilvimarinusChinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gilvimarinus chinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilvimarinusChinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121921.protein.info.v11.5.txt",
		        "node_list_path": "1121921.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErpetoichthysCalabaricusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erpetoichthys calabaricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErpetoichthysCalabaricusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "27687.clusters.info.v11.5.txt",
		        "cluster_tree_path": "27687.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "27687.clusters.proteins.v11.5.txt",
		        "sequence_path": "27687.protein.sequences.v11.5.fa",
		        "enrichment_path": "27687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27687.protein.info.v11.5.txt",
		        "node_list_path": "27687.cluster.nodes.v11.5.txt",
		        "edge_list_path": "27687.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophomonasWolfeiSubspMethylbutyratica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei subsp. methylbutyratica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophomonasWolfeiSubspMethylbutyratica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "378794.protein.sequences.v11.5.fa",
		        "enrichment_path": "378794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "378794.protein.info.v11.5.txt",
		        "node_list_path": "378794.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinispirillumAlkaliphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinispirillum alkaliphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinispirillumAlkaliphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1008392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1008392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1008392.protein.info.v11.5.txt",
		        "node_list_path": "1008392.protein.complete.v11.5.txt"
		    }
		]
    )()

def TilletiaControversa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tilletia controversa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TilletiaControversa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13291.protein.sequences.v11.5.fa",
		        "enrichment_path": "13291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13291.protein.info.v11.5.txt",
		        "node_list_path": "13291.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodolunaLacicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodoluna lacicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodolunaLacicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "529884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "529884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "529884.clusters.proteins.v11.5.txt",
		        "sequence_path": "529884.protein.sequences.v11.5.fa",
		        "enrichment_path": "529884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529884.protein.info.v11.5.txt",
		        "node_list_path": "529884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "529884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpAtexabd23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. ATexABD23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpAtexabd23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157635.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157635.protein.info.v11.5.txt",
		        "node_list_path": "1157635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelobacterAcetylenicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter acetylenicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelobacterAcetylenicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29542.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29542.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29542.clusters.proteins.v11.5.txt",
		        "sequence_path": "29542.protein.sequences.v11.5.fa",
		        "enrichment_path": "29542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29542.protein.info.v11.5.txt",
		        "node_list_path": "29542.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29542.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpadix(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas spadix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpadix", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1045855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045855.protein.info.v11.5.txt",
		        "node_list_path": "1045855.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArdenticatenaMaritimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ardenticatena maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArdenticatenaMaritimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "872965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "872965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "872965.clusters.proteins.v11.5.txt",
		        "sequence_path": "872965.protein.sequences.v11.5.fa",
		        "enrichment_path": "872965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "872965.protein.info.v11.5.txt",
		        "node_list_path": "872965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "872965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3917Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_39_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3917Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801770.protein.info.v11.5.txt",
		        "node_list_path": "1801770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full4412b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_44_12b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full4412b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802772.protein.info.v11.5.txt",
		        "node_list_path": "1802772.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAzotoformansLmg9581(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus azotoformans LMG 9581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAzotoformansLmg9581", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131731.protein.info.v11.5.txt",
		        "node_list_path": "1131731.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusDefluviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus defluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusDefluviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1323361.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1323361.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1323361.clusters.proteins.v11.5.txt",
		        "sequence_path": "1323361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1323361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1323361.protein.info.v11.5.txt",
		        "node_list_path": "1323361.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1323361.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumTerpenotabidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium terpenotabidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumTerpenotabidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1200352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1200352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1200352.clusters.proteins.v11.5.txt",
		        "sequence_path": "1200352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200352.protein.info.v11.5.txt",
		        "node_list_path": "1200352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1200352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumVulneris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium vulneris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumVulneris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "547163.protein.sequences.v11.5.fa",
		        "enrichment_path": "547163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547163.protein.info.v11.5.txt",
		        "node_list_path": "547163.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacterium4484702Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_70.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484702Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1970783.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1970783.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1970783.clusters.proteins.v11.5.txt",
		        "sequence_path": "1970783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970783.protein.info.v11.5.txt",
		        "node_list_path": "1970783.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1970783.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsphigho202Full4521(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPHIGHO2_02_FULL_45_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202Full4521", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801854.protein.info.v11.5.txt",
		        "node_list_path": "1801854.protein.complete.v11.5.txt"
		    }
		]
    )()

def TarsiusSyrichtaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tarsius syrichta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TarsiusSyrichtaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9478.clusters.proteins.v11.5.txt",
		        "sequence_path": "9478.protein.sequences.v11.5.fa",
		        "enrichment_path": "9478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9478.protein.info.v11.5.txt",
		        "node_list_path": "9478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAquilaeDsm44791Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium aquilae DSM 44791 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAquilaeDsm44791Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1431546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1431546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1431546.clusters.proteins.v11.5.txt",
		        "sequence_path": "1431546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1431546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1431546.protein.info.v11.5.txt",
		        "node_list_path": "1431546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1431546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaMarcescensDb11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia marcescens Db11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaMarcescensDb11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "273526.protein.sequences.v11.5.fa",
		        "enrichment_path": "273526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273526.protein.info.v11.5.txt",
		        "node_list_path": "273526.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaWillistoniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila willistoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaWillistoniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7260.clusters.proteins.v11.5.txt",
		        "sequence_path": "7260.protein.sequences.v11.5.fa",
		        "enrichment_path": "7260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7260.protein.info.v11.5.txt",
		        "node_list_path": "7260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZygosaccharomycesRouxiiCbs732Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zygosaccharomyces rouxii CBS 732 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZygosaccharomycesRouxiiCbs732Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "559307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "559307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "559307.clusters.proteins.v11.5.txt",
		        "sequence_path": "559307.protein.sequences.v11.5.fa",
		        "enrichment_path": "559307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559307.protein.info.v11.5.txt",
		        "node_list_path": "559307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "559307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychromonasAquimarinaAtccBaa1526Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas aquimarina ATCC BAA-1526 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychromonasAquimarinaAtccBaa1526Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278312.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278312.protein.info.v11.5.txt",
		        "node_list_path": "1278312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaladaptatusSpR4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haladaptatus sp. R4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaladaptatusSpR4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1679489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1679489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1679489.clusters.proteins.v11.5.txt",
		        "sequence_path": "1679489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679489.protein.info.v11.5.txt",
		        "node_list_path": "1679489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1679489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizopusAzygosporus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus azygosporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopusAzygosporus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86630.protein.sequences.v11.5.fa",
		        "enrichment_path": "86630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86630.protein.info.v11.5.txt",
		        "node_list_path": "86630.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3820Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_38_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3820Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802515.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802515.protein.info.v11.5.txt",
		        "node_list_path": "1802515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterPelagiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter pelagius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterPelagiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "379482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "379482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "379482.clusters.proteins.v11.5.txt",
		        "sequence_path": "379482.protein.sequences.v11.5.fa",
		        "enrichment_path": "379482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "379482.protein.info.v11.5.txt",
		        "node_list_path": "379482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "379482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterAlgicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterAlgicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "443152.protein.sequences.v11.5.fa",
		        "enrichment_path": "443152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443152.protein.info.v11.5.txt",
		        "node_list_path": "443152.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusDaejeonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus daejeonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusDaejeonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122917.protein.info.v11.5.txt",
		        "node_list_path": "1122917.protein.complete.v11.5.txt"
		    }
		]
    )()

def FischerellaSpPcc9431Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9431 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FischerellaSpPcc9431Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173023.protein.info.v11.5.txt",
		        "node_list_path": "1173023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacteralesBacteriumFibro01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacterales bacterium Fibro_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacteralesBacteriumFibro01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674899.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674899.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674899.protein.info.v11.5.txt",
		        "node_list_path": "1674899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpermophilusDauricusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spermophilus dauricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpermophilusDauricusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "99837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "99837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "99837.clusters.proteins.v11.5.txt",
		        "sequence_path": "99837.protein.sequences.v11.5.fa",
		        "enrichment_path": "99837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "99837.protein.info.v11.5.txt",
		        "node_list_path": "99837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "99837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IlyobacterPolytropus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ilyobacter polytropus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IlyobacterPolytropus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "572544.protein.sequences.v11.5.fa",
		        "enrichment_path": "572544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572544.protein.info.v11.5.txt",
		        "node_list_path": "572544.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusBorstelensisAk1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus borstelensis AK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusBorstelensisAk1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1300222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1300222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1300222.clusters.proteins.v11.5.txt",
		        "sequence_path": "1300222.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300222.protein.info.v11.5.txt",
		        "node_list_path": "1300222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1300222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinosynnemaMirumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinosynnema mirum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinosynnemaMirumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "446462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "446462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "446462.clusters.proteins.v11.5.txt",
		        "sequence_path": "446462.protein.sequences.v11.5.fa",
		        "enrichment_path": "446462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446462.protein.info.v11.5.txt",
		        "node_list_path": "446462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "446462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteiniborusSpDw1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteiniborus sp. DW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteiniborusSpDw1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1889883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1889883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1889883.clusters.proteins.v11.5.txt",
		        "sequence_path": "1889883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889883.protein.info.v11.5.txt",
		        "node_list_path": "1889883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1889883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb243495d8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB243_495D8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb243495d8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1471469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1471469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1471469.clusters.proteins.v11.5.txt",
		        "sequence_path": "1471469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471469.protein.info.v11.5.txt",
		        "node_list_path": "1471469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1471469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LitomosoidesSigmodontis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Litomosoides sigmodontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LitomosoidesSigmodontis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42156.protein.sequences.v11.5.fa",
		        "enrichment_path": "42156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42156.protein.info.v11.5.txt",
		        "node_list_path": "42156.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSalivariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus salivarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSalivariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304.protein.info.v11.5.txt",
		        "node_list_path": "1304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag786Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:786 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag786Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262893.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262893.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262893.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262893.protein.info.v11.5.txt",
		        "node_list_path": "1262893.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262893.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusSaccharolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus saccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSaccharolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1139996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1139996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1139996.protein.info.v11.5.txt",
		        "node_list_path": "1139996.protein.complete.v11.5.txt"
		    }
		]
    )()

def CrucibulumLaeve(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crucibulum laeve graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrucibulumLaeve", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68775.protein.sequences.v11.5.fa",
		        "enrichment_path": "68775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68775.protein.info.v11.5.txt",
		        "node_list_path": "68775.protein.complete.v11.5.txt"
		    }
		]
    )()

def WinogradskyellaSpJ142Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Winogradskyella sp. J14-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinogradskyellaSpJ142Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1936080.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1936080.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1936080.clusters.proteins.v11.5.txt",
		        "sequence_path": "1936080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1936080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1936080.protein.info.v11.5.txt",
		        "node_list_path": "1936080.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1936080.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusArsenophonusLipoptenaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arsenophonus lipoptenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusArsenophonusLipoptenaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634113.clusters.proteins.v11.5.txt",
		        "sequence_path": "634113.protein.sequences.v11.5.fa",
		        "enrichment_path": "634113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634113.protein.info.v11.5.txt",
		        "node_list_path": "634113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterDubius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter dubius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterDubius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "218673.protein.sequences.v11.5.fa",
		        "enrichment_path": "218673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218673.protein.info.v11.5.txt",
		        "node_list_path": "218673.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200251961Sch5331710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-51961_SCH5331710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200251961Sch5331710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834105.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834105.protein.info.v11.5.txt",
		        "node_list_path": "1834105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusParasanguinisFw213Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis FW213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusParasanguinisFw213Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1114965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1114965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1114965.clusters.proteins.v11.5.txt",
		        "sequence_path": "1114965.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114965.protein.info.v11.5.txt",
		        "node_list_path": "1114965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1114965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LutimaribacterSaemankumensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lutimaribacter saemankumensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutimaribacterSaemankumensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "490829.protein.sequences.v11.5.fa",
		        "enrichment_path": "490829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "490829.protein.info.v11.5.txt",
		        "node_list_path": "490829.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_33_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802210.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802210.protein.info.v11.5.txt",
		        "node_list_path": "1802210.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumUliginosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium uliginosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumUliginosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "119641.clusters.info.v11.5.txt",
		        "cluster_tree_path": "119641.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "119641.clusters.proteins.v11.5.txt",
		        "sequence_path": "119641.protein.sequences.v11.5.fa",
		        "enrichment_path": "119641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "119641.protein.info.v11.5.txt",
		        "node_list_path": "119641.cluster.nodes.v11.5.txt",
		        "edge_list_path": "119641.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPortnoybacteriaBacteriumRifcsphigho212Full389Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RIFCSPHIGHO2_12_FULL_38_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRifcsphigho212Full389Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801997.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801997.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801997.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801997.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801997.protein.info.v11.5.txt",
		        "node_list_path": "1801997.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801997.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpSoil766(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil766 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpSoil766", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736404.protein.info.v11.5.txt",
		        "node_list_path": "1736404.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrococcusLuteusNctc2665Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micrococcus luteus NCTC 2665 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcusLuteusNctc2665Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "465515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "465515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "465515.clusters.proteins.v11.5.txt",
		        "sequence_path": "465515.protein.sequences.v11.5.fa",
		        "enrichment_path": "465515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "465515.protein.info.v11.5.txt",
		        "node_list_path": "465515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "465515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptothrixCholodniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptothrix cholodnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptothrixCholodniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "395495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "395495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "395495.clusters.proteins.v11.5.txt",
		        "sequence_path": "395495.protein.sequences.v11.5.fa",
		        "enrichment_path": "395495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395495.protein.info.v11.5.txt",
		        "node_list_path": "395495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "395495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpK24Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. K24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpK24Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1472716.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1472716.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1472716.clusters.proteins.v11.5.txt",
		        "sequence_path": "1472716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1472716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1472716.protein.info.v11.5.txt",
		        "node_list_path": "1472716.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1472716.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpMm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. MM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpMm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "745310.protein.sequences.v11.5.fa",
		        "enrichment_path": "745310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745310.protein.info.v11.5.txt",
		        "node_list_path": "745310.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriumAlbum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacterium album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriumAlbum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "945713.protein.sequences.v11.5.fa",
		        "enrichment_path": "945713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "945713.protein.info.v11.5.txt",
		        "node_list_path": "945713.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCoahuilensisP1143(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coahuilensis p1.1.43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCoahuilensisP1143", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150625.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150625.protein.info.v11.5.txt",
		        "node_list_path": "1150625.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumDtu027(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium DTU027 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumDtu027", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671663.protein.info.v11.5.txt",
		        "node_list_path": "1671663.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumRbg166630(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_16_66_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg166630", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797274.protein.info.v11.5.txt",
		        "node_list_path": "1797274.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSpSk11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSpSk11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1454000.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1454000.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1454000.clusters.proteins.v11.5.txt",
		        "sequence_path": "1454000.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454000.protein.info.v11.5.txt",
		        "node_list_path": "1454000.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1454000.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpNfr12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpNfr12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566261.protein.info.v11.5.txt",
		        "node_list_path": "1566261.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpPamc26605Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PAMC26605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpPamc26605Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1112214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1112214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1112214.clusters.proteins.v11.5.txt",
		        "sequence_path": "1112214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112214.protein.info.v11.5.txt",
		        "node_list_path": "1112214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1112214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylosarcinaFibrataAmlC10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylosarcina fibrata AML-C10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylosarcinaFibrataAmlC10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1132443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1132443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1132443.protein.info.v11.5.txt",
		        "node_list_path": "1132443.protein.complete.v11.5.txt"
		    }
		]
    )()

def PectobacteriumWasabiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium wasabiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumWasabiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "561231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "561231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "561231.clusters.proteins.v11.5.txt",
		        "sequence_path": "561231.protein.sequences.v11.5.fa",
		        "enrichment_path": "561231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561231.protein.info.v11.5.txt",
		        "node_list_path": "561231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "561231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpOv259(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. OV259 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpOv259", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500286.protein.info.v11.5.txt",
		        "node_list_path": "1500286.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpS6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. S6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpS6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1479623.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479623.protein.info.v11.5.txt",
		        "node_list_path": "1479623.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg167214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_72_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg167214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797663.protein.info.v11.5.txt",
		        "node_list_path": "1797663.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotogaCaldifontisAzm44c09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga caldifontis AZM44c09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaCaldifontisAzm44c09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408159.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408159.protein.info.v11.5.txt",
		        "node_list_path": "1408159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ToxoplasmaGondii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Toxoplasma gondii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ToxoplasmaGondii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5811.protein.sequences.v11.5.fa",
		        "enrichment_path": "5811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5811.protein.info.v11.5.txt",
		        "node_list_path": "5811.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrancisellaUliginisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella uliginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaUliginisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573570.clusters.proteins.v11.5.txt",
		        "sequence_path": "573570.protein.sequences.v11.5.fa",
		        "enrichment_path": "573570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573570.protein.info.v11.5.txt",
		        "node_list_path": "573570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusSomnusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus somnus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusSomnusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "205914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "205914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "205914.clusters.proteins.v11.5.txt",
		        "sequence_path": "205914.protein.sequences.v11.5.fa",
		        "enrichment_path": "205914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "205914.protein.info.v11.5.txt",
		        "node_list_path": "205914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "205914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFrigidarium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium frigidarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFrigidarium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121890.protein.info.v11.5.txt",
		        "node_list_path": "1121890.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalothiobacillusSpXi15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halothiobacillus sp. XI15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalothiobacillusSpXi15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1766620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1766620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1766620.protein.info.v11.5.txt",
		        "node_list_path": "1766620.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusApinorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus apinorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusApinorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218495.protein.info.v11.5.txt",
		        "node_list_path": "1218495.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProsthecomicrobiumHirschiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prosthecomicrobium hirschii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProsthecomicrobiumHirschiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665126.clusters.proteins.v11.5.txt",
		        "sequence_path": "665126.protein.sequences.v11.5.fa",
		        "enrichment_path": "665126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665126.protein.info.v11.5.txt",
		        "node_list_path": "665126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalogranumGelatinilyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halogranum gelatinilyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalogranumGelatinilyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "660521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "660521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "660521.clusters.proteins.v11.5.txt",
		        "sequence_path": "660521.protein.sequences.v11.5.fa",
		        "enrichment_path": "660521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660521.protein.info.v11.5.txt",
		        "node_list_path": "660521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "660521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpMaepy2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. MAEPY2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpMaepy2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1395587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1395587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1395587.clusters.proteins.v11.5.txt",
		        "sequence_path": "1395587.protein.sequences.v11.5.fa",
		        "enrichment_path": "1395587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1395587.protein.info.v11.5.txt",
		        "node_list_path": "1395587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1395587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpJcbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. JCB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpJcbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1414719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1414719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1414719.clusters.proteins.v11.5.txt",
		        "sequence_path": "1414719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414719.protein.info.v11.5.txt",
		        "node_list_path": "1414719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1414719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodospirillaceaeBacteriumBrhC57Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillaceae bacterium BRH_c57 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillaceaeBacteriumBrhC57Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629718.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629718.protein.info.v11.5.txt",
		        "node_list_path": "1629718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpDlviii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. DLVIII graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpDlviii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641107.protein.sequences.v11.5.fa",
		        "enrichment_path": "641107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641107.protein.info.v11.5.txt",
		        "node_list_path": "641107.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSpS32(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. S3-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSpS32", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1747903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1747903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1747903.protein.info.v11.5.txt",
		        "node_list_path": "1747903.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParastagonosporaNodorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parastagonospora nodorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParastagonosporaNodorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13684.protein.sequences.v11.5.fa",
		        "enrichment_path": "13684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13684.protein.info.v11.5.txt",
		        "node_list_path": "13684.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaAggregata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina aggregata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaAggregata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1642818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1642818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1642818.protein.info.v11.5.txt",
		        "node_list_path": "1642818.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcaceaeBacteriumPga8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium pGA-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcaceaeBacteriumPga8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520829.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520829.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520829.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520829.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520829.protein.info.v11.5.txt",
		        "node_list_path": "1520829.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520829.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HistoplasmaCapsulatumG186arCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum G186AR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HistoplasmaCapsulatumG186arCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "447093.clusters.info.v11.5.txt",
		        "cluster_tree_path": "447093.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "447093.clusters.proteins.v11.5.txt",
		        "sequence_path": "447093.protein.sequences.v11.5.fa",
		        "enrichment_path": "447093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "447093.protein.info.v11.5.txt",
		        "node_list_path": "447093.cluster.nodes.v11.5.txt",
		        "edge_list_path": "447093.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "265726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "265726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "265726.clusters.proteins.v11.5.txt",
		        "sequence_path": "265726.protein.sequences.v11.5.fa",
		        "enrichment_path": "265726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265726.protein.info.v11.5.txt",
		        "node_list_path": "265726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "265726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumHominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumHominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "420404.protein.sequences.v11.5.fa",
		        "enrichment_path": "420404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420404.protein.info.v11.5.txt",
		        "node_list_path": "420404.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMarmotaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus marmotae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMarmotaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1825069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1825069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1825069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1825069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1825069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1825069.protein.info.v11.5.txt",
		        "node_list_path": "1825069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1825069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VirgibacillusHalodenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus halodenitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusHalodenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196028.protein.info.v11.5.txt",
		        "node_list_path": "1196028.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSegetis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium segetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSegetis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "271157.protein.sequences.v11.5.fa",
		        "enrichment_path": "271157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "271157.protein.info.v11.5.txt",
		        "node_list_path": "271157.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumRifcsplowo201Full4816Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPLOWO2_01_FULL_48_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsplowo201Full4816Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802461.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802461.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802461.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802461.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802461.protein.info.v11.5.txt",
		        "node_list_path": "1802461.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802461.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EuryarchaeotaArchaeonRbg19ftCombo5621Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_19FT_COMBO_56_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EuryarchaeotaArchaeonRbg19ftCombo5621Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797983.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797983.protein.info.v11.5.txt",
		        "node_list_path": "1797983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurovumSpEnrichmentCultureCloneC5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum sp. enrichment culture clone C5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurovumSpEnrichmentCultureCloneC5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "497650.clusters.info.v11.5.txt",
		        "cluster_tree_path": "497650.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "497650.clusters.proteins.v11.5.txt",
		        "sequence_path": "497650.protein.sequences.v11.5.fa",
		        "enrichment_path": "497650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "497650.protein.info.v11.5.txt",
		        "node_list_path": "497650.cluster.nodes.v11.5.txt",
		        "edge_list_path": "497650.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenobaculumSpY04aas1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenobaculum sp. Y04AAS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenobaculumSpY04aas1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "380749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "380749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "380749.clusters.proteins.v11.5.txt",
		        "sequence_path": "380749.protein.sequences.v11.5.fa",
		        "enrichment_path": "380749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380749.protein.info.v11.5.txt",
		        "node_list_path": "380749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "380749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumSpOccitanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium sp. occitanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumSpOccitanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290292.protein.sequences.v11.5.fa",
		        "enrichment_path": "290292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290292.protein.info.v11.5.txt",
		        "node_list_path": "290292.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalarchaeumAcidiphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halarchaeum acidiphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalarchaeumAcidiphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1261545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1261545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1261545.clusters.proteins.v11.5.txt",
		        "sequence_path": "1261545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261545.protein.info.v11.5.txt",
		        "node_list_path": "1261545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1261545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumCg2303430(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG2_30_34_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumCg2303430", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805160.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805160.protein.info.v11.5.txt",
		        "node_list_path": "1805160.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpRoot65(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. Root65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpRoot65", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736576.protein.info.v11.5.txt",
		        "node_list_path": "1736576.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiohalospiraHalophilaDsm15071(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiohalospira halophila DSM 15071 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiohalospiraHalophilaDsm15071", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123397.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123397.protein.info.v11.5.txt",
		        "node_list_path": "1123397.protein.complete.v11.5.txt"
		    }
		]
    )()

def DuganellaSpLeaf126(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. Leaf126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpLeaf126", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736266.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736266.protein.info.v11.5.txt",
		        "node_list_path": "1736266.protein.complete.v11.5.txt"
		    }
		]
    )()

def BabesiaEquiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Babesia equi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BabesiaEquiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5872.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5872.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5872.clusters.proteins.v11.5.txt",
		        "sequence_path": "5872.protein.sequences.v11.5.fa",
		        "enrichment_path": "5872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5872.protein.info.v11.5.txt",
		        "node_list_path": "5872.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5872.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpRit328Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. RIT328 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpRit328Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1470591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1470591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1470591.clusters.proteins.v11.5.txt",
		        "sequence_path": "1470591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470591.protein.info.v11.5.txt",
		        "node_list_path": "1470591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1470591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShimiaSpSk013(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shimia sp. SK013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShimiaSpSk013", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1389006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1389006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1389006.protein.info.v11.5.txt",
		        "node_list_path": "1389006.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinomonasUshuaiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas ushuaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasUshuaiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122207.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122207.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122207.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122207.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122207.protein.info.v11.5.txt",
		        "node_list_path": "1122207.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122207.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EggerthellaSpCag368Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eggerthella sp. CAG:368 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthellaSpCag368Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262877.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262877.protein.info.v11.5.txt",
		        "node_list_path": "1262877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusRaffinosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus raffinosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusRaffinosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158602.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158602.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158602.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158602.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158602.protein.info.v11.5.txt",
		        "node_list_path": "1158602.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158602.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpPr090111t3t6a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PR090111T3T6A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpPr090111t3t6a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "685778.protein.sequences.v11.5.fa",
		        "enrichment_path": "685778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "685778.protein.info.v11.5.txt",
		        "node_list_path": "685778.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaPneumophilaParisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila Paris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaPneumophilaParisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "297246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "297246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "297246.clusters.proteins.v11.5.txt",
		        "sequence_path": "297246.protein.sequences.v11.5.fa",
		        "enrichment_path": "297246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "297246.protein.info.v11.5.txt",
		        "node_list_path": "297246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "297246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpMarseilleP2538(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. Marseille-P2538 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpMarseilleP2538", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816694.protein.info.v11.5.txt",
		        "node_list_path": "1816694.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat26652Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-26652 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat26652Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1684141.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1684141.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1684141.clusters.proteins.v11.5.txt",
		        "sequence_path": "1684141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1684141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1684141.protein.info.v11.5.txt",
		        "node_list_path": "1684141.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1684141.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrovirgaSpBsc39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microvirga sp. BSC39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaSpBsc39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1549810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1549810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1549810.protein.info.v11.5.txt",
		        "node_list_path": "1549810.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesMassiliensisDnlkv3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis dnLKV3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesMassiliensisDnlkv3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235788.protein.info.v11.5.txt",
		        "node_list_path": "1235788.protein.complete.v11.5.txt"
		    }
		]
    )()

def BabjeviellaInositovoraNrrlY12698(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Babjeviella inositovora NRRL Y-12698 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BabjeviellaInositovoraNrrlY12698", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "984486.protein.sequences.v11.5.fa",
		        "enrichment_path": "984486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "984486.protein.info.v11.5.txt",
		        "node_list_path": "984486.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaPseudobrasiliensisNbrc108224(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia pseudobrasiliensis NBRC 108224 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaPseudobrasiliensisNbrc108224", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210086.protein.info.v11.5.txt",
		        "node_list_path": "1210086.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusFlexusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus flexus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusFlexusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1444310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1444310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1444310.clusters.proteins.v11.5.txt",
		        "sequence_path": "1444310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444310.protein.info.v11.5.txt",
		        "node_list_path": "1444310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1444310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantheraPardus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Panthera pardus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantheraPardus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9691.protein.sequences.v11.5.fa",
		        "enrichment_path": "9691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9691.protein.info.v11.5.txt",
		        "node_list_path": "9691.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaRhizosphera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia rhizosphera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaRhizosphera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1108045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1108045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1108045.protein.info.v11.5.txt",
		        "node_list_path": "1108045.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1308866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1308866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1308866.clusters.proteins.v11.5.txt",
		        "sequence_path": "1308866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1308866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1308866.protein.info.v11.5.txt",
		        "node_list_path": "1308866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1308866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EthanoligenensHarbinenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ethanoligenens harbinense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EthanoligenensHarbinenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "663278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "663278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "663278.clusters.proteins.v11.5.txt",
		        "sequence_path": "663278.protein.sequences.v11.5.fa",
		        "enrichment_path": "663278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663278.protein.info.v11.5.txt",
		        "node_list_path": "663278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "663278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxCitrulliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax citrulli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxCitrulliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "397945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "397945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "397945.clusters.proteins.v11.5.txt",
		        "sequence_path": "397945.protein.sequences.v11.5.fa",
		        "enrichment_path": "397945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397945.protein.info.v11.5.txt",
		        "node_list_path": "397945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "397945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag822(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:822 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag822", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263032.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263032.protein.info.v11.5.txt",
		        "node_list_path": "1263032.protein.complete.v11.5.txt"
		    }
		]
    )()

def CatenuloplanesJaponicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catenuloplanes japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenuloplanesJaponicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33876.protein.sequences.v11.5.fa",
		        "enrichment_path": "33876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33876.protein.info.v11.5.txt",
		        "node_list_path": "33876.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaSpC6a8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema sp. C6A8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSpC6a8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410609.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410609.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410609.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410609.protein.info.v11.5.txt",
		        "node_list_path": "1410609.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410609.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumCentrolobii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium centrolobii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumCentrolobii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1505087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505087.protein.info.v11.5.txt",
		        "node_list_path": "1505087.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusAmargosae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus amargosae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusAmargosae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1296565.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296565.protein.info.v11.5.txt",
		        "node_list_path": "1296565.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusColwellbacteriaBacteriumRifcsplowo201Full4810(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_01_FULL_48_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo201Full4810", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797690.protein.info.v11.5.txt",
		        "node_list_path": "1797690.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusFermentumIfo3956Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fermentum IFO3956 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFermentumIfo3956Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "334390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "334390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "334390.clusters.proteins.v11.5.txt",
		        "sequence_path": "334390.protein.sequences.v11.5.fa",
		        "enrichment_path": "334390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334390.protein.info.v11.5.txt",
		        "node_list_path": "334390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "334390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpYbl2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. YBL2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpYbl2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "484429.protein.sequences.v11.5.fa",
		        "enrichment_path": "484429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484429.protein.info.v11.5.txt",
		        "node_list_path": "484429.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusRuberCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusRuberCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1240349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1240349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1240349.clusters.proteins.v11.5.txt",
		        "sequence_path": "1240349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1240349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1240349.protein.info.v11.5.txt",
		        "node_list_path": "1240349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1240349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnh287(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNH287 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnh287", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288082.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288082.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288082.protein.info.v11.5.txt",
		        "node_list_path": "1288082.protein.complete.v11.5.txt"
		    }
		]
    )()

def PezolomaEricae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pezoloma ericae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PezolomaEricae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1745343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1745343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1745343.protein.info.v11.5.txt",
		        "node_list_path": "1745343.protein.complete.v11.5.txt"
		    }
		]
    )()

def SubdoligranulumVariabileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Subdoligranulum variabile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SubdoligranulumVariabileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411471.clusters.proteins.v11.5.txt",
		        "sequence_path": "411471.protein.sequences.v11.5.fa",
		        "enrichment_path": "411471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411471.protein.info.v11.5.txt",
		        "node_list_path": "411471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaPedisStrTA4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema pedis str. T A4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPedisStrTA4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1291379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1291379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1291379.clusters.proteins.v11.5.txt",
		        "sequence_path": "1291379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291379.protein.info.v11.5.txt",
		        "node_list_path": "1291379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1291379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasGingivalisAtcc33277Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis ATCC33277 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasGingivalisAtcc33277Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "431947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "431947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "431947.clusters.proteins.v11.5.txt",
		        "sequence_path": "431947.protein.sequences.v11.5.fa",
		        "enrichment_path": "431947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431947.protein.info.v11.5.txt",
		        "node_list_path": "431947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "431947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPortnoybacteriaBacteriumRifcsphigho212Full389(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RIFCSPHIGHO2_12_FULL_38_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRifcsphigho212Full389", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801997.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801997.protein.info.v11.5.txt",
		        "node_list_path": "1801997.protein.complete.v11.5.txt"
		    }
		]
    )()

def IsoptericolaDokdonensisDs3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Isoptericola dokdonensis DS-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IsoptericolaDokdonensisDs3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1300344.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1300344.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1300344.clusters.proteins.v11.5.txt",
		        "sequence_path": "1300344.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300344.protein.info.v11.5.txt",
		        "node_list_path": "1300344.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1300344.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkaliphilusMetalliredigens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkaliphilus metalliredigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkaliphilusMetalliredigens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "293826.protein.sequences.v11.5.fa",
		        "enrichment_path": "293826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "293826.protein.info.v11.5.txt",
		        "node_list_path": "293826.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumDtu025(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU025 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumDtu025", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671639.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671639.protein.info.v11.5.txt",
		        "node_list_path": "1671639.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpDg25a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. DG25A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpDg25a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385663.protein.info.v11.5.txt",
		        "node_list_path": "1385663.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumDtu030Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU030 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumDtu030Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671640.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671640.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671640.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671640.protein.info.v11.5.txt",
		        "node_list_path": "1671640.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671640.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumDtu025Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU025 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumDtu025Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671639.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671639.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671639.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671639.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671639.protein.info.v11.5.txt",
		        "node_list_path": "1671639.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671639.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonRbg135212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_52_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg135212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797379.protein.info.v11.5.txt",
		        "node_list_path": "1797379.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloferulaStellata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloferula stellata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloferulaStellata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "876269.protein.sequences.v11.5.fa",
		        "enrichment_path": "876269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "876269.protein.info.v11.5.txt",
		        "node_list_path": "876269.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMassiliglaciei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus massiliglaciei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMassiliglaciei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816693.protein.info.v11.5.txt",
		        "node_list_path": "1816693.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaVeroralisF0319Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella veroralis F0319 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaVeroralisF0319Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649761.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649761.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649761.clusters.proteins.v11.5.txt",
		        "sequence_path": "649761.protein.sequences.v11.5.fa",
		        "enrichment_path": "649761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649761.protein.info.v11.5.txt",
		        "node_list_path": "649761.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649761.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HistophilusSomni2336(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Histophilus somni 2336 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HistophilusSomni2336", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "228400.protein.sequences.v11.5.fa",
		        "enrichment_path": "228400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228400.protein.info.v11.5.txt",
		        "node_list_path": "228400.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesMarimammalium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces marimammalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesMarimammalium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "156892.protein.sequences.v11.5.fa",
		        "enrichment_path": "156892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156892.protein.info.v11.5.txt",
		        "node_list_path": "156892.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbiconiuxGinsengi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbiconiux ginsengi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbiconiuxGinsengi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "381665.protein.sequences.v11.5.fa",
		        "enrichment_path": "381665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381665.protein.info.v11.5.txt",
		        "node_list_path": "381665.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhyseterCatodonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Physeter catodon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhyseterCatodonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9755.clusters.proteins.v11.5.txt",
		        "sequence_path": "9755.protein.sequences.v11.5.fa",
		        "enrichment_path": "9755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9755.protein.info.v11.5.txt",
		        "node_list_path": "9755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ImmundisolibacterCernigliaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Immundisolibacter cernigliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ImmundisolibacterCernigliaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1810504.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1810504.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1810504.clusters.proteins.v11.5.txt",
		        "sequence_path": "1810504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1810504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1810504.protein.info.v11.5.txt",
		        "node_list_path": "1810504.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1810504.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCrispatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus crispatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCrispatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "748671.protein.sequences.v11.5.fa",
		        "enrichment_path": "748671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748671.protein.info.v11.5.txt",
		        "node_list_path": "748671.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonosporascusSpCrb92(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. CRB-9-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSpCrb92", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2211643.protein.sequences.v11.5.fa",
		        "enrichment_path": "2211643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2211643.protein.info.v11.5.txt",
		        "node_list_path": "2211643.protein.complete.v11.5.txt"
		    }
		]
    )()

def KazachstaniaSaulgeensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania saulgeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KazachstaniaSaulgeensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1789683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1789683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1789683.protein.info.v11.5.txt",
		        "node_list_path": "1789683.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaNiastensisDsm21313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia niastensis DSM 21313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaNiastensisDsm21313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122215.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122215.protein.info.v11.5.txt",
		        "node_list_path": "1122215.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsplowo212Full6019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_12_FULL_60_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo212Full6019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797894.protein.info.v11.5.txt",
		        "node_list_path": "1797894.protein.complete.v11.5.txt"
		    }
		]
    )()

def TerrimicrobiumSacchariphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terrimicrobium sacchariphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrimicrobiumSacchariphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "690879.clusters.info.v11.5.txt",
		        "cluster_tree_path": "690879.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "690879.clusters.proteins.v11.5.txt",
		        "sequence_path": "690879.protein.sequences.v11.5.fa",
		        "enrichment_path": "690879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690879.protein.info.v11.5.txt",
		        "node_list_path": "690879.cluster.nodes.v11.5.txt",
		        "edge_list_path": "690879.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhialosimplexSpHf37(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phialosimplex sp. HF37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhialosimplexSpHf37", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1960876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1960876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1960876.protein.info.v11.5.txt",
		        "node_list_path": "1960876.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumEmbrapense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium embrapense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumEmbrapense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "630921.protein.sequences.v11.5.fa",
		        "enrichment_path": "630921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "630921.protein.info.v11.5.txt",
		        "node_list_path": "630921.protein.complete.v11.5.txt"
		    }
		]
    )()

def IntestinimonasMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Intestinimonas massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntestinimonasMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1673721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673721.protein.info.v11.5.txt",
		        "node_list_path": "1673721.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermosiphoMelanesiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosipho melanesiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosiphoMelanesiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391009.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391009.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391009.clusters.proteins.v11.5.txt",
		        "sequence_path": "391009.protein.sequences.v11.5.fa",
		        "enrichment_path": "391009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391009.protein.info.v11.5.txt",
		        "node_list_path": "391009.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391009.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasChlororaphisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas chlororaphis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasChlororaphisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "587753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "587753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "587753.clusters.proteins.v11.5.txt",
		        "sequence_path": "587753.protein.sequences.v11.5.fa",
		        "enrichment_path": "587753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "587753.protein.info.v11.5.txt",
		        "node_list_path": "587753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "587753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCc53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CC53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCc53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906740.protein.info.v11.5.txt",
		        "node_list_path": "1906740.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeon13140cm3386(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon 13_1_40CM_3_38_6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeon13140cm3386", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805390.protein.info.v11.5.txt",
		        "node_list_path": "1805390.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProtochlamydiaAmoebophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Protochlamydia amoebophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProtochlamydiaAmoebophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264201.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264201.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264201.clusters.proteins.v11.5.txt",
		        "sequence_path": "264201.protein.sequences.v11.5.fa",
		        "enrichment_path": "264201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264201.protein.info.v11.5.txt",
		        "node_list_path": "264201.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264201.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HoefleaSpImcc20628(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hoeflea sp. IMCC20628 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoefleaSpImcc20628", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1620421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1620421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1620421.protein.info.v11.5.txt",
		        "node_list_path": "1620421.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlbidiferaxSpOv413(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Albidiferax sp. OV413 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlbidiferaxSpOv413", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855285.protein.info.v11.5.txt",
		        "node_list_path": "1855285.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumMultihospitium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium multihospitium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumMultihospitium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "410764.protein.sequences.v11.5.fa",
		        "enrichment_path": "410764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "410764.protein.info.v11.5.txt",
		        "node_list_path": "410764.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaInnocuaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria innocua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaInnocuaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272626.clusters.proteins.v11.5.txt",
		        "sequence_path": "272626.protein.sequences.v11.5.fa",
		        "enrichment_path": "272626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272626.protein.info.v11.5.txt",
		        "node_list_path": "272626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpRoot264Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root264 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpRoot264Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736503.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736503.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736503.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736503.protein.info.v11.5.txt",
		        "node_list_path": "1736503.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736503.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseolineaSerpens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseolinea serpens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseolineaSerpens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "947013.protein.sequences.v11.5.fa",
		        "enrichment_path": "947013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "947013.protein.info.v11.5.txt",
		        "node_list_path": "947013.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhlebiopsisGigantea110611Cr56Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phlebiopsis gigantea 11061_1 CR5-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhlebiopsisGigantea110611Cr56Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "745531.clusters.info.v11.5.txt",
		        "cluster_tree_path": "745531.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "745531.clusters.proteins.v11.5.txt",
		        "sequence_path": "745531.protein.sequences.v11.5.fa",
		        "enrichment_path": "745531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745531.protein.info.v11.5.txt",
		        "node_list_path": "745531.cluster.nodes.v11.5.txt",
		        "edge_list_path": "745531.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusParalimentariusDsm19674(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paralimentarius DSM 19674 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParalimentariusDsm19674", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423788.protein.info.v11.5.txt",
		        "node_list_path": "1423788.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriovoraxSpBsw11iv(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. BSW11IV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriovoraxSpBsw11iv", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1353529.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353529.protein.info.v11.5.txt",
		        "node_list_path": "1353529.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanofollisEthanolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanofollis ethanolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanofollisEthanolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "488124.protein.sequences.v11.5.fa",
		        "enrichment_path": "488124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "488124.protein.info.v11.5.txt",
		        "node_list_path": "488124.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprococcusPhoceensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus phoceensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprococcusPhoceensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1870993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870993.protein.info.v11.5.txt",
		        "node_list_path": "1870993.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumRifcsphigho212Full4012(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_12_FULL_40_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho212Full4012", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802457.protein.info.v11.5.txt",
		        "node_list_path": "1802457.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobacterCurvatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacter curvatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacterCurvatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121396.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121396.protein.info.v11.5.txt",
		        "node_list_path": "1121396.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZetaproteobacteriaBacteriumCg2304652(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG2_30_46_52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaproteobacteriaBacteriumCg2304652", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805429.protein.info.v11.5.txt",
		        "node_list_path": "1805429.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpGa1999(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1999 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpGa1999", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1772275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772275.protein.info.v11.5.txt",
		        "node_list_path": "1772275.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotorhabdusAustralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photorhabdus australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotorhabdusAustralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "286156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "286156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "286156.clusters.proteins.v11.5.txt",
		        "sequence_path": "286156.protein.sequences.v11.5.fa",
		        "enrichment_path": "286156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "286156.protein.info.v11.5.txt",
		        "node_list_path": "286156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "286156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusGordonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus gordonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusGordonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "467705.protein.sequences.v11.5.fa",
		        "enrichment_path": "467705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "467705.protein.info.v11.5.txt",
		        "node_list_path": "467705.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanospirillumLinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum linum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanospirillumLinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "966.clusters.proteins.v11.5.txt",
		        "sequence_path": "966.protein.sequences.v11.5.fa",
		        "enrichment_path": "966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "966.protein.info.v11.5.txt",
		        "node_list_path": "966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumSm2331Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium SM23_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumSm2331Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703762.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703762.protein.info.v11.5.txt",
		        "node_list_path": "1703762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AllofrancisellaGuangzhouensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Allofrancisella guangzhouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllofrancisellaGuangzhouensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "594679.protein.sequences.v11.5.fa",
		        "enrichment_path": "594679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "594679.protein.info.v11.5.txt",
		        "node_list_path": "594679.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumColombiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium colombiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumColombiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041522.protein.info.v11.5.txt",
		        "node_list_path": "1041522.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAc2031(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2031 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAc2031", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392493.protein.info.v11.5.txt",
		        "node_list_path": "1392493.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumNurukiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium nuruki Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumNurukiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "863239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "863239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "863239.clusters.proteins.v11.5.txt",
		        "sequence_path": "863239.protein.sequences.v11.5.fa",
		        "enrichment_path": "863239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "863239.protein.info.v11.5.txt",
		        "node_list_path": "863239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "863239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaDispersa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea dispersa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaDispersa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59814.protein.sequences.v11.5.fa",
		        "enrichment_path": "59814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59814.protein.info.v11.5.txt",
		        "node_list_path": "59814.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumAutotrophicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum autotrophicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumAutotrophicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "180195.protein.sequences.v11.5.fa",
		        "enrichment_path": "180195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180195.protein.info.v11.5.txt",
		        "node_list_path": "180195.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFuscovaginaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fuscovaginae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFuscovaginaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "50340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "50340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "50340.clusters.proteins.v11.5.txt",
		        "sequence_path": "50340.protein.sequences.v11.5.fa",
		        "enrichment_path": "50340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50340.protein.info.v11.5.txt",
		        "node_list_path": "50340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "50340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrahymenaThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetrahymena thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrahymenaThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5911.protein.sequences.v11.5.fa",
		        "enrichment_path": "5911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5911.protein.info.v11.5.txt",
		        "node_list_path": "5911.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23623(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_36_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23623", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618480.protein.info.v11.5.txt",
		        "node_list_path": "1618480.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesPurpeofuscusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces purpeofuscus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPurpeofuscusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67352.clusters.proteins.v11.5.txt",
		        "sequence_path": "67352.protein.sequences.v11.5.fa",
		        "enrichment_path": "67352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67352.protein.info.v11.5.txt",
		        "node_list_path": "67352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesTogonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides togonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesTogonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1917883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917883.protein.info.v11.5.txt",
		        "node_list_path": "1917883.protein.complete.v11.5.txt"
		    }
		]
    )()

def PicoidesPubescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Picoides pubescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PicoidesPubescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118200.clusters.proteins.v11.5.txt",
		        "sequence_path": "118200.protein.sequences.v11.5.fa",
		        "enrichment_path": "118200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118200.protein.info.v11.5.txt",
		        "node_list_path": "118200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FermentimonasCaenicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fermentimonas caenicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FermentimonasCaenicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1562970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1562970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1562970.protein.info.v11.5.txt",
		        "node_list_path": "1562970.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumOxysporumFSpRadicisCucumerinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. radicis-cucumerinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumOxysporumFSpRadicisCucumerinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "327505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "327505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "327505.clusters.proteins.v11.5.txt",
		        "sequence_path": "327505.protein.sequences.v11.5.fa",
		        "enrichment_path": "327505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "327505.protein.info.v11.5.txt",
		        "node_list_path": "327505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "327505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KockovaellaImperatae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kockovaella imperatae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KockovaellaImperatae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4999.protein.sequences.v11.5.fa",
		        "enrichment_path": "4999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4999.protein.info.v11.5.txt",
		        "node_list_path": "4999.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSpYr412(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. YR412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpYr412", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881030.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881030.protein.info.v11.5.txt",
		        "node_list_path": "1881030.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioCyclitrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cyclitrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCyclitrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1136163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1136163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1136163.clusters.proteins.v11.5.txt",
		        "sequence_path": "1136163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1136163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1136163.protein.info.v11.5.txt",
		        "node_list_path": "1136163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1136163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27231(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27231 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27231", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1679168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679168.protein.info.v11.5.txt",
		        "node_list_path": "1679168.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasHussainii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas hussainii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasHussainii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1429083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1429083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1429083.protein.info.v11.5.txt",
		        "node_list_path": "1429083.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaeBacteriumRifcsphigho212Full4911Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPHIGHO2_12_FULL_49_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaeBacteriumRifcsphigho212Full4911Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797603.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797603.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797603.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797603.protein.info.v11.5.txt",
		        "node_list_path": "1797603.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797603.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SimiduiaAgarivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Simiduia agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SimiduiaAgarivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117647.protein.info.v11.5.txt",
		        "node_list_path": "1117647.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumVitaeruminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium vitaeruminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumVitaeruminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1224164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1224164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1224164.clusters.proteins.v11.5.txt",
		        "sequence_path": "1224164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224164.protein.info.v11.5.txt",
		        "node_list_path": "1224164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1224164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpRcc307(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. RCC307 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpRcc307", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316278.protein.sequences.v11.5.fa",
		        "enrichment_path": "316278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316278.protein.info.v11.5.txt",
		        "node_list_path": "316278.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaParaffinivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia paraffinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaParaffinivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223543.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223543.protein.info.v11.5.txt",
		        "node_list_path": "1223543.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseobacterSpCcs2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. CCS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterSpCcs2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391593.protein.sequences.v11.5.fa",
		        "enrichment_path": "391593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391593.protein.info.v11.5.txt",
		        "node_list_path": "391593.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpMilost1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. MilosT1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpMilost1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "90813.protein.sequences.v11.5.fa",
		        "enrichment_path": "90813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90813.protein.info.v11.5.txt",
		        "node_list_path": "90813.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpEpsl27Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. EPSL27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpEpsl27Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1745378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1745378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1745378.clusters.proteins.v11.5.txt",
		        "sequence_path": "1745378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1745378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1745378.protein.info.v11.5.txt",
		        "node_list_path": "1745378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1745378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaecibacterMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caecibacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaecibacterMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852378.protein.info.v11.5.txt",
		        "node_list_path": "1852378.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpJa33ab(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. JA33Ab graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpJa33ab", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321327.protein.sequences.v11.5.fa",
		        "enrichment_path": "321327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321327.protein.info.v11.5.txt",
		        "node_list_path": "321327.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumSg841(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium SG8_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumSg841", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703391.protein.info.v11.5.txt",
		        "node_list_path": "1703391.protein.complete.v11.5.txt"
		    }
		]
    )()

def AndreeseniaAngusta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Andreesenia angusta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AndreeseniaAngusta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39480.protein.sequences.v11.5.fa",
		        "enrichment_path": "39480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39480.protein.info.v11.5.txt",
		        "node_list_path": "39480.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb1388(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_38_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb1388", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618864.protein.info.v11.5.txt",
		        "node_list_path": "1618864.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZimmermannellaFaecalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zimmermannella faecalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZimmermannellaFaecalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278308.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278308.protein.info.v11.5.txt",
		        "node_list_path": "1278308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1329250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1329250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1329250.protein.info.v11.5.txt",
		        "node_list_path": "1329250.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumConfluentisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium confluentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumConfluentisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28047.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28047.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28047.clusters.proteins.v11.5.txt",
		        "sequence_path": "28047.protein.sequences.v11.5.fa",
		        "enrichment_path": "28047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28047.protein.info.v11.5.txt",
		        "node_list_path": "28047.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28047.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHtcc7214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC7214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHtcc7214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1400524.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400524.protein.info.v11.5.txt",
		        "node_list_path": "1400524.protein.complete.v11.5.txt"
		    }
		]
    )()

def KitasatosporaArboriphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora arboriphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaArboriphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "258052.protein.sequences.v11.5.fa",
		        "enrichment_path": "258052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "258052.protein.info.v11.5.txt",
		        "node_list_path": "258052.protein.complete.v11.5.txt"
		    }
		]
    )()

def JuncoHyemalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Junco hyemalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JuncoHyemalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40217.clusters.proteins.v11.5.txt",
		        "sequence_path": "40217.protein.sequences.v11.5.fa",
		        "enrichment_path": "40217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40217.protein.info.v11.5.txt",
		        "node_list_path": "40217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaArthritidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma arthritidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaArthritidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243272.clusters.proteins.v11.5.txt",
		        "sequence_path": "243272.protein.sequences.v11.5.fa",
		        "enrichment_path": "243272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243272.protein.info.v11.5.txt",
		        "node_list_path": "243272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxya2Full588Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2_FULL_58_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2Full588Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797962.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797962.protein.info.v11.5.txt",
		        "node_list_path": "1797962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumTaihuense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium taihuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumTaihuense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1141221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141221.protein.info.v11.5.txt",
		        "node_list_path": "1141221.protein.complete.v11.5.txt"
		    }
		]
    )()

def MolaMolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mola mola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MolaMolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "94237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "94237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "94237.clusters.proteins.v11.5.txt",
		        "sequence_path": "94237.protein.sequences.v11.5.fa",
		        "enrichment_path": "94237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94237.protein.info.v11.5.txt",
		        "node_list_path": "94237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "94237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophomonasWolfei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophomonasWolfei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "335541.protein.sequences.v11.5.fa",
		        "enrichment_path": "335541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335541.protein.info.v11.5.txt",
		        "node_list_path": "335541.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucobacterSpUcdThuCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter sp. UCD-THU Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterSpUcdThuCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1292023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1292023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1292023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1292023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292023.protein.info.v11.5.txt",
		        "node_list_path": "1292023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1292023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpCag877(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:877 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpCag877", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262907.protein.info.v11.5.txt",
		        "node_list_path": "1262907.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpSk140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. SK140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpSk140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095726.protein.info.v11.5.txt",
		        "node_list_path": "1095726.protein.complete.v11.5.txt"
		    }
		]
    )()

def MannheimiaVarigenaUsmarc1296(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena USMARC1296 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaVarigenaUsmarc1296", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1433287.protein.sequences.v11.0.fa",
		        "enrichment_path": "1433287.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1433287.protein.info.v11.0.txt",
		        "node_list_path": "1433287.protein.complete.v11.0.txt"
		    }
		]
    )()

def MannheimiaHaemolyticaSerotypeA2Bovine(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica serotype A2 BOVINE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaHaemolyticaSerotypeA2Bovine", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "669262.protein.sequences.v11.5.fa",
		        "enrichment_path": "669262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "669262.protein.info.v11.5.txt",
		        "node_list_path": "669262.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262998.protein.info.v11.5.txt",
		        "node_list_path": "1262998.protein.complete.v11.5.txt"
		    }
		]
    )()

def AscoideaRubescensDsm1968Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ascoidea rubescens DSM 1968 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AscoideaRubescensDsm1968Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1344418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1344418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1344418.clusters.proteins.v11.5.txt",
		        "sequence_path": "1344418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1344418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1344418.protein.info.v11.5.txt",
		        "node_list_path": "1344418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1344418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaPickettiiDtp0602Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia pickettii DTP0602 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaPickettiiDtp0602Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1366050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1366050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1366050.clusters.proteins.v11.5.txt",
		        "sequence_path": "1366050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1366050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1366050.protein.info.v11.5.txt",
		        "node_list_path": "1366050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1366050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumKht7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KHT7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumKht7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855373.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855373.protein.info.v11.5.txt",
		        "node_list_path": "1855373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumCg1023744(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium CG1_02_37_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumCg1023744", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805146.protein.info.v11.5.txt",
		        "node_list_path": "1805146.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterSp12014mblMicdivCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter sp. 1_2014MBL_MicDiv Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterSp12014mblMicdivCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1644130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1644130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1644130.clusters.proteins.v11.5.txt",
		        "sequence_path": "1644130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1644130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1644130.protein.info.v11.5.txt",
		        "node_list_path": "1644130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1644130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumRhizogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium rhizogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumRhizogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "359.clusters.proteins.v11.5.txt",
		        "sequence_path": "359.protein.sequences.v11.5.fa",
		        "enrichment_path": "359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "359.protein.info.v11.5.txt",
		        "node_list_path": "359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaGrayi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria grayi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaGrayi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525367.protein.sequences.v11.5.fa",
		        "enrichment_path": "525367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525367.protein.info.v11.5.txt",
		        "node_list_path": "525367.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaF1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida F1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaF1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351746.protein.sequences.v11.5.fa",
		        "enrichment_path": "351746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351746.protein.info.v11.5.txt",
		        "node_list_path": "351746.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterTjernbergiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter tjernbergiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterTjernbergiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "202955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "202955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "202955.clusters.proteins.v11.5.txt",
		        "sequence_path": "202955.protein.sequences.v11.5.fa",
		        "enrichment_path": "202955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202955.protein.info.v11.5.txt",
		        "node_list_path": "202955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "202955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlexithrixDorotheaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flexithrix dorotheae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlexithrixDorotheaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121904.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121904.protein.info.v11.5.txt",
		        "node_list_path": "1121904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanothermococcusThermolithotrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanothermococcus thermolithotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermococcusThermolithotrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "523845.protein.sequences.v11.5.fa",
		        "enrichment_path": "523845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523845.protein.info.v11.5.txt",
		        "node_list_path": "523845.protein.complete.v11.5.txt"
		    }
		]
    )()

def GolovinomycesMagnicellulatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Golovinomyces magnicellulatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GolovinomycesMagnicellulatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "62714.protein.sequences.v11.5.fa",
		        "enrichment_path": "62714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62714.protein.info.v11.5.txt",
		        "node_list_path": "62714.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full4213Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_42_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full4213Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798286.protein.info.v11.5.txt",
		        "node_list_path": "1798286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasJejuensisNbrc106434(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas jejuensis NBRC 106434 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasJejuensisNbrc106434", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321608.protein.info.v11.5.txt",
		        "node_list_path": "1321608.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwc26444(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWC2_64_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwc26444", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797935.protein.info.v11.5.txt",
		        "node_list_path": "1797935.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIs1264(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1264 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIs1264", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834158.protein.info.v11.5.txt",
		        "node_list_path": "1834158.protein.complete.v11.5.txt"
		    }
		]
    )()

def CastellaniellaDefragrans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Castellaniella defragrans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CastellaniellaDefragrans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437824.protein.info.v11.5.txt",
		        "node_list_path": "1437824.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf38(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf38", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736217.protein.info.v11.5.txt",
		        "node_list_path": "1736217.protein.complete.v11.5.txt"
		    }
		]
    )()

def DenticepsClupeoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Denticeps clupeoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DenticepsClupeoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "299321.protein.sequences.v11.5.fa",
		        "enrichment_path": "299321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299321.protein.info.v11.5.txt",
		        "node_list_path": "299321.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisSpNrrlB16309Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. NRRL B-16309 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisSpNrrlB16309Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1519494.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1519494.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1519494.clusters.proteins.v11.5.txt",
		        "sequence_path": "1519494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519494.protein.info.v11.5.txt",
		        "node_list_path": "1519494.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1519494.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmorphusCoralli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amorphus coralli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmorphusCoralli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120983.protein.info.v11.5.txt",
		        "node_list_path": "1120983.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumEtliCfn42(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli CFN42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumEtliCfn42", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "347834.protein.sequences.v11.5.fa",
		        "enrichment_path": "347834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "347834.protein.info.v11.5.txt",
		        "node_list_path": "347834.protein.complete.v11.5.txt"
		    }
		]
    )()

def FriedmanniellaFlavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Friedmanniella flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FriedmanniellaFlavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1036181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1036181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1036181.clusters.proteins.v11.5.txt",
		        "sequence_path": "1036181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036181.protein.info.v11.5.txt",
		        "node_list_path": "1036181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1036181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonadalesBacterium6970(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 69-70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonadalesBacterium6970", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895869.protein.info.v11.5.txt",
		        "node_list_path": "1895869.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSulfidigenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sulfidigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSulfidigenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "318464.clusters.info.v11.5.txt",
		        "cluster_tree_path": "318464.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "318464.clusters.proteins.v11.5.txt",
		        "sequence_path": "318464.protein.sequences.v11.5.fa",
		        "enrichment_path": "318464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318464.protein.info.v11.5.txt",
		        "node_list_path": "318464.cluster.nodes.v11.5.txt",
		        "edge_list_path": "318464.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidilobusSaccharovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidilobus saccharovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidilobusSaccharovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "666510.protein.sequences.v11.5.fa",
		        "enrichment_path": "666510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "666510.protein.info.v11.5.txt",
		        "node_list_path": "666510.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAziziiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus azizii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAziziiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1579424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1579424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1579424.clusters.proteins.v11.5.txt",
		        "sequence_path": "1579424.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579424.protein.info.v11.5.txt",
		        "node_list_path": "1579424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1579424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerrisporobacterOthiniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terrisporobacter othiniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrisporobacterOthiniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577792.protein.info.v11.5.txt",
		        "node_list_path": "1577792.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwa24319Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_43_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa24319Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797804.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797804.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797804.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797804.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797804.protein.info.v11.5.txt",
		        "node_list_path": "1797804.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797804.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OleibacterMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oleibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OleibacterMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "484498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "484498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "484498.clusters.proteins.v11.5.txt",
		        "sequence_path": "484498.protein.sequences.v11.5.fa",
		        "enrichment_path": "484498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484498.protein.info.v11.5.txt",
		        "node_list_path": "484498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "484498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumGas113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium GAS113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumGas113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884352.protein.info.v11.5.txt",
		        "node_list_path": "1884352.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaTurkmenica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena turkmenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaTurkmenica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "543526.protein.sequences.v11.5.fa",
		        "enrichment_path": "543526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543526.protein.info.v11.5.txt",
		        "node_list_path": "543526.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf28(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf28", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735695.protein.info.v11.5.txt",
		        "node_list_path": "1735695.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerostipesCaccae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerostipes caccae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerostipesCaccae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411490.protein.sequences.v11.5.fa",
		        "enrichment_path": "411490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411490.protein.info.v11.5.txt",
		        "node_list_path": "411490.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumFormicaceticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium formicaceticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumFormicaceticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1497.protein.info.v11.5.txt",
		        "node_list_path": "1497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DomibacillusIndicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusIndicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437523.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437523.protein.info.v11.5.txt",
		        "node_list_path": "1437523.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpLeaf127(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf127 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpLeaf127", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736267.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736267.protein.info.v11.5.txt",
		        "node_list_path": "1736267.protein.complete.v11.5.txt"
		    }
		]
    )()

def MurdochiellaVaginalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Murdochiella vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MurdochiellaVaginalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852373.protein.info.v11.5.txt",
		        "node_list_path": "1852373.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanicaulisSpHl87(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. HL87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicaulisSpHl87", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1479238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479238.protein.info.v11.5.txt",
		        "node_list_path": "1479238.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag552Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:552 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag552Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263029.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263029.protein.info.v11.5.txt",
		        "node_list_path": "1263029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SandarakinorhabdusSpAap62(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sandarakinorhabdus sp. AAP62 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SandarakinorhabdusSpAap62", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1248916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1248916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1248916.protein.info.v11.5.txt",
		        "node_list_path": "1248916.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmodiophoraBrassicae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodiophora brassicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiophoraBrassicae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37360.protein.sequences.v11.5.fa",
		        "enrichment_path": "37360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37360.protein.info.v11.5.txt",
		        "node_list_path": "37360.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag349Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag349Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262797.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262797.protein.info.v11.5.txt",
		        "node_list_path": "1262797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AfipiaBirgiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Afipia birgiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaBirgiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1197906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1197906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1197906.clusters.proteins.v11.5.txt",
		        "sequence_path": "1197906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197906.protein.info.v11.5.txt",
		        "node_list_path": "1197906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1197906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacterium6626Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 66-26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacterium6626Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895727.protein.info.v11.5.txt",
		        "node_list_path": "1895727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaArginini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma arginini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaArginini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1188236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188236.protein.info.v11.5.txt",
		        "node_list_path": "1188236.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSynoviaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma synoviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSynoviaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "262723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "262723.clusters.proteins.v11.5.txt",
		        "sequence_path": "262723.protein.sequences.v11.5.fa",
		        "enrichment_path": "262723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262723.protein.info.v11.5.txt",
		        "node_list_path": "262723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "262723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumOleivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium oleivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumOleivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "273677.protein.sequences.v11.5.fa",
		        "enrichment_path": "273677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273677.protein.info.v11.5.txt",
		        "node_list_path": "273677.protein.complete.v11.5.txt"
		    }
		]
    )()

def ModestobacterSpLeaf380Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Modestobacter sp. Leaf380 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ModestobacterSpLeaf380Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736356.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736356.protein.info.v11.5.txt",
		        "node_list_path": "1736356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirosomaEndophyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma endophyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaEndophyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "662367.protein.sequences.v11.5.fa",
		        "enrichment_path": "662367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "662367.protein.info.v11.5.txt",
		        "node_list_path": "662367.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpUnc305mfcol52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. UNC305MFCol52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpUnc305mfcol52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449076.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449076.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449076.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449076.protein.info.v11.5.txt",
		        "node_list_path": "1449076.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449076.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh8109(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8109 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh8109", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "166314.protein.sequences.v11.5.fa",
		        "enrichment_path": "166314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "166314.protein.info.v11.5.txt",
		        "node_list_path": "166314.protein.complete.v11.5.txt"
		    }
		]
    )()

def OctopusBimaculoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Octopus bimaculoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OctopusBimaculoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37653.protein.sequences.v11.5.fa",
		        "enrichment_path": "37653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37653.protein.info.v11.5.txt",
		        "node_list_path": "37653.protein.complete.v11.5.txt"
		    }
		]
    )()

def PuniceicoccalesBacteriumVerruco01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Puniceicoccales bacterium Verruco_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PuniceicoccalesBacteriumVerruco01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674912.protein.info.v11.5.txt",
		        "node_list_path": "1674912.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrugiaMalayi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brugia malayi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrugiaMalayi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6279.protein.sequences.v11.5.fa",
		        "enrichment_path": "6279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6279.protein.info.v11.5.txt",
		        "node_list_path": "6279.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumRamulus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium ramulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumRamulus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1256908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1256908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1256908.protein.info.v11.5.txt",
		        "node_list_path": "1256908.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxyb2Full497Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2_FULL_49_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2Full497Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797968.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797968.protein.info.v11.5.txt",
		        "node_list_path": "1797968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaAuris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Candida] auris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaAuris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "498019.protein.sequences.v11.5.fa",
		        "enrichment_path": "498019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498019.protein.info.v11.5.txt",
		        "node_list_path": "498019.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterTowneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter towneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterTowneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "202956.protein.sequences.v11.5.fa",
		        "enrichment_path": "202956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202956.protein.info.v11.5.txt",
		        "node_list_path": "202956.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4922bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_01_FULL_49_22b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4922bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802448.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802448.protein.info.v11.5.txt",
		        "node_list_path": "1802448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasSpMwyl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. MWYL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasSpMwyl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "400668.protein.sequences.v11.5.fa",
		        "enrichment_path": "400668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400668.protein.info.v11.5.txt",
		        "node_list_path": "400668.protein.complete.v11.5.txt"
		    }
		]
    )()

def MacrophominaPhaseolina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Macrophomina phaseolina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacrophominaPhaseolina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35725.protein.sequences.v11.5.fa",
		        "enrichment_path": "35725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35725.protein.info.v11.5.txt",
		        "node_list_path": "35725.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu072(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU072 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu072", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671656.protein.info.v11.5.txt",
		        "node_list_path": "1671656.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuricibacterSpH121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Turicibacter sp. H121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuricibacterSpH121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1712675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1712675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1712675.protein.info.v11.5.txt",
		        "node_list_path": "1712675.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetitomaculumRuminisDsm5522Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetitomaculum ruminis DSM 5522 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetitomaculumRuminisDsm5522Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120918.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120918.protein.info.v11.5.txt",
		        "node_list_path": "1120918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag451(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:451 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag451", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262809.protein.info.v11.5.txt",
		        "node_list_path": "1262809.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalimicrobiumAerophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalimicrobium aerophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalimicrobiumAerophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717772.protein.sequences.v11.5.fa",
		        "enrichment_path": "717772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717772.protein.info.v11.5.txt",
		        "node_list_path": "717772.protein.complete.v11.5.txt"
		    }
		]
    )()

def RaoultellaOrnithinolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Raoultella ornithinolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RaoultellaOrnithinolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1286170.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1286170.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1286170.clusters.proteins.v11.5.txt",
		        "sequence_path": "1286170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286170.protein.info.v11.5.txt",
		        "node_list_path": "1286170.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1286170.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FacklamiaHominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Facklamia hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FacklamiaHominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883110.protein.sequences.v11.5.fa",
		        "enrichment_path": "883110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883110.protein.info.v11.5.txt",
		        "node_list_path": "883110.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophilusMethylotrophus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus methylotrophus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusMethylotrophus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122236.protein.info.v11.5.txt",
		        "node_list_path": "1122236.protein.complete.v11.5.txt"
		    }
		]
    )()

def DichomitusSqualens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dichomitus squalens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DichomitusSqualens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "114155.protein.sequences.v11.5.fa",
		        "enrichment_path": "114155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "114155.protein.info.v11.5.txt",
		        "node_list_path": "114155.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlomeribacterGigasporarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glomeribacter gigasporarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlomeribacterGigasporarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1070319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1070319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1070319.protein.info.v11.5.txt",
		        "node_list_path": "1070319.protein.complete.v11.5.txt"
		    }
		]
    )()

def FervidicolaFerrireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fervidicola ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidicolaFerrireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "520764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "520764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "520764.clusters.proteins.v11.5.txt",
		        "sequence_path": "520764.protein.sequences.v11.5.fa",
		        "enrichment_path": "520764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "520764.protein.info.v11.5.txt",
		        "node_list_path": "520764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "520764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusJaponica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusJaponica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53341.protein.sequences.v11.5.fa",
		        "enrichment_path": "53341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53341.protein.info.v11.5.txt",
		        "node_list_path": "53341.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizoclosmatiumGlobosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizoclosmatium globosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizoclosmatiumGlobosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "329046.clusters.info.v11.5.txt",
		        "cluster_tree_path": "329046.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "329046.clusters.proteins.v11.5.txt",
		        "sequence_path": "329046.protein.sequences.v11.5.fa",
		        "enrichment_path": "329046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "329046.protein.info.v11.5.txt",
		        "node_list_path": "329046.cluster.nodes.v11.5.txt",
		        "edge_list_path": "329046.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaTenuis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida tenuis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaTenuis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45596.protein.sequences.v11.5.fa",
		        "enrichment_path": "45596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45596.protein.info.v11.5.txt",
		        "node_list_path": "45596.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkaliphilusMetalliredigensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkaliphilus metalliredigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkaliphilusMetalliredigensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "293826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "293826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "293826.clusters.proteins.v11.5.txt",
		        "sequence_path": "293826.protein.sequences.v11.5.fa",
		        "enrichment_path": "293826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "293826.protein.info.v11.5.txt",
		        "node_list_path": "293826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "293826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpGcs4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. GCS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpGcs4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1692239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1692239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1692239.clusters.proteins.v11.5.txt",
		        "sequence_path": "1692239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1692239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1692239.protein.info.v11.5.txt",
		        "node_list_path": "1692239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1692239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumCg104938(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium CG10_49_38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumCg104938", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1911687.protein.sequences.v11.5.fa",
		        "enrichment_path": "1911687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1911687.protein.info.v11.5.txt",
		        "node_list_path": "1911687.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb245a519a13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_519A13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb245a519a13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1471509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471509.protein.info.v11.5.txt",
		        "node_list_path": "1471509.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfitobacteriumDehalogenansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium dehalogenans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitobacteriumDehalogenansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "756499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "756499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "756499.clusters.proteins.v11.5.txt",
		        "sequence_path": "756499.protein.sequences.v11.5.fa",
		        "enrichment_path": "756499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "756499.protein.info.v11.5.txt",
		        "node_list_path": "756499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "756499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpJs623Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JS623 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpJs623Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "212767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "212767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "212767.clusters.proteins.v11.5.txt",
		        "sequence_path": "212767.protein.sequences.v11.5.fa",
		        "enrichment_path": "212767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "212767.protein.info.v11.5.txt",
		        "node_list_path": "212767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "212767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BipolarisZeicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris zeicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisZeicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5017.clusters.proteins.v11.5.txt",
		        "sequence_path": "5017.protein.sequences.v11.5.fa",
		        "enrichment_path": "5017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5017.protein.info.v11.5.txt",
		        "node_list_path": "5017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumBrachiatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium brachiatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumBrachiatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "269660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "269660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "269660.clusters.proteins.v11.5.txt",
		        "sequence_path": "269660.protein.sequences.v11.5.fa",
		        "enrichment_path": "269660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269660.protein.info.v11.5.txt",
		        "node_list_path": "269660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "269660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsphigho202Full4711Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_47_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full4711Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802270.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802270.protein.info.v11.5.txt",
		        "node_list_path": "1802270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MusSpicilegusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mus spicilegus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusSpicilegusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10103.clusters.proteins.v11.5.txt",
		        "sequence_path": "10103.protein.sequences.v11.5.fa",
		        "enrichment_path": "10103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10103.protein.info.v11.5.txt",
		        "node_list_path": "10103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicavibrioAeruginosavorusArl13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micavibrio aeruginosavorus ARL13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicavibrioAeruginosavorusArl13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "856793.clusters.info.v11.5.txt",
		        "cluster_tree_path": "856793.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "856793.clusters.proteins.v11.5.txt",
		        "sequence_path": "856793.protein.sequences.v11.5.fa",
		        "enrichment_path": "856793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "856793.protein.info.v11.5.txt",
		        "node_list_path": "856793.cluster.nodes.v11.5.txt",
		        "edge_list_path": "856793.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpGm21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. GM21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpGm21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144325.protein.info.v11.5.txt",
		        "node_list_path": "1144325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumAethiopicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum aethiopicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumAethiopicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1758255.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1758255.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1758255.clusters.proteins.v11.5.txt",
		        "sequence_path": "1758255.protein.sequences.v11.5.fa",
		        "enrichment_path": "1758255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1758255.protein.info.v11.5.txt",
		        "node_list_path": "1758255.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1758255.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumJaponicumUsda6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum USDA6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumJaponicumUsda6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1037409.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1037409.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1037409.clusters.proteins.v11.5.txt",
		        "sequence_path": "1037409.protein.sequences.v11.5.fa",
		        "enrichment_path": "1037409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1037409.protein.info.v11.5.txt",
		        "node_list_path": "1037409.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1037409.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HanseniasporaOsmophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hanseniaspora osmophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HanseniasporaOsmophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56408.protein.sequences.v11.5.fa",
		        "enrichment_path": "56408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56408.protein.info.v11.5.txt",
		        "node_list_path": "56408.protein.complete.v11.5.txt"
		    }
		]
    )()

def BatrachochytriumDendrobatidisJam81Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis JAM81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BatrachochytriumDendrobatidisJam81Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "684364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "684364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "684364.clusters.proteins.v11.5.txt",
		        "sequence_path": "684364.protein.sequences.v11.5.fa",
		        "enrichment_path": "684364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "684364.protein.info.v11.5.txt",
		        "node_list_path": "684364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "684364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalopigerXanaduensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halopiger xanaduensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalopigerXanaduensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "797210.clusters.info.v11.5.txt",
		        "cluster_tree_path": "797210.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "797210.clusters.proteins.v11.5.txt",
		        "sequence_path": "797210.protein.sequences.v11.5.fa",
		        "enrichment_path": "797210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797210.protein.info.v11.5.txt",
		        "node_list_path": "797210.cluster.nodes.v11.5.txt",
		        "edge_list_path": "797210.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollinsellaIntestinalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collinsella intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaIntestinalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521003.protein.sequences.v11.5.fa",
		        "enrichment_path": "521003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521003.protein.info.v11.5.txt",
		        "node_list_path": "521003.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumHch1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium HCH-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumHch1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1748249.protein.sequences.v11.5.fa",
		        "enrichment_path": "1748249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1748249.protein.info.v11.5.txt",
		        "node_list_path": "1748249.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytophthoraSojaeStrainP6497Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora sojae strain P6497 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraSojaeStrainP6497Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094619.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094619.protein.info.v11.5.txt",
		        "node_list_path": "1094619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasSpNyagatareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Nyagatare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasSpNyagatareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1552758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1552758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1552758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1552758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1552758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1552758.protein.info.v11.5.txt",
		        "node_list_path": "1552758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1552758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FerrimonasFuttsuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas futtsuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrimonasFuttsuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121878.protein.info.v11.5.txt",
		        "node_list_path": "1121878.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichococcusPalustrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichococcus palustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichococcusPalustrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "140314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "140314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "140314.clusters.proteins.v11.5.txt",
		        "sequence_path": "140314.protein.sequences.v11.5.fa",
		        "enrichment_path": "140314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "140314.protein.info.v11.5.txt",
		        "node_list_path": "140314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "140314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSchekmanbacteriaBacteriumRifcsplowo212Full3815(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Schekmanbacteria bacterium RIFCSPLOWO2_12_FULL_38_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSchekmanbacteriaBacteriumRifcsplowo212Full3815", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817883.protein.info.v11.5.txt",
		        "node_list_path": "1817883.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalosimplexCarlsbadenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halosimplex carlsbadense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalosimplexCarlsbadenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "797114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "797114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "797114.clusters.proteins.v11.5.txt",
		        "sequence_path": "797114.protein.sequences.v11.5.fa",
		        "enrichment_path": "797114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797114.protein.info.v11.5.txt",
		        "node_list_path": "797114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "797114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpRoot568(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root568 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpRoot568", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736565.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736565.protein.info.v11.5.txt",
		        "node_list_path": "1736565.protein.complete.v11.5.txt"
		    }
		]
    )()

def NesterenkoniaAlba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesterenkoniaAlba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122602.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122602.protein.info.v11.5.txt",
		        "node_list_path": "1122602.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseoluteus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseoluteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseoluteus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29306.protein.sequences.v11.5.fa",
		        "enrichment_path": "29306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29306.protein.info.v11.5.txt",
		        "node_list_path": "29306.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh7805(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 7805 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh7805", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59931.protein.sequences.v11.5.fa",
		        "enrichment_path": "59931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59931.protein.info.v11.5.txt",
		        "node_list_path": "59931.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrodictiumDelaneyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrodictium delaneyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrodictiumDelaneyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1273541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1273541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1273541.clusters.proteins.v11.5.txt",
		        "sequence_path": "1273541.protein.sequences.v11.5.fa",
		        "enrichment_path": "1273541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1273541.protein.info.v11.5.txt",
		        "node_list_path": "1273541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1273541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetarhiziumAcridumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium acridum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetarhiziumAcridumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "92637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "92637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "92637.clusters.proteins.v11.5.txt",
		        "sequence_path": "92637.protein.sequences.v11.5.fa",
		        "enrichment_path": "92637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92637.protein.info.v11.5.txt",
		        "node_list_path": "92637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "92637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomonasIntermediaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas intermedia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomonasIntermediaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "75379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "75379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "75379.clusters.proteins.v11.5.txt",
		        "sequence_path": "75379.protein.sequences.v11.5.fa",
		        "enrichment_path": "75379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75379.protein.info.v11.5.txt",
		        "node_list_path": "75379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "75379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusApis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus apis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusApis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "303541.protein.sequences.v11.5.fa",
		        "enrichment_path": "303541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "303541.protein.info.v11.5.txt",
		        "node_list_path": "303541.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusParacaseiAtcc334Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paracasei ATCC 334 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParacaseiAtcc334Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "321967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "321967.clusters.proteins.v11.5.txt",
		        "sequence_path": "321967.protein.sequences.v11.5.fa",
		        "enrichment_path": "321967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321967.protein.info.v11.5.txt",
		        "node_list_path": "321967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "321967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseibacteriumElongatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseibacterium elongatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseibacteriumElongatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1294273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294273.protein.info.v11.5.txt",
		        "node_list_path": "1294273.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusGarvieaeDcc43(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae DCC43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusGarvieaeDcc43", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231377.protein.info.v11.5.txt",
		        "node_list_path": "1231377.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusCcmp1375Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus CCMP1375 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusCcmp1375Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "167539.clusters.info.v11.5.txt",
		        "cluster_tree_path": "167539.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "167539.clusters.proteins.v11.5.txt",
		        "sequence_path": "167539.protein.sequences.v11.5.fa",
		        "enrichment_path": "167539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167539.protein.info.v11.5.txt",
		        "node_list_path": "167539.cluster.nodes.v11.5.txt",
		        "edge_list_path": "167539.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCaspiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium caspium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCaspiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121355.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121355.protein.info.v11.5.txt",
		        "node_list_path": "1121355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensPf01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Pf01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensPf01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "205922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "205922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "205922.clusters.proteins.v11.5.txt",
		        "sequence_path": "205922.protein.sequences.v11.5.fa",
		        "enrichment_path": "205922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "205922.protein.info.v11.5.txt",
		        "node_list_path": "205922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "205922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacterKumamotonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter kumamotonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterKumamotonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "354243.protein.sequences.v11.5.fa",
		        "enrichment_path": "354243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "354243.protein.info.v11.5.txt",
		        "node_list_path": "354243.protein.complete.v11.5.txt"
		    }
		]
    )()

def SediminibacillusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacillusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "482461.protein.sequences.v11.5.fa",
		        "enrichment_path": "482461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "482461.protein.info.v11.5.txt",
		        "node_list_path": "482461.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho202Full4018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_40_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full4018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798605.protein.info.v11.5.txt",
		        "node_list_path": "1798605.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmborellaTrichopodaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amborella trichopoda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmborellaTrichopodaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13333.clusters.proteins.v11.5.txt",
		        "sequence_path": "13333.protein.sequences.v11.5.fa",
		        "enrichment_path": "13333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13333.protein.info.v11.5.txt",
		        "node_list_path": "13333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3815Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_38_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3815Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801752.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801752.protein.info.v11.5.txt",
		        "node_list_path": "1801752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlammeovirgaSpMy04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flammeovirga sp. MY04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlammeovirgaSpMy04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1191459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1191459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1191459.protein.info.v11.5.txt",
		        "node_list_path": "1191459.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpStBin4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. ST-bin4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpStBin4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1978764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1978764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1978764.clusters.proteins.v11.5.txt",
		        "sequence_path": "1978764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978764.protein.info.v11.5.txt",
		        "node_list_path": "1978764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1978764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanogenicArchaeonIso4H5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return methanogenic archaeon ISO4-H5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanogenicArchaeonIso4H5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1495144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495144.protein.info.v11.5.txt",
		        "node_list_path": "1495144.protein.complete.v11.5.txt"
		    }
		]
    )()

def TalaromycesAtroroseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces atroroseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesAtroroseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1441469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1441469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1441469.clusters.proteins.v11.5.txt",
		        "sequence_path": "1441469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1441469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1441469.protein.info.v11.5.txt",
		        "node_list_path": "1441469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1441469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095767.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095767.protein.info.v11.5.txt",
		        "node_list_path": "1095767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalilimnicolaEhrlichiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalilimnicola ehrlichii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalilimnicolaEhrlichiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "187272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "187272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "187272.clusters.proteins.v11.5.txt",
		        "sequence_path": "187272.protein.sequences.v11.5.fa",
		        "enrichment_path": "187272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "187272.protein.info.v11.5.txt",
		        "node_list_path": "187272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "187272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaCtuCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ctu Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaCtuCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "261317.clusters.info.v11.0.txt",
		        "cluster_tree_path": "261317.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "261317.clusters.proteins.v11.0.txt",
		        "sequence_path": "261317.protein.sequences.v11.0.fa",
		        "enrichment_path": "261317.protein.enrichment.terms.v11.0.txt",
		        "info_path": "261317.protein.info.v11.0.txt",
		        "node_list_path": "261317.cluster.nodes.v11.0.txt",
		        "edge_list_path": "261317.protein.cluster.v11.0.txt"
		    }
		]
    )()

def ChlamydiaPneumoniaeLpcoln(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia pneumoniae LPCoLN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaPneumoniaeLpcoln", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "406984.protein.sequences.v11.5.fa",
		        "enrichment_path": "406984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406984.protein.info.v11.5.txt",
		        "node_list_path": "406984.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSp172e8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. 172E8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSp172e8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1535287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1535287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1535287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1535287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1535287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1535287.protein.info.v11.5.txt",
		        "node_list_path": "1535287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1535287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfDrosophilaSimulans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila simulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophilaSimulans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236908.protein.info.v11.5.txt",
		        "node_list_path": "1236908.protein.complete.v11.5.txt"
		    }
		]
    )()

def HoldemaniaSpMarseilleP2844Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Holdemania sp. Marseille-P2844 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoldemaniaSpMarseilleP2844Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852366.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852366.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852366.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852366.protein.info.v11.5.txt",
		        "node_list_path": "1852366.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852366.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusParauberisNcfd2020Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parauberis NCFD2020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusParauberisNcfd2020Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "873447.clusters.info.v11.5.txt",
		        "cluster_tree_path": "873447.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "873447.clusters.proteins.v11.5.txt",
		        "sequence_path": "873447.protein.sequences.v11.5.fa",
		        "enrichment_path": "873447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "873447.protein.info.v11.5.txt",
		        "node_list_path": "873447.cluster.nodes.v11.5.txt",
		        "edge_list_path": "873447.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnoanaerobaculumSaburreum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoanaerobaculumSaburreum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "467210.protein.sequences.v11.5.fa",
		        "enrichment_path": "467210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "467210.protein.info.v11.5.txt",
		        "node_list_path": "467210.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteroidesSalmoniphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacteroides salmoniphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteroidesSalmoniphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "404941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "404941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "404941.clusters.proteins.v11.5.txt",
		        "sequence_path": "404941.protein.sequences.v11.5.fa",
		        "enrichment_path": "404941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "404941.protein.info.v11.5.txt",
		        "node_list_path": "404941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "404941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphibacillusSediminisNbrc103570(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amphibacillus sediminis NBRC 103570 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphibacillusSediminisNbrc103570", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220586.protein.info.v11.5.txt",
		        "node_list_path": "1220586.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLeaf391(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf391 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLeaf391", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736360.protein.info.v11.5.txt",
		        "node_list_path": "1736360.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiaBacteriumTcs55Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiaBacteriumTcs55Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1781246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1781246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1781246.clusters.proteins.v11.5.txt",
		        "sequence_path": "1781246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1781246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1781246.protein.info.v11.5.txt",
		        "node_list_path": "1781246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1781246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubritaleaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubritalea marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubritaleaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123070.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123070.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123070.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123070.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123070.protein.info.v11.5.txt",
		        "node_list_path": "1123070.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123070.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusPorciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus porci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPorciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123315.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123315.protein.info.v11.5.txt",
		        "node_list_path": "1123315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSericytochromatiaBacteriumS15bMn24Cbmw12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sericytochromatia bacterium S15B-MN24 CBMW_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSericytochromatiaBacteriumS15bMn24Cbmw12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1919279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1919279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1919279.protein.info.v11.5.txt",
		        "node_list_path": "1919279.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfDrosophilaMelanogaster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila melanogaster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophilaMelanogaster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "163164.protein.sequences.v11.5.fa",
		        "enrichment_path": "163164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "163164.protein.info.v11.5.txt",
		        "node_list_path": "163164.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusRubinfantis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus rubinfantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusRubinfantis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720296.protein.info.v11.5.txt",
		        "node_list_path": "1720296.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807730.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807730.protein.info.v11.5.txt",
		        "node_list_path": "1807730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacillusDabanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus dabanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusDabanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "240302.protein.sequences.v11.5.fa",
		        "enrichment_path": "240302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240302.protein.info.v11.5.txt",
		        "node_list_path": "240302.protein.complete.v11.5.txt"
		    }
		]
    )()

def TateyamariaSpAngS1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tateyamaria sp. ANG-S1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TateyamariaSpAngS1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577905.protein.info.v11.5.txt",
		        "node_list_path": "1577905.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag1185(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1185 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag1185", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262921.protein.info.v11.5.txt",
		        "node_list_path": "1262921.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumLotiMaff303099Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti MAFF303099 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumLotiMaff303099Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266835.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266835.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266835.clusters.proteins.v11.5.txt",
		        "sequence_path": "266835.protein.sequences.v11.5.fa",
		        "enrichment_path": "266835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266835.protein.info.v11.5.txt",
		        "node_list_path": "266835.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266835.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRaac3Tm71Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RAAC3_TM7_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRaac3Tm71Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1394711.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1394711.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1394711.clusters.proteins.v11.5.txt",
		        "sequence_path": "1394711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394711.protein.info.v11.5.txt",
		        "node_list_path": "1394711.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1394711.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSulfonivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sulfonivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSulfonivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "121290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "121290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "121290.clusters.proteins.v11.5.txt",
		        "sequence_path": "121290.protein.sequences.v11.5.fa",
		        "enrichment_path": "121290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121290.protein.info.v11.5.txt",
		        "node_list_path": "121290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "121290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnoanaerobaculumSaburreumDsm3986Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum DSM3986 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoanaerobaculumSaburreumDsm3986Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "887325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "887325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "887325.clusters.proteins.v11.5.txt",
		        "sequence_path": "887325.protein.sequences.v11.5.fa",
		        "enrichment_path": "887325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "887325.protein.info.v11.5.txt",
		        "node_list_path": "887325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "887325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusLactolyticusS7113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus S7113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusLactolyticusS7113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1284686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284686.protein.info.v11.5.txt",
		        "node_list_path": "1284686.protein.complete.v11.5.txt"
		    }
		]
    )()

def NereidaIgnava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nereida ignava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NereidaIgnava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "282199.protein.sequences.v11.5.fa",
		        "enrichment_path": "282199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "282199.protein.info.v11.5.txt",
		        "node_list_path": "282199.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPantholopisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pantholopis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPantholopisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811193.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811193.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811193.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811193.protein.info.v11.5.txt",
		        "node_list_path": "1811193.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811193.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LongilineaArvoryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Longilinea arvoryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LongilineaArvoryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "360412.protein.sequences.v11.5.fa",
		        "enrichment_path": "360412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360412.protein.info.v11.5.txt",
		        "node_list_path": "360412.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1564956.protein.sequences.v11.5.fa",
		        "enrichment_path": "1564956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1564956.protein.info.v11.5.txt",
		        "node_list_path": "1564956.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesThermoautotrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces thermoautotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesThermoautotrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1469144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1469144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1469144.clusters.proteins.v11.5.txt",
		        "sequence_path": "1469144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469144.protein.info.v11.5.txt",
		        "node_list_path": "1469144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1469144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrovirgulaAerodenitrificansDsm15089Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microvirgula aerodenitrificans DSM 15089 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgulaAerodenitrificansDsm15089Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122240.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122240.protein.info.v11.5.txt",
		        "node_list_path": "1122240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseoflavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseoflavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseoflavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "467200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "467200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "467200.clusters.proteins.v11.5.txt",
		        "sequence_path": "467200.protein.sequences.v11.5.fa",
		        "enrichment_path": "467200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "467200.protein.info.v11.5.txt",
		        "node_list_path": "467200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "467200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeisingeraSpAngVp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leisingera sp. ANG-Vp graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraSpAngVp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577896.protein.info.v11.5.txt",
		        "node_list_path": "1577896.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridioidesMangenotiiLm2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridioides mangenotii LM2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridioidesMangenotiiLm2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392497.protein.info.v11.5.txt",
		        "node_list_path": "1392497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpCra2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. CRA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpCra2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1955620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1955620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1955620.clusters.proteins.v11.5.txt",
		        "sequence_path": "1955620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1955620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1955620.protein.info.v11.5.txt",
		        "node_list_path": "1955620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1955620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwc246850(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWC2_46_850 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwc246850", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797327.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797327.protein.info.v11.5.txt",
		        "node_list_path": "1797327.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesEpiroticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles epiroticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesEpiroticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "199890.protein.sequences.v11.5.fa",
		        "enrichment_path": "199890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "199890.protein.info.v11.5.txt",
		        "node_list_path": "199890.protein.complete.v11.5.txt"
		    }
		]
    )()

def CentipedaPeriodontiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Centipeda periodontii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CentipedaPeriodontiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888060.clusters.proteins.v11.5.txt",
		        "sequence_path": "888060.protein.sequences.v11.5.fa",
		        "enrichment_path": "888060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888060.protein.info.v11.5.txt",
		        "node_list_path": "888060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomonasMethanica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas methanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasMethanica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "857087.protein.sequences.v11.5.fa",
		        "enrichment_path": "857087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857087.protein.info.v11.5.txt",
		        "node_list_path": "857087.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfipiaSpP5210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. P5210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaSpP5210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1429916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1429916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1429916.protein.info.v11.5.txt",
		        "node_list_path": "1429916.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeoglobusAcetivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geoglobus acetivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeoglobusAcetivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "565033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "565033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "565033.clusters.proteins.v11.5.txt",
		        "sequence_path": "565033.protein.sequences.v11.5.fa",
		        "enrichment_path": "565033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565033.protein.info.v11.5.txt",
		        "node_list_path": "565033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "565033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinivibrioSharmensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio sharmensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivibrioSharmensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "390883.protein.sequences.v11.5.fa",
		        "enrichment_path": "390883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390883.protein.info.v11.5.txt",
		        "node_list_path": "390883.protein.complete.v11.5.txt"
		    }
		]
    )()

def DysgonomonasSpHgc4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas sp. HGC4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasSpHgc4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658009.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658009.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658009.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658009.protein.info.v11.5.txt",
		        "node_list_path": "1658009.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658009.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaceaeBacteriumBrhC20a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium BRH_c20a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaceaeBacteriumBrhC20a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629719.protein.info.v11.5.txt",
		        "node_list_path": "1629719.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSpF0436Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. F0436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSpF0436Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "879308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "879308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "879308.clusters.proteins.v11.5.txt",
		        "sequence_path": "879308.protein.sequences.v11.5.fa",
		        "enrichment_path": "879308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879308.protein.info.v11.5.txt",
		        "node_list_path": "879308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "879308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpRoot935(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root935 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpRoot935", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736610.protein.info.v11.5.txt",
		        "node_list_path": "1736610.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumSpRac06Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. RAC06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumSpRac06Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1842536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1842536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1842536.clusters.proteins.v11.5.txt",
		        "sequence_path": "1842536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842536.protein.info.v11.5.txt",
		        "node_list_path": "1842536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1842536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerinicoccusSpJlt9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serinicoccus sp. JLT9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerinicoccusSpJlt9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1758689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1758689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1758689.protein.info.v11.5.txt",
		        "node_list_path": "1758689.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf2890Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF2890 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf2890Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463845.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463845.protein.info.v11.5.txt",
		        "node_list_path": "1463845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasNasturtiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas nasturtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasNasturtiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1843581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1843581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1843581.clusters.proteins.v11.5.txt",
		        "sequence_path": "1843581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1843581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1843581.protein.info.v11.5.txt",
		        "node_list_path": "1843581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1843581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyxococcusFulvusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus fulvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcusFulvusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "483219.clusters.info.v11.5.txt",
		        "cluster_tree_path": "483219.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "483219.clusters.proteins.v11.5.txt",
		        "sequence_path": "483219.protein.sequences.v11.5.fa",
		        "enrichment_path": "483219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483219.protein.info.v11.5.txt",
		        "node_list_path": "483219.cluster.nodes.v11.5.txt",
		        "edge_list_path": "483219.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpTglY2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. TGL-Y2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpTglY2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1407071.protein.sequences.v11.5.fa",
		        "enrichment_path": "1407071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1407071.protein.info.v11.5.txt",
		        "node_list_path": "1407071.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetaceaeBacterium457259Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetaceae bacterium 4572_59 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaceaeBacterium457259Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1971727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1971727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1971727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1971727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971727.protein.info.v11.5.txt",
		        "node_list_path": "1971727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1971727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EhrlichiaChaffeensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia chaffeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EhrlichiaChaffeensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "205920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "205920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "205920.clusters.proteins.v11.5.txt",
		        "sequence_path": "205920.protein.sequences.v11.5.fa",
		        "enrichment_path": "205920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "205920.protein.info.v11.5.txt",
		        "node_list_path": "205920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "205920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumSpF0437(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium sp. F0437 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumSpF0437", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "861452.protein.sequences.v11.5.fa",
		        "enrichment_path": "861452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861452.protein.info.v11.5.txt",
		        "node_list_path": "861452.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusVogelbacteriaBacteriumGwa15114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium GWA1_51_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusVogelbacteriaBacteriumGwa15114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802435.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802435.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802435.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802435.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802435.protein.info.v11.5.txt",
		        "node_list_path": "1802435.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802435.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasBauzanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas bauzanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBauzanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "653930.protein.sequences.v11.5.fa",
		        "enrichment_path": "653930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "653930.protein.info.v11.5.txt",
		        "node_list_path": "653930.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMethylopumilusTuricensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methylopumilus turicensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethylopumilusTuricensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1581680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581680.protein.info.v11.5.txt",
		        "node_list_path": "1581680.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasFlavigenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas flavigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasFlavigenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "446466.clusters.info.v11.5.txt",
		        "cluster_tree_path": "446466.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "446466.clusters.proteins.v11.5.txt",
		        "sequence_path": "446466.protein.sequences.v11.5.fa",
		        "enrichment_path": "446466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446466.protein.info.v11.5.txt",
		        "node_list_path": "446466.cluster.nodes.v11.5.txt",
		        "edge_list_path": "446466.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag921Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:921 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag921Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262847.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262847.protein.info.v11.5.txt",
		        "node_list_path": "1262847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumThermophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumThermophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33905.clusters.proteins.v11.5.txt",
		        "sequence_path": "33905.protein.sequences.v11.5.fa",
		        "enrichment_path": "33905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33905.protein.info.v11.5.txt",
		        "node_list_path": "33905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiumMinutumPei191Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobium minutum Pei191 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiumMinutumPei191Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445932.clusters.proteins.v11.5.txt",
		        "sequence_path": "445932.protein.sequences.v11.5.fa",
		        "enrichment_path": "445932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445932.protein.info.v11.5.txt",
		        "node_list_path": "445932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusFerusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus ferus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusFerusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123303.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123303.protein.info.v11.5.txt",
		        "node_list_path": "1123303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3719(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_02_FULL_37_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3719", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802072.protein.info.v11.5.txt",
		        "node_list_path": "1802072.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirosomaLuteumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma luteum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaLuteumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123276.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123276.protein.info.v11.5.txt",
		        "node_list_path": "1123276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumGibsoniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum gibsoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumGibsoniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "767817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "767817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "767817.clusters.proteins.v11.5.txt",
		        "sequence_path": "767817.protein.sequences.v11.5.fa",
		        "enrichment_path": "767817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767817.protein.info.v11.5.txt",
		        "node_list_path": "767817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "767817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusAquatilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus aquatilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusAquatilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121378.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121378.protein.info.v11.5.txt",
		        "node_list_path": "1121378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAntibioticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces antibioticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAntibioticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1890.clusters.proteins.v11.5.txt",
		        "sequence_path": "1890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1890.protein.info.v11.5.txt",
		        "node_list_path": "1890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AccumulibacterPhosphatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Accumulibacter phosphatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AccumulibacterPhosphatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "522306.protein.sequences.v11.5.fa",
		        "enrichment_path": "522306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "522306.protein.info.v11.5.txt",
		        "node_list_path": "522306.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlutamicibacterHalophytocolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glutamicibacter halophytocola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlutamicibacterHalophytocolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1933880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1933880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1933880.clusters.proteins.v11.5.txt",
		        "sequence_path": "1933880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933880.protein.info.v11.5.txt",
		        "node_list_path": "1933880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1933880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KineosphaeraLimosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kineosphaera limosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KineosphaeraLimosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1184609.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1184609.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1184609.clusters.proteins.v11.5.txt",
		        "sequence_path": "1184609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1184609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1184609.protein.info.v11.5.txt",
		        "node_list_path": "1184609.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1184609.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaPneumoniaeLpcolnCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia pneumoniae LPCoLN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaPneumoniaeLpcolnCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "406984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "406984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "406984.clusters.proteins.v11.5.txt",
		        "sequence_path": "406984.protein.sequences.v11.5.fa",
		        "enrichment_path": "406984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406984.protein.info.v11.5.txt",
		        "node_list_path": "406984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "406984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodotorulaSpCcfee5036(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula sp. CCFEE 5036 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodotorulaSpCcfee5036", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1965284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1965284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1965284.protein.info.v11.5.txt",
		        "node_list_path": "1965284.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusHokkaidonensisJcm18461Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hokkaidonensis JCM 18461 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHokkaidonensisJcm18461Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1291742.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1291742.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1291742.clusters.proteins.v11.5.txt",
		        "sequence_path": "1291742.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291742.protein.info.v11.5.txt",
		        "node_list_path": "1291742.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1291742.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulophagaSpW5cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga sp. W5C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaSpW5cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1888890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1888890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1888890.clusters.proteins.v11.5.txt",
		        "sequence_path": "1888890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1888890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1888890.protein.info.v11.5.txt",
		        "node_list_path": "1888890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1888890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenarthrobacterNicotinovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenarthrobacter nicotinovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenarthrobacterNicotinovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29320.clusters.proteins.v11.5.txt",
		        "sequence_path": "29320.protein.sequences.v11.5.fa",
		        "enrichment_path": "29320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29320.protein.info.v11.5.txt",
		        "node_list_path": "29320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumOligotrophicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium oligotrophicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumOligotrophicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1245469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245469.protein.info.v11.5.txt",
		        "node_list_path": "1245469.protein.complete.v11.5.txt"
		    }
		]
    )()

def RothiaKristinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rothia kristinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RothiaKristinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37923.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37923.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37923.clusters.proteins.v11.5.txt",
		        "sequence_path": "37923.protein.sequences.v11.5.fa",
		        "enrichment_path": "37923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37923.protein.info.v11.5.txt",
		        "node_list_path": "37923.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37923.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusOralisAtcc35037(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis ATCC35037 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOralisAtcc35037", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655813.protein.sequences.v11.5.fa",
		        "enrichment_path": "655813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655813.protein.info.v11.5.txt",
		        "node_list_path": "655813.protein.complete.v11.5.txt"
		    }
		]
    )()

def FervidobacteriumPennivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium pennivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidobacteriumPennivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "771875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "771875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "771875.clusters.proteins.v11.5.txt",
		        "sequence_path": "771875.protein.sequences.v11.5.fa",
		        "enrichment_path": "771875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "771875.protein.info.v11.5.txt",
		        "node_list_path": "771875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "771875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TalaromycesStipitatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces stipitatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesStipitatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28564.clusters.proteins.v11.5.txt",
		        "sequence_path": "28564.protein.sequences.v11.5.fa",
		        "enrichment_path": "28564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28564.protein.info.v11.5.txt",
		        "node_list_path": "28564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ReinekeaBlandensisMed297(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Reinekea blandensis MED297 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ReinekeaBlandensisMed297", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314283.protein.sequences.v11.5.fa",
		        "enrichment_path": "314283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314283.protein.info.v11.5.txt",
		        "node_list_path": "314283.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusOdorifer(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus odorifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusOdorifer", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "189426.protein.sequences.v11.5.fa",
		        "enrichment_path": "189426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189426.protein.info.v11.5.txt",
		        "node_list_path": "189426.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAurantiacusDsm18675Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus aurantiacus DSM 18675 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAurantiacusDsm18675Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121086.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121086.protein.info.v11.5.txt",
		        "node_list_path": "1121086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhyllobacteriumSpYr531Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. YR531 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhyllobacteriumSpYr531Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144343.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144343.protein.info.v11.5.txt",
		        "node_list_path": "1144343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSpCag514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpCag514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262696.protein.info.v11.5.txt",
		        "node_list_path": "1262696.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobulbusElongatusDsm2908(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus elongatus DSM 2908 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbusElongatusDsm2908", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121402.protein.info.v11.5.txt",
		        "node_list_path": "1121402.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlesiocystisPacificaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plesiocystis pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlesiocystisPacificaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391625.clusters.proteins.v11.5.txt",
		        "sequence_path": "391625.protein.sequences.v11.5.fa",
		        "enrichment_path": "391625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391625.protein.info.v11.5.txt",
		        "node_list_path": "391625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SuccinimonasAmylolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Succinimonas amylolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuccinimonasAmylolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265507.protein.info.v11.5.txt",
		        "node_list_path": "1265507.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumAcmicro4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium acMicro-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumAcmicro4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1504317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1504317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1504317.clusters.proteins.v11.5.txt",
		        "sequence_path": "1504317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504317.protein.info.v11.5.txt",
		        "node_list_path": "1504317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1504317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DaedaleaQuercinaL15889Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Daedalea quercina L-15889 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DaedaleaQuercinaL15889Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314783.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314783.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314783.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314783.protein.info.v11.5.txt",
		        "node_list_path": "1314783.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314783.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FluoribacterDumoffii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fluoribacter dumoffii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FluoribacterDumoffii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094715.protein.info.v11.5.txt",
		        "node_list_path": "1094715.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSimiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas simiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSimiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321846.clusters.info.v11.5.txt",
		        "cluster_tree_path": "321846.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "321846.clusters.proteins.v11.5.txt",
		        "sequence_path": "321846.protein.sequences.v11.5.fa",
		        "enrichment_path": "321846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321846.protein.info.v11.5.txt",
		        "node_list_path": "321846.cluster.nodes.v11.5.txt",
		        "edge_list_path": "321846.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacterium13120cm5428(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium 13_1_20CM_54_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacterium13120cm5428", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805411.protein.info.v11.5.txt",
		        "node_list_path": "1805411.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaRobiniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea robiniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaRobiniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1036780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1036780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1036780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1036780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036780.protein.info.v11.5.txt",
		        "node_list_path": "1036780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1036780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalophilicArchaeonJ07hb67(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return halophilic archaeon J07HB67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalophilicArchaeonJ07hb67", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1085029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1085029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1085029.protein.info.v11.5.txt",
		        "node_list_path": "1085029.protein.complete.v11.5.txt"
		    }
		]
    )()

def KetogulonicigeniumVulgareY25(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ketogulonicigenium vulgare Y25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KetogulonicigeniumVulgareY25", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "880591.protein.sequences.v11.5.fa",
		        "enrichment_path": "880591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880591.protein.info.v11.5.txt",
		        "node_list_path": "880591.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpPm2P129Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. PM2-P1-29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpPm2P129Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "403776.clusters.info.v11.5.txt",
		        "cluster_tree_path": "403776.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "403776.clusters.proteins.v11.5.txt",
		        "sequence_path": "403776.protein.sequences.v11.5.fa",
		        "enrichment_path": "403776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "403776.protein.info.v11.5.txt",
		        "node_list_path": "403776.cluster.nodes.v11.5.txt",
		        "edge_list_path": "403776.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5420(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5420", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798513.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798513.protein.info.v11.5.txt",
		        "node_list_path": "1798513.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConiosporiumApollinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coniosporium apollinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConiosporiumApollinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61459.protein.sequences.v11.5.fa",
		        "enrichment_path": "61459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61459.protein.info.v11.5.txt",
		        "node_list_path": "61459.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpKctc13219(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Bacillus] sp. KCTC 13219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpKctc13219", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811976.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811976.protein.info.v11.5.txt",
		        "node_list_path": "1811976.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb245a518o7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_518O7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb245a518o7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1471508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471508.protein.info.v11.5.txt",
		        "node_list_path": "1471508.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaSp3andimar09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella sp. 3ANDIMAR09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaSp3andimar09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1225657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225657.protein.info.v11.5.txt",
		        "node_list_path": "1225657.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusSpLeaf326Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. Leaf326 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusSpLeaf326Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736338.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736338.protein.info.v11.5.txt",
		        "node_list_path": "1736338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasBalearicaDsm6083(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas balearica DSM 6083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBalearicaDsm6083", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123016.protein.info.v11.5.txt",
		        "node_list_path": "1123016.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaBarthiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza barthii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaBarthiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "65489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "65489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "65489.clusters.proteins.v11.5.txt",
		        "sequence_path": "65489.protein.sequences.v11.5.fa",
		        "enrichment_path": "65489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65489.protein.info.v11.5.txt",
		        "node_list_path": "65489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "65489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichinellaNelsoni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichinella nelsoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaNelsoni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6336.protein.sequences.v11.5.fa",
		        "enrichment_path": "6336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6336.protein.info.v11.5.txt",
		        "node_list_path": "6336.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwe23640Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE2_36_40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe23640Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618713.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618713.protein.info.v11.5.txt",
		        "node_list_path": "1618713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGa0077523Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077523 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077523Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752198.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752198.protein.info.v11.5.txt",
		        "node_list_path": "1752198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpC105kso13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. C105KSO13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpC105kso13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776045.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776045.protein.info.v11.5.txt",
		        "node_list_path": "1776045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumLuteum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium luteum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumLuteum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1638988.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638988.protein.info.v11.5.txt",
		        "node_list_path": "1638988.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaRuckeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia ruckeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaRuckeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29486.clusters.proteins.v11.5.txt",
		        "sequence_path": "29486.protein.sequences.v11.5.fa",
		        "enrichment_path": "29486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29486.protein.info.v11.5.txt",
		        "node_list_path": "29486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusSpC1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus sp. C1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusSpC1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1661745.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1661745.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1661745.clusters.proteins.v11.5.txt",
		        "sequence_path": "1661745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661745.protein.info.v11.5.txt",
		        "node_list_path": "1661745.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1661745.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4241(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_42_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4241", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802759.protein.info.v11.5.txt",
		        "node_list_path": "1802759.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpLc2012(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. lc2012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpLc2012", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761886.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761886.protein.info.v11.5.txt",
		        "node_list_path": "1761886.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpAntB3c2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. ANT-B3C2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpAntB3c2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1844758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1844758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1844758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1844758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1844758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1844758.protein.info.v11.5.txt",
		        "node_list_path": "1844758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1844758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumRhodesiaeJs60(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rhodesiae JS60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumRhodesiaeJs60", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "931627.protein.sequences.v11.5.fa",
		        "enrichment_path": "931627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "931627.protein.info.v11.5.txt",
		        "node_list_path": "931627.protein.complete.v11.5.txt"
		    }
		]
    )()

def LacinutrixMariniflavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix mariniflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixMariniflavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "342955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "342955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "342955.clusters.proteins.v11.5.txt",
		        "sequence_path": "342955.protein.sequences.v11.5.fa",
		        "enrichment_path": "342955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342955.protein.info.v11.5.txt",
		        "node_list_path": "342955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "342955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMidichloriaMitochondriiIricvaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Midichloria mitochondrii IricVA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMidichloriaMitochondriiIricvaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "696127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "696127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "696127.clusters.proteins.v11.5.txt",
		        "sequence_path": "696127.protein.sequences.v11.5.fa",
		        "enrichment_path": "696127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696127.protein.info.v11.5.txt",
		        "node_list_path": "696127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "696127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaBccCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola BCc Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaBccCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "372461.clusters.info.v11.5.txt",
		        "cluster_tree_path": "372461.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "372461.clusters.proteins.v11.5.txt",
		        "sequence_path": "372461.protein.sequences.v11.5.fa",
		        "enrichment_path": "372461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "372461.protein.info.v11.5.txt",
		        "node_list_path": "372461.cluster.nodes.v11.5.txt",
		        "edge_list_path": "372461.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicosporidiumSpAtcc50920(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicosporidium sp. ATCC 50920 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicosporidiumSpAtcc50920", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1291522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291522.protein.info.v11.5.txt",
		        "node_list_path": "1291522.protein.complete.v11.5.txt"
		    }
		]
    )()

def SarcophilusHarrisiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sarcophilus harrisii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SarcophilusHarrisiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9305.clusters.proteins.v11.5.txt",
		        "sequence_path": "9305.protein.sequences.v11.5.fa",
		        "enrichment_path": "9305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9305.protein.info.v11.5.txt",
		        "node_list_path": "9305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteiniphilumAcetatigenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteiniphilum acetatigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteiniphilumAcetatigenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123008.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123008.protein.info.v11.5.txt",
		        "node_list_path": "1123008.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaPhagedenisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema phagedenis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPhagedenisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "754027.clusters.info.v11.5.txt",
		        "cluster_tree_path": "754027.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "754027.clusters.proteins.v11.5.txt",
		        "sequence_path": "754027.protein.sequences.v11.5.fa",
		        "enrichment_path": "754027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754027.protein.info.v11.5.txt",
		        "node_list_path": "754027.cluster.nodes.v11.5.txt",
		        "edge_list_path": "754027.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumSaheli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium saheli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumSaheli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36856.protein.sequences.v11.5.fa",
		        "enrichment_path": "36856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36856.protein.info.v11.5.txt",
		        "node_list_path": "36856.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospirillalesBacteriumBbd199114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium BBD 1991-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillalesBacteriumBbd199114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852621.protein.info.v11.5.txt",
		        "node_list_path": "1852621.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfovibrioSpN1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio sp. N1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfovibrioSpN1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871110.protein.info.v11.5.txt",
		        "node_list_path": "1871110.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodothermusProfundiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodothermus profundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodothermusProfundiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "633813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "633813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "633813.clusters.proteins.v11.5.txt",
		        "sequence_path": "633813.protein.sequences.v11.5.fa",
		        "enrichment_path": "633813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633813.protein.info.v11.5.txt",
		        "node_list_path": "633813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "633813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharomycesCerevisiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomyces cerevisiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomycesCerevisiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4932.clusters.proteins.v11.5.txt",
		        "sequence_path": "4932.protein.sequences.v11.5.fa",
		        "enrichment_path": "4932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4932.protein.info.v11.5.txt",
		        "node_list_path": "4932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAcidianusCopahuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acidianus copahuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAcidianusCopahuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1160895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160895.protein.info.v11.5.txt",
		        "node_list_path": "1160895.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaSpLeaf53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia sp. Leaf53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaSpLeaf53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736225.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736225.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736225.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736225.protein.info.v11.5.txt",
		        "node_list_path": "1736225.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736225.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpG5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. G5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpG5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1268068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268068.protein.info.v11.5.txt",
		        "node_list_path": "1268068.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full398Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_39_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full398Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797533.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797533.protein.info.v11.5.txt",
		        "node_list_path": "1797533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaCinaraStrobiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara strobi) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaCinaraStrobiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1921549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1921549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1921549.clusters.proteins.v11.5.txt",
		        "sequence_path": "1921549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921549.protein.info.v11.5.txt",
		        "node_list_path": "1921549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1921549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterGyllenbergiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter gyllenbergii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterGyllenbergiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217658.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217658.protein.info.v11.5.txt",
		        "node_list_path": "1217658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusUreasiticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus ureasiticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusUreasiticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "903984.protein.sequences.v11.5.fa",
		        "enrichment_path": "903984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903984.protein.info.v11.5.txt",
		        "node_list_path": "903984.protein.complete.v11.5.txt"
		    }
		]
    )()

def LampropediaHyalinaDsm16112(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lampropedia hyalina DSM 16112 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LampropediaHyalinaDsm16112", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122156.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122156.protein.info.v11.5.txt",
		        "node_list_path": "1122156.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacteriumHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacterium halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacteriumHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1082931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1082931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1082931.protein.info.v11.5.txt",
		        "node_list_path": "1082931.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusInfantisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusInfantisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68892.clusters.proteins.v11.5.txt",
		        "sequence_path": "68892.protein.sequences.v11.5.fa",
		        "enrichment_path": "68892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68892.protein.info.v11.5.txt",
		        "node_list_path": "68892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Paracoccus denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "318586.protein.sequences.v11.0.fa",
		        "enrichment_path": "318586.protein.enrichment.terms.v11.0.txt",
		        "info_path": "318586.protein.info.v11.0.txt",
		        "node_list_path": "318586.protein.complete.v11.0.txt"
		    }
		]
    )()

def SalinimonasChungwhensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinimonas chungwhensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinimonasChungwhensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123236.protein.info.v11.5.txt",
		        "node_list_path": "1123236.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxBorkumensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax borkumensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxBorkumensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "393595.protein.sequences.v11.5.fa",
		        "enrichment_path": "393595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393595.protein.info.v11.5.txt",
		        "node_list_path": "393595.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasCryotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas cryotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasCryotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131553.protein.info.v11.5.txt",
		        "node_list_path": "1131553.protein.complete.v11.5.txt"
		    }
		]
    )()

def DokdoniaSpMed134Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dokdonia sp. MED134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DokdoniaSpMed134Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313590.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313590.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313590.clusters.proteins.v11.5.txt",
		        "sequence_path": "313590.protein.sequences.v11.5.fa",
		        "enrichment_path": "313590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313590.protein.info.v11.5.txt",
		        "node_list_path": "313590.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313590.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HamiltonellaDefensaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hamiltonella defensa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HamiltonellaDefensaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "572265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "572265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "572265.clusters.proteins.v11.5.txt",
		        "sequence_path": "572265.protein.sequences.v11.5.fa",
		        "enrichment_path": "572265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572265.protein.info.v11.5.txt",
		        "node_list_path": "572265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "572265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PapaverSomniferumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Papaver somniferum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PapaverSomniferumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3469.clusters.proteins.v11.5.txt",
		        "sequence_path": "3469.protein.sequences.v11.5.fa",
		        "enrichment_path": "3469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3469.protein.info.v11.5.txt",
		        "node_list_path": "3469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumHumireducensNbrc106098Dsm45392Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium humireducens NBRC 106098 DSM 45392 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumHumireducensNbrc106098Dsm45392Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223515.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223515.protein.info.v11.5.txt",
		        "node_list_path": "1223515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermovibrioAmmonificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermovibrio ammonificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermovibrioAmmonificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "648996.protein.sequences.v11.5.fa",
		        "enrichment_path": "648996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "648996.protein.info.v11.5.txt",
		        "node_list_path": "648996.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapitellaTeletaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capitella teleta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapitellaTeletaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "283909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "283909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "283909.clusters.proteins.v11.5.txt",
		        "sequence_path": "283909.protein.sequences.v11.5.fa",
		        "enrichment_path": "283909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283909.protein.info.v11.5.txt",
		        "node_list_path": "283909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "283909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinoplanesSpTfc3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes sp. TFC3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesSpTfc3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1710355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1710355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1710355.clusters.proteins.v11.5.txt",
		        "sequence_path": "1710355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1710355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1710355.protein.info.v11.5.txt",
		        "node_list_path": "1710355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1710355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusCatalpae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus catalpae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusCatalpae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1045775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045775.protein.info.v11.5.txt",
		        "node_list_path": "1045775.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumImitans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium imitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumImitans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "156978.protein.sequences.v11.5.fa",
		        "enrichment_path": "156978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156978.protein.info.v11.5.txt",
		        "node_list_path": "156978.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterNorwichensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter norwichensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterNorwichensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121957.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121957.protein.info.v11.5.txt",
		        "node_list_path": "1121957.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionKazanBacteriumRifcsphigho201Full4414Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RIFCSPHIGHO2_01_FULL_44_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionKazanBacteriumRifcsphigho201Full4414Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798536.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798536.protein.info.v11.5.txt",
		        "node_list_path": "1798536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuciliaCuprina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lucilia cuprina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuciliaCuprina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7375.protein.sequences.v11.5.fa",
		        "enrichment_path": "7375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7375.protein.info.v11.5.txt",
		        "node_list_path": "7375.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27231Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27231 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27231Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1679168.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1679168.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1679168.clusters.proteins.v11.5.txt",
		        "sequence_path": "1679168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679168.protein.info.v11.5.txt",
		        "node_list_path": "1679168.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1679168.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusButanolivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus butanolivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusButanolivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "421767.protein.sequences.v11.5.fa",
		        "enrichment_path": "421767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "421767.protein.info.v11.5.txt",
		        "node_list_path": "421767.protein.complete.v11.5.txt"
		    }
		]
    )()

def TubulinosemaRatisbonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tubulinosema ratisbonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TubulinosemaRatisbonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "291195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "291195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "291195.clusters.proteins.v11.5.txt",
		        "sequence_path": "291195.protein.sequences.v11.5.fa",
		        "enrichment_path": "291195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "291195.protein.info.v11.5.txt",
		        "node_list_path": "291195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "291195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FriedmanniellaLuteolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Friedmanniella luteola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FriedmanniellaLuteolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546871.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546871.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546871.clusters.proteins.v11.5.txt",
		        "sequence_path": "546871.protein.sequences.v11.5.fa",
		        "enrichment_path": "546871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546871.protein.info.v11.5.txt",
		        "node_list_path": "546871.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546871.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarssoninaCoronariaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marssonina coronariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarssoninaCoronariaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "503106.clusters.info.v11.5.txt",
		        "cluster_tree_path": "503106.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "503106.clusters.proteins.v11.5.txt",
		        "sequence_path": "503106.protein.sequences.v11.5.fa",
		        "enrichment_path": "503106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "503106.protein.info.v11.5.txt",
		        "node_list_path": "503106.cluster.nodes.v11.5.txt",
		        "edge_list_path": "503106.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassiosiraOceanica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassiosira oceanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassiosiraOceanica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "159749.protein.sequences.v11.5.fa",
		        "enrichment_path": "159749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "159749.protein.info.v11.5.txt",
		        "node_list_path": "159749.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrellaSpEs10322(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrella sp. ES10-3-2-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrellaSpEs10322", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834519.protein.info.v11.5.txt",
		        "node_list_path": "1834519.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaBarkeri3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri 3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaBarkeri3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434107.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434107.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434107.protein.info.v11.5.txt",
		        "node_list_path": "1434107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifcsphigho202Full5216Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_02_FULL_52_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho202Full5216Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801920.protein.info.v11.5.txt",
		        "node_list_path": "1801920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag254(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:254 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag254", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262953.protein.info.v11.5.txt",
		        "node_list_path": "1262953.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaSpLeaf51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. Leaf51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpLeaf51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736224.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736224.protein.info.v11.5.txt",
		        "node_list_path": "1736224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpJls(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JLS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpJls", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "164757.protein.sequences.v11.5.fa",
		        "enrichment_path": "164757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "164757.protein.info.v11.5.txt",
		        "node_list_path": "164757.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumGw2011Gwb1378(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWB1_37_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwb1378", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618463.protein.info.v11.5.txt",
		        "node_list_path": "1618463.protein.complete.v11.5.txt"
		    }
		]
    )()

def SymbiobacteriumThermophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Symbiobacterium thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SymbiobacteriumThermophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "292459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "292459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "292459.clusters.proteins.v11.5.txt",
		        "sequence_path": "292459.protein.sequences.v11.5.fa",
		        "enrichment_path": "292459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292459.protein.info.v11.5.txt",
		        "node_list_path": "292459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "292459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasZinciduransB6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas zincidurans B6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasZinciduransB6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1446475.protein.sequences.v11.5.fa",
		        "enrichment_path": "1446475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1446475.protein.info.v11.5.txt",
		        "node_list_path": "1446475.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaOvipneumoniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma ovipneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaOvipneumoniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1188239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1188239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1188239.clusters.proteins.v11.5.txt",
		        "sequence_path": "1188239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188239.protein.info.v11.5.txt",
		        "node_list_path": "1188239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1188239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArsenophonusEndosymbiont(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arsenophonus endosymbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArsenophonusEndosymbiont", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1247024.protein.sequences.v11.5.fa",
		        "enrichment_path": "1247024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1247024.protein.info.v11.5.txt",
		        "node_list_path": "1247024.protein.complete.v11.5.txt"
		    }
		]
    )()

def RikenellaceaeBacteriumM3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium M3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RikenellaceaeBacteriumM3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1433126.protein.sequences.v11.5.fa",
		        "enrichment_path": "1433126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1433126.protein.info.v11.5.txt",
		        "node_list_path": "1433126.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharophagusDegradans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharophagus degradans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharophagusDegradans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "203122.protein.sequences.v11.5.fa",
		        "enrichment_path": "203122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203122.protein.info.v11.5.txt",
		        "node_list_path": "203122.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaKunkeliiCr23x(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma kunkelii CR2-3x graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaKunkeliiCr23x", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "273035.protein.sequences.v11.5.fa",
		        "enrichment_path": "273035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273035.protein.info.v11.5.txt",
		        "node_list_path": "273035.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag354Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:354 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag354Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262799.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262799.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262799.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262799.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262799.protein.info.v11.5.txt",
		        "node_list_path": "1262799.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262799.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OwenweeksiaHongkongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Owenweeksia hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OwenweeksiaHongkongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926562.clusters.proteins.v11.5.txt",
		        "sequence_path": "926562.protein.sequences.v11.5.fa",
		        "enrichment_path": "926562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926562.protein.info.v11.5.txt",
		        "node_list_path": "926562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaAlbertiiKf1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia albertii KF1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaAlbertiiKf1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1440052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1440052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1440052.protein.info.v11.5.txt",
		        "node_list_path": "1440052.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaMelaninogenicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella melaninogenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMelaninogenicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553174.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553174.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553174.clusters.proteins.v11.5.txt",
		        "sequence_path": "553174.protein.sequences.v11.5.fa",
		        "enrichment_path": "553174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553174.protein.info.v11.5.txt",
		        "node_list_path": "553174.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553174.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaCanadensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia canadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaCanadensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "293613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "293613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "293613.clusters.proteins.v11.5.txt",
		        "sequence_path": "293613.protein.sequences.v11.5.fa",
		        "enrichment_path": "293613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "293613.protein.info.v11.5.txt",
		        "node_list_path": "293613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "293613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptosphaeriaMaculansJn3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptosphaeria maculans JN3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptosphaeriaMaculansJn3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "985895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "985895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "985895.clusters.proteins.v11.5.txt",
		        "sequence_path": "985895.protein.sequences.v11.5.fa",
		        "enrichment_path": "985895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985895.protein.info.v11.5.txt",
		        "node_list_path": "985895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "985895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfuricellaDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricella denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricellaDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1163617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1163617.clusters.proteins.v11.5.txt",
		        "sequence_path": "1163617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163617.protein.info.v11.5.txt",
		        "node_list_path": "1163617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1163617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumDoosanense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium doosanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumDoosanense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "558173.protein.sequences.v11.5.fa",
		        "enrichment_path": "558173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558173.protein.info.v11.5.txt",
		        "node_list_path": "558173.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaRibeironisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia ribeironis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaRibeironisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1247936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1247936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1247936.clusters.proteins.v11.5.txt",
		        "sequence_path": "1247936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1247936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1247936.protein.info.v11.5.txt",
		        "node_list_path": "1247936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1247936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusCasseliflavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus casseliflavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusCasseliflavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "565655.clusters.info.v11.5.txt",
		        "cluster_tree_path": "565655.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "565655.clusters.proteins.v11.5.txt",
		        "sequence_path": "565655.protein.sequences.v11.5.fa",
		        "enrichment_path": "565655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565655.protein.info.v11.5.txt",
		        "node_list_path": "565655.cluster.nodes.v11.5.txt",
		        "edge_list_path": "565655.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisJsc3bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris JSC-3b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisJsc3bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1421013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1421013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1421013.clusters.proteins.v11.5.txt",
		        "sequence_path": "1421013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1421013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1421013.protein.info.v11.5.txt",
		        "node_list_path": "1421013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1421013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusDevriesei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus devriesei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusDevriesei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "319970.protein.sequences.v11.5.fa",
		        "enrichment_path": "319970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319970.protein.info.v11.5.txt",
		        "node_list_path": "319970.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSaccharolyticumWm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium saccharolyticum WM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSaccharolyticumWm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "610130.protein.sequences.v11.5.fa",
		        "enrichment_path": "610130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "610130.protein.info.v11.5.txt",
		        "node_list_path": "610130.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaShandongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia shandongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaShandongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121928.protein.info.v11.5.txt",
		        "node_list_path": "1121928.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwr3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWR3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwr3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896217.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896217.protein.info.v11.5.txt",
		        "node_list_path": "1896217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeisingeraAquaemixtae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leisingera aquaemixtae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraAquaemixtae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1396826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1396826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1396826.protein.info.v11.5.txt",
		        "node_list_path": "1396826.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlaciecolaLipolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola lipolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaLipolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1127673.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1127673.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1127673.clusters.proteins.v11.5.txt",
		        "sequence_path": "1127673.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127673.protein.info.v11.5.txt",
		        "node_list_path": "1127673.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1127673.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpNsp222Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. NSP222 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpNsp222Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071073.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071073.protein.info.v11.5.txt",
		        "node_list_path": "1071073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AminobacterSpJ41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aminobacter sp. J41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminobacterSpJ41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935261.protein.sequences.v11.5.fa",
		        "enrichment_path": "935261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935261.protein.info.v11.5.txt",
		        "node_list_path": "935261.protein.complete.v11.5.txt"
		    }
		]
    )()

def GluconobacterMorbiferCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter morbifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterMorbiferCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1088869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1088869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1088869.clusters.proteins.v11.5.txt",
		        "sequence_path": "1088869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1088869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1088869.protein.info.v11.5.txt",
		        "node_list_path": "1088869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1088869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AuriculariopsisAmpla(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Auriculariopsis ampla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AuriculariopsisAmpla", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "97359.protein.sequences.v11.5.fa",
		        "enrichment_path": "97359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97359.protein.info.v11.5.txt",
		        "node_list_path": "97359.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263017.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263017.protein.info.v11.5.txt",
		        "node_list_path": "1263017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumGw2011Gwa14424Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWA1_44_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwa14424Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619002.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619002.protein.info.v11.5.txt",
		        "node_list_path": "1619002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumBovisDsm19482(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium bovis DSM 19482 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumBovisDsm19482", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121284.protein.info.v11.5.txt",
		        "node_list_path": "1121284.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag508Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:508 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag508Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262815.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262815.protein.info.v11.5.txt",
		        "node_list_path": "1262815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTuberculosisVariantMicrotiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant microti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTuberculosisVariantMicrotiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1806.clusters.proteins.v11.5.txt",
		        "sequence_path": "1806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806.protein.info.v11.5.txt",
		        "node_list_path": "1806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHtcc5015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC5015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHtcc5015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391615.protein.sequences.v11.5.fa",
		        "enrichment_path": "391615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391615.protein.info.v11.5.txt",
		        "node_list_path": "391615.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag1092Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1092 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag1092Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262919.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262919.protein.info.v11.5.txt",
		        "node_list_path": "1262919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpPbh53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. PBH53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpPbh53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577075.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577075.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577075.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577075.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577075.protein.info.v11.5.txt",
		        "node_list_path": "1577075.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577075.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag967(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:967 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag967", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262849.protein.info.v11.5.txt",
		        "node_list_path": "1262849.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodotorulaGraminisWp1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula graminis WP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodotorulaGraminisWp1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "578459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "578459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "578459.clusters.proteins.v11.5.txt",
		        "sequence_path": "578459.protein.sequences.v11.5.fa",
		        "enrichment_path": "578459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578459.protein.info.v11.5.txt",
		        "node_list_path": "578459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "578459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4249(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_42_49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4249", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802694.protein.info.v11.5.txt",
		        "node_list_path": "1802694.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArhodomonasAquaeoleiDsm8974(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arhodomonas aquaeolei DSM 8974 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArhodomonasAquaeoleiDsm8974", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121016.protein.info.v11.5.txt",
		        "node_list_path": "1121016.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsphigho202Full3814Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO2_02_FULL_38_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho202Full3814Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802620.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802620.protein.info.v11.5.txt",
		        "node_list_path": "1802620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaOralisAtcc33269Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oralis ATCC33269 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOralisAtcc33269Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "873533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "873533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "873533.clusters.proteins.v11.5.txt",
		        "sequence_path": "873533.protein.sequences.v11.5.fa",
		        "enrichment_path": "873533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "873533.protein.info.v11.5.txt",
		        "node_list_path": "873533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "873533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarboxydothermusIslandicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carboxydothermus islandicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarboxydothermusIslandicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "661089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "661089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "661089.clusters.proteins.v11.5.txt",
		        "sequence_path": "661089.protein.sequences.v11.5.fa",
		        "enrichment_path": "661089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "661089.protein.info.v11.5.txt",
		        "node_list_path": "661089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "661089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PediococcusCellicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus cellicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusCellicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "319652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "319652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "319652.clusters.proteins.v11.5.txt",
		        "sequence_path": "319652.protein.sequences.v11.5.fa",
		        "enrichment_path": "319652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319652.protein.info.v11.5.txt",
		        "node_list_path": "319652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "319652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumCv2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium cv2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumCv2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1627893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1627893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1627893.protein.info.v11.5.txt",
		        "node_list_path": "1627893.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpSpb78Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. SPB78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpSpb78Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "591157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "591157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "591157.clusters.proteins.v11.5.txt",
		        "sequence_path": "591157.protein.sequences.v11.5.fa",
		        "enrichment_path": "591157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591157.protein.info.v11.5.txt",
		        "node_list_path": "591157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "591157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumTrifoliiWsm2304(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum trifolii WSM2304 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumTrifoliiWsm2304", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "395492.protein.sequences.v11.5.fa",
		        "enrichment_path": "395492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395492.protein.info.v11.5.txt",
		        "node_list_path": "395492.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParasutterellaExcrementihominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parasutterella excrementihominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParasutterellaExcrementihominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762966.protein.sequences.v11.5.fa",
		        "enrichment_path": "762966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762966.protein.info.v11.5.txt",
		        "node_list_path": "762966.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusAviariusSubspAraffinosusDsm20653(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus aviarius subsp. araffinosus DSM 20653 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAviariusSubspAraffinosusDsm20653", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423820.protein.info.v11.5.txt",
		        "node_list_path": "1423820.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfipiaSp1nls2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. 1NLS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaSp1nls2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "666684.protein.sequences.v11.5.fa",
		        "enrichment_path": "666684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "666684.protein.info.v11.5.txt",
		        "node_list_path": "666684.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpCf385Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. CF385 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpCf385Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881042.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881042.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881042.protein.info.v11.5.txt",
		        "node_list_path": "1881042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParachlamydiaAcanthamoebae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parachlamydia acanthamoebae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParachlamydiaAcanthamoebae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765952.protein.sequences.v11.5.fa",
		        "enrichment_path": "765952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765952.protein.info.v11.5.txt",
		        "node_list_path": "765952.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChelatococcusDaeguensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chelatococcus daeguensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelatococcusDaeguensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "444444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "444444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "444444.clusters.proteins.v11.5.txt",
		        "sequence_path": "444444.protein.sequences.v11.5.fa",
		        "enrichment_path": "444444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444444.protein.info.v11.5.txt",
		        "node_list_path": "444444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "444444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumSpOralTaxon193(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium sp. oral taxon 193 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumSpOralTaxon193", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "671223.protein.sequences.v11.5.fa",
		        "enrichment_path": "671223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "671223.protein.info.v11.5.txt",
		        "node_list_path": "671223.protein.complete.v11.5.txt"
		    }
		]
    )()

def RouxiellaChamberiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rouxiella chamberiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RouxiellaChamberiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1513468.protein.sequences.v11.5.fa",
		        "enrichment_path": "1513468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1513468.protein.info.v11.5.txt",
		        "node_list_path": "1513468.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisNctc12261Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis NCTC 12261 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisNctc12261Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246201.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246201.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246201.clusters.proteins.v11.5.txt",
		        "sequence_path": "246201.protein.sequences.v11.5.fa",
		        "enrichment_path": "246201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246201.protein.info.v11.5.txt",
		        "node_list_path": "246201.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246201.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusEquiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus equi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusEquiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40041.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40041.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40041.clusters.proteins.v11.5.txt",
		        "sequence_path": "40041.protein.sequences.v11.5.fa",
		        "enrichment_path": "40041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40041.protein.info.v11.5.txt",
		        "node_list_path": "40041.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40041.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterSpA7aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter sp. A7A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterSpA7aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1350366.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1350366.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1350366.clusters.proteins.v11.5.txt",
		        "sequence_path": "1350366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1350366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1350366.protein.info.v11.5.txt",
		        "node_list_path": "1350366.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1350366.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonomuraeaMaritima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaMaritima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "683260.protein.sequences.v11.5.fa",
		        "enrichment_path": "683260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683260.protein.info.v11.5.txt",
		        "node_list_path": "683260.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychroserpensBurtonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens burtonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroserpensBurtonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123037.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123037.protein.info.v11.5.txt",
		        "node_list_path": "1123037.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaWashoeensis0850475(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella washoeensis 085-0475 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaWashoeensis0850475", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094564.protein.info.v11.5.txt",
		        "node_list_path": "1094564.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumGriseofulvumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium griseofulvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumGriseofulvumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5078.clusters.proteins.v11.5.txt",
		        "sequence_path": "5078.protein.sequences.v11.5.fa",
		        "enrichment_path": "5078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5078.protein.info.v11.5.txt",
		        "node_list_path": "5078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumIncanumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum incanum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumIncanumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1573173.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1573173.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1573173.clusters.proteins.v11.5.txt",
		        "sequence_path": "1573173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1573173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1573173.protein.info.v11.5.txt",
		        "node_list_path": "1573173.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1573173.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusBeveridgeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus beveridgei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusBeveridgeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "632773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "632773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "632773.clusters.proteins.v11.5.txt",
		        "sequence_path": "632773.protein.sequences.v11.5.fa",
		        "enrichment_path": "632773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632773.protein.info.v11.5.txt",
		        "node_list_path": "632773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "632773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicaulisSpHl87Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. HL87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicaulisSpHl87Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1479238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1479238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1479238.clusters.proteins.v11.5.txt",
		        "sequence_path": "1479238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479238.protein.info.v11.5.txt",
		        "node_list_path": "1479238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1479238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag579(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag579", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262963.protein.info.v11.5.txt",
		        "node_list_path": "1262963.protein.complete.v11.5.txt"
		    }
		]
    )()

def CinnamomumMicranthumFKanehirae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cinnamomum micranthum f. kanehirae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CinnamomumMicranthumFKanehirae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "337451.protein.sequences.v11.5.fa",
		        "enrichment_path": "337451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "337451.protein.info.v11.5.txt",
		        "node_list_path": "337451.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAurantiacusDsm18675(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus aurantiacus DSM 18675 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAurantiacusDsm18675", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121086.protein.info.v11.5.txt",
		        "node_list_path": "1121086.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumPentaromativorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium pentaromativorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumPentaromativorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1088721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1088721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1088721.protein.info.v11.5.txt",
		        "node_list_path": "1088721.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusHopiensisKr140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus hopiensis KR-140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusHopiensisKr140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "695939.protein.sequences.v11.5.fa",
		        "enrichment_path": "695939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "695939.protein.info.v11.5.txt",
		        "node_list_path": "695939.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumImcc26256(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium IMCC26256 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumImcc26256", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1650658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1650658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1650658.protein.info.v11.5.txt",
		        "node_list_path": "1650658.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_55_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798516.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798516.protein.info.v11.5.txt",
		        "node_list_path": "1798516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumScgcAaa044D11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA044-D11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumScgcAaa044D11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "938518.protein.sequences.v11.5.fa",
		        "enrichment_path": "938518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938518.protein.info.v11.5.txt",
		        "node_list_path": "938518.protein.complete.v11.5.txt"
		    }
		]
    )()

def VirgibacillusAlimentarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus alimentarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusAlimentarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "698769.protein.sequences.v11.5.fa",
		        "enrichment_path": "698769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698769.protein.info.v11.5.txt",
		        "node_list_path": "698769.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelleaBalneolensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hellea balneolensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelleaBalneolensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121948.protein.info.v11.5.txt",
		        "node_list_path": "1121948.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaSpCf118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga sp. CF118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaSpCf118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884367.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884367.protein.info.v11.5.txt",
		        "node_list_path": "1884367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBoissieriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter boissieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBoissieriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219383.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219383.protein.info.v11.5.txt",
		        "node_list_path": "1219383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FerriphaselusAmnicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferriphaselus amnicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerriphaselusAmnicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1188319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1188319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1188319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1188319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188319.protein.info.v11.5.txt",
		        "node_list_path": "1188319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1188319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwd23811Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWD2_38_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwd23811Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618941.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618941.protein.info.v11.5.txt",
		        "node_list_path": "1618941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag579Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag579Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262963.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262963.protein.info.v11.5.txt",
		        "node_list_path": "1262963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaTestacea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia testacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaTestacea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206739.protein.info.v11.5.txt",
		        "node_list_path": "1206739.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosospiraMultiformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira multiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraMultiformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "323848.clusters.info.v11.5.txt",
		        "cluster_tree_path": "323848.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "323848.clusters.proteins.v11.5.txt",
		        "sequence_path": "323848.protein.sequences.v11.5.fa",
		        "enrichment_path": "323848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323848.protein.info.v11.5.txt",
		        "node_list_path": "323848.cluster.nodes.v11.5.txt",
		        "edge_list_path": "323848.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRbg133914(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RBG_13_39_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRbg133914", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797985.protein.info.v11.5.txt",
		        "node_list_path": "1797985.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpathasporaPassalidarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spathaspora passalidarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpathasporaPassalidarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "340170.protein.sequences.v11.5.fa",
		        "enrichment_path": "340170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340170.protein.info.v11.5.txt",
		        "node_list_path": "340170.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumSpAgr2158(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. AGR2158 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumSpAgr2158", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280675.protein.info.v11.5.txt",
		        "node_list_path": "1280675.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaBrassicaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma brassicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaBrassicaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61635.clusters.proteins.v11.5.txt",
		        "sequence_path": "61635.protein.sequences.v11.5.fa",
		        "enrichment_path": "61635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61635.protein.info.v11.5.txt",
		        "node_list_path": "61635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full3939(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_39_39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full3939", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802758.protein.info.v11.5.txt",
		        "node_list_path": "1802758.protein.complete.v11.5.txt"
		    }
		]
    )()

def NectriaHaematococcaMpvi77134(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Nectria] haematococca mpVI 77-13-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NectriaHaematococcaMpvi77134", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "660122.protein.sequences.v11.5.fa",
		        "enrichment_path": "660122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660122.protein.info.v11.5.txt",
		        "node_list_path": "660122.protein.complete.v11.5.txt"
		    }
		]
    )()

def JannaschiaHelgolandensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia helgolandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaHelgolandensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "188906.protein.sequences.v11.5.fa",
		        "enrichment_path": "188906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188906.protein.info.v11.5.txt",
		        "node_list_path": "188906.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesChartreusisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces chartreusis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesChartreusisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1079986.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1079986.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1079986.clusters.proteins.v11.5.txt",
		        "sequence_path": "1079986.protein.sequences.v11.5.fa",
		        "enrichment_path": "1079986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1079986.protein.info.v11.5.txt",
		        "node_list_path": "1079986.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1079986.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KitasatosporaCheerisanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora cheerisanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaCheerisanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348663.protein.info.v11.5.txt",
		        "node_list_path": "1348663.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifoxyd12Full3317Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD12_FULL_33_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd12Full3317Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798706.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798706.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798706.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798706.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798706.protein.info.v11.5.txt",
		        "node_list_path": "1798706.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798706.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaStercoreaCag629Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella stercorea CAG:629 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaStercoreaCag629Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263103.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263103.protein.info.v11.5.txt",
		        "node_list_path": "1263103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls149Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS149 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls149Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463885.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463885.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463885.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463885.protein.info.v11.5.txt",
		        "node_list_path": "1463885.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463885.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeolentinusLepideusHhb14362Ss1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neolentinus lepideus HHB14362 ss-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeolentinusLepideusHhb14362Ss1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314782.protein.info.v11.5.txt",
		        "node_list_path": "1314782.protein.complete.v11.5.txt"
		    }
		]
    )()

def HoldemaniaSpMarseilleP2844(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Holdemania sp. Marseille-P2844 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoldemaniaSpMarseilleP2844", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852366.protein.info.v11.5.txt",
		        "node_list_path": "1852366.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichophytonInterdigitaleMr816Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton interdigitale MR816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichophytonInterdigitaleMr816Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1215338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1215338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1215338.clusters.proteins.v11.5.txt",
		        "sequence_path": "1215338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215338.protein.info.v11.5.txt",
		        "node_list_path": "1215338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1215338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TomitellaBiformata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tomitella biformata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TomitellaBiformata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1448389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448389.protein.info.v11.5.txt",
		        "node_list_path": "1448389.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifoxyd1Full4619Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYD1_FULL_46_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyd1Full4619Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802552.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802552.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802552.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802552.protein.info.v11.5.txt",
		        "node_list_path": "1802552.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802552.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KtedonobacterRacemifer(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ktedonobacter racemifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KtedonobacterRacemifer", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "485913.protein.sequences.v11.5.fa",
		        "enrichment_path": "485913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485913.protein.info.v11.5.txt",
		        "node_list_path": "485913.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumArcachonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum arcachonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumArcachonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123326.protein.info.v11.5.txt",
		        "node_list_path": "1123326.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpAa23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. AA23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpAa23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1854058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1854058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1854058.clusters.proteins.v11.5.txt",
		        "sequence_path": "1854058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1854058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1854058.protein.info.v11.5.txt",
		        "node_list_path": "1854058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1854058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AminiphilusCircumscriptusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aminiphilus circumscriptus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminiphilusCircumscriptusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304874.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304874.protein.info.v11.5.txt",
		        "node_list_path": "1304874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacillusParabrevis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus parabrevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusParabrevis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "54914.protein.sequences.v11.5.fa",
		        "enrichment_path": "54914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54914.protein.info.v11.5.txt",
		        "node_list_path": "54914.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4521Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFCSPLOWO2_02_FULL_45_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4521Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797989.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797989.protein.info.v11.5.txt",
		        "node_list_path": "1797989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeobacterSpS60(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter sp. S60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterSpS60", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1569353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1569353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1569353.protein.info.v11.5.txt",
		        "node_list_path": "1569353.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisBaekryungensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis baekryungensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisBaekryungensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123270.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123270.protein.info.v11.5.txt",
		        "node_list_path": "1123270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnetococcusMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetococcus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetococcusMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "156889.protein.sequences.v11.5.fa",
		        "enrichment_path": "156889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156889.protein.info.v11.5.txt",
		        "node_list_path": "156889.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermofilumPendensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum pendens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermofilumPendensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "368408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "368408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "368408.clusters.proteins.v11.5.txt",
		        "sequence_path": "368408.protein.sequences.v11.5.fa",
		        "enrichment_path": "368408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "368408.protein.info.v11.5.txt",
		        "node_list_path": "368408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "368408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag724Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:724 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag724Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262966.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262966.protein.info.v11.5.txt",
		        "node_list_path": "1262966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumSwingsii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium swingsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumSwingsii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "680026.protein.sequences.v11.5.fa",
		        "enrichment_path": "680026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "680026.protein.info.v11.5.txt",
		        "node_list_path": "680026.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumGw2011Gwa14161(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium GW2011_GWA1_41_61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumGw2011Gwa14161", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618419.protein.info.v11.5.txt",
		        "node_list_path": "1618419.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnsiferSpLc11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. LC11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferSpLc11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1873712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1873712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1873712.clusters.proteins.v11.5.txt",
		        "sequence_path": "1873712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1873712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1873712.protein.info.v11.5.txt",
		        "node_list_path": "1873712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1873712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSp6526(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 65-26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSp6526", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895781.protein.info.v11.5.txt",
		        "node_list_path": "1895781.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpSka58(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SKA58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpSka58", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314266.protein.sequences.v11.5.fa",
		        "enrichment_path": "314266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314266.protein.info.v11.5.txt",
		        "node_list_path": "314266.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaAtypicaAcs049vsch6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella atypica ACS049VSch6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaAtypicaAcs049vsch6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "866776.protein.sequences.v11.5.fa",
		        "enrichment_path": "866776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866776.protein.info.v11.5.txt",
		        "node_list_path": "866776.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClavibacterMichiganensisSubspCapsiciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis subsp. capsici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavibacterMichiganensisSubspCapsiciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1874630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1874630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1874630.clusters.proteins.v11.5.txt",
		        "sequence_path": "1874630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1874630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1874630.protein.info.v11.5.txt",
		        "node_list_path": "1874630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1874630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsplowo202Full3811Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO2_02_FULL_38_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo202Full3811Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798293.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798293.protein.info.v11.5.txt",
		        "node_list_path": "1798293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaBacilliformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaBacilliformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "360095.protein.sequences.v11.5.fa",
		        "enrichment_path": "360095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360095.protein.info.v11.5.txt",
		        "node_list_path": "360095.protein.complete.v11.5.txt"
		    }
		]
    )()

def KnoelliaFlava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Knoellia flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KnoelliaFlava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385518.protein.info.v11.5.txt",
		        "node_list_path": "1385518.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpRoot4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpRoot4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736525.protein.info.v11.5.txt",
		        "node_list_path": "1736525.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSp9mfcol31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 9MFCol31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSp9mfcol31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150398.protein.info.v11.5.txt",
		        "node_list_path": "1150398.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisBenzoatilyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis benzoatilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisBenzoatilyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089544.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089544.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089544.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089544.protein.info.v11.5.txt",
		        "node_list_path": "1089544.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089544.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumMangrovi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium mangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumMangrovi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1043493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1043493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1043493.protein.info.v11.5.txt",
		        "node_list_path": "1043493.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumGenosp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium genosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumGenosp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936455.protein.sequences.v11.5.fa",
		        "enrichment_path": "936455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936455.protein.info.v11.5.txt",
		        "node_list_path": "936455.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesPyridomyceticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces pyridomyceticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPyridomyceticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68260.protein.sequences.v11.5.fa",
		        "enrichment_path": "68260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68260.protein.info.v11.5.txt",
		        "node_list_path": "68260.protein.complete.v11.5.txt"
		    }
		]
    )()

def EchinicolaPacifica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Echinicola pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EchinicolaPacifica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121859.protein.info.v11.5.txt",
		        "node_list_path": "1121859.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterCanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterCanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1357399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1357399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1357399.clusters.proteins.v11.5.txt",
		        "sequence_path": "1357399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357399.protein.info.v11.5.txt",
		        "node_list_path": "1357399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1357399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsphigho202Full4521Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPHIGHO2_02_FULL_45_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202Full4521Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801854.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801854.protein.info.v11.5.txt",
		        "node_list_path": "1801854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpizellomycesPunctatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spizellomyces punctatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpizellomycesPunctatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "109760.protein.sequences.v11.5.fa",
		        "enrichment_path": "109760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109760.protein.info.v11.5.txt",
		        "node_list_path": "109760.protein.complete.v11.5.txt"
		    }
		]
    )()

def LabrysSpWjw(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Labrys sp. WJW graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrysSpWjw", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1737983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1737983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1737983.protein.info.v11.5.txt",
		        "node_list_path": "1737983.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanibacterSpHtcc2649(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janibacter sp. HTCC2649 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterSpHtcc2649", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313589.protein.sequences.v11.5.fa",
		        "enrichment_path": "313589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313589.protein.info.v11.5.txt",
		        "node_list_path": "313589.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegaseliaScalaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megaselia scalaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegaseliaScalaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36166.protein.sequences.v11.5.fa",
		        "enrichment_path": "36166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36166.protein.info.v11.5.txt",
		        "node_list_path": "36166.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesRadiopugnansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces radiopugnans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRadiopugnansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "403935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "403935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "403935.clusters.proteins.v11.5.txt",
		        "sequence_path": "403935.protein.sequences.v11.5.fa",
		        "enrichment_path": "403935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "403935.protein.info.v11.5.txt",
		        "node_list_path": "403935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "403935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaglaciecolaHydrolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraglaciecola hydrolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaglaciecolaHydrolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1799789.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1799789.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1799789.clusters.proteins.v11.5.txt",
		        "sequence_path": "1799789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1799789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1799789.protein.info.v11.5.txt",
		        "node_list_path": "1799789.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1799789.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaMazeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina mazei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaMazeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "192952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "192952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "192952.clusters.proteins.v11.5.txt",
		        "sequence_path": "192952.protein.sequences.v11.5.fa",
		        "enrichment_path": "192952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192952.protein.info.v11.5.txt",
		        "node_list_path": "192952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "192952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusPoinariiG6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus poinarii G6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusPoinariiG6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354304.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354304.protein.info.v11.5.txt",
		        "node_list_path": "1354304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaBrassicae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma brassicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaBrassicae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61635.protein.sequences.v11.5.fa",
		        "enrichment_path": "61635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61635.protein.info.v11.5.txt",
		        "node_list_path": "61635.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacterium3818Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 38-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacterium3818Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895746.protein.info.v11.5.txt",
		        "node_list_path": "1895746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSp31yCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 31Y Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSp31yCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1115632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1115632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1115632.clusters.proteins.v11.5.txt",
		        "sequence_path": "1115632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1115632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1115632.protein.info.v11.5.txt",
		        "node_list_path": "1115632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1115632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PediococcusAcidilacticiDsm20284Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus acidilactici DSM20284 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusAcidilacticiDsm20284Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "862514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "862514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "862514.clusters.proteins.v11.5.txt",
		        "sequence_path": "862514.protein.sequences.v11.5.fa",
		        "enrichment_path": "862514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862514.protein.info.v11.5.txt",
		        "node_list_path": "862514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "862514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrococcalesBacterium72143Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 72-143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcalesBacterium72143Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895790.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895790.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895790.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895790.protein.info.v11.5.txt",
		        "node_list_path": "1895790.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895790.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAmbofaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces ambofaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAmbofaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889.protein.info.v11.5.txt",
		        "node_list_path": "1889.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitiniphilusShinanonensisDsm23277(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitiniphilus shinanonensis DSM 23277 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitiniphilusShinanonensisDsm23277", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121280.protein.info.v11.5.txt",
		        "node_list_path": "1121280.protein.complete.v11.5.txt"
		    }
		]
    )()

def CronobacterDublinensisSubspLactaridiLmg23825Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. lactaridi LMG 23825 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CronobacterDublinensisSubspLactaridiLmg23825Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1159496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1159496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1159496.clusters.proteins.v11.5.txt",
		        "sequence_path": "1159496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159496.protein.info.v11.5.txt",
		        "node_list_path": "1159496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1159496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacterium4128(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 41-28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacterium4128", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895706.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895706.protein.info.v11.5.txt",
		        "node_list_path": "1895706.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterWuianus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter wuianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterWuianus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1743168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743168.protein.info.v11.5.txt",
		        "node_list_path": "1743168.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsphigho202Full4416(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO2_02_FULL_44_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho202Full4416", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797862.protein.info.v11.5.txt",
		        "node_list_path": "1797862.protein.complete.v11.5.txt"
		    }
		]
    )()

def AbsidiaRepensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Absidia repens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AbsidiaRepensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "90262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "90262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "90262.clusters.proteins.v11.5.txt",
		        "sequence_path": "90262.protein.sequences.v11.5.fa",
		        "enrichment_path": "90262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90262.protein.info.v11.5.txt",
		        "node_list_path": "90262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "90262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisBiprosthecumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis biprosthecum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisBiprosthecumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "715226.clusters.info.v11.5.txt",
		        "cluster_tree_path": "715226.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "715226.clusters.proteins.v11.5.txt",
		        "sequence_path": "715226.protein.sequences.v11.5.fa",
		        "enrichment_path": "715226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "715226.protein.info.v11.5.txt",
		        "node_list_path": "715226.cluster.nodes.v11.5.txt",
		        "edge_list_path": "715226.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4516Fw969Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4516 (FW-969) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4516Fw969Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420910.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420910.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420910.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420910.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420910.protein.info.v11.5.txt",
		        "node_list_path": "1420910.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420910.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag330Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag330Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262954.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262954.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262954.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262954.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262954.protein.info.v11.5.txt",
		        "node_list_path": "1262954.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262954.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGsubCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Gsub Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGsubCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1615892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1615892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1615892.clusters.proteins.v11.5.txt",
		        "sequence_path": "1615892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1615892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1615892.protein.info.v11.5.txt",
		        "node_list_path": "1615892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1615892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusPhocae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus phocae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPhocae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "119224.protein.sequences.v11.5.fa",
		        "enrichment_path": "119224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "119224.protein.info.v11.5.txt",
		        "node_list_path": "119224.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "468059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "468059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "468059.clusters.proteins.v11.5.txt",
		        "sequence_path": "468059.protein.sequences.v11.5.fa",
		        "enrichment_path": "468059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "468059.protein.info.v11.5.txt",
		        "node_list_path": "468059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "468059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquilaChrysaetosChrysaetos(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquila chrysaetos chrysaetos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquilaChrysaetosChrysaetos", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "223781.protein.sequences.v11.5.fa",
		        "enrichment_path": "223781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223781.protein.info.v11.5.txt",
		        "node_list_path": "223781.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusCleftensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus cleftensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusCleftensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "163003.protein.sequences.v11.5.fa",
		        "enrichment_path": "163003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "163003.protein.info.v11.5.txt",
		        "node_list_path": "163003.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNucleicultrixAmoebiphilaFs5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nucleicultrix amoebiphila FS5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNucleicultrixAmoebiphilaFs5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1414854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414854.protein.info.v11.5.txt",
		        "node_list_path": "1414854.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb1416Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_41_6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb1416Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618869.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618869.protein.info.v11.5.txt",
		        "node_list_path": "1618869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasGinsengisoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasGinsengisoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "336566.protein.sequences.v11.5.fa",
		        "enrichment_path": "336566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336566.protein.info.v11.5.txt",
		        "node_list_path": "336566.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaprevotellaClaraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraprevotella clara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaprevotellaClaraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762968.clusters.proteins.v11.5.txt",
		        "sequence_path": "762968.protein.sequences.v11.5.fa",
		        "enrichment_path": "762968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762968.protein.info.v11.5.txt",
		        "node_list_path": "762968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumRifcsphigho201Full4114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO2_01_FULL_41_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho201Full4114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797217.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797217.protein.info.v11.5.txt",
		        "node_list_path": "1797217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumS714Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium S714 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumS714Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1284708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1284708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1284708.clusters.proteins.v11.5.txt",
		        "sequence_path": "1284708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284708.protein.info.v11.5.txt",
		        "node_list_path": "1284708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1284708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674847.protein.info.v11.5.txt",
		        "node_list_path": "1674847.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumFlavumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium flavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumFlavumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1638981.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1638981.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1638981.clusters.proteins.v11.5.txt",
		        "sequence_path": "1638981.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638981.protein.info.v11.5.txt",
		        "node_list_path": "1638981.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1638981.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpathasporaSpJa1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spathaspora sp. JA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpathasporaSpJa1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2028339.protein.sequences.v11.5.fa",
		        "enrichment_path": "2028339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2028339.protein.info.v11.5.txt",
		        "node_list_path": "2028339.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSp770b2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. 770b2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSp770b2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566271.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566271.protein.info.v11.5.txt",
		        "node_list_path": "1566271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NematocidaSp1Ertm2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nematocida sp. 1 ERTm2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NematocidaSp1Ertm2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "944018.protein.sequences.v11.5.fa",
		        "enrichment_path": "944018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944018.protein.info.v11.5.txt",
		        "node_list_path": "944018.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag202Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:202 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag202Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262884.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262884.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262884.protein.info.v11.5.txt",
		        "node_list_path": "1262884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NecropsobacterRosorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Necropsobacter rosorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NecropsobacterRosorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "908285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "908285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "908285.clusters.proteins.v11.5.txt",
		        "sequence_path": "908285.protein.sequences.v11.5.fa",
		        "enrichment_path": "908285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908285.protein.info.v11.5.txt",
		        "node_list_path": "908285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "908285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterCanadensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter canadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterCanadensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "537970.protein.sequences.v11.5.fa",
		        "enrichment_path": "537970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537970.protein.info.v11.5.txt",
		        "node_list_path": "537970.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylosinusTrichosporiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylosinus trichosporium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylosinusTrichosporiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "595536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "595536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "595536.clusters.proteins.v11.5.txt",
		        "sequence_path": "595536.protein.sequences.v11.5.fa",
		        "enrichment_path": "595536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595536.protein.info.v11.5.txt",
		        "node_list_path": "595536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "595536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachyspiraSpCag484(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira sp. CAG:484 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraSpCag484", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262759.protein.info.v11.5.txt",
		        "node_list_path": "1262759.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusHorneckiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus horneckiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHorneckiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "549687.clusters.info.v11.5.txt",
		        "cluster_tree_path": "549687.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "549687.clusters.proteins.v11.5.txt",
		        "sequence_path": "549687.protein.sequences.v11.5.fa",
		        "enrichment_path": "549687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "549687.protein.info.v11.5.txt",
		        "node_list_path": "549687.cluster.nodes.v11.5.txt",
		        "edge_list_path": "549687.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumBarkeri2011R4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium barkeri 2011-R4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumBarkeri2011R4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1197720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1197720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1197720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1197720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197720.protein.info.v11.5.txt",
		        "node_list_path": "1197720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1197720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumBarnesiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum barnesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumBarnesiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "760154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "760154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "760154.clusters.proteins.v11.5.txt",
		        "sequence_path": "760154.protein.sequences.v11.5.fa",
		        "enrichment_path": "760154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "760154.protein.info.v11.5.txt",
		        "node_list_path": "760154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "760154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterRudis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter rudis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterRudis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "632955.protein.sequences.v11.5.fa",
		        "enrichment_path": "632955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632955.protein.info.v11.5.txt",
		        "node_list_path": "632955.protein.complete.v11.5.txt"
		    }
		]
    )()

def GardnerellaVaginalis6119v5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis 6119V5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GardnerellaVaginalis6119v5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "698961.protein.sequences.v11.5.fa",
		        "enrichment_path": "698961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698961.protein.info.v11.5.txt",
		        "node_list_path": "698961.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumMacuxiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium macuxiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumMacuxiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1755647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1755647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1755647.protein.info.v11.5.txt",
		        "node_list_path": "1755647.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSalivarius57i(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus salivarius 57I graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSalivarius57i", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1046629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046629.protein.info.v11.5.txt",
		        "node_list_path": "1046629.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerotruncusSpG3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. G3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotruncusSpG3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235835.protein.info.v11.5.txt",
		        "node_list_path": "1235835.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusSpPk(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sp. PK graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSpPk", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "913025.protein.sequences.v11.5.fa",
		        "enrichment_path": "913025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913025.protein.info.v11.5.txt",
		        "node_list_path": "913025.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterButzleriEd1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter butzleri ED1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterButzleriEd1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "944546.protein.sequences.v11.5.fa",
		        "enrichment_path": "944546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944546.protein.info.v11.5.txt",
		        "node_list_path": "944546.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusThermophilusJl18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus JL-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusThermophilusJl18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "798128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "798128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "798128.clusters.proteins.v11.5.txt",
		        "sequence_path": "798128.protein.sequences.v11.5.fa",
		        "enrichment_path": "798128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "798128.protein.info.v11.5.txt",
		        "node_list_path": "798128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "798128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureobasidiumSubglacialeExf2481Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium subglaciale EXF-2481 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureobasidiumSubglacialeExf2481Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1043005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1043005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1043005.clusters.proteins.v11.5.txt",
		        "sequence_path": "1043005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1043005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1043005.protein.info.v11.5.txt",
		        "node_list_path": "1043005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1043005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacterLuteusImvB3098Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacter luteus IMV-B-3098 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacterLuteusImvB3098Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095552.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095552.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095552.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095552.protein.info.v11.5.txt",
		        "node_list_path": "1095552.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095552.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpFuku2Iso50(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Fuku2-ISO-50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpFuku2Iso50", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739114.protein.info.v11.5.txt",
		        "node_list_path": "1739114.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumSandarakinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium sandarakinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumSandarakinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "629680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "629680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "629680.clusters.proteins.v11.5.txt",
		        "sequence_path": "629680.protein.sequences.v11.5.fa",
		        "enrichment_path": "629680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "629680.protein.info.v11.5.txt",
		        "node_list_path": "629680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "629680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxSpP2s70(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. P2S70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxSpP2s70", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397527.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397527.protein.info.v11.5.txt",
		        "node_list_path": "1397527.protein.complete.v11.5.txt"
		    }
		]
    )()

def EhrlichiaMinasensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia minasensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EhrlichiaMinasensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1242993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1242993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1242993.protein.info.v11.5.txt",
		        "node_list_path": "1242993.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasTelluritireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas telluritireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasTelluritireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "162160.protein.sequences.v11.5.fa",
		        "enrichment_path": "162160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "162160.protein.info.v11.5.txt",
		        "node_list_path": "162160.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusEapokensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus eapokensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusEapokensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1873482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1873482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1873482.protein.info.v11.5.txt",
		        "node_list_path": "1873482.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrialbaTaiwanensisDsm12281(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrialba taiwanensis DSM 12281 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaTaiwanensisDsm12281", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230458.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230458.protein.info.v11.5.txt",
		        "node_list_path": "1230458.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaPolaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia polaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaPolaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326537.protein.sequences.v11.5.fa",
		        "enrichment_path": "326537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326537.protein.info.v11.5.txt",
		        "node_list_path": "326537.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusAlbus7Dsm20455(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus albus 7  DSM 20455 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusAlbus7Dsm20455", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "697329.protein.sequences.v11.5.fa",
		        "enrichment_path": "697329.protein.enrichment.terms.v11.5.txt",
		        "info_path": "697329.protein.info.v11.5.txt",
		        "node_list_path": "697329.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaBronchialisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella bronchialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaBronchialisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "463025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "463025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "463025.clusters.proteins.v11.5.txt",
		        "sequence_path": "463025.protein.sequences.v11.5.fa",
		        "enrichment_path": "463025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "463025.protein.info.v11.5.txt",
		        "node_list_path": "463025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "463025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDichloromethanomonasElyunquensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dichloromethanomonas elyunquensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDichloromethanomonasElyunquensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1755312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1755312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1755312.protein.info.v11.5.txt",
		        "node_list_path": "1755312.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusAcididuransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus acididurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusAcididuransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "476652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "476652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "476652.clusters.proteins.v11.5.txt",
		        "sequence_path": "476652.protein.sequences.v11.5.fa",
		        "enrichment_path": "476652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "476652.protein.info.v11.5.txt",
		        "node_list_path": "476652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "476652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IctidomysTridecemlineatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ictidomys tridecemlineatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IctidomysTridecemlineatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43179.clusters.proteins.v11.5.txt",
		        "sequence_path": "43179.protein.sequences.v11.5.fa",
		        "enrichment_path": "43179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43179.protein.info.v11.5.txt",
		        "node_list_path": "43179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErysiphePulchraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysiphe pulchra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysiphePulchraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "225359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "225359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "225359.clusters.proteins.v11.5.txt",
		        "sequence_path": "225359.protein.sequences.v11.5.fa",
		        "enrichment_path": "225359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225359.protein.info.v11.5.txt",
		        "node_list_path": "225359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "225359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchistosomaHaematobiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma haematobium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaHaematobiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6185.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6185.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6185.clusters.proteins.v11.5.txt",
		        "sequence_path": "6185.protein.sequences.v11.5.fa",
		        "enrichment_path": "6185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6185.protein.info.v11.5.txt",
		        "node_list_path": "6185.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6185.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCns606(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNS606 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCns606", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1305837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305837.protein.info.v11.5.txt",
		        "node_list_path": "1305837.protein.complete.v11.5.txt"
		    }
		]
    )()

def RathayibacterTritici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rathayibacter tritici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RathayibacterTritici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33888.protein.sequences.v11.5.fa",
		        "enrichment_path": "33888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33888.protein.info.v11.5.txt",
		        "node_list_path": "33888.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrrhodermaNoxium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrrhoderma noxium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrrhodermaNoxium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2282107.protein.sequences.v11.5.fa",
		        "enrichment_path": "2282107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2282107.protein.info.v11.5.txt",
		        "node_list_path": "2282107.protein.complete.v11.5.txt"
		    }
		]
    )()

def Bacterium2013ark19i(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium 2013Ark19i graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Bacterium2013ark19i", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1561004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561004.protein.info.v11.5.txt",
		        "node_list_path": "1561004.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZeaMays(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zea mays graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZeaMays", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4577.protein.sequences.v11.5.fa",
		        "enrichment_path": "4577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4577.protein.info.v11.5.txt",
		        "node_list_path": "4577.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesHelcogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides helcogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesHelcogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "693979.protein.sequences.v11.5.fa",
		        "enrichment_path": "693979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693979.protein.info.v11.5.txt",
		        "node_list_path": "693979.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiabellaAurantiaca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Niabella aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiabellaAurantiaca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122605.protein.info.v11.5.txt",
		        "node_list_path": "1122605.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpYcRl4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. YC-RL4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpYcRl4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1682113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1682113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1682113.clusters.proteins.v11.5.txt",
		        "sequence_path": "1682113.protein.sequences.v11.5.fa",
		        "enrichment_path": "1682113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1682113.protein.info.v11.5.txt",
		        "node_list_path": "1682113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1682113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag341(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:341 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag341", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263019.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263019.protein.info.v11.5.txt",
		        "node_list_path": "1263019.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaviibacterAbscessusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caviibacter abscessus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaviibacterAbscessusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1766719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1766719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1766719.clusters.proteins.v11.5.txt",
		        "sequence_path": "1766719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1766719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1766719.protein.info.v11.5.txt",
		        "node_list_path": "1766719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1766719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRifcsplowo202Full6415Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO2_02_FULL_64_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202Full6415Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797181.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797181.protein.info.v11.5.txt",
		        "node_list_path": "1797181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaNodosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia nodosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaNodosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121127.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121127.protein.info.v11.5.txt",
		        "node_list_path": "1121127.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSp174mfsha11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 174MFSha1.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSp174mfsha11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502749.protein.info.v11.5.txt",
		        "node_list_path": "1502749.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanococcusMaripaludisC7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusMaripaludisC7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426368.protein.sequences.v11.5.fa",
		        "enrichment_path": "426368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426368.protein.info.v11.5.txt",
		        "node_list_path": "426368.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSpAls9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. ALS9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpAls9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805819.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805819.protein.info.v11.5.txt",
		        "node_list_path": "1805819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OryzaBarthii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryza barthii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaBarthii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "65489.protein.sequences.v11.5.fa",
		        "enrichment_path": "65489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65489.protein.info.v11.5.txt",
		        "node_list_path": "65489.protein.complete.v11.5.txt"
		    }
		]
    )()

def KingellaOralisAtcc51147(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kingella oralis ATCC 51147 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KingellaOralisAtcc51147", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "629741.protein.sequences.v11.5.fa",
		        "enrichment_path": "629741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "629741.protein.info.v11.5.txt",
		        "node_list_path": "629741.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexusAurantiacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexus aurantiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexusAurantiacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "324602.clusters.info.v11.5.txt",
		        "cluster_tree_path": "324602.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "324602.clusters.proteins.v11.5.txt",
		        "sequence_path": "324602.protein.sequences.v11.5.fa",
		        "enrichment_path": "324602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "324602.protein.info.v11.5.txt",
		        "node_list_path": "324602.cluster.nodes.v11.5.txt",
		        "edge_list_path": "324602.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterPolytrichastri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter polytrichastri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterPolytrichastri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1302689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302689.protein.info.v11.5.txt",
		        "node_list_path": "1302689.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusAquistagniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus aquistagni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusAquistagniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852522.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852522.protein.info.v11.5.txt",
		        "node_list_path": "1852522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnabaenaVariabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anabaena variabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabaenaVariabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "240292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "240292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "240292.clusters.proteins.v11.5.txt",
		        "sequence_path": "240292.protein.sequences.v11.5.fa",
		        "enrichment_path": "240292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240292.protein.info.v11.5.txt",
		        "node_list_path": "240292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "240292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumLemurumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium lemurum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumLemurumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1603886.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1603886.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1603886.clusters.proteins.v11.5.txt",
		        "sequence_path": "1603886.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603886.protein.info.v11.5.txt",
		        "node_list_path": "1603886.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1603886.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumGwb1558Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWB1_55_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumGwb1558Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797386.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797386.protein.info.v11.5.txt",
		        "node_list_path": "1797386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaAzotonutriciumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema azotonutricium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaAzotonutriciumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "545695.clusters.info.v11.5.txt",
		        "cluster_tree_path": "545695.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "545695.clusters.proteins.v11.5.txt",
		        "sequence_path": "545695.protein.sequences.v11.5.fa",
		        "enrichment_path": "545695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545695.protein.info.v11.5.txt",
		        "node_list_path": "545695.cluster.nodes.v11.5.txt",
		        "edge_list_path": "545695.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaSpDd3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. DD3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpDd3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410619.protein.info.v11.5.txt",
		        "node_list_path": "1410619.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpPamc28756Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. PAMC 28756 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpPamc28756Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1795053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1795053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1795053.clusters.proteins.v11.5.txt",
		        "sequence_path": "1795053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795053.protein.info.v11.5.txt",
		        "node_list_path": "1795053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1795053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfitibacterSpBrhC19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfitibacter sp. BRH_c19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitibacterSpBrhC19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1734395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1734395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1734395.protein.info.v11.5.txt",
		        "node_list_path": "1734395.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaRocourtiaeFslF6920Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria rocourtiae FSL F6-920 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaRocourtiaeFslF6920Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265846.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265846.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265846.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265846.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265846.protein.info.v11.5.txt",
		        "node_list_path": "1265846.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265846.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaPluranimaliumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella pluranimalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaPluranimaliumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "470453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "470453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "470453.clusters.proteins.v11.5.txt",
		        "sequence_path": "470453.protein.sequences.v11.5.fa",
		        "enrichment_path": "470453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "470453.protein.info.v11.5.txt",
		        "node_list_path": "470453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "470453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpAgr2160Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. AGR2160 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpAgr2160Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280674.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280674.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280674.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280674.protein.info.v11.5.txt",
		        "node_list_path": "1280674.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280674.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaSpRaccoon60Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. Raccoon60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpRaccoon60Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1933912.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1933912.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1933912.clusters.proteins.v11.5.txt",
		        "sequence_path": "1933912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933912.protein.info.v11.5.txt",
		        "node_list_path": "1933912.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1933912.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SediminicolaSpYik13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sediminicola sp. YIK13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminicolaSpYik13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1453352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1453352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1453352.clusters.proteins.v11.5.txt",
		        "sequence_path": "1453352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453352.protein.info.v11.5.txt",
		        "node_list_path": "1453352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1453352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterOlleyaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter olleyae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterOlleyaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "294671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "294671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "294671.clusters.proteins.v11.5.txt",
		        "sequence_path": "294671.protein.sequences.v11.5.fa",
		        "enrichment_path": "294671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294671.protein.info.v11.5.txt",
		        "node_list_path": "294671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "294671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ItalianCloverPhyllodyPhytoplasmaStrMa1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Italian clover phyllody phytoplasma str. MA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ItalianCloverPhyllodyPhytoplasmaStrMa1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196421.protein.info.v11.5.txt",
		        "node_list_path": "1196421.protein.complete.v11.5.txt"
		    }
		]
    )()

def MalonomonasRubraDsm5091(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Malonomonas rubra DSM 5091 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalonomonasRubraDsm5091", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122189.protein.info.v11.5.txt",
		        "node_list_path": "1122189.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSacchariCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSacchariCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "159450.clusters.info.v11.5.txt",
		        "cluster_tree_path": "159450.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "159450.clusters.proteins.v11.5.txt",
		        "sequence_path": "159450.protein.sequences.v11.5.fa",
		        "enrichment_path": "159450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "159450.protein.info.v11.5.txt",
		        "node_list_path": "159450.cluster.nodes.v11.5.txt",
		        "edge_list_path": "159450.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacteriumGwa27023(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium GWA2_70_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacteriumGwa27023", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802095.protein.info.v11.5.txt",
		        "node_list_path": "1802095.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpSirexaaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. SirexAAE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpSirexaaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "862751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "862751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "862751.clusters.proteins.v11.5.txt",
		        "sequence_path": "862751.protein.sequences.v11.5.fa",
		        "enrichment_path": "862751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862751.protein.info.v11.5.txt",
		        "node_list_path": "862751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "862751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedMegasphaeraSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Megasphaera sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedMegasphaeraSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "165188.protein.sequences.v11.5.fa",
		        "enrichment_path": "165188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "165188.protein.info.v11.5.txt",
		        "node_list_path": "165188.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastomonasSpAap53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastomonas sp. AAP53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomonasSpAap53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1248760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1248760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1248760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1248760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1248760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1248760.protein.info.v11.5.txt",
		        "node_list_path": "1248760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1248760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4122Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_41_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4122Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802067.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802067.protein.info.v11.5.txt",
		        "node_list_path": "1802067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusFaeciumNrrlb2354Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecium NRRLB2354 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusFaeciumNrrlb2354Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1104325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1104325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1104325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1104325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104325.protein.info.v11.5.txt",
		        "node_list_path": "1104325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1104325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaAlbicans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida albicans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaAlbicans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5476.protein.sequences.v11.5.fa",
		        "enrichment_path": "5476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5476.protein.info.v11.5.txt",
		        "node_list_path": "5476.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720302.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720302.protein.info.v11.5.txt",
		        "node_list_path": "1720302.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesMinimus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles minimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesMinimus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "112268.protein.sequences.v11.5.fa",
		        "enrichment_path": "112268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112268.protein.info.v11.5.txt",
		        "node_list_path": "112268.protein.complete.v11.5.txt"
		    }
		]
    )()

def XiphophorusMaculatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xiphophorus maculatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XiphophorusMaculatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8083.clusters.proteins.v11.5.txt",
		        "sequence_path": "8083.protein.sequences.v11.5.fa",
		        "enrichment_path": "8083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8083.protein.info.v11.5.txt",
		        "node_list_path": "8083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumStercorarium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium stercorarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumStercorarium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121335.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121335.protein.info.v11.5.txt",
		        "node_list_path": "1121335.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElephantulusEdwardiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elephantulus edwardii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElephantulusEdwardiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28737.clusters.proteins.v11.5.txt",
		        "sequence_path": "28737.protein.sequences.v11.5.fa",
		        "enrichment_path": "28737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28737.protein.info.v11.5.txt",
		        "node_list_path": "28737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SunxiuqiniaEllipticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sunxiuqinia elliptica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SunxiuqiniaEllipticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655355.clusters.proteins.v11.5.txt",
		        "sequence_path": "655355.protein.sequences.v11.5.fa",
		        "enrichment_path": "655355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655355.protein.info.v11.5.txt",
		        "node_list_path": "655355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasSpAe122(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas sp. AE122 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSpAe122", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "558884.protein.sequences.v11.5.fa",
		        "enrichment_path": "558884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558884.protein.info.v11.5.txt",
		        "node_list_path": "558884.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndozoicomonasNumazuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas numazuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndozoicomonasNumazuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1137799.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137799.protein.info.v11.5.txt",
		        "node_list_path": "1137799.protein.complete.v11.5.txt"
		    }
		]
    )()

def LibanicoccusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Libanicoccus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LibanicoccusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871022.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871022.protein.info.v11.5.txt",
		        "node_list_path": "1871022.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureimonasPhyllosphaeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas phyllosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasPhyllosphaeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1166078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1166078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1166078.clusters.proteins.v11.5.txt",
		        "sequence_path": "1166078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166078.protein.info.v11.5.txt",
		        "node_list_path": "1166078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1166078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BermanellaMarisrubri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bermanella marisrubri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BermanellaMarisrubri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "207949.protein.sequences.v11.5.fa",
		        "enrichment_path": "207949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "207949.protein.info.v11.5.txt",
		        "node_list_path": "207949.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsphigho212Full429Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_12_FULL_42_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho212Full429Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802511.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802511.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802511.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802511.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802511.protein.info.v11.5.txt",
		        "node_list_path": "1802511.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802511.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiaBacteriumScgcAaa160I06Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium SCGC AAA160-I06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiaBacteriumScgcAaa160I06Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1007123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1007123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1007123.clusters.proteins.v11.5.txt",
		        "sequence_path": "1007123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007123.protein.info.v11.5.txt",
		        "node_list_path": "1007123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1007123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpLeaf78(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpLeaf78", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736237.protein.info.v11.5.txt",
		        "node_list_path": "1736237.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaSpF0234Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaSpF0234Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888059.clusters.proteins.v11.5.txt",
		        "sequence_path": "888059.protein.sequences.v11.5.fa",
		        "enrichment_path": "888059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888059.protein.info.v11.5.txt",
		        "node_list_path": "888059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusAquistagni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus aquistagni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusAquistagni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852522.protein.info.v11.5.txt",
		        "node_list_path": "1852522.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmodiumCynomolgiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium cynomolgi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumCynomolgiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5827.clusters.proteins.v11.5.txt",
		        "sequence_path": "5827.protein.sequences.v11.5.fa",
		        "enrichment_path": "5827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5827.protein.info.v11.5.txt",
		        "node_list_path": "5827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraBroomiiSerovarHurstbridgeStr5399(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira broomii serovar Hurstbridge str. 5399 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraBroomiiSerovarHurstbridgeStr5399", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1049789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1049789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1049789.protein.info.v11.5.txt",
		        "node_list_path": "1049789.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumDrakeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium drakei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumDrakeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "332101.clusters.info.v11.5.txt",
		        "cluster_tree_path": "332101.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "332101.clusters.proteins.v11.5.txt",
		        "sequence_path": "332101.protein.sequences.v11.5.fa",
		        "enrichment_path": "332101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332101.protein.info.v11.5.txt",
		        "node_list_path": "332101.cluster.nodes.v11.5.txt",
		        "edge_list_path": "332101.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaSpRac05(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. RAC05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpRac05", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1842539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842539.protein.info.v11.5.txt",
		        "node_list_path": "1842539.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasMelonisTyCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas melonis TY Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasMelonisTyCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "621456.clusters.info.v11.5.txt",
		        "cluster_tree_path": "621456.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "621456.clusters.proteins.v11.5.txt",
		        "sequence_path": "621456.protein.sequences.v11.5.fa",
		        "enrichment_path": "621456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "621456.protein.info.v11.5.txt",
		        "node_list_path": "621456.cluster.nodes.v11.5.txt",
		        "edge_list_path": "621456.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasSpNyagatare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Nyagatare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasSpNyagatare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1552758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1552758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1552758.protein.info.v11.5.txt",
		        "node_list_path": "1552758.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaGeojensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia geojensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaGeojensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "443610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "443610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "443610.clusters.proteins.v11.5.txt",
		        "sequence_path": "443610.protein.sequences.v11.5.fa",
		        "enrichment_path": "443610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443610.protein.info.v11.5.txt",
		        "node_list_path": "443610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "443610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobaculumAquaticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobaculum aquaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobaculumAquaticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1312852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1312852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1312852.clusters.proteins.v11.5.txt",
		        "sequence_path": "1312852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1312852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1312852.protein.info.v11.5.txt",
		        "node_list_path": "1312852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1312852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusCaeni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusCaeni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "405946.protein.sequences.v11.5.fa",
		        "enrichment_path": "405946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405946.protein.info.v11.5.txt",
		        "node_list_path": "405946.protein.complete.v11.5.txt"
		    }
		]
    )()

def AncylobacterRudongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ancylobacter rudongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AncylobacterRudongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "177413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "177413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "177413.clusters.proteins.v11.5.txt",
		        "sequence_path": "177413.protein.sequences.v11.5.fa",
		        "enrichment_path": "177413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "177413.protein.info.v11.5.txt",
		        "node_list_path": "177413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "177413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpRac01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. RAC01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpRac01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1842533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842533.protein.info.v11.5.txt",
		        "node_list_path": "1842533.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumUc512e3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-2E3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumUc512e3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1697781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1697781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1697781.clusters.proteins.v11.5.txt",
		        "sequence_path": "1697781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1697781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1697781.protein.info.v11.5.txt",
		        "node_list_path": "1697781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1697781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CycloclasticusSpSymbiontOfPoeciloscleridaSpM(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Poecilosclerida sp. M graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CycloclasticusSpSymbiontOfPoeciloscleridaSpM", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1840537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1840537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1840537.protein.info.v11.5.txt",
		        "node_list_path": "1840537.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeofusicoccumParvumUcrnp2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neofusicoccum parvum UCRNP2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeofusicoccumParvumUcrnp2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1287680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287680.protein.info.v11.5.txt",
		        "node_list_path": "1287680.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodotorulaGraminisWp1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula graminis WP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodotorulaGraminisWp1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "578459.protein.sequences.v11.5.fa",
		        "enrichment_path": "578459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578459.protein.info.v11.5.txt",
		        "node_list_path": "578459.protein.complete.v11.5.txt"
		    }
		]
    )()

def KyrpidiaTusciaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kyrpidia tusciae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KyrpidiaTusciaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "562970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "562970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "562970.clusters.proteins.v11.5.txt",
		        "sequence_path": "562970.protein.sequences.v11.5.fa",
		        "enrichment_path": "562970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562970.protein.info.v11.5.txt",
		        "node_list_path": "562970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "562970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaSpR4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. R4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpR4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "928210.protein.sequences.v11.5.fa",
		        "enrichment_path": "928210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "928210.protein.info.v11.5.txt",
		        "node_list_path": "928210.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumSgBin9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SG_bin9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumSgBin9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1827385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1827385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1827385.clusters.proteins.v11.5.txt",
		        "sequence_path": "1827385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827385.protein.info.v11.5.txt",
		        "node_list_path": "1827385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1827385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterFetusSubspFetusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. fetus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterFetusSubspFetusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32019.clusters.proteins.v11.5.txt",
		        "sequence_path": "32019.protein.sequences.v11.5.fa",
		        "enrichment_path": "32019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32019.protein.info.v11.5.txt",
		        "node_list_path": "32019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedMethanoculleusSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Methanoculleus sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedMethanoculleusSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "183762.protein.sequences.v11.5.fa",
		        "enrichment_path": "183762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "183762.protein.info.v11.5.txt",
		        "node_list_path": "183762.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaAustralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaAustralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094489.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094489.protein.info.v11.5.txt",
		        "node_list_path": "1094489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaMallotivora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia mallotivora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaMallotivora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69222.protein.sequences.v11.5.fa",
		        "enrichment_path": "69222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69222.protein.info.v11.5.txt",
		        "node_list_path": "69222.protein.complete.v11.5.txt"
		    }
		]
    )()

def KosmotogaOlearia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kosmotoga olearia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KosmotogaOlearia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521045.protein.sequences.v11.5.fa",
		        "enrichment_path": "521045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521045.protein.info.v11.5.txt",
		        "node_list_path": "521045.protein.complete.v11.5.txt"
		    }
		]
    )()

def GranulibacterBethesdensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Granulibacter bethesdensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulibacterBethesdensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391165.protein.sequences.v11.5.fa",
		        "enrichment_path": "391165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391165.protein.info.v11.5.txt",
		        "node_list_path": "391165.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesGraevenitzii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces graevenitzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesGraevenitzii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "435830.protein.sequences.v11.5.fa",
		        "enrichment_path": "435830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435830.protein.info.v11.5.txt",
		        "node_list_path": "435830.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc14312Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_43_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc14312Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618909.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618909.protein.info.v11.5.txt",
		        "node_list_path": "1618909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PasteurellaMultocidaSubspMultocidaStrPm70(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida subsp. multocida str. Pm70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaMultocidaSubspMultocidaStrPm70", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272843.protein.sequences.v11.5.fa",
		        "enrichment_path": "272843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272843.protein.info.v11.5.txt",
		        "node_list_path": "272843.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioCoralliilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio coralliilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCoralliilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675814.protein.sequences.v11.5.fa",
		        "enrichment_path": "675814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675814.protein.info.v11.5.txt",
		        "node_list_path": "675814.protein.complete.v11.5.txt"
		    }
		]
    )()

def SteinernemaCarpocapsaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Steinernema carpocapsae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SteinernemaCarpocapsaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34508.clusters.proteins.v11.5.txt",
		        "sequence_path": "34508.protein.sequences.v11.5.fa",
		        "enrichment_path": "34508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34508.protein.info.v11.5.txt",
		        "node_list_path": "34508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaCibariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella cibaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaCibariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "911104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "911104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "911104.clusters.proteins.v11.5.txt",
		        "sequence_path": "911104.protein.sequences.v11.5.fa",
		        "enrichment_path": "911104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "911104.protein.info.v11.5.txt",
		        "node_list_path": "911104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "911104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiO157H7StrSakaiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli O157:H7 str. Sakai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiO157H7StrSakaiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "386585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "386585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "386585.clusters.proteins.v11.5.txt",
		        "sequence_path": "386585.protein.sequences.v11.5.fa",
		        "enrichment_path": "386585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "386585.protein.info.v11.5.txt",
		        "node_list_path": "386585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "386585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermotogaPetrophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga petrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaPetrophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "390874.protein.sequences.v11.5.fa",
		        "enrichment_path": "390874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390874.protein.info.v11.5.txt",
		        "node_list_path": "390874.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeeksellaSpFf8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weeksella sp. FF8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeeksellaSpFf8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461577.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461577.protein.info.v11.5.txt",
		        "node_list_path": "1461577.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiastellaPopuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Niastella populi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiastellaPopuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "550983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "550983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "550983.clusters.proteins.v11.5.txt",
		        "sequence_path": "550983.protein.sequences.v11.5.fa",
		        "enrichment_path": "550983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "550983.protein.info.v11.5.txt",
		        "node_list_path": "550983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "550983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSp24mn13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 24MN13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSp24mn13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1622150.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622150.protein.info.v11.5.txt",
		        "node_list_path": "1622150.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureobasidiumPullulansExf150Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium pullulans EXF-150 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureobasidiumPullulansExf150Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1043002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1043002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1043002.clusters.proteins.v11.5.txt",
		        "sequence_path": "1043002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1043002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1043002.protein.info.v11.5.txt",
		        "node_list_path": "1043002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1043002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpCip102129(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP102129 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpCip102129", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144664.protein.info.v11.5.txt",
		        "node_list_path": "1144664.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusUberisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus uberis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusUberisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "218495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "218495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "218495.clusters.proteins.v11.5.txt",
		        "sequence_path": "218495.protein.sequences.v11.5.fa",
		        "enrichment_path": "218495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218495.protein.info.v11.5.txt",
		        "node_list_path": "218495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "218495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UstilaginoideaVirens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ustilaginoidea virens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UstilaginoideaVirens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1159556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159556.protein.info.v11.5.txt",
		        "node_list_path": "1159556.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalopelagiusInordinatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halopelagius inordinatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalopelagiusInordinatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553467.protein.sequences.v11.5.fa",
		        "enrichment_path": "553467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553467.protein.info.v11.5.txt",
		        "node_list_path": "553467.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionisporaVibrioidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionispora vibrioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionisporaVibrioidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "112903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "112903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "112903.clusters.proteins.v11.5.txt",
		        "sequence_path": "112903.protein.sequences.v11.5.fa",
		        "enrichment_path": "112903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112903.protein.info.v11.5.txt",
		        "node_list_path": "112903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "112903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNealsonbacteriaBacteriumRifcsphigho202Full4313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFCSPHIGHO2_02_FULL_43_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifcsphigho202Full4313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801668.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801668.protein.info.v11.5.txt",
		        "node_list_path": "1801668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho202Full4018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_40_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full4018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798605.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798605.protein.info.v11.5.txt",
		        "node_list_path": "1798605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinophagaceaeBacteriumIbvucb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium IBVUCB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaceaeBacteriumIbvucb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1985173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1985173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1985173.protein.info.v11.5.txt",
		        "node_list_path": "1985173.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesYeochonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces yeochonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesYeochonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449355.protein.info.v11.5.txt",
		        "node_list_path": "1449355.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaScatoligenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella scatoligenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaScatoligenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1299998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1299998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1299998.clusters.proteins.v11.5.txt",
		        "sequence_path": "1299998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1299998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1299998.protein.info.v11.5.txt",
		        "node_list_path": "1299998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1299998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumGwf2429(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_42_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumGwf2429", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801958.protein.info.v11.5.txt",
		        "node_list_path": "1801958.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4624Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_46_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4624Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817825.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817825.protein.info.v11.5.txt",
		        "node_list_path": "1817825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaWelshimeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria welshimeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaWelshimeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "386043.protein.sequences.v11.5.fa",
		        "enrichment_path": "386043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "386043.protein.info.v11.5.txt",
		        "node_list_path": "386043.protein.complete.v11.5.txt"
		    }
		]
    )()

def PandoraeaSpSd62Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea sp. SD62 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaSpSd62Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1286093.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1286093.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1286093.clusters.proteins.v11.5.txt",
		        "sequence_path": "1286093.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286093.protein.info.v11.5.txt",
		        "node_list_path": "1286093.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1286093.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumGw2011Gwc2489(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium GW2011_GWC2_48_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumGw2011Gwc2489", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619071.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619071.protein.info.v11.5.txt",
		        "node_list_path": "1619071.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaSprentiaeWsm5005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia sprentiae WSM5005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaSprentiaeWsm5005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "754502.protein.sequences.v11.5.fa",
		        "enrichment_path": "754502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754502.protein.info.v11.5.txt",
		        "node_list_path": "754502.protein.complete.v11.5.txt"
		    }
		]
    )()

def PostiaPlacentaMad698R(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Postia placenta Mad-698-R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PostiaPlacentaMad698R", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "561896.protein.sequences.v11.5.fa",
		        "enrichment_path": "561896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561896.protein.info.v11.5.txt",
		        "node_list_path": "561896.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaglaciecolaPolarisLmg21857(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraglaciecola polaris LMG 21857 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaglaciecolaPolarisLmg21857", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1129793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1129793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1129793.protein.info.v11.5.txt",
		        "node_list_path": "1129793.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumVitaeruminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium vitaeruminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumVitaeruminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1224164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224164.protein.info.v11.5.txt",
		        "node_list_path": "1224164.protein.complete.v11.5.txt"
		    }
		]
    )()

def TissierelliaBacteriumKa00581Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tissierellia bacterium KA00581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TissierelliaBacteriumKa00581Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1588751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1588751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1588751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1588751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588751.protein.info.v11.5.txt",
		        "node_list_path": "1588751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1588751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNbrc110611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NBRC 110611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNbrc110611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1621259.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1621259.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1621259.clusters.proteins.v11.5.txt",
		        "sequence_path": "1621259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1621259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1621259.protein.info.v11.5.txt",
		        "node_list_path": "1621259.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1621259.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavisolibacterTropicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavisolibacter tropicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavisolibacterTropicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1492898.protein.sequences.v11.5.fa",
		        "enrichment_path": "1492898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1492898.protein.info.v11.5.txt",
		        "node_list_path": "1492898.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAgalactiaeLmg14747Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae LMG14747 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAgalactiaeLmg14747Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1154860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1154860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1154860.clusters.proteins.v11.5.txt",
		        "sequence_path": "1154860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1154860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1154860.protein.info.v11.5.txt",
		        "node_list_path": "1154860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1154860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParastagonosporaNodorumSn15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parastagonospora nodorum SN15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParastagonosporaNodorumSn15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321614.protein.sequences.v11.5.fa",
		        "enrichment_path": "321614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321614.protein.info.v11.5.txt",
		        "node_list_path": "321614.protein.complete.v11.5.txt"
		    }
		]
    )()

def NelumboNucifera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nelumbo nucifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NelumboNucifera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4432.protein.sequences.v11.5.fa",
		        "enrichment_path": "4432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4432.protein.info.v11.5.txt",
		        "node_list_path": "4432.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZymomonasMobilisAtcc10988(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zymomonas mobilis ATCC10988 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymomonasMobilisAtcc10988", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "555217.protein.sequences.v11.5.fa",
		        "enrichment_path": "555217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555217.protein.info.v11.5.txt",
		        "node_list_path": "555217.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanogenicArchaeonIso4H5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return methanogenic archaeon ISO4-H5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanogenicArchaeonIso4H5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1495144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1495144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1495144.clusters.proteins.v11.5.txt",
		        "sequence_path": "1495144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495144.protein.info.v11.5.txt",
		        "node_list_path": "1495144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1495144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfuricurvumKujiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricurvum kujiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricurvumKujiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "709032.protein.sequences.v11.5.fa",
		        "enrichment_path": "709032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709032.protein.info.v11.5.txt",
		        "node_list_path": "709032.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantheraTigrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Panthera tigris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantheraTigrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9694.clusters.proteins.v11.5.txt",
		        "sequence_path": "9694.protein.sequences.v11.5.fa",
		        "enrichment_path": "9694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9694.protein.info.v11.5.txt",
		        "node_list_path": "9694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaSechelliaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila sechellia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaSechelliaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7238.clusters.proteins.v11.5.txt",
		        "sequence_path": "7238.protein.sequences.v11.5.fa",
		        "enrichment_path": "7238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7238.protein.info.v11.5.txt",
		        "node_list_path": "7238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpYr568(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. YR568 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpYr568", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855301.protein.info.v11.5.txt",
		        "node_list_path": "1855301.protein.complete.v11.5.txt"
		    }
		]
    )()

def PediococcusAcidilacticiDsm20284(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus acidilactici DSM20284 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusAcidilacticiDsm20284", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "862514.protein.sequences.v11.5.fa",
		        "enrichment_path": "862514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862514.protein.info.v11.5.txt",
		        "node_list_path": "862514.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBaumannii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBaumannii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "470.protein.sequences.v11.5.fa",
		        "enrichment_path": "470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "470.protein.info.v11.5.txt",
		        "node_list_path": "470.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSp6357Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. 63-57 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSp6357Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895751.protein.info.v11.5.txt",
		        "node_list_path": "1895751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacterRiflensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacter riflensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacterRiflensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735162.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735162.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735162.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735162.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735162.protein.info.v11.5.txt",
		        "node_list_path": "1735162.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735162.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpRitPiECluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. RIT-PI-e Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpRitPiECluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1681197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1681197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1681197.clusters.proteins.v11.5.txt",
		        "sequence_path": "1681197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1681197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1681197.protein.info.v11.5.txt",
		        "node_list_path": "1681197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1681197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaSpA12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. A12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSpA12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217052.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217052.protein.info.v11.5.txt",
		        "node_list_path": "1217052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumMalmoense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium malmoense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumMalmoense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780.protein.info.v11.5.txt",
		        "node_list_path": "1780.protein.complete.v11.5.txt"
		    }
		]
    )()

def NostocSpPcc7524(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7524 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocSpPcc7524", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28072.protein.sequences.v11.5.fa",
		        "enrichment_path": "28072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28072.protein.info.v11.5.txt",
		        "node_list_path": "28072.protein.complete.v11.5.txt"
		    }
		]
    )()

def DiplorickettsiaMassiliensis20b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Diplorickettsia massiliensis 20B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiplorickettsiaMassiliensis20b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1156986.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156986.protein.info.v11.5.txt",
		        "node_list_path": "1156986.protein.complete.v11.5.txt"
		    }
		]
    )()

def GillisiaLimnaea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gillisia limnaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GillisiaLimnaea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "865937.protein.sequences.v11.5.fa",
		        "enrichment_path": "865937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "865937.protein.info.v11.5.txt",
		        "node_list_path": "865937.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumRedseaS34B6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium REDSEA-S34_B6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumRedseaS34B6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811624.protein.info.v11.5.txt",
		        "node_list_path": "1811624.protein.complete.v11.5.txt"
		    }
		]
    )()

def CommensalibacterIntestiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Commensalibacter intestini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CommensalibacterIntestiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1088868.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1088868.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1088868.clusters.proteins.v11.5.txt",
		        "sequence_path": "1088868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1088868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1088868.protein.info.v11.5.txt",
		        "node_list_path": "1088868.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1088868.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaOklahomensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia oklahomensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaOklahomensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "342113.protein.sequences.v11.5.fa",
		        "enrichment_path": "342113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342113.protein.info.v11.5.txt",
		        "node_list_path": "342113.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifoxya2Full479Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYA2_FULL_47_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxya2Full479Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797995.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797995.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797995.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797995.protein.info.v11.5.txt",
		        "node_list_path": "1797995.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797995.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumViciaeGb30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae GB30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumViciaeGb30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041142.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041142.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041142.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041142.protein.info.v11.5.txt",
		        "node_list_path": "1041142.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041142.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAkl19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. AKL19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAkl19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1266914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266914.protein.info.v11.5.txt",
		        "node_list_path": "1266914.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaCaviae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella caviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaCaviae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34060.protein.sequences.v11.5.fa",
		        "enrichment_path": "34060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34060.protein.info.v11.5.txt",
		        "node_list_path": "34060.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusIndolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus indolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusIndolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "997350.clusters.info.v11.5.txt",
		        "cluster_tree_path": "997350.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "997350.clusters.proteins.v11.5.txt",
		        "sequence_path": "997350.protein.sequences.v11.5.fa",
		        "enrichment_path": "997350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997350.protein.info.v11.5.txt",
		        "node_list_path": "997350.cluster.nodes.v11.5.txt",
		        "edge_list_path": "997350.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumViridifuturiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium viridifuturi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumViridifuturiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1654716.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1654716.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1654716.clusters.proteins.v11.5.txt",
		        "sequence_path": "1654716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1654716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1654716.protein.info.v11.5.txt",
		        "node_list_path": "1654716.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1654716.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaWaltersii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella waltersii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaWaltersii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66969.protein.sequences.v11.5.fa",
		        "enrichment_path": "66969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66969.protein.info.v11.5.txt",
		        "node_list_path": "66969.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusPuniceusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus puniceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusPuniceusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1182568.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1182568.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1182568.clusters.proteins.v11.5.txt",
		        "sequence_path": "1182568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182568.protein.info.v11.5.txt",
		        "node_list_path": "1182568.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1182568.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TheionarchaeaArchaeonDg701Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Theionarchaea archaeon DG-70-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheionarchaeaArchaeonDg701Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803814.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803814.protein.info.v11.5.txt",
		        "node_list_path": "1803814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusCohnii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus cohnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusCohnii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29382.protein.sequences.v11.5.fa",
		        "enrichment_path": "29382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29382.protein.info.v11.5.txt",
		        "node_list_path": "29382.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyroidesPhaeus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myroides phaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyroidesPhaeus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "702745.protein.sequences.v11.5.fa",
		        "enrichment_path": "702745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702745.protein.info.v11.5.txt",
		        "node_list_path": "702745.protein.complete.v11.5.txt"
		    }
		]
    )()

def AegilopsTauschii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aegilops tauschii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AegilopsTauschii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37682.protein.sequences.v11.5.fa",
		        "enrichment_path": "37682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37682.protein.info.v11.5.txt",
		        "node_list_path": "37682.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacterium9401234Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9401234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacterium9401234Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "938288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "938288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "938288.clusters.proteins.v11.5.txt",
		        "sequence_path": "938288.protein.sequences.v11.5.fa",
		        "enrichment_path": "938288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938288.protein.info.v11.5.txt",
		        "node_list_path": "938288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "938288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSobrinusDsm20742Atcc33478Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sobrinus DSM 20742 ATCC 33478 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSobrinusDsm20742Atcc33478Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123317.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123317.protein.info.v11.5.txt",
		        "node_list_path": "1123317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusOdoratitofuiDsm19909Jcm15043(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus odoratitofui DSM 19909 JCM 15043 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOdoratitofuiDsm19909Jcm15043", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423776.protein.info.v11.5.txt",
		        "node_list_path": "1423776.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErysipelotrichaceaeBacteriumNyuBlE8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium NYU-BL-E8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelotrichaceaeBacteriumNyuBlE8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1917463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917463.protein.info.v11.5.txt",
		        "node_list_path": "1917463.protein.complete.v11.5.txt"
		    }
		]
    )()

def DothistromaSeptosporumNze10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dothistroma septosporum NZE10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DothistromaSeptosporumNze10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675120.protein.sequences.v11.5.fa",
		        "enrichment_path": "675120.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675120.protein.info.v11.5.txt",
		        "node_list_path": "675120.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonadaceaeBacteriumFc4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium FC4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonadaceaeBacteriumFc4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720317.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720317.protein.info.v11.5.txt",
		        "node_list_path": "1720317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHimb083Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HIMB083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHimb083Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1096769.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1096769.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1096769.clusters.proteins.v11.5.txt",
		        "sequence_path": "1096769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1096769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1096769.protein.info.v11.5.txt",
		        "node_list_path": "1096769.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1096769.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumUrocaniciphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium urocaniciphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumUrocaniciphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1299341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1299341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1299341.clusters.proteins.v11.5.txt",
		        "sequence_path": "1299341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1299341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1299341.protein.info.v11.5.txt",
		        "node_list_path": "1299341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1299341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumMesoamericanum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium mesoamericanum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumMesoamericanum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211777.protein.info.v11.5.txt",
		        "node_list_path": "1211777.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerminiimonasSpCn(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herminiimonas sp. CN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerminiimonasSpCn", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349818.protein.info.v11.5.txt",
		        "node_list_path": "1349818.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumMacuxienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium macuxiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumMacuxienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1755647.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1755647.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1755647.clusters.proteins.v11.5.txt",
		        "sequence_path": "1755647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1755647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1755647.protein.info.v11.5.txt",
		        "node_list_path": "1755647.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1755647.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteibacterSp9143Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter sp. 9143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterSp9143Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500890.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500890.protein.info.v11.5.txt",
		        "node_list_path": "1500890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesTangfeifaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces tangfeifanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesTangfeifaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1912795.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1912795.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1912795.clusters.proteins.v11.5.txt",
		        "sequence_path": "1912795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912795.protein.info.v11.5.txt",
		        "node_list_path": "1912795.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1912795.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OryzaSativaIndicaGroup(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Indica Group graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaSativaIndicaGroup", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39946.protein.sequences.v11.5.fa",
		        "enrichment_path": "39946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39946.protein.info.v11.5.txt",
		        "node_list_path": "39946.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpLeaf334Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Leaf334 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpLeaf334Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736339.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736339.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736339.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736339.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736339.protein.info.v11.5.txt",
		        "node_list_path": "1736339.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736339.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusRhamnosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rhamnosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusRhamnosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "568703.clusters.info.v11.5.txt",
		        "cluster_tree_path": "568703.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "568703.clusters.proteins.v11.5.txt",
		        "sequence_path": "568703.protein.sequences.v11.5.fa",
		        "enrichment_path": "568703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568703.protein.info.v11.5.txt",
		        "node_list_path": "568703.cluster.nodes.v11.5.txt",
		        "edge_list_path": "568703.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesParvulus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces parvulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesParvulus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "146923.protein.sequences.v11.5.fa",
		        "enrichment_path": "146923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146923.protein.info.v11.5.txt",
		        "node_list_path": "146923.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlF6676Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL F-6676 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlF6676Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463878.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463878.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463878.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463878.protein.info.v11.5.txt",
		        "node_list_path": "1463878.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463878.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag343(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:343 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag343", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262796.protein.info.v11.5.txt",
		        "node_list_path": "1262796.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium4146Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 41-46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium4146Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895922.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895922.protein.info.v11.5.txt",
		        "node_list_path": "1895922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RasamsoniaEmersoniiCbs39364Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rasamsonia emersonii CBS 393.64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RasamsoniaEmersoniiCbs39364Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408163.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408163.protein.info.v11.5.txt",
		        "node_list_path": "1408163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyalangiumMinutum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyalangium minutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyalangiumMinutum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "394096.protein.sequences.v11.5.fa",
		        "enrichment_path": "394096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394096.protein.info.v11.5.txt",
		        "node_list_path": "394096.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpSrsW22016(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. SRS-W-2-2016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpSrsW22016", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926878.protein.info.v11.5.txt",
		        "node_list_path": "1926878.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaQueenslandensisAustNh15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella queenslandensis AUST/NH15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaQueenslandensisAustNh15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1221525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1221525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1221525.clusters.proteins.v11.5.txt",
		        "sequence_path": "1221525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1221525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1221525.protein.info.v11.5.txt",
		        "node_list_path": "1221525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1221525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaPsittaci6bc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia psittaci 6BC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaPsittaci6bc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "331636.protein.sequences.v11.5.fa",
		        "enrichment_path": "331636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331636.protein.info.v11.5.txt",
		        "node_list_path": "331636.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpBlattaOrientalisStrTarazonaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. (Blatta orientalis) str. Tarazona Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpBlattaOrientalisStrTarazonaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1072467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1072467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1072467.clusters.proteins.v11.5.txt",
		        "sequence_path": "1072467.protein.sequences.v11.5.fa",
		        "enrichment_path": "1072467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1072467.protein.info.v11.5.txt",
		        "node_list_path": "1072467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1072467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusParasanguinisAtcc903Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis ATCC903 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusParasanguinisAtcc903Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888048.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888048.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888048.clusters.proteins.v11.5.txt",
		        "sequence_path": "888048.protein.sequences.v11.5.fa",
		        "enrichment_path": "888048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888048.protein.info.v11.5.txt",
		        "node_list_path": "888048.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888048.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRbg164224(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_42_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164224", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802485.protein.info.v11.5.txt",
		        "node_list_path": "1802485.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb241528o2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241528O2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb241528o2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1471459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1471459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1471459.clusters.proteins.v11.5.txt",
		        "sequence_path": "1471459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471459.protein.info.v11.5.txt",
		        "node_list_path": "1471459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1471459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeonGw2011Ar15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return archaeon GW2011_AR15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeonGw2011Ar15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1579373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1579373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1579373.clusters.proteins.v11.5.txt",
		        "sequence_path": "1579373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579373.protein.info.v11.5.txt",
		        "node_list_path": "1579373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1579373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasMobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasMobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "51642.protein.sequences.v11.5.fa",
		        "enrichment_path": "51642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51642.protein.info.v11.5.txt",
		        "node_list_path": "51642.protein.complete.v11.5.txt"
		    }
		]
    )()

def TessaracoccusFlavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus flavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusFlavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1610493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1610493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1610493.protein.info.v11.5.txt",
		        "node_list_path": "1610493.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusMannitolivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus mannitolivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusMannitolivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120965.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120965.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120965.protein.info.v11.5.txt",
		        "node_list_path": "1120965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg134915Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_49_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg134915Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797827.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797827.protein.info.v11.5.txt",
		        "node_list_path": "1797827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRbg165211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_52_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg165211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798374.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798374.protein.info.v11.5.txt",
		        "node_list_path": "1798374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MustelaPutorius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mustela putorius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MustelaPutorius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9668.protein.sequences.v11.5.fa",
		        "enrichment_path": "9668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9668.protein.info.v11.5.txt",
		        "node_list_path": "9668.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaBalticaOs155(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella baltica OS155 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaBalticaOs155", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "325240.protein.sequences.v11.5.fa",
		        "enrichment_path": "325240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "325240.protein.info.v11.5.txt",
		        "node_list_path": "325240.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterSpCag977Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter sp. CAG:977 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterSpCag977Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262685.protein.info.v11.5.txt",
		        "node_list_path": "1262685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosospiraSpNsp14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraSpNsp14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855333.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855333.protein.info.v11.5.txt",
		        "node_list_path": "1855333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterEnclensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter enclensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterEnclensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "993070.clusters.info.v11.5.txt",
		        "cluster_tree_path": "993070.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "993070.clusters.proteins.v11.5.txt",
		        "sequence_path": "993070.protein.sequences.v11.5.fa",
		        "enrichment_path": "993070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "993070.protein.info.v11.5.txt",
		        "node_list_path": "993070.cluster.nodes.v11.5.txt",
		        "edge_list_path": "993070.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HordeumVulgareSubspVulgareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hordeum vulgare subsp. vulgare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HordeumVulgareSubspVulgareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "112509.clusters.info.v11.5.txt",
		        "cluster_tree_path": "112509.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "112509.clusters.proteins.v11.5.txt",
		        "sequence_path": "112509.protein.sequences.v11.5.fa",
		        "enrichment_path": "112509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112509.protein.info.v11.5.txt",
		        "node_list_path": "112509.cluster.nodes.v11.5.txt",
		        "edge_list_path": "112509.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PteropusVampyrusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pteropus vampyrus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PteropusVampyrusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "132908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "132908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "132908.clusters.proteins.v11.5.txt",
		        "sequence_path": "132908.protein.sequences.v11.5.fa",
		        "enrichment_path": "132908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "132908.protein.info.v11.5.txt",
		        "node_list_path": "132908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "132908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAciduriciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acidurici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAciduriciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1128398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1128398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1128398.clusters.proteins.v11.5.txt",
		        "sequence_path": "1128398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128398.protein.info.v11.5.txt",
		        "node_list_path": "1128398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1128398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquincolaTertiaricarbonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquincola tertiaricarbonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquincolaTertiaricarbonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391953.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391953.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391953.clusters.proteins.v11.5.txt",
		        "sequence_path": "391953.protein.sequences.v11.5.fa",
		        "enrichment_path": "391953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391953.protein.info.v11.5.txt",
		        "node_list_path": "391953.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391953.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpKordi52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpKordi52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585425.clusters.proteins.v11.5.txt",
		        "sequence_path": "585425.protein.sequences.v11.5.fa",
		        "enrichment_path": "585425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585425.protein.info.v11.5.txt",
		        "node_list_path": "585425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSabulitectumSilens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sabulitectum silens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSabulitectumSilens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1902299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1902299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1902299.protein.info.v11.5.txt",
		        "node_list_path": "1902299.protein.complete.v11.5.txt"
		    }
		]
    )()

def LewinellaCohaerens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lewinella cohaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LewinellaCohaerens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122176.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122176.protein.info.v11.5.txt",
		        "node_list_path": "1122176.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpCip562(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP56.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpCip562", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144672.protein.info.v11.5.txt",
		        "node_list_path": "1144672.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaOroxyli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia oroxyli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaOroxyli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "366584.protein.sequences.v11.5.fa",
		        "enrichment_path": "366584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366584.protein.info.v11.5.txt",
		        "node_list_path": "366584.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaColumbinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma columbinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaColumbinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1037410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1037410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1037410.protein.info.v11.5.txt",
		        "node_list_path": "1037410.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumS5A14a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium S5-A14a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumS5A14a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230734.protein.info.v11.5.txt",
		        "node_list_path": "1230734.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSabulitectumSilensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sabulitectum silens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSabulitectumSilensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1902299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1902299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1902299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1902299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1902299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1902299.protein.info.v11.5.txt",
		        "node_list_path": "1902299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1902299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_45_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802706.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802706.protein.info.v11.5.txt",
		        "node_list_path": "1802706.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpAe3005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. AE3005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpAe3005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1485543.protein.sequences.v11.5.fa",
		        "enrichment_path": "1485543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1485543.protein.info.v11.5.txt",
		        "node_list_path": "1485543.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParasponiaAndersonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parasponia andersonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParasponiaAndersonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3476.protein.sequences.v11.5.fa",
		        "enrichment_path": "3476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3476.protein.info.v11.5.txt",
		        "node_list_path": "3476.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSp32352Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 32352 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSp32352Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1969111.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1969111.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1969111.clusters.proteins.v11.5.txt",
		        "sequence_path": "1969111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1969111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1969111.protein.info.v11.5.txt",
		        "node_list_path": "1969111.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1969111.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf412Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf412Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736370.protein.info.v11.5.txt",
		        "node_list_path": "1736370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesMangrovisoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces mangrovisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesMangrovisoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1428628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1428628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1428628.protein.info.v11.5.txt",
		        "node_list_path": "1428628.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf407Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf407 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf407Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736369.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736369.protein.info.v11.5.txt",
		        "node_list_path": "1736369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastomycesPercursusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces percursus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomycesPercursusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658174.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658174.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658174.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658174.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658174.protein.info.v11.5.txt",
		        "node_list_path": "1658174.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658174.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfobacillusAcidophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfobacillus acidophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfobacillusAcidophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1051632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1051632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1051632.clusters.proteins.v11.5.txt",
		        "sequence_path": "1051632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051632.protein.info.v11.5.txt",
		        "node_list_path": "1051632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1051632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMuproteobacteriaBacteriumRifcsplowo201Full6018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RIFCSPLOWO2_01_FULL_60_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRifcsplowo201Full6018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817768.protein.info.v11.5.txt",
		        "node_list_path": "1817768.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpTs2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. TS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpTs2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1450694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450694.protein.info.v11.5.txt",
		        "node_list_path": "1450694.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRaymondbacteriaBacteriumRifoxyc2Full5021Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Raymondbacteria bacterium RIFOXYC2_FULL_50_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRaymondbacteriaBacteriumRifoxyc2Full5021Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817889.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817889.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817889.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817889.protein.info.v11.5.txt",
		        "node_list_path": "1817889.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817889.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RudaeaCellulosilyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rudaea cellulosilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RudaeaCellulosilyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123073.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123073.protein.info.v11.5.txt",
		        "node_list_path": "1123073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NecropsobacterMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Necropsobacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NecropsobacterMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1400001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1400001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1400001.clusters.proteins.v11.5.txt",
		        "sequence_path": "1400001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400001.protein.info.v11.5.txt",
		        "node_list_path": "1400001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1400001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexusAggregans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexus aggregans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexusAggregans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326427.protein.sequences.v11.5.fa",
		        "enrichment_path": "326427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326427.protein.info.v11.5.txt",
		        "node_list_path": "326427.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumStBin15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium ST_bin15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumStBin15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1978763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1978763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1978763.clusters.proteins.v11.5.txt",
		        "sequence_path": "1978763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978763.protein.info.v11.5.txt",
		        "node_list_path": "1978763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1978763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123307.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123307.protein.info.v11.5.txt",
		        "node_list_path": "1123307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaQuintanaRm11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella quintana RM-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaQuintanaRm11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1225179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225179.protein.info.v11.5.txt",
		        "node_list_path": "1225179.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlloactinosynnemaIranicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alloactinosynnema iranicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloactinosynnemaIranicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1271860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1271860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1271860.protein.info.v11.5.txt",
		        "node_list_path": "1271860.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpBJedd(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. B-jedd graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpBJedd", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1476857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1476857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1476857.protein.info.v11.5.txt",
		        "node_list_path": "1476857.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpGa2829Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-2829 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpGa2829Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1772283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1772283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1772283.clusters.proteins.v11.5.txt",
		        "sequence_path": "1772283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772283.protein.info.v11.5.txt",
		        "node_list_path": "1772283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1772283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasNitroreducensTx1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens TX1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasNitroreducensTx1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1226994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1226994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1226994.protein.info.v11.5.txt",
		        "node_list_path": "1226994.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerobaculumHydrogeniformans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobaculum hydrogeniformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobaculumHydrogeniformans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "592015.protein.sequences.v11.5.fa",
		        "enrichment_path": "592015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592015.protein.info.v11.5.txt",
		        "node_list_path": "592015.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3837Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYB1_FULL_38_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3837Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802224.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802224.protein.info.v11.5.txt",
		        "node_list_path": "1802224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharopolysporaShandongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharopolyspora shandongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharopolysporaShandongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "418495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "418495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "418495.clusters.proteins.v11.5.txt",
		        "sequence_path": "418495.protein.sequences.v11.5.fa",
		        "enrichment_path": "418495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "418495.protein.info.v11.5.txt",
		        "node_list_path": "418495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "418495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNbrc110611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NBRC 110611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNbrc110611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1621259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1621259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1621259.protein.info.v11.5.txt",
		        "node_list_path": "1621259.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumCoryneforme(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium coryneforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumCoryneforme", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1687.protein.sequences.v11.5.fa",
		        "enrichment_path": "1687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1687.protein.info.v11.5.txt",
		        "node_list_path": "1687.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChroogloeocystisSiderophila52SC1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chroogloeocystis siderophila 5.2 s.c.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChroogloeocystisSiderophila52SC1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "247279.protein.sequences.v11.5.fa",
		        "enrichment_path": "247279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247279.protein.info.v11.5.txt",
		        "node_list_path": "247279.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumRifcsplowo202Full4354Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPLOWO2_02_FULL_43_54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsplowo202Full4354Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797230.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797230.protein.info.v11.5.txt",
		        "node_list_path": "1797230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusEquiDsm15833Jcm10991Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus equi DSM 15833 JCM 10991 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusEquiDsm15833Jcm10991Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423740.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423740.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423740.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423740.protein.info.v11.5.txt",
		        "node_list_path": "1423740.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423740.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolymorphumGilvum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polymorphum gilvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolymorphumGilvum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "991905.protein.sequences.v11.5.fa",
		        "enrichment_path": "991905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "991905.protein.info.v11.5.txt",
		        "node_list_path": "991905.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRbg167010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RBG_16_70_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRbg167010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797174.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797174.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797174.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797174.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797174.protein.info.v11.5.txt",
		        "node_list_path": "1797174.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797174.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaGamsii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma gamsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaGamsii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398673.protein.sequences.v11.5.fa",
		        "enrichment_path": "398673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398673.protein.info.v11.5.txt",
		        "node_list_path": "398673.protein.complete.v11.5.txt"
		    }
		]
    )()

def TatumellaMorbirosei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tatumella morbirosei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TatumellaMorbirosei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "642227.protein.sequences.v11.5.fa",
		        "enrichment_path": "642227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "642227.protein.info.v11.5.txt",
		        "node_list_path": "642227.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumArenae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium arenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumArenae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1856850.protein.sequences.v11.5.fa",
		        "enrichment_path": "1856850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1856850.protein.info.v11.5.txt",
		        "node_list_path": "1856850.protein.complete.v11.5.txt"
		    }
		]
    )()

def SanguibacterGelidistatuariaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter gelidistatuariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SanguibacterGelidistatuariaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1814289.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1814289.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1814289.clusters.proteins.v11.5.txt",
		        "sequence_path": "1814289.protein.sequences.v11.5.fa",
		        "enrichment_path": "1814289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1814289.protein.info.v11.5.txt",
		        "node_list_path": "1814289.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1814289.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaRobiniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea robiniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaRobiniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1036780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036780.protein.info.v11.5.txt",
		        "node_list_path": "1036780.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychroserpensBurtonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens burtonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroserpensBurtonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123037.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123037.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123037.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123037.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123037.protein.info.v11.5.txt",
		        "node_list_path": "1123037.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123037.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumGonidiaformans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium gonidiaformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumGonidiaformans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469615.protein.sequences.v11.5.fa",
		        "enrichment_path": "469615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469615.protein.info.v11.5.txt",
		        "node_list_path": "469615.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaAnthophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea anthophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaAnthophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "470931.clusters.info.v11.5.txt",
		        "cluster_tree_path": "470931.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "470931.clusters.proteins.v11.5.txt",
		        "sequence_path": "470931.protein.sequences.v11.5.fa",
		        "enrichment_path": "470931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "470931.protein.info.v11.5.txt",
		        "node_list_path": "470931.cluster.nodes.v11.5.txt",
		        "edge_list_path": "470931.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporocytophagaMyxococcoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporocytophaga myxococcoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporocytophagaMyxococcoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "153721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "153721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "153721.clusters.proteins.v11.5.txt",
		        "sequence_path": "153721.protein.sequences.v11.5.fa",
		        "enrichment_path": "153721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "153721.protein.info.v11.5.txt",
		        "node_list_path": "153721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "153721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoffeaCanephora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coffea canephora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoffeaCanephora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "49390.protein.sequences.v11.5.fa",
		        "enrichment_path": "49390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "49390.protein.info.v11.5.txt",
		        "node_list_path": "49390.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpSfb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. SFB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpSfb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805634.protein.info.v11.5.txt",
		        "node_list_path": "1805634.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermothelomycesThermophilusAtcc42464Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermothelomyces thermophilus ATCC 42464 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermothelomycesThermophilusAtcc42464Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573729.clusters.proteins.v11.5.txt",
		        "sequence_path": "573729.protein.sequences.v11.5.fa",
		        "enrichment_path": "573729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573729.protein.info.v11.5.txt",
		        "node_list_path": "573729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizopusStolonifer(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus stolonifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopusStolonifer", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4846.protein.sequences.v11.5.fa",
		        "enrichment_path": "4846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4846.protein.info.v11.5.txt",
		        "node_list_path": "4846.protein.complete.v11.5.txt"
		    }
		]
    )()

def EdwardsiellaTardaAtcc15947(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Edwardsiella tarda ATCC15947 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EdwardsiellaTardaAtcc15947", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "667121.protein.sequences.v11.5.fa",
		        "enrichment_path": "667121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667121.protein.info.v11.5.txt",
		        "node_list_path": "667121.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichophytonRubrumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton rubrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichophytonRubrumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5551.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5551.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5551.clusters.proteins.v11.5.txt",
		        "sequence_path": "5551.protein.sequences.v11.5.fa",
		        "enrichment_path": "5551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5551.protein.info.v11.5.txt",
		        "node_list_path": "5551.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5551.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZonotrichiaAlbicollis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zonotrichia albicollis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZonotrichiaAlbicollis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44394.protein.sequences.v11.5.fa",
		        "enrichment_path": "44394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44394.protein.info.v11.5.txt",
		        "node_list_path": "44394.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacaBermudensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibaca bermudensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacaBermudensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314265.protein.sequences.v11.5.fa",
		        "enrichment_path": "314265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314265.protein.info.v11.5.txt",
		        "node_list_path": "314265.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiaBacteriumScgcAaa298D23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium SCGC AAA298-D23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiaBacteriumScgcAaa298D23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "939857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "939857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "939857.clusters.proteins.v11.5.txt",
		        "sequence_path": "939857.protein.sequences.v11.5.fa",
		        "enrichment_path": "939857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939857.protein.info.v11.5.txt",
		        "node_list_path": "939857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "939857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpJcm18996(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 18996 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpJcm18996", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1301085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1301085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1301085.protein.info.v11.5.txt",
		        "node_list_path": "1301085.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacterium6e(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium 6E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacterium6e", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1688776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1688776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1688776.protein.info.v11.5.txt",
		        "node_list_path": "1688776.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaylandiaZebraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maylandia zebra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaylandiaZebraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "106582.clusters.info.v11.5.txt",
		        "cluster_tree_path": "106582.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "106582.clusters.proteins.v11.5.txt",
		        "sequence_path": "106582.protein.sequences.v11.5.fa",
		        "enrichment_path": "106582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106582.protein.info.v11.5.txt",
		        "node_list_path": "106582.cluster.nodes.v11.5.txt",
		        "edge_list_path": "106582.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSpHgb0015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. HGB0015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSpHgb0015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1078083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078083.protein.info.v11.5.txt",
		        "node_list_path": "1078083.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCampbellbacteriaBacteriumRifoxyc2Full3525Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFOXYC2_FULL_35_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifoxyc2Full3525Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797582.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797582.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797582.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797582.protein.info.v11.5.txt",
		        "node_list_path": "1797582.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797582.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoraliomargaritaSpCag312Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coraliomargarita sp. CAG:312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoraliomargaritaSpCag312Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262865.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262865.protein.info.v11.5.txt",
		        "node_list_path": "1262865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedClostridiaBacteriumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Clostridia bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedClostridiaBacteriumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "244328.clusters.info.v11.5.txt",
		        "cluster_tree_path": "244328.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "244328.clusters.proteins.v11.5.txt",
		        "sequence_path": "244328.protein.sequences.v11.5.fa",
		        "enrichment_path": "244328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244328.protein.info.v11.5.txt",
		        "node_list_path": "244328.cluster.nodes.v11.5.txt",
		        "edge_list_path": "244328.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnoanaerobaculumSaburreumF0468(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum F0468 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoanaerobaculumSaburreumF0468", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095750.protein.info.v11.5.txt",
		        "node_list_path": "1095750.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasXinjiangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasXinjiangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "487184.protein.sequences.v11.5.fa",
		        "enrichment_path": "487184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487184.protein.info.v11.5.txt",
		        "node_list_path": "487184.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumRifcsplowo202Full4354(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPLOWO2_02_FULL_43_54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsplowo202Full4354", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797230.protein.info.v11.5.txt",
		        "node_list_path": "1797230.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaPsychrophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaPsychrophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1476.protein.info.v11.5.txt",
		        "node_list_path": "1476.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpKle1755(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. KLE1755 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpKle1755", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1226325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1226325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1226325.protein.info.v11.5.txt",
		        "node_list_path": "1226325.protein.complete.v11.5.txt"
		    }
		]
    )()

def SetosphaeriaTurcica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Setosphaeria turcica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SetosphaeriaTurcica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93612.protein.sequences.v11.5.fa",
		        "enrichment_path": "93612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93612.protein.info.v11.5.txt",
		        "node_list_path": "93612.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpYi23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. YI23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpYi23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1097668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1097668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1097668.clusters.proteins.v11.5.txt",
		        "sequence_path": "1097668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1097668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1097668.protein.info.v11.5.txt",
		        "node_list_path": "1097668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1097668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpS62(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. S-6-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpS62", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1931241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1931241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1931241.protein.info.v11.5.txt",
		        "node_list_path": "1931241.protein.complete.v11.5.txt"
		    }
		]
    )()

def DethiosulfovibrioSalsuginis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dethiosulfovibrio salsuginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DethiosulfovibrioSalsuginis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "561720.protein.sequences.v11.5.fa",
		        "enrichment_path": "561720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561720.protein.info.v11.5.txt",
		        "node_list_path": "561720.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuaniaAlbidiflavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruania albidiflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuaniaAlbidiflavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123065.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123065.protein.info.v11.5.txt",
		        "node_list_path": "1123065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquisalimonasAsiatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquisalimonas asiatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquisalimonasAsiatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "406100.protein.sequences.v11.5.fa",
		        "enrichment_path": "406100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406100.protein.info.v11.5.txt",
		        "node_list_path": "406100.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusSpJcm18860Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus sp. JCM 18860 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusSpJcm18860Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1306159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1306159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1306159.clusters.proteins.v11.5.txt",
		        "sequence_path": "1306159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306159.protein.info.v11.5.txt",
		        "node_list_path": "1306159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1306159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulforhopalusSingaporensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulforhopalus singaporensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulforhopalusSingaporensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "91360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "91360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "91360.clusters.proteins.v11.5.txt",
		        "sequence_path": "91360.protein.sequences.v11.5.fa",
		        "enrichment_path": "91360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91360.protein.info.v11.5.txt",
		        "node_list_path": "91360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "91360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPortieraAleyrodidarumBtBHrs(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portiera aleyrodidarum BT-B-HRs graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPortieraAleyrodidarumBtBHrs", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206109.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206109.protein.info.v11.5.txt",
		        "node_list_path": "1206109.protein.complete.v11.5.txt"
		    }
		]
    )()

def GilvimarinusChinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gilvimarinus chinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilvimarinusChinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121921.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121921.protein.info.v11.5.txt",
		        "node_list_path": "1121921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopirellulaBaltica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopirellula baltica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopirellulaBaltica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243090.protein.sequences.v11.5.fa",
		        "enrichment_path": "243090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243090.protein.info.v11.5.txt",
		        "node_list_path": "243090.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolitaleaCanadensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solitalea canadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolitaleaCanadensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "929556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "929556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "929556.clusters.proteins.v11.5.txt",
		        "sequence_path": "929556.protein.sequences.v11.5.fa",
		        "enrichment_path": "929556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929556.protein.info.v11.5.txt",
		        "node_list_path": "929556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "929556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaloramatorSpAld01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caloramator sp. ALD01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloramatorSpAld01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1031288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1031288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1031288.clusters.proteins.v11.5.txt",
		        "sequence_path": "1031288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1031288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1031288.protein.info.v11.5.txt",
		        "node_list_path": "1031288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1031288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735683.protein.info.v11.5.txt",
		        "node_list_path": "1735683.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumArachidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium arachidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumArachidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1416778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1416778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1416778.clusters.proteins.v11.5.txt",
		        "sequence_path": "1416778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416778.protein.info.v11.5.txt",
		        "node_list_path": "1416778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1416778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobacillusDevorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacillus devorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobacillusDevorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "279813.protein.sequences.v11.5.fa",
		        "enrichment_path": "279813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279813.protein.info.v11.5.txt",
		        "node_list_path": "279813.protein.complete.v11.5.txt"
		    }
		]
    )()

def CardiobacteriumHominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cardiobacterium hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CardiobacteriumHominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2718.protein.sequences.v11.5.fa",
		        "enrichment_path": "2718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2718.protein.info.v11.5.txt",
		        "node_list_path": "2718.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteiniphilumSpEbm39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteiniphilum sp. EBM-39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteiniphilumSpEbm39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1918497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918497.protein.info.v11.5.txt",
		        "node_list_path": "1918497.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumCoprostanoligenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium coprostanoligenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumCoprostanoligenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290054.clusters.proteins.v11.5.txt",
		        "sequence_path": "290054.protein.sequences.v11.5.fa",
		        "enrichment_path": "290054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290054.protein.info.v11.5.txt",
		        "node_list_path": "290054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MooreaProducensPal815081(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moorea producens PAL-8-15-08-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MooreaProducensPal815081", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1458985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458985.protein.info.v11.5.txt",
		        "node_list_path": "1458985.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrococcusHorikoshii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus horikoshii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusHorikoshii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "70601.protein.sequences.v11.5.fa",
		        "enrichment_path": "70601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "70601.protein.info.v11.5.txt",
		        "node_list_path": "70601.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpF0429(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0429 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpF0429", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1127695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127695.protein.info.v11.5.txt",
		        "node_list_path": "1127695.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerovibrioSpJc8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerovibrio sp. JC8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerovibrioSpJc8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1240085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1240085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1240085.protein.info.v11.5.txt",
		        "node_list_path": "1240085.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaTasmaniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia tasmaniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaTasmaniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "465817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "465817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "465817.clusters.proteins.v11.5.txt",
		        "sequence_path": "465817.protein.sequences.v11.5.fa",
		        "enrichment_path": "465817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "465817.protein.info.v11.5.txt",
		        "node_list_path": "465817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "465817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasIndicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasIndicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "428993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "428993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "428993.clusters.proteins.v11.5.txt",
		        "sequence_path": "428993.protein.sequences.v11.5.fa",
		        "enrichment_path": "428993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428993.protein.info.v11.5.txt",
		        "node_list_path": "428993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "428993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesVietnamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces vietnamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesVietnamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "362257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "362257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "362257.clusters.proteins.v11.5.txt",
		        "sequence_path": "362257.protein.sequences.v11.5.fa",
		        "enrichment_path": "362257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362257.protein.info.v11.5.txt",
		        "node_list_path": "362257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "362257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MegasphaeraSpMjr8396c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. MJR8396C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraSpMjr8396c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1603888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603888.protein.info.v11.5.txt",
		        "node_list_path": "1603888.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpM143(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. M143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpM143", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "563037.protein.sequences.v11.5.fa",
		        "enrichment_path": "563037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563037.protein.info.v11.5.txt",
		        "node_list_path": "563037.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc13521(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_35_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc13521", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618892.protein.info.v11.5.txt",
		        "node_list_path": "1618892.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonasAquaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasAquaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219031.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219031.protein.info.v11.5.txt",
		        "node_list_path": "1219031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExophialaMesophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exophiala mesophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaMesophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "212818.protein.sequences.v11.5.fa",
		        "enrichment_path": "212818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "212818.protein.info.v11.5.txt",
		        "node_list_path": "212818.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumTsurumiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium tsurumiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumTsurumiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "356829.protein.sequences.v11.5.fa",
		        "enrichment_path": "356829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "356829.protein.info.v11.5.txt",
		        "node_list_path": "356829.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "455632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "455632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "455632.clusters.proteins.v11.5.txt",
		        "sequence_path": "455632.protein.sequences.v11.5.fa",
		        "enrichment_path": "455632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "455632.protein.info.v11.5.txt",
		        "node_list_path": "455632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "455632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaSpFsc1006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella sp. FSC1006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaSpFsc1006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1547445.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1547445.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1547445.clusters.proteins.v11.5.txt",
		        "sequence_path": "1547445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1547445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1547445.protein.info.v11.5.txt",
		        "node_list_path": "1547445.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1547445.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudorhodoplanesSinuspersici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodoplanes sinuspersici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodoplanesSinuspersici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235591.protein.info.v11.5.txt",
		        "node_list_path": "1235591.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalegentibacterMishustinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter mishustinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterMishustinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "270918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "270918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "270918.clusters.proteins.v11.5.txt",
		        "sequence_path": "270918.protein.sequences.v11.5.fa",
		        "enrichment_path": "270918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "270918.protein.info.v11.5.txt",
		        "node_list_path": "270918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "270918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClavibacterMichiganensisSubspTessellarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis subsp. tessellarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavibacterMichiganensisSubspTessellarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "31965.protein.sequences.v11.5.fa",
		        "enrichment_path": "31965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31965.protein.info.v11.5.txt",
		        "node_list_path": "31965.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumSalinitoleransStrHayward0363(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium salinitolerans str. Hayward 0363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumSalinitoleransStrHayward0363", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1183434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1183434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1183434.protein.info.v11.5.txt",
		        "node_list_path": "1183434.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlareaLozoyensisAtcc20868(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glarea lozoyensis ATCC 20868 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlareaLozoyensisAtcc20868", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1116229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116229.protein.info.v11.5.txt",
		        "node_list_path": "1116229.protein.complete.v11.5.txt"
		    }
		]
    )()

def FomitiporiaMediterraneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fomitiporia mediterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FomitiporiaMediterraneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "208960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "208960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "208960.clusters.proteins.v11.5.txt",
		        "sequence_path": "208960.protein.sequences.v11.5.fa",
		        "enrichment_path": "208960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208960.protein.info.v11.5.txt",
		        "node_list_path": "208960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "208960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FriedmanniomycesEndolithicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Friedmanniomyces endolithicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FriedmanniomycesEndolithicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "329885.clusters.info.v11.5.txt",
		        "cluster_tree_path": "329885.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "329885.clusters.proteins.v11.5.txt",
		        "sequence_path": "329885.protein.sequences.v11.5.fa",
		        "enrichment_path": "329885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "329885.protein.info.v11.5.txt",
		        "node_list_path": "329885.cluster.nodes.v11.5.txt",
		        "edge_list_path": "329885.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidocellaAminolytica101Dsm11237Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidocella aminolytica 101 DSM 11237 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidocellaAminolytica101Dsm11237Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120923.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120923.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120923.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120923.protein.info.v11.5.txt",
		        "node_list_path": "1120923.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120923.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSoliNbrc100801(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas soli NBRC 100801 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSoliNbrc100801", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219055.protein.info.v11.5.txt",
		        "node_list_path": "1219055.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasHalocynthiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas halocynthiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasHalocynthiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121940.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121940.protein.info.v11.5.txt",
		        "node_list_path": "1121940.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpF0442Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0442 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpF0442Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999425.clusters.proteins.v11.5.txt",
		        "sequence_path": "999425.protein.sequences.v11.5.fa",
		        "enrichment_path": "999425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999425.protein.info.v11.5.txt",
		        "node_list_path": "999425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRiesiaPediculischaeffi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia pediculischaeffi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRiesiaPediculischaeffi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "428411.protein.sequences.v11.5.fa",
		        "enrichment_path": "428411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428411.protein.info.v11.5.txt",
		        "node_list_path": "428411.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtopobiumMinutum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium minutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumMinutum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381.protein.info.v11.5.txt",
		        "node_list_path": "1381.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusOshimai(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus oshimai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusOshimai", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "751945.protein.sequences.v11.5.fa",
		        "enrichment_path": "751945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "751945.protein.info.v11.5.txt",
		        "node_list_path": "751945.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaHinzii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella hinzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaHinzii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392838.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392838.protein.info.v11.5.txt",
		        "node_list_path": "1392838.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacterium9400853(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9400853 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacterium9400853", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "938278.protein.sequences.v11.5.fa",
		        "enrichment_path": "938278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938278.protein.info.v11.5.txt",
		        "node_list_path": "938278.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpBmg536Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. BMG5.36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpBmg536Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834512.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834512.protein.info.v11.5.txt",
		        "node_list_path": "1834512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpDvCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. DV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpDvCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1844708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1844708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1844708.clusters.proteins.v11.5.txt",
		        "sequence_path": "1844708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1844708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1844708.protein.info.v11.5.txt",
		        "node_list_path": "1844708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1844708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VenustampullaEchinocandica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Venustampulla echinocandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VenustampullaEchinocandica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2656787.protein.sequences.v11.5.fa",
		        "enrichment_path": "2656787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2656787.protein.info.v11.5.txt",
		        "node_list_path": "2656787.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusGlycinifermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus glycinifermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGlycinifermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1664069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1664069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1664069.protein.info.v11.5.txt",
		        "node_list_path": "1664069.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumVerticillioides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium verticillioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumVerticillioides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "117187.protein.sequences.v11.5.fa",
		        "enrichment_path": "117187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "117187.protein.info.v11.5.txt",
		        "node_list_path": "117187.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusDesertiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus deserti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusDesertiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546414.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546414.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546414.clusters.proteins.v11.5.txt",
		        "sequence_path": "546414.protein.sequences.v11.5.fa",
		        "enrichment_path": "546414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546414.protein.info.v11.5.txt",
		        "node_list_path": "546414.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546414.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaBombi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella bombi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaBombi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1505725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505725.protein.info.v11.5.txt",
		        "node_list_path": "1505725.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegasphaeraElsdenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera elsdenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraElsdenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1064535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1064535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1064535.protein.info.v11.5.txt",
		        "node_list_path": "1064535.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAlbusAlbusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Streptomyces albus albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAlbusAlbusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67257.clusters.info.v11.0.txt",
		        "cluster_tree_path": "67257.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "67257.clusters.proteins.v11.0.txt",
		        "sequence_path": "67257.protein.sequences.v11.0.fa",
		        "enrichment_path": "67257.protein.enrichment.terms.v11.0.txt",
		        "info_path": "67257.protein.info.v11.0.txt",
		        "node_list_path": "67257.cluster.nodes.v11.0.txt",
		        "edge_list_path": "67257.protein.cluster.v11.0.txt"
		    }
		]
    )()

def LactobacillusAcidipiscisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidipiscis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAcidipiscisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "89059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "89059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "89059.clusters.proteins.v11.5.txt",
		        "sequence_path": "89059.protein.sequences.v11.5.fa",
		        "enrichment_path": "89059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89059.protein.info.v11.5.txt",
		        "node_list_path": "89059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "89059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanospirillumMarisDsm6286Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum maris DSM 6286 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanospirillumMarisDsm6286Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122617.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122617.protein.info.v11.5.txt",
		        "node_list_path": "1122617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterocytozoonHepatopenaeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterocytozoon hepatopenaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterocytozoonHepatopenaeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "646526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "646526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "646526.clusters.proteins.v11.5.txt",
		        "sequence_path": "646526.protein.sequences.v11.5.fa",
		        "enrichment_path": "646526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "646526.protein.info.v11.5.txt",
		        "node_list_path": "646526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "646526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerovibrioLipolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerovibrio lipolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerovibrioLipolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408423.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408423.protein.info.v11.5.txt",
		        "node_list_path": "1408423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterTandoii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter tandoii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterTandoii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "202954.protein.sequences.v11.5.fa",
		        "enrichment_path": "202954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202954.protein.info.v11.5.txt",
		        "node_list_path": "202954.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchangiumGephyra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archangium gephyra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchangiumGephyra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "48.protein.sequences.v11.5.fa",
		        "enrichment_path": "48.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48.protein.info.v11.5.txt",
		        "node_list_path": "48.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylothermusMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylothermus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylothermusMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "399550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "399550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "399550.clusters.proteins.v11.5.txt",
		        "sequence_path": "399550.protein.sequences.v11.5.fa",
		        "enrichment_path": "399550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399550.protein.info.v11.5.txt",
		        "node_list_path": "399550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "399550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCgr1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CGR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCgr1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1696072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1696072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1696072.clusters.proteins.v11.5.txt",
		        "sequence_path": "1696072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1696072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1696072.protein.info.v11.5.txt",
		        "node_list_path": "1696072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1696072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MustelaPutoriusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mustela putorius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MustelaPutoriusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9668.clusters.proteins.v11.5.txt",
		        "sequence_path": "9668.protein.sequences.v11.5.fa",
		        "enrichment_path": "9668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9668.protein.info.v11.5.txt",
		        "node_list_path": "9668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraBorgpeterseniiSerovarHardjo(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii serovar Hardjo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraBorgpeterseniiSerovarHardjo", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "328971.protein.sequences.v11.5.fa",
		        "enrichment_path": "328971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "328971.protein.info.v11.5.txt",
		        "node_list_path": "328971.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotogaMaritimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaMaritimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243274.clusters.proteins.v11.5.txt",
		        "sequence_path": "243274.protein.sequences.v11.5.fa",
		        "enrichment_path": "243274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243274.protein.info.v11.5.txt",
		        "node_list_path": "243274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DactylellinaHaptotyla(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dactylellina haptotyla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DactylellinaHaptotyla", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "430498.protein.sequences.v11.5.fa",
		        "enrichment_path": "430498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "430498.protein.info.v11.5.txt",
		        "node_list_path": "430498.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaOroxyliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia oroxyli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaOroxyliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "366584.clusters.info.v11.5.txt",
		        "cluster_tree_path": "366584.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "366584.clusters.proteins.v11.5.txt",
		        "sequence_path": "366584.protein.sequences.v11.5.fa",
		        "enrichment_path": "366584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366584.protein.info.v11.5.txt",
		        "node_list_path": "366584.cluster.nodes.v11.5.txt",
		        "edge_list_path": "366584.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo202Full6614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_02_FULL_66_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202Full6614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797490.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797490.protein.info.v11.5.txt",
		        "node_list_path": "1797490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioclavaSpF366(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. F36-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaSpF366", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1915316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915316.protein.info.v11.5.txt",
		        "node_list_path": "1915316.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumGraminearum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium graminearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumGraminearum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5518.protein.sequences.v11.5.fa",
		        "enrichment_path": "5518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5518.protein.info.v11.5.txt",
		        "node_list_path": "5518.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcromyrmexEchinatior(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acromyrmex echinatior graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcromyrmexEchinatior", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "103372.protein.sequences.v11.5.fa",
		        "enrichment_path": "103372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103372.protein.info.v11.5.txt",
		        "node_list_path": "103372.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanicoccusSagamiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicoccus sagamiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicoccusSagamiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "716816.protein.sequences.v11.5.fa",
		        "enrichment_path": "716816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "716816.protein.info.v11.5.txt",
		        "node_list_path": "716816.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanospirillaceaeBacteriumAsp1002a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillaceae bacterium ASP10-02a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanospirillaceaeBacteriumAsp1002a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1622229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622229.protein.info.v11.5.txt",
		        "node_list_path": "1622229.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaSpDmeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Dme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaSpDmeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "163164.clusters.info.v11.0.txt",
		        "cluster_tree_path": "163164.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "163164.clusters.proteins.v11.0.txt",
		        "sequence_path": "163164.protein.sequences.v11.0.fa",
		        "enrichment_path": "163164.protein.enrichment.terms.v11.0.txt",
		        "info_path": "163164.protein.info.v11.0.txt",
		        "node_list_path": "163164.cluster.nodes.v11.0.txt",
		        "edge_list_path": "163164.protein.cluster.v11.0.txt"
		    }
		]
    )()

def LimnobacterSpMed105(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnobacter sp. MED105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnobacterSpMed105", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391597.protein.sequences.v11.5.fa",
		        "enrichment_path": "391597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391597.protein.info.v11.5.txt",
		        "node_list_path": "391597.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110055Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110055 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110055Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1570344.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1570344.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1570344.clusters.proteins.v11.5.txt",
		        "sequence_path": "1570344.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570344.protein.info.v11.5.txt",
		        "node_list_path": "1570344.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1570344.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenisporosarcinaSpTg14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenisporosarcina sp. TG14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenisporosarcinaSpTg14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231057.protein.info.v11.5.txt",
		        "node_list_path": "1231057.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterSmithiiAtcc35061(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter smithii ATCC35061 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterSmithiiAtcc35061", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "420247.protein.sequences.v11.5.fa",
		        "enrichment_path": "420247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420247.protein.info.v11.5.txt",
		        "node_list_path": "420247.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesDenticolens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces denticolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesDenticolens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52767.protein.sequences.v11.5.fa",
		        "enrichment_path": "52767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52767.protein.info.v11.5.txt",
		        "node_list_path": "52767.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSuccinicans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium succinicans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSuccinicans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1450525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450525.protein.info.v11.5.txt",
		        "node_list_path": "1450525.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaAcetivoransC2aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina acetivorans C2A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaAcetivoransC2aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "188937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "188937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "188937.clusters.proteins.v11.5.txt",
		        "sequence_path": "188937.protein.sequences.v11.5.fa",
		        "enrichment_path": "188937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188937.protein.info.v11.5.txt",
		        "node_list_path": "188937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "188937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMacauensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus macauensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMacauensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196324.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196324.protein.info.v11.5.txt",
		        "node_list_path": "1196324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpF0263Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0263 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpF0263Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321782.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321782.protein.info.v11.5.txt",
		        "node_list_path": "1321782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrocarboniphagaDaqingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga daqingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrocarboniphagaDaqingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "490188.protein.sequences.v11.5.fa",
		        "enrichment_path": "490188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "490188.protein.info.v11.5.txt",
		        "node_list_path": "490188.protein.complete.v11.5.txt"
		    }
		]
    )()

def SuccinatimonasSpCag777(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Succinatimonas sp. CAG:777 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuccinatimonasSpCag777", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262974.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262974.protein.info.v11.5.txt",
		        "node_list_path": "1262974.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrnithinimicrobiumPekingenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ornithinimicrobium pekingense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithinimicrobiumPekingenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122622.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122622.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122622.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122622.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122622.protein.info.v11.5.txt",
		        "node_list_path": "1122622.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122622.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichinellaPapuaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichinella papuae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaPapuaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "268474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "268474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "268474.clusters.proteins.v11.5.txt",
		        "sequence_path": "268474.protein.sequences.v11.5.fa",
		        "enrichment_path": "268474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "268474.protein.info.v11.5.txt",
		        "node_list_path": "268474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "268474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp2915(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 29_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp2915", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896982.protein.info.v11.5.txt",
		        "node_list_path": "1896982.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProtomycesLactucaedebilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Protomyces lactucaedebilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProtomycesLactucaedebilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56484.clusters.proteins.v11.5.txt",
		        "sequence_path": "56484.protein.sequences.v11.5.fa",
		        "enrichment_path": "56484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56484.protein.info.v11.5.txt",
		        "node_list_path": "56484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasSalmonicidaSubspAchromogenesAs03(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. achromogenes AS03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSalmonicidaSubspAchromogenesAs03", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1233098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1233098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1233098.protein.info.v11.5.txt",
		        "node_list_path": "1233098.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterCastelli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter castelli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterCastelli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121019.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121019.protein.info.v11.5.txt",
		        "node_list_path": "1121019.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterSphagniphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter sphagniphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterSphagniphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1743169.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1743169.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1743169.clusters.proteins.v11.5.txt",
		        "sequence_path": "1743169.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743169.protein.info.v11.5.txt",
		        "node_list_path": "1743169.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1743169.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterOrnithocola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter ornithocola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterOrnithocola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1848766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848766.protein.info.v11.5.txt",
		        "node_list_path": "1848766.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChelonoidisAbingdonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chelonoidis abingdonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelonoidisAbingdonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "106734.protein.sequences.v11.5.fa",
		        "enrichment_path": "106734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106734.protein.info.v11.5.txt",
		        "node_list_path": "106734.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliellaChilensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borreliella chilensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliellaChilensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1245910.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245910.protein.info.v11.5.txt",
		        "node_list_path": "1245910.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaMediterraneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella mediterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaMediterraneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871031.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871031.protein.info.v11.5.txt",
		        "node_list_path": "1871031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTerrybacteriaBacteriumRifcsplowo201Full4424(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPLOWO2_01_FULL_44_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsplowo201Full4424", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802367.protein.info.v11.5.txt",
		        "node_list_path": "1802367.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrionalesBacteriumGwa2659Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrionales bacterium GWA2_65_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrionalesBacteriumGwa2659Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797915.protein.info.v11.5.txt",
		        "node_list_path": "1797915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MacrophominaPhaseolinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Macrophomina phaseolina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacrophominaPhaseolinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35725.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35725.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35725.clusters.proteins.v11.5.txt",
		        "sequence_path": "35725.protein.sequences.v11.5.fa",
		        "enrichment_path": "35725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35725.protein.info.v11.5.txt",
		        "node_list_path": "35725.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35725.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OnchocercaFlexuosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Onchocerca flexuosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OnchocercaFlexuosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "387005.protein.sequences.v11.5.fa",
		        "enrichment_path": "387005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "387005.protein.info.v11.5.txt",
		        "node_list_path": "387005.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaSpKh3b4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella sp. KH3B4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaSpKh3b4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855394.protein.info.v11.5.txt",
		        "node_list_path": "1855394.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinibacillusKushneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinibacillus kushneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinibacillusKushneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "237682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "237682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "237682.clusters.proteins.v11.5.txt",
		        "sequence_path": "237682.protein.sequences.v11.5.fa",
		        "enrichment_path": "237682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237682.protein.info.v11.5.txt",
		        "node_list_path": "237682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "237682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LoktanellaSp1andimar09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella sp. 1ANDIMAR09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaSp1andimar09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1700845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1700845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1700845.clusters.proteins.v11.5.txt",
		        "sequence_path": "1700845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1700845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1700845.protein.info.v11.5.txt",
		        "node_list_path": "1700845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1700845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumSpIcm42b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. ICM42b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumSpIcm42b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1190620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1190620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1190620.protein.info.v11.5.txt",
		        "node_list_path": "1190620.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalovenusAranensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halovenus aranensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalovenusAranensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "890420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "890420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "890420.clusters.proteins.v11.5.txt",
		        "sequence_path": "890420.protein.sequences.v11.5.fa",
		        "enrichment_path": "890420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "890420.protein.info.v11.5.txt",
		        "node_list_path": "890420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "890420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyopneumoniae168(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae 168 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyopneumoniae168", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "907287.protein.sequences.v11.5.fa",
		        "enrichment_path": "907287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "907287.protein.info.v11.5.txt",
		        "node_list_path": "907287.protein.complete.v11.5.txt"
		    }
		]
    )()

def RenibacteriumSalmoninarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Renibacterium salmoninarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RenibacteriumSalmoninarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "288705.protein.sequences.v11.5.fa",
		        "enrichment_path": "288705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "288705.protein.info.v11.5.txt",
		        "node_list_path": "288705.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg165817(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_58_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165817", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797845.protein.info.v11.5.txt",
		        "node_list_path": "1797845.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetrasphaeraJaponicaT1X7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera japonica T1-X7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrasphaeraJaponicaT1X7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1194083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1194083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1194083.clusters.proteins.v11.5.txt",
		        "sequence_path": "1194083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194083.protein.info.v11.5.txt",
		        "node_list_path": "1194083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1194083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalovivaxRuberCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halovivax ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalovivaxRuberCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "797302.clusters.info.v11.5.txt",
		        "cluster_tree_path": "797302.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "797302.clusters.proteins.v11.5.txt",
		        "sequence_path": "797302.protein.sequences.v11.5.fa",
		        "enrichment_path": "797302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797302.protein.info.v11.5.txt",
		        "node_list_path": "797302.cluster.nodes.v11.5.txt",
		        "edge_list_path": "797302.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpRoot710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpRoot710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736594.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736594.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736594.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736594.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736594.protein.info.v11.5.txt",
		        "node_list_path": "1736594.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736594.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaTurbans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia turbans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaTurbans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777134.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777134.protein.info.v11.5.txt",
		        "node_list_path": "1777134.protein.complete.v11.5.txt"
		    }
		]
    )()

def AdhaeribacterAquaticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Adhaeribacter aquaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AdhaeribacterAquaticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926549.protein.sequences.v11.5.fa",
		        "enrichment_path": "926549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926549.protein.info.v11.5.txt",
		        "node_list_path": "926549.protein.complete.v11.5.txt"
		    }
		]
    )()

def GranulicatellaBalaenopteraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Granulicatella balaenopterae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicatellaBalaenopteraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "137733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "137733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "137733.clusters.proteins.v11.5.txt",
		        "sequence_path": "137733.protein.sequences.v11.5.fa",
		        "enrichment_path": "137733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137733.protein.info.v11.5.txt",
		        "node_list_path": "137733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "137733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CytophagaHutchinsoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cytophaga hutchinsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CytophagaHutchinsoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "269798.clusters.info.v11.5.txt",
		        "cluster_tree_path": "269798.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "269798.clusters.proteins.v11.5.txt",
		        "sequence_path": "269798.protein.sequences.v11.5.fa",
		        "enrichment_path": "269798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269798.protein.info.v11.5.txt",
		        "node_list_path": "269798.cluster.nodes.v11.5.txt",
		        "edge_list_path": "269798.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EptesicusFuscus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eptesicus fuscus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EptesicusFuscus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29078.protein.sequences.v11.5.fa",
		        "enrichment_path": "29078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29078.protein.info.v11.5.txt",
		        "node_list_path": "29078.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollinsellaPhocaeensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collinsella phocaeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaPhocaeensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871016.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871016.protein.info.v11.5.txt",
		        "node_list_path": "1871016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoriobacteriaceaeBacteriumChkci002(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium CHKCI002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacteriaceaeBacteriumChkci002", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1780377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780377.protein.info.v11.5.txt",
		        "node_list_path": "1780377.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloversatilisThermotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloversatilis thermotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloversatilisThermotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1346290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346290.protein.info.v11.5.txt",
		        "node_list_path": "1346290.protein.complete.v11.5.txt"
		    }
		]
    )()

def BeijerinckiaMobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Beijerinckia mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeijerinckiaMobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "231434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "231434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "231434.clusters.proteins.v11.5.txt",
		        "sequence_path": "231434.protein.sequences.v11.5.fa",
		        "enrichment_path": "231434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "231434.protein.info.v11.5.txt",
		        "node_list_path": "231434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "231434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SistotremastrumSuecicumHhb10207Ss3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sistotremastrum suecicum HHB10207 ss-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SistotremastrumSuecicumHhb10207Ss3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314776.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314776.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314776.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314776.protein.info.v11.5.txt",
		        "node_list_path": "1314776.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314776.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumLsSobCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium LS_SOB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumLsSobCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671877.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671877.protein.info.v11.5.txt",
		        "node_list_path": "1671877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsplowo201Full4813Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPLOWO2_01_FULL_48_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsplowo201Full4813Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802146.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802146.protein.info.v11.5.txt",
		        "node_list_path": "1802146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesEuropaeusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces europaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesEuropaeusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883069.clusters.proteins.v11.5.txt",
		        "sequence_path": "883069.protein.sequences.v11.5.fa",
		        "enrichment_path": "883069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883069.protein.info.v11.5.txt",
		        "node_list_path": "883069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacterKriegiiDsm6294Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacter kriegii DSM 6294 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacterKriegiiDsm6294Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122615.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122615.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122615.protein.info.v11.5.txt",
		        "node_list_path": "1122615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusBogoriensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus bogoriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusBogoriensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408424.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408424.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408424.protein.info.v11.5.txt",
		        "node_list_path": "1408424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FormosaAlgae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Formosa algae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaAlgae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "225843.protein.sequences.v11.5.fa",
		        "enrichment_path": "225843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225843.protein.info.v11.5.txt",
		        "node_list_path": "225843.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumRamulusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium ramulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumRamulusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1256908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1256908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1256908.clusters.proteins.v11.5.txt",
		        "sequence_path": "1256908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1256908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1256908.protein.info.v11.5.txt",
		        "node_list_path": "1256908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1256908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumGwa24611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWA2_46_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumGwa24611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801691.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801691.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801691.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801691.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801691.protein.info.v11.5.txt",
		        "node_list_path": "1801691.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801691.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusVini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus vini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusVini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1133569.protein.sequences.v11.5.fa",
		        "enrichment_path": "1133569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1133569.protein.info.v11.5.txt",
		        "node_list_path": "1133569.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumExpansumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium expansum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumExpansumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "27334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "27334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "27334.clusters.proteins.v11.5.txt",
		        "sequence_path": "27334.protein.sequences.v11.5.fa",
		        "enrichment_path": "27334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27334.protein.info.v11.5.txt",
		        "node_list_path": "27334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "27334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterGlucosidilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter glucosidilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterGlucosidilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122941.protein.info.v11.5.txt",
		        "node_list_path": "1122941.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerolineaeBacterium4920Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium 49_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaeBacterium4920Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1641376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1641376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1641376.clusters.proteins.v11.5.txt",
		        "sequence_path": "1641376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1641376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1641376.protein.info.v11.5.txt",
		        "node_list_path": "1641376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1641376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrauserellaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prauserella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrauserellaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "530584.protein.sequences.v11.5.fa",
		        "enrichment_path": "530584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "530584.protein.info.v11.5.txt",
		        "node_list_path": "530584.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumGwf25735(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_57_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumGwf25735", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798576.protein.info.v11.5.txt",
		        "node_list_path": "1798576.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumGw2011Gwc14710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011_GWC1_47_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011Gwc14710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619122.protein.info.v11.5.txt",
		        "node_list_path": "1619122.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfipiaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Afipia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "211460.protein.sequences.v11.5.fa",
		        "enrichment_path": "211460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211460.protein.info.v11.5.txt",
		        "node_list_path": "211460.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusKunkeeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kunkeei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKunkeeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "148814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "148814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "148814.clusters.proteins.v11.5.txt",
		        "sequence_path": "148814.protein.sequences.v11.5.fa",
		        "enrichment_path": "148814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "148814.protein.info.v11.5.txt",
		        "node_list_path": "148814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "148814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyadobacterBeijingensisDsm21582(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter beijingensis DSM 21582 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterBeijingensisDsm21582", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121482.protein.info.v11.5.txt",
		        "node_list_path": "1121482.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseivirgaEhrenbergii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseivirga ehrenbergii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivirgaEhrenbergii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "279360.protein.sequences.v11.5.fa",
		        "enrichment_path": "279360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279360.protein.info.v11.5.txt",
		        "node_list_path": "279360.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumKlh11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium KLH11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumKlh11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "467661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "467661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "467661.clusters.proteins.v11.5.txt",
		        "sequence_path": "467661.protein.sequences.v11.5.fa",
		        "enrichment_path": "467661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "467661.protein.info.v11.5.txt",
		        "node_list_path": "467661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "467661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusYoungiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus youngiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusYoungiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "768710.clusters.info.v11.5.txt",
		        "cluster_tree_path": "768710.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "768710.clusters.proteins.v11.5.txt",
		        "sequence_path": "768710.protein.sequences.v11.5.fa",
		        "enrichment_path": "768710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768710.protein.info.v11.5.txt",
		        "node_list_path": "768710.cluster.nodes.v11.5.txt",
		        "edge_list_path": "768710.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DichelobacterNodosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dichelobacter nodosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DichelobacterNodosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246195.protein.sequences.v11.5.fa",
		        "enrichment_path": "246195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246195.protein.info.v11.5.txt",
		        "node_list_path": "246195.protein.complete.v11.5.txt"
		    }
		]
    )()

def DuganellaZoogloeoidesAtcc25935Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Duganella zoogloeoides ATCC 25935 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaZoogloeoidesAtcc25935Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1261617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1261617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1261617.clusters.proteins.v11.5.txt",
		        "sequence_path": "1261617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261617.protein.info.v11.5.txt",
		        "node_list_path": "1261617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1261617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JeotgalibacillusMalaysiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalibacillus malaysiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalibacillusMalaysiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1508404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1508404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1508404.protein.info.v11.5.txt",
		        "node_list_path": "1508404.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanktotaleaFrisia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planktotalea frisia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktotaleaFrisia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "696762.protein.sequences.v11.5.fa",
		        "enrichment_path": "696762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696762.protein.info.v11.5.txt",
		        "node_list_path": "696762.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm05Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm05Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674843.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674843.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674843.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674843.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674843.protein.info.v11.5.txt",
		        "node_list_path": "1674843.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674843.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotorhabdusHeterorhabditisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photorhabdus heterorhabditis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotorhabdusHeterorhabditisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "880156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "880156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "880156.clusters.proteins.v11.5.txt",
		        "sequence_path": "880156.protein.sequences.v11.5.fa",
		        "enrichment_path": "880156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880156.protein.info.v11.5.txt",
		        "node_list_path": "880156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "880156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumViciaeGb30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae GB30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumViciaeGb30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041142.protein.info.v11.5.txt",
		        "node_list_path": "1041142.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674848.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674848.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674848.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674848.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674848.protein.info.v11.5.txt",
		        "node_list_path": "1674848.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674848.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpPbts1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. PBTS 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpPbts1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1653478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1653478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1653478.clusters.proteins.v11.5.txt",
		        "sequence_path": "1653478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1653478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1653478.protein.info.v11.5.txt",
		        "node_list_path": "1653478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1653478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwh4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWH4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwh4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896210.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896210.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896210.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896210.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896210.protein.info.v11.5.txt",
		        "node_list_path": "1896210.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896210.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentzeaAlbidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentzea albida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentzeaAlbidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "65499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "65499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "65499.clusters.proteins.v11.5.txt",
		        "sequence_path": "65499.protein.sequences.v11.5.fa",
		        "enrichment_path": "65499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65499.protein.info.v11.5.txt",
		        "node_list_path": "65499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "65499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcusMaripaludisS2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis S2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusMaripaludisS2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "267377.protein.sequences.v11.5.fa",
		        "enrichment_path": "267377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267377.protein.info.v11.5.txt",
		        "node_list_path": "267377.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraVanthieliiSerovarHollandStrWazHollandAtcc700522Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira vanthielii serovar Holland str. Waz Holland ATCC 700522 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraVanthieliiSerovarHollandStrWazHollandAtcc700522Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218591.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218591.protein.info.v11.5.txt",
		        "node_list_path": "1218591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureobasidiumNamibiaeCbs14797Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium namibiae CBS 147.97 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureobasidiumNamibiaeCbs14797Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1043004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1043004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1043004.clusters.proteins.v11.5.txt",
		        "sequence_path": "1043004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1043004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1043004.protein.info.v11.5.txt",
		        "node_list_path": "1043004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1043004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobaculaSpRifoxya12Full4616Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacula sp. RIFOXYA12_FULL_46_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobaculaSpRifoxya12Full4616Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797911.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797911.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797911.protein.info.v11.5.txt",
		        "node_list_path": "1797911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4515Fw2607(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4515 (FW-2607) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4515Fw2607", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420909.protein.info.v11.5.txt",
		        "node_list_path": "1420909.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAzambacteriaBacteriumRifcsphigho202Full4518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPHIGHO2_02_FULL_45_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsphigho202Full4518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797303.protein.info.v11.5.txt",
		        "node_list_path": "1797303.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusEquicursoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus equicursoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusEquicursoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293597.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293597.protein.info.v11.5.txt",
		        "node_list_path": "1293597.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrospiraNitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira nitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrospiraNitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1742973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1742973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1742973.clusters.proteins.v11.5.txt",
		        "sequence_path": "1742973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742973.protein.info.v11.5.txt",
		        "node_list_path": "1742973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1742973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FaecalicatenaFissicatenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalicatena fissicatena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalicatenaFissicatenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290055.clusters.proteins.v11.5.txt",
		        "sequence_path": "290055.protein.sequences.v11.5.fa",
		        "enrichment_path": "290055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290055.protein.info.v11.5.txt",
		        "node_list_path": "290055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CobetiaCrustatorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cobetia crustatorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CobetiaCrustatorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553385.clusters.proteins.v11.5.txt",
		        "sequence_path": "553385.protein.sequences.v11.5.fa",
		        "enrichment_path": "553385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553385.protein.info.v11.5.txt",
		        "node_list_path": "553385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusDiolivoransDsm14421Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus diolivorans DSM 14421 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusDiolivoransDsm14421Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423739.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423739.protein.info.v11.5.txt",
		        "node_list_path": "1423739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSp21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. 21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSp21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743722.protein.sequences.v11.5.fa",
		        "enrichment_path": "743722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743722.protein.info.v11.5.txt",
		        "node_list_path": "743722.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraBroomiiSerovarHurstbridgeStr5399Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira broomii serovar Hurstbridge str. 5399 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraBroomiiSerovarHurstbridgeStr5399Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1049789.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1049789.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1049789.clusters.proteins.v11.5.txt",
		        "sequence_path": "1049789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1049789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1049789.protein.info.v11.5.txt",
		        "node_list_path": "1049789.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1049789.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurimonasDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326298.protein.sequences.v11.5.fa",
		        "enrichment_path": "326298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326298.protein.info.v11.5.txt",
		        "node_list_path": "326298.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiumSpinosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobium spinosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiumSpinosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "240016.protein.sequences.v11.5.fa",
		        "enrichment_path": "240016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240016.protein.info.v11.5.txt",
		        "node_list_path": "240016.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumEbm40(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium EBM-40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumEbm40", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1918508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918508.protein.info.v11.5.txt",
		        "node_list_path": "1918508.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1638987.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1638987.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1638987.clusters.proteins.v11.5.txt",
		        "sequence_path": "1638987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638987.protein.info.v11.5.txt",
		        "node_list_path": "1638987.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1638987.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatenovulumAgarivoransDs2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catenovulum agarivorans DS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenovulumAgarivoransDs2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1328313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1328313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1328313.clusters.proteins.v11.5.txt",
		        "sequence_path": "1328313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1328313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1328313.protein.info.v11.5.txt",
		        "node_list_path": "1328313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1328313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusEdwardsbacteriaBacteriumGwe25412(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Edwardsbacteria bacterium GWE2_54_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusEdwardsbacteriaBacteriumGwe25412", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817850.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817850.protein.info.v11.5.txt",
		        "node_list_path": "1817850.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioPigerCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio piger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioPigerCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411464.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411464.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411464.clusters.proteins.v11.5.txt",
		        "sequence_path": "411464.protein.sequences.v11.5.fa",
		        "enrichment_path": "411464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411464.protein.info.v11.5.txt",
		        "node_list_path": "411464.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411464.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf23316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_33_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf23316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797341.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797341.protein.info.v11.5.txt",
		        "node_list_path": "1797341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsphigho212Full4422Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_12_FULL_44_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho212Full4422Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798342.protein.info.v11.5.txt",
		        "node_list_path": "1798342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19046Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM19046 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19046Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1460640.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1460640.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1460640.clusters.proteins.v11.5.txt",
		        "sequence_path": "1460640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460640.protein.info.v11.5.txt",
		        "node_list_path": "1460640.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1460640.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KinetoplastibacteriumOncopeltii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium oncopeltii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KinetoplastibacteriumOncopeltii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208920.protein.info.v11.5.txt",
		        "node_list_path": "1208920.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShuttleworthiaSpMsx8b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shuttleworthia sp. MSX8B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShuttleworthiaSpMsx8b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936574.protein.sequences.v11.5.fa",
		        "enrichment_path": "936574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936574.protein.info.v11.5.txt",
		        "node_list_path": "936574.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag632Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:632 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag632Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262830.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262830.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262830.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262830.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262830.protein.info.v11.5.txt",
		        "node_list_path": "1262830.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262830.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermofilumAdornatus1505Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum adornatus 1505 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermofilumAdornatus1505Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "697581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "697581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "697581.clusters.proteins.v11.5.txt",
		        "sequence_path": "697581.protein.sequences.v11.5.fa",
		        "enrichment_path": "697581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "697581.protein.info.v11.5.txt",
		        "node_list_path": "697581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "697581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucorAmbiguusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucor ambiguus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucorAmbiguusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "91626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "91626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "91626.clusters.proteins.v11.5.txt",
		        "sequence_path": "91626.protein.sequences.v11.5.fa",
		        "enrichment_path": "91626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91626.protein.info.v11.5.txt",
		        "node_list_path": "91626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "91626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinisporaPacificaDsm45543Cns863(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45543 CNS-863 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisporaPacificaDsm45543Cns863", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999542.protein.sequences.v11.5.fa",
		        "enrichment_path": "999542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999542.protein.info.v11.5.txt",
		        "node_list_path": "999542.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumSubtileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium subtile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumSubtileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "77635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "77635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "77635.clusters.proteins.v11.5.txt",
		        "sequence_path": "77635.protein.sequences.v11.5.fa",
		        "enrichment_path": "77635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77635.protein.info.v11.5.txt",
		        "node_list_path": "77635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "77635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisSk1080Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK1080 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisSk1080Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1008453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1008453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1008453.clusters.proteins.v11.5.txt",
		        "sequence_path": "1008453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1008453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1008453.protein.info.v11.5.txt",
		        "node_list_path": "1008453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1008453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpAsf502Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ASF502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpAsf502Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "97139.clusters.info.v11.5.txt",
		        "cluster_tree_path": "97139.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "97139.clusters.proteins.v11.5.txt",
		        "sequence_path": "97139.protein.sequences.v11.5.fa",
		        "enrichment_path": "97139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97139.protein.info.v11.5.txt",
		        "node_list_path": "97139.cluster.nodes.v11.5.txt",
		        "edge_list_path": "97139.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAkagiiDsm12554(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium akagii DSM 12554 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAkagiiDsm12554", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121293.protein.info.v11.5.txt",
		        "node_list_path": "1121293.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPhocaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus phocaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPhocaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776378.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776378.protein.info.v11.5.txt",
		        "node_list_path": "1776378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobiBacteriumNicil2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobi bacterium NICIL-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiBacteriumNicil2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1662223.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662223.protein.info.v11.5.txt",
		        "node_list_path": "1662223.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumGa0077548(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077548 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumGa0077548", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752226.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752226.protein.info.v11.5.txt",
		        "node_list_path": "1752226.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaSpD27(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina sp. D27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaSpD27", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1382305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382305.protein.info.v11.5.txt",
		        "node_list_path": "1382305.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterRuber(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterRuber", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "990371.protein.sequences.v11.5.fa",
		        "enrichment_path": "990371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990371.protein.info.v11.5.txt",
		        "node_list_path": "990371.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurimonasGotlandica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas gotlandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasGotlandica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "929558.protein.sequences.v11.5.fa",
		        "enrichment_path": "929558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929558.protein.info.v11.5.txt",
		        "node_list_path": "929558.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSpSg55Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. SG55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSpSg55Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500270.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500270.protein.info.v11.5.txt",
		        "node_list_path": "1500270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSanguinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSanguinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122925.protein.info.v11.5.txt",
		        "node_list_path": "1122925.protein.complete.v11.5.txt"
		    }
		]
    )()

def IdiomarinaZobelliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina zobellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaZobelliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86103.clusters.proteins.v11.5.txt",
		        "sequence_path": "86103.protein.sequences.v11.5.fa",
		        "enrichment_path": "86103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86103.protein.info.v11.5.txt",
		        "node_list_path": "86103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterCryptus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter cryptus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterCryptus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122970.protein.info.v11.5.txt",
		        "node_list_path": "1122970.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanibacterSpHtcc2649Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janibacter sp. HTCC2649 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterSpHtcc2649Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313589.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313589.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313589.clusters.proteins.v11.5.txt",
		        "sequence_path": "313589.protein.sequences.v11.5.fa",
		        "enrichment_path": "313589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313589.protein.info.v11.5.txt",
		        "node_list_path": "313589.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313589.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumOxysporumFSpLycopersici4287(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. lycopersici 4287 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumOxysporumFSpLycopersici4287", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426428.protein.sequences.v11.5.fa",
		        "enrichment_path": "426428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426428.protein.info.v11.5.txt",
		        "node_list_path": "426428.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterCloacaeJd6301Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae JD6301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterCloacaeJd6301Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1399774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1399774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1399774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1399774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399774.protein.info.v11.5.txt",
		        "node_list_path": "1399774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1399774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteusMirabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteus mirabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteusMirabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "529507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "529507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "529507.clusters.proteins.v11.5.txt",
		        "sequence_path": "529507.protein.sequences.v11.5.fa",
		        "enrichment_path": "529507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529507.protein.info.v11.5.txt",
		        "node_list_path": "529507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "529507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KocuriaTurfanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kocuria turfanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaTurfanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "388357.clusters.info.v11.5.txt",
		        "cluster_tree_path": "388357.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "388357.clusters.proteins.v11.5.txt",
		        "sequence_path": "388357.protein.sequences.v11.5.fa",
		        "enrichment_path": "388357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388357.protein.info.v11.5.txt",
		        "node_list_path": "388357.cluster.nodes.v11.5.txt",
		        "edge_list_path": "388357.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumCanarienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium canariense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumCanarienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "255045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "255045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "255045.clusters.proteins.v11.5.txt",
		        "sequence_path": "255045.protein.sequences.v11.5.fa",
		        "enrichment_path": "255045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "255045.protein.info.v11.5.txt",
		        "node_list_path": "255045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "255045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpSrs2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SRS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpSrs2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "133190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "133190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "133190.clusters.proteins.v11.5.txt",
		        "sequence_path": "133190.protein.sequences.v11.5.fa",
		        "enrichment_path": "133190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133190.protein.info.v11.5.txt",
		        "node_list_path": "133190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "133190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RufibacterRuberCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rufibacter ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RufibacterRuberCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1783499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1783499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1783499.clusters.proteins.v11.5.txt",
		        "sequence_path": "1783499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1783499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1783499.protein.info.v11.5.txt",
		        "node_list_path": "1783499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1783499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpHun007(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. HUN007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpHun007", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1514668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1514668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1514668.protein.info.v11.5.txt",
		        "node_list_path": "1514668.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinotignumSchaalii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinotignum schaalii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinotignumSchaalii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59505.protein.sequences.v11.5.fa",
		        "enrichment_path": "59505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59505.protein.info.v11.5.txt",
		        "node_list_path": "59505.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumTumefaciensCherryCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens Cherry Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumTumefaciensCherryCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1281779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1281779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1281779.clusters.proteins.v11.5.txt",
		        "sequence_path": "1281779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1281779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1281779.protein.info.v11.5.txt",
		        "node_list_path": "1281779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1281779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloarculaArgentinensisDsm12282Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula argentinensis DSM 12282 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaArgentinensisDsm12282Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230451.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230451.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230451.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230451.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230451.protein.info.v11.5.txt",
		        "node_list_path": "1230451.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230451.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParapedobacterLuteusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parapedobacter luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParapedobacterLuteusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "623280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "623280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "623280.clusters.proteins.v11.5.txt",
		        "sequence_path": "623280.protein.sequences.v11.5.fa",
		        "enrichment_path": "623280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "623280.protein.info.v11.5.txt",
		        "node_list_path": "623280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "623280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalococcusSp197a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halococcus sp. 197A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusSp197a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1197130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197130.protein.info.v11.5.txt",
		        "node_list_path": "1197130.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimnobacterSpCaciam66h1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnobacter sp. CACIAM 66H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnobacterSpCaciam66h1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1813033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1813033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1813033.clusters.proteins.v11.5.txt",
		        "sequence_path": "1813033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1813033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1813033.protein.info.v11.5.txt",
		        "node_list_path": "1813033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1813033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychroserpensSpHelI66Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens sp. Hel_I_66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroserpensSpHelI66Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1250004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1250004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1250004.clusters.proteins.v11.5.txt",
		        "sequence_path": "1250004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250004.protein.info.v11.5.txt",
		        "node_list_path": "1250004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1250004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full4222Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_42_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full4222Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802207.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802207.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802207.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802207.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802207.protein.info.v11.5.txt",
		        "node_list_path": "1802207.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802207.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterAalborgensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter aalborgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterAalborgensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1860102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1860102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1860102.clusters.proteins.v11.5.txt",
		        "sequence_path": "1860102.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860102.protein.info.v11.5.txt",
		        "node_list_path": "1860102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1860102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusCoxii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus coxii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusCoxii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "755172.protein.sequences.v11.5.fa",
		        "enrichment_path": "755172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "755172.protein.info.v11.5.txt",
		        "node_list_path": "755172.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusDevriesei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus devriesei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDevriesei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123300.protein.info.v11.5.txt",
		        "node_list_path": "1123300.protein.complete.v11.5.txt"
		    }
		]
    )()

def WinogradskyellaJejuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Winogradskyella jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinogradskyellaJejuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089305.protein.info.v11.5.txt",
		        "node_list_path": "1089305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaLijiangensisNbrc108240(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia lijiangensis NBRC 108240 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaLijiangensisNbrc108240", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210083.protein.info.v11.5.txt",
		        "node_list_path": "1210083.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScyliorhinusTorazame(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scyliorhinus torazame graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScyliorhinusTorazame", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "75743.protein.sequences.v11.5.fa",
		        "enrichment_path": "75743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75743.protein.info.v11.5.txt",
		        "node_list_path": "75743.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumGw2011Gwb24422(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_44_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24422", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618387.protein.info.v11.5.txt",
		        "node_list_path": "1618387.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCampbellbacteriaBacteriumRifcsplowo2023512Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFCSPLOWO2_02_35_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifcsplowo2023512Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797580.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797580.protein.info.v11.5.txt",
		        "node_list_path": "1797580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurimonasSpRifcsplowo2123612(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFCSPLOWO2_12_36_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasSpRifcsplowo2123612", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802253.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802253.protein.info.v11.5.txt",
		        "node_list_path": "1802253.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiohalocapsaSpMl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiohalocapsa sp. ML1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiohalocapsaSpMl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1431688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1431688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1431688.clusters.proteins.v11.5.txt",
		        "sequence_path": "1431688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1431688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1431688.protein.info.v11.5.txt",
		        "node_list_path": "1431688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1431688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermosiphoAtlanticusDsm15807Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosipho atlanticus DSM 15807 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosiphoAtlanticusDsm15807Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123380.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123380.protein.info.v11.5.txt",
		        "node_list_path": "1123380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomaduraAtramentariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura atramentaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraAtramentariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120936.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120936.protein.info.v11.5.txt",
		        "node_list_path": "1120936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioQuintilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio quintilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioQuintilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117707.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117707.protein.info.v11.5.txt",
		        "node_list_path": "1117707.protein.complete.v11.5.txt"
		    }
		]
    )()

def YarrowiaLipolyticaClib122Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yarrowia lipolytica CLIB122 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YarrowiaLipolyticaClib122Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "284591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "284591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "284591.clusters.proteins.v11.5.txt",
		        "sequence_path": "284591.protein.sequences.v11.5.fa",
		        "enrichment_path": "284591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284591.protein.info.v11.5.txt",
		        "node_list_path": "284591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "284591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaPseudomalleiK96243Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei K96243 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaPseudomalleiK96243Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272560.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272560.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272560.clusters.proteins.v11.5.txt",
		        "sequence_path": "272560.protein.sequences.v11.5.fa",
		        "enrichment_path": "272560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272560.protein.info.v11.5.txt",
		        "node_list_path": "272560.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272560.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidimicrobiiaBacteriumBacl6Mag120910Bin40Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium BACL6 MAG-120910-bin40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidimicrobiiaBacteriumBacl6Mag120910Bin40Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1655586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1655586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1655586.clusters.proteins.v11.5.txt",
		        "sequence_path": "1655586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655586.protein.info.v11.5.txt",
		        "node_list_path": "1655586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1655586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusHodgkiniaCicadicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hodgkinia cicadicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHodgkiniaCicadicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573658.protein.sequences.v11.5.fa",
		        "enrichment_path": "573658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573658.protein.info.v11.5.txt",
		        "node_list_path": "573658.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaVerecundumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma verecundum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaVerecundumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "171291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "171291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "171291.clusters.proteins.v11.5.txt",
		        "sequence_path": "171291.protein.sequences.v11.5.fa",
		        "enrichment_path": "171291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "171291.protein.info.v11.5.txt",
		        "node_list_path": "171291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "171291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsplowo201Full4717Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_01_FULL_47_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo201Full4717Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802400.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802400.protein.info.v11.5.txt",
		        "node_list_path": "1802400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumAestuariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumAestuariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1821621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1821621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1821621.clusters.proteins.v11.5.txt",
		        "sequence_path": "1821621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1821621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1821621.protein.info.v11.5.txt",
		        "node_list_path": "1821621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1821621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumResistens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium resistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumResistens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "662755.protein.sequences.v11.5.fa",
		        "enrichment_path": "662755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "662755.protein.info.v11.5.txt",
		        "node_list_path": "662755.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifcsplowo212Full459(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFCSPLOWO2_12_FULL_45_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifcsplowo212Full459", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802568.protein.info.v11.5.txt",
		        "node_list_path": "1802568.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBifidumNcimb41171Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum NCIMB41171 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBifidumNcimb41171Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398513.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398513.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398513.clusters.proteins.v11.5.txt",
		        "sequence_path": "398513.protein.sequences.v11.5.fa",
		        "enrichment_path": "398513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398513.protein.info.v11.5.txt",
		        "node_list_path": "398513.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398513.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpNxc14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. NXC14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpNxc14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1981173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1981173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1981173.protein.info.v11.5.txt",
		        "node_list_path": "1981173.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1934979.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934979.protein.info.v11.5.txt",
		        "node_list_path": "1934979.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRbg19ftCombo5311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RBG_19FT_COMBO_53_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRbg19ftCombo5311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802613.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802613.protein.info.v11.5.txt",
		        "node_list_path": "1802613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DenitrobacteriumDetoxificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Denitrobacterium detoxificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DenitrobacteriumDetoxificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "79604.clusters.info.v11.5.txt",
		        "cluster_tree_path": "79604.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "79604.clusters.proteins.v11.5.txt",
		        "sequence_path": "79604.protein.sequences.v11.5.fa",
		        "enrichment_path": "79604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79604.protein.info.v11.5.txt",
		        "node_list_path": "79604.cluster.nodes.v11.5.txt",
		        "edge_list_path": "79604.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DialisterSpCag486(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dialister sp. CAG:486 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterSpCag486", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262870.protein.info.v11.5.txt",
		        "node_list_path": "1262870.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesRadicidentis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces radicidentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesRadicidentis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "111015.protein.sequences.v11.5.fa",
		        "enrichment_path": "111015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "111015.protein.info.v11.5.txt",
		        "node_list_path": "111015.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSeohaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter seohaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSeohaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "281376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "281376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "281376.clusters.proteins.v11.5.txt",
		        "sequence_path": "281376.protein.sequences.v11.5.fa",
		        "enrichment_path": "281376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "281376.protein.info.v11.5.txt",
		        "node_list_path": "281376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "281376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaCanadense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma canadense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaCanadense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29554.protein.sequences.v11.5.fa",
		        "enrichment_path": "29554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29554.protein.info.v11.5.txt",
		        "node_list_path": "29554.protein.complete.v11.5.txt"
		    }
		]
    )()

def HoldemaniaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Holdemania massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoldemaniaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211819.protein.info.v11.5.txt",
		        "node_list_path": "1211819.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaRohdeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia rohdei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaRohdeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29485.clusters.proteins.v11.5.txt",
		        "sequence_path": "29485.protein.sequences.v11.5.fa",
		        "enrichment_path": "29485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29485.protein.info.v11.5.txt",
		        "node_list_path": "29485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlossinaAusteni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glossina austeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlossinaAusteni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7395.protein.sequences.v11.5.fa",
		        "enrichment_path": "7395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7395.protein.info.v11.5.txt",
		        "node_list_path": "7395.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusThailandensisDsm22698Jcm13996Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus thailandensis DSM 22698 JCM 13996 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusThailandensisDsm22698Jcm13996Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423810.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423810.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423810.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423810.protein.info.v11.5.txt",
		        "node_list_path": "1423810.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423810.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhialophoraAttaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phialophora attae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhialophoraAttaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1664694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1664694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1664694.clusters.proteins.v11.5.txt",
		        "sequence_path": "1664694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1664694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1664694.protein.info.v11.5.txt",
		        "node_list_path": "1664694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1664694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpP1xp2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P1XP2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpP1xp2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1472719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1472719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1472719.clusters.proteins.v11.5.txt",
		        "sequence_path": "1472719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1472719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1472719.protein.info.v11.5.txt",
		        "node_list_path": "1472719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1472719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumSpA11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. A11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumSpA11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1394176.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394176.protein.info.v11.5.txt",
		        "node_list_path": "1394176.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionKazanBacteriumGw2011Gwa15015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium GW2011_GWA1_50_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionKazanBacteriumGw2011Gwa15015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1620412.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1620412.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1620412.clusters.proteins.v11.5.txt",
		        "sequence_path": "1620412.protein.sequences.v11.5.fa",
		        "enrichment_path": "1620412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1620412.protein.info.v11.5.txt",
		        "node_list_path": "1620412.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1620412.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaSpIstkb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea sp. ISTKB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaSpIstkb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1586708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1586708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1586708.protein.info.v11.5.txt",
		        "node_list_path": "1586708.protein.complete.v11.5.txt"
		    }
		]
    )()

def KerstersiaGyiorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kerstersia gyiorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KerstersiaGyiorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "206506.clusters.info.v11.5.txt",
		        "cluster_tree_path": "206506.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "206506.clusters.proteins.v11.5.txt",
		        "sequence_path": "206506.protein.sequences.v11.5.fa",
		        "enrichment_path": "206506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "206506.protein.info.v11.5.txt",
		        "node_list_path": "206506.cluster.nodes.v11.5.txt",
		        "edge_list_path": "206506.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FacklamiaHominisCcug36813(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Facklamia hominis CCUG 36813 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FacklamiaHominisCcug36813", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883111.protein.sequences.v11.5.fa",
		        "enrichment_path": "883111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883111.protein.info.v11.5.txt",
		        "node_list_path": "883111.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesCoprocola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides coprocola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCoprocola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "470145.protein.sequences.v11.5.fa",
		        "enrichment_path": "470145.protein.enrichment.terms.v11.5.txt",
		        "info_path": "470145.protein.info.v11.5.txt",
		        "node_list_path": "470145.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterHyointestinalisSubspHyointestinalisLmg9260(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter hyointestinalis subsp. hyointestinalis LMG 9260 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterHyointestinalisSubspHyointestinalisLmg9260", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1031746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1031746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1031746.protein.info.v11.5.txt",
		        "node_list_path": "1031746.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo212Full4526Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_12_FULL_45_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo212Full4526Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798525.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798525.protein.info.v11.5.txt",
		        "node_list_path": "1798525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraMegakarya(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora megakarya graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraMegakarya", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4795.protein.sequences.v11.5.fa",
		        "enrichment_path": "4795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4795.protein.info.v11.5.txt",
		        "node_list_path": "4795.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSp6146afaa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. 6146AFAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSp6146afaa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665942.protein.sequences.v11.5.fa",
		        "enrichment_path": "665942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665942.protein.info.v11.5.txt",
		        "node_list_path": "665942.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterCryptusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter cryptus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterCryptusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122970.protein.info.v11.5.txt",
		        "node_list_path": "1122970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MartelellaEndophyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Martelella endophytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MartelellaEndophyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1486262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1486262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1486262.clusters.proteins.v11.5.txt",
		        "sequence_path": "1486262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1486262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1486262.protein.info.v11.5.txt",
		        "node_list_path": "1486262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1486262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeonectriaDitissima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neonectria ditissima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeonectriaDitissima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "78410.protein.sequences.v11.5.fa",
		        "enrichment_path": "78410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78410.protein.info.v11.5.txt",
		        "node_list_path": "78410.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthromitusSpSfbmousejapan(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBmouseJapan graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthromitusSpSfbmousejapan", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1029718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1029718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1029718.protein.info.v11.5.txt",
		        "node_list_path": "1029718.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat25496Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-25496 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat25496Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1742359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1742359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1742359.clusters.proteins.v11.5.txt",
		        "sequence_path": "1742359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742359.protein.info.v11.5.txt",
		        "node_list_path": "1742359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1742359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumIranicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium iranicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumIranicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1370125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1370125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1370125.protein.info.v11.5.txt",
		        "node_list_path": "1370125.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumVincentii3136a2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii 3136A2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumVincentii3136a2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469604.protein.sequences.v11.5.fa",
		        "enrichment_path": "469604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469604.protein.info.v11.5.txt",
		        "node_list_path": "469604.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydomonasReinhardtii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydomonas reinhardtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydomonasReinhardtii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3055.protein.sequences.v11.5.fa",
		        "enrichment_path": "3055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3055.protein.info.v11.5.txt",
		        "node_list_path": "3055.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanibaculumPacificumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanibaculum pacificum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanibaculumPacificumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "580166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "580166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "580166.clusters.proteins.v11.5.txt",
		        "sequence_path": "580166.protein.sequences.v11.5.fa",
		        "enrichment_path": "580166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "580166.protein.info.v11.5.txt",
		        "node_list_path": "580166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "580166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusLimi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus limi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusLimi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930131.protein.sequences.v11.5.fa",
		        "enrichment_path": "930131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930131.protein.info.v11.5.txt",
		        "node_list_path": "930131.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChristensenellaceaeBacteriumPhil7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Christensenellaceae bacterium Phil7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChristensenellaceaeBacteriumPhil7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930013.protein.info.v11.5.txt",
		        "node_list_path": "1930013.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusPersicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus persicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPersicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930146.protein.sequences.v11.5.fa",
		        "enrichment_path": "930146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930146.protein.info.v11.5.txt",
		        "node_list_path": "930146.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasTaetrolens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas taetrolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasTaetrolens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47884.protein.sequences.v11.5.fa",
		        "enrichment_path": "47884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47884.protein.info.v11.5.txt",
		        "node_list_path": "47884.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumMarseilleP2986(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Marseille-P2986 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumMarseilleP2986", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852391.protein.info.v11.5.txt",
		        "node_list_path": "1852391.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterSpongiicolaDsm21749Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter spongiicola DSM 21749 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterSpongiicolaDsm21749Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122188.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122188.protein.info.v11.5.txt",
		        "node_list_path": "1122188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBaumanniiBjab07104Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii BJAB07104 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBaumanniiBjab07104Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1096995.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1096995.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1096995.clusters.proteins.v11.5.txt",
		        "sequence_path": "1096995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1096995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1096995.protein.info.v11.5.txt",
		        "node_list_path": "1096995.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1096995.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusThailandensisDsm22698Jcm13996(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus thailandensis DSM 22698 JCM 13996 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusThailandensisDsm22698Jcm13996", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423810.protein.info.v11.5.txt",
		        "node_list_path": "1423810.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumTepidiprofundiDsm19306Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tepidiprofundi DSM 19306 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTepidiprofundiDsm19306Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121338.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121338.protein.info.v11.5.txt",
		        "node_list_path": "1121338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DielmaFastidiosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dielma fastidiosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DielmaFastidiosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1034346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1034346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1034346.clusters.proteins.v11.5.txt",
		        "sequence_path": "1034346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034346.protein.info.v11.5.txt",
		        "node_list_path": "1034346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1034346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusRhodochrous(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus rhodochrous graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusRhodochrous", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1429046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1429046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1429046.protein.info.v11.5.txt",
		        "node_list_path": "1429046.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasMendocinaNk01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina NK01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMendocinaNk01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1001585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1001585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1001585.clusters.proteins.v11.5.txt",
		        "sequence_path": "1001585.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001585.protein.info.v11.5.txt",
		        "node_list_path": "1001585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1001585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpCcge1001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpCcge1001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "640510.clusters.info.v11.5.txt",
		        "cluster_tree_path": "640510.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "640510.clusters.proteins.v11.5.txt",
		        "sequence_path": "640510.protein.sequences.v11.5.fa",
		        "enrichment_path": "640510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640510.protein.info.v11.5.txt",
		        "node_list_path": "640510.cluster.nodes.v11.5.txt",
		        "edge_list_path": "640510.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErysipheNecator(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erysiphe necator graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipheNecator", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52586.protein.sequences.v11.5.fa",
		        "enrichment_path": "52586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52586.protein.info.v11.5.txt",
		        "node_list_path": "52586.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacterium9403326Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9403326 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacterium9403326Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "938289.clusters.info.v11.5.txt",
		        "cluster_tree_path": "938289.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "938289.clusters.proteins.v11.5.txt",
		        "sequence_path": "938289.protein.sequences.v11.5.fa",
		        "enrichment_path": "938289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938289.protein.info.v11.5.txt",
		        "node_list_path": "938289.cluster.nodes.v11.5.txt",
		        "edge_list_path": "938289.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpongiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas spongiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpongiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1117319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1117319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1117319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117319.protein.info.v11.5.txt",
		        "node_list_path": "1117319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1117319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaDisiensFb03509an(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella disiens FB03509AN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaDisiensFb03509an", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "866771.protein.sequences.v11.5.fa",
		        "enrichment_path": "866771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866771.protein.info.v11.5.txt",
		        "node_list_path": "866771.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1659199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1659199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1659199.clusters.proteins.v11.5.txt",
		        "sequence_path": "1659199.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659199.protein.info.v11.5.txt",
		        "node_list_path": "1659199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1659199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusVelezensisTrigocor1448Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus velezensis TrigoCor1448 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusVelezensisTrigocor1448Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449088.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449088.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449088.protein.info.v11.5.txt",
		        "node_list_path": "1449088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaematobacterMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haematobacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaematobacterMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "195105.protein.sequences.v11.5.fa",
		        "enrichment_path": "195105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195105.protein.info.v11.5.txt",
		        "node_list_path": "195105.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpDs20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. DS20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpDs20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1532555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1532555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1532555.clusters.proteins.v11.5.txt",
		        "sequence_path": "1532555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1532555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1532555.protein.info.v11.5.txt",
		        "node_list_path": "1532555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1532555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumK1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium K1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumK1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807743.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807743.protein.info.v11.5.txt",
		        "node_list_path": "1807743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3523Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_35_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3523Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798274.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798274.protein.info.v11.5.txt",
		        "node_list_path": "1798274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UstilagoHordeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ustilago hordei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UstilagoHordeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "120017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "120017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "120017.clusters.proteins.v11.5.txt",
		        "sequence_path": "120017.protein.sequences.v11.5.fa",
		        "enrichment_path": "120017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "120017.protein.info.v11.5.txt",
		        "node_list_path": "120017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "120017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpPamc25486Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. PAMC 25486 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpPamc25486Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1494608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1494608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1494608.clusters.proteins.v11.5.txt",
		        "sequence_path": "1494608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1494608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1494608.protein.info.v11.5.txt",
		        "node_list_path": "1494608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1494608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DoreaSpD27(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dorea sp. D27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaSpD27", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658665.protein.sequences.v11.5.fa",
		        "enrichment_path": "658665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658665.protein.info.v11.5.txt",
		        "node_list_path": "658665.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaPaludivivens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella paludivivens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaPaludivivens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122990.protein.info.v11.5.txt",
		        "node_list_path": "1122990.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1316444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1316444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1316444.protein.info.v11.5.txt",
		        "node_list_path": "1316444.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesStercorirosoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides stercorirosoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesStercorirosoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236514.protein.info.v11.5.txt",
		        "node_list_path": "1236514.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807736.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807736.protein.info.v11.5.txt",
		        "node_list_path": "1807736.protein.complete.v11.5.txt"
		    }
		]
    )()

def IctalurusPunctatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ictalurus punctatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IctalurusPunctatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7998.clusters.proteins.v11.5.txt",
		        "sequence_path": "7998.protein.sequences.v11.5.fa",
		        "enrichment_path": "7998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7998.protein.info.v11.5.txt",
		        "node_list_path": "7998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaBronchiseptica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella bronchiseptica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaBronchiseptica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "257310.protein.sequences.v11.5.fa",
		        "enrichment_path": "257310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "257310.protein.info.v11.5.txt",
		        "node_list_path": "257310.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillibacterSp5720Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. 57_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSp5720Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897011.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897011.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897011.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897011.protein.info.v11.5.txt",
		        "node_list_path": "1897011.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897011.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteusHauseriAtcc700826Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteus hauseri ATCC 700826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteusHauseriAtcc700826Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354271.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354271.protein.info.v11.5.txt",
		        "node_list_path": "1354271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYonathbacteriaBacteriumRifoxyd1Full5236Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFOXYD1_FULL_52_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifoxyd1Full5236Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802730.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802730.protein.info.v11.5.txt",
		        "node_list_path": "1802730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonadaceaeBacteriumScn6820(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium SCN 68-20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonadaceaeBacteriumScn6820", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660161.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660161.protein.info.v11.5.txt",
		        "node_list_path": "1660161.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpAntH11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ant H11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpAntH11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1564113.protein.sequences.v11.5.fa",
		        "enrichment_path": "1564113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1564113.protein.info.v11.5.txt",
		        "node_list_path": "1564113.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusAcidocaldariusTc41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius Tc41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusAcidocaldariusTc41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1048834.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1048834.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1048834.clusters.proteins.v11.5.txt",
		        "sequence_path": "1048834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048834.protein.info.v11.5.txt",
		        "node_list_path": "1048834.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1048834.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumTusciaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium tusciae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumTusciaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "75922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "75922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "75922.clusters.proteins.v11.5.txt",
		        "sequence_path": "75922.protein.sequences.v11.5.fa",
		        "enrichment_path": "75922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75922.protein.info.v11.5.txt",
		        "node_list_path": "75922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "75922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureimonasSpAu22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpAu22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1638162.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638162.protein.info.v11.5.txt",
		        "node_list_path": "1638162.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaTimonaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia timonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaTimonaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883126.clusters.proteins.v11.5.txt",
		        "sequence_path": "883126.protein.sequences.v11.5.fa",
		        "enrichment_path": "883126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883126.protein.info.v11.5.txt",
		        "node_list_path": "883126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumRifcsphigho201Full4822(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPHIGHO2_01_FULL_48_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsphigho201Full4822", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802555.protein.info.v11.5.txt",
		        "node_list_path": "1802555.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27916(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27916", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1679169.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679169.protein.info.v11.5.txt",
		        "node_list_path": "1679169.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumSandarakinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium sandarakinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumSandarakinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "629680.protein.sequences.v11.5.fa",
		        "enrichment_path": "629680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "629680.protein.info.v11.5.txt",
		        "node_list_path": "629680.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusPontisDsm8475(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pontis DSM 8475 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPontisDsm8475", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423794.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423794.protein.info.v11.5.txt",
		        "node_list_path": "1423794.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlossinaMorsitansMorsitans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glossina morsitans morsitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlossinaMorsitansMorsitans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37546.protein.sequences.v11.5.fa",
		        "enrichment_path": "37546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37546.protein.info.v11.5.txt",
		        "node_list_path": "37546.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpRoot485(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Root485 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpRoot485", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736546.protein.info.v11.5.txt",
		        "node_list_path": "1736546.protein.complete.v11.5.txt"
		    }
		]
    )()

def FluviicolaTaffensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fluviicola taffensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FluviicolaTaffensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "755732.clusters.info.v11.5.txt",
		        "cluster_tree_path": "755732.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "755732.clusters.proteins.v11.5.txt",
		        "sequence_path": "755732.protein.sequences.v11.5.fa",
		        "enrichment_path": "755732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "755732.protein.info.v11.5.txt",
		        "node_list_path": "755732.cluster.nodes.v11.5.txt",
		        "edge_list_path": "755732.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionNc10BacteriumRifcsplowo202Full6622(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division NC10 bacterium RIFCSPLOWO2_02_FULL_66_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionNc10BacteriumRifcsplowo202Full6622", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801658.protein.info.v11.5.txt",
		        "node_list_path": "1801658.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusResistensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus resistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusResistensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1750590.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1750590.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1750590.clusters.proteins.v11.5.txt",
		        "sequence_path": "1750590.protein.sequences.v11.5.fa",
		        "enrichment_path": "1750590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1750590.protein.info.v11.5.txt",
		        "node_list_path": "1750590.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1750590.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMatruchotiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium matruchotii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMatruchotiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553207.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553207.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553207.clusters.proteins.v11.5.txt",
		        "sequence_path": "553207.protein.sequences.v11.5.fa",
		        "enrichment_path": "553207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553207.protein.info.v11.5.txt",
		        "node_list_path": "553207.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553207.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaOvisStrMichigan(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma ovis str. Michigan graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaOvisStrMichigan", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415773.protein.info.v11.5.txt",
		        "node_list_path": "1415773.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumGallinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumGallinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "78344.protein.sequences.v11.5.fa",
		        "enrichment_path": "78344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78344.protein.info.v11.5.txt",
		        "node_list_path": "78344.protein.complete.v11.5.txt"
		    }
		]
    )()

def JiulongibacterSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jiulongibacter sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JiulongibacterSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1605367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1605367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1605367.protein.info.v11.5.txt",
		        "node_list_path": "1605367.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusMarmoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus marmoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusMarmoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121381.protein.info.v11.5.txt",
		        "node_list_path": "1121381.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeiothermusTaiwanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusTaiwanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122222.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122222.protein.info.v11.5.txt",
		        "node_list_path": "1122222.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterUreolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter ureolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterUreolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "827.protein.sequences.v11.5.fa",
		        "enrichment_path": "827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "827.protein.info.v11.5.txt",
		        "node_list_path": "827.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusJeojienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus jeojiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusJeojienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "436229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "436229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "436229.clusters.proteins.v11.5.txt",
		        "sequence_path": "436229.protein.sequences.v11.5.fa",
		        "enrichment_path": "436229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436229.protein.info.v11.5.txt",
		        "node_list_path": "436229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "436229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermosiphoAfricanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosipho africanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosiphoAfricanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "484019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "484019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "484019.clusters.proteins.v11.5.txt",
		        "sequence_path": "484019.protein.sequences.v11.5.fa",
		        "enrichment_path": "484019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484019.protein.info.v11.5.txt",
		        "node_list_path": "484019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "484019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo202Full6319Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_02_FULL_63_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202Full6319Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797486.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797486.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797486.protein.info.v11.5.txt",
		        "node_list_path": "1797486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassomonasActiniarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassomonas actiniarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassomonasActiniarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "485447.protein.sequences.v11.5.fa",
		        "enrichment_path": "485447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485447.protein.info.v11.5.txt",
		        "node_list_path": "485447.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetalesBacterium4484113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 4484_113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetalesBacterium4484113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1956161.protein.sequences.v11.5.fa",
		        "enrichment_path": "1956161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1956161.protein.info.v11.5.txt",
		        "node_list_path": "1956161.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporisoriumReilianumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporisorium reilianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporisoriumReilianumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "72558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "72558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "72558.clusters.proteins.v11.5.txt",
		        "sequence_path": "72558.protein.sequences.v11.5.fa",
		        "enrichment_path": "72558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72558.protein.info.v11.5.txt",
		        "node_list_path": "72558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "72558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GrosmanniaClavigera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Grosmannia clavigera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GrosmanniaClavigera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "226899.protein.sequences.v11.5.fa",
		        "enrichment_path": "226899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226899.protein.info.v11.5.txt",
		        "node_list_path": "226899.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaVeterana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia veterana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaVeterana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206743.protein.info.v11.5.txt",
		        "node_list_path": "1206743.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRoot140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRoot140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736460.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736460.protein.info.v11.5.txt",
		        "node_list_path": "1736460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevundimonasNaejangsanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas naejangsanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasNaejangsanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "588932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "588932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "588932.clusters.proteins.v11.5.txt",
		        "sequence_path": "588932.protein.sequences.v11.5.fa",
		        "enrichment_path": "588932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588932.protein.info.v11.5.txt",
		        "node_list_path": "588932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "588932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusSojae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus sojae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusSojae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582851.protein.sequences.v11.5.fa",
		        "enrichment_path": "582851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582851.protein.info.v11.5.txt",
		        "node_list_path": "582851.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumRifcsphigho212Full3622Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium RIFCSPHIGHO2_12_FULL_36_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumRifcsphigho212Full3622Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802376.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802376.protein.info.v11.5.txt",
		        "node_list_path": "1802376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PacificibacterMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pacificibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PacificibacterMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658057.protein.sequences.v11.5.fa",
		        "enrichment_path": "658057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658057.protein.info.v11.5.txt",
		        "node_list_path": "658057.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsphigho202Full4712(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_02_FULL_47_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho202Full4712", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802137.protein.info.v11.5.txt",
		        "node_list_path": "1802137.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph3623(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH 3623 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph3623", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217698.protein.info.v11.5.txt",
		        "node_list_path": "1217698.protein.complete.v11.5.txt"
		    }
		]
    )()

def MillerozymaFarinosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Millerozyma farinosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MillerozymaFarinosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4920.protein.sequences.v11.5.fa",
		        "enrichment_path": "4920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4920.protein.info.v11.5.txt",
		        "node_list_path": "4920.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpYr527Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. YR527 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpYr527Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881028.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881028.protein.info.v11.5.txt",
		        "node_list_path": "1881028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200250816Sch5313054B(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-50816_SCH5313054-b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200250816Sch5313054B", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834092.protein.info.v11.5.txt",
		        "node_list_path": "1834092.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumRifoxyc2Full3521(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYC2_FULL_35_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyc2Full3521", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798452.protein.info.v11.5.txt",
		        "node_list_path": "1798452.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucorCircinelloides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucorCircinelloides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36080.protein.sequences.v11.5.fa",
		        "enrichment_path": "36080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36080.protein.info.v11.5.txt",
		        "node_list_path": "36080.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusNovalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus novalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusNovalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "220687.protein.sequences.v11.5.fa",
		        "enrichment_path": "220687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220687.protein.info.v11.5.txt",
		        "node_list_path": "220687.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "376733.protein.sequences.v11.5.fa",
		        "enrichment_path": "376733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376733.protein.info.v11.5.txt",
		        "node_list_path": "376733.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumEndosymbiontOfPedicinusBadiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Pedicinus badii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumEndosymbiontOfPedicinusBadiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1719126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1719126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1719126.clusters.proteins.v11.5.txt",
		        "sequence_path": "1719126.protein.sequences.v11.5.fa",
		        "enrichment_path": "1719126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1719126.protein.info.v11.5.txt",
		        "node_list_path": "1719126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1719126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSulciaMuelleriSmdsem(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri SMDSEM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSulciaMuelleriSmdsem", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "595499.protein.sequences.v11.5.fa",
		        "enrichment_path": "595499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595499.protein.info.v11.5.txt",
		        "node_list_path": "595499.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifcsphigho201Full5524Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_01_FULL_55_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho201Full5524Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801638.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801638.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801638.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801638.protein.info.v11.5.txt",
		        "node_list_path": "1801638.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801638.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiBl21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli BL21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiBl21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469008.protein.sequences.v11.5.fa",
		        "enrichment_path": "469008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469008.protein.info.v11.5.txt",
		        "node_list_path": "469008.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesResistomycificus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces resistomycificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesResistomycificus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67356.protein.sequences.v11.5.fa",
		        "enrichment_path": "67356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67356.protein.info.v11.5.txt",
		        "node_list_path": "67356.protein.complete.v11.5.txt"
		    }
		]
    )()

def LipotesVexillifer(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lipotes vexillifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LipotesVexillifer", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118797.protein.sequences.v11.5.fa",
		        "enrichment_path": "118797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118797.protein.info.v11.5.txt",
		        "node_list_path": "118797.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhormidesmisPriestleyiAnaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi Ana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhormidesmisPriestleyiAnaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1666911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1666911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1666911.clusters.proteins.v11.5.txt",
		        "sequence_path": "1666911.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666911.protein.info.v11.5.txt",
		        "node_list_path": "1666911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1666911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemellaSanguinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaSanguinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "562983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "562983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "562983.clusters.proteins.v11.5.txt",
		        "sequence_path": "562983.protein.sequences.v11.5.fa",
		        "enrichment_path": "562983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562983.protein.info.v11.5.txt",
		        "node_list_path": "562983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "562983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermicanusAegyptius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermicanus aegyptius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermicanusAegyptius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089548.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089548.protein.info.v11.5.txt",
		        "node_list_path": "1089548.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaBronchialis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia bronchialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaBronchialis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "526226.protein.sequences.v11.5.fa",
		        "enrichment_path": "526226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526226.protein.info.v11.5.txt",
		        "node_list_path": "526226.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumFaeciumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium faecium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumFaeciumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "446465.clusters.info.v11.5.txt",
		        "cluster_tree_path": "446465.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "446465.clusters.proteins.v11.5.txt",
		        "sequence_path": "446465.protein.sequences.v11.5.fa",
		        "enrichment_path": "446465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446465.protein.info.v11.5.txt",
		        "node_list_path": "446465.cluster.nodes.v11.5.txt",
		        "edge_list_path": "446465.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchangiumSpCbG35Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archangium sp. Cb G35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchangiumSpCbG35Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1920190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1920190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1920190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1920190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920190.protein.info.v11.5.txt",
		        "node_list_path": "1920190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1920190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotorhabdusAsymbioticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photorhabdus asymbiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotorhabdusAsymbioticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "291112.clusters.info.v11.5.txt",
		        "cluster_tree_path": "291112.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "291112.clusters.proteins.v11.5.txt",
		        "sequence_path": "291112.protein.sequences.v11.5.fa",
		        "enrichment_path": "291112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "291112.protein.info.v11.5.txt",
		        "node_list_path": "291112.cluster.nodes.v11.5.txt",
		        "edge_list_path": "291112.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NicotianaSylvestris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nicotiana sylvestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NicotianaSylvestris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4096.protein.sequences.v11.5.fa",
		        "enrichment_path": "4096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4096.protein.info.v11.5.txt",
		        "node_list_path": "4096.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodoplanesSpZ2Yc6860(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodoplanes sp. Z2-YC6860 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodoplanesSpZ2Yc6860", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "674703.protein.sequences.v11.5.fa",
		        "enrichment_path": "674703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "674703.protein.info.v11.5.txt",
		        "node_list_path": "674703.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumYad3003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium YAD3003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumYad3003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520816.protein.info.v11.5.txt",
		        "node_list_path": "1520816.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusDendritiformisC454Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus dendritiformis C454 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusDendritiformisC454Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131935.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131935.protein.info.v11.5.txt",
		        "node_list_path": "1131935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterShowaeRm3277(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter showae RM3277 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterShowaeRm3277", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553219.protein.sequences.v11.5.fa",
		        "enrichment_path": "553219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553219.protein.info.v11.5.txt",
		        "node_list_path": "553219.protein.complete.v11.5.txt"
		    }
		]
    )()

def LingulaAnatinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lingula anatina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LingulaAnatinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7574.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7574.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7574.clusters.proteins.v11.5.txt",
		        "sequence_path": "7574.protein.sequences.v11.5.fa",
		        "enrichment_path": "7574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7574.protein.info.v11.5.txt",
		        "node_list_path": "7574.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7574.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanobacteriumPcc7702(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return cyanobacterium PCC7702 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobacteriumPcc7702", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173021.protein.info.v11.5.txt",
		        "node_list_path": "1173021.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumProfundumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium profundum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumProfundumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1714300.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1714300.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1714300.clusters.proteins.v11.5.txt",
		        "sequence_path": "1714300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714300.protein.info.v11.5.txt",
		        "node_list_path": "1714300.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1714300.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaBirtlesiiIbs325Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella birtlesii IBS 325 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaBirtlesiiIbs325Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095900.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095900.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095900.protein.info.v11.5.txt",
		        "node_list_path": "1095900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumFortuitumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium fortuitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumFortuitumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1766.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1766.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1766.clusters.proteins.v11.5.txt",
		        "sequence_path": "1766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1766.protein.info.v11.5.txt",
		        "node_list_path": "1766.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1766.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasSpTw1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. TW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasSpTw1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1561203.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561203.protein.info.v11.5.txt",
		        "node_list_path": "1561203.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeosartoryaFischeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neosartorya fischeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeosartoryaFischeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36630.protein.sequences.v11.5.fa",
		        "enrichment_path": "36630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36630.protein.info.v11.5.txt",
		        "node_list_path": "36630.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioAlginolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioAlginolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "663.protein.sequences.v11.5.fa",
		        "enrichment_path": "663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663.protein.info.v11.5.txt",
		        "node_list_path": "663.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumUasb124(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium UASB124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumUasb124", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1655308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655308.protein.info.v11.5.txt",
		        "node_list_path": "1655308.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpartansiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium spartansii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpartansiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278819.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278819.protein.info.v11.5.txt",
		        "node_list_path": "1278819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHtcc2148Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHtcc2148Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "247634.clusters.info.v11.5.txt",
		        "cluster_tree_path": "247634.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "247634.clusters.proteins.v11.5.txt",
		        "sequence_path": "247634.protein.sequences.v11.5.fa",
		        "enrichment_path": "247634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247634.protein.info.v11.5.txt",
		        "node_list_path": "247634.cluster.nodes.v11.5.txt",
		        "edge_list_path": "247634.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpSyk6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. SYK6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpSyk6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "627192.protein.sequences.v11.5.fa",
		        "enrichment_path": "627192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "627192.protein.info.v11.5.txt",
		        "node_list_path": "627192.protein.complete.v11.5.txt"
		    }
		]
    )()

def LaodelphaxStriatellusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Laodelphax striatellus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LaodelphaxStriatellusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "195883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "195883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "195883.clusters.proteins.v11.5.txt",
		        "sequence_path": "195883.protein.sequences.v11.5.fa",
		        "enrichment_path": "195883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195883.protein.info.v11.5.txt",
		        "node_list_path": "195883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "195883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterChlorophenolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter chlorophenolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterChlorophenolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "452863.protein.sequences.v11.5.fa",
		        "enrichment_path": "452863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452863.protein.info.v11.5.txt",
		        "node_list_path": "452863.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylovorusGlucosetrophus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylovorus glucosetrophus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylovorusGlucosetrophus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582744.protein.sequences.v11.5.fa",
		        "enrichment_path": "582744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582744.protein.info.v11.5.txt",
		        "node_list_path": "582744.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusFleurettii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus fleurettii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusFleurettii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "150056.protein.sequences.v11.5.fa",
		        "enrichment_path": "150056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150056.protein.info.v11.5.txt",
		        "node_list_path": "150056.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArenibacterAlgicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenibacter algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenibacterAlgicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "616991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "616991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "616991.clusters.proteins.v11.5.txt",
		        "sequence_path": "616991.protein.sequences.v11.5.fa",
		        "enrichment_path": "616991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "616991.protein.info.v11.5.txt",
		        "node_list_path": "616991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "616991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AllofrancisellaGuangzhouensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Allofrancisella guangzhouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllofrancisellaGuangzhouensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "594679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "594679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "594679.clusters.proteins.v11.5.txt",
		        "sequence_path": "594679.protein.sequences.v11.5.fa",
		        "enrichment_path": "594679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "594679.protein.info.v11.5.txt",
		        "node_list_path": "594679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "594679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZobelliaUliginosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zobellia uliginosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZobelliaUliginosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "143224.protein.sequences.v11.5.fa",
		        "enrichment_path": "143224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "143224.protein.info.v11.5.txt",
		        "node_list_path": "143224.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumLeiognathiMandapamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi mandapamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumLeiognathiMandapamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1001530.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001530.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001530.protein.info.v11.5.txt",
		        "node_list_path": "1001530.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophagaLonarensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga lonarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaLonarensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1286106.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286106.protein.info.v11.5.txt",
		        "node_list_path": "1286106.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3813(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_38_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3813", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802768.protein.info.v11.5.txt",
		        "node_list_path": "1802768.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumPalustreCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium palustre Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumPalustreCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "153971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "153971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "153971.clusters.proteins.v11.5.txt",
		        "sequence_path": "153971.protein.sequences.v11.5.fa",
		        "enrichment_path": "153971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "153971.protein.info.v11.5.txt",
		        "node_list_path": "153971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "153971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpizellomycesPunctatusDaomBr117Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spizellomyces punctatus DAOM BR117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpizellomycesPunctatusDaomBr117Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "645134.clusters.info.v11.5.txt",
		        "cluster_tree_path": "645134.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "645134.clusters.proteins.v11.5.txt",
		        "sequence_path": "645134.protein.sequences.v11.5.fa",
		        "enrichment_path": "645134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645134.protein.info.v11.5.txt",
		        "node_list_path": "645134.cluster.nodes.v11.5.txt",
		        "edge_list_path": "645134.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMendocinaYmp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina ymp graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMendocinaYmp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "399739.protein.sequences.v11.5.fa",
		        "enrichment_path": "399739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399739.protein.info.v11.5.txt",
		        "node_list_path": "399739.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaCapricolumSubspCapripneumoniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma capricolum subsp. capripneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaCapricolumSubspCapripneumoniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40480.protein.sequences.v11.5.fa",
		        "enrichment_path": "40480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40480.protein.info.v11.5.txt",
		        "node_list_path": "40480.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusCrassostreaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus crassostreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusCrassostreaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1763538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1763538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1763538.clusters.proteins.v11.5.txt",
		        "sequence_path": "1763538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1763538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1763538.protein.info.v11.5.txt",
		        "node_list_path": "1763538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1763538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaGingivalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga gingivalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaGingivalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553178.protein.sequences.v11.5.fa",
		        "enrichment_path": "553178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553178.protein.info.v11.5.txt",
		        "node_list_path": "553178.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCelluloflavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces celluloflavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCelluloflavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "58344.clusters.info.v11.5.txt",
		        "cluster_tree_path": "58344.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "58344.clusters.proteins.v11.5.txt",
		        "sequence_path": "58344.protein.sequences.v11.5.fa",
		        "enrichment_path": "58344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58344.protein.info.v11.5.txt",
		        "node_list_path": "58344.cluster.nodes.v11.5.txt",
		        "edge_list_path": "58344.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusTengchongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus tengchongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusTengchongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "368812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "368812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "368812.clusters.proteins.v11.5.txt",
		        "sequence_path": "368812.protein.sequences.v11.5.fa",
		        "enrichment_path": "368812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "368812.protein.info.v11.5.txt",
		        "node_list_path": "368812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "368812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumMola455Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MOLA455 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumMola455Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1411685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1411685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1411685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1411685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1411685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1411685.protein.info.v11.5.txt",
		        "node_list_path": "1411685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1411685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZeaMaysCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zea mays Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZeaMaysCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4577.clusters.proteins.v11.5.txt",
		        "sequence_path": "4577.protein.sequences.v11.5.fa",
		        "enrichment_path": "4577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4577.protein.info.v11.5.txt",
		        "node_list_path": "4577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaSpCag878(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma sp. CAG:878 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaSpCag878", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262686.protein.info.v11.5.txt",
		        "node_list_path": "1262686.protein.complete.v11.5.txt"
		    }
		]
    )()

def BermanellaMarisrubriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bermanella marisrubri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BermanellaMarisrubriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "207949.clusters.info.v11.5.txt",
		        "cluster_tree_path": "207949.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "207949.clusters.proteins.v11.5.txt",
		        "sequence_path": "207949.protein.sequences.v11.5.fa",
		        "enrichment_path": "207949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "207949.protein.info.v11.5.txt",
		        "node_list_path": "207949.cluster.nodes.v11.5.txt",
		        "edge_list_path": "207949.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpH1aiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. H1ai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpH1aiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408813.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408813.protein.info.v11.5.txt",
		        "node_list_path": "1408813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaHellenicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella hellenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaHellenicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46256.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46256.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46256.clusters.proteins.v11.5.txt",
		        "sequence_path": "46256.protein.sequences.v11.5.fa",
		        "enrichment_path": "46256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46256.protein.info.v11.5.txt",
		        "node_list_path": "46256.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46256.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg167013(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_70_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg167013", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797662.protein.info.v11.5.txt",
		        "node_list_path": "1797662.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachanceaDasiensisCbs10888Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachancea dasiensis CBS 10888 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachanceaDasiensisCbs10888Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1266660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1266660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1266660.clusters.proteins.v11.5.txt",
		        "sequence_path": "1266660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266660.protein.info.v11.5.txt",
		        "node_list_path": "1266660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1266660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium6247Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 62-47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium6247Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895811.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895811.protein.info.v11.5.txt",
		        "node_list_path": "1895811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpathasporaPassalidarumNrrlY27907(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spathaspora passalidarum NRRL Y-27907 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpathasporaPassalidarumNrrlY27907", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "619300.protein.sequences.v11.5.fa",
		        "enrichment_path": "619300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "619300.protein.info.v11.5.txt",
		        "node_list_path": "619300.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaMarisrubriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria marisrubri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaMarisrubriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1685379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1685379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1685379.clusters.proteins.v11.5.txt",
		        "sequence_path": "1685379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685379.protein.info.v11.5.txt",
		        "node_list_path": "1685379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1685379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudocercosporaFijiensisCirad86(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudocercospora fijiensis CIRAD86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudocercosporaFijiensisCirad86", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "383855.protein.sequences.v11.5.fa",
		        "enrichment_path": "383855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "383855.protein.info.v11.5.txt",
		        "node_list_path": "383855.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSoil764(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil764 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSoil764", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736403.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736403.protein.info.v11.5.txt",
		        "node_list_path": "1736403.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumResinovorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium resinovorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumResinovorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "158500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "158500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "158500.clusters.proteins.v11.5.txt",
		        "sequence_path": "158500.protein.sequences.v11.5.fa",
		        "enrichment_path": "158500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158500.protein.info.v11.5.txt",
		        "node_list_path": "158500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "158500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IlyobacterPolytropusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ilyobacter polytropus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IlyobacterPolytropusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "572544.clusters.info.v11.5.txt",
		        "cluster_tree_path": "572544.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "572544.clusters.proteins.v11.5.txt",
		        "sequence_path": "572544.protein.sequences.v11.5.fa",
		        "enrichment_path": "572544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572544.protein.info.v11.5.txt",
		        "node_list_path": "572544.cluster.nodes.v11.5.txt",
		        "edge_list_path": "572544.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc078h07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC078H07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc078h07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739379.protein.info.v11.5.txt",
		        "node_list_path": "1739379.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaballeroniaGlatheiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia glathei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaGlatheiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "60547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "60547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "60547.clusters.proteins.v11.5.txt",
		        "sequence_path": "60547.protein.sequences.v11.5.fa",
		        "enrichment_path": "60547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60547.protein.info.v11.5.txt",
		        "node_list_path": "60547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "60547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterCaeniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterCaeniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "288992.clusters.info.v11.5.txt",
		        "cluster_tree_path": "288992.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "288992.clusters.proteins.v11.5.txt",
		        "sequence_path": "288992.protein.sequences.v11.5.fa",
		        "enrichment_path": "288992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "288992.protein.info.v11.5.txt",
		        "node_list_path": "288992.cluster.nodes.v11.5.txt",
		        "edge_list_path": "288992.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSpCg232(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. CG23_2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSpCg232", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1706231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1706231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1706231.protein.info.v11.5.txt",
		        "node_list_path": "1706231.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpBsw20308Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. Bsw20308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpBsw20308Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "283699.clusters.info.v11.5.txt",
		        "cluster_tree_path": "283699.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "283699.clusters.proteins.v11.5.txt",
		        "sequence_path": "283699.protein.sequences.v11.5.fa",
		        "enrichment_path": "283699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283699.protein.info.v11.5.txt",
		        "node_list_path": "283699.cluster.nodes.v11.5.txt",
		        "edge_list_path": "283699.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConiochaetaPulveracea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coniochaeta pulveracea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConiochaetaPulveracea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "177199.protein.sequences.v11.5.fa",
		        "enrichment_path": "177199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "177199.protein.info.v11.5.txt",
		        "node_list_path": "177199.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasHengshuiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas hengshuiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasHengshuiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1609977.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1609977.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1609977.clusters.proteins.v11.5.txt",
		        "sequence_path": "1609977.protein.sequences.v11.5.fa",
		        "enrichment_path": "1609977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1609977.protein.info.v11.5.txt",
		        "node_list_path": "1609977.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1609977.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ApisCeranaCeranaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Apis cerana cerana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApisCeranaCeranaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "94128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "94128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "94128.clusters.proteins.v11.5.txt",
		        "sequence_path": "94128.protein.sequences.v11.5.fa",
		        "enrichment_path": "94128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94128.protein.info.v11.5.txt",
		        "node_list_path": "94128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "94128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpNuni2hMbin003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nuni2H_MBin003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpNuni2hMbin003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884657.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884657.protein.info.v11.5.txt",
		        "node_list_path": "1884657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusApisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus apis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusApisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "303541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "303541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "303541.clusters.proteins.v11.5.txt",
		        "sequence_path": "303541.protein.sequences.v11.5.fa",
		        "enrichment_path": "303541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "303541.protein.info.v11.5.txt",
		        "node_list_path": "303541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "303541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysobacterSpRoot494Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root494 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterSpRoot494Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736549.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736549.protein.info.v11.5.txt",
		        "node_list_path": "1736549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusWulumuqiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus wulumuqiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusWulumuqiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288484.protein.info.v11.5.txt",
		        "node_list_path": "1288484.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusInfantisXCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis X Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusInfantisXCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "997830.clusters.info.v11.5.txt",
		        "cluster_tree_path": "997830.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "997830.clusters.proteins.v11.5.txt",
		        "sequence_path": "997830.protein.sequences.v11.5.fa",
		        "enrichment_path": "997830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997830.protein.info.v11.5.txt",
		        "node_list_path": "997830.cluster.nodes.v11.5.txt",
		        "edge_list_path": "997830.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpBgi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Bgi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpBgi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1186051.protein.sequences.v11.0.fa",
		        "enrichment_path": "1186051.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1186051.protein.info.v11.0.txt",
		        "node_list_path": "1186051.protein.complete.v11.0.txt"
		    }
		]
    )()

def HaloglycomycesAlbus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloglycomyces albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloglycomycesAlbus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089549.protein.info.v11.5.txt",
		        "node_list_path": "1089549.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumAStrAtcc3502(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum A str. ATCC 3502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumAStrAtcc3502", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "413999.protein.sequences.v11.5.fa",
		        "enrichment_path": "413999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "413999.protein.info.v11.5.txt",
		        "node_list_path": "413999.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpFw1012bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. FW1012B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpFw1012bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644968.clusters.proteins.v11.5.txt",
		        "sequence_path": "644968.protein.sequences.v11.5.fa",
		        "enrichment_path": "644968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644968.protein.info.v11.5.txt",
		        "node_list_path": "644968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCoagulans26Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coagulans 26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCoagulans26Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "941639.clusters.info.v11.5.txt",
		        "cluster_tree_path": "941639.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "941639.clusters.proteins.v11.5.txt",
		        "sequence_path": "941639.protein.sequences.v11.5.fa",
		        "enrichment_path": "941639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "941639.protein.info.v11.5.txt",
		        "node_list_path": "941639.cluster.nodes.v11.5.txt",
		        "edge_list_path": "941639.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfacinumInfernumDsm9756Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfacinum infernum DSM 9756 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfacinumInfernumDsm9756Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121391.protein.info.v11.5.txt",
		        "node_list_path": "1121391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaSchinkiiDsm10518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia schinkii DSM 10518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaSchinkiiDsm10518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410649.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410649.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410649.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410649.protein.info.v11.5.txt",
		        "node_list_path": "1410649.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410649.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CesiribacterAndamanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cesiribacter andamanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CesiribacterAndamanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1279009.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1279009.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1279009.clusters.proteins.v11.5.txt",
		        "sequence_path": "1279009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1279009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1279009.protein.info.v11.5.txt",
		        "node_list_path": "1279009.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1279009.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RodentibacterGenomosp1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter genomosp. 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterGenomosp1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1908264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1908264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1908264.clusters.proteins.v11.5.txt",
		        "sequence_path": "1908264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908264.protein.info.v11.5.txt",
		        "node_list_path": "1908264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1908264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacillusStearothermophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus stearothermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusStearothermophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1295642.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1295642.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1295642.clusters.proteins.v11.5.txt",
		        "sequence_path": "1295642.protein.sequences.v11.5.fa",
		        "enrichment_path": "1295642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1295642.protein.info.v11.5.txt",
		        "node_list_path": "1295642.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1295642.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAndersenbacteriaBacteriumRifcsphigho201Full4636Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Andersenbacteria bacterium RIFCSPHIGHO2_01_FULL_46_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAndersenbacteriaBacteriumRifcsphigho201Full4636Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797278.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797278.protein.info.v11.5.txt",
		        "node_list_path": "1797278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MangrovimonasYunxiaonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mangrovimonas yunxiaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MangrovimonasYunxiaonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1197477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197477.protein.info.v11.5.txt",
		        "node_list_path": "1197477.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumEligensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium eligens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumEligensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "515620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "515620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "515620.clusters.proteins.v11.5.txt",
		        "sequence_path": "515620.protein.sequences.v11.5.fa",
		        "enrichment_path": "515620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515620.protein.info.v11.5.txt",
		        "node_list_path": "515620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "515620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc2387Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC2_38_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc2387Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618920.protein.info.v11.5.txt",
		        "node_list_path": "1618920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KetogulonicigeniumRobustumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ketogulonicigenium robustum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KetogulonicigeniumRobustumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "92947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "92947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "92947.clusters.proteins.v11.5.txt",
		        "sequence_path": "92947.protein.sequences.v11.5.fa",
		        "enrichment_path": "92947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92947.protein.info.v11.5.txt",
		        "node_list_path": "92947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "92947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OvisAries(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ovis aries graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OvisAries", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9940.protein.sequences.v11.5.fa",
		        "enrichment_path": "9940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9940.protein.info.v11.5.txt",
		        "node_list_path": "9940.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonasPusillaCcmp1545(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonas pusilla CCMP1545 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonasPusillaCcmp1545", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "564608.protein.sequences.v11.5.fa",
		        "enrichment_path": "564608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "564608.protein.info.v11.5.txt",
		        "node_list_path": "564608.protein.complete.v11.5.txt"
		    }
		]
    )()

def RozellaAllomycisCsf55(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rozella allomycis CSF55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RozellaAllomycisCsf55", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "988480.protein.sequences.v11.5.fa",
		        "enrichment_path": "988480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "988480.protein.info.v11.5.txt",
		        "node_list_path": "988480.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumGp2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium GP2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumGp2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807746.protein.info.v11.5.txt",
		        "node_list_path": "1807746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaplasmaMarginaleStCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma marginale St. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaplasmaMarginaleStCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "234826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "234826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "234826.clusters.proteins.v11.5.txt",
		        "sequence_path": "234826.protein.sequences.v11.5.fa",
		        "enrichment_path": "234826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "234826.protein.info.v11.5.txt",
		        "node_list_path": "234826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "234826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumA37t11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium A37T11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumA37t11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855384.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855384.protein.info.v11.5.txt",
		        "node_list_path": "1855384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CephalotusFollicularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cephalotus follicularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CephalotusFollicularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3775.protein.sequences.v11.5.fa",
		        "enrichment_path": "3775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3775.protein.info.v11.5.txt",
		        "node_list_path": "3775.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24218Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_42_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24218Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618821.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618821.protein.info.v11.5.txt",
		        "node_list_path": "1618821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpOv700Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. OV700 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpOv700Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882826.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882826.protein.info.v11.5.txt",
		        "node_list_path": "1882826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpL21syrab(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. L21SyrAB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpL21syrab", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1307759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307759.protein.info.v11.5.txt",
		        "node_list_path": "1307759.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesGerencseriaeDsm6844Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces gerencseriae DSM 6844 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesGerencseriaeDsm6844Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120943.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120943.protein.info.v11.5.txt",
		        "node_list_path": "1120943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho202Full5012Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_02_FULL_50_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho202Full5012Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802685.protein.info.v11.5.txt",
		        "node_list_path": "1802685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpTs2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. TS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpTs2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1450694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1450694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1450694.clusters.proteins.v11.5.txt",
		        "sequence_path": "1450694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450694.protein.info.v11.5.txt",
		        "node_list_path": "1450694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1450694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermomonosporaCurvata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermomonospora curvata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermomonosporaCurvata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471852.protein.sequences.v11.5.fa",
		        "enrichment_path": "471852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471852.protein.info.v11.5.txt",
		        "node_list_path": "471852.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwa24015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_40_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwa24015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797319.protein.info.v11.5.txt",
		        "node_list_path": "1797319.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterThermophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterThermophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1197874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197874.protein.info.v11.5.txt",
		        "node_list_path": "1197874.protein.complete.v11.5.txt"
		    }
		]
    )()

def PustulibacteriumMarinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pustulibacterium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PustulibacteriumMarinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1224947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224947.protein.info.v11.5.txt",
		        "node_list_path": "1224947.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterSpMit975078Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. MIT975078 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSpMit975078Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1548153.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1548153.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1548153.clusters.proteins.v11.5.txt",
		        "sequence_path": "1548153.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548153.protein.info.v11.5.txt",
		        "node_list_path": "1548153.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1548153.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeucobacterChironomiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter chironomi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterChironomiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122175.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122175.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122175.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122175.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122175.protein.info.v11.5.txt",
		        "node_list_path": "1122175.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122175.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumAntarcticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumAntarcticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "416450.protein.sequences.v11.5.fa",
		        "enrichment_path": "416450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416450.protein.info.v11.5.txt",
		        "node_list_path": "416450.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpRs01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. RS01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpRs01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1924286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1924286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1924286.protein.info.v11.5.txt",
		        "node_list_path": "1924286.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaSpPamc20917(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia sp. PAMC 20917 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaSpPamc20917", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816218.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816218.protein.info.v11.5.txt",
		        "node_list_path": "1816218.protein.complete.v11.5.txt"
		    }
		]
    )()

def KitasatosporaSpRoot187(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora sp. Root187 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaSpRoot187", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736486.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736486.protein.info.v11.5.txt",
		        "node_list_path": "1736486.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumBrhC25(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium BRH_c25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumBrhC25", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1734399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1734399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1734399.protein.info.v11.5.txt",
		        "node_list_path": "1734399.protein.complete.v11.5.txt"
		    }
		]
    )()

def CephaloticoccusCapnophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cephaloticoccus capnophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CephaloticoccusCapnophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1548208.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548208.protein.info.v11.5.txt",
		        "node_list_path": "1548208.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumScgcAaa164E04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium SCGC AAA164-E04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumScgcAaa164E04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1009415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1009415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1009415.clusters.proteins.v11.5.txt",
		        "sequence_path": "1009415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009415.protein.info.v11.5.txt",
		        "node_list_path": "1009415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1009415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaSpCag309Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:309 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSpCag309Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262945.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262945.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262945.protein.info.v11.5.txt",
		        "node_list_path": "1262945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaCitriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma citri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaCitriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2133.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2133.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2133.clusters.proteins.v11.5.txt",
		        "sequence_path": "2133.protein.sequences.v11.5.fa",
		        "enrichment_path": "2133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2133.protein.info.v11.5.txt",
		        "node_list_path": "2133.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2133.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyopneumoniaeJ(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae J graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyopneumoniaeJ", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262719.protein.sequences.v11.5.fa",
		        "enrichment_path": "262719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262719.protein.info.v11.5.txt",
		        "node_list_path": "262719.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesSpCag268Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:268 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpCag268Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262693.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262693.protein.info.v11.5.txt",
		        "node_list_path": "1262693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusMetallidurans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus metallidurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusMetallidurans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266264.protein.sequences.v11.5.fa",
		        "enrichment_path": "266264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266264.protein.info.v11.5.txt",
		        "node_list_path": "266264.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpKms(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KMS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpKms", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566023.protein.info.v11.5.txt",
		        "node_list_path": "1566023.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacteraceaeBacteriumCg1023614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacteraceae bacterium CG1_02_36_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacteraceaeBacteriumCg1023614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805214.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805214.protein.info.v11.5.txt",
		        "node_list_path": "1805214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFabifermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fabifermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFabifermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1400520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400520.protein.info.v11.5.txt",
		        "node_list_path": "1400520.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1844972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1844972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1844972.clusters.proteins.v11.5.txt",
		        "sequence_path": "1844972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1844972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1844972.protein.info.v11.5.txt",
		        "node_list_path": "1844972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1844972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumMucogenicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium mucogenicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumMucogenicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56689.clusters.proteins.v11.5.txt",
		        "sequence_path": "56689.protein.sequences.v11.5.fa",
		        "enrichment_path": "56689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56689.protein.info.v11.5.txt",
		        "node_list_path": "56689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AscochytaRabiei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ascochyta rabiei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AscochytaRabiei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5454.protein.sequences.v11.5.fa",
		        "enrichment_path": "5454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5454.protein.info.v11.5.txt",
		        "node_list_path": "5454.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium4616Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 46-16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium4616Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895925.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895925.protein.info.v11.5.txt",
		        "node_list_path": "1895925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErysipelotrichaceaeBacterium3153Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium 3153 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelotrichaceaeBacterium3153Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658659.clusters.proteins.v11.5.txt",
		        "sequence_path": "658659.protein.sequences.v11.5.fa",
		        "enrichment_path": "658659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658659.protein.info.v11.5.txt",
		        "node_list_path": "658659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumBrisbanense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium brisbanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumBrisbanense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "146020.protein.sequences.v11.5.fa",
		        "enrichment_path": "146020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146020.protein.info.v11.5.txt",
		        "node_list_path": "146020.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAc2028(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAc2028", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408321.protein.info.v11.5.txt",
		        "node_list_path": "1408321.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeminicoccusRoseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geminicoccus roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeminicoccusRoseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089551.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089551.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089551.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089551.protein.info.v11.5.txt",
		        "node_list_path": "1089551.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089551.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasFragariae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas fragariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasFragariae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131451.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131451.protein.info.v11.5.txt",
		        "node_list_path": "1131451.protein.complete.v11.5.txt"
		    }
		]
    )()

def TepidibacterThalassicusDsm15285(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tepidibacter thalassicus DSM 15285 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidibacterThalassicusDsm15285", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123350.protein.info.v11.5.txt",
		        "node_list_path": "1123350.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusCarbonariusItem5010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus carbonarius ITEM 5010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusCarbonariusItem5010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "602072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "602072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "602072.clusters.proteins.v11.5.txt",
		        "sequence_path": "602072.protein.sequences.v11.5.fa",
		        "enrichment_path": "602072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "602072.protein.info.v11.5.txt",
		        "node_list_path": "602072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "602072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumAcetoxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum acetoxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumAcetoxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "485916.protein.sequences.v11.5.fa",
		        "enrichment_path": "485916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485916.protein.info.v11.5.txt",
		        "node_list_path": "485916.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium4393(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 43-93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium4393", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895924.protein.info.v11.5.txt",
		        "node_list_path": "1895924.protein.complete.v11.5.txt"
		    }
		]
    )()

def AchromobacterXylosoxidansA8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans A8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterXylosoxidansA8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762376.clusters.proteins.v11.5.txt",
		        "sequence_path": "762376.protein.sequences.v11.5.fa",
		        "enrichment_path": "762376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762376.protein.info.v11.5.txt",
		        "node_list_path": "762376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BeggiatoaLeptomitoformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Beggiatoa leptomitoformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeggiatoaLeptomitoformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "288004.protein.sequences.v11.5.fa",
		        "enrichment_path": "288004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "288004.protein.info.v11.5.txt",
		        "node_list_path": "288004.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumEtli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumEtli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29449.protein.sequences.v11.5.fa",
		        "enrichment_path": "29449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29449.protein.info.v11.5.txt",
		        "node_list_path": "29449.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwa24010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_40_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa24010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619037.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619037.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619037.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619037.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619037.protein.info.v11.5.txt",
		        "node_list_path": "1619037.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619037.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumCg10244142Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG1_02_44_142 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumCg10244142Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805276.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805276.protein.info.v11.5.txt",
		        "node_list_path": "1805276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRbg16378Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_37_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg16378Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798371.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798371.protein.info.v11.5.txt",
		        "node_list_path": "1798371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumFrediiUsda257Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii USDA257 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumFrediiUsda257Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1185652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1185652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1185652.clusters.proteins.v11.5.txt",
		        "sequence_path": "1185652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185652.protein.info.v11.5.txt",
		        "node_list_path": "1185652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1185652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloarculaSpCba1127(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula sp. CBA1127 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaSpCba1127", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1765055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765055.protein.info.v11.5.txt",
		        "node_list_path": "1765055.protein.complete.v11.5.txt"
		    }
		]
    )()

def MannheimiaHaemolyticaSerotypeA2BovineCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica serotype A2 BOVINE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaHaemolyticaSerotypeA2BovineCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "669262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "669262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "669262.clusters.proteins.v11.5.txt",
		        "sequence_path": "669262.protein.sequences.v11.5.fa",
		        "enrichment_path": "669262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "669262.protein.info.v11.5.txt",
		        "node_list_path": "669262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "669262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobiumPhaeobacteroidesBs1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium phaeobacteroides BS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumPhaeobacteroidesBs1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "331678.protein.sequences.v11.5.fa",
		        "enrichment_path": "331678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331678.protein.info.v11.5.txt",
		        "node_list_path": "331678.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumViciae3841Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae 3841 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumViciae3841Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216596.clusters.proteins.v11.5.txt",
		        "sequence_path": "216596.protein.sequences.v11.5.fa",
		        "enrichment_path": "216596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216596.protein.info.v11.5.txt",
		        "node_list_path": "216596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaSpCag257(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blautia sp. CAG:257 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaSpCag257", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262756.protein.info.v11.5.txt",
		        "node_list_path": "1262756.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriRch2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri RCH2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriRch2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644801.protein.sequences.v11.5.fa",
		        "enrichment_path": "644801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644801.protein.info.v11.5.txt",
		        "node_list_path": "644801.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButtiauxellaAgrestisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buttiauxella agrestis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButtiauxellaAgrestisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1006004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1006004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1006004.clusters.proteins.v11.5.txt",
		        "sequence_path": "1006004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1006004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1006004.protein.info.v11.5.txt",
		        "node_list_path": "1006004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1006004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanibacterHoylei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janibacter hoylei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterHoylei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210046.protein.info.v11.5.txt",
		        "node_list_path": "1210046.protein.complete.v11.5.txt"
		    }
		]
    )()

def LutibaculumBaratangense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lutibaculum baratangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutibaculumBaratangense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "631454.protein.sequences.v11.5.fa",
		        "enrichment_path": "631454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "631454.protein.info.v11.5.txt",
		        "node_list_path": "631454.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosopumilusSpLsAoaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. LS_AOA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopumilusSpLsAoaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671876.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671876.protein.info.v11.5.txt",
		        "node_list_path": "1671876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaProteobacteriumAap65(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return beta proteobacterium AAP65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaProteobacteriumAap65", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523424.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523424.protein.info.v11.5.txt",
		        "node_list_path": "1523424.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoruegeriaSabulilitorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoruegeria sabulilitoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoruegeriaSabulilitorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1510458.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1510458.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1510458.clusters.proteins.v11.5.txt",
		        "sequence_path": "1510458.protein.sequences.v11.5.fa",
		        "enrichment_path": "1510458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1510458.protein.info.v11.5.txt",
		        "node_list_path": "1510458.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1510458.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerrabacterSp28(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terrabacter sp. 28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrabacterSp28", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619947.protein.info.v11.5.txt",
		        "node_list_path": "1619947.protein.complete.v11.5.txt"
		    }
		]
    )()

def MannheimiaMassilioguelmaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia massilioguelmaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaMassilioguelmaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1604354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1604354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1604354.clusters.proteins.v11.5.txt",
		        "sequence_path": "1604354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1604354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1604354.protein.info.v11.5.txt",
		        "node_list_path": "1604354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1604354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlegusellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olegusella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlegusellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776381.protein.info.v11.5.txt",
		        "node_list_path": "1776381.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermosiphoAfricanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermosipho africanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosiphoAfricanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "484019.protein.sequences.v11.5.fa",
		        "enrichment_path": "484019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484019.protein.info.v11.5.txt",
		        "node_list_path": "484019.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpRoot102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpRoot102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736422.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736422.protein.info.v11.5.txt",
		        "node_list_path": "1736422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerminephrobacterEiseniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verminephrobacter eiseniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerminephrobacterEiseniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391735.clusters.proteins.v11.5.txt",
		        "sequence_path": "391735.protein.sequences.v11.5.fa",
		        "enrichment_path": "391735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391735.protein.info.v11.5.txt",
		        "node_list_path": "391735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusOrientis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus orientis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusOrientis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "768706.protein.sequences.v11.5.fa",
		        "enrichment_path": "768706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768706.protein.info.v11.5.txt",
		        "node_list_path": "768706.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpCf125(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. CF125 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpCf125", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855303.protein.info.v11.5.txt",
		        "node_list_path": "1855303.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaSpUcdKl21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. UCD-KL21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSpUcdKl21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1917164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1917164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1917164.clusters.proteins.v11.5.txt",
		        "sequence_path": "1917164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917164.protein.info.v11.5.txt",
		        "node_list_path": "1917164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1917164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StereumHirsutumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stereum hirsutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StereumHirsutumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40492.clusters.proteins.v11.5.txt",
		        "sequence_path": "40492.protein.sequences.v11.5.fa",
		        "enrichment_path": "40492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40492.protein.info.v11.5.txt",
		        "node_list_path": "40492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpOralTaxon136Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpOralTaxon136Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "713030.clusters.info.v11.5.txt",
		        "cluster_tree_path": "713030.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "713030.clusters.proteins.v11.5.txt",
		        "sequence_path": "713030.protein.sequences.v11.5.fa",
		        "enrichment_path": "713030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713030.protein.info.v11.5.txt",
		        "node_list_path": "713030.cluster.nodes.v11.5.txt",
		        "edge_list_path": "713030.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterGuillouiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter guillouiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterGuillouiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217656.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217656.protein.info.v11.5.txt",
		        "node_list_path": "1217656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterBrevisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterBrevisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "74348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "74348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "74348.clusters.proteins.v11.5.txt",
		        "sequence_path": "74348.protein.sequences.v11.5.fa",
		        "enrichment_path": "74348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74348.protein.info.v11.5.txt",
		        "node_list_path": "74348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "74348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumParafortuitum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium parafortuitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumParafortuitum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39692.protein.sequences.v11.5.fa",
		        "enrichment_path": "39692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39692.protein.info.v11.5.txt",
		        "node_list_path": "39692.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaSpHmsc064e01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC064E01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSpHmsc064e01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1715052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715052.protein.info.v11.5.txt",
		        "node_list_path": "1715052.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenisporosarcinaSpTg14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenisporosarcina sp. TG14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenisporosarcinaSpTg14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231057.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231057.protein.info.v11.5.txt",
		        "node_list_path": "1231057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyorhinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyorhinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2100.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2100.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2100.clusters.proteins.v11.5.txt",
		        "sequence_path": "2100.protein.sequences.v11.5.fa",
		        "enrichment_path": "2100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2100.protein.info.v11.5.txt",
		        "node_list_path": "2100.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2100.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4716b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_47_16b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4716b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802142.protein.info.v11.5.txt",
		        "node_list_path": "1802142.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobiumTepidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium tepidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumTepidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "194439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "194439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "194439.clusters.proteins.v11.5.txt",
		        "sequence_path": "194439.protein.sequences.v11.5.fa",
		        "enrichment_path": "194439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "194439.protein.info.v11.5.txt",
		        "node_list_path": "194439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "194439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusTaiwanensisDsm18679Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus taiwanensis DSM 18679 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusTaiwanensisDsm18679Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122926.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122926.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122926.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122926.protein.info.v11.5.txt",
		        "node_list_path": "1122926.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122926.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SnodgrassellaSpCfcc13594(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Snodgrassella sp. CFCC 13594 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SnodgrassellaSpCfcc13594", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1775559.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775559.protein.info.v11.5.txt",
		        "node_list_path": "1775559.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslH70331(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSL H7-0331 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslH70331", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1920421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920421.protein.info.v11.5.txt",
		        "node_list_path": "1920421.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorchorusOlitorius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corchorus olitorius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorchorusOlitorius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93759.protein.sequences.v11.5.fa",
		        "enrichment_path": "93759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93759.protein.info.v11.5.txt",
		        "node_list_path": "93759.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterOralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter oralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterOralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66851.protein.sequences.v11.5.fa",
		        "enrichment_path": "66851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66851.protein.info.v11.5.txt",
		        "node_list_path": "66851.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyadobacterSp5039Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter sp. 50-39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterSp5039Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895756.protein.info.v11.5.txt",
		        "node_list_path": "1895756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCurvatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus curvatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCurvatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1074451.protein.sequences.v11.5.fa",
		        "enrichment_path": "1074451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1074451.protein.info.v11.5.txt",
		        "node_list_path": "1074451.protein.complete.v11.5.txt"
		    }
		]
    )()

def DialisterMicraerophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dialister micraerophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterMicraerophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888062.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888062.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888062.clusters.proteins.v11.5.txt",
		        "sequence_path": "888062.protein.sequences.v11.5.fa",
		        "enrichment_path": "888062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888062.protein.info.v11.5.txt",
		        "node_list_path": "888062.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888062.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloarculaArgentinensisDsm12282(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula argentinensis DSM 12282 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaArgentinensisDsm12282", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230451.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230451.protein.info.v11.5.txt",
		        "node_list_path": "1230451.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesGeorgiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces georgiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesGeorgiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120942.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120942.protein.info.v11.5.txt",
		        "node_list_path": "1120942.protein.complete.v11.5.txt"
		    }
		]
    )()

def BaudoiniaCompniacensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Baudoinia compniacensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BaudoiniaCompniacensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "430998.protein.sequences.v11.5.fa",
		        "enrichment_path": "430998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "430998.protein.info.v11.5.txt",
		        "node_list_path": "430998.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200210029Sch5224772(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-10029_SCH5224772 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200210029Sch5224772", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834083.protein.info.v11.5.txt",
		        "node_list_path": "1834083.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumLarrymooreiAf310Atcc51759Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium larrymoorei AF3.10 ATCC 51759 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumLarrymooreiAf310Atcc51759Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1367849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1367849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1367849.clusters.proteins.v11.5.txt",
		        "sequence_path": "1367849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1367849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1367849.protein.info.v11.5.txt",
		        "node_list_path": "1367849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1367849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopirellulaSpSwk7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopirellula sp. SWK7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopirellulaSpSwk7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "595460.protein.sequences.v11.5.fa",
		        "enrichment_path": "595460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595460.protein.info.v11.5.txt",
		        "node_list_path": "595460.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallionellalesBacteriumGwa26018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_60_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallionellalesBacteriumGwa26018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798247.protein.info.v11.5.txt",
		        "node_list_path": "1798247.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaRettgeriDsm1131(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Providencia rettgeri DSM1131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaRettgeriDsm1131", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521000.protein.sequences.v11.5.fa",
		        "enrichment_path": "521000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521000.protein.info.v11.5.txt",
		        "node_list_path": "521000.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpEm1321(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. EM1321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpEm1321", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1492738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1492738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1492738.protein.info.v11.5.txt",
		        "node_list_path": "1492738.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusSpBgCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. BG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusSpBgCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1633135.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1633135.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1633135.clusters.proteins.v11.5.txt",
		        "sequence_path": "1633135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1633135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1633135.protein.info.v11.5.txt",
		        "node_list_path": "1633135.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1633135.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSalivae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella salivae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSalivae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888832.protein.sequences.v11.5.fa",
		        "enrichment_path": "888832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888832.protein.info.v11.5.txt",
		        "node_list_path": "888832.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusKribbensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus kribbensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusKribbensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "172713.protein.sequences.v11.5.fa",
		        "enrichment_path": "172713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "172713.protein.info.v11.5.txt",
		        "node_list_path": "172713.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSulphureus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sulphureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSulphureus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123321.protein.info.v11.5.txt",
		        "node_list_path": "1123321.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusFarraginis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus farraginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFarraginis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423743.protein.info.v11.5.txt",
		        "node_list_path": "1423743.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChrysiogenesArsenatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chrysiogenes arsenatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChrysiogenesArsenatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118005.protein.sequences.v11.5.fa",
		        "enrichment_path": "118005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118005.protein.info.v11.5.txt",
		        "node_list_path": "118005.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumAlbertimagniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium albertimagni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumAlbertimagniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1156935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1156935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1156935.clusters.proteins.v11.5.txt",
		        "sequence_path": "1156935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156935.protein.info.v11.5.txt",
		        "node_list_path": "1156935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1156935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaSp25mfcol41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. 25mfcol4.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSp25mfcol41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761899.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761899.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761899.protein.info.v11.5.txt",
		        "node_list_path": "1761899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterXylosoxidansA8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans A8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterXylosoxidansA8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762376.protein.sequences.v11.5.fa",
		        "enrichment_path": "762376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762376.protein.info.v11.5.txt",
		        "node_list_path": "762376.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpartansii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium spartansii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpartansii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278819.protein.info.v11.5.txt",
		        "node_list_path": "1278819.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp11mf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 11MF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp11mf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1169146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169146.protein.info.v11.5.txt",
		        "node_list_path": "1169146.protein.complete.v11.5.txt"
		    }
		]
    )()

def GossypiumHirsutum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gossypium hirsutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GossypiumHirsutum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3635.protein.sequences.v11.5.fa",
		        "enrichment_path": "3635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3635.protein.info.v11.5.txt",
		        "node_list_path": "3635.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrinemaPellirubrumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrinema pellirubrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrinemaPellirubrumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "797303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "797303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "797303.clusters.proteins.v11.5.txt",
		        "sequence_path": "797303.protein.sequences.v11.5.fa",
		        "enrichment_path": "797303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797303.protein.info.v11.5.txt",
		        "node_list_path": "797303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "797303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NiastellaKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Niastella koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiastellaKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "700598.protein.sequences.v11.5.fa",
		        "enrichment_path": "700598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "700598.protein.info.v11.5.txt",
		        "node_list_path": "700598.protein.complete.v11.5.txt"
		    }
		]
    )()

def KinetoplastibacteriumCrithidii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium crithidii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KinetoplastibacteriumCrithidii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208918.protein.info.v11.5.txt",
		        "node_list_path": "1208918.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaMediterranea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella mediterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaMediterranea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871031.protein.info.v11.5.txt",
		        "node_list_path": "1871031.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpLm4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. LM4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpLm4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1938609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938609.protein.info.v11.5.txt",
		        "node_list_path": "1938609.protein.complete.v11.5.txt"
		    }
		]
    )()

def FuerstiaMarisgermanicaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fuerstia marisgermanicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FuerstiaMarisgermanicaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1891926.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1891926.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1891926.clusters.proteins.v11.5.txt",
		        "sequence_path": "1891926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891926.protein.info.v11.5.txt",
		        "node_list_path": "1891926.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1891926.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinopolymorphaAlba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinopolymorpha alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolymorphaAlba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120950.protein.info.v11.5.txt",
		        "node_list_path": "1120950.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseobacterSpSk20926(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. SK20926 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterSpSk20926", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "388739.protein.sequences.v11.5.fa",
		        "enrichment_path": "388739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388739.protein.info.v11.5.txt",
		        "node_list_path": "388739.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusAlkenifer(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus alkenifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusAlkenifer", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "65735.protein.sequences.v11.5.fa",
		        "enrichment_path": "65735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65735.protein.info.v11.5.txt",
		        "node_list_path": "65735.protein.complete.v11.5.txt"
		    }
		]
    )()

def KluyveraAscorbataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kluyvera ascorbata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KluyveraAscorbataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1006000.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1006000.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1006000.clusters.proteins.v11.5.txt",
		        "sequence_path": "1006000.protein.sequences.v11.5.fa",
		        "enrichment_path": "1006000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1006000.protein.info.v11.5.txt",
		        "node_list_path": "1006000.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1006000.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeovibrioSpL21acebes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geovibrio sp. L21AceBES graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeovibrioSpL21acebes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304888.protein.info.v11.5.txt",
		        "node_list_path": "1304888.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSpAsf360Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sp. ASF360 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSpAsf360Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "97137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "97137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "97137.clusters.proteins.v11.5.txt",
		        "sequence_path": "97137.protein.sequences.v11.5.fa",
		        "enrichment_path": "97137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97137.protein.info.v11.5.txt",
		        "node_list_path": "97137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "97137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1659200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659200.protein.info.v11.5.txt",
		        "node_list_path": "1659200.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillaceaeBacteriumGas479(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillaceae bacterium GAS479 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillaceaeBacteriumGas479", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882832.protein.info.v11.5.txt",
		        "node_list_path": "1882832.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacteriumRifcsplowo212Full3511Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFCSPLOWO2_12_FULL_35_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifcsplowo212Full3511Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801609.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801609.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801609.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801609.protein.info.v11.5.txt",
		        "node_list_path": "1801609.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801609.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PicoidesPubescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Picoides pubescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PicoidesPubescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118200.protein.sequences.v11.5.fa",
		        "enrichment_path": "118200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118200.protein.info.v11.5.txt",
		        "node_list_path": "118200.protein.complete.v11.5.txt"
		    }
		]
    )()

def NonomuraeaPusilla(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea pusilla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaPusilla", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46177.protein.sequences.v11.5.fa",
		        "enrichment_path": "46177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46177.protein.info.v11.5.txt",
		        "node_list_path": "46177.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanospirillaceaeBacteriumAsp1002aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillaceae bacterium ASP10-02a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanospirillaceaeBacteriumAsp1002aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1622229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1622229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1622229.clusters.proteins.v11.5.txt",
		        "sequence_path": "1622229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622229.protein.info.v11.5.txt",
		        "node_list_path": "1622229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1622229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerendipitaVermiferaMaff305830(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serendipita vermifera MAFF 305830 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerendipitaVermiferaMaff305830", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "933852.protein.sequences.v11.5.fa",
		        "enrichment_path": "933852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933852.protein.info.v11.5.txt",
		        "node_list_path": "933852.protein.complete.v11.5.txt"
		    }
		]
    )()

def PachysolenTannophilusNrrlY2460(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pachysolen tannophilus NRRL Y-2460 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PachysolenTannophilusNrrlY2460", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "669874.protein.sequences.v11.5.fa",
		        "enrichment_path": "669874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "669874.protein.info.v11.5.txt",
		        "node_list_path": "669874.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpAsf502(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ASF502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpAsf502", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "97139.protein.sequences.v11.5.fa",
		        "enrichment_path": "97139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97139.protein.info.v11.5.txt",
		        "node_list_path": "97139.protein.complete.v11.5.txt"
		    }
		]
    )()

def RufibacterSpDg15c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rufibacter sp. DG15C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RufibacterSpDg15c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379909.protein.info.v11.5.txt",
		        "node_list_path": "1379909.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpGa1841(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1841 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpGa1841", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834154.protein.info.v11.5.txt",
		        "node_list_path": "1834154.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasMacacaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas macacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasMacacaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28115.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28115.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28115.clusters.proteins.v11.5.txt",
		        "sequence_path": "28115.protein.sequences.v11.5.fa",
		        "enrichment_path": "28115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28115.protein.info.v11.5.txt",
		        "node_list_path": "28115.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28115.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaBrevis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBrevis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410666.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410666.protein.info.v11.5.txt",
		        "node_list_path": "1410666.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacterium1109(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium 1109 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacterium1109", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1655638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655638.protein.info.v11.5.txt",
		        "node_list_path": "1655638.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSediminicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora sediminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSediminicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "946078.protein.sequences.v11.5.fa",
		        "enrichment_path": "946078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946078.protein.info.v11.5.txt",
		        "node_list_path": "946078.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacterium3913Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 39-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacterium3913Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895767.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895767.protein.info.v11.5.txt",
		        "node_list_path": "1895767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaBissettiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia bissettii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaBissettiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521010.clusters.proteins.v11.5.txt",
		        "sequence_path": "521010.protein.sequences.v11.5.fa",
		        "enrichment_path": "521010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521010.protein.info.v11.5.txt",
		        "node_list_path": "521010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChristensenellaMinuta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Christensenella minuta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChristensenellaMinuta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "626937.protein.sequences.v11.5.fa",
		        "enrichment_path": "626937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626937.protein.info.v11.5.txt",
		        "node_list_path": "626937.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusFaecalis13sdw01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecalis 13SDW01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusFaecalis13sdw01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1260356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1260356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1260356.protein.info.v11.5.txt",
		        "node_list_path": "1260356.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpF0425Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0425 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpF0425Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "904296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "904296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "904296.clusters.proteins.v11.5.txt",
		        "sequence_path": "904296.protein.sequences.v11.5.fa",
		        "enrichment_path": "904296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904296.protein.info.v11.5.txt",
		        "node_list_path": "904296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "904296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanotheceSpAtcc51142Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. ATCC51142 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanotheceSpAtcc51142Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43989.clusters.proteins.v11.5.txt",
		        "sequence_path": "43989.protein.sequences.v11.5.fa",
		        "enrichment_path": "43989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43989.protein.info.v11.5.txt",
		        "node_list_path": "43989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full3914(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_39_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full3914", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797532.protein.info.v11.5.txt",
		        "node_list_path": "1797532.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExserohilumTurcicaEt28a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exserohilum turcica Et28A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExserohilumTurcicaEt28a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "671987.protein.sequences.v11.5.fa",
		        "enrichment_path": "671987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "671987.protein.info.v11.5.txt",
		        "node_list_path": "671987.protein.complete.v11.5.txt"
		    }
		]
    )()

def BosMutus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bos mutus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BosMutus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "72004.protein.sequences.v11.5.fa",
		        "enrichment_path": "72004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72004.protein.info.v11.5.txt",
		        "node_list_path": "72004.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpPcc6406Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC6406 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpPcc6406Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173264.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173264.protein.info.v11.5.txt",
		        "node_list_path": "1173264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusScotoductusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus scotoductus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusScotoductusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743525.clusters.proteins.v11.5.txt",
		        "sequence_path": "743525.protein.sequences.v11.5.fa",
		        "enrichment_path": "743525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743525.protein.info.v11.5.txt",
		        "node_list_path": "743525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PucciniaTriticina11BbbdRace1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Puccinia triticina 1-1 BBBD Race 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PucciniaTriticina11BbbdRace1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "630390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "630390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "630390.clusters.proteins.v11.5.txt",
		        "sequence_path": "630390.protein.sequences.v11.5.fa",
		        "enrichment_path": "630390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "630390.protein.info.v11.5.txt",
		        "node_list_path": "630390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "630390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesIleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides ilei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesIleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907658.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907658.protein.info.v11.5.txt",
		        "node_list_path": "1907658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlbimonasPacifica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Albimonas pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlbimonasPacifica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1114924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114924.protein.info.v11.5.txt",
		        "node_list_path": "1114924.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerolineaceaeBacterium4572322(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium 4572_32.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaceaeBacterium4572322", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1971624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971624.protein.info.v11.5.txt",
		        "node_list_path": "1971624.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpOhsuiiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. OHSUIII Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpOhsuiiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1297865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1297865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1297865.clusters.proteins.v11.5.txt",
		        "sequence_path": "1297865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297865.protein.info.v11.5.txt",
		        "node_list_path": "1297865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1297865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasXianhensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas xianhensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasXianhensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "442341.protein.sequences.v11.5.fa",
		        "enrichment_path": "442341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "442341.protein.info.v11.5.txt",
		        "node_list_path": "442341.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb1468Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_46_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb1468Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618880.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618880.protein.info.v11.5.txt",
		        "node_list_path": "1618880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterSpMhB5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. MH-B5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterSpMhB5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1172626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1172626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1172626.clusters.proteins.v11.5.txt",
		        "sequence_path": "1172626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172626.protein.info.v11.5.txt",
		        "node_list_path": "1172626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1172626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumYoeliiYoeliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium yoelii yoelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumYoeliiYoeliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "73239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "73239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "73239.clusters.proteins.v11.5.txt",
		        "sequence_path": "73239.protein.sequences.v11.5.fa",
		        "enrichment_path": "73239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "73239.protein.info.v11.5.txt",
		        "node_list_path": "73239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "73239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumGenitalium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium genitalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumGenitalium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585529.protein.sequences.v11.5.fa",
		        "enrichment_path": "585529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585529.protein.info.v11.5.txt",
		        "node_list_path": "585529.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifoxya12Full5229(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFOXYA12_FULL_52_29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxya12Full5229", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802571.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802571.protein.info.v11.5.txt",
		        "node_list_path": "1802571.protein.complete.v11.5.txt"
		    }
		]
    )()

def MorusNotabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Morus notabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MorusNotabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "981085.protein.sequences.v11.5.fa",
		        "enrichment_path": "981085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981085.protein.info.v11.5.txt",
		        "node_list_path": "981085.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasRubra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasRubra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117318.protein.info.v11.5.txt",
		        "node_list_path": "1117318.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumJdfr85Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumJdfr85Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935146.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935146.protein.info.v11.5.txt",
		        "node_list_path": "1935146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumXanthumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium xanthum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumXanthumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69322.clusters.proteins.v11.5.txt",
		        "sequence_path": "69322.protein.sequences.v11.5.fa",
		        "enrichment_path": "69322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69322.protein.info.v11.5.txt",
		        "node_list_path": "69322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacinutrixHimadriensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix himadriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixHimadriensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641549.protein.sequences.v11.5.fa",
		        "enrichment_path": "641549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641549.protein.info.v11.5.txt",
		        "node_list_path": "641549.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5422Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_54_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5422Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798495.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798495.protein.info.v11.5.txt",
		        "node_list_path": "1798495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807738.protein.info.v11.5.txt",
		        "node_list_path": "1807738.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaSpF0234(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaSpF0234", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888059.protein.sequences.v11.5.fa",
		        "enrichment_path": "888059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888059.protein.info.v11.5.txt",
		        "node_list_path": "888059.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesProvencensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces provencensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesProvencensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720198.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720198.protein.info.v11.5.txt",
		        "node_list_path": "1720198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag448(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:448 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag448", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262808.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262808.protein.info.v11.5.txt",
		        "node_list_path": "1262808.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobacteraceaeBacterium4572123(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium 4572_123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteraceaeBacterium4572123", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1971629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971629.protein.info.v11.5.txt",
		        "node_list_path": "1971629.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumCg1026336Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_63_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumCg1026336Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805133.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805133.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805133.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805133.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805133.protein.info.v11.5.txt",
		        "node_list_path": "1805133.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805133.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaBivia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bivia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBivia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28125.protein.sequences.v11.5.fa",
		        "enrichment_path": "28125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28125.protein.info.v11.5.txt",
		        "node_list_path": "28125.protein.complete.v11.5.txt"
		    }
		]
    )()

def TindalliaMagadiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tindallia magadiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TindalliaMagadiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69895.clusters.proteins.v11.5.txt",
		        "sequence_path": "69895.protein.sequences.v11.5.fa",
		        "enrichment_path": "69895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69895.protein.info.v11.5.txt",
		        "node_list_path": "69895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacteriumThermosaccharolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium thermosaccharolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacteriumThermosaccharolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "580327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "580327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "580327.clusters.proteins.v11.5.txt",
		        "sequence_path": "580327.protein.sequences.v11.5.fa",
		        "enrichment_path": "580327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "580327.protein.info.v11.5.txt",
		        "node_list_path": "580327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "580327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCh12i(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CH12i graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCh12i", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1479651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479651.protein.info.v11.5.txt",
		        "node_list_path": "1479651.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp2621Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 26_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp2621Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896977.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896977.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896977.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896977.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896977.protein.info.v11.5.txt",
		        "node_list_path": "1896977.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896977.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusTepidamans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus tepidamans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusTepidamans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1382358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382358.protein.info.v11.5.txt",
		        "node_list_path": "1382358.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifcsplowo212Full599Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO2_12_FULL_59_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo212Full599Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797952.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797952.protein.info.v11.5.txt",
		        "node_list_path": "1797952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumNoviomagense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium noviomagense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumNoviomagense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "459858.protein.sequences.v11.5.fa",
		        "enrichment_path": "459858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "459858.protein.info.v11.5.txt",
		        "node_list_path": "459858.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGwe24236Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWE2_42_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGwe24236Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798262.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798262.protein.info.v11.5.txt",
		        "node_list_path": "1798262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NiastellaYeongjuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Niastella yeongjuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiastellaYeongjuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "354355.protein.sequences.v11.5.fa",
		        "enrichment_path": "354355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "354355.protein.info.v11.5.txt",
		        "node_list_path": "354355.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsphigho202Full3919(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_02_FULL_39_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho202Full3919", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802746.protein.info.v11.5.txt",
		        "node_list_path": "1802746.protein.complete.v11.5.txt"
		    }
		]
    )()

def PalleroniaMarisminoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Palleronia marisminoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PalleroniaMarisminoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "315423.protein.sequences.v11.5.fa",
		        "enrichment_path": "315423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "315423.protein.info.v11.5.txt",
		        "node_list_path": "315423.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCampbellbacteriaBacteriumGw2011Od13428Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium GW2011_OD1_34_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumGw2011Od13428Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618633.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618633.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618633.protein.info.v11.5.txt",
		        "node_list_path": "1618633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaDiuraphisNoxia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Diuraphis noxia) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaDiuraphisNoxia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118101.protein.sequences.v11.5.fa",
		        "enrichment_path": "118101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118101.protein.info.v11.5.txt",
		        "node_list_path": "118101.protein.complete.v11.5.txt"
		    }
		]
    )()

def PerlucidibacaPiscinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Perlucidibaca piscinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PerlucidibacaPiscinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122951.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122951.protein.info.v11.5.txt",
		        "node_list_path": "1122951.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSpN418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. N418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpN418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "701176.protein.sequences.v11.5.fa",
		        "enrichment_path": "701176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "701176.protein.info.v11.5.txt",
		        "node_list_path": "701176.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusRattiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus ratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusRattiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "699248.clusters.info.v11.5.txt",
		        "cluster_tree_path": "699248.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "699248.clusters.proteins.v11.5.txt",
		        "sequence_path": "699248.protein.sequences.v11.5.fa",
		        "enrichment_path": "699248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "699248.protein.info.v11.5.txt",
		        "node_list_path": "699248.cluster.nodes.v11.5.txt",
		        "edge_list_path": "699248.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaAnsorpiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella ansorpii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaAnsorpiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "288768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "288768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "288768.clusters.proteins.v11.5.txt",
		        "sequence_path": "288768.protein.sequences.v11.5.fa",
		        "enrichment_path": "288768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "288768.protein.info.v11.5.txt",
		        "node_list_path": "288768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "288768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfurococcusMucosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurococcus mucosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurococcusMucosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765177.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765177.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765177.clusters.proteins.v11.5.txt",
		        "sequence_path": "765177.protein.sequences.v11.5.fa",
		        "enrichment_path": "765177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765177.protein.info.v11.5.txt",
		        "node_list_path": "765177.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765177.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidimonasBauzanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidimonas bauzanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidimonasBauzanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658167.protein.sequences.v11.5.fa",
		        "enrichment_path": "658167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658167.protein.info.v11.5.txt",
		        "node_list_path": "658167.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpNfr01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. NFR01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpNfr01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566279.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566279.protein.info.v11.5.txt",
		        "node_list_path": "1566279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StappiaSpEs058Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stappia sp. ES.058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StappiaSpEs058Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881061.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881061.protein.info.v11.5.txt",
		        "node_list_path": "1881061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonasSpV450(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. V450 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasSpV450", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1912139.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912139.protein.info.v11.5.txt",
		        "node_list_path": "1912139.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioVulgarisMiyazaki(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio vulgaris Miyazaki graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioVulgarisMiyazaki", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883.protein.sequences.v11.5.fa",
		        "enrichment_path": "883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883.protein.info.v11.5.txt",
		        "node_list_path": "883.protein.complete.v11.5.txt"
		    }
		]
    )()

def LonsdaleaPopuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lonsdalea populi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LonsdaleaPopuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1172565.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1172565.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1172565.clusters.proteins.v11.5.txt",
		        "sequence_path": "1172565.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172565.protein.info.v11.5.txt",
		        "node_list_path": "1172565.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1172565.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3837(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYB1_FULL_38_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3837", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802224.protein.info.v11.5.txt",
		        "node_list_path": "1802224.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium3146faa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 3146FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium3146faa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665950.protein.sequences.v11.5.fa",
		        "enrichment_path": "665950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665950.protein.info.v11.5.txt",
		        "node_list_path": "665950.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaSchoenbuchensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella schoenbuchensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSchoenbuchensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094496.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094496.protein.info.v11.5.txt",
		        "node_list_path": "1094496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalothrixSpHk06(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Calothrix sp. HK-06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalothrixSpHk06", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1137096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137096.protein.info.v11.5.txt",
		        "node_list_path": "1137096.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraDefluvii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira defluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraDefluvii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "330214.protein.sequences.v11.5.fa",
		        "enrichment_path": "330214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "330214.protein.info.v11.5.txt",
		        "node_list_path": "330214.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermocrinisMinervaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermocrinis minervae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocrinisMinervaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "381751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "381751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "381751.clusters.proteins.v11.5.txt",
		        "sequence_path": "381751.protein.sequences.v11.5.fa",
		        "enrichment_path": "381751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381751.protein.info.v11.5.txt",
		        "node_list_path": "381751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "381751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf357Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf357Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736350.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736350.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736350.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736350.protein.info.v11.5.txt",
		        "node_list_path": "1736350.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736350.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetascardoviaCricetiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metascardovia criceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetascardoviaCricetiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122228.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122228.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122228.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122228.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122228.protein.info.v11.5.txt",
		        "node_list_path": "1122228.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122228.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SutterellaParvirubraYit11816Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sutterella parvirubra YIT 11816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SutterellaParvirubraYit11816Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762967.clusters.proteins.v11.5.txt",
		        "sequence_path": "762967.protein.sequences.v11.5.fa",
		        "enrichment_path": "762967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762967.protein.info.v11.5.txt",
		        "node_list_path": "762967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NostocPiscinaleCena21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nostoc piscinale CENA21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocPiscinaleCena21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "224013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "224013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "224013.clusters.proteins.v11.5.txt",
		        "sequence_path": "224013.protein.sequences.v11.5.fa",
		        "enrichment_path": "224013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224013.protein.info.v11.5.txt",
		        "node_list_path": "224013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "224013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumImcc26134(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium IMCC26134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumImcc26134", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1637999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1637999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1637999.protein.info.v11.5.txt",
		        "node_list_path": "1637999.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterDaecheongensisDsm21074(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter daecheongensis DSM 21074 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterDaecheongensisDsm21074", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121955.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121955.protein.info.v11.5.txt",
		        "node_list_path": "1121955.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlareaLozoyensisAtcc20868Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glarea lozoyensis ATCC 20868 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlareaLozoyensisAtcc20868Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1116229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1116229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1116229.clusters.proteins.v11.5.txt",
		        "sequence_path": "1116229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116229.protein.info.v11.5.txt",
		        "node_list_path": "1116229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1116229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaUniformisNbrc13702(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia uniformis NBRC 13702 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaUniformisNbrc13702", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210100.protein.info.v11.5.txt",
		        "node_list_path": "1210100.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125718.protein.info.v11.5.txt",
		        "node_list_path": "1125718.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaShayeganii871Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria shayeganii 871 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaShayeganii871Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1032488.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1032488.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1032488.clusters.proteins.v11.5.txt",
		        "sequence_path": "1032488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1032488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1032488.protein.info.v11.5.txt",
		        "node_list_path": "1032488.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1032488.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusApachensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus apachensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusApachensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121377.protein.info.v11.5.txt",
		        "node_list_path": "1121377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslr70273(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70273 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslr70273", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1536772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536772.protein.info.v11.5.txt",
		        "node_list_path": "1536772.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaKoehlerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella koehlerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaKoehlerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1134510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134510.protein.info.v11.5.txt",
		        "node_list_path": "1134510.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharopolysporaErythraeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharopolyspora erythraea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharopolysporaErythraeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "405948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "405948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "405948.clusters.proteins.v11.5.txt",
		        "sequence_path": "405948.protein.sequences.v11.5.fa",
		        "enrichment_path": "405948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405948.protein.info.v11.5.txt",
		        "node_list_path": "405948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "405948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiopsisGanjiahuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis ganjiahuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisGanjiahuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1237500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1237500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1237500.clusters.proteins.v11.5.txt",
		        "sequence_path": "1237500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1237500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1237500.protein.info.v11.5.txt",
		        "node_list_path": "1237500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1237500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaGeestiana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella geestiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaGeestiana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45065.protein.sequences.v11.5.fa",
		        "enrichment_path": "45065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45065.protein.info.v11.5.txt",
		        "node_list_path": "45065.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumCallitrichosCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium callitrichos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumCallitrichosCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437609.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437609.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437609.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437609.protein.info.v11.5.txt",
		        "node_list_path": "1437609.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437609.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterSpVk13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. VK13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterSpVk13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1938817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938817.protein.info.v11.5.txt",
		        "node_list_path": "1938817.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumCg2303346Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium CG2_30_33_46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumCg2303346Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805400.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805400.protein.info.v11.5.txt",
		        "node_list_path": "1805400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumJkg1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium JKG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumJkg1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1128421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128421.protein.info.v11.5.txt",
		        "node_list_path": "1128421.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhycisphaeraeBacteriumSm2330Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phycisphaerae bacterium SM23_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycisphaeraeBacteriumSm2330Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703411.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703411.protein.info.v11.5.txt",
		        "node_list_path": "1703411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaricaulisSpW15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maricaulis sp. W15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaricaulisSpW15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1772333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772333.protein.info.v11.5.txt",
		        "node_list_path": "1772333.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpMit0601Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpMit0601Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499498.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499498.protein.info.v11.5.txt",
		        "node_list_path": "1499498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterAerophilusDsm13606(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter aerophilus DSM 13606 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterAerophilusDsm13606", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121953.protein.info.v11.5.txt",
		        "node_list_path": "1121953.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrabulsiellaGuamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trabulsiella guamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrabulsiellaGuamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005994.protein.info.v11.5.txt",
		        "node_list_path": "1005994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasRuthenica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas ruthenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasRuthenica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216007.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216007.protein.info.v11.5.txt",
		        "node_list_path": "1216007.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraRifamyciniDsm43936Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura rifamycini DSM 43936 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraRifamyciniDsm43936Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120937.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120937.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120937.protein.info.v11.5.txt",
		        "node_list_path": "1120937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwe24063(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_40_63 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwe24063", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797335.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797335.protein.info.v11.5.txt",
		        "node_list_path": "1797335.protein.complete.v11.5.txt"
		    }
		]
    )()

def OchrobactrumPseudogrignonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum pseudogrignonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OchrobactrumPseudogrignonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "419475.protein.sequences.v11.5.fa",
		        "enrichment_path": "419475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419475.protein.info.v11.5.txt",
		        "node_list_path": "419475.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenophilusAzovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenophilus azovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenophilusAzovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123504.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123504.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123504.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123504.protein.info.v11.5.txt",
		        "node_list_path": "1123504.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123504.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxKonjaciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax konjaci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxKonjaciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32040.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32040.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32040.clusters.proteins.v11.5.txt",
		        "sequence_path": "32040.protein.sequences.v11.5.fa",
		        "enrichment_path": "32040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32040.protein.info.v11.5.txt",
		        "node_list_path": "32040.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32040.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilaceaeBacteriumUrhb0062Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHB0062 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilaceaeBacteriumUrhb0062Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380353.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380353.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380353.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380353.protein.info.v11.5.txt",
		        "node_list_path": "1380353.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380353.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacillusMinorNm305(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus minor NM305 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusMinorNm305", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "637911.protein.sequences.v11.5.fa",
		        "enrichment_path": "637911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637911.protein.info.v11.5.txt",
		        "node_list_path": "637911.protein.complete.v11.5.txt"
		    }
		]
    )()

def PygoscelisAdeliae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pygoscelis adeliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PygoscelisAdeliae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9238.protein.sequences.v11.5.fa",
		        "enrichment_path": "9238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9238.protein.info.v11.5.txt",
		        "node_list_path": "9238.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpD14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. D14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpD14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "621372.protein.sequences.v11.5.fa",
		        "enrichment_path": "621372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "621372.protein.info.v11.5.txt",
		        "node_list_path": "621372.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpOk095Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. OK095 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpOk095Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882760.protein.info.v11.5.txt",
		        "node_list_path": "1882760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag628Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:628 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag628Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262829.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262829.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262829.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262829.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262829.protein.info.v11.5.txt",
		        "node_list_path": "1262829.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262829.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusSpMctg156(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius sp. MCTG156 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusSpMctg156", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354722.protein.info.v11.5.txt",
		        "node_list_path": "1354722.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusThioglobusAutotrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus autotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThioglobusAutotrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1705394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1705394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1705394.clusters.proteins.v11.5.txt",
		        "sequence_path": "1705394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705394.protein.info.v11.5.txt",
		        "node_list_path": "1705394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1705394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRbg163710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RBG_16_37_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRbg163710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802610.protein.info.v11.5.txt",
		        "node_list_path": "1802610.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusCalidoustus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus calidoustus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusCalidoustus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "454130.protein.sequences.v11.5.fa",
		        "enrichment_path": "454130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454130.protein.info.v11.5.txt",
		        "node_list_path": "454130.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusBombicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus bombicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBombicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1505723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505723.protein.info.v11.5.txt",
		        "node_list_path": "1505723.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls237(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS237 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls237", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463895.protein.info.v11.5.txt",
		        "node_list_path": "1463895.protein.complete.v11.5.txt"
		    }
		]
    )()

def KtedonobacterSp13120cm45311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ktedonobacter sp. 13_1_20CM_4_53_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KtedonobacterSp13120cm45311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805225.protein.info.v11.5.txt",
		        "node_list_path": "1805225.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlammeovirgaSpSjp92Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flammeovirga sp. SJP92 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlammeovirgaSpSjp92Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1775430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1775430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1775430.clusters.proteins.v11.5.txt",
		        "sequence_path": "1775430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775430.protein.info.v11.5.txt",
		        "node_list_path": "1775430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1775430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumRifoxyd12Full368(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYD12_FULL_36_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyd12Full368", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798454.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798454.protein.info.v11.5.txt",
		        "node_list_path": "1798454.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyadobacterFermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterFermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471854.clusters.proteins.v11.5.txt",
		        "sequence_path": "471854.protein.sequences.v11.5.fa",
		        "enrichment_path": "471854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471854.protein.info.v11.5.txt",
		        "node_list_path": "471854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumSpJkg1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. JKG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumSpJkg1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1128421.protein.sequences.v11.0.fa",
		        "enrichment_path": "1128421.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1128421.protein.info.v11.0.txt",
		        "node_list_path": "1128421.protein.complete.v11.0.txt"
		    }
		]
    )()

def CorynebacteriumPyruviciproducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pyruviciproducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPyruviciproducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125779.protein.info.v11.5.txt",
		        "node_list_path": "1125779.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaSpPdc64Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. PDC64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpPdc64Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881046.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881046.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881046.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881046.protein.info.v11.5.txt",
		        "node_list_path": "1881046.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881046.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesJaponicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesJaponicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4897.clusters.proteins.v11.5.txt",
		        "sequence_path": "4897.protein.sequences.v11.5.fa",
		        "enrichment_path": "4897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4897.protein.info.v11.5.txt",
		        "node_list_path": "4897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaCanimorsus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga canimorsus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaCanimorsus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "860228.protein.sequences.v11.5.fa",
		        "enrichment_path": "860228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "860228.protein.info.v11.5.txt",
		        "node_list_path": "860228.protein.complete.v11.5.txt"
		    }
		]
    )()

def TepidimonasTaiwanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tepidimonas taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidimonasTaiwanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "307486.protein.sequences.v11.5.fa",
		        "enrichment_path": "307486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "307486.protein.info.v11.5.txt",
		        "node_list_path": "307486.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "988821.protein.sequences.v11.5.fa",
		        "enrichment_path": "988821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "988821.protein.info.v11.5.txt",
		        "node_list_path": "988821.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotogaHypogeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga hypogea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaHypogeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219084.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219084.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219084.protein.info.v11.5.txt",
		        "node_list_path": "1219084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AstyanaxMexicanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Astyanax mexicanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AstyanaxMexicanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7994.protein.sequences.v11.5.fa",
		        "enrichment_path": "7994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7994.protein.info.v11.5.txt",
		        "node_list_path": "7994.protein.complete.v11.5.txt"
		    }
		]
    )()

def CatelliglobosisporaKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catelliglobosispora koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatelliglobosisporaKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121272.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121272.protein.info.v11.5.txt",
		        "node_list_path": "1121272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynesporaCassiicolaPhilippinesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynespora cassiicola Philippines Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynesporaCassiicolaPhilippinesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1448308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1448308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1448308.clusters.proteins.v11.5.txt",
		        "sequence_path": "1448308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448308.protein.info.v11.5.txt",
		        "node_list_path": "1448308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1448308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaGlaucaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora glauca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaGlaucaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "928724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "928724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "928724.clusters.proteins.v11.5.txt",
		        "sequence_path": "928724.protein.sequences.v11.5.fa",
		        "enrichment_path": "928724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "928724.protein.info.v11.5.txt",
		        "node_list_path": "928724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "928724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumGwf16617Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GWF1_66_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumGwf16617Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797551.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797551.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797551.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797551.protein.info.v11.5.txt",
		        "node_list_path": "1797551.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797551.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumJicamae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium jicamae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumJicamae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "280332.protein.sequences.v11.5.fa",
		        "enrichment_path": "280332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "280332.protein.info.v11.5.txt",
		        "node_list_path": "280332.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacterVinaykumariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter vinaykumarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterVinaykumariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "407234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "407234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "407234.clusters.proteins.v11.5.txt",
		        "sequence_path": "407234.protein.sequences.v11.5.fa",
		        "enrichment_path": "407234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "407234.protein.info.v11.5.txt",
		        "node_list_path": "407234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "407234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpMan2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. MAN2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpMan2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1101188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1101188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1101188.clusters.proteins.v11.5.txt",
		        "sequence_path": "1101188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101188.protein.info.v11.5.txt",
		        "node_list_path": "1101188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1101188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryobacteriumPsychrotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryobacterium psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryobacteriumPsychrotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "386301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "386301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "386301.clusters.proteins.v11.5.txt",
		        "sequence_path": "386301.protein.sequences.v11.5.fa",
		        "enrichment_path": "386301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "386301.protein.info.v11.5.txt",
		        "node_list_path": "386301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "386301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpYr577(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. YR577 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpYr577", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884373.protein.info.v11.5.txt",
		        "node_list_path": "1884373.protein.complete.v11.5.txt"
		    }
		]
    )()

def YooniaLitorea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yoonia litorea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YooniaLitorea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123755.protein.info.v11.5.txt",
		        "node_list_path": "1123755.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumSp7101Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. 7101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumSp7101Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1394175.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1394175.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1394175.clusters.proteins.v11.5.txt",
		        "sequence_path": "1394175.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394175.protein.info.v11.5.txt",
		        "node_list_path": "1394175.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1394175.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosospiraSpNl5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nl5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraSpNl5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "200120.protein.sequences.v11.5.fa",
		        "enrichment_path": "200120.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200120.protein.info.v11.5.txt",
		        "node_list_path": "200120.protein.complete.v11.5.txt"
		    }
		]
    )()

def PucciniaStriiformisFSpTriticiPst78Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Puccinia striiformis f. sp. tritici PST-78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PucciniaStriiformisFSpTriticiPst78Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1165861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1165861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1165861.clusters.proteins.v11.5.txt",
		        "sequence_path": "1165861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1165861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1165861.protein.info.v11.5.txt",
		        "node_list_path": "1165861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1165861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatenovulumMaritimum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catenovulum maritimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenovulumMaritimum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1513271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1513271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1513271.protein.info.v11.5.txt",
		        "node_list_path": "1513271.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiaBacteriumTcs52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiaBacteriumTcs52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1781243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1781243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1781243.clusters.proteins.v11.5.txt",
		        "sequence_path": "1781243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1781243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1781243.protein.info.v11.5.txt",
		        "node_list_path": "1781243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1781243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHtcc8051Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC8051 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHtcc8051Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "466038.clusters.info.v11.5.txt",
		        "cluster_tree_path": "466038.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "466038.clusters.proteins.v11.5.txt",
		        "sequence_path": "466038.protein.sequences.v11.5.fa",
		        "enrichment_path": "466038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "466038.protein.info.v11.5.txt",
		        "node_list_path": "466038.cluster.nodes.v11.5.txt",
		        "edge_list_path": "466038.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterCetorumMit995656Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cetorum MIT995656 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterCetorumMit995656Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163745.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1163745.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1163745.clusters.proteins.v11.5.txt",
		        "sequence_path": "1163745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163745.protein.info.v11.5.txt",
		        "node_list_path": "1163745.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1163745.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ScytonemaTolypothrichoidesVb61278Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scytonema tolypothrichoides VB-61278 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScytonemaTolypothrichoidesVb61278Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1233231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1233231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1233231.clusters.proteins.v11.5.txt",
		        "sequence_path": "1233231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1233231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1233231.protein.info.v11.5.txt",
		        "node_list_path": "1233231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1233231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpEr16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. ER1/6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpEr16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1891920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1891920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1891920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1891920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891920.protein.info.v11.5.txt",
		        "node_list_path": "1891920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1891920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacterialesBacteriumAlc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriales bacterium ALC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacterialesBacteriumAlc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391603.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391603.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391603.clusters.proteins.v11.5.txt",
		        "sequence_path": "391603.protein.sequences.v11.5.fa",
		        "enrichment_path": "391603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391603.protein.info.v11.5.txt",
		        "node_list_path": "391603.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391603.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpUnc23mfcrub11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. UNC23MFCrub11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpUnc23mfcrub11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449068.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449068.protein.info.v11.5.txt",
		        "node_list_path": "1449068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaSpCag52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blautia sp. CAG:52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaSpCag52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262758.protein.info.v11.5.txt",
		        "node_list_path": "1262758.protein.complete.v11.5.txt"
		    }
		]
    )()

def DialisterSuccinatiphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dialister succinatiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterSuccinatiphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742743.clusters.proteins.v11.5.txt",
		        "sequence_path": "742743.protein.sequences.v11.5.fa",
		        "enrichment_path": "742743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742743.protein.info.v11.5.txt",
		        "node_list_path": "742743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FictibacillusArsenicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fictibacillus arsenicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FictibacillusArsenicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "255247.protein.sequences.v11.5.fa",
		        "enrichment_path": "255247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "255247.protein.info.v11.5.txt",
		        "node_list_path": "255247.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacteriumSaccharolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium saccharolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacteriumSaccharolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094508.protein.info.v11.5.txt",
		        "node_list_path": "1094508.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_43_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618826.protein.info.v11.5.txt",
		        "node_list_path": "1618826.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraPelophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira pelophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraPelophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123517.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123517.protein.info.v11.5.txt",
		        "node_list_path": "1123517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfatibacillumAlkenivoransDsm16219Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans DSM 16219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfatibacillumAlkenivoransDsm16219Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121393.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121393.protein.info.v11.5.txt",
		        "node_list_path": "1121393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaTyphi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia typhi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaTyphi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "257363.protein.sequences.v11.5.fa",
		        "enrichment_path": "257363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "257363.protein.info.v11.5.txt",
		        "node_list_path": "257363.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeronosporaEffusaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peronospora effusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeronosporaEffusaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "542832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "542832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "542832.clusters.proteins.v11.5.txt",
		        "sequence_path": "542832.protein.sequences.v11.5.fa",
		        "enrichment_path": "542832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "542832.protein.info.v11.5.txt",
		        "node_list_path": "542832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "542832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LechevalieriaFradiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lechevalieria fradiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LechevalieriaFradiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "200378.protein.sequences.v11.5.fa",
		        "enrichment_path": "200378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200378.protein.info.v11.5.txt",
		        "node_list_path": "200378.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoculleusThermophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusThermophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2200.protein.sequences.v11.5.fa",
		        "enrichment_path": "2200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2200.protein.info.v11.5.txt",
		        "node_list_path": "2200.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetarhiziumAlbumArsef1941(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium album ARSEF 1941 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetarhiziumAlbumArsef1941", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1081103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081103.protein.info.v11.5.txt",
		        "node_list_path": "1081103.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoplanusPetrolearius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanoplanus petrolearius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoplanusPetrolearius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679926.protein.sequences.v11.5.fa",
		        "enrichment_path": "679926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679926.protein.info.v11.5.txt",
		        "node_list_path": "679926.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorhodospiraHalophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorhodospira halophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorhodospiraHalophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349124.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349124.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349124.clusters.proteins.v11.5.txt",
		        "sequence_path": "349124.protein.sequences.v11.5.fa",
		        "enrichment_path": "349124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349124.protein.info.v11.5.txt",
		        "node_list_path": "349124.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349124.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShigellaBoydiiCdc308394Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shigella boydii CDC 3083-94 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShigellaBoydiiCdc308394Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "344609.clusters.info.v11.5.txt",
		        "cluster_tree_path": "344609.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "344609.clusters.proteins.v11.5.txt",
		        "sequence_path": "344609.protein.sequences.v11.5.fa",
		        "enrichment_path": "344609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "344609.protein.info.v11.5.txt",
		        "node_list_path": "344609.cluster.nodes.v11.5.txt",
		        "edge_list_path": "344609.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumRifcsplowo212Full3712Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RIFCSPLOWO2_12_FULL_37_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumRifcsplowo212Full3712Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797365.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797365.protein.info.v11.5.txt",
		        "node_list_path": "1797365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumYl45Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium YL45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumYl45Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834205.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834205.protein.info.v11.5.txt",
		        "node_list_path": "1834205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharibacterFloricola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharibacter floricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharibacterFloricola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123227.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123227.protein.info.v11.5.txt",
		        "node_list_path": "1123227.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumAcidifaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acidifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumAcidifaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122994.protein.info.v11.5.txt",
		        "node_list_path": "1122994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizophagusIrregularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizophagusIrregularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "588596.protein.sequences.v11.5.fa",
		        "enrichment_path": "588596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588596.protein.info.v11.5.txt",
		        "node_list_path": "588596.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumSubtile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium subtile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumSubtile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "77635.protein.sequences.v11.5.fa",
		        "enrichment_path": "77635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77635.protein.info.v11.5.txt",
		        "node_list_path": "77635.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrialbaceaeArchaeonTcBr11E2g1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon Tc-Br11_E2g1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaceaeArchaeonTcBr11E2g1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729461.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729461.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729461.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729461.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729461.protein.info.v11.5.txt",
		        "node_list_path": "1729461.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729461.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CordycepsConfragosaRcef1005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps confragosa RCEF 1005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CordycepsConfragosaRcef1005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1081108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1081108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1081108.clusters.proteins.v11.5.txt",
		        "sequence_path": "1081108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081108.protein.info.v11.5.txt",
		        "node_list_path": "1081108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1081108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumRivuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium rivuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumRivuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121895.protein.info.v11.5.txt",
		        "node_list_path": "1121895.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrancisellaNoatunensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella noatunensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaNoatunensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163389.protein.info.v11.5.txt",
		        "node_list_path": "1163389.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusAminophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus aminophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusAminophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1367847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1367847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1367847.clusters.proteins.v11.5.txt",
		        "sequence_path": "1367847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1367847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1367847.protein.info.v11.5.txt",
		        "node_list_path": "1367847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1367847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LutibacterSpLpb0138Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lutibacter sp. LPB0138 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutibacterSpLpb0138Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1850246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1850246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1850246.clusters.proteins.v11.5.txt",
		        "sequence_path": "1850246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850246.protein.info.v11.5.txt",
		        "node_list_path": "1850246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1850246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacillusMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacillus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacillusMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385511.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385511.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385511.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385511.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385511.protein.info.v11.5.txt",
		        "node_list_path": "1385511.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385511.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AdvenellaKashmirensisW13003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Advenella kashmirensis W13003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AdvenellaKashmirensisW13003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1424334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1424334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1424334.protein.info.v11.5.txt",
		        "node_list_path": "1424334.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifoxyb1Full4015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYB1_FULL_40_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyb1Full4015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798697.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798697.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798697.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798697.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798697.protein.info.v11.5.txt",
		        "node_list_path": "1798697.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798697.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioMetschnikovii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio metschnikovii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioMetschnikovii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675813.protein.sequences.v11.5.fa",
		        "enrichment_path": "675813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675813.protein.info.v11.5.txt",
		        "node_list_path": "675813.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwb1437(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWB1_43_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwb1437", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618747.protein.info.v11.5.txt",
		        "node_list_path": "1618747.protein.complete.v11.5.txt"
		    }
		]
    )()

def CheloniaMydas(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chelonia mydas graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CheloniaMydas", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8469.protein.sequences.v11.5.fa",
		        "enrichment_path": "8469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8469.protein.info.v11.5.txt",
		        "node_list_path": "8469.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaColwellianaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella colwelliana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaColwellianaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "23.clusters.info.v11.5.txt",
		        "cluster_tree_path": "23.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "23.clusters.proteins.v11.5.txt",
		        "sequence_path": "23.protein.sequences.v11.5.fa",
		        "enrichment_path": "23.protein.enrichment.terms.v11.5.txt",
		        "info_path": "23.protein.info.v11.5.txt",
		        "node_list_path": "23.cluster.nodes.v11.5.txt",
		        "edge_list_path": "23.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwb1448(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWB1_44_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwb1448", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618505.protein.info.v11.5.txt",
		        "node_list_path": "1618505.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConiochaetaLigniariaNrrl30616Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coniochaeta ligniaria NRRL 30616 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConiochaetaLigniariaNrrl30616Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408157.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408157.protein.info.v11.5.txt",
		        "node_list_path": "1408157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanohalarchaeumThermophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanohalarchaeum thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanohalarchaeumThermophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1903181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1903181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1903181.clusters.proteins.v11.5.txt",
		        "sequence_path": "1903181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903181.protein.info.v11.5.txt",
		        "node_list_path": "1903181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1903181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DomibacillusMangroviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus mangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusMangroviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1714354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1714354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1714354.clusters.proteins.v11.5.txt",
		        "sequence_path": "1714354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714354.protein.info.v11.5.txt",
		        "node_list_path": "1714354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1714354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaeBacteriumGa0074140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium Ga0074140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaeBacteriumGa0074140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752208.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752208.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752208.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752208.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752208.protein.info.v11.5.txt",
		        "node_list_path": "1752208.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752208.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumLentocellumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium lentocellum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumLentocellumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "642492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "642492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "642492.clusters.proteins.v11.5.txt",
		        "sequence_path": "642492.protein.sequences.v11.5.fa",
		        "enrichment_path": "642492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "642492.protein.info.v11.5.txt",
		        "node_list_path": "642492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "642492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacillusSubterraneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusSubterraneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "129338.protein.sequences.v11.5.fa",
		        "enrichment_path": "129338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "129338.protein.info.v11.5.txt",
		        "node_list_path": "129338.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumRifcsplowo212Full3511(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium RIFCSPLOWO2_12_FULL_35_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumRifcsplowo212Full3511", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798016.protein.info.v11.5.txt",
		        "node_list_path": "1798016.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlobicatellaSulfidifaciensDsm15739Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Globicatella sulfidifaciens DSM 15739 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlobicatellaSulfidifaciensDsm15739Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121925.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121925.protein.info.v11.5.txt",
		        "node_list_path": "1121925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalegentibacterSpHeli6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter sp. HelI6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterSpHeli6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1250278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250278.protein.info.v11.5.txt",
		        "node_list_path": "1250278.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterSpT28(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter sp. T28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterSpT28", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1836467.protein.sequences.v11.5.fa",
		        "enrichment_path": "1836467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1836467.protein.info.v11.5.txt",
		        "node_list_path": "1836467.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesProvencensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes provencensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesProvencensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816676.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816676.protein.info.v11.5.txt",
		        "node_list_path": "1816676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxJadensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax jadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxJadensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1177181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177181.protein.info.v11.5.txt",
		        "node_list_path": "1177181.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumGwf24413(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWF2_44_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumGwf24413", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801702.protein.info.v11.5.txt",
		        "node_list_path": "1801702.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaSpPsnih2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. PSNIH2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpPsnih2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1484157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484157.protein.info.v11.5.txt",
		        "node_list_path": "1484157.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetaSpEbm43(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta sp. EBM-43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaSpEbm43", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1918502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918502.protein.info.v11.5.txt",
		        "node_list_path": "1918502.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpB6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. B6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpB6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1570137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570137.protein.info.v11.5.txt",
		        "node_list_path": "1570137.protein.complete.v11.5.txt"
		    }
		]
    )()

def WallemiaMellicolaCbs63366Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wallemia mellicola CBS 633.66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WallemiaMellicolaCbs63366Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "671144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "671144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "671144.clusters.proteins.v11.5.txt",
		        "sequence_path": "671144.protein.sequences.v11.5.fa",
		        "enrichment_path": "671144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "671144.protein.info.v11.5.txt",
		        "node_list_path": "671144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "671144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HoefleaSpImcc20628Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hoeflea sp. IMCC20628 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoefleaSpImcc20628Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1620421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1620421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1620421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1620421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1620421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1620421.protein.info.v11.5.txt",
		        "node_list_path": "1620421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1620421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMendocinaYmpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina ymp Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMendocinaYmpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "399739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "399739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "399739.clusters.proteins.v11.5.txt",
		        "sequence_path": "399739.protein.sequences.v11.5.fa",
		        "enrichment_path": "399739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399739.protein.info.v11.5.txt",
		        "node_list_path": "399739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "399739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrovirgaFlocculans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microvirga flocculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaFlocculans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336243.protein.info.v11.5.txt",
		        "node_list_path": "1336243.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaIvanoviiPam55(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria ivanovii PAM55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaIvanoviiPam55", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "881621.protein.sequences.v11.5.fa",
		        "enrichment_path": "881621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "881621.protein.info.v11.5.txt",
		        "node_list_path": "881621.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusPraedii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus praedii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPraedii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1742358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742358.protein.info.v11.5.txt",
		        "node_list_path": "1742358.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerroglobusPlacidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferroglobus placidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerroglobusPlacidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "589924.protein.sequences.v11.5.fa",
		        "enrichment_path": "589924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "589924.protein.info.v11.5.txt",
		        "node_list_path": "589924.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZavarzinellaFormosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zavarzinella formosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZavarzinellaFormosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123508.protein.info.v11.5.txt",
		        "node_list_path": "1123508.protein.complete.v11.5.txt"
		    }
		]
    )()

def ImtechellaHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Imtechella halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ImtechellaHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "946077.protein.sequences.v11.5.fa",
		        "enrichment_path": "946077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946077.protein.info.v11.5.txt",
		        "node_list_path": "946077.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho202Full3718(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_37_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full3718", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798603.protein.info.v11.5.txt",
		        "node_list_path": "1798603.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSaccharogumiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium saccharogumia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSaccharogumiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121333.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121333.protein.info.v11.5.txt",
		        "node_list_path": "1121333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc3903(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 3903 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc3903", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977883.protein.info.v11.5.txt",
		        "node_list_path": "1977883.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoplasmatalesArchaeonIPlasma(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon I-plasma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmatalesArchaeonIPlasma", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "667138.protein.sequences.v11.5.fa",
		        "enrichment_path": "667138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667138.protein.info.v11.5.txt",
		        "node_list_path": "667138.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalipigerProfundusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salipiger profundus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalipigerProfundusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229727.protein.info.v11.5.txt",
		        "node_list_path": "1229727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCibiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cibi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCibiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "265729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "265729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "265729.clusters.proteins.v11.5.txt",
		        "sequence_path": "265729.protein.sequences.v11.5.fa",
		        "enrichment_path": "265729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265729.protein.info.v11.5.txt",
		        "node_list_path": "265729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "265729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpMa2016Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. MA2016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpMa2016Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408310.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408310.protein.info.v11.5.txt",
		        "node_list_path": "1408310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicolaNanhaiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola nanhaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaNanhaiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122614.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122614.protein.info.v11.5.txt",
		        "node_list_path": "1122614.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801776.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801776.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801776.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801776.protein.info.v11.5.txt",
		        "node_list_path": "1801776.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801776.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnditaleaAndensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anditalea andensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnditaleaAndensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1048983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048983.protein.info.v11.5.txt",
		        "node_list_path": "1048983.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusParaburkholderiaKirkiiUzhbot1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Paraburkholderia kirkii UZHbot1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusParaburkholderiaKirkiiUzhbot1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1055526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1055526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1055526.protein.info.v11.5.txt",
		        "node_list_path": "1055526.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfuricellaDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricella denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricellaDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163617.protein.info.v11.5.txt",
		        "node_list_path": "1163617.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumSg824(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium SG8_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumSg824", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703768.protein.info.v11.5.txt",
		        "node_list_path": "1703768.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterPaludisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter paludis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterPaludisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "714943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "714943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "714943.clusters.proteins.v11.5.txt",
		        "sequence_path": "714943.protein.sequences.v11.5.fa",
		        "enrichment_path": "714943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "714943.protein.info.v11.5.txt",
		        "node_list_path": "714943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "714943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumCg10264396Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium CG1_02_64_396 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumCg10264396Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805333.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805333.protein.info.v11.5.txt",
		        "node_list_path": "1805333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumAurantiacumDsm6208Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium aurantiacum DSM 6208 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumAurantiacumDsm6208Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397694.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397694.protein.info.v11.5.txt",
		        "node_list_path": "1397694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFarraginisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus farraginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFarraginisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423743.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423743.protein.info.v11.5.txt",
		        "node_list_path": "1423743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoflavonifractorSpMarseilleP3106Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoflavonifractor sp. Marseille-P3106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoflavonifractorSpMarseilleP3106Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871015.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871015.protein.info.v11.5.txt",
		        "node_list_path": "1871015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgicolaSagamiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algicola sagamiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgicolaSagamiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120963.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120963.protein.info.v11.5.txt",
		        "node_list_path": "1120963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnisphaeraAggregansDsm17230(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignisphaera aggregans DSM 17230 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnisphaeraAggregansDsm17230", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "583356.protein.sequences.v11.5.fa",
		        "enrichment_path": "583356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "583356.protein.info.v11.5.txt",
		        "node_list_path": "583356.protein.complete.v11.5.txt"
		    }
		]
    )()

def LautropiaSpScn6989(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lautropia sp. SCN 69-89 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LautropiaSpScn6989", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660104.protein.info.v11.5.txt",
		        "node_list_path": "1660104.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaQuateirensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella quateirensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaQuateirensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45072.clusters.proteins.v11.5.txt",
		        "sequence_path": "45072.protein.sequences.v11.5.fa",
		        "enrichment_path": "45072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45072.protein.info.v11.5.txt",
		        "node_list_path": "45072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaSpRoot381Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. Root381 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpRoot381Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736524.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736524.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736524.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736524.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736524.protein.info.v11.5.txt",
		        "node_list_path": "1736524.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736524.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4714Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_47_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4714Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798680.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798680.protein.info.v11.5.txt",
		        "node_list_path": "1798680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcoidesVulcani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanococcoides vulcani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcoidesVulcani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1353158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353158.protein.info.v11.5.txt",
		        "node_list_path": "1353158.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag555Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:555 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag555Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263030.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263030.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263030.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263030.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263030.protein.info.v11.5.txt",
		        "node_list_path": "1263030.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263030.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSalexigensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio salexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSalexigensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "526222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "526222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "526222.clusters.proteins.v11.5.txt",
		        "sequence_path": "526222.protein.sequences.v11.5.fa",
		        "enrichment_path": "526222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526222.protein.info.v11.5.txt",
		        "node_list_path": "526222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "526222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumJdfr85(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumJdfr85", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935146.protein.info.v11.5.txt",
		        "node_list_path": "1935146.protein.complete.v11.5.txt"
		    }
		]
    )()

def OctopusBimaculoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Octopus bimaculoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OctopusBimaculoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37653.clusters.proteins.v11.5.txt",
		        "sequence_path": "37653.protein.sequences.v11.5.fa",
		        "enrichment_path": "37653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37653.protein.info.v11.5.txt",
		        "node_list_path": "37653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromohalobacterSalexigensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chromohalobacter salexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromohalobacterSalexigensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290398.clusters.proteins.v11.5.txt",
		        "sequence_path": "290398.protein.sequences.v11.5.fa",
		        "enrichment_path": "290398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290398.protein.info.v11.5.txt",
		        "node_list_path": "290398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoaciditogaLauensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesoaciditoga lauensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoaciditogaLauensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150474.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150474.protein.info.v11.5.txt",
		        "node_list_path": "1150474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermotogaLettingae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga lettingae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaLettingae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "416591.protein.sequences.v11.5.fa",
		        "enrichment_path": "416591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416591.protein.info.v11.5.txt",
		        "node_list_path": "416591.protein.complete.v11.5.txt"
		    }
		]
    )()

def EggerthellaSp519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eggerthella sp. 51_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthellaSp519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897000.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897000.protein.info.v11.5.txt",
		        "node_list_path": "1897000.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4924Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_02_FULL_49_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4924Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817834.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817834.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817834.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817834.protein.info.v11.5.txt",
		        "node_list_path": "1817834.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817834.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSpicheri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus spicheri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSpicheri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216463.protein.sequences.v11.5.fa",
		        "enrichment_path": "216463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216463.protein.info.v11.5.txt",
		        "node_list_path": "216463.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "226505.protein.sequences.v11.5.fa",
		        "enrichment_path": "226505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226505.protein.info.v11.5.txt",
		        "node_list_path": "226505.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOdinarchaeotaArchaeonLcb4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Odinarchaeota archaeon LCB_4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOdinarchaeotaArchaeonLcb4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841599.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841599.protein.info.v11.5.txt",
		        "node_list_path": "1841599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeitlerinemaSpPcc9228(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC 9228 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeitlerinemaSpPcc9228", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "111611.protein.sequences.v11.5.fa",
		        "enrichment_path": "111611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "111611.protein.info.v11.5.txt",
		        "node_list_path": "111611.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryptococcusNeoformansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus neoformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptococcusNeoformansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5207.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5207.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5207.clusters.proteins.v11.5.txt",
		        "sequence_path": "5207.protein.sequences.v11.5.fa",
		        "enrichment_path": "5207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5207.protein.info.v11.5.txt",
		        "node_list_path": "5207.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5207.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusMetalliduransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus metallidurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusMetalliduransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266264.clusters.proteins.v11.5.txt",
		        "sequence_path": "266264.protein.sequences.v11.5.fa",
		        "enrichment_path": "266264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266264.protein.info.v11.5.txt",
		        "node_list_path": "266264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudooceanicolaNitratireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudooceanicola nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudooceanicolaNitratireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "517719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "517719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "517719.clusters.proteins.v11.5.txt",
		        "sequence_path": "517719.protein.sequences.v11.5.fa",
		        "enrichment_path": "517719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "517719.protein.info.v11.5.txt",
		        "node_list_path": "517719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "517719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaFrigidimarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella frigidimarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaFrigidimarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "318167.protein.sequences.v11.5.fa",
		        "enrichment_path": "318167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318167.protein.info.v11.5.txt",
		        "node_list_path": "318167.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumAsf500(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium ASF500 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumAsf500", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1378168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1378168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1378168.protein.info.v11.5.txt",
		        "node_list_path": "1378168.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsphigho202Full4811Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPHIGHO2_02_FULL_48_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202Full4811Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801856.protein.info.v11.5.txt",
		        "node_list_path": "1801856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusSpAmp6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. amp6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusSpAmp6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "388051.protein.sequences.v11.5.fa",
		        "enrichment_path": "388051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388051.protein.info.v11.5.txt",
		        "node_list_path": "388051.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusBingmayongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus bingmayongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusBingmayongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150157.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150157.protein.info.v11.5.txt",
		        "node_list_path": "1150157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacillusThermoglucosidasiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus thermoglucosidasius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusThermoglucosidasiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634956.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634956.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634956.clusters.proteins.v11.5.txt",
		        "sequence_path": "634956.protein.sequences.v11.5.fa",
		        "enrichment_path": "634956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634956.protein.info.v11.5.txt",
		        "node_list_path": "634956.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634956.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaRohdei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia rohdei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaRohdei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29485.protein.sequences.v11.5.fa",
		        "enrichment_path": "29485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29485.protein.info.v11.5.txt",
		        "node_list_path": "29485.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacteraceaeBacteriumPmmr1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacteraceae bacterium PMMR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacteraceaeBacteriumPmmr1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1382303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1382303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1382303.clusters.proteins.v11.5.txt",
		        "sequence_path": "1382303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382303.protein.info.v11.5.txt",
		        "node_list_path": "1382303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1382303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusLarvaeSubspLarvae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus larvae subsp. larvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusLarvaeSubspLarvae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "147375.protein.sequences.v11.5.fa",
		        "enrichment_path": "147375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "147375.protein.info.v11.5.txt",
		        "node_list_path": "147375.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpHel13378Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel1_33_78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpHel13378Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336804.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336804.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336804.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336804.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336804.protein.info.v11.5.txt",
		        "node_list_path": "1336804.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336804.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureobasidiumMelanogenumCbs110374Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium melanogenum CBS 110374 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureobasidiumMelanogenumCbs110374Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1043003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1043003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1043003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1043003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1043003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1043003.protein.info.v11.5.txt",
		        "node_list_path": "1043003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1043003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterPhenanthrenivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter phenanthrenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterPhenanthrenivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930171.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930171.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930171.clusters.proteins.v11.5.txt",
		        "sequence_path": "930171.protein.sequences.v11.5.fa",
		        "enrichment_path": "930171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930171.protein.info.v11.5.txt",
		        "node_list_path": "930171.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930171.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumRifoxyc2Full3521Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYC2_FULL_35_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyc2Full3521Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798452.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798452.protein.info.v11.5.txt",
		        "node_list_path": "1798452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelomonasSpRoot1237Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1237 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelomonasSpRoot1237Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736434.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736434.protein.info.v11.5.txt",
		        "node_list_path": "1736434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "693986.protein.sequences.v11.5.fa",
		        "enrichment_path": "693986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693986.protein.info.v11.5.txt",
		        "node_list_path": "693986.protein.complete.v11.5.txt"
		    }
		]
    )()

def GloeophyllumTrabeumAtcc11539(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gloeophyllum trabeum ATCC 11539 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeophyllumTrabeumAtcc11539", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "670483.protein.sequences.v11.5.fa",
		        "enrichment_path": "670483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670483.protein.info.v11.5.txt",
		        "node_list_path": "670483.protein.complete.v11.5.txt"
		    }
		]
    )()

def PasteurellaDagmatisAtcc43325Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella dagmatis ATCC 43325 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaDagmatisAtcc43325Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "667128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "667128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "667128.clusters.proteins.v11.5.txt",
		        "sequence_path": "667128.protein.sequences.v11.5.fa",
		        "enrichment_path": "667128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667128.protein.info.v11.5.txt",
		        "node_list_path": "667128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "667128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpRoot102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpRoot102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736422.protein.info.v11.5.txt",
		        "node_list_path": "1736422.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpAcs1612Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS1612 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpAcs1612Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834117.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834117.protein.info.v11.5.txt",
		        "node_list_path": "1834117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumUndaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium undae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumUndaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397693.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397693.protein.info.v11.5.txt",
		        "node_list_path": "1397693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HebelomaCylindrosporumH7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hebeloma cylindrosporum h7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HebelomaCylindrosporumH7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "686832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "686832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "686832.clusters.proteins.v11.5.txt",
		        "sequence_path": "686832.protein.sequences.v11.5.fa",
		        "enrichment_path": "686832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686832.protein.info.v11.5.txt",
		        "node_list_path": "686832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "686832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerobiumAcetethylicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobium acetethylicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobiumAcetethylicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619234.protein.info.v11.5.txt",
		        "node_list_path": "1619234.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpYr583(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. YR583 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpYr583", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881047.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881047.protein.info.v11.5.txt",
		        "node_list_path": "1881047.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAlbulusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces albulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAlbulusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68570.clusters.proteins.v11.5.txt",
		        "sequence_path": "68570.protein.sequences.v11.5.fa",
		        "enrichment_path": "68570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68570.protein.info.v11.5.txt",
		        "node_list_path": "68570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichococcusFlocculiformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichococcus flocculiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichococcusFlocculiformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "82803.protein.sequences.v11.5.fa",
		        "enrichment_path": "82803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82803.protein.info.v11.5.txt",
		        "node_list_path": "82803.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylomicrobiumAlcaliphilum20z(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomicrobium alcaliphilum 20Z graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomicrobiumAlcaliphilum20z", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1091494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1091494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1091494.protein.info.v11.5.txt",
		        "node_list_path": "1091494.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchistosomaMattheei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma mattheei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaMattheei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "31246.protein.sequences.v11.5.fa",
		        "enrichment_path": "31246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31246.protein.info.v11.5.txt",
		        "node_list_path": "31246.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydomonasReinhardtiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydomonas reinhardtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydomonasReinhardtiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3055.clusters.proteins.v11.5.txt",
		        "sequence_path": "3055.protein.sequences.v11.5.fa",
		        "enrichment_path": "3055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3055.protein.info.v11.5.txt",
		        "node_list_path": "3055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpCf136Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. CF136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpCf136Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144313.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144313.protein.info.v11.5.txt",
		        "node_list_path": "1144313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfofustisGlycolicusDsm9705Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfofustis glycolicus DSM 9705 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfofustisGlycolicusDsm9705Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121409.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121409.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121409.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121409.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121409.protein.info.v11.5.txt",
		        "node_list_path": "1121409.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121409.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full4013b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full4013b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802041.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802041.protein.info.v11.5.txt",
		        "node_list_path": "1802041.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptonychotesWeddellii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptonychotes weddellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptonychotesWeddellii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9713.protein.sequences.v11.5.fa",
		        "enrichment_path": "9713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9713.protein.info.v11.5.txt",
		        "node_list_path": "9713.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusShapirobacteriaBacteriumCg2303520(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium CG2_30_35_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusShapirobacteriaBacteriumCg2303520", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805376.protein.info.v11.5.txt",
		        "node_list_path": "1805376.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchistosomaMansoni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma mansoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaMansoni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6183.protein.sequences.v11.5.fa",
		        "enrichment_path": "6183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6183.protein.info.v11.5.txt",
		        "node_list_path": "6183.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumSpCcbau05631(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. CCBAU05631 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumSpCcbau05631", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "794846.protein.sequences.v11.5.fa",
		        "enrichment_path": "794846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "794846.protein.info.v11.5.txt",
		        "node_list_path": "794846.protein.complete.v11.5.txt"
		    }
		]
    )()

def GorillaGorillaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gorilla gorilla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GorillaGorillaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9593.clusters.proteins.v11.5.txt",
		        "sequence_path": "9593.protein.sequences.v11.5.fa",
		        "enrichment_path": "9593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9593.protein.info.v11.5.txt",
		        "node_list_path": "9593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalothrixSp3363(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Calothrix sp. 3363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalothrixSp3363", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1337936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1337936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1337936.protein.info.v11.5.txt",
		        "node_list_path": "1337936.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaHaemolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga haemolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaHaemolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45243.protein.sequences.v11.5.fa",
		        "enrichment_path": "45243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45243.protein.info.v11.5.txt",
		        "node_list_path": "45243.protein.complete.v11.5.txt"
		    }
		]
    )()

def MuricaudaAntarctica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Muricauda antarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuricaudaAntarctica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1055723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1055723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1055723.protein.info.v11.5.txt",
		        "node_list_path": "1055723.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumSpSo1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. SO1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumSpSo1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1244869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1244869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1244869.protein.info.v11.5.txt",
		        "node_list_path": "1244869.protein.complete.v11.5.txt"
		    }
		]
    )()

def HeliocybeSulcata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Heliocybe sulcata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeliocybeSulcata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5364.protein.sequences.v11.5.fa",
		        "enrichment_path": "5364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5364.protein.info.v11.5.txt",
		        "node_list_path": "5364.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpUrha0014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. URHA0014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpUrha0014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380372.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380372.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380372.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380372.protein.info.v11.5.txt",
		        "node_list_path": "1380372.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380372.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodospirillalesBacteriumUrhd0088Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium URHD0088 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillalesBacteriumUrhd0088Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380394.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380394.protein.info.v11.5.txt",
		        "node_list_path": "1380394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpX2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. X2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpX2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "941449.clusters.info.v11.5.txt",
		        "cluster_tree_path": "941449.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "941449.clusters.proteins.v11.5.txt",
		        "sequence_path": "941449.protein.sequences.v11.5.fa",
		        "enrichment_path": "941449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "941449.protein.info.v11.5.txt",
		        "node_list_path": "941449.cluster.nodes.v11.5.txt",
		        "edge_list_path": "941449.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichosporonAsahii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichosporon asahii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichosporonAsahii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "82508.protein.sequences.v11.5.fa",
		        "enrichment_path": "82508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82508.protein.info.v11.5.txt",
		        "node_list_path": "82508.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirosomaEndophyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma endophyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaEndophyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "662367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "662367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "662367.clusters.proteins.v11.5.txt",
		        "sequence_path": "662367.protein.sequences.v11.5.fa",
		        "enrichment_path": "662367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "662367.protein.info.v11.5.txt",
		        "node_list_path": "662367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "662367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsphigho201Full4023Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO2_01_FULL_40_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201Full4023Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802616.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802616.protein.info.v11.5.txt",
		        "node_list_path": "1802616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaceaeBacteriumKbs89(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS89 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs89", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267534.protein.info.v11.5.txt",
		        "node_list_path": "1267534.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeferribacteralesBacteriumDeferri01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deferribacterales bacterium Deferri_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeferribacteralesBacteriumDeferri01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674894.protein.info.v11.5.txt",
		        "node_list_path": "1674894.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHtcc2207(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2207 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2207", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314287.protein.sequences.v11.0.fa",
		        "enrichment_path": "314287.protein.enrichment.terms.v11.0.txt",
		        "info_path": "314287.protein.info.v11.0.txt",
		        "node_list_path": "314287.protein.complete.v11.0.txt"
		    }
		]
    )()

def XylanimonasCellulosilytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xylanimonas cellulosilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylanimonasCellulosilytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "446471.protein.sequences.v11.5.fa",
		        "enrichment_path": "446471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446471.protein.info.v11.5.txt",
		        "node_list_path": "446471.protein.complete.v11.5.txt"
		    }
		]
    )()

def DefluviitogaTunisiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Defluviitoga tunisiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DefluviitogaTunisiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1006576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1006576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1006576.protein.info.v11.5.txt",
		        "node_list_path": "1006576.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaLiquefaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia liquefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaLiquefaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "614.protein.sequences.v11.5.fa",
		        "enrichment_path": "614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "614.protein.info.v11.5.txt",
		        "node_list_path": "614.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSasangense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sasangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSasangense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121896.protein.info.v11.5.txt",
		        "node_list_path": "1121896.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaEnterocoliticaLc20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica LC20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaEnterocoliticaLc20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1443113.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443113.protein.info.v11.5.txt",
		        "node_list_path": "1443113.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumViciae3841(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae 3841 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumViciae3841", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216596.protein.sequences.v11.5.fa",
		        "enrichment_path": "216596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216596.protein.info.v11.5.txt",
		        "node_list_path": "216596.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnabaenaSpCaAtcc33047Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anabaena sp. CA ATCC 33047 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabaenaSpCaAtcc33047Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52271.clusters.proteins.v11.5.txt",
		        "sequence_path": "52271.protein.sequences.v11.5.fa",
		        "enrichment_path": "52271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52271.protein.info.v11.5.txt",
		        "node_list_path": "52271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GluconobacterAlbidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter albidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterAlbidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "318683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "318683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "318683.clusters.proteins.v11.5.txt",
		        "sequence_path": "318683.protein.sequences.v11.5.fa",
		        "enrichment_path": "318683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318683.protein.info.v11.5.txt",
		        "node_list_path": "318683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "318683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolimonasVariicoloris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solimonas variicoloris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolimonasVariicoloris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123256.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123256.protein.info.v11.5.txt",
		        "node_list_path": "1123256.protein.complete.v11.5.txt"
		    }
		]
    )()

def OxobacterPfennigiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oxobacter pfennigii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OxobacterPfennigiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36849.clusters.proteins.v11.5.txt",
		        "sequence_path": "36849.protein.sequences.v11.5.fa",
		        "enrichment_path": "36849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36849.protein.info.v11.5.txt",
		        "node_list_path": "36849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FriedmanniellaFlava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Friedmanniella flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FriedmanniellaFlava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1036181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036181.protein.info.v11.5.txt",
		        "node_list_path": "1036181.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaSpF0412Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. F0412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaSpF0412Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "879309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "879309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "879309.clusters.proteins.v11.5.txt",
		        "sequence_path": "879309.protein.sequences.v11.5.fa",
		        "enrichment_path": "879309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879309.protein.info.v11.5.txt",
		        "node_list_path": "879309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "879309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidaminococcusSpCag542(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidaminococcus sp. CAG:542 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminococcusSpCag542", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262687.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262687.protein.info.v11.5.txt",
		        "node_list_path": "1262687.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActibacteriumAtlanticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actibacterium atlanticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActibacteriumAtlanticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461693.protein.info.v11.5.txt",
		        "node_list_path": "1461693.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobotryumLychnidisDioicaeP1a1LamoleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbotryum lychnidis-dioicae p1A1 Lamole Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobotryumLychnidisDioicaeP1a1LamoleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "683840.clusters.info.v11.5.txt",
		        "cluster_tree_path": "683840.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "683840.clusters.proteins.v11.5.txt",
		        "sequence_path": "683840.protein.sequences.v11.5.fa",
		        "enrichment_path": "683840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683840.protein.info.v11.5.txt",
		        "node_list_path": "683840.cluster.nodes.v11.5.txt",
		        "edge_list_path": "683840.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacteriaceaeBacteriumLsjc7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium LSJC7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacteriaceaeBacteriumLsjc7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1224136.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1224136.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1224136.clusters.proteins.v11.5.txt",
		        "sequence_path": "1224136.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224136.protein.info.v11.5.txt",
		        "node_list_path": "1224136.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1224136.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyxococcalesBacterium6820(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myxococcales bacterium 68-20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcalesBacterium6820", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895795.protein.info.v11.5.txt",
		        "node_list_path": "1895795.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaTuberumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia tuberum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaTuberumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "157910.clusters.info.v11.5.txt",
		        "cluster_tree_path": "157910.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "157910.clusters.proteins.v11.5.txt",
		        "sequence_path": "157910.protein.sequences.v11.5.fa",
		        "enrichment_path": "157910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157910.protein.info.v11.5.txt",
		        "node_list_path": "157910.cluster.nodes.v11.5.txt",
		        "edge_list_path": "157910.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptosphaeriaMaculansJn3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptosphaeria maculans JN3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptosphaeriaMaculansJn3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "985895.protein.sequences.v11.5.fa",
		        "enrichment_path": "985895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985895.protein.info.v11.5.txt",
		        "node_list_path": "985895.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasHussainiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas hussainii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasHussainiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1429083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1429083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1429083.clusters.proteins.v11.5.txt",
		        "sequence_path": "1429083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1429083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1429083.protein.info.v11.5.txt",
		        "node_list_path": "1429083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1429083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicoccusAlkaliphilusDsm16010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus alkaliphilus DSM 16010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusAlkaliphilusDsm16010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123231.protein.info.v11.5.txt",
		        "node_list_path": "1123231.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteralesBacteriumY4iCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium Y4I Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteralesBacteriumY4iCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "439496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "439496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "439496.clusters.proteins.v11.5.txt",
		        "sequence_path": "439496.protein.sequences.v11.5.fa",
		        "enrichment_path": "439496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439496.protein.info.v11.5.txt",
		        "node_list_path": "439496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "439496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterOboediens174bp2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter oboediens 174Bp2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterOboediens174bp2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "940286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "940286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "940286.clusters.proteins.v11.5.txt",
		        "sequence_path": "940286.protein.sequences.v11.5.fa",
		        "enrichment_path": "940286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "940286.protein.info.v11.5.txt",
		        "node_list_path": "940286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "940286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSanguinisSk1057Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK1057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSanguinisSk1057Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888821.clusters.proteins.v11.5.txt",
		        "sequence_path": "888821.protein.sequences.v11.5.fa",
		        "enrichment_path": "888821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888821.protein.info.v11.5.txt",
		        "node_list_path": "888821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonomuraeaMaritimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaMaritimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "683260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "683260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "683260.clusters.proteins.v11.5.txt",
		        "sequence_path": "683260.protein.sequences.v11.5.fa",
		        "enrichment_path": "683260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683260.protein.info.v11.5.txt",
		        "node_list_path": "683260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "683260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopococcusTabaci(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopococcus tabaci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopococcusTabaci", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121024.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121024.protein.info.v11.5.txt",
		        "node_list_path": "1121024.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumGw2011Gwc14715(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWC1_47_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwc14715", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618364.protein.info.v11.5.txt",
		        "node_list_path": "1618364.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full4019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_40_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full4019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798281.protein.info.v11.5.txt",
		        "node_list_path": "1798281.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesDirus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles dirus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesDirus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7168.protein.sequences.v11.5.fa",
		        "enrichment_path": "7168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7168.protein.info.v11.5.txt",
		        "node_list_path": "7168.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumLarrymooreiAf310Atcc51759(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium larrymoorei AF3.10 ATCC 51759 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumLarrymooreiAf310Atcc51759", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1367849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1367849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1367849.protein.info.v11.5.txt",
		        "node_list_path": "1367849.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasGuangdongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas guangdongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasGuangdongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1245526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1245526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1245526.clusters.proteins.v11.5.txt",
		        "sequence_path": "1245526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245526.protein.info.v11.5.txt",
		        "node_list_path": "1245526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1245526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphriteaAtlanticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amphritea atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphriteaAtlanticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "355243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "355243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "355243.clusters.proteins.v11.5.txt",
		        "sequence_path": "355243.protein.sequences.v11.5.fa",
		        "enrichment_path": "355243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "355243.protein.info.v11.5.txt",
		        "node_list_path": "355243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "355243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacteriumLuteolum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacterium luteolum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacteriumLuteolum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "440168.protein.sequences.v11.5.fa",
		        "enrichment_path": "440168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "440168.protein.info.v11.5.txt",
		        "node_list_path": "440168.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaematospirillumJordaniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haematospirillum jordaniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaematospirillumJordaniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1549855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1549855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1549855.protein.info.v11.5.txt",
		        "node_list_path": "1549855.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusSpLc300(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. LC300 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusSpLc300", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1519377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519377.protein.info.v11.5.txt",
		        "node_list_path": "1519377.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaSpNrrlS836Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia sp. NRRL S-836 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSpNrrlS836Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1519492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1519492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1519492.clusters.proteins.v11.5.txt",
		        "sequence_path": "1519492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519492.protein.info.v11.5.txt",
		        "node_list_path": "1519492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1519492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidimicrobiumFerrooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidimicrobium ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidimicrobiumFerrooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525909.clusters.proteins.v11.5.txt",
		        "sequence_path": "525909.protein.sequences.v11.5.fa",
		        "enrichment_path": "525909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525909.protein.info.v11.5.txt",
		        "node_list_path": "525909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicolaSpHl35(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola sp. HL35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaSpHl35", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1305735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305735.protein.info.v11.5.txt",
		        "node_list_path": "1305735.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlossinaMorsitansMorsitansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glossina morsitans morsitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlossinaMorsitansMorsitansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37546.clusters.proteins.v11.5.txt",
		        "sequence_path": "37546.protein.sequences.v11.5.fa",
		        "enrichment_path": "37546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37546.protein.info.v11.5.txt",
		        "node_list_path": "37546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasPanacihumi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas panacihumi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasPanacihumi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "676599.protein.sequences.v11.5.fa",
		        "enrichment_path": "676599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "676599.protein.info.v11.5.txt",
		        "node_list_path": "676599.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpCag611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpCag611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262905.protein.info.v11.5.txt",
		        "node_list_path": "1262905.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChrysochlorisAsiaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chrysochloris asiatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChrysochlorisAsiaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "185453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "185453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "185453.clusters.proteins.v11.5.txt",
		        "sequence_path": "185453.protein.sequences.v11.5.fa",
		        "enrichment_path": "185453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "185453.protein.info.v11.5.txt",
		        "node_list_path": "185453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "185453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusSpA2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius sp. A-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusSpA2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1570360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1570360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1570360.clusters.proteins.v11.5.txt",
		        "sequence_path": "1570360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570360.protein.info.v11.5.txt",
		        "node_list_path": "1570360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1570360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusSpEp1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sp. EP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSpEp1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1591054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1591054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1591054.protein.info.v11.5.txt",
		        "node_list_path": "1591054.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpKk4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. KK4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpKk4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855729.protein.info.v11.5.txt",
		        "node_list_path": "1855729.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteiniphilumAcetatigenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteiniphilum acetatigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteiniphilumAcetatigenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123008.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123008.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123008.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123008.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123008.protein.info.v11.5.txt",
		        "node_list_path": "1123008.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123008.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OryzaMeridionalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza meridionalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaMeridionalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40149.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40149.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40149.clusters.proteins.v11.5.txt",
		        "sequence_path": "40149.protein.sequences.v11.5.fa",
		        "enrichment_path": "40149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40149.protein.info.v11.5.txt",
		        "node_list_path": "40149.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40149.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusTuaregi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus tuaregi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusTuaregi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816695.protein.info.v11.5.txt",
		        "node_list_path": "1816695.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterSputorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sputorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSputorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32024.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32024.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32024.clusters.proteins.v11.5.txt",
		        "sequence_path": "32024.protein.sequences.v11.5.fa",
		        "enrichment_path": "32024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32024.protein.info.v11.5.txt",
		        "node_list_path": "32024.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32024.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpJl475(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. JL475 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpJl475", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "383381.protein.sequences.v11.5.fa",
		        "enrichment_path": "383381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "383381.protein.info.v11.5.txt",
		        "node_list_path": "383381.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHtcc2083(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HTCC2083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHtcc2083", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314270.protein.sequences.v11.5.fa",
		        "enrichment_path": "314270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314270.protein.info.v11.5.txt",
		        "node_list_path": "314270.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinimicrobiumXinjiangenseDsm19287(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinimicrobium xinjiangense DSM 19287 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinimicrobiumXinjiangenseDsm19287", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123235.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123235.protein.info.v11.5.txt",
		        "node_list_path": "1123235.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRbg165811Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_58_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRbg165811Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797476.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797476.protein.info.v11.5.txt",
		        "node_list_path": "1797476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StegodyphusMimosarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stegodyphus mimosarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StegodyphusMimosarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "407821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "407821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "407821.clusters.proteins.v11.5.txt",
		        "sequence_path": "407821.protein.sequences.v11.5.fa",
		        "enrichment_path": "407821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "407821.protein.info.v11.5.txt",
		        "node_list_path": "407821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "407821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerriglobusRoseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terriglobus roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerriglobusRoseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926566.clusters.proteins.v11.5.txt",
		        "sequence_path": "926566.protein.sequences.v11.5.fa",
		        "enrichment_path": "926566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926566.protein.info.v11.5.txt",
		        "node_list_path": "926566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSp3524zxxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 3524ZXX Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSp3524zxxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1545915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1545915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1545915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1545915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545915.protein.info.v11.5.txt",
		        "node_list_path": "1545915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1545915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAle19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAle19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1266909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1266909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1266909.clusters.proteins.v11.5.txt",
		        "sequence_path": "1266909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266909.protein.info.v11.5.txt",
		        "node_list_path": "1266909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1266909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarboxydocellaSpUlo1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carboxydocella sp. ULO1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarboxydocellaSpUlo1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926599.protein.info.v11.5.txt",
		        "node_list_path": "1926599.protein.complete.v11.5.txt"
		    }
		]
    )()

def PostiaPlacentaMad698RCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Postia placenta Mad-698-R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PostiaPlacentaMad698RCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "561896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "561896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "561896.clusters.proteins.v11.5.txt",
		        "sequence_path": "561896.protein.sequences.v11.5.fa",
		        "enrichment_path": "561896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561896.protein.info.v11.5.txt",
		        "node_list_path": "561896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "561896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColinusVirginianusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colinus virginianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColinusVirginianusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9014.clusters.proteins.v11.5.txt",
		        "sequence_path": "9014.protein.sequences.v11.5.fa",
		        "enrichment_path": "9014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9014.protein.info.v11.5.txt",
		        "node_list_path": "9014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SanguibacterSuareziiNbrc16159Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter suarezii NBRC 16159 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SanguibacterSuareziiNbrc16159Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223525.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223525.protein.info.v11.5.txt",
		        "node_list_path": "1223525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrugiaPahangi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brugia pahangi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrugiaPahangi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6280.protein.sequences.v11.5.fa",
		        "enrichment_path": "6280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6280.protein.info.v11.5.txt",
		        "node_list_path": "6280.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlwc3626(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3626 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlwc3626", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463926.protein.info.v11.5.txt",
		        "node_list_path": "1463926.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaSpEc08061901(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. EC080619-01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaSpEc08061901", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1096856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1096856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1096856.protein.info.v11.5.txt",
		        "node_list_path": "1096856.protein.complete.v11.5.txt"
		    }
		]
    )()

def EremotheciumCymbalariaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium cymbalariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremotheciumCymbalariaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45285.clusters.proteins.v11.5.txt",
		        "sequence_path": "45285.protein.sequences.v11.5.fa",
		        "enrichment_path": "45285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45285.protein.info.v11.5.txt",
		        "node_list_path": "45285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpSr15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. SR1/5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpSr15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "657323.clusters.info.v11.5.txt",
		        "cluster_tree_path": "657323.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "657323.clusters.proteins.v11.5.txt",
		        "sequence_path": "657323.protein.sequences.v11.5.fa",
		        "enrichment_path": "657323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657323.protein.info.v11.5.txt",
		        "node_list_path": "657323.cluster.nodes.v11.5.txt",
		        "edge_list_path": "657323.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumStercorariumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium stercorarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumStercorariumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121335.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121335.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121335.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121335.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121335.protein.info.v11.5.txt",
		        "node_list_path": "1121335.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121335.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StemphyliumLycopersiciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stemphylium lycopersici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StemphyliumLycopersiciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "183478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "183478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "183478.clusters.proteins.v11.5.txt",
		        "sequence_path": "183478.protein.sequences.v11.5.fa",
		        "enrichment_path": "183478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "183478.protein.info.v11.5.txt",
		        "node_list_path": "183478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "183478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumM102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium M102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumM102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235796.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235796.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235796.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235796.protein.info.v11.5.txt",
		        "node_list_path": "1235796.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235796.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusAquaticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus aquaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusAquaticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "498848.clusters.info.v11.5.txt",
		        "cluster_tree_path": "498848.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "498848.clusters.proteins.v11.5.txt",
		        "sequence_path": "498848.protein.sequences.v11.5.fa",
		        "enrichment_path": "498848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498848.protein.info.v11.5.txt",
		        "node_list_path": "498848.cluster.nodes.v11.5.txt",
		        "edge_list_path": "498848.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyellaJaponicaA8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyella japonica A8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaJaponicaA8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217721.protein.info.v11.5.txt",
		        "node_list_path": "1217721.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumSpVcm10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium sp. VCM10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumSpVcm10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1381751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381751.protein.info.v11.5.txt",
		        "node_list_path": "1381751.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalieaceaeBacteriumImcc3088(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halieaceae bacterium IMCC3088 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalieaceaeBacteriumImcc3088", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2518989.protein.sequences.v11.5.fa",
		        "enrichment_path": "2518989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2518989.protein.info.v11.5.txt",
		        "node_list_path": "2518989.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaGrimshawiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila grimshawi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaGrimshawiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7222.clusters.proteins.v11.5.txt",
		        "sequence_path": "7222.protein.sequences.v11.5.fa",
		        "enrichment_path": "7222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7222.protein.info.v11.5.txt",
		        "node_list_path": "7222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaSputorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea sputorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaSputorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93222.clusters.proteins.v11.5.txt",
		        "sequence_path": "93222.protein.sequences.v11.5.fa",
		        "enrichment_path": "93222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93222.protein.info.v11.5.txt",
		        "node_list_path": "93222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsplowo201Full4534Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_01_FULL_45_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo201Full4534Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798351.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798351.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798351.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798351.protein.info.v11.5.txt",
		        "node_list_path": "1798351.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798351.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorellaSorokinianaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorella sorokiniana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorellaSorokinianaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3076.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3076.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3076.clusters.proteins.v11.5.txt",
		        "sequence_path": "3076.protein.sequences.v11.5.fa",
		        "enrichment_path": "3076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3076.protein.info.v11.5.txt",
		        "node_list_path": "3076.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3076.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraInterrogansSerovarLaiStr56601Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira interrogans serovar Lai str. 56601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraInterrogansSerovarLaiStr56601Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "189518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "189518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "189518.clusters.proteins.v11.5.txt",
		        "sequence_path": "189518.protein.sequences.v11.5.fa",
		        "enrichment_path": "189518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189518.protein.info.v11.5.txt",
		        "node_list_path": "189518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "189518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag563Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:563 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag563Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262961.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262961.protein.info.v11.5.txt",
		        "node_list_path": "1262961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesHygroscopicusSubspHygroscopicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus subsp. hygroscopicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesHygroscopicusSubspHygroscopicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68042.protein.sequences.v11.5.fa",
		        "enrichment_path": "68042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68042.protein.info.v11.5.txt",
		        "node_list_path": "68042.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusRenniniDsm20253Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rennini DSM 20253 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusRenniniDsm20253Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423796.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423796.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423796.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423796.protein.info.v11.5.txt",
		        "node_list_path": "1423796.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423796.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrucellaMelitensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brucella melitensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrucellaMelitensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "224914.protein.sequences.v11.5.fa",
		        "enrichment_path": "224914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224914.protein.info.v11.5.txt",
		        "node_list_path": "224914.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumCitreumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium citreum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumCitreumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2036.clusters.proteins.v11.5.txt",
		        "sequence_path": "2036.protein.sequences.v11.5.fa",
		        "enrichment_path": "2036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2036.protein.info.v11.5.txt",
		        "node_list_path": "2036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RiemerellaColumbipharyngisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Riemerella columbipharyngis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RiemerellaColumbipharyngisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071918.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071918.protein.info.v11.5.txt",
		        "node_list_path": "1071918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf407(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf407 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf407", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736369.protein.info.v11.5.txt",
		        "node_list_path": "1736369.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaWadsworthiiDsm21896Atcc33877Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella wadsworthii DSM 21896 ATCC 33877 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaWadsworthiiDsm21896Atcc33877Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122170.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122170.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122170.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122170.protein.info.v11.5.txt",
		        "node_list_path": "1122170.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122170.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumSpH133(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. H133 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumSpH133", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "861208.protein.sequences.v11.5.fa",
		        "enrichment_path": "861208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861208.protein.info.v11.5.txt",
		        "node_list_path": "861208.protein.complete.v11.5.txt"
		    }
		]
    )()

def YangiaPacifica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yangia pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YangiaPacifica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "311180.protein.sequences.v11.5.fa",
		        "enrichment_path": "311180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311180.protein.info.v11.5.txt",
		        "node_list_path": "311180.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpEpsL25(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. EpS/L25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpEpsL25", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1749078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1749078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1749078.protein.info.v11.5.txt",
		        "node_list_path": "1749078.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlloactinosynnemaSpL07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alloactinosynnema sp. L-07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloactinosynnemaSpL07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1653480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1653480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1653480.clusters.proteins.v11.5.txt",
		        "sequence_path": "1653480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1653480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1653480.protein.info.v11.5.txt",
		        "node_list_path": "1653480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1653480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaSpielmanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia spielmanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaSpielmanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "498742.protein.sequences.v11.5.fa",
		        "enrichment_path": "498742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498742.protein.info.v11.5.txt",
		        "node_list_path": "498742.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucobacterSalsiciusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter salsicius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterSalsiciusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1238186.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1238186.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1238186.clusters.proteins.v11.5.txt",
		        "sequence_path": "1238186.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238186.protein.info.v11.5.txt",
		        "node_list_path": "1238186.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1238186.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpSg611l(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SG61-1L graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpSg611l", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1603897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603897.protein.info.v11.5.txt",
		        "node_list_path": "1603897.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprobacillusSpCag826(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus sp. CAG:826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprobacillusSpCag826", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262857.protein.info.v11.5.txt",
		        "node_list_path": "1262857.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusApinorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus apinorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusApinorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218495.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218495.protein.info.v11.5.txt",
		        "node_list_path": "1218495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusJensenii1153chnCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii 1153CHN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusJensenii1153chnCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575605.clusters.proteins.v11.5.txt",
		        "sequence_path": "575605.protein.sequences.v11.5.fa",
		        "enrichment_path": "575605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575605.protein.info.v11.5.txt",
		        "node_list_path": "575605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpCf080Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF080 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpCf080Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144310.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144310.protein.info.v11.5.txt",
		        "node_list_path": "1144310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfacinumHydrothermaleDsm13146Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfacinum hydrothermale DSM 13146 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfacinumHydrothermaleDsm13146Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121390.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121390.protein.info.v11.5.txt",
		        "node_list_path": "1121390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalococcusSediminicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halococcus sediminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusSediminicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1264579.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1264579.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1264579.clusters.proteins.v11.5.txt",
		        "sequence_path": "1264579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1264579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1264579.protein.info.v11.5.txt",
		        "node_list_path": "1264579.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1264579.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyxococcalesBacteriumSg838(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myxococcales bacterium SG8_38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcalesBacteriumSg838", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703407.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703407.protein.info.v11.5.txt",
		        "node_list_path": "1703407.protein.complete.v11.5.txt"
		    }
		]
    )()

def ValsaMalicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Valsa malicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ValsaMalicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "356882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "356882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "356882.clusters.proteins.v11.5.txt",
		        "sequence_path": "356882.protein.sequences.v11.5.fa",
		        "enrichment_path": "356882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "356882.protein.info.v11.5.txt",
		        "node_list_path": "356882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "356882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TeredinibacterTurneraeT7902(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Teredinibacter turnerae T7902 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TeredinibacterTurneraeT7902", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1056820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1056820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1056820.protein.info.v11.5.txt",
		        "node_list_path": "1056820.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpJpy347(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. JPY347 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpJpy347", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "667632.protein.sequences.v11.5.fa",
		        "enrichment_path": "667632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667632.protein.info.v11.5.txt",
		        "node_list_path": "667632.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasSpIs79a3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Is79A3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasSpIs79a3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "261292.protein.sequences.v11.5.fa",
		        "enrichment_path": "261292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "261292.protein.info.v11.5.txt",
		        "node_list_path": "261292.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseibacaCalidilacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseibaca calidilacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseibacaCalidilacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1666912.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1666912.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1666912.clusters.proteins.v11.5.txt",
		        "sequence_path": "1666912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666912.protein.info.v11.5.txt",
		        "node_list_path": "1666912.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1666912.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ReichenbachiellaFaecimaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Reichenbachiella faecimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ReichenbachiellaFaecimaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "692418.protein.sequences.v11.5.fa",
		        "enrichment_path": "692418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "692418.protein.info.v11.5.txt",
		        "node_list_path": "692418.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSelenitireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus selenitireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSelenitireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1324314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1324314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1324314.protein.info.v11.5.txt",
		        "node_list_path": "1324314.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo202Full6614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_02_FULL_66_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202Full6614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797490.protein.info.v11.5.txt",
		        "node_list_path": "1797490.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacterSpHtcc7211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter sp. HTCC7211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterSpHtcc7211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "439493.clusters.info.v11.5.txt",
		        "cluster_tree_path": "439493.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "439493.clusters.proteins.v11.5.txt",
		        "sequence_path": "439493.protein.sequences.v11.5.fa",
		        "enrichment_path": "439493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439493.protein.info.v11.5.txt",
		        "node_list_path": "439493.cluster.nodes.v11.5.txt",
		        "edge_list_path": "439493.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrenneriaSpEnid312Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brenneria sp. EniD312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrenneriaSpEnid312Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "598467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "598467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "598467.clusters.proteins.v11.5.txt",
		        "sequence_path": "598467.protein.sequences.v11.5.fa",
		        "enrichment_path": "598467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "598467.protein.info.v11.5.txt",
		        "node_list_path": "598467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "598467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusSteyniiIbt23096(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus steynii IBT 23096 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusSteyniiIbt23096", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392250.protein.info.v11.5.txt",
		        "node_list_path": "1392250.protein.complete.v11.5.txt"
		    }
		]
    )()

def PisolithusTinctoriusMarx270(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pisolithus tinctorius Marx 270 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PisolithusTinctoriusMarx270", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "870435.protein.sequences.v11.5.fa",
		        "enrichment_path": "870435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "870435.protein.info.v11.5.txt",
		        "node_list_path": "870435.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSaltansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter saltans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSaltansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762903.clusters.proteins.v11.5.txt",
		        "sequence_path": "762903.protein.sequences.v11.5.fa",
		        "enrichment_path": "762903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762903.protein.info.v11.5.txt",
		        "node_list_path": "762903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMikellaEndobia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mikella endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMikellaEndobia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1778264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1778264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1778264.protein.info.v11.5.txt",
		        "node_list_path": "1778264.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarivirgaSericea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marivirga sericea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivirgaSericea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028.protein.info.v11.5.txt",
		        "node_list_path": "1028.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterCloacaeAtcc13047Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae ATCC13047 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterCloacaeAtcc13047Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "716541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "716541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "716541.clusters.proteins.v11.5.txt",
		        "sequence_path": "716541.protein.sequences.v11.5.fa",
		        "enrichment_path": "716541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "716541.protein.info.v11.5.txt",
		        "node_list_path": "716541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "716541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquimarinaMegaterium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina megaterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaMegaterium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1443666.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443666.protein.info.v11.5.txt",
		        "node_list_path": "1443666.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusVogelbacteriaBacteriumRifoxyd1Full4432(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_44_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full4432", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802438.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802438.protein.info.v11.5.txt",
		        "node_list_path": "1802438.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterWiegeliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter wiegelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterWiegeliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "697303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "697303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "697303.clusters.proteins.v11.5.txt",
		        "sequence_path": "697303.protein.sequences.v11.5.fa",
		        "enrichment_path": "697303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "697303.protein.info.v11.5.txt",
		        "node_list_path": "697303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "697303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeucobacterSalsicius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter salsicius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterSalsicius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1238186.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238186.protein.info.v11.5.txt",
		        "node_list_path": "1238186.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpH83Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. H83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpH83Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1827324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1827324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1827324.clusters.proteins.v11.5.txt",
		        "sequence_path": "1827324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827324.protein.info.v11.5.txt",
		        "node_list_path": "1827324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1827324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolycyclovoransAlgicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polycyclovorans algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolycyclovoransAlgicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415779.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415779.protein.info.v11.5.txt",
		        "node_list_path": "1415779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrococcusLuteusNctc2665(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micrococcus luteus NCTC 2665 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcusLuteusNctc2665", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "465515.protein.sequences.v11.5.fa",
		        "enrichment_path": "465515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "465515.protein.info.v11.5.txt",
		        "node_list_path": "465515.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBaylyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter baylyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBaylyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "202950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "202950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "202950.clusters.proteins.v11.5.txt",
		        "sequence_path": "202950.protein.sequences.v11.5.fa",
		        "enrichment_path": "202950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202950.protein.info.v11.5.txt",
		        "node_list_path": "202950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "202950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesHordeovulneris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces hordeovulneris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesHordeovulneris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52770.protein.sequences.v11.5.fa",
		        "enrichment_path": "52770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52770.protein.info.v11.5.txt",
		        "node_list_path": "52770.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhaeodactylumTricornutum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeodactylum tricornutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeodactylumTricornutum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2850.protein.sequences.v11.5.fa",
		        "enrichment_path": "2850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2850.protein.info.v11.5.txt",
		        "node_list_path": "2850.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasArgentinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas argentinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasArgentinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "289370.protein.sequences.v11.5.fa",
		        "enrichment_path": "289370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "289370.protein.info.v11.5.txt",
		        "node_list_path": "289370.protein.complete.v11.5.txt"
		    }
		]
    )()

def ToxoplasmaGondiiVegCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Toxoplasma gondii VEG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ToxoplasmaGondiiVegCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "432359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "432359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "432359.clusters.proteins.v11.5.txt",
		        "sequence_path": "432359.protein.sequences.v11.5.fa",
		        "enrichment_path": "432359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "432359.protein.info.v11.5.txt",
		        "node_list_path": "432359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "432359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnsiferShofinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer shofinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferShofinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1850094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1850094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1850094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1850094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850094.protein.info.v11.5.txt",
		        "node_list_path": "1850094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1850094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyprinodonVariegatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyprinodon variegatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyprinodonVariegatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28743.protein.sequences.v11.5.fa",
		        "enrichment_path": "28743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28743.protein.info.v11.5.txt",
		        "node_list_path": "28743.protein.complete.v11.5.txt"
		    }
		]
    )()

def KomagataellaPhaffiiGs115(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Komagataella phaffii GS115 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataellaPhaffiiGs115", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644223.protein.sequences.v11.5.fa",
		        "enrichment_path": "644223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644223.protein.info.v11.5.txt",
		        "node_list_path": "644223.protein.complete.v11.5.txt"
		    }
		]
    )()

def EmilianiaHuxleyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Emiliania huxleyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmilianiaHuxleyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2903.protein.sequences.v11.5.fa",
		        "enrichment_path": "2903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2903.protein.info.v11.5.txt",
		        "node_list_path": "2903.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapsicumBaccatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capsicum baccatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsicumBaccatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33114.protein.sequences.v11.5.fa",
		        "enrichment_path": "33114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33114.protein.info.v11.5.txt",
		        "node_list_path": "33114.protein.complete.v11.5.txt"
		    }
		]
    )()

def CupriavidusGilardiiCr3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus gilardii CR3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusGilardiiCr3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267562.protein.info.v11.5.txt",
		        "node_list_path": "1267562.protein.complete.v11.5.txt"
		    }
		]
    )()

def KwoniellaHeveanensisBcc8398Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella heveanensis BCC8398 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KwoniellaHeveanensisBcc8398Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1296120.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1296120.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1296120.clusters.proteins.v11.5.txt",
		        "sequence_path": "1296120.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296120.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296120.protein.info.v11.5.txt",
		        "node_list_path": "1296120.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1296120.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag177Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:177 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag177Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262952.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262952.protein.info.v11.5.txt",
		        "node_list_path": "1262952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg165611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_56_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg165611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797649.protein.info.v11.5.txt",
		        "node_list_path": "1797649.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpS6spd3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. S6Spd3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpS6spd3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1284680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284680.protein.info.v11.5.txt",
		        "node_list_path": "1284680.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658218.protein.sequences.v11.5.fa",
		        "enrichment_path": "658218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658218.protein.info.v11.5.txt",
		        "node_list_path": "658218.protein.complete.v11.5.txt"
		    }
		]
    )()

def Sar86ClusterBacteriumBacl1Mag120820Bin45Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium BACL1 MAG-120820-bin45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar86ClusterBacteriumBacl1Mag120820Bin45Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1655612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1655612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1655612.clusters.proteins.v11.5.txt",
		        "sequence_path": "1655612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655612.protein.info.v11.5.txt",
		        "node_list_path": "1655612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1655612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerrabacterSpSoil810(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terrabacter sp. Soil810 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrabacterSpSoil810", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736418.protein.info.v11.5.txt",
		        "node_list_path": "1736418.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioBrasiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioBrasiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "945543.protein.sequences.v11.5.fa",
		        "enrichment_path": "945543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "945543.protein.info.v11.5.txt",
		        "node_list_path": "945543.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisSpYbe204Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. YBE204 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisSpYbe204Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1282363.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1282363.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1282363.clusters.proteins.v11.5.txt",
		        "sequence_path": "1282363.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282363.protein.info.v11.5.txt",
		        "node_list_path": "1282363.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1282363.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusJiangxiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus jiangxiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusJiangxiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "235985.protein.sequences.v11.5.fa",
		        "enrichment_path": "235985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "235985.protein.info.v11.5.txt",
		        "node_list_path": "235985.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSpHv1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. Hv1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpHv1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1740090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1740090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1740090.protein.info.v11.5.txt",
		        "node_list_path": "1740090.protein.complete.v11.5.txt"
		    }
		]
    )()

def SegetibacterKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Segetibacter koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SegetibacterKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123248.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123248.protein.info.v11.5.txt",
		        "node_list_path": "1123248.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusTigurinus1366Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus tigurinus 1366 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusTigurinus1366Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1282665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1282665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1282665.clusters.proteins.v11.5.txt",
		        "sequence_path": "1282665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282665.protein.info.v11.5.txt",
		        "node_list_path": "1282665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1282665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusAtlanticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusAtlanticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1641875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1641875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1641875.protein.info.v11.5.txt",
		        "node_list_path": "1641875.protein.complete.v11.5.txt"
		    }
		]
    )()

def VagococcusLutrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vagococcus lutrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VagococcusLutrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408226.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408226.protein.info.v11.5.txt",
		        "node_list_path": "1408226.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_40_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619047.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619047.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619047.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619047.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619047.protein.info.v11.5.txt",
		        "node_list_path": "1619047.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619047.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KallipygaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kallipyga massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KallipygaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118059.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118059.protein.info.v11.5.txt",
		        "node_list_path": "1118059.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassobacterArenae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacter arenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobacterArenae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123360.protein.info.v11.5.txt",
		        "node_list_path": "1123360.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterGlacincola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter glacincola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterGlacincola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56810.protein.sequences.v11.5.fa",
		        "enrichment_path": "56810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56810.protein.info.v11.5.txt",
		        "node_list_path": "56810.protein.complete.v11.5.txt"
		    }
		]
    )()

def PterulaGracilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pterula gracilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PterulaGracilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884261.protein.info.v11.5.txt",
		        "node_list_path": "1884261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CynoglossusSemilaevisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cynoglossus semilaevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CynoglossusSemilaevisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "244447.clusters.info.v11.5.txt",
		        "cluster_tree_path": "244447.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "244447.clusters.proteins.v11.5.txt",
		        "sequence_path": "244447.protein.sequences.v11.5.fa",
		        "enrichment_path": "244447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244447.protein.info.v11.5.txt",
		        "node_list_path": "244447.cluster.nodes.v11.5.txt",
		        "edge_list_path": "244447.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomonasMethanicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas methanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasMethanicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "857087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "857087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "857087.clusters.proteins.v11.5.txt",
		        "sequence_path": "857087.protein.sequences.v11.5.fa",
		        "enrichment_path": "857087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857087.protein.info.v11.5.txt",
		        "node_list_path": "857087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "857087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPacearchaeotaArchaeonRbg133326Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacearchaeota archaeon RBG_13_33_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacearchaeotaArchaeonRbg133326Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801880.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801880.protein.info.v11.5.txt",
		        "node_list_path": "1801880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpCag472Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:472 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpCag472Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262904.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262904.protein.info.v11.5.txt",
		        "node_list_path": "1262904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpPamc26617Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PAMC26617 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpPamc26617Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1112216.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1112216.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1112216.clusters.proteins.v11.5.txt",
		        "sequence_path": "1112216.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112216.protein.info.v11.5.txt",
		        "node_list_path": "1112216.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1112216.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LawsoniaIntracellularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lawsonia intracellularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LawsoniaIntracellularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "363253.clusters.info.v11.5.txt",
		        "cluster_tree_path": "363253.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "363253.clusters.proteins.v11.5.txt",
		        "sequence_path": "363253.protein.sequences.v11.5.fa",
		        "enrichment_path": "363253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "363253.protein.info.v11.5.txt",
		        "node_list_path": "363253.cluster.nodes.v11.5.txt",
		        "edge_list_path": "363253.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiovulumSpEs(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiovulum sp. ES graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiovulumSpEs", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1177931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177931.protein.info.v11.5.txt",
		        "node_list_path": "1177931.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwh4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWH4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwh4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896210.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896210.protein.info.v11.5.txt",
		        "node_list_path": "1896210.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSpZym1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. ZYM-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSpZym1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1681184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1681184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1681184.clusters.proteins.v11.5.txt",
		        "sequence_path": "1681184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1681184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1681184.protein.info.v11.5.txt",
		        "node_list_path": "1681184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1681184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerolineaceaeBacterium457278Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium 4572_78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaceaeBacterium457278Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1972460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1972460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1972460.clusters.proteins.v11.5.txt",
		        "sequence_path": "1972460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1972460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1972460.protein.info.v11.5.txt",
		        "node_list_path": "1972460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1972460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HolosporaObtusa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Holospora obtusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HolosporaObtusa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1399147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399147.protein.info.v11.5.txt",
		        "node_list_path": "1399147.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpYr295Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR295 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpYr295Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500257.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500257.protein.info.v11.5.txt",
		        "node_list_path": "1500257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZygosaccharomycesRouxii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zygosaccharomyces rouxii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZygosaccharomycesRouxii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4956.protein.sequences.v11.5.fa",
		        "enrichment_path": "4956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4956.protein.info.v11.5.txt",
		        "node_list_path": "4956.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRbg165712Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RBG_16_57_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRbg165712Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798266.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798266.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798266.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798266.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798266.protein.info.v11.5.txt",
		        "node_list_path": "1798266.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798266.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumGallicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium gallicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumGallicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "561180.clusters.info.v11.5.txt",
		        "cluster_tree_path": "561180.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "561180.clusters.proteins.v11.5.txt",
		        "sequence_path": "561180.protein.sequences.v11.5.fa",
		        "enrichment_path": "561180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561180.protein.info.v11.5.txt",
		        "node_list_path": "561180.cluster.nodes.v11.5.txt",
		        "edge_list_path": "561180.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerostipesSp494aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerostipes sp. 494a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerostipesSp494aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1261636.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1261636.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1261636.clusters.proteins.v11.5.txt",
		        "sequence_path": "1261636.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261636.protein.info.v11.5.txt",
		        "node_list_path": "1261636.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1261636.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho201Full37110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_37_110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full37110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801730.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801730.protein.info.v11.5.txt",
		        "node_list_path": "1801730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConchiformibiusKuhniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Conchiformibius kuhniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConchiformibiusKuhniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121351.protein.info.v11.5.txt",
		        "node_list_path": "1121351.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpWmmb714(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. WMMB 714 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpWmmb714", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1286822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286822.protein.info.v11.5.txt",
		        "node_list_path": "1286822.protein.complete.v11.5.txt"
		    }
		]
    )()

def IdiomarinaIndicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaIndicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1159017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1159017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1159017.clusters.proteins.v11.5.txt",
		        "sequence_path": "1159017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159017.protein.info.v11.5.txt",
		        "node_list_path": "1159017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1159017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AfipiaBirgiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Afipia birgiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaBirgiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1197906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197906.protein.info.v11.5.txt",
		        "node_list_path": "1197906.protein.complete.v11.5.txt"
		    }
		]
    )()

def HirschiaBalticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hirschia baltica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HirschiaBalticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582402.clusters.proteins.v11.5.txt",
		        "sequence_path": "582402.protein.sequences.v11.5.fa",
		        "enrichment_path": "582402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582402.protein.info.v11.5.txt",
		        "node_list_path": "582402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SmittiumMegazygosporum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Smittium megazygosporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmittiumMegazygosporum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "133381.protein.sequences.v11.5.fa",
		        "enrichment_path": "133381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133381.protein.info.v11.5.txt",
		        "node_list_path": "133381.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanococcusAtlanticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanococcus atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanococcusAtlanticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1317117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317117.protein.info.v11.5.txt",
		        "node_list_path": "1317117.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChaetomiumThermophilumVarThermophilumDsm1495Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium thermophilum var. thermophilum DSM 1495 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChaetomiumThermophilumVarThermophilumDsm1495Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "759272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "759272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "759272.clusters.proteins.v11.5.txt",
		        "sequence_path": "759272.protein.sequences.v11.5.fa",
		        "enrichment_path": "759272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759272.protein.info.v11.5.txt",
		        "node_list_path": "759272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "759272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporosarcinaKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "334735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "334735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "334735.clusters.proteins.v11.5.txt",
		        "sequence_path": "334735.protein.sequences.v11.5.fa",
		        "enrichment_path": "334735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334735.protein.info.v11.5.txt",
		        "node_list_path": "334735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "334735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisDx1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris DX1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisDx1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "652103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "652103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "652103.clusters.proteins.v11.5.txt",
		        "sequence_path": "652103.protein.sequences.v11.5.fa",
		        "enrichment_path": "652103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "652103.protein.info.v11.5.txt",
		        "node_list_path": "652103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "652103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720302.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720302.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720302.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720302.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720302.protein.info.v11.5.txt",
		        "node_list_path": "1720302.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720302.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumMola455(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MOLA455 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumMola455", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1411685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1411685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1411685.protein.info.v11.5.txt",
		        "node_list_path": "1411685.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium4146(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 41-46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium4146", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895922.protein.info.v11.5.txt",
		        "node_list_path": "1895922.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioMaritimus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio maritimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioMaritimus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "990268.protein.sequences.v11.5.fa",
		        "enrichment_path": "990268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990268.protein.info.v11.5.txt",
		        "node_list_path": "990268.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph298Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH 298 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph298Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217692.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217692.protein.info.v11.5.txt",
		        "node_list_path": "1217692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizopogonVinicolorAmOr11026(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizopogon vinicolor AM-OR11-026 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopogonVinicolorAmOr11026", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314800.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314800.protein.info.v11.5.txt",
		        "node_list_path": "1314800.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScardoviaInopinata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scardovia inopinata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScardoviaInopinata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641146.protein.sequences.v11.5.fa",
		        "enrichment_path": "641146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641146.protein.info.v11.5.txt",
		        "node_list_path": "641146.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaBovigenitalium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma bovigenitalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaBovigenitalium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1188235.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188235.protein.info.v11.5.txt",
		        "node_list_path": "1188235.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5123Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5123Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463856.protein.info.v11.5.txt",
		        "node_list_path": "1463856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCarsonellaRuddiiCeIsolateThao2000Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii CE isolate Thao2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCarsonellaRuddiiCeIsolateThao2000Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1202536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1202536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1202536.clusters.proteins.v11.5.txt",
		        "sequence_path": "1202536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202536.protein.info.v11.5.txt",
		        "node_list_path": "1202536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1202536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp21311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2131.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp21311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855346.protein.info.v11.5.txt",
		        "node_list_path": "1855346.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpLeaf363Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Leaf363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpLeaf363Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736353.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736353.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736353.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736353.protein.info.v11.5.txt",
		        "node_list_path": "1736353.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736353.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomicrobiumZhouii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomicrobium zhouii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomicrobiumZhouii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "767519.protein.sequences.v11.5.fa",
		        "enrichment_path": "767519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767519.protein.info.v11.5.txt",
		        "node_list_path": "767519.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpKg01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. KG01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpKg01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674920.protein.info.v11.5.txt",
		        "node_list_path": "1674920.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZimmermannellaBifidaNbrc103089Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Zimmermannella] bifida NBRC 103089 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZimmermannellaBifidaNbrc103089Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349787.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349787.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349787.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349787.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349787.protein.info.v11.5.txt",
		        "node_list_path": "1349787.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349787.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EndozoicomonasNumazuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas numazuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndozoicomonasNumazuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1137799.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1137799.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1137799.clusters.proteins.v11.5.txt",
		        "sequence_path": "1137799.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137799.protein.info.v11.5.txt",
		        "node_list_path": "1137799.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1137799.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GloeobacterKilaueensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gloeobacter kilaueensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeobacterKilaueensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1183438.protein.sequences.v11.5.fa",
		        "enrichment_path": "1183438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1183438.protein.info.v11.5.txt",
		        "node_list_path": "1183438.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwf1518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWF1_51_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwf1518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802190.protein.info.v11.5.txt",
		        "node_list_path": "1802190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusPittmaniaeHk85Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus pittmaniae HK 85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusPittmaniaeHk85Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035188.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035188.protein.info.v11.5.txt",
		        "node_list_path": "1035188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassotaleaSpPp2459(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassotalea sp. PP2-459 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassotaleaSpPp2459", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1742724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742724.protein.info.v11.5.txt",
		        "node_list_path": "1742724.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaNigra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora nigra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaNigra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "145857.protein.sequences.v11.5.fa",
		        "enrichment_path": "145857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "145857.protein.info.v11.5.txt",
		        "node_list_path": "145857.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumTardaugensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium tardaugens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumTardaugensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219035.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219035.protein.info.v11.5.txt",
		        "node_list_path": "1219035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophorhabdusAromaticivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophorhabdus aromaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophorhabdusAromaticivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "909663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "909663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "909663.clusters.proteins.v11.5.txt",
		        "sequence_path": "909663.protein.sequences.v11.5.fa",
		        "enrichment_path": "909663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "909663.protein.info.v11.5.txt",
		        "node_list_path": "909663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "909663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachanceaDasiensisCbs10888(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachancea dasiensis CBS 10888 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachanceaDasiensisCbs10888", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1266660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266660.protein.info.v11.5.txt",
		        "node_list_path": "1266660.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumCg10237114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_37_114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumCg10237114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805131.protein.info.v11.5.txt",
		        "node_list_path": "1805131.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisNigoni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis nigoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisNigoni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1611254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1611254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1611254.protein.info.v11.5.txt",
		        "node_list_path": "1611254.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaSpScgcAb629i23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota sp. SCGC AB629I23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaSpScgcAb629i23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131266.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1131266.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1131266.clusters.proteins.v11.0.txt",
		        "sequence_path": "1131266.protein.sequences.v11.0.fa",
		        "enrichment_path": "1131266.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1131266.protein.info.v11.0.txt",
		        "node_list_path": "1131266.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1131266.protein.cluster.v11.0.txt"
		    }
		]
    )()

def BlastocystisSpAtcc50177NandIiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastocystis sp. ATCC 50177/Nand II Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastocystisSpAtcc50177NandIiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "478820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "478820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "478820.clusters.proteins.v11.5.txt",
		        "sequence_path": "478820.protein.sequences.v11.5.fa",
		        "enrichment_path": "478820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "478820.protein.info.v11.5.txt",
		        "node_list_path": "478820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "478820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSp2kl3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 2KL-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSp2kl3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1100700.protein.sequences.v11.5.fa",
		        "enrichment_path": "1100700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1100700.protein.info.v11.5.txt",
		        "node_list_path": "1100700.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseomonasGilardii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas gilardii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseomonasGilardii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336208.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336208.protein.info.v11.5.txt",
		        "node_list_path": "1336208.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumGoodiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium goodii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumGoodiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "134601.clusters.info.v11.5.txt",
		        "cluster_tree_path": "134601.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "134601.clusters.proteins.v11.5.txt",
		        "sequence_path": "134601.protein.sequences.v11.5.fa",
		        "enrichment_path": "134601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134601.protein.info.v11.5.txt",
		        "node_list_path": "134601.cluster.nodes.v11.5.txt",
		        "edge_list_path": "134601.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidimicrobiumFerrooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidimicrobium ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidimicrobiumFerrooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525909.protein.sequences.v11.5.fa",
		        "enrichment_path": "525909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525909.protein.info.v11.5.txt",
		        "node_list_path": "525909.protein.complete.v11.5.txt"
		    }
		]
    )()

def CycloclasticusZanclesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus zancles Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CycloclasticusZanclesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1198232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1198232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1198232.clusters.proteins.v11.5.txt",
		        "sequence_path": "1198232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198232.protein.info.v11.5.txt",
		        "node_list_path": "1198232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1198232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriKos6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri KOS6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriKos6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218352.protein.info.v11.5.txt",
		        "node_list_path": "1218352.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaSpOralTaxon807Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella sp. oral taxon 807 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaSpOralTaxon807Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "712411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "712411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "712411.clusters.proteins.v11.5.txt",
		        "sequence_path": "712411.protein.sequences.v11.5.fa",
		        "enrichment_path": "712411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712411.protein.info.v11.5.txt",
		        "node_list_path": "712411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "712411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorKristjanssoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor kristjanssonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorKristjanssoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "632335.clusters.info.v11.5.txt",
		        "cluster_tree_path": "632335.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "632335.clusters.proteins.v11.5.txt",
		        "sequence_path": "632335.protein.sequences.v11.5.fa",
		        "enrichment_path": "632335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632335.protein.info.v11.5.txt",
		        "node_list_path": "632335.cluster.nodes.v11.5.txt",
		        "edge_list_path": "632335.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferVariabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer variabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferVariabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1279017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1279017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1279017.clusters.proteins.v11.5.txt",
		        "sequence_path": "1279017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1279017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1279017.protein.info.v11.5.txt",
		        "node_list_path": "1279017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1279017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiopsisSalinaYim90010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis salina YIM 90010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisSalinaYim90010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246485.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246485.protein.info.v11.5.txt",
		        "node_list_path": "1246485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HypoxylonSpCi4a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hypoxylon sp. CI-4A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HypoxylonSpCi4a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1001833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001833.protein.info.v11.5.txt",
		        "node_list_path": "1001833.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaSpCua673Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. CUA-673 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaSpCua673Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1904969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1904969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1904969.clusters.proteins.v11.5.txt",
		        "sequence_path": "1904969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904969.protein.info.v11.5.txt",
		        "node_list_path": "1904969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1904969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusSpTm1035(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius sp. TM1035 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusSpTm1035", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391613.protein.sequences.v11.5.fa",
		        "enrichment_path": "391613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391613.protein.info.v11.5.txt",
		        "node_list_path": "391613.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLpu83(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. LPU83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLpu83", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "348824.protein.sequences.v11.5.fa",
		        "enrichment_path": "348824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "348824.protein.info.v11.5.txt",
		        "node_list_path": "348824.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslH80548(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSL H8-0548 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslH80548", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1920422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920422.protein.info.v11.5.txt",
		        "node_list_path": "1920422.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfovibrioAggregans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio aggregans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfovibrioAggregans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86166.protein.sequences.v11.5.fa",
		        "enrichment_path": "86166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86166.protein.info.v11.5.txt",
		        "node_list_path": "86166.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaTeleogrylli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Erwinia] teleogrylli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaTeleogrylli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1384589.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384589.protein.info.v11.5.txt",
		        "node_list_path": "1384589.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasArcisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas arcis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasArcisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "416873.clusters.info.v11.5.txt",
		        "cluster_tree_path": "416873.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "416873.clusters.proteins.v11.5.txt",
		        "sequence_path": "416873.protein.sequences.v11.5.fa",
		        "enrichment_path": "416873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416873.protein.info.v11.5.txt",
		        "node_list_path": "416873.cluster.nodes.v11.5.txt",
		        "edge_list_path": "416873.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusVeneficus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus veneficus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusVeneficus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "693661.protein.sequences.v11.5.fa",
		        "enrichment_path": "693661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693661.protein.info.v11.5.txt",
		        "node_list_path": "693661.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScleropagesFormosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scleropages formosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScleropagesFormosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "113540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "113540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "113540.clusters.proteins.v11.5.txt",
		        "sequence_path": "113540.protein.sequences.v11.5.fa",
		        "enrichment_path": "113540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113540.protein.info.v11.5.txt",
		        "node_list_path": "113540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "113540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpMit0602(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0602 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpMit0602", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499499.protein.info.v11.5.txt",
		        "node_list_path": "1499499.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanolobusPsychrophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus psychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolobusPsychrophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094980.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094980.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094980.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094980.protein.info.v11.5.txt",
		        "node_list_path": "1094980.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094980.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrincolaLacisaponensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrincola lacisaponensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrincolaLacisaponensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "267850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "267850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "267850.clusters.proteins.v11.5.txt",
		        "sequence_path": "267850.protein.sequences.v11.5.fa",
		        "enrichment_path": "267850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267850.protein.info.v11.5.txt",
		        "node_list_path": "267850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "267850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpibacteriumUlvae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epibacterium ulvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpibacteriumUlvae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1156985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156985.protein.info.v11.5.txt",
		        "node_list_path": "1156985.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArenibacterLatericiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenibacter latericius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenibacterLatericiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121012.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121012.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121012.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121012.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121012.protein.info.v11.5.txt",
		        "node_list_path": "1121012.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121012.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MobilicoccusPelagius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mobilicoccus pelagius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobilicoccusPelagius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089455.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089455.protein.info.v11.5.txt",
		        "node_list_path": "1089455.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262802.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262802.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262802.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262802.protein.info.v11.5.txt",
		        "node_list_path": "1262802.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262802.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumSubtropicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium subtropicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumSubtropicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "753702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "753702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "753702.clusters.proteins.v11.5.txt",
		        "sequence_path": "753702.protein.sequences.v11.5.fa",
		        "enrichment_path": "753702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "753702.protein.info.v11.5.txt",
		        "node_list_path": "753702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "753702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpRac03Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. RAC03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpRac03Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1843368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1843368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1843368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1843368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1843368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1843368.protein.info.v11.5.txt",
		        "node_list_path": "1843368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1843368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhascolarctobacteriumSuccinatutens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phascolarctobacterium succinatutens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhascolarctobacteriumSuccinatutens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "626940.protein.sequences.v11.5.fa",
		        "enrichment_path": "626940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626940.protein.info.v11.5.txt",
		        "node_list_path": "626940.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosopumilusAdriaticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus adriaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopumilusAdriaticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1580092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1580092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1580092.protein.info.v11.5.txt",
		        "node_list_path": "1580092.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerpentinomonasRaichei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serpentinomonas raichei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerpentinomonasRaichei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1458425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458425.protein.info.v11.5.txt",
		        "node_list_path": "1458425.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanothermococcusOkinawensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanothermococcus okinawensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermococcusOkinawensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "647113.protein.sequences.v11.5.fa",
		        "enrichment_path": "647113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "647113.protein.info.v11.5.txt",
		        "node_list_path": "647113.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1329250.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1329250.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1329250.clusters.proteins.v11.5.txt",
		        "sequence_path": "1329250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1329250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1329250.protein.info.v11.5.txt",
		        "node_list_path": "1329250.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1329250.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaGrandensisFslF60971Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria grandensis FSL F6-0971 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaGrandensisFslF60971Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265819.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265819.protein.info.v11.5.txt",
		        "node_list_path": "1265819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PythiumIwayamai(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pythium iwayamai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PythiumIwayamai", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "115417.protein.sequences.v11.5.fa",
		        "enrichment_path": "115417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115417.protein.info.v11.5.txt",
		        "node_list_path": "115417.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "252474.protein.sequences.v11.5.fa",
		        "enrichment_path": "252474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "252474.protein.info.v11.5.txt",
		        "node_list_path": "252474.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChrysemysPictaBelliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chrysemys picta bellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChrysemysPictaBelliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8478.clusters.proteins.v11.5.txt",
		        "sequence_path": "8478.protein.sequences.v11.5.fa",
		        "enrichment_path": "8478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8478.protein.info.v11.5.txt",
		        "node_list_path": "8478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorientalisSpIm1011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorientalis sp. IM1011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorientalisSpIm1011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1932360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1932360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1932360.clusters.proteins.v11.5.txt",
		        "sequence_path": "1932360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1932360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1932360.protein.info.v11.5.txt",
		        "node_list_path": "1932360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1932360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrenarchaeotaArchaeon13140cm3535Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_53_5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenarchaeotaArchaeon13140cm3535Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805098.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805098.protein.info.v11.5.txt",
		        "node_list_path": "1805098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraParasiticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora parasitica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraParasiticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4792.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4792.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4792.clusters.proteins.v11.5.txt",
		        "sequence_path": "4792.protein.sequences.v11.5.fa",
		        "enrichment_path": "4792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4792.protein.info.v11.5.txt",
		        "node_list_path": "4792.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4792.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5062.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5062.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5062.clusters.proteins.v11.5.txt",
		        "sequence_path": "5062.protein.sequences.v11.5.fa",
		        "enrichment_path": "5062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5062.protein.info.v11.5.txt",
		        "node_list_path": "5062.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5062.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaSp499(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. 499 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSp499", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1261634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261634.protein.info.v11.5.txt",
		        "node_list_path": "1261634.protein.complete.v11.5.txt"
		    }
		]
    )()

def StrigopsHabroptilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Strigops habroptila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrigopsHabroptilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2489341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2489341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2489341.clusters.proteins.v11.5.txt",
		        "sequence_path": "2489341.protein.sequences.v11.5.fa",
		        "enrichment_path": "2489341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2489341.protein.info.v11.5.txt",
		        "node_list_path": "2489341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2489341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TaphrinaDeformansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Taphrina deformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TaphrinaDeformansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5011.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5011.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5011.clusters.proteins.v11.5.txt",
		        "sequence_path": "5011.protein.sequences.v11.5.fa",
		        "enrichment_path": "5011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5011.protein.info.v11.5.txt",
		        "node_list_path": "5011.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5011.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumBrisbanenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium brisbanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumBrisbanenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "146020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "146020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "146020.clusters.proteins.v11.5.txt",
		        "sequence_path": "146020.protein.sequences.v11.5.fa",
		        "enrichment_path": "146020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146020.protein.info.v11.5.txt",
		        "node_list_path": "146020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "146020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesThermolilacinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces thermolilacinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesThermolilacinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1306406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1306406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1306406.clusters.proteins.v11.5.txt",
		        "sequence_path": "1306406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306406.protein.info.v11.5.txt",
		        "node_list_path": "1306406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1306406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3918Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_39_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3918Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801771.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801771.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801771.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801771.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801771.protein.info.v11.5.txt",
		        "node_list_path": "1801771.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801771.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaeB728a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae B728a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaeB728a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "205918.protein.sequences.v11.5.fa",
		        "enrichment_path": "205918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "205918.protein.info.v11.5.txt",
		        "node_list_path": "205918.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaLondiniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella londiniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaLondiniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45068.clusters.proteins.v11.5.txt",
		        "sequence_path": "45068.protein.sequences.v11.5.fa",
		        "enrichment_path": "45068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45068.protein.info.v11.5.txt",
		        "node_list_path": "45068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysobacterArseniciresistensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter arseniciresistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterArseniciresistensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "913325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "913325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "913325.clusters.proteins.v11.5.txt",
		        "sequence_path": "913325.protein.sequences.v11.5.fa",
		        "enrichment_path": "913325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913325.protein.info.v11.5.txt",
		        "node_list_path": "913325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "913325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinophagaGinsengisegetis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga ginsengisegetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaGinsengisegetis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "393003.protein.sequences.v11.5.fa",
		        "enrichment_path": "393003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393003.protein.info.v11.5.txt",
		        "node_list_path": "393003.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaYuzhufengensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia yuzhufengensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaYuzhufengensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1164594.protein.sequences.v11.5.fa",
		        "enrichment_path": "1164594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1164594.protein.info.v11.5.txt",
		        "node_list_path": "1164594.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollinsellaIntestinalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collinsella intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaIntestinalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521003.clusters.proteins.v11.5.txt",
		        "sequence_path": "521003.protein.sequences.v11.5.fa",
		        "enrichment_path": "521003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521003.protein.info.v11.5.txt",
		        "node_list_path": "521003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaCanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaCanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117644.protein.info.v11.5.txt",
		        "node_list_path": "1117644.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCrudilactis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium crudilactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCrudilactis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1652495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1652495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1652495.protein.info.v11.5.txt",
		        "node_list_path": "1652495.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusViridansAtcc11563(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus viridans ATCC11563 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusViridansAtcc11563", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655812.protein.sequences.v11.5.fa",
		        "enrichment_path": "655812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655812.protein.info.v11.5.txt",
		        "node_list_path": "655812.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorallococcusSpCag1435(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corallococcus sp. CAG:1435 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorallococcusSpCag1435", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262867.protein.info.v11.5.txt",
		        "node_list_path": "1262867.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasMandeliiPd30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mandelii PD30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMandeliiPd30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1419583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1419583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1419583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1419583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1419583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1419583.protein.info.v11.5.txt",
		        "node_list_path": "1419583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1419583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTsri0107Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TSRI0107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTsri0107Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703942.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703942.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703942.protein.info.v11.5.txt",
		        "node_list_path": "1703942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusOtakiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus otakiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOtakiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423780.protein.info.v11.5.txt",
		        "node_list_path": "1423780.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtheneCunicularia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Athene cunicularia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtheneCunicularia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "194338.protein.sequences.v11.5.fa",
		        "enrichment_path": "194338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "194338.protein.info.v11.5.txt",
		        "node_list_path": "194338.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho201Full3826(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_38_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3826", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798591.protein.info.v11.5.txt",
		        "node_list_path": "1798591.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraMesophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira mesophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraMesophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293891.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293891.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293891.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293891.protein.info.v11.5.txt",
		        "node_list_path": "1293891.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293891.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevirhabdusPacifica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevirhabdus pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevirhabdusPacifica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267768.protein.info.v11.5.txt",
		        "node_list_path": "1267768.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaLongbeachaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella longbeachae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaLongbeachaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "661367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "661367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "661367.clusters.proteins.v11.5.txt",
		        "sequence_path": "661367.protein.sequences.v11.5.fa",
		        "enrichment_path": "661367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "661367.protein.info.v11.5.txt",
		        "node_list_path": "661367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "661367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHtcc2080Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2080 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2080Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "247639.clusters.info.v11.0.txt",
		        "cluster_tree_path": "247639.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "247639.clusters.proteins.v11.0.txt",
		        "sequence_path": "247639.protein.sequences.v11.0.fa",
		        "enrichment_path": "247639.protein.enrichment.terms.v11.0.txt",
		        "info_path": "247639.protein.info.v11.0.txt",
		        "node_list_path": "247639.cluster.nodes.v11.0.txt",
		        "edge_list_path": "247639.protein.cluster.v11.0.txt"
		    }
		]
    )()

def ThaueraSp28(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. 28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraSp28", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "303682.protein.sequences.v11.5.fa",
		        "enrichment_path": "303682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "303682.protein.info.v11.5.txt",
		        "node_list_path": "303682.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSpPamc26640Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. PAMC 26640 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSpPamc26640Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1300914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1300914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1300914.clusters.proteins.v11.5.txt",
		        "sequence_path": "1300914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300914.protein.info.v11.5.txt",
		        "node_list_path": "1300914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1300914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudothermotogaHypogeaDsm11164Nbrc106472Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudothermotoga hypogea DSM 11164 NBRC 106472 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudothermotogaHypogeaDsm11164Nbrc106472Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123384.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123384.protein.info.v11.5.txt",
		        "node_list_path": "1123384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHlucco07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCO07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHlucco07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1666914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666914.protein.info.v11.5.txt",
		        "node_list_path": "1666914.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpF0430Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0430 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpF0430Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "879310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "879310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "879310.clusters.proteins.v11.5.txt",
		        "sequence_path": "879310.protein.sequences.v11.5.fa",
		        "enrichment_path": "879310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879310.protein.info.v11.5.txt",
		        "node_list_path": "879310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "879310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaGrimmiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia grimmiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaGrimmiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071679.protein.info.v11.5.txt",
		        "node_list_path": "1071679.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaColi536(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli 536 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColi536", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "362663.protein.sequences.v11.5.fa",
		        "enrichment_path": "362663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362663.protein.info.v11.5.txt",
		        "node_list_path": "362663.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsaiaPlatycodiJcm25414(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asaia platycodi JCM 25414 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsaiaPlatycodiJcm25414", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236525.protein.info.v11.5.txt",
		        "node_list_path": "1236525.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetovibrioBlakemorei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetovibrio blakemorei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetovibrioBlakemorei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28181.protein.sequences.v11.5.fa",
		        "enrichment_path": "28181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28181.protein.info.v11.5.txt",
		        "node_list_path": "28181.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpRoot154(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. Root154 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpRoot154", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736476.protein.info.v11.5.txt",
		        "node_list_path": "1736476.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumUlceransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium ulcerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumUlceransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469617.clusters.proteins.v11.5.txt",
		        "sequence_path": "469617.protein.sequences.v11.5.fa",
		        "enrichment_path": "469617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469617.protein.info.v11.5.txt",
		        "node_list_path": "469617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterPiechaudiiAtcc43553Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii ATCC43553 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterPiechaudiiAtcc43553Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742159.clusters.proteins.v11.5.txt",
		        "sequence_path": "742159.protein.sequences.v11.5.fa",
		        "enrichment_path": "742159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742159.protein.info.v11.5.txt",
		        "node_list_path": "742159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerobutyricumHalliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobutyricum hallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobutyricumHalliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39488.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39488.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39488.clusters.proteins.v11.5.txt",
		        "sequence_path": "39488.protein.sequences.v11.5.fa",
		        "enrichment_path": "39488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39488.protein.info.v11.5.txt",
		        "node_list_path": "39488.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39488.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RodentibacterGenomosp1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter genomosp. 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterGenomosp1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1908264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908264.protein.info.v11.5.txt",
		        "node_list_path": "1908264.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusAnaerobiusVpi4330(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius VPI4330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusAnaerobiusVpi4330", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035196.protein.info.v11.5.txt",
		        "node_list_path": "1035196.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLeaf311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLeaf311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736332.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736332.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736332.protein.info.v11.5.txt",
		        "node_list_path": "1736332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusSpLeaf369(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus sp. Leaf369 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusSpLeaf369", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736354.protein.info.v11.5.txt",
		        "node_list_path": "1736354.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumKocuriiJcm14978Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum kocurii JCM 14978 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumKocuriiJcm14978Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230456.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230456.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230456.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230456.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230456.protein.info.v11.5.txt",
		        "node_list_path": "1230456.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230456.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag245Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:245 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag245Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262784.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262784.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262784.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262784.protein.info.v11.5.txt",
		        "node_list_path": "1262784.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262784.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwb11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWB11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwb11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896202.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896202.protein.info.v11.5.txt",
		        "node_list_path": "1896202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeorickettsiaSp179522Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neorickettsia sp. 179522 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorickettsiaSp179522Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1714371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1714371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1714371.clusters.proteins.v11.5.txt",
		        "sequence_path": "1714371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714371.protein.info.v11.5.txt",
		        "node_list_path": "1714371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1714371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDesulfopertinaxCoweniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desulfopertinax cowenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDesulfopertinaxCoweniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1919273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1919273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1919273.clusters.proteins.v11.5.txt",
		        "sequence_path": "1919273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1919273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1919273.protein.info.v11.5.txt",
		        "node_list_path": "1919273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1919273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoactinomycesDaqusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoactinomyces daqus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoactinomycesDaqusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1329516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1329516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1329516.clusters.proteins.v11.5.txt",
		        "sequence_path": "1329516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1329516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1329516.protein.info.v11.5.txt",
		        "node_list_path": "1329516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1329516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioKanaloaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio kanaloae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioKanaloaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1191299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1191299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1191299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1191299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1191299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1191299.protein.info.v11.5.txt",
		        "node_list_path": "1191299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1191299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumCg1023744Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium CG1_02_37_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumCg1023744Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805146.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805146.protein.info.v11.5.txt",
		        "node_list_path": "1805146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalopigerSpIih2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halopiger sp. IIH2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalopigerSpIih2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293047.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293047.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293047.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293047.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293047.protein.info.v11.5.txt",
		        "node_list_path": "1293047.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293047.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquilunaSpImcc13023(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquiluna sp. IMCC13023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquilunaSpImcc13023", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1081644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081644.protein.info.v11.5.txt",
		        "node_list_path": "1081644.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporomusaMalonica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporomusa malonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporomusaMalonica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "112901.protein.sequences.v11.5.fa",
		        "enrichment_path": "112901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112901.protein.info.v11.5.txt",
		        "node_list_path": "112901.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumGwf2429Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_42_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumGwf2429Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801958.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801958.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801958.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801958.protein.info.v11.5.txt",
		        "node_list_path": "1801958.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801958.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiopsisSinuspersiciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis sinuspersici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisSinuspersiciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "501010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "501010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "501010.clusters.proteins.v11.5.txt",
		        "sequence_path": "501010.protein.sequences.v11.5.fa",
		        "enrichment_path": "501010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "501010.protein.info.v11.5.txt",
		        "node_list_path": "501010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "501010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusFerrooxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus ferrooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusFerrooxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471514.protein.sequences.v11.5.fa",
		        "enrichment_path": "471514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471514.protein.info.v11.5.txt",
		        "node_list_path": "471514.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpSoil774Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil774 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpSoil774Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736408.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736408.protein.info.v11.5.txt",
		        "node_list_path": "1736408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusBvHnlc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus bv. HNLC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusBvHnlc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041938.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041938.protein.info.v11.5.txt",
		        "node_list_path": "1041938.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSp31syn3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. 31syn3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSp31syn3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "457398.protein.sequences.v11.5.fa",
		        "enrichment_path": "457398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457398.protein.info.v11.5.txt",
		        "node_list_path": "457398.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumMagnumDsm2767Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium magnum DSM 2767 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumMagnumDsm2767Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121326.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121326.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121326.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121326.protein.info.v11.5.txt",
		        "node_list_path": "1121326.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121326.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumCsp14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium CSP1-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumCsp14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1640513.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640513.protein.info.v11.5.txt",
		        "node_list_path": "1640513.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnoanaerobaculumSaburreumF0468Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum F0468 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoanaerobaculumSaburreumF0468Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095750.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095750.protein.info.v11.5.txt",
		        "node_list_path": "1095750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaFermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaFermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "496833.protein.sequences.v11.5.fa",
		        "enrichment_path": "496833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "496833.protein.info.v11.5.txt",
		        "node_list_path": "496833.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpGa6a2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. Ga6A2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpGa6a2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410608.protein.info.v11.5.txt",
		        "node_list_path": "1410608.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsphigho212Full4616Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_12_FULL_46_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho212Full4616Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802513.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802513.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802513.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802513.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802513.protein.info.v11.5.txt",
		        "node_list_path": "1802513.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802513.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaBelliiRml369c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia bellii RML369C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaBelliiRml369c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "336407.protein.sequences.v11.5.fa",
		        "enrichment_path": "336407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336407.protein.info.v11.5.txt",
		        "node_list_path": "336407.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpTglY2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. TGL-Y2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpTglY2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1407071.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1407071.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1407071.clusters.proteins.v11.5.txt",
		        "sequence_path": "1407071.protein.sequences.v11.5.fa",
		        "enrichment_path": "1407071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1407071.protein.info.v11.5.txt",
		        "node_list_path": "1407071.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1407071.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesHygroscopicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesHygroscopicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1133850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1133850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1133850.clusters.proteins.v11.5.txt",
		        "sequence_path": "1133850.protein.sequences.v11.5.fa",
		        "enrichment_path": "1133850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1133850.protein.info.v11.5.txt",
		        "node_list_path": "1133850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1133850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacaMethylaminivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibaca methylaminivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacaMethylaminivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "515897.protein.sequences.v11.5.fa",
		        "enrichment_path": "515897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515897.protein.info.v11.5.txt",
		        "node_list_path": "515897.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgromycesSpRoot81(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agromyces sp. Root81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesSpRoot81", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736601.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736601.protein.info.v11.5.txt",
		        "node_list_path": "1736601.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "176090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "176090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "176090.clusters.proteins.v11.5.txt",
		        "sequence_path": "176090.protein.sequences.v11.5.fa",
		        "enrichment_path": "176090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "176090.protein.info.v11.5.txt",
		        "node_list_path": "176090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "176090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpA9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. A9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpA9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1284352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1284352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1284352.clusters.proteins.v11.5.txt",
		        "sequence_path": "1284352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284352.protein.info.v11.5.txt",
		        "node_list_path": "1284352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1284352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumTwa4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium TWA4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumTwa4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392836.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392836.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392836.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392836.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392836.protein.info.v11.5.txt",
		        "node_list_path": "1392836.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392836.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumMedpeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MedPE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumMedpeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1860093.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1860093.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1860093.clusters.proteins.v11.5.txt",
		        "sequence_path": "1860093.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860093.protein.info.v11.5.txt",
		        "node_list_path": "1860093.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1860093.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalalkalibacillusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halalkalibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalalkalibacillusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121936.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121936.protein.info.v11.5.txt",
		        "node_list_path": "1121936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaPleuritidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella pleuritidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaPleuritidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236494.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236494.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236494.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236494.protein.info.v11.5.txt",
		        "node_list_path": "1236494.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236494.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgromycesSpLeaf222Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agromyces sp. Leaf222 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesSpLeaf222Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735688.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735688.protein.info.v11.5.txt",
		        "node_list_path": "1735688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonBa2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon BA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonBa2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1700836.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1700836.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1700836.clusters.proteins.v11.5.txt",
		        "sequence_path": "1700836.protein.sequences.v11.5.fa",
		        "enrichment_path": "1700836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1700836.protein.info.v11.5.txt",
		        "node_list_path": "1700836.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1700836.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifcsplowo212Full6140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO2_12_FULL_61_40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo212Full6140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797566.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797566.protein.info.v11.5.txt",
		        "node_list_path": "1797566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GallionellalesBacteriumGwa25518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_55_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallionellalesBacteriumGwa25518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798244.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798244.protein.info.v11.5.txt",
		        "node_list_path": "1798244.protein.complete.v11.5.txt"
		    }
		]
    )()

def TistliaConsotensisUsba355Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tistlia consotensis USBA 355 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TistliaConsotensisUsba355Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "560819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "560819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "560819.clusters.proteins.v11.5.txt",
		        "sequence_path": "560819.protein.sequences.v11.5.fa",
		        "enrichment_path": "560819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "560819.protein.info.v11.5.txt",
		        "node_list_path": "560819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "560819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumOxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium oxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumOxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "82380.protein.sequences.v11.5.fa",
		        "enrichment_path": "82380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82380.protein.info.v11.5.txt",
		        "node_list_path": "82380.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomicronemaHongdechlorisC2206(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomicronema hongdechloris C2206 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomicronemaHongdechlorisC2206", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1641165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1641165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1641165.protein.info.v11.5.txt",
		        "node_list_path": "1641165.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquilunaSpImcc13023Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquiluna sp. IMCC13023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquilunaSpImcc13023Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1081644.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1081644.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1081644.clusters.proteins.v11.5.txt",
		        "sequence_path": "1081644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081644.protein.info.v11.5.txt",
		        "node_list_path": "1081644.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1081644.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UstilaginoideaVirensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ustilaginoidea virens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UstilaginoideaVirensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1159556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1159556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1159556.clusters.proteins.v11.5.txt",
		        "sequence_path": "1159556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159556.protein.info.v11.5.txt",
		        "node_list_path": "1159556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1159556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852364.protein.info.v11.5.txt",
		        "node_list_path": "1852364.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSanfranciscensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sanfranciscensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSanfranciscensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "714313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "714313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "714313.clusters.proteins.v11.5.txt",
		        "sequence_path": "714313.protein.sequences.v11.5.fa",
		        "enrichment_path": "714313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "714313.protein.info.v11.5.txt",
		        "node_list_path": "714313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "714313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp351mftsu51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 351MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp351mftsu51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1172180.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1172180.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1172180.clusters.proteins.v11.5.txt",
		        "sequence_path": "1172180.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172180.protein.info.v11.5.txt",
		        "node_list_path": "1172180.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1172180.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRifcsplowo212Full6819Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO2_12_FULL_68_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212Full6819Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797194.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797194.protein.info.v11.5.txt",
		        "node_list_path": "1797194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumFasciculatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium fasciculatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumFasciculatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2594813.protein.sequences.v11.5.fa",
		        "enrichment_path": "2594813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2594813.protein.info.v11.5.txt",
		        "node_list_path": "2594813.protein.complete.v11.5.txt"
		    }
		]
    )()

def TessaracoccusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1522311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522311.protein.info.v11.5.txt",
		        "node_list_path": "1522311.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusReuteri10023Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri 10023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusReuteri10023Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349123.clusters.proteins.v11.5.txt",
		        "sequence_path": "349123.protein.sequences.v11.5.fa",
		        "enrichment_path": "349123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349123.protein.info.v11.5.txt",
		        "node_list_path": "349123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GrosmanniaClavigeraKw1407(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Grosmannia clavigera kw1407 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GrosmanniaClavigeraKw1407", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655863.protein.sequences.v11.5.fa",
		        "enrichment_path": "655863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655863.protein.info.v11.5.txt",
		        "node_list_path": "655863.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCampbellbacteriaBacteriumRifcsplowo2023512(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFCSPLOWO2_02_35_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifcsplowo2023512", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797580.protein.info.v11.5.txt",
		        "node_list_path": "1797580.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasBrassicacearumSubspBrassicacearumNfm421Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas brassicacearum subsp. brassicacearum NFM421 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBrassicacearumSubspBrassicacearumNfm421Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "994484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "994484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "994484.clusters.proteins.v11.5.txt",
		        "sequence_path": "994484.protein.sequences.v11.5.fa",
		        "enrichment_path": "994484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "994484.protein.info.v11.5.txt",
		        "node_list_path": "994484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "994484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasAsaccharolyticaNbrc15499Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas asaccharolytica NBRC 15499 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasAsaccharolyticaNbrc15499Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219040.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219040.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219040.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219040.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219040.protein.info.v11.5.txt",
		        "node_list_path": "1219040.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219040.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag594Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:594 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag594Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262826.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262826.protein.info.v11.5.txt",
		        "node_list_path": "1262826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPeoriae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus peoriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPeoriae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1087481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1087481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1087481.protein.info.v11.5.txt",
		        "node_list_path": "1087481.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpErv7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. ERV7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpErv7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1322334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1322334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1322334.clusters.proteins.v11.5.txt",
		        "sequence_path": "1322334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1322334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1322334.protein.info.v11.5.txt",
		        "node_list_path": "1322334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1322334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumDecipiens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium decipiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumDecipiens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1430326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1430326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1430326.protein.info.v11.5.txt",
		        "node_list_path": "1430326.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumSg839Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium SG8_39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumSg839Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703390.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703390.protein.info.v11.5.txt",
		        "node_list_path": "1703390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusParacuniculus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus paracuniculus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusParacuniculus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "734.protein.sequences.v11.5.fa",
		        "enrichment_path": "734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "734.protein.info.v11.5.txt",
		        "node_list_path": "734.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloversatilisUniversalisEhg5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloversatilis universalis EHg5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloversatilisUniversalisEhg5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999628.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999628.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999628.clusters.proteins.v11.5.txt",
		        "sequence_path": "999628.protein.sequences.v11.5.fa",
		        "enrichment_path": "999628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999628.protein.info.v11.5.txt",
		        "node_list_path": "999628.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999628.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpMarseilleP2426(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. Marseille-P2426 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpMarseilleP2426", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816686.protein.info.v11.5.txt",
		        "node_list_path": "1816686.protein.complete.v11.5.txt"
		    }
		]
    )()

def GulosibacterMolinativoraxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gulosibacter molinativorax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GulosibacterMolinativoraxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121934.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121934.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121934.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121934.protein.info.v11.5.txt",
		        "node_list_path": "1121934.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121934.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProcaviaCapensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Procavia capensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProcaviaCapensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9813.clusters.proteins.v11.5.txt",
		        "sequence_path": "9813.protein.sequences.v11.5.fa",
		        "enrichment_path": "9813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9813.protein.info.v11.5.txt",
		        "node_list_path": "9813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasGingeriNcppb3146Lmg5327Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas gingeri NCPPB 3146 LMG 5327 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasGingeriNcppb3146Lmg5327Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "707248.clusters.info.v11.5.txt",
		        "cluster_tree_path": "707248.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "707248.clusters.proteins.v11.5.txt",
		        "sequence_path": "707248.protein.sequences.v11.5.fa",
		        "enrichment_path": "707248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "707248.protein.info.v11.5.txt",
		        "node_list_path": "707248.cluster.nodes.v11.5.txt",
		        "edge_list_path": "707248.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionisporaSp2237Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionispora sp. 2/2-37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionisporaSp2237Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1677858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1677858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1677858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1677858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1677858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1677858.protein.info.v11.5.txt",
		        "node_list_path": "1677858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1677858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcanthocheilonemaViteaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acanthocheilonema viteae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcanthocheilonemaViteaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6277.clusters.proteins.v11.5.txt",
		        "sequence_path": "6277.protein.sequences.v11.5.fa",
		        "enrichment_path": "6277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6277.protein.info.v11.5.txt",
		        "node_list_path": "6277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSpCs1gbmeth3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. CS1GBMeth3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSpCs1gbmeth3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1892845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892845.protein.info.v11.5.txt",
		        "node_list_path": "1892845.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosopumilusSpAr2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. AR2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopumilusSpAr2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229909.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229909.protein.info.v11.5.txt",
		        "node_list_path": "1229909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpNo7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. No. 7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpNo7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1714373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1714373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1714373.clusters.proteins.v11.5.txt",
		        "sequence_path": "1714373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714373.protein.info.v11.5.txt",
		        "node_list_path": "1714373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1714373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTenderiaElectrophagaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tenderia electrophaga Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTenderiaElectrophagaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1748243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1748243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1748243.clusters.proteins.v11.5.txt",
		        "sequence_path": "1748243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1748243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1748243.protein.info.v11.5.txt",
		        "node_list_path": "1748243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1748243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaShakespeareiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella shakespearei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaShakespeareiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122169.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122169.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122169.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122169.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122169.protein.info.v11.5.txt",
		        "node_list_path": "1122169.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122169.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusHelveticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHelveticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1587.protein.sequences.v11.5.fa",
		        "enrichment_path": "1587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1587.protein.info.v11.5.txt",
		        "node_list_path": "1587.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumFlavigenum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium flavigenum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumFlavigenum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "254877.protein.sequences.v11.5.fa",
		        "enrichment_path": "254877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "254877.protein.info.v11.5.txt",
		        "node_list_path": "254877.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp7243faaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 7243FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp7243faaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "457396.clusters.info.v11.5.txt",
		        "cluster_tree_path": "457396.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "457396.clusters.proteins.v11.5.txt",
		        "sequence_path": "457396.protein.sequences.v11.5.fa",
		        "enrichment_path": "457396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457396.protein.info.v11.5.txt",
		        "node_list_path": "457396.cluster.nodes.v11.5.txt",
		        "edge_list_path": "457396.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumRubi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium rubi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumRubi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220582.protein.info.v11.5.txt",
		        "node_list_path": "1220582.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraXiamenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraXiamenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123366.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123366.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123366.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123366.protein.info.v11.5.txt",
		        "node_list_path": "1123366.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123366.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpH83(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. H83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpH83", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1827324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827324.protein.info.v11.5.txt",
		        "node_list_path": "1827324.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu053Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU053 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu053Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671652.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671652.protein.info.v11.5.txt",
		        "node_list_path": "1671652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwe24242(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_42_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwe24242", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797339.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797339.protein.info.v11.5.txt",
		        "node_list_path": "1797339.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisFlavescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisFlavescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "758803.protein.sequences.v11.5.fa",
		        "enrichment_path": "758803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758803.protein.info.v11.5.txt",
		        "node_list_path": "758803.protein.complete.v11.5.txt"
		    }
		]
    )()

def PontibacillusLitoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacillus litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacillusLitoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385512.protein.info.v11.5.txt",
		        "node_list_path": "1385512.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaoerskoviaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraoerskovia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaoerskoviaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122933.protein.info.v11.5.txt",
		        "node_list_path": "1122933.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteimonasSpFcs9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas sp. FCS-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteimonasSpFcs9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1547516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1547516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1547516.protein.info.v11.5.txt",
		        "node_list_path": "1547516.protein.complete.v11.5.txt"
		    }
		]
    )()

def AllobaculumStercoricanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Allobaculum stercoricanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllobaculumStercoricanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1050201.protein.sequences.v11.5.fa",
		        "enrichment_path": "1050201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1050201.protein.info.v11.5.txt",
		        "node_list_path": "1050201.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParvularculaOceani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parvularcula oceani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvularculaOceani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1247963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1247963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1247963.protein.info.v11.5.txt",
		        "node_list_path": "1247963.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaAtrilutea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella atrilutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaAtrilutea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "366533.protein.sequences.v11.5.fa",
		        "enrichment_path": "366533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366533.protein.info.v11.5.txt",
		        "node_list_path": "366533.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacterVinaykumarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter vinaykumarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterVinaykumarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "407234.protein.sequences.v11.5.fa",
		        "enrichment_path": "407234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "407234.protein.info.v11.5.txt",
		        "node_list_path": "407234.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaShimofusensisNbrc100134Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia shimofusensis NBRC 100134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaShimofusensisNbrc100134Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210087.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210087.protein.info.v11.5.txt",
		        "node_list_path": "1210087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpLz4w(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Lz4W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpLz4w", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206777.protein.info.v11.5.txt",
		        "node_list_path": "1206777.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumAsp1004aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium ASP10-04a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumAsp1004aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1622230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1622230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1622230.clusters.proteins.v11.5.txt",
		        "sequence_path": "1622230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622230.protein.info.v11.5.txt",
		        "node_list_path": "1622230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1622230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnobacteriumBovisDsm14045Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnobacterium bovis DSM 14045 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnobacteriumBovisDsm14045Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122142.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122142.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122142.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122142.protein.info.v11.5.txt",
		        "node_list_path": "1122142.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122142.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethermicoccusShengliensisDsm18856(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methermicoccus shengliensis DSM 18856 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethermicoccusShengliensisDsm18856", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122233.protein.info.v11.5.txt",
		        "node_list_path": "1122233.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParascardoviaDenticolensDsm10105(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parascardovia denticolens DSM10105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParascardoviaDenticolensDsm10105", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "864564.protein.sequences.v11.5.fa",
		        "enrichment_path": "864564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864564.protein.info.v11.5.txt",
		        "node_list_path": "864564.protein.complete.v11.5.txt"
		    }
		]
    )()

def GillisiaSpCal575(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gillisia sp. CAL575 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GillisiaSpCal575", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "985255.protein.sequences.v11.5.fa",
		        "enrichment_path": "985255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985255.protein.info.v11.5.txt",
		        "node_list_path": "985255.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpA47Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. A47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpA47Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1561217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1561217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1561217.clusters.proteins.v11.5.txt",
		        "sequence_path": "1561217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561217.protein.info.v11.5.txt",
		        "node_list_path": "1561217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1561217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifoxyd1Full3935(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFOXYD1_FULL_39_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifoxyd1Full3935", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802780.protein.info.v11.5.txt",
		        "node_list_path": "1802780.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErysipelothrixRhusiopathiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erysipelothrix rhusiopathiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelothrixRhusiopathiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "650150.protein.sequences.v11.5.fa",
		        "enrichment_path": "650150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "650150.protein.info.v11.5.txt",
		        "node_list_path": "650150.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyroidesOdoratimimus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myroides odoratimimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyroidesOdoratimimus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1416760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416760.protein.info.v11.5.txt",
		        "node_list_path": "1416760.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521393.clusters.proteins.v11.5.txt",
		        "sequence_path": "521393.protein.sequences.v11.5.fa",
		        "enrichment_path": "521393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521393.protein.info.v11.5.txt",
		        "node_list_path": "521393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TolypothrixSpPcc7601Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tolypothrix sp. PCC 7601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolypothrixSpPcc7601Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1188.clusters.proteins.v11.5.txt",
		        "sequence_path": "1188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188.protein.info.v11.5.txt",
		        "node_list_path": "1188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterTandoiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter tandoii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterTandoiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "202954.clusters.info.v11.5.txt",
		        "cluster_tree_path": "202954.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "202954.clusters.proteins.v11.5.txt",
		        "sequence_path": "202954.protein.sequences.v11.5.fa",
		        "enrichment_path": "202954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202954.protein.info.v11.5.txt",
		        "node_list_path": "202954.cluster.nodes.v11.5.txt",
		        "edge_list_path": "202954.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassospiraSpMccc1a02491Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A02491 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraSpMccc1a02491Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1769751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1769751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1769751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1769751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1769751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1769751.protein.info.v11.5.txt",
		        "node_list_path": "1769751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1769751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSaskatchewanense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium saskatchewanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSaskatchewanense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "220927.protein.sequences.v11.5.fa",
		        "enrichment_path": "220927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220927.protein.info.v11.5.txt",
		        "node_list_path": "220927.protein.complete.v11.5.txt"
		    }
		]
    )()

def AustwickiaChelonae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Austwickia chelonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AustwickiaChelonae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1184607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1184607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1184607.protein.info.v11.5.txt",
		        "node_list_path": "1184607.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaTrachomatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia trachomatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaTrachomatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "813.protein.sequences.v11.5.fa",
		        "enrichment_path": "813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "813.protein.info.v11.5.txt",
		        "node_list_path": "813.protein.complete.v11.5.txt"
		    }
		]
    )()

def KomagataellaPastoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Komagataella pastoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataellaPastoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4922.protein.sequences.v11.5.fa",
		        "enrichment_path": "4922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4922.protein.info.v11.5.txt",
		        "node_list_path": "4922.protein.complete.v11.5.txt"
		    }
		]
    )()

def BipolarisZeicola26R13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris zeicola 26-R-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisZeicola26R13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930089.protein.sequences.v11.5.fa",
		        "enrichment_path": "930089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930089.protein.info.v11.5.txt",
		        "node_list_path": "930089.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpG2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. G2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpG2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1243664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1243664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1243664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1243664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1243664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1243664.protein.info.v11.5.txt",
		        "node_list_path": "1243664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1243664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DehalococcoidiaBacteriumSm23282(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoidia bacterium SM23_28_2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalococcoidiaBacteriumSm23282", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703396.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703396.protein.info.v11.5.txt",
		        "node_list_path": "1703396.protein.complete.v11.5.txt"
		    }
		]
    )()

def GillisiaSpHel133143Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gillisia sp. Hel1_33_143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GillisiaSpHel133143Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336796.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336796.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336796.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336796.protein.info.v11.5.txt",
		        "node_list_path": "1336796.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336796.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpAap1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpAap1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523413.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523413.protein.info.v11.5.txt",
		        "node_list_path": "1523413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaphaeosphaeriaSporulosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraphaeosphaeria sporulosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaphaeosphaeriaSporulosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1460663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460663.protein.info.v11.5.txt",
		        "node_list_path": "1460663.protein.complete.v11.5.txt"
		    }
		]
    )()

def KlenkiaTaihuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klenkia taihuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlenkiaTaihuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1225127.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225127.protein.info.v11.5.txt",
		        "node_list_path": "1225127.protein.complete.v11.5.txt"
		    }
		]
    )()

def KiritimatiellaGlycovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kiritimatiella glycovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KiritimatiellaGlycovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1307763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307763.protein.info.v11.5.txt",
		        "node_list_path": "1307763.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaPrimitiaZas2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema primitia ZAS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPrimitiaZas2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "545694.protein.sequences.v11.5.fa",
		        "enrichment_path": "545694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545694.protein.info.v11.5.txt",
		        "node_list_path": "545694.protein.complete.v11.5.txt"
		    }
		]
    )()

def KordiaAlgicidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kordia algicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KordiaAlgicidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391587.clusters.proteins.v11.5.txt",
		        "sequence_path": "391587.protein.sequences.v11.5.fa",
		        "enrichment_path": "391587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391587.protein.info.v11.5.txt",
		        "node_list_path": "391587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaTenuisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida tenuis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaTenuisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45596.clusters.proteins.v11.5.txt",
		        "sequence_path": "45596.protein.sequences.v11.5.fa",
		        "enrichment_path": "45596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45596.protein.info.v11.5.txt",
		        "node_list_path": "45596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioMagneticusRs1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio magneticus RS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioMagneticusRs1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573370.clusters.proteins.v11.5.txt",
		        "sequence_path": "573370.protein.sequences.v11.5.fa",
		        "enrichment_path": "573370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573370.protein.info.v11.5.txt",
		        "node_list_path": "573370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpEprs66(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. EpRS66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpEprs66", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1743140.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743140.protein.info.v11.5.txt",
		        "node_list_path": "1743140.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraWeiliiSerovarRanarumStrIcft(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira weilii serovar Ranarum str. ICFT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraWeiliiSerovarRanarumStrIcft", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218598.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218598.protein.info.v11.5.txt",
		        "node_list_path": "1218598.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSilageiJcm19001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus silagei JCM 19001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSilageiJcm19001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1302250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302250.protein.info.v11.5.txt",
		        "node_list_path": "1302250.protein.complete.v11.5.txt"
		    }
		]
    )()

def TolumonasSpBrl61Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tolumonas sp. BRL61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolumonasSpBrl61Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1283284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1283284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1283284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1283284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283284.protein.info.v11.5.txt",
		        "node_list_path": "1283284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1283284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NakamurellaMultipartita(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nakamurella multipartita graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NakamurellaMultipartita", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "479431.protein.sequences.v11.5.fa",
		        "enrichment_path": "479431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479431.protein.info.v11.5.txt",
		        "node_list_path": "479431.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlutamicibacterSp0426(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glutamicibacter sp. 0426 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlutamicibacterSp0426", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1913445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1913445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1913445.protein.info.v11.5.txt",
		        "node_list_path": "1913445.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaAquatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaAquatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1416759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416759.protein.info.v11.5.txt",
		        "node_list_path": "1416759.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpF0430(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0430 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpF0430", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "879310.protein.sequences.v11.5.fa",
		        "enrichment_path": "879310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879310.protein.info.v11.5.txt",
		        "node_list_path": "879310.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaAlgaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella algae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaAlgaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "38313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "38313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "38313.clusters.proteins.v11.5.txt",
		        "sequence_path": "38313.protein.sequences.v11.5.fa",
		        "enrichment_path": "38313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38313.protein.info.v11.5.txt",
		        "node_list_path": "38313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "38313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusMaliNbrc102425(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus mali NBRC 102425 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusMaliNbrc102425", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314748.protein.info.v11.5.txt",
		        "node_list_path": "1314748.protein.complete.v11.5.txt"
		    }
		]
    )()

def DelftiaAcidovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Delftia acidovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DelftiaAcidovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398578.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398578.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398578.clusters.proteins.v11.5.txt",
		        "sequence_path": "398578.protein.sequences.v11.5.fa",
		        "enrichment_path": "398578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398578.protein.info.v11.5.txt",
		        "node_list_path": "398578.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398578.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcaryochlorisMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acaryochloris marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcaryochlorisMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "329726.protein.sequences.v11.5.fa",
		        "enrichment_path": "329726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "329726.protein.info.v11.5.txt",
		        "node_list_path": "329726.protein.complete.v11.5.txt"
		    }
		]
    )()

def AggregatibacterSegnis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter segnis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterSegnis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "739.protein.sequences.v11.5.fa",
		        "enrichment_path": "739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "739.protein.info.v11.5.txt",
		        "node_list_path": "739.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfobacteriumCommuneCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium commune Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfobacteriumCommuneCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "289377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "289377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "289377.clusters.proteins.v11.5.txt",
		        "sequence_path": "289377.protein.sequences.v11.5.fa",
		        "enrichment_path": "289377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "289377.protein.info.v11.5.txt",
		        "node_list_path": "289377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "289377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaVacciniiNbrc15922Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia vaccinii NBRC 15922 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaVacciniiNbrc15922Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210098.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210098.protein.info.v11.5.txt",
		        "node_list_path": "1210098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcusMaripaludisC7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusMaripaludisC7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426368.clusters.proteins.v11.5.txt",
		        "sequence_path": "426368.protein.sequences.v11.5.fa",
		        "enrichment_path": "426368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426368.protein.info.v11.5.txt",
		        "node_list_path": "426368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871013.protein.info.v11.5.txt",
		        "node_list_path": "1871013.protein.complete.v11.5.txt"
		    }
		]
    )()

def PocilloporaDamicornisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pocillopora damicornis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PocilloporaDamicornisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46731.clusters.proteins.v11.5.txt",
		        "sequence_path": "46731.protein.sequences.v11.5.fa",
		        "enrichment_path": "46731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46731.protein.info.v11.5.txt",
		        "node_list_path": "46731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalieaRubra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haliea rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalieaRubra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265313.protein.info.v11.5.txt",
		        "node_list_path": "1265313.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnt318(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT318 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnt318", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288079.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288079.protein.info.v11.5.txt",
		        "node_list_path": "1288079.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicractiniumConductrixCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micractinium conductrix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicractiniumConductrixCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "554055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "554055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "554055.clusters.proteins.v11.5.txt",
		        "sequence_path": "554055.protein.sequences.v11.5.fa",
		        "enrichment_path": "554055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "554055.protein.info.v11.5.txt",
		        "node_list_path": "554055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "554055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MollicutesBacteriumHr1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mollicutes bacterium HR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MollicutesBacteriumHr1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1541959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1541959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1541959.protein.info.v11.5.txt",
		        "node_list_path": "1541959.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterSpMit975078(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. MIT975078 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSpMit975078", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1548153.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548153.protein.info.v11.5.txt",
		        "node_list_path": "1548153.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusCoryniformisKctc3167Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis KCTC3167 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCoryniformisKctc3167Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "913848.clusters.info.v11.5.txt",
		        "cluster_tree_path": "913848.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "913848.clusters.proteins.v11.5.txt",
		        "sequence_path": "913848.protein.sequences.v11.5.fa",
		        "enrichment_path": "913848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913848.protein.info.v11.5.txt",
		        "node_list_path": "913848.cluster.nodes.v11.5.txt",
		        "edge_list_path": "913848.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprobacterFastidiosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprobacter fastidiosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprobacterFastidiosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349822.protein.info.v11.5.txt",
		        "node_list_path": "1349822.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaPutrefaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella putrefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaPutrefaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "319224.protein.sequences.v11.5.fa",
		        "enrichment_path": "319224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319224.protein.info.v11.5.txt",
		        "node_list_path": "319224.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "874156.protein.sequences.v11.5.fa",
		        "enrichment_path": "874156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "874156.protein.info.v11.5.txt",
		        "node_list_path": "874156.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidiphiliumCryptumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidiphilium cryptum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidiphiliumCryptumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349163.clusters.proteins.v11.5.txt",
		        "sequence_path": "349163.protein.sequences.v11.5.fa",
		        "enrichment_path": "349163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349163.protein.info.v11.5.txt",
		        "node_list_path": "349163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusHermanniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus hermanniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusHermanniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "249189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "249189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "249189.clusters.proteins.v11.5.txt",
		        "sequence_path": "249189.protein.sequences.v11.5.fa",
		        "enrichment_path": "249189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "249189.protein.info.v11.5.txt",
		        "node_list_path": "249189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "249189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelleaBalneolensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hellea balneolensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelleaBalneolensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121948.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121948.protein.info.v11.5.txt",
		        "node_list_path": "1121948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OxalobacterFormigenesOxcc13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes OXCC13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OxalobacterFormigenesOxcc13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "556269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "556269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "556269.clusters.proteins.v11.5.txt",
		        "sequence_path": "556269.protein.sequences.v11.5.fa",
		        "enrichment_path": "556269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556269.protein.info.v11.5.txt",
		        "node_list_path": "556269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "556269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumOxidotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium oxidotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumOxidotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397699.protein.info.v11.5.txt",
		        "node_list_path": "1397699.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisKunsanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis kunsanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisKunsanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246445.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246445.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246445.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246445.protein.info.v11.5.txt",
		        "node_list_path": "1246445.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246445.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliifodinibiusRoseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aliifodinibius roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliifodinibiusRoseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1194090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194090.protein.info.v11.5.txt",
		        "node_list_path": "1194090.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHimb30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HIMB30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHimb30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "751994.protein.sequences.v11.5.fa",
		        "enrichment_path": "751994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "751994.protein.info.v11.5.txt",
		        "node_list_path": "751994.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumSteckiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium steckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumSteckiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "303698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "303698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "303698.clusters.proteins.v11.5.txt",
		        "sequence_path": "303698.protein.sequences.v11.5.fa",
		        "enrichment_path": "303698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "303698.protein.info.v11.5.txt",
		        "node_list_path": "303698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "303698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EremotheciumSinecaudumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium sinecaudum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremotheciumSinecaudumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45286.clusters.proteins.v11.5.txt",
		        "sequence_path": "45286.protein.sequences.v11.5.fa",
		        "enrichment_path": "45286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45286.protein.info.v11.5.txt",
		        "node_list_path": "45286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumJohnsoniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium johnsoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumJohnsoniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "376686.protein.sequences.v11.5.fa",
		        "enrichment_path": "376686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376686.protein.info.v11.5.txt",
		        "node_list_path": "376686.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosopumilusSpNsub(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. Nsub graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopumilusSpNsub", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776294.protein.info.v11.5.txt",
		        "node_list_path": "1776294.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNiyogibacteriaBacteriumRifcsplowo212Full4113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Niyogibacteria bacterium RIFCSPLOWO2_12_FULL_41_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNiyogibacteriaBacteriumRifcsplowo212Full4113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801726.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801726.protein.info.v11.5.txt",
		        "node_list_path": "1801726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumLacusprofundi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum lacusprofundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumLacusprofundi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "416348.protein.sequences.v11.5.fa",
		        "enrichment_path": "416348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416348.protein.info.v11.5.txt",
		        "node_list_path": "416348.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSordidicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sordidicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSordidicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "196367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "196367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "196367.clusters.proteins.v11.5.txt",
		        "sequence_path": "196367.protein.sequences.v11.5.fa",
		        "enrichment_path": "196367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "196367.protein.info.v11.5.txt",
		        "node_list_path": "196367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "196367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpLs16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. LS16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpLs16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1690248.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1690248.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1690248.clusters.proteins.v11.5.txt",
		        "sequence_path": "1690248.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690248.protein.info.v11.5.txt",
		        "node_list_path": "1690248.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1690248.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaSediminumDsm21906Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sediminum DSM 21906 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaSediminumDsm21906Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122124.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122124.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122124.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122124.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122124.protein.info.v11.5.txt",
		        "node_list_path": "1122124.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122124.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetarhiziumAcridumCqma102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium acridum CQMa 102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetarhiziumAcridumCqma102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655827.protein.sequences.v11.5.fa",
		        "enrichment_path": "655827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655827.protein.info.v11.5.txt",
		        "node_list_path": "655827.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemellaHaemolysansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella haemolysans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaHaemolysansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379.protein.info.v11.5.txt",
		        "node_list_path": "1379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesBacteriumOlb22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates bacterium OLB22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesBacteriumOlb22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617428.protein.info.v11.5.txt",
		        "node_list_path": "1617428.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp12747610(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1274761.0 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp12747610", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834077.protein.info.v11.5.txt",
		        "node_list_path": "1834077.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesScabrisporus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces scabrisporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesScabrisporus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123320.protein.info.v11.5.txt",
		        "node_list_path": "1123320.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpWsm2230(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. WSM2230 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpWsm2230", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "944435.protein.sequences.v11.5.fa",
		        "enrichment_path": "944435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944435.protein.info.v11.5.txt",
		        "node_list_path": "944435.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpM240Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. M240 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpM240Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216932.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216932.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216932.protein.info.v11.5.txt",
		        "node_list_path": "1216932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSenegalimassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus senegalimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSenegalimassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1737426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1737426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1737426.clusters.proteins.v11.5.txt",
		        "sequence_path": "1737426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1737426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1737426.protein.info.v11.5.txt",
		        "node_list_path": "1737426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1737426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AurantimonasSpLeaf443Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aurantimonas sp. Leaf443 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AurantimonasSpLeaf443Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736378.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736378.protein.info.v11.5.txt",
		        "node_list_path": "1736378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoemansiaReversaNrrl1564(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coemansia reversa NRRL 1564 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoemansiaReversaNrrl1564", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "763665.protein.sequences.v11.5.fa",
		        "enrichment_path": "763665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "763665.protein.info.v11.5.txt",
		        "node_list_path": "763665.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterGlucosidilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter glucosidilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterGlucosidilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122941.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122941.protein.info.v11.5.txt",
		        "node_list_path": "1122941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusSpBg(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. BG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusSpBg", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1633135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1633135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1633135.protein.info.v11.5.txt",
		        "node_list_path": "1633135.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpHsism1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. HSISM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpHsism1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1316408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1316408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1316408.protein.info.v11.5.txt",
		        "node_list_path": "1316408.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSpMarseille(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. Marseille graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSpMarseille", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "375286.protein.sequences.v11.5.fa",
		        "enrichment_path": "375286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375286.protein.info.v11.5.txt",
		        "node_list_path": "375286.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpEi5cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. EI5c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpEi5cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "683316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "683316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "683316.clusters.proteins.v11.5.txt",
		        "sequence_path": "683316.protein.sequences.v11.5.fa",
		        "enrichment_path": "683316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683316.protein.info.v11.5.txt",
		        "node_list_path": "683316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "683316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LyngbyaSpPcc8106Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lyngbya sp. PCC8106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LyngbyaSpPcc8106Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313612.clusters.proteins.v11.5.txt",
		        "sequence_path": "313612.protein.sequences.v11.5.fa",
		        "enrichment_path": "313612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313612.protein.info.v11.5.txt",
		        "node_list_path": "313612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FilifactorAlocisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Filifactor alocis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FilifactorAlocisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546269.clusters.proteins.v11.5.txt",
		        "sequence_path": "546269.protein.sequences.v11.5.fa",
		        "enrichment_path": "546269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546269.protein.info.v11.5.txt",
		        "node_list_path": "546269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusSpAmp6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. amp6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusSpAmp6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "388051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "388051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "388051.clusters.proteins.v11.5.txt",
		        "sequence_path": "388051.protein.sequences.v11.5.fa",
		        "enrichment_path": "388051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388051.protein.info.v11.5.txt",
		        "node_list_path": "388051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "388051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpKbs0721Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KBS0721 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpKbs0721Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1179672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1179672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1179672.clusters.proteins.v11.5.txt",
		        "sequence_path": "1179672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179672.protein.info.v11.5.txt",
		        "node_list_path": "1179672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1179672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSuis22083Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis 22083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSuis22083Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1214184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1214184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1214184.clusters.proteins.v11.5.txt",
		        "sequence_path": "1214184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214184.protein.info.v11.5.txt",
		        "node_list_path": "1214184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1214184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaVirilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila virilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaVirilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7244.protein.sequences.v11.5.fa",
		        "enrichment_path": "7244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7244.protein.info.v11.5.txt",
		        "node_list_path": "7244.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonJdfr11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon JdFR-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonJdfr11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935119.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935119.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935119.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935119.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935119.protein.info.v11.5.txt",
		        "node_list_path": "1935119.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935119.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalibacteriumQingdaonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salibacterium qingdaonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalibacteriumQingdaonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266892.protein.sequences.v11.5.fa",
		        "enrichment_path": "266892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266892.protein.info.v11.5.txt",
		        "node_list_path": "266892.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumMercanteiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium mercantei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumMercanteiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1904807.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1904807.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1904807.clusters.proteins.v11.5.txt",
		        "sequence_path": "1904807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904807.protein.info.v11.5.txt",
		        "node_list_path": "1904807.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1904807.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LatesCalcarifer(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lates calcarifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LatesCalcarifer", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8187.protein.sequences.v11.5.fa",
		        "enrichment_path": "8187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8187.protein.info.v11.5.txt",
		        "node_list_path": "8187.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasFuscansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas fuscans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasFuscansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "366649.clusters.info.v11.5.txt",
		        "cluster_tree_path": "366649.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "366649.clusters.proteins.v11.5.txt",
		        "sequence_path": "366649.protein.sequences.v11.5.fa",
		        "enrichment_path": "366649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366649.protein.info.v11.5.txt",
		        "node_list_path": "366649.cluster.nodes.v11.5.txt",
		        "edge_list_path": "366649.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UrmitellaTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Urmitella timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UrmitellaTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1870994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870994.protein.info.v11.5.txt",
		        "node_list_path": "1870994.protein.complete.v11.5.txt"
		    }
		]
    )()

def RufibacterRoseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rufibacter roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RufibacterRoseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1567108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1567108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1567108.clusters.proteins.v11.5.txt",
		        "sequence_path": "1567108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1567108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1567108.protein.info.v11.5.txt",
		        "node_list_path": "1567108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1567108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanohalarchaeumThermophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanohalarchaeum thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanohalarchaeumThermophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1903181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903181.protein.info.v11.5.txt",
		        "node_list_path": "1903181.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPeli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas peli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPeli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "592361.protein.sequences.v11.5.fa",
		        "enrichment_path": "592361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592361.protein.info.v11.5.txt",
		        "node_list_path": "592361.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrococcusKukulkanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus kukulkanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusKukulkanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1609559.protein.sequences.v11.5.fa",
		        "enrichment_path": "1609559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1609559.protein.info.v11.5.txt",
		        "node_list_path": "1609559.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMuproteobacteriaBacteriumRifcsphigho201Full6516Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RIFCSPHIGHO2_01_FULL_65_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRifcsphigho201Full6516Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817764.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817764.protein.info.v11.5.txt",
		        "node_list_path": "1817764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterGinsenosidimutansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter ginsenosidimutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterGinsenosidimutansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "687842.clusters.info.v11.5.txt",
		        "cluster_tree_path": "687842.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "687842.clusters.proteins.v11.5.txt",
		        "sequence_path": "687842.protein.sequences.v11.5.fa",
		        "enrichment_path": "687842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "687842.protein.info.v11.5.txt",
		        "node_list_path": "687842.cluster.nodes.v11.5.txt",
		        "edge_list_path": "687842.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpLnhc252b00Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LNHC252B00 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpLnhc252b00Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1287252.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1287252.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1287252.clusters.proteins.v11.5.txt",
		        "sequence_path": "1287252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287252.protein.info.v11.5.txt",
		        "node_list_path": "1287252.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1287252.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumPhenoxybenzoativorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium phenoxybenzoativorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumPhenoxybenzoativorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1592790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1592790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1592790.protein.info.v11.5.txt",
		        "node_list_path": "1592790.protein.complete.v11.5.txt"
		    }
		]
    )()

def HenriciellaPelagiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Henriciella pelagia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HenriciellaPelagiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977912.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977912.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977912.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977912.protein.info.v11.5.txt",
		        "node_list_path": "1977912.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977912.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IchthyophthiriusMultifiliisStrainG5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ichthyophthirius multifiliis strain G5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IchthyophthiriusMultifiliisStrainG5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "857967.protein.sequences.v11.5.fa",
		        "enrichment_path": "857967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857967.protein.info.v11.5.txt",
		        "node_list_path": "857967.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumGlycinophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium glycinophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumGlycinophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1404245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1404245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1404245.protein.info.v11.5.txt",
		        "node_list_path": "1404245.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumPuteiDsm12395(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum putei DSM 12395 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumPuteiDsm12395", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121429.protein.info.v11.5.txt",
		        "node_list_path": "1121429.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumNitrativoransNl23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium nitrativorans NL23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumNitrativoransNl23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1029756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1029756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1029756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1029756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1029756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1029756.protein.info.v11.5.txt",
		        "node_list_path": "1029756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1029756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechocystisSpPcc6714Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC6714 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechocystisSpPcc6714Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1147.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1147.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1147.clusters.proteins.v11.5.txt",
		        "sequence_path": "1147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1147.protein.info.v11.5.txt",
		        "node_list_path": "1147.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1147.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsSpCamponotiSaundersiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps sp. camponoti-saundersi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsSpCamponotiSaundersiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2039874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2039874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2039874.clusters.proteins.v11.5.txt",
		        "sequence_path": "2039874.protein.sequences.v11.5.fa",
		        "enrichment_path": "2039874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2039874.protein.info.v11.5.txt",
		        "node_list_path": "2039874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2039874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumFreireiPrf81Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium freirei PRF 81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumFreireiPrf81Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "363754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "363754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "363754.clusters.proteins.v11.5.txt",
		        "sequence_path": "363754.protein.sequences.v11.5.fa",
		        "enrichment_path": "363754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "363754.protein.info.v11.5.txt",
		        "node_list_path": "363754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "363754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OtolemurGarnettiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Otolemur garnettii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OtolemurGarnettiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "30611.clusters.info.v11.5.txt",
		        "cluster_tree_path": "30611.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "30611.clusters.proteins.v11.5.txt",
		        "sequence_path": "30611.protein.sequences.v11.5.fa",
		        "enrichment_path": "30611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30611.protein.info.v11.5.txt",
		        "node_list_path": "30611.cluster.nodes.v11.5.txt",
		        "edge_list_path": "30611.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaBillingiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia billingiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaBillingiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634500.protein.sequences.v11.5.fa",
		        "enrichment_path": "634500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634500.protein.info.v11.5.txt",
		        "node_list_path": "634500.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusPrevotiiDsm20548Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus prevotii DSM20548 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusPrevotiiDsm20548Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525919.clusters.proteins.v11.5.txt",
		        "sequence_path": "525919.protein.sequences.v11.5.fa",
		        "enrichment_path": "525919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525919.protein.info.v11.5.txt",
		        "node_list_path": "525919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaWallisii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea wallisii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaWallisii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1076551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076551.protein.info.v11.5.txt",
		        "node_list_path": "1076551.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusArachidicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus arachidicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusArachidicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "656916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "656916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "656916.clusters.proteins.v11.5.txt",
		        "sequence_path": "656916.protein.sequences.v11.5.fa",
		        "enrichment_path": "656916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656916.protein.info.v11.5.txt",
		        "node_list_path": "656916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "656916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumOxidoreducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium oxidoreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumOxidoreducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1732.protein.info.v11.5.txt",
		        "node_list_path": "1732.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium6247(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 62-47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium6247", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895811.protein.info.v11.5.txt",
		        "node_list_path": "1895811.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterorhabdusCaecimuris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterorhabdus caecimuris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterorhabdusCaecimuris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235794.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235794.protein.info.v11.5.txt",
		        "node_list_path": "1235794.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiK12Mg1655Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 MG1655 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiK12Mg1655Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "511145.clusters.info.v11.0.txt",
		        "cluster_tree_path": "511145.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "511145.clusters.proteins.v11.0.txt",
		        "sequence_path": "511145.protein.sequences.v11.0.fa",
		        "enrichment_path": "511145.protein.enrichment.terms.v11.0.txt",
		        "info_path": "511145.protein.info.v11.0.txt",
		        "node_list_path": "511145.cluster.nodes.v11.0.txt",
		        "edge_list_path": "511145.protein.cluster.v11.0.txt"
		    }
		]
    )()

def BacteroidesPropionicifaciensDsm19291Jcm14649Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides propionicifaciens DSM 19291 JCM 14649 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesPropionicifaciensDsm19291Jcm14649Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121099.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121099.protein.info.v11.5.txt",
		        "node_list_path": "1121099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3713(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_37_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3713", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801750.protein.info.v11.5.txt",
		        "node_list_path": "1801750.protein.complete.v11.5.txt"
		    }
		]
    )()

def AromatoleumTolulyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aromatoleum tolulyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AromatoleumTolulyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34027.protein.sequences.v11.5.fa",
		        "enrichment_path": "34027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34027.protein.info.v11.5.txt",
		        "node_list_path": "34027.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumTropicale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum tropicale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumTropicale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1765655.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765655.protein.info.v11.5.txt",
		        "node_list_path": "1765655.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSp31y(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 31Y graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSp31y", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1115632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1115632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1115632.protein.info.v11.5.txt",
		        "node_list_path": "1115632.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacterSpImcc9063(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter sp. IMCC9063 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterSpImcc9063", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1002672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002672.protein.info.v11.5.txt",
		        "node_list_path": "1002672.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoplanesDerwentensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes derwentensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesDerwentensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "113562.protein.sequences.v11.5.fa",
		        "enrichment_path": "113562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113562.protein.info.v11.5.txt",
		        "node_list_path": "113562.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumGwc23926(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWC2_39_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumGwc23926", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801951.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801951.protein.info.v11.5.txt",
		        "node_list_path": "1801951.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaCapricolumSubspCapripneumoniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma capricolum subsp. capripneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaCapricolumSubspCapripneumoniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40480.clusters.proteins.v11.5.txt",
		        "sequence_path": "40480.protein.sequences.v11.5.fa",
		        "enrichment_path": "40480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40480.protein.info.v11.5.txt",
		        "node_list_path": "40480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumNitrogenifigens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium nitrogenifigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumNitrogenifigens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983920.protein.sequences.v11.5.fa",
		        "enrichment_path": "983920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983920.protein.info.v11.5.txt",
		        "node_list_path": "983920.protein.complete.v11.5.txt"
		    }
		]
    )()

def MillerozymaFarinosaCbs7064Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Millerozyma farinosa CBS 7064 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MillerozymaFarinosaCbs7064Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "559304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "559304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "559304.clusters.proteins.v11.5.txt",
		        "sequence_path": "559304.protein.sequences.v11.5.fa",
		        "enrichment_path": "559304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559304.protein.info.v11.5.txt",
		        "node_list_path": "559304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "559304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpA12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. A12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpA12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1759399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1759399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1759399.clusters.proteins.v11.5.txt",
		        "sequence_path": "1759399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759399.protein.info.v11.5.txt",
		        "node_list_path": "1759399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1759399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSp446(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 446 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSp446", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426117.protein.sequences.v11.5.fa",
		        "enrichment_path": "426117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426117.protein.info.v11.5.txt",
		        "node_list_path": "426117.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumPhleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium phlei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumPhleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1771.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1771.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1771.clusters.proteins.v11.5.txt",
		        "sequence_path": "1771.protein.sequences.v11.5.fa",
		        "enrichment_path": "1771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1771.protein.info.v11.5.txt",
		        "node_list_path": "1771.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1771.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquimarinaMuelleri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina muelleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaMuelleri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121007.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121007.protein.info.v11.5.txt",
		        "node_list_path": "1121007.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasCremoricolorataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas cremoricolorata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCremoricolorataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "157783.clusters.info.v11.5.txt",
		        "cluster_tree_path": "157783.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "157783.clusters.proteins.v11.5.txt",
		        "sequence_path": "157783.protein.sequences.v11.5.fa",
		        "enrichment_path": "157783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157783.protein.info.v11.5.txt",
		        "node_list_path": "157783.cluster.nodes.v11.5.txt",
		        "edge_list_path": "157783.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpKpl1995(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1995 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpKpl1995", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203624.protein.info.v11.5.txt",
		        "node_list_path": "1203624.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasHydrothermalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas hydrothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasHydrothermalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "115561.protein.sequences.v11.5.fa",
		        "enrichment_path": "115561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115561.protein.info.v11.5.txt",
		        "node_list_path": "115561.protein.complete.v11.5.txt"
		    }
		]
    )()

def PercaFlavescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Perca flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PercaFlavescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8167.protein.sequences.v11.5.fa",
		        "enrichment_path": "8167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8167.protein.info.v11.5.txt",
		        "node_list_path": "8167.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxya2Full3919Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2_FULL_39_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2Full3919Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797957.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797957.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797957.protein.info.v11.5.txt",
		        "node_list_path": "1797957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetarhiziumAnisopliaeBrip53293Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium anisopliae BRIP 53293 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetarhiziumAnisopliaeBrip53293Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1291518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1291518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1291518.clusters.proteins.v11.5.txt",
		        "sequence_path": "1291518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291518.protein.info.v11.5.txt",
		        "node_list_path": "1291518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1291518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusIntermedius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus intermedius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusIntermedius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "862967.protein.sequences.v11.5.fa",
		        "enrichment_path": "862967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862967.protein.info.v11.5.txt",
		        "node_list_path": "862967.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3715Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_37_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3715Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802036.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802036.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802036.protein.info.v11.5.txt",
		        "node_list_path": "1802036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliterellaAtlanticaCena595Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliterella atlantica CENA595 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliterellaAtlanticaCena595Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618023.protein.info.v11.5.txt",
		        "node_list_path": "1618023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TatumellaSaanichensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tatumella saanichensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TatumellaSaanichensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "480813.protein.sequences.v11.5.fa",
		        "enrichment_path": "480813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "480813.protein.info.v11.5.txt",
		        "node_list_path": "480813.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumGw2011Gwc14710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011_GWC1_47_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011Gwc14710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619122.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619122.protein.info.v11.5.txt",
		        "node_list_path": "1619122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacterium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacterium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1898207.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898207.protein.info.v11.5.txt",
		        "node_list_path": "1898207.protein.complete.v11.5.txt"
		    }
		]
    )()

def LutisporaThermophilaDsm19022(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lutispora thermophila DSM 19022 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutisporaThermophilaDsm19022", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122184.protein.info.v11.5.txt",
		        "node_list_path": "1122184.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifoxyb2Full487(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFOXYB2_FULL_48_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2Full487", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802583.protein.info.v11.5.txt",
		        "node_list_path": "1802583.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicocarpusGriseusUamh5409(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicocarpus griseus UAMH5409 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicocarpusGriseusUamh5409", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1447875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1447875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1447875.protein.info.v11.5.txt",
		        "node_list_path": "1447875.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacteriumCg1024614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_46_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805288.protein.info.v11.5.txt",
		        "node_list_path": "1805288.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIec1808(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IEC1808 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIec1808", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1743230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743230.protein.info.v11.5.txt",
		        "node_list_path": "1743230.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasAbyssalisTar001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas abyssalis TAR-001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasAbyssalisTar001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1391729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391729.protein.info.v11.5.txt",
		        "node_list_path": "1391729.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumCg2303616(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium CG2_30_36_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumCg2303616", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805221.protein.info.v11.5.txt",
		        "node_list_path": "1805221.protein.complete.v11.5.txt"
		    }
		]
    )()

def TolypocladiumOphioglossoidesCbs100239Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tolypocladium ophioglossoides CBS 100239 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolypocladiumOphioglossoidesCbs100239Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1163406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1163406.clusters.proteins.v11.5.txt",
		        "sequence_path": "1163406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163406.protein.info.v11.5.txt",
		        "node_list_path": "1163406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1163406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillospiraceaeBacteriumZagget12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillospiraceae bacterium Zagget12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillospiraceaeBacteriumZagget12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930020.protein.info.v11.5.txt",
		        "node_list_path": "1930020.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaSp5ratimar09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella sp. 5RATIMAR09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaSp5ratimar09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1225655.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225655.protein.info.v11.5.txt",
		        "node_list_path": "1225655.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrifoliumPratenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trifolium pratense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrifoliumPratenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "57577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "57577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "57577.clusters.proteins.v11.5.txt",
		        "sequence_path": "57577.protein.sequences.v11.5.fa",
		        "enrichment_path": "57577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "57577.protein.info.v11.5.txt",
		        "node_list_path": "57577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "57577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaPickettiiDtp0602(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia pickettii DTP0602 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaPickettiiDtp0602", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1366050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1366050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1366050.protein.info.v11.5.txt",
		        "node_list_path": "1366050.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesFulvoviolaceusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces fulvoviolaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesFulvoviolaceusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "285535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "285535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "285535.clusters.proteins.v11.5.txt",
		        "sequence_path": "285535.protein.sequences.v11.5.fa",
		        "enrichment_path": "285535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285535.protein.info.v11.5.txt",
		        "node_list_path": "285535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "285535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf24131Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_41_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf24131Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797348.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797348.protein.info.v11.5.txt",
		        "node_list_path": "1797348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPacebacteriaBacteriumGw2011Gwa14610(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium GW2011_GWA1_46_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacebacteriaBacteriumGw2011Gwa14610", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618469.protein.info.v11.5.txt",
		        "node_list_path": "1618469.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpEb01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. EB01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpEb01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1347086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347086.protein.info.v11.5.txt",
		        "node_list_path": "1347086.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaueraTerpenicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera terpenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraTerpenicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348657.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348657.protein.info.v11.5.txt",
		        "node_list_path": "1348657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CloacibacteriumNormanenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cloacibacterium normanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CloacibacteriumNormanenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "237258.clusters.info.v11.5.txt",
		        "cluster_tree_path": "237258.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "237258.clusters.proteins.v11.5.txt",
		        "sequence_path": "237258.protein.sequences.v11.5.fa",
		        "enrichment_path": "237258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237258.protein.info.v11.5.txt",
		        "node_list_path": "237258.cluster.nodes.v11.5.txt",
		        "edge_list_path": "237258.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpAcs4054Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS4054 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpAcs4054Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834119.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834119.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834119.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834119.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834119.protein.info.v11.5.txt",
		        "node_list_path": "1834119.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834119.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PasteurellaPneumotropica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella pneumotropica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaPneumotropica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "758.protein.sequences.v11.5.fa",
		        "enrichment_path": "758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758.protein.info.v11.5.txt",
		        "node_list_path": "758.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesDistasonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides distasonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesDistasonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "435591.protein.sequences.v11.5.fa",
		        "enrichment_path": "435591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435591.protein.info.v11.5.txt",
		        "node_list_path": "435591.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAdolescentis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium adolescentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAdolescentis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1680.protein.info.v11.5.txt",
		        "node_list_path": "1680.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumRbg135024Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RBG_13_50_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumRbg135024Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801962.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801962.protein.info.v11.5.txt",
		        "node_list_path": "1801962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpDd12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpDd12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777880.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777880.protein.info.v11.5.txt",
		        "node_list_path": "1777880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumPavilionensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium pavilionensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumPavilionensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1345023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1345023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1345023.protein.info.v11.5.txt",
		        "node_list_path": "1345023.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylomagnumIshizawai(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomagnum ishizawai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomagnumIshizawai", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1760988.protein.sequences.v11.5.fa",
		        "enrichment_path": "1760988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1760988.protein.info.v11.5.txt",
		        "node_list_path": "1760988.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterTropicalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter tropicalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterTropicalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "104102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "104102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "104102.clusters.proteins.v11.5.txt",
		        "sequence_path": "104102.protein.sequences.v11.5.fa",
		        "enrichment_path": "104102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104102.protein.info.v11.5.txt",
		        "node_list_path": "104102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "104102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonadalesBacteriumGa0077559(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium Ga0077559 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonadalesBacteriumGa0077559", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752233.protein.info.v11.5.txt",
		        "node_list_path": "1752233.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisBisa53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisA53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisBisa53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316055.protein.sequences.v11.5.fa",
		        "enrichment_path": "316055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316055.protein.info.v11.5.txt",
		        "node_list_path": "316055.protein.complete.v11.5.txt"
		    }
		]
    )()

def PontibacaMethylaminivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibaca methylaminivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacaMethylaminivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "515897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "515897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "515897.clusters.proteins.v11.5.txt",
		        "sequence_path": "515897.protein.sequences.v11.5.fa",
		        "enrichment_path": "515897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515897.protein.info.v11.5.txt",
		        "node_list_path": "515897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "515897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteibacterSp9135Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter sp. 9135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterSp9135Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500893.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500893.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500893.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500893.protein.info.v11.5.txt",
		        "node_list_path": "1500893.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500893.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichinellaNativa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichinella nativa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaNativa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6335.protein.sequences.v11.5.fa",
		        "enrichment_path": "6335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6335.protein.info.v11.5.txt",
		        "node_list_path": "6335.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGwf24113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWF2_41_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGwf24113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798263.protein.info.v11.5.txt",
		        "node_list_path": "1798263.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSpPacm27299(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. PACM 27299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpPacm27299", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1727164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1727164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1727164.protein.info.v11.5.txt",
		        "node_list_path": "1727164.protein.complete.v11.5.txt"
		    }
		]
    )()

def HamadaeaTsunoensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hamadaea tsunoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HamadaeaTsunoensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121946.protein.info.v11.5.txt",
		        "node_list_path": "1121946.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsialesBacteriumExBugulaNeritinaAb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium (ex Bugula neritina AB1) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsialesBacteriumExBugulaNeritinaAb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1868285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1868285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1868285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1868285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1868285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1868285.protein.info.v11.5.txt",
		        "node_list_path": "1868285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1868285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusLutrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lutrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusLutrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "155085.protein.sequences.v11.5.fa",
		        "enrichment_path": "155085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "155085.protein.info.v11.5.txt",
		        "node_list_path": "155085.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpWsm2230Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. WSM2230 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpWsm2230Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "944435.clusters.info.v11.5.txt",
		        "cluster_tree_path": "944435.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "944435.clusters.proteins.v11.5.txt",
		        "sequence_path": "944435.protein.sequences.v11.5.fa",
		        "enrichment_path": "944435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944435.protein.info.v11.5.txt",
		        "node_list_path": "944435.cluster.nodes.v11.5.txt",
		        "edge_list_path": "944435.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcoidesMethylutensMm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanococcoides methylutens MM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcoidesMethylutensMm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434104.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434104.protein.info.v11.5.txt",
		        "node_list_path": "1434104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyncephalastrumRacemosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syncephalastrum racemosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyncephalastrumRacemosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13706.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13706.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13706.clusters.proteins.v11.5.txt",
		        "sequence_path": "13706.protein.sequences.v11.5.fa",
		        "enrichment_path": "13706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13706.protein.info.v11.5.txt",
		        "node_list_path": "13706.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13706.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudohongiellaActicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudohongiella acticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudohongiellaActicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1524254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1524254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1524254.clusters.proteins.v11.5.txt",
		        "sequence_path": "1524254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1524254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1524254.protein.info.v11.5.txt",
		        "node_list_path": "1524254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1524254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BotryobasidiumBotryosumFd172Ss1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Botryobasidium botryosum FD-172 SS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotryobasidiumBotryosumFd172Ss1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930990.clusters.proteins.v11.5.txt",
		        "sequence_path": "930990.protein.sequences.v11.5.fa",
		        "enrichment_path": "930990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930990.protein.info.v11.5.txt",
		        "node_list_path": "930990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumValentinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium valentinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumValentinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1518501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1518501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1518501.clusters.proteins.v11.5.txt",
		        "sequence_path": "1518501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1518501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1518501.protein.info.v11.5.txt",
		        "node_list_path": "1518501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1518501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumResistensNbrc103078(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium resistens NBRC 103078 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumResistensNbrc103078", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223505.protein.info.v11.5.txt",
		        "node_list_path": "1223505.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycetaceaeBacteriumBa112(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomycetaceae bacterium BA112 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycetaceaeBacteriumBa112", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1823756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1823756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1823756.protein.info.v11.5.txt",
		        "node_list_path": "1823756.protein.complete.v11.5.txt"
		    }
		]
    )()

def NecropsobacterMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Necropsobacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NecropsobacterMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1400001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400001.protein.info.v11.5.txt",
		        "node_list_path": "1400001.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterSpLpb0137Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. LPB0137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSpLpb0137Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1850254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1850254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1850254.clusters.proteins.v11.5.txt",
		        "sequence_path": "1850254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850254.protein.info.v11.5.txt",
		        "node_list_path": "1850254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1850254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumGa0077535Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium Ga0077535 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumGa0077535Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752192.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752192.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752192.protein.info.v11.5.txt",
		        "node_list_path": "1752192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaCepaciaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia cepacia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaCepaciaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "292.clusters.proteins.v11.5.txt",
		        "sequence_path": "292.protein.sequences.v11.5.fa",
		        "enrichment_path": "292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292.protein.info.v11.5.txt",
		        "node_list_path": "292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaBiviaDnf00188Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bivia DNF00188 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBiviaDnf00188Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1287476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1287476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1287476.clusters.proteins.v11.5.txt",
		        "sequence_path": "1287476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287476.protein.info.v11.5.txt",
		        "node_list_path": "1287476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1287476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacteriumRifcsplowo212Full3511(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFCSPLOWO2_12_FULL_35_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifcsplowo212Full3511", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801609.protein.info.v11.5.txt",
		        "node_list_path": "1801609.protein.complete.v11.5.txt"
		    }
		]
    )()

def VulcanibacillusModesticaldusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vulcanibacillus modesticaldus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulcanibacillusModesticaldusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "337097.clusters.info.v11.5.txt",
		        "cluster_tree_path": "337097.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "337097.clusters.proteins.v11.5.txt",
		        "sequence_path": "337097.protein.sequences.v11.5.fa",
		        "enrichment_path": "337097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "337097.protein.info.v11.5.txt",
		        "node_list_path": "337097.cluster.nodes.v11.5.txt",
		        "edge_list_path": "337097.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrasphaeraAustraliensisBen110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera australiensis Ben110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrasphaeraAustraliensisBen110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193182.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193182.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193182.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193182.protein.info.v11.5.txt",
		        "node_list_path": "1193182.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193182.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AneurinibacillusAneurinilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aneurinibacillus aneurinilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AneurinibacillusAneurinilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649747.protein.sequences.v11.5.fa",
		        "enrichment_path": "649747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649747.protein.info.v11.5.txt",
		        "node_list_path": "649747.protein.complete.v11.5.txt"
		    }
		]
    )()

def DictyosteliumDiscoideumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dictyostelium discoideum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DictyosteliumDiscoideumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44689.clusters.proteins.v11.5.txt",
		        "sequence_path": "44689.protein.sequences.v11.5.fa",
		        "enrichment_path": "44689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44689.protein.info.v11.5.txt",
		        "node_list_path": "44689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaClarridgeiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella clarridgeiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaClarridgeiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "696125.protein.sequences.v11.5.fa",
		        "enrichment_path": "696125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696125.protein.info.v11.5.txt",
		        "node_list_path": "696125.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpWsm1253(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM1253 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpWsm1253", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "319003.protein.sequences.v11.5.fa",
		        "enrichment_path": "319003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319003.protein.info.v11.5.txt",
		        "node_list_path": "319003.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaArvensicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga arvensicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaArvensicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29529.protein.sequences.v11.5.fa",
		        "enrichment_path": "29529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29529.protein.info.v11.5.txt",
		        "node_list_path": "29529.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpSoil750(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil750 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpSoil750", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736398.protein.info.v11.5.txt",
		        "node_list_path": "1736398.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpPamc22219Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. PAMC22219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpPamc22219Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1569209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1569209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1569209.clusters.proteins.v11.5.txt",
		        "sequence_path": "1569209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1569209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1569209.protein.info.v11.5.txt",
		        "node_list_path": "1569209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1569209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpTca20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. TCA20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpTca20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499968.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499968.protein.info.v11.5.txt",
		        "node_list_path": "1499968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpJ37Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. J37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJ37Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935837.clusters.proteins.v11.5.txt",
		        "sequence_path": "935837.protein.sequences.v11.5.fa",
		        "enrichment_path": "935837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935837.protein.info.v11.5.txt",
		        "node_list_path": "935837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PundamiliaNyerereiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pundamilia nyererei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PundamiliaNyerereiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "303518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "303518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "303518.clusters.proteins.v11.5.txt",
		        "sequence_path": "303518.protein.sequences.v11.5.fa",
		        "enrichment_path": "303518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "303518.protein.info.v11.5.txt",
		        "node_list_path": "303518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "303518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudovibrioAscidiaceicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio ascidiaceicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioAscidiaceicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "285279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "285279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "285279.clusters.proteins.v11.5.txt",
		        "sequence_path": "285279.protein.sequences.v11.5.fa",
		        "enrichment_path": "285279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285279.protein.info.v11.5.txt",
		        "node_list_path": "285279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "285279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloferacaceaeArchaeonB1Br10E2g22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloferacaceae archaeon B1-Br10_E2g22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloferacaceaeArchaeonB1Br10E2g22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1732021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1732021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1732021.clusters.proteins.v11.5.txt",
		        "sequence_path": "1732021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1732021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1732021.protein.info.v11.5.txt",
		        "node_list_path": "1732021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1732021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnicellularCyanobacteriumSu2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return unicellular cyanobacterium SU2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnicellularCyanobacteriumSu2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1981054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1981054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1981054.clusters.proteins.v11.5.txt",
		        "sequence_path": "1981054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1981054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1981054.protein.info.v11.5.txt",
		        "node_list_path": "1981054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1981054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusMacerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus macerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusMacerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44252.protein.sequences.v11.5.fa",
		        "enrichment_path": "44252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44252.protein.info.v11.5.txt",
		        "node_list_path": "44252.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpAnt303Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Ant303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpAnt303Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1488328.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1488328.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1488328.clusters.proteins.v11.5.txt",
		        "sequence_path": "1488328.protein.sequences.v11.5.fa",
		        "enrichment_path": "1488328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1488328.protein.info.v11.5.txt",
		        "node_list_path": "1488328.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1488328.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaGlabrata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida glabrata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaGlabrata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5478.protein.sequences.v11.5.fa",
		        "enrichment_path": "5478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5478.protein.info.v11.5.txt",
		        "node_list_path": "5478.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumDigitatumPhi26Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium digitatum PHI26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumDigitatumPhi26Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1170229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1170229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1170229.clusters.proteins.v11.5.txt",
		        "sequence_path": "1170229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1170229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1170229.protein.info.v11.5.txt",
		        "node_list_path": "1170229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1170229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PapillibacterCinnamivoransDsm12816Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Papillibacter cinnamivorans DSM 12816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PapillibacterCinnamivoransDsm12816Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122930.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122930.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122930.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122930.protein.info.v11.5.txt",
		        "node_list_path": "1122930.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122930.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaPsychrophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaPsychrophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "728005.protein.sequences.v11.5.fa",
		        "enrichment_path": "728005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "728005.protein.info.v11.5.txt",
		        "node_list_path": "728005.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophilalesBacteriumLsucc0135(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophilales bacterium LSUCC0135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilalesBacteriumLsucc0135", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1778481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1778481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1778481.protein.info.v11.5.txt",
		        "node_list_path": "1778481.protein.complete.v11.5.txt"
		    }
		]
    )()

def CastorCanadensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Castor canadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CastorCanadensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "51338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "51338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "51338.clusters.proteins.v11.5.txt",
		        "sequence_path": "51338.protein.sequences.v11.5.fa",
		        "enrichment_path": "51338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51338.protein.info.v11.5.txt",
		        "node_list_path": "51338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "51338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpL250(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. L250 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpL250", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411489.protein.sequences.v11.5.fa",
		        "enrichment_path": "411489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411489.protein.info.v11.5.txt",
		        "node_list_path": "411489.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaSpDsm29012(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella sp. DSM 29012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaSpDsm29012", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881056.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881056.protein.info.v11.5.txt",
		        "node_list_path": "1881056.protein.complete.v11.5.txt"
		    }
		]
    )()

def RubidibacterLacunae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubidibacter lacunae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubidibacterLacunae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582515.protein.sequences.v11.5.fa",
		        "enrichment_path": "582515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582515.protein.info.v11.5.txt",
		        "node_list_path": "582515.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioPalustrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio palustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioPalustrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1918946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1918946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1918946.clusters.proteins.v11.5.txt",
		        "sequence_path": "1918946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918946.protein.info.v11.5.txt",
		        "node_list_path": "1918946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1918946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaRiboflavinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia riboflavina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaRiboflavinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46914.clusters.proteins.v11.5.txt",
		        "sequence_path": "46914.protein.sequences.v11.5.fa",
		        "enrichment_path": "46914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46914.protein.info.v11.5.txt",
		        "node_list_path": "46914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSp316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSp316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1603293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603293.protein.info.v11.5.txt",
		        "node_list_path": "1603293.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLloydbacteriaBacteriumRifcsplowo202Full5111Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPLOWO2_02_FULL_51_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsplowo202Full5111Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798667.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798667.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798667.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798667.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798667.protein.info.v11.5.txt",
		        "node_list_path": "1798667.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798667.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSp10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSp10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1101191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101191.protein.info.v11.5.txt",
		        "node_list_path": "1101191.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsplowo202Full4714(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_02_FULL_47_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo202Full4714", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802129.protein.info.v11.5.txt",
		        "node_list_path": "1802129.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferAgarilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer agarilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferAgarilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1042377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042377.protein.info.v11.5.txt",
		        "node_list_path": "1042377.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusBifermentansDsm20003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus bifermentans DSM 20003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBifermentansDsm20003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423726.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423726.protein.info.v11.5.txt",
		        "node_list_path": "1423726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VirgibacillusSp6rCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus sp. 6R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusSp6rCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1911587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1911587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1911587.clusters.proteins.v11.5.txt",
		        "sequence_path": "1911587.protein.sequences.v11.5.fa",
		        "enrichment_path": "1911587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1911587.protein.info.v11.5.txt",
		        "node_list_path": "1911587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1911587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumNebraskenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium nebraskense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumNebraskenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "244292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "244292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "244292.clusters.proteins.v11.5.txt",
		        "sequence_path": "244292.protein.sequences.v11.5.fa",
		        "enrichment_path": "244292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244292.protein.info.v11.5.txt",
		        "node_list_path": "244292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "244292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ManihotEsculentaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Manihot esculenta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ManihotEsculentaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3983.clusters.proteins.v11.5.txt",
		        "sequence_path": "3983.protein.sequences.v11.5.fa",
		        "enrichment_path": "3983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3983.protein.info.v11.5.txt",
		        "node_list_path": "3983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumSteckii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium steckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumSteckii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "303698.protein.sequences.v11.5.fa",
		        "enrichment_path": "303698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "303698.protein.info.v11.5.txt",
		        "node_list_path": "303698.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSpA16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. A16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpA16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736675.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736675.protein.info.v11.5.txt",
		        "node_list_path": "1736675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrusXBretschneideriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrus x bretschneideri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrusXBretschneideriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "225117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "225117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "225117.clusters.proteins.v11.5.txt",
		        "sequence_path": "225117.protein.sequences.v11.5.fa",
		        "enrichment_path": "225117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225117.protein.info.v11.5.txt",
		        "node_list_path": "225117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "225117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanobacteriumEndosymbiontOfEpithemiaTurgidaIsolateEtsbLakeYunoko(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return cyanobacterium endosymbiont of Epithemia turgida isolate EtSB Lake Yunoko graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobacteriumEndosymbiontOfEpithemiaTurgidaIsolateEtsbLakeYunoko", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1228987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1228987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1228987.protein.info.v11.5.txt",
		        "node_list_path": "1228987.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumKyorinense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kyorinense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumKyorinense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "487514.protein.sequences.v11.5.fa",
		        "enrichment_path": "487514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487514.protein.info.v11.5.txt",
		        "node_list_path": "487514.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpNfacc26Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. NFACC26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpNfacc26Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566275.protein.info.v11.5.txt",
		        "node_list_path": "1566275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaFlavescensNrl30031h210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria flavescens NRL30031H210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaFlavescensNrl30031h210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546264.clusters.proteins.v11.5.txt",
		        "sequence_path": "546264.protein.sequences.v11.5.fa",
		        "enrichment_path": "546264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546264.protein.info.v11.5.txt",
		        "node_list_path": "546264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrientiaChutoStrDubaiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Orientia chuto str. Dubai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrientiaChutoStrDubaiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1359168.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1359168.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1359168.clusters.proteins.v11.5.txt",
		        "sequence_path": "1359168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1359168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1359168.protein.info.v11.5.txt",
		        "node_list_path": "1359168.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1359168.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumAzadirachtae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium azadirachtae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumAzadirachtae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582680.protein.sequences.v11.5.fa",
		        "enrichment_path": "582680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582680.protein.info.v11.5.txt",
		        "node_list_path": "582680.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusGlacialisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus glacialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusGlacialisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "494026.clusters.info.v11.5.txt",
		        "cluster_tree_path": "494026.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "494026.clusters.proteins.v11.5.txt",
		        "sequence_path": "494026.protein.sequences.v11.5.fa",
		        "enrichment_path": "494026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "494026.protein.info.v11.5.txt",
		        "node_list_path": "494026.cluster.nodes.v11.5.txt",
		        "edge_list_path": "494026.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaceaeBacteriumDtu059(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaceaeBacteriumDtu059", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671644.protein.info.v11.5.txt",
		        "node_list_path": "1671644.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaFlava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaFlava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095025.protein.info.v11.5.txt",
		        "node_list_path": "1095025.protein.complete.v11.5.txt"
		    }
		]
    )()

def MailhellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mailhella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MailhellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1903261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1903261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1903261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1903261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903261.protein.info.v11.5.txt",
		        "node_list_path": "1903261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1903261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumXenopiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium xenopi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumXenopiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1789.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1789.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1789.clusters.proteins.v11.5.txt",
		        "sequence_path": "1789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1789.protein.info.v11.5.txt",
		        "node_list_path": "1789.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1789.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumCongolenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium congolense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumCongolenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118062.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118062.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118062.clusters.proteins.v11.5.txt",
		        "sequence_path": "118062.protein.sequences.v11.5.fa",
		        "enrichment_path": "118062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118062.protein.info.v11.5.txt",
		        "node_list_path": "118062.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118062.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermosynechococcusElongatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosynechococcus elongatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosynechococcusElongatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "197221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "197221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "197221.clusters.proteins.v11.5.txt",
		        "sequence_path": "197221.protein.sequences.v11.5.fa",
		        "enrichment_path": "197221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "197221.protein.info.v11.5.txt",
		        "node_list_path": "197221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "197221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisNctc12261(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis NCTC 12261 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisNctc12261", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246201.protein.sequences.v11.5.fa",
		        "enrichment_path": "246201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246201.protein.info.v11.5.txt",
		        "node_list_path": "246201.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3811(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_38_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3811", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802060.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802060.protein.info.v11.5.txt",
		        "node_list_path": "1802060.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrococcusSpSt04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus sp. ST04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusSpSt04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1183377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1183377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1183377.protein.info.v11.5.txt",
		        "node_list_path": "1183377.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParameciumTetraurelia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paramecium tetraurelia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParameciumTetraurelia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5888.protein.sequences.v11.5.fa",
		        "enrichment_path": "5888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5888.protein.info.v11.5.txt",
		        "node_list_path": "5888.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndozoicomonasMontiporae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas montiporae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndozoicomonasMontiporae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1027273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1027273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1027273.protein.info.v11.5.txt",
		        "node_list_path": "1027273.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5719(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_57_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5719", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802391.protein.info.v11.5.txt",
		        "node_list_path": "1802391.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpOralTaxon920(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 920 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpOralTaxon920", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884263.protein.info.v11.5.txt",
		        "node_list_path": "1884263.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp12747566(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1274756.6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp12747566", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834076.protein.info.v11.5.txt",
		        "node_list_path": "1834076.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumXenophagum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium xenophagum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumXenophagum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1192759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192759.protein.info.v11.5.txt",
		        "node_list_path": "1192759.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPhytoplasmaSolani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma solani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPhytoplasmaSolani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69896.protein.sequences.v11.5.fa",
		        "enrichment_path": "69896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69896.protein.info.v11.5.txt",
		        "node_list_path": "69896.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbidosporaCretacea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbidospora cretacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbidosporaCretacea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28444.protein.sequences.v11.5.fa",
		        "enrichment_path": "28444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28444.protein.info.v11.5.txt",
		        "node_list_path": "28444.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusOryziterraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus oryziterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusOryziterraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1191699.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1191699.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1191699.clusters.proteins.v11.5.txt",
		        "sequence_path": "1191699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1191699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1191699.protein.info.v11.5.txt",
		        "node_list_path": "1191699.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1191699.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZymomonasMobilisZm4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zymomonas mobilis ZM4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymomonasMobilisZm4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264203.protein.sequences.v11.5.fa",
		        "enrichment_path": "264203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264203.protein.info.v11.5.txt",
		        "node_list_path": "264203.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaGlobisporaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina globispora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaGlobisporaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1459.clusters.proteins.v11.5.txt",
		        "sequence_path": "1459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1459.protein.info.v11.5.txt",
		        "node_list_path": "1459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrenobacterLuteus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crenobacter luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenobacterLuteus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1452487.protein.sequences.v11.5.fa",
		        "enrichment_path": "1452487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1452487.protein.info.v11.5.txt",
		        "node_list_path": "1452487.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProsthecochlorisAestuariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prosthecochloris aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProsthecochlorisAestuariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290512.clusters.proteins.v11.5.txt",
		        "sequence_path": "290512.protein.sequences.v11.5.fa",
		        "enrichment_path": "290512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290512.protein.info.v11.5.txt",
		        "node_list_path": "290512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrenarchaeotaArchaeonScgcAaa471B05Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon SCGC AAA471-B05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenarchaeotaArchaeonScgcAaa471B05Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1052801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1052801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1052801.clusters.proteins.v11.5.txt",
		        "sequence_path": "1052801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1052801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1052801.protein.info.v11.5.txt",
		        "node_list_path": "1052801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1052801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852365.protein.info.v11.5.txt",
		        "node_list_path": "1852365.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFukatsuiaSymbioticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fukatsuia symbiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFukatsuiaSymbioticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1878942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1878942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1878942.clusters.proteins.v11.5.txt",
		        "sequence_path": "1878942.protein.sequences.v11.5.fa",
		        "enrichment_path": "1878942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1878942.protein.info.v11.5.txt",
		        "node_list_path": "1878942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1878942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpSk643Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. SK643 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpSk643Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095727.protein.info.v11.5.txt",
		        "node_list_path": "1095727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumCrudilactis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium crudilactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumCrudilactis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "327277.protein.sequences.v11.5.fa",
		        "enrichment_path": "327277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "327277.protein.info.v11.5.txt",
		        "node_list_path": "327277.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanktotaleaArctica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planktotalea arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktotaleaArctica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1481893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1481893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1481893.protein.info.v11.5.txt",
		        "node_list_path": "1481893.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteralesBacteriumHtcc2255(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium HTCC2255 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteralesBacteriumHtcc2255", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "367336.protein.sequences.v11.5.fa",
		        "enrichment_path": "367336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "367336.protein.info.v11.5.txt",
		        "node_list_path": "367336.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusMucosaeLm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mucosae LM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMucosaeLm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1130798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1130798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1130798.protein.info.v11.5.txt",
		        "node_list_path": "1130798.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPanipatensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas panipatensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPanipatensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "428992.clusters.info.v11.5.txt",
		        "cluster_tree_path": "428992.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "428992.clusters.proteins.v11.5.txt",
		        "sequence_path": "428992.protein.sequences.v11.5.fa",
		        "enrichment_path": "428992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428992.protein.info.v11.5.txt",
		        "node_list_path": "428992.cluster.nodes.v11.5.txt",
		        "edge_list_path": "428992.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinophagaCostaii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga costaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaCostaii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1335309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1335309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1335309.protein.info.v11.5.txt",
		        "node_list_path": "1335309.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumCsp14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium CSP1-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumCsp14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1640513.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1640513.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1640513.clusters.proteins.v11.5.txt",
		        "sequence_path": "1640513.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640513.protein.info.v11.5.txt",
		        "node_list_path": "1640513.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1640513.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumCatenulatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium catenulatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumCatenulatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "566552.clusters.info.v11.5.txt",
		        "cluster_tree_path": "566552.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "566552.clusters.proteins.v11.5.txt",
		        "sequence_path": "566552.protein.sequences.v11.5.fa",
		        "enrichment_path": "566552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "566552.protein.info.v11.5.txt",
		        "node_list_path": "566552.cluster.nodes.v11.5.txt",
		        "edge_list_path": "566552.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaHospitaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia hospita Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaHospitaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "169430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "169430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "169430.clusters.proteins.v11.5.txt",
		        "sequence_path": "169430.protein.sequences.v11.5.fa",
		        "enrichment_path": "169430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "169430.protein.info.v11.5.txt",
		        "node_list_path": "169430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "169430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaOneidensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella oneidensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaOneidensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "211586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "211586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "211586.clusters.proteins.v11.5.txt",
		        "sequence_path": "211586.protein.sequences.v11.5.fa",
		        "enrichment_path": "211586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211586.protein.info.v11.5.txt",
		        "node_list_path": "211586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "211586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfospiraJoergenseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfospira joergensenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfospiraJoergenseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265505.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265505.protein.info.v11.5.txt",
		        "node_list_path": "1265505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumGw2011Gwb1446Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB1_44_6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb1446Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618384.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618384.protein.info.v11.5.txt",
		        "node_list_path": "1618384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactococcusLactisCremorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus lactis cremoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusLactisCremorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "416870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "416870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "416870.clusters.proteins.v11.5.txt",
		        "sequence_path": "416870.protein.sequences.v11.5.fa",
		        "enrichment_path": "416870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416870.protein.info.v11.5.txt",
		        "node_list_path": "416870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "416870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MuribaculumIntestinaleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Muribaculum intestinale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuribaculumIntestinaleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1796646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1796646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1796646.clusters.proteins.v11.5.txt",
		        "sequence_path": "1796646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796646.protein.info.v11.5.txt",
		        "node_list_path": "1796646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1796646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusDidelphis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus didelphis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDidelphis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123301.protein.info.v11.5.txt",
		        "node_list_path": "1123301.protein.complete.v11.5.txt"
		    }
		]
    )()

def HeterobasidionIrregulareTc321Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Heterobasidion irregulare TC 32-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeterobasidionIrregulareTc321Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "747525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "747525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "747525.clusters.proteins.v11.5.txt",
		        "sequence_path": "747525.protein.sequences.v11.5.fa",
		        "enrichment_path": "747525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747525.protein.info.v11.5.txt",
		        "node_list_path": "747525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "747525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferVariabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer variabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferVariabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1279017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1279017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1279017.protein.info.v11.5.txt",
		        "node_list_path": "1279017.protein.complete.v11.5.txt"
		    }
		]
    )()

def FilomicrobiumInsigne(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Filomicrobium insigne graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FilomicrobiumInsigne", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "418854.protein.sequences.v11.5.fa",
		        "enrichment_path": "418854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "418854.protein.info.v11.5.txt",
		        "node_list_path": "418854.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioRuminisAd2017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis AD2017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioRuminisAd2017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280694.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280694.protein.info.v11.5.txt",
		        "node_list_path": "1280694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusCcmp1375(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus CCMP1375 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusCcmp1375", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "167539.protein.sequences.v11.5.fa",
		        "enrichment_path": "167539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167539.protein.info.v11.5.txt",
		        "node_list_path": "167539.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_43_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618826.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618826.protein.info.v11.5.txt",
		        "node_list_path": "1618826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSalinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter salinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSalinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1874317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1874317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1874317.clusters.proteins.v11.5.txt",
		        "sequence_path": "1874317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1874317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1874317.protein.info.v11.5.txt",
		        "node_list_path": "1874317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1874317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaLoihiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina loihiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaLoihiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "283942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "283942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "283942.clusters.proteins.v11.5.txt",
		        "sequence_path": "283942.protein.sequences.v11.5.fa",
		        "enrichment_path": "283942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283942.protein.info.v11.5.txt",
		        "node_list_path": "283942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "283942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3814Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_38_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3814Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798279.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798279.protein.info.v11.5.txt",
		        "node_list_path": "1798279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LabilibacterMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Labilibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabilibacterMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1477105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1477105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1477105.clusters.proteins.v11.5.txt",
		        "sequence_path": "1477105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1477105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1477105.protein.info.v11.5.txt",
		        "node_list_path": "1477105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1477105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacillusReuszeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus reuszeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusReuszeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "54915.protein.sequences.v11.5.fa",
		        "enrichment_path": "54915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54915.protein.info.v11.5.txt",
		        "node_list_path": "54915.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalioglobusJaponicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halioglobus japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalioglobusJaponicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930805.protein.sequences.v11.5.fa",
		        "enrichment_path": "930805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930805.protein.info.v11.5.txt",
		        "node_list_path": "930805.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumOleivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium oleivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumOleivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "273677.clusters.info.v11.5.txt",
		        "cluster_tree_path": "273677.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "273677.clusters.proteins.v11.5.txt",
		        "sequence_path": "273677.protein.sequences.v11.5.fa",
		        "enrichment_path": "273677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273677.protein.info.v11.5.txt",
		        "node_list_path": "273677.cluster.nodes.v11.5.txt",
		        "edge_list_path": "273677.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylosinusTrichosporium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylosinus trichosporium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylosinusTrichosporium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "595536.protein.sequences.v11.5.fa",
		        "enrichment_path": "595536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595536.protein.info.v11.5.txt",
		        "node_list_path": "595536.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpNsp21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. NSP2.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpNsp21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071072.protein.info.v11.5.txt",
		        "node_list_path": "1071072.protein.complete.v11.5.txt"
		    }
		]
    )()

def JoostellaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Joostella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JoostellaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926559.protein.sequences.v11.5.fa",
		        "enrichment_path": "926559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926559.protein.info.v11.5.txt",
		        "node_list_path": "926559.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusGinsengihumiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus ginsengihumi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGinsengihumiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "363870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "363870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "363870.clusters.proteins.v11.5.txt",
		        "sequence_path": "363870.protein.sequences.v11.5.fa",
		        "enrichment_path": "363870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "363870.protein.info.v11.5.txt",
		        "node_list_path": "363870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "363870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMargulisbacteriaBacteriumGwd239127Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Margulisbacteria bacterium GWD2_39_127 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMargulisbacteriaBacteriumGwd239127Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817871.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817871.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817871.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817871.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817871.protein.info.v11.5.txt",
		        "node_list_path": "1817871.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817871.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSpechtbacteriaBacteriumRifcsphigho212Full3830Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPHIGHO2_12_FULL_38_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsphigho212Full3830Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802160.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802160.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802160.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802160.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802160.protein.info.v11.5.txt",
		        "node_list_path": "1802160.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802160.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaFonticolaAuap2cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia fonticola AUAP2C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaFonticolaAuap2cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1332071.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1332071.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1332071.clusters.proteins.v11.5.txt",
		        "sequence_path": "1332071.protein.sequences.v11.5.fa",
		        "enrichment_path": "1332071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1332071.protein.info.v11.5.txt",
		        "node_list_path": "1332071.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1332071.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumPuniceumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium puniceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPuniceumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29367.clusters.proteins.v11.5.txt",
		        "sequence_path": "29367.protein.sequences.v11.5.fa",
		        "enrichment_path": "29367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29367.protein.info.v11.5.txt",
		        "node_list_path": "29367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasAsaccharolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas asaccharolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasAsaccharolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "879243.protein.sequences.v11.5.fa",
		        "enrichment_path": "879243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879243.protein.info.v11.5.txt",
		        "node_list_path": "879243.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioAerogenesCect7868(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio aerogenes CECT 7868 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioAerogenesCect7868", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216006.protein.info.v11.5.txt",
		        "node_list_path": "1216006.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpHl111Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. HL-111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpHl111Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798193.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798193.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798193.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798193.protein.info.v11.5.txt",
		        "node_list_path": "1798193.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798193.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeolentinusLepideusHhb14362Ss1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neolentinus lepideus HHB14362 ss-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeolentinusLepideusHhb14362Ss1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314782.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314782.protein.info.v11.5.txt",
		        "node_list_path": "1314782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyellaGinsengisoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyella ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaGinsengisoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1234364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1234364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1234364.clusters.proteins.v11.5.txt",
		        "sequence_path": "1234364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234364.protein.info.v11.5.txt",
		        "node_list_path": "1234364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1234364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaCincinnatiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella cincinnatiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaCincinnatiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28085.clusters.proteins.v11.5.txt",
		        "sequence_path": "28085.protein.sequences.v11.5.fa",
		        "enrichment_path": "28085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28085.protein.info.v11.5.txt",
		        "node_list_path": "28085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaAtlantae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella atlantae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaAtlantae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34059.protein.sequences.v11.5.fa",
		        "enrichment_path": "34059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34059.protein.info.v11.5.txt",
		        "node_list_path": "34059.protein.complete.v11.5.txt"
		    }
		]
    )()

def PomaceaCanaliculata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pomacea canaliculata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PomaceaCanaliculata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "400727.protein.sequences.v11.5.fa",
		        "enrichment_path": "400727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400727.protein.info.v11.5.txt",
		        "node_list_path": "400727.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc074e01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC074E01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc074e01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1715017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715017.protein.info.v11.5.txt",
		        "node_list_path": "1715017.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSpE463Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. E463 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSpE463Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1234593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1234593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1234593.clusters.proteins.v11.5.txt",
		        "sequence_path": "1234593.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234593.protein.info.v11.5.txt",
		        "node_list_path": "1234593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1234593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumPolynesiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium polynesiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPolynesiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1325933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325933.protein.info.v11.5.txt",
		        "node_list_path": "1325933.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesViridochromogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces viridochromogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesViridochromogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "591159.protein.sequences.v11.5.fa",
		        "enrichment_path": "591159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591159.protein.info.v11.5.txt",
		        "node_list_path": "591159.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasAlbilineans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas albilineans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasAlbilineans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "380358.protein.sequences.v11.5.fa",
		        "enrichment_path": "380358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380358.protein.info.v11.5.txt",
		        "node_list_path": "380358.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrachymyrmexCornetziCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trachymyrmex cornetzi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrachymyrmexCornetziCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471704.clusters.proteins.v11.5.txt",
		        "sequence_path": "471704.protein.sequences.v11.5.fa",
		        "enrichment_path": "471704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471704.protein.info.v11.5.txt",
		        "node_list_path": "471704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLiberibacterAfricanusPtsapsyCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liberibacter africanus PTSAPSY Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiberibacterAfricanusPtsapsyCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1277257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1277257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1277257.clusters.proteins.v11.5.txt",
		        "sequence_path": "1277257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1277257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1277257.protein.info.v11.5.txt",
		        "node_list_path": "1277257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1277257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfolobusAcidocaldariusSusaz(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius SUSAZ graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusAcidocaldariusSusaz", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1435377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1435377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1435377.protein.info.v11.5.txt",
		        "node_list_path": "1435377.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasMobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasMobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "51642.clusters.info.v11.5.txt",
		        "cluster_tree_path": "51642.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "51642.clusters.proteins.v11.5.txt",
		        "sequence_path": "51642.protein.sequences.v11.5.fa",
		        "enrichment_path": "51642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51642.protein.info.v11.5.txt",
		        "node_list_path": "51642.cluster.nodes.v11.5.txt",
		        "edge_list_path": "51642.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KorarchaeumCryptofilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Korarchaeum cryptofilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KorarchaeumCryptofilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "374847.protein.sequences.v11.5.fa",
		        "enrichment_path": "374847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "374847.protein.info.v11.5.txt",
		        "node_list_path": "374847.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudaminobacterSalicylatoxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudaminobacter salicylatoxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudaminobacterSalicylatoxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1192868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192868.protein.info.v11.5.txt",
		        "node_list_path": "1192868.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19041Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19041 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19041Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1460637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1460637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1460637.clusters.proteins.v11.5.txt",
		        "sequence_path": "1460637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460637.protein.info.v11.5.txt",
		        "node_list_path": "1460637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1460637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatenovulumAgarivoransDs2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catenovulum agarivorans DS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenovulumAgarivoransDs2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1328313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1328313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1328313.protein.info.v11.5.txt",
		        "node_list_path": "1328313.protein.complete.v11.5.txt"
		    }
		]
    )()

def OleispiraAntarcticaRb8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oleispira antarctica RB-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OleispiraAntarcticaRb8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "698738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "698738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "698738.clusters.proteins.v11.5.txt",
		        "sequence_path": "698738.protein.sequences.v11.5.fa",
		        "enrichment_path": "698738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698738.protein.info.v11.5.txt",
		        "node_list_path": "698738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "698738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasByunsanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas byunsanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasByunsanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "327939.protein.sequences.v11.5.fa",
		        "enrichment_path": "327939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "327939.protein.info.v11.5.txt",
		        "node_list_path": "327939.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumSpH133Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. H133 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumSpH133Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "861208.clusters.info.v11.5.txt",
		        "cluster_tree_path": "861208.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "861208.clusters.proteins.v11.5.txt",
		        "sequence_path": "861208.protein.sequences.v11.5.fa",
		        "enrichment_path": "861208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861208.protein.info.v11.5.txt",
		        "node_list_path": "861208.cluster.nodes.v11.5.txt",
		        "edge_list_path": "861208.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiorhodococcusSpAk35(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiorhodococcus sp. AK35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiorhodococcusSpAk35", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1249627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249627.protein.info.v11.5.txt",
		        "node_list_path": "1249627.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoxiellaEndosymbiontOfAmblyommaAmericanumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coxiella endosymbiont of Amblyomma americanum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoxiellaEndosymbiontOfAmblyommaAmericanumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "325775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "325775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "325775.clusters.proteins.v11.5.txt",
		        "sequence_path": "325775.protein.sequences.v11.5.fa",
		        "enrichment_path": "325775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "325775.protein.info.v11.5.txt",
		        "node_list_path": "325775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "325775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeucobacterSpPh1c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter sp. PH1c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterSpPh1c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397278.protein.info.v11.5.txt",
		        "node_list_path": "1397278.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloversatilisUniversalisFam5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloversatilis universalis FAM5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloversatilisUniversalisFam5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1000565.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1000565.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1000565.clusters.proteins.v11.5.txt",
		        "sequence_path": "1000565.protein.sequences.v11.5.fa",
		        "enrichment_path": "1000565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1000565.protein.info.v11.5.txt",
		        "node_list_path": "1000565.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1000565.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacteriumGwf23715Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium GWF2_37_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacteriumGwf23715Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801606.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801606.protein.info.v11.5.txt",
		        "node_list_path": "1801606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KocuriaVariansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kocuria varians Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaVariansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1272.clusters.proteins.v11.5.txt",
		        "sequence_path": "1272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1272.protein.info.v11.5.txt",
		        "node_list_path": "1272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodovulumSpP5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. P5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovulumSpP5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1564506.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1564506.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1564506.clusters.proteins.v11.5.txt",
		        "sequence_path": "1564506.protein.sequences.v11.5.fa",
		        "enrichment_path": "1564506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1564506.protein.info.v11.5.txt",
		        "node_list_path": "1564506.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1564506.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoniaMobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesonia mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoniaMobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122226.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122226.protein.info.v11.5.txt",
		        "node_list_path": "1122226.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAle14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAle14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158168.protein.info.v11.5.txt",
		        "node_list_path": "1158168.protein.complete.v11.5.txt"
		    }
		]
    )()

def MangrovibacterSpMfb070(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mangrovibacter sp. MFB070 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MangrovibacterSpMfb070", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1224318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224318.protein.info.v11.5.txt",
		        "node_list_path": "1224318.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavihumibacterSpZg627Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavihumibacter sp. ZG627 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavihumibacterSpZg627Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463156.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463156.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463156.protein.info.v11.5.txt",
		        "node_list_path": "1463156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DethiobacterAlkaliphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dethiobacter alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DethiobacterAlkaliphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "555088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "555088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "555088.clusters.proteins.v11.5.txt",
		        "sequence_path": "555088.protein.sequences.v11.5.fa",
		        "enrichment_path": "555088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555088.protein.info.v11.5.txt",
		        "node_list_path": "555088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "555088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpLz4wCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Lz4W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpLz4wCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206777.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206777.protein.info.v11.5.txt",
		        "node_list_path": "1206777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterAerogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter aerogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterAerogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1028307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1028307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1028307.clusters.proteins.v11.5.txt",
		        "sequence_path": "1028307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028307.protein.info.v11.5.txt",
		        "node_list_path": "1028307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1028307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaSpF0581(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. F0581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaSpF0581", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321774.protein.info.v11.5.txt",
		        "node_list_path": "1321774.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusToleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius tolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusToleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "74031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "74031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "74031.clusters.proteins.v11.5.txt",
		        "sequence_path": "74031.protein.sequences.v11.5.fa",
		        "enrichment_path": "74031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74031.protein.info.v11.5.txt",
		        "node_list_path": "74031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "74031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollichthysLucidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collichthys lucidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollichthysLucidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "240159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "240159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "240159.clusters.proteins.v11.5.txt",
		        "sequence_path": "240159.protein.sequences.v11.5.fa",
		        "enrichment_path": "240159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240159.protein.info.v11.5.txt",
		        "node_list_path": "240159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "240159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitromicrobiumBathyomarinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citromicrobium bathyomarinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitromicrobiumBathyomarinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "685035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "685035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "685035.clusters.proteins.v11.5.txt",
		        "sequence_path": "685035.protein.sequences.v11.5.fa",
		        "enrichment_path": "685035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "685035.protein.info.v11.5.txt",
		        "node_list_path": "685035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "685035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumPaludisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium paludis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumPaludisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "868131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "868131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "868131.clusters.proteins.v11.5.txt",
		        "sequence_path": "868131.protein.sequences.v11.5.fa",
		        "enrichment_path": "868131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "868131.protein.info.v11.5.txt",
		        "node_list_path": "868131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "868131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrasphaeraSpSoil756Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera sp. Soil756 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrasphaeraSpSoil756Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736399.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736399.protein.info.v11.5.txt",
		        "node_list_path": "1736399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusCallidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus callidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusCallidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411473.clusters.proteins.v11.5.txt",
		        "sequence_path": "411473.protein.sequences.v11.5.fa",
		        "enrichment_path": "411473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411473.protein.info.v11.5.txt",
		        "node_list_path": "411473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanoculleusHoronobensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus horonobensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusHoronobensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "528314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "528314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "528314.clusters.proteins.v11.5.txt",
		        "sequence_path": "528314.protein.sequences.v11.5.fa",
		        "enrichment_path": "528314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "528314.protein.info.v11.5.txt",
		        "node_list_path": "528314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "528314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RheinheimeraSpA13l(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera sp. A13L graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraSpA13l", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "506534.protein.sequences.v11.5.fa",
		        "enrichment_path": "506534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "506534.protein.info.v11.5.txt",
		        "node_list_path": "506534.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpSoil797(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil797 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpSoil797", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736413.protein.info.v11.5.txt",
		        "node_list_path": "1736413.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaPsychrerythraeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia psychrerythraea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaPsychrerythraeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28229.clusters.proteins.v11.5.txt",
		        "sequence_path": "28229.protein.sequences.v11.5.fa",
		        "enrichment_path": "28229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28229.protein.info.v11.5.txt",
		        "node_list_path": "28229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumRifcsphigho201Full4114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO2_01_FULL_41_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho201Full4114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797217.protein.info.v11.5.txt",
		        "node_list_path": "1797217.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterMediterraneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter mediterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterMediterraneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83219.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83219.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83219.clusters.proteins.v11.5.txt",
		        "sequence_path": "83219.protein.sequences.v11.5.fa",
		        "enrichment_path": "83219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83219.protein.info.v11.5.txt",
		        "node_list_path": "83219.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83219.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaSpJc4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema sp. JC4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSpJc4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1124982.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1124982.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1124982.clusters.proteins.v11.5.txt",
		        "sequence_path": "1124982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1124982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1124982.protein.info.v11.5.txt",
		        "node_list_path": "1124982.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1124982.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaGb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida GB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaGb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "76869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "76869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "76869.clusters.proteins.v11.5.txt",
		        "sequence_path": "76869.protein.sequences.v11.5.fa",
		        "enrichment_path": "76869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76869.protein.info.v11.5.txt",
		        "node_list_path": "76869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "76869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VenustampullaEchinocandicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Venustampulla echinocandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VenustampullaEchinocandicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2656787.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2656787.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2656787.clusters.proteins.v11.5.txt",
		        "sequence_path": "2656787.protein.sequences.v11.5.fa",
		        "enrichment_path": "2656787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2656787.protein.info.v11.5.txt",
		        "node_list_path": "2656787.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2656787.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccidioidesBrasiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccidioidesBrasiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "121759.protein.sequences.v11.5.fa",
		        "enrichment_path": "121759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121759.protein.info.v11.5.txt",
		        "node_list_path": "121759.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaPsychrerythraea34h(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia psychrerythraea 34H graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaPsychrerythraea34h", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "167879.protein.sequences.v11.5.fa",
		        "enrichment_path": "167879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167879.protein.info.v11.5.txt",
		        "node_list_path": "167879.protein.complete.v11.5.txt"
		    }
		]
    )()

def CrenarchaeotaArchaeon13120cm25314(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_20CM_2_53_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenarchaeotaArchaeon13120cm25314", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805094.protein.info.v11.5.txt",
		        "node_list_path": "1805094.protein.complete.v11.5.txt"
		    }
		]
    )()

def SucciniclasticumRuminisDsm9236Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Succiniclasticum ruminis DSM 9236 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SucciniclasticumRuminisDsm9236Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123323.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123323.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123323.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123323.protein.info.v11.5.txt",
		        "node_list_path": "1123323.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123323.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentibacillusHalodurans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus halodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentibacillusHalodurans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "237679.protein.sequences.v11.5.fa",
		        "enrichment_path": "237679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237679.protein.info.v11.5.txt",
		        "node_list_path": "237679.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprinellusMicaceus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprinellus micaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprinellusMicaceus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "71717.protein.sequences.v11.5.fa",
		        "enrichment_path": "71717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "71717.protein.info.v11.5.txt",
		        "node_list_path": "71717.protein.complete.v11.5.txt"
		    }
		]
    )()

def CharadriusVociferus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Charadrius vociferus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CharadriusVociferus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "50402.protein.sequences.v11.5.fa",
		        "enrichment_path": "50402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50402.protein.info.v11.5.txt",
		        "node_list_path": "50402.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusAlbusJl83Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus albus JL83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusAlbusJl83Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449352.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449352.protein.info.v11.5.txt",
		        "node_list_path": "1449352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumKroppenstedtii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium kroppenstedtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumKroppenstedtii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "645127.protein.sequences.v11.5.fa",
		        "enrichment_path": "645127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645127.protein.info.v11.5.txt",
		        "node_list_path": "645127.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpIbun(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. IBUN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpIbun", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1042326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042326.protein.info.v11.5.txt",
		        "node_list_path": "1042326.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpJcc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. JCC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpJcc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1414720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414720.protein.info.v11.5.txt",
		        "node_list_path": "1414720.protein.complete.v11.5.txt"
		    }
		]
    )()

def LonsdaleaBritannica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lonsdalea britannica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LonsdaleaBritannica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1082704.protein.sequences.v11.5.fa",
		        "enrichment_path": "1082704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1082704.protein.info.v11.5.txt",
		        "node_list_path": "1082704.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumSpLeaf291(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Leaf291 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumSpLeaf291", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736325.protein.info.v11.5.txt",
		        "node_list_path": "1736325.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesClavuligerusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces clavuligerus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesClavuligerusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "443255.clusters.info.v11.5.txt",
		        "cluster_tree_path": "443255.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "443255.clusters.proteins.v11.5.txt",
		        "sequence_path": "443255.protein.sequences.v11.5.fa",
		        "enrichment_path": "443255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443255.protein.info.v11.5.txt",
		        "node_list_path": "443255.cluster.nodes.v11.5.txt",
		        "edge_list_path": "443255.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaTaeniospiralisNbrc102512Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga taeniospiralis NBRC 102512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaTaeniospiralisNbrc102512Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349793.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349793.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349793.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349793.protein.info.v11.5.txt",
		        "node_list_path": "1349793.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349793.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NafulsellaTurpanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nafulsella turpanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NafulsellaTurpanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1124780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1124780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1124780.protein.info.v11.5.txt",
		        "node_list_path": "1124780.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumPhox21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium Phox-21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumPhox21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1918507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1918507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1918507.clusters.proteins.v11.5.txt",
		        "sequence_path": "1918507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918507.protein.info.v11.5.txt",
		        "node_list_path": "1918507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1918507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedosphaeraParvulaEllin514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedosphaera parvula Ellin514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedosphaeraParvulaEllin514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "320771.protein.sequences.v11.5.fa",
		        "enrichment_path": "320771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "320771.protein.info.v11.5.txt",
		        "node_list_path": "320771.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumStBin15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium ST_bin15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumStBin15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1978763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978763.protein.info.v11.5.txt",
		        "node_list_path": "1978763.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat14578Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-14578 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat14578Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208600.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208600.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208600.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208600.protein.info.v11.5.txt",
		        "node_list_path": "1208600.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208600.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesGlycerinitoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces glycerinitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesGlycerinitoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1892869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1892869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1892869.clusters.proteins.v11.5.txt",
		        "sequence_path": "1892869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892869.protein.info.v11.5.txt",
		        "node_list_path": "1892869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1892869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobacterSpRoot29Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobacterSpRoot29Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736511.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736511.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736511.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736511.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736511.protein.info.v11.5.txt",
		        "node_list_path": "1736511.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736511.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumAquaticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium aquaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumAquaticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "452084.protein.sequences.v11.5.fa",
		        "enrichment_path": "452084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452084.protein.info.v11.5.txt",
		        "node_list_path": "452084.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrioExovorus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrio exovorus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrioExovorus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1184267.protein.sequences.v11.5.fa",
		        "enrichment_path": "1184267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1184267.protein.info.v11.5.txt",
		        "node_list_path": "1184267.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumUlceransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium ulcerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumUlceransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "945712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "945712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "945712.clusters.proteins.v11.5.txt",
		        "sequence_path": "945712.protein.sequences.v11.5.fa",
		        "enrichment_path": "945712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "945712.protein.info.v11.5.txt",
		        "node_list_path": "945712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "945712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh5701(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 5701 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh5701", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69042.protein.sequences.v11.5.fa",
		        "enrichment_path": "69042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69042.protein.info.v11.5.txt",
		        "node_list_path": "69042.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusOryzaeRib40Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus oryzae RIB40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusOryzaeRib40Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "510516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "510516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "510516.clusters.proteins.v11.5.txt",
		        "sequence_path": "510516.protein.sequences.v11.5.fa",
		        "enrichment_path": "510516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "510516.protein.info.v11.5.txt",
		        "node_list_path": "510516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "510516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807753.protein.info.v11.5.txt",
		        "node_list_path": "1807753.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasPiscicida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas piscicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasPiscicida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43662.protein.sequences.v11.5.fa",
		        "enrichment_path": "43662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43662.protein.info.v11.5.txt",
		        "node_list_path": "43662.protein.complete.v11.5.txt"
		    }
		]
    )()

def RodentibacterMrazii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter mrazii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterMrazii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1908257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908257.protein.info.v11.5.txt",
		        "node_list_path": "1908257.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumJoshi001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium JOSHI001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumJoshi001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "864051.protein.sequences.v11.5.fa",
		        "enrichment_path": "864051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864051.protein.info.v11.5.txt",
		        "node_list_path": "864051.protein.complete.v11.5.txt"
		    }
		]
    )()

def RouxiellaBadensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rouxiella badensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RouxiellaBadensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1646377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1646377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1646377.protein.info.v11.5.txt",
		        "node_list_path": "1646377.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaCinerea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria cinerea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaCinerea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546262.protein.sequences.v11.5.fa",
		        "enrichment_path": "546262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546262.protein.info.v11.5.txt",
		        "node_list_path": "546262.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusThiodiazotrophaEndoloripes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thiodiazotropha endoloripes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThiodiazotrophaEndoloripes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1818881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1818881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1818881.protein.info.v11.5.txt",
		        "node_list_path": "1818881.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpBl107Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. BL107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpBl107Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313625.clusters.proteins.v11.5.txt",
		        "sequence_path": "313625.protein.sequences.v11.5.fa",
		        "enrichment_path": "313625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313625.protein.info.v11.5.txt",
		        "node_list_path": "313625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachypodiumDistachyonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachypodium distachyon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachypodiumDistachyonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "15368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "15368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "15368.clusters.proteins.v11.5.txt",
		        "sequence_path": "15368.protein.sequences.v11.5.fa",
		        "enrichment_path": "15368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "15368.protein.info.v11.5.txt",
		        "node_list_path": "15368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "15368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GallaecimonasXiamenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallaecimonas xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallaecimonasXiamenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "745411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "745411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "745411.clusters.proteins.v11.5.txt",
		        "sequence_path": "745411.protein.sequences.v11.5.fa",
		        "enrichment_path": "745411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745411.protein.info.v11.5.txt",
		        "node_list_path": "745411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "745411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BatrachochytriumSalamandrivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Batrachochytrium salamandrivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BatrachochytriumSalamandrivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1357716.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1357716.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1357716.clusters.proteins.v11.5.txt",
		        "sequence_path": "1357716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357716.protein.info.v11.5.txt",
		        "node_list_path": "1357716.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1357716.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterSp4636Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter sp. 46_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterSp4636Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896965.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896965.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896965.protein.info.v11.5.txt",
		        "node_list_path": "1896965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterMobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterMobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "488533.protein.sequences.v11.5.fa",
		        "enrichment_path": "488533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "488533.protein.info.v11.5.txt",
		        "node_list_path": "488533.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinarimonasRoseaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinarimonas rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinarimonasRoseaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123229.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123229.protein.info.v11.5.txt",
		        "node_list_path": "1123229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterPsychrotoleransDsm18569(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter psychrotolerans DSM 18569 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterPsychrotoleransDsm18569", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121959.protein.info.v11.5.txt",
		        "node_list_path": "1121959.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpJs623(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JS623 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpJs623", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "212767.protein.sequences.v11.5.fa",
		        "enrichment_path": "212767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "212767.protein.info.v11.5.txt",
		        "node_list_path": "212767.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloarculaHispanica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula hispanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaHispanica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634497.protein.sequences.v11.5.fa",
		        "enrichment_path": "634497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634497.protein.info.v11.5.txt",
		        "node_list_path": "634497.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoorellaGlyceriniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moorella glycerini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoorellaGlyceriniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "55779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "55779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "55779.clusters.proteins.v11.5.txt",
		        "sequence_path": "55779.protein.sequences.v11.5.fa",
		        "enrichment_path": "55779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55779.protein.info.v11.5.txt",
		        "node_list_path": "55779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "55779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpYr528Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR528 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpYr528Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500258.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500258.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500258.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500258.protein.info.v11.5.txt",
		        "node_list_path": "1500258.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500258.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAdolescentisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium adolescentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAdolescentisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1680.clusters.proteins.v11.5.txt",
		        "sequence_path": "1680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1680.protein.info.v11.5.txt",
		        "node_list_path": "1680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NematocidaDisplodere(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nematocida displodere graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NematocidaDisplodere", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805483.protein.info.v11.5.txt",
		        "node_list_path": "1805483.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSelenitireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus selenitireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSelenitireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1324314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1324314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1324314.clusters.proteins.v11.5.txt",
		        "sequence_path": "1324314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1324314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1324314.protein.info.v11.5.txt",
		        "node_list_path": "1324314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1324314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCrK1wCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Cr-K1W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCrK1wCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1452537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1452537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1452537.clusters.proteins.v11.5.txt",
		        "sequence_path": "1452537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1452537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1452537.protein.info.v11.5.txt",
		        "node_list_path": "1452537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1452537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlsr1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALSr1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlsr1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "748658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "748658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "748658.clusters.proteins.v11.5.txt",
		        "sequence_path": "748658.protein.sequences.v11.5.fa",
		        "enrichment_path": "748658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748658.protein.info.v11.5.txt",
		        "node_list_path": "748658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "748658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LabilithrixLuteola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Labilithrix luteola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabilithrixLuteola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1391654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391654.protein.info.v11.5.txt",
		        "node_list_path": "1391654.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumRifcsphigho201Full5728Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPHIGHO2_01_FULL_57_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsphigho201Full5728Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798647.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798647.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798647.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798647.protein.info.v11.5.txt",
		        "node_list_path": "1798647.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798647.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KordiaJejudonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kordia jejudonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KordiaJejudonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348245.protein.info.v11.5.txt",
		        "node_list_path": "1348245.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldivirgaSpMu80Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldivirga sp. MU80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldivirgaSpMu80Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1650354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1650354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1650354.clusters.proteins.v11.5.txt",
		        "sequence_path": "1650354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1650354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1650354.protein.info.v11.5.txt",
		        "node_list_path": "1650354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1650354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsphigho202Full4912(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_49_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full4912", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802271.protein.info.v11.5.txt",
		        "node_list_path": "1802271.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaLimiDsm17137(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia limi DSM 17137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaLimiDsm17137", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121477.protein.info.v11.5.txt",
		        "node_list_path": "1121477.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBereziniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter bereziniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBereziniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "106648.protein.sequences.v11.5.fa",
		        "enrichment_path": "106648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106648.protein.info.v11.5.txt",
		        "node_list_path": "106648.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHydrogenedentesBacteriumCg1024214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrogenedentes bacterium CG1_02_42_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHydrogenedentesBacteriumCg1024214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805216.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805216.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805216.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805216.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805216.protein.info.v11.5.txt",
		        "node_list_path": "1805216.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805216.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2055.protein.sequences.v11.5.fa",
		        "enrichment_path": "2055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2055.protein.info.v11.5.txt",
		        "node_list_path": "2055.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusSpHmsc06h08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus sp. HMSC06H08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusSpHmsc06h08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1581129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1581129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1581129.clusters.proteins.v11.5.txt",
		        "sequence_path": "1581129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581129.protein.info.v11.5.txt",
		        "node_list_path": "1581129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1581129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaSp499Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. 499 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSp499Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1261634.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1261634.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1261634.clusters.proteins.v11.5.txt",
		        "sequence_path": "1261634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261634.protein.info.v11.5.txt",
		        "node_list_path": "1261634.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1261634.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumBal38Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium BAL38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumBal38Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391598.clusters.proteins.v11.5.txt",
		        "sequence_path": "391598.protein.sequences.v11.5.fa",
		        "enrichment_path": "391598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391598.protein.info.v11.5.txt",
		        "node_list_path": "391598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumGwf25735Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_57_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumGwf25735Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798576.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798576.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798576.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798576.protein.info.v11.5.txt",
		        "node_list_path": "1798576.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798576.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyopneumoniae232Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae 232 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyopneumoniae232Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "295358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "295358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "295358.clusters.proteins.v11.5.txt",
		        "sequence_path": "295358.protein.sequences.v11.5.fa",
		        "enrichment_path": "295358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "295358.protein.info.v11.5.txt",
		        "node_list_path": "295358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "295358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpLm4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. LM4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpLm4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1938609.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1938609.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1938609.clusters.proteins.v11.5.txt",
		        "sequence_path": "1938609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938609.protein.info.v11.5.txt",
		        "node_list_path": "1938609.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1938609.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseomonasGilardiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas gilardii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseomonasGilardiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336208.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336208.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336208.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336208.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336208.protein.info.v11.5.txt",
		        "node_list_path": "1336208.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336208.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag274Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:274 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag274Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262888.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262888.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262888.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262888.protein.info.v11.5.txt",
		        "node_list_path": "1262888.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262888.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioPiezophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio piezophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioPiezophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1322246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1322246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1322246.protein.info.v11.5.txt",
		        "node_list_path": "1322246.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumLitorale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium litorale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumLitorale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122201.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122201.protein.info.v11.5.txt",
		        "node_list_path": "1122201.protein.complete.v11.5.txt"
		    }
		]
    )()

def TatlockiaMicdadei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tatlockia micdadei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TatlockiaMicdadei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "451.protein.sequences.v11.5.fa",
		        "enrichment_path": "451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "451.protein.info.v11.5.txt",
		        "node_list_path": "451.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseobacterDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "375451.clusters.info.v11.5.txt",
		        "cluster_tree_path": "375451.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "375451.clusters.proteins.v11.5.txt",
		        "sequence_path": "375451.protein.sequences.v11.5.fa",
		        "enrichment_path": "375451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375451.protein.info.v11.5.txt",
		        "node_list_path": "375451.cluster.nodes.v11.5.txt",
		        "edge_list_path": "375451.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAvermitilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces avermitilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAvermitilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "227882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "227882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "227882.clusters.proteins.v11.5.txt",
		        "sequence_path": "227882.protein.sequences.v11.5.fa",
		        "enrichment_path": "227882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227882.protein.info.v11.5.txt",
		        "node_list_path": "227882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "227882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseibacaCalidilacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseibaca calidilacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseibacaCalidilacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1666912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666912.protein.info.v11.5.txt",
		        "node_list_path": "1666912.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumOtitidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium otitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumOtitidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29321.clusters.proteins.v11.5.txt",
		        "sequence_path": "29321.protein.sequences.v11.5.fa",
		        "enrichment_path": "29321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29321.protein.info.v11.5.txt",
		        "node_list_path": "29321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaTeleogrylliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Erwinia] teleogrylli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaTeleogrylliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1384589.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1384589.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1384589.clusters.proteins.v11.5.txt",
		        "sequence_path": "1384589.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384589.protein.info.v11.5.txt",
		        "node_list_path": "1384589.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1384589.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KutzneriaSp744(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kutzneria sp. 744 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KutzneriaSp744", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "345341.protein.sequences.v11.5.fa",
		        "enrichment_path": "345341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "345341.protein.info.v11.5.txt",
		        "node_list_path": "345341.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp32133(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3213.3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp32133", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855348.protein.info.v11.5.txt",
		        "node_list_path": "1855348.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho201Full4016Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_40_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4016Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798595.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798595.protein.info.v11.5.txt",
		        "node_list_path": "1798595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusElongatusPcc6301Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus elongatus PCC6301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusElongatusPcc6301Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "269084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "269084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "269084.clusters.proteins.v11.5.txt",
		        "sequence_path": "269084.protein.sequences.v11.5.fa",
		        "enrichment_path": "269084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269084.protein.info.v11.5.txt",
		        "node_list_path": "269084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "269084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpKctc13219Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Bacillus] sp. KCTC 13219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpKctc13219Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811976.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811976.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811976.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811976.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811976.protein.info.v11.5.txt",
		        "node_list_path": "1811976.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811976.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioCholeraeO1Biovar(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cholerae O1 biovar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCholeraeO1Biovar", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243277.protein.sequences.v11.5.fa",
		        "enrichment_path": "243277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243277.protein.info.v11.5.txt",
		        "node_list_path": "243277.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeonGw2011Ar20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return archaeon GW2011_AR20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeonGw2011Ar20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1579378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579378.protein.info.v11.5.txt",
		        "node_list_path": "1579378.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusTerrigena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus terrigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusTerrigena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122927.protein.info.v11.5.txt",
		        "node_list_path": "1122927.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusPacaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus pacaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusPacaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776390.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776390.protein.info.v11.5.txt",
		        "node_list_path": "1776390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpA45Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. A45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpA45Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945862.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945862.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945862.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945862.protein.info.v11.5.txt",
		        "node_list_path": "1945862.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945862.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LebetimonasSpJs170(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lebetimonas sp. JS170 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LebetimonasSpJs170", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "990073.protein.sequences.v11.5.fa",
		        "enrichment_path": "990073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990073.protein.info.v11.5.txt",
		        "node_list_path": "990073.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaTestaceaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia testacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaTestaceaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206739.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206739.protein.info.v11.5.txt",
		        "node_list_path": "1206739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellvibrioSpBr(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio sp. BR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioSpBr", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1134474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134474.protein.info.v11.5.txt",
		        "node_list_path": "1134474.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacterium7064(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 70-64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacterium7064", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895733.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895733.protein.info.v11.5.txt",
		        "node_list_path": "1895733.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphaerochaetaGlobosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphaerochaeta globosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerochaetaGlobosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "158189.protein.sequences.v11.5.fa",
		        "enrichment_path": "158189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158189.protein.info.v11.5.txt",
		        "node_list_path": "158189.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumAngustum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium angustum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumAngustum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314292.protein.sequences.v11.5.fa",
		        "enrichment_path": "314292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314292.protein.info.v11.5.txt",
		        "node_list_path": "314292.protein.complete.v11.5.txt"
		    }
		]
    )()

def PvcGroupBacteriumExBugulaNeritinaAb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return PVC group bacterium (ex Bugula neritina AB1) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PvcGroupBacteriumExBugulaNeritinaAb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1868283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1868283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1868283.clusters.proteins.v11.5.txt",
		        "sequence_path": "1868283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1868283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1868283.protein.info.v11.5.txt",
		        "node_list_path": "1868283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1868283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusSp8g7Msg3316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sp. 8G7_MSG3316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSp8g7Msg3316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834191.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834191.protein.info.v11.5.txt",
		        "node_list_path": "1834191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasAlkaliantarcticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas alkaliantarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasAlkaliantarcticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "232346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "232346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "232346.clusters.proteins.v11.5.txt",
		        "sequence_path": "232346.protein.sequences.v11.5.fa",
		        "enrichment_path": "232346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "232346.protein.info.v11.5.txt",
		        "node_list_path": "232346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "232346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DysgonomonasMossiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas mossii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasMossiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742767.clusters.proteins.v11.5.txt",
		        "sequence_path": "742767.protein.sequences.v11.5.fa",
		        "enrichment_path": "742767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742767.protein.info.v11.5.txt",
		        "node_list_path": "742767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatenibacteriumSpCag290Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catenibacterium sp. CAG:290 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenibacteriumSpCag290Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262767.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262767.protein.info.v11.5.txt",
		        "node_list_path": "1262767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwf24518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWF2_45_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwf24518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618539.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618539.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618539.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618539.protein.info.v11.5.txt",
		        "node_list_path": "1618539.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618539.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110052Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110052 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110052Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1570341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1570341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1570341.clusters.proteins.v11.5.txt",
		        "sequence_path": "1570341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570341.protein.info.v11.5.txt",
		        "node_list_path": "1570341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1570341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotorhabdusAustralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photorhabdus australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotorhabdusAustralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "286156.protein.sequences.v11.5.fa",
		        "enrichment_path": "286156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "286156.protein.info.v11.5.txt",
		        "node_list_path": "286156.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaGrahamii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella grahamii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaGrahamii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634504.protein.sequences.v11.5.fa",
		        "enrichment_path": "634504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634504.protein.info.v11.5.txt",
		        "node_list_path": "634504.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaApis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma apis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaApis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1276258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276258.protein.info.v11.5.txt",
		        "node_list_path": "1276258.protein.complete.v11.5.txt"
		    }
		]
    )()

def PisolithusTinctoriusMarx270Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pisolithus tinctorius Marx 270 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PisolithusTinctoriusMarx270Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "870435.clusters.info.v11.5.txt",
		        "cluster_tree_path": "870435.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "870435.clusters.proteins.v11.5.txt",
		        "sequence_path": "870435.protein.sequences.v11.5.fa",
		        "enrichment_path": "870435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "870435.protein.info.v11.5.txt",
		        "node_list_path": "870435.cluster.nodes.v11.5.txt",
		        "edge_list_path": "870435.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterSuis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter suis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSuis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "710393.protein.sequences.v11.5.fa",
		        "enrichment_path": "710393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710393.protein.info.v11.5.txt",
		        "node_list_path": "710393.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacterium13220cm5510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium 13_2_20CM_55_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacterium13220cm5510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805420.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805420.protein.info.v11.5.txt",
		        "node_list_path": "1805420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CenarchaeumSymbiosumACluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cenarchaeum symbiosum A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CenarchaeumSymbiosumACluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "414004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "414004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "414004.clusters.proteins.v11.5.txt",
		        "sequence_path": "414004.protein.sequences.v11.5.fa",
		        "enrichment_path": "414004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "414004.protein.info.v11.5.txt",
		        "node_list_path": "414004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "414004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumGw2011Gwa14311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA1_43_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa14311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618436.protein.info.v11.5.txt",
		        "node_list_path": "1618436.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumCg1024390Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_43_90 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg1024390Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805281.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805281.protein.info.v11.5.txt",
		        "node_list_path": "1805281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumRbg136212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_13_62_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg136212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797269.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797269.protein.info.v11.5.txt",
		        "node_list_path": "1797269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhormidesmisPriestleyiAna(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi Ana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhormidesmisPriestleyiAna", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1666911.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666911.protein.info.v11.5.txt",
		        "node_list_path": "1666911.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaSpDme(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Dme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaSpDme", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "163164.protein.sequences.v11.0.fa",
		        "enrichment_path": "163164.protein.enrichment.terms.v11.0.txt",
		        "info_path": "163164.protein.info.v11.0.txt",
		        "node_list_path": "163164.protein.complete.v11.0.txt"
		    }
		]
    )()

def DietziaAlimentaria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dietzia alimentaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DietziaAlimentaria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1077144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077144.protein.info.v11.5.txt",
		        "node_list_path": "1077144.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfuricurvumSpGwf24489Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. GWF2_44_89 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricurvumSpGwf24489Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802241.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802241.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802241.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802241.protein.info.v11.5.txt",
		        "node_list_path": "1802241.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802241.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfallasGeothermicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfallas geothermicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfallasGeothermicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39060.protein.sequences.v11.5.fa",
		        "enrichment_path": "39060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39060.protein.info.v11.5.txt",
		        "node_list_path": "39060.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnoclostridiumPhytofermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnoclostridium phytofermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoclostridiumPhytofermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "357809.protein.sequences.v11.5.fa",
		        "enrichment_path": "357809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357809.protein.info.v11.5.txt",
		        "node_list_path": "357809.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanothermococcusOkinawensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothermococcus okinawensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermococcusOkinawensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "647113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "647113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "647113.clusters.proteins.v11.5.txt",
		        "sequence_path": "647113.protein.sequences.v11.5.fa",
		        "enrichment_path": "647113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "647113.protein.info.v11.5.txt",
		        "node_list_path": "647113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "647113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfovibrioAggregansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio aggregans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfovibrioAggregansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86166.clusters.proteins.v11.5.txt",
		        "sequence_path": "86166.protein.sequences.v11.5.fa",
		        "enrichment_path": "86166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86166.protein.info.v11.5.txt",
		        "node_list_path": "86166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpR575Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. R57-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpR575Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1610576.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1610576.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1610576.clusters.proteins.v11.5.txt",
		        "sequence_path": "1610576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1610576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1610576.protein.info.v11.5.txt",
		        "node_list_path": "1610576.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1610576.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusAlbusJl83(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus albus JL83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusAlbusJl83", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449352.protein.info.v11.5.txt",
		        "node_list_path": "1449352.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpFsw0699Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. FSW06-99 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpFsw0699Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739113.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739113.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739113.protein.info.v11.5.txt",
		        "node_list_path": "1739113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RamlibacterTataouinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ramlibacter tataouinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RamlibacterTataouinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "365046.clusters.info.v11.5.txt",
		        "cluster_tree_path": "365046.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "365046.clusters.proteins.v11.5.txt",
		        "sequence_path": "365046.protein.sequences.v11.5.fa",
		        "enrichment_path": "365046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "365046.protein.info.v11.5.txt",
		        "node_list_path": "365046.cluster.nodes.v11.5.txt",
		        "edge_list_path": "365046.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpWsm3983(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM3983 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpWsm3983", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1038867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038867.protein.info.v11.5.txt",
		        "node_list_path": "1038867.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3926(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_39_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3926", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802770.protein.info.v11.5.txt",
		        "node_list_path": "1802770.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsplowo202Full5016(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_02_FULL_50_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo202Full5016", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797881.protein.info.v11.5.txt",
		        "node_list_path": "1797881.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCloacimonetesBacterium457255(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Cloacimonetes bacterium 4572_55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCloacimonetesBacterium457255", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1971726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971726.protein.info.v11.5.txt",
		        "node_list_path": "1971726.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudohongiellaSpirulinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudohongiella spirulinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudohongiellaSpirulinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1249552.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1249552.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1249552.clusters.proteins.v11.5.txt",
		        "sequence_path": "1249552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249552.protein.info.v11.5.txt",
		        "node_list_path": "1249552.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1249552.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsplowo2025612Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_02_56_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo2025612Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797874.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797874.protein.info.v11.5.txt",
		        "node_list_path": "1797874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PriciaAntarcticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pricia antarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PriciaAntarcticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641691.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641691.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641691.clusters.proteins.v11.5.txt",
		        "sequence_path": "641691.protein.sequences.v11.5.fa",
		        "enrichment_path": "641691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641691.protein.info.v11.5.txt",
		        "node_list_path": "641691.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641691.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeomicrobiumSpJcm19038(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM19038 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeomicrobiumSpJcm19038", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1460635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460635.protein.info.v11.5.txt",
		        "node_list_path": "1460635.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusErythropolisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus erythropolis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusErythropolisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "234621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "234621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "234621.clusters.proteins.v11.5.txt",
		        "sequence_path": "234621.protein.sequences.v11.5.fa",
		        "enrichment_path": "234621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "234621.protein.info.v11.5.txt",
		        "node_list_path": "234621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "234621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpFxanac1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. FxanaC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpFxanac1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157640.protein.info.v11.5.txt",
		        "node_list_path": "1157640.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloquadratumWalsbyiJ07hqw2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi J07HQW2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloquadratumWalsbyiJ07hqw2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1238425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238425.protein.info.v11.5.txt",
		        "node_list_path": "1238425.protein.complete.v11.5.txt"
		    }
		]
    )()

def AequorivitaSoesokkakensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aequorivita soesokkakensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AequorivitaSoesokkakensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385699.protein.info.v11.5.txt",
		        "node_list_path": "1385699.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCompetibacterDenitrificansRunAD11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Competibacter denitrificans Run_A_D11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCompetibacterDenitrificansRunAD11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1400863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1400863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1400863.clusters.proteins.v11.5.txt",
		        "sequence_path": "1400863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400863.protein.info.v11.5.txt",
		        "node_list_path": "1400863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1400863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LihuaxuellaThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lihuaxuella thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LihuaxuellaThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173111.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173111.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173111.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173111.protein.info.v11.5.txt",
		        "node_list_path": "1173111.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173111.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumGwa24615(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium GWA2_46_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumGwa24615", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802443.protein.info.v11.5.txt",
		        "node_list_path": "1802443.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh8016Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh8016Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "166318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "166318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "166318.clusters.proteins.v11.5.txt",
		        "sequence_path": "166318.protein.sequences.v11.5.fa",
		        "enrichment_path": "166318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "166318.protein.info.v11.5.txt",
		        "node_list_path": "166318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "166318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VagococcusPenaei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vagococcus penaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VagococcusPenaei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "633807.protein.sequences.v11.5.fa",
		        "enrichment_path": "633807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633807.protein.info.v11.5.txt",
		        "node_list_path": "633807.protein.complete.v11.5.txt"
		    }
		]
    )()

def MalasseziaPachydermatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Malassezia pachydermatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalasseziaPachydermatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "77020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "77020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "77020.clusters.proteins.v11.5.txt",
		        "sequence_path": "77020.protein.sequences.v11.5.fa",
		        "enrichment_path": "77020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77020.protein.info.v11.5.txt",
		        "node_list_path": "77020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "77020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaFrigiditurrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella frigiditurris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaFrigiditurrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1542390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1542390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1542390.clusters.proteins.v11.5.txt",
		        "sequence_path": "1542390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1542390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1542390.protein.info.v11.5.txt",
		        "node_list_path": "1542390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1542390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacterium351910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium 351910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacterium351910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "531844.protein.sequences.v11.5.fa",
		        "enrichment_path": "531844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "531844.protein.info.v11.5.txt",
		        "node_list_path": "531844.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDesantisbacteriaBacteriumCg1023846Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG1_02_38_46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg1023846Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817893.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817893.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817893.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817893.protein.info.v11.5.txt",
		        "node_list_path": "1817893.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817893.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpC1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. C-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpC1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262667.clusters.info.v11.5.txt",
		        "cluster_tree_path": "262667.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "262667.clusters.proteins.v11.5.txt",
		        "sequence_path": "262667.protein.sequences.v11.5.fa",
		        "enrichment_path": "262667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262667.protein.info.v11.5.txt",
		        "node_list_path": "262667.cluster.nodes.v11.5.txt",
		        "edge_list_path": "262667.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteribacillusBidgolensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteribacillus bidgolensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteribacillusBidgolensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930129.clusters.proteins.v11.5.txt",
		        "sequence_path": "930129.protein.sequences.v11.5.fa",
		        "enrichment_path": "930129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930129.protein.info.v11.5.txt",
		        "node_list_path": "930129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FomitopsisPinicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fomitopsis pinicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FomitopsisPinicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40483.clusters.proteins.v11.5.txt",
		        "sequence_path": "40483.protein.sequences.v11.5.fa",
		        "enrichment_path": "40483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40483.protein.info.v11.5.txt",
		        "node_list_path": "40483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpYbl2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. YBL2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpYbl2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "484429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "484429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "484429.clusters.proteins.v11.5.txt",
		        "sequence_path": "484429.protein.sequences.v11.5.fa",
		        "enrichment_path": "484429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484429.protein.info.v11.5.txt",
		        "node_list_path": "484429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "484429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumTepidiprofundiDsm19306(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tepidiprofundi DSM 19306 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTepidiprofundiDsm19306", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121338.protein.info.v11.5.txt",
		        "node_list_path": "1121338.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaueraChlorobenzoica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thauera chlorobenzoica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraChlorobenzoica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "96773.protein.sequences.v11.5.fa",
		        "enrichment_path": "96773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "96773.protein.info.v11.5.txt",
		        "node_list_path": "96773.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYonathbacteriaBacteriumRifcsphigho201Full4441Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPHIGHO2_01_FULL_44_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsphigho201Full4441Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802722.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802722.protein.info.v11.5.txt",
		        "node_list_path": "1802722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg167013Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_70_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg167013Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797662.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797662.protein.info.v11.5.txt",
		        "node_list_path": "1797662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasCommunisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas communis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasCommunisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44574.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44574.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44574.clusters.proteins.v11.5.txt",
		        "sequence_path": "44574.protein.sequences.v11.5.fa",
		        "enrichment_path": "44574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44574.protein.info.v11.5.txt",
		        "node_list_path": "44574.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44574.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraMoscoviensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira moscoviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraMoscoviensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42253.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42253.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42253.clusters.proteins.v11.5.txt",
		        "sequence_path": "42253.protein.sequences.v11.5.fa",
		        "enrichment_path": "42253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42253.protein.info.v11.5.txt",
		        "node_list_path": "42253.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42253.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PararheinheimeraTexasensisDsm17496(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pararheinheimera texasensis DSM 17496 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PararheinheimeraTexasensisDsm17496", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123055.protein.info.v11.5.txt",
		        "node_list_path": "1123055.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerosalibacterSpMarseilleP3206(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerosalibacter sp. Marseille-P3206 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerosalibacterSpMarseilleP3206", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871005.protein.info.v11.5.txt",
		        "node_list_path": "1871005.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpUnc41mfs5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. UNC41MFS5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpUnc41mfs5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449046.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449046.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449046.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449046.protein.info.v11.5.txt",
		        "node_list_path": "1449046.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449046.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSepticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium septicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSepticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1504.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1504.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1504.clusters.proteins.v11.5.txt",
		        "sequence_path": "1504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504.protein.info.v11.5.txt",
		        "node_list_path": "1504.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1504.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsAustralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsAustralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1399860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1399860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1399860.clusters.proteins.v11.5.txt",
		        "sequence_path": "1399860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399860.protein.info.v11.5.txt",
		        "node_list_path": "1399860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1399860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpWg5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. WG5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpWg5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1707785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1707785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1707785.protein.info.v11.5.txt",
		        "node_list_path": "1707785.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_02_FULL_46_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817832.protein.info.v11.5.txt",
		        "node_list_path": "1817832.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5436Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_54_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5436Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798482.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798482.protein.info.v11.5.txt",
		        "node_list_path": "1798482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumA52c2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium A52C2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumA52c2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855383.protein.info.v11.5.txt",
		        "node_list_path": "1855383.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanococcusHalocryophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planococcus halocryophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusHalocryophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1215089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215089.protein.info.v11.5.txt",
		        "node_list_path": "1215089.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeorickettsiaHelminthoecaStrOregonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neorickettsia helminthoeca str. Oregon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorickettsiaHelminthoecaStrOregonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1286528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1286528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1286528.clusters.proteins.v11.5.txt",
		        "sequence_path": "1286528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286528.protein.info.v11.5.txt",
		        "node_list_path": "1286528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1286528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurihydrogenibiumAzorense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium azorense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurihydrogenibiumAzorense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "204536.protein.sequences.v11.5.fa",
		        "enrichment_path": "204536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "204536.protein.info.v11.5.txt",
		        "node_list_path": "204536.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseofilumReptotaeniumAo1A(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseofilum reptotaenium AO1-A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseofilumReptotaeniumAo1A", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1925591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1925591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1925591.protein.info.v11.5.txt",
		        "node_list_path": "1925591.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioScophthalmi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio scophthalmi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioScophthalmi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "870967.protein.sequences.v11.5.fa",
		        "enrichment_path": "870967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "870967.protein.info.v11.5.txt",
		        "node_list_path": "870967.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProlixibacterBellariivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prolixibacter bellariivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProlixibacterBellariivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408473.protein.info.v11.5.txt",
		        "node_list_path": "1408473.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumUasb270Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacterium UASB270 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumUasb270Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499967.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499967.protein.info.v11.5.txt",
		        "node_list_path": "1499967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrobaculumCalidifontis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum calidifontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumCalidifontis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "410359.protein.sequences.v11.5.fa",
		        "enrichment_path": "410359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "410359.protein.info.v11.5.txt",
		        "node_list_path": "410359.protein.complete.v11.5.txt"
		    }
		]
    )()

def CognatishimiaMaritima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cognatishimia maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CognatishimiaMaritima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "870908.protein.sequences.v11.5.fa",
		        "enrichment_path": "870908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "870908.protein.info.v11.5.txt",
		        "node_list_path": "870908.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterSpRm8964Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM8964 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSpRm8964Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660074.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660074.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660074.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660074.protein.info.v11.5.txt",
		        "node_list_path": "1660074.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660074.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifcsplowo201Full5410(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO2_01_FULL_54_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201Full5410", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797945.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797945.protein.info.v11.5.txt",
		        "node_list_path": "1797945.protein.complete.v11.5.txt"
		    }
		]
    )()

def PalleroniaMarisminorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Palleronia marisminoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PalleroniaMarisminorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "315423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "315423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "315423.clusters.proteins.v11.5.txt",
		        "sequence_path": "315423.protein.sequences.v11.5.fa",
		        "enrichment_path": "315423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "315423.protein.info.v11.5.txt",
		        "node_list_path": "315423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "315423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AndreprevotiaChitinilyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Andreprevotia chitinilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AndreprevotiaChitinilyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120999.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120999.protein.info.v11.5.txt",
		        "node_list_path": "1120999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoruegeriaLutimarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoruegeria lutimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoruegeriaLutimarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "571298.clusters.info.v11.5.txt",
		        "cluster_tree_path": "571298.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "571298.clusters.proteins.v11.5.txt",
		        "sequence_path": "571298.protein.sequences.v11.5.fa",
		        "enrichment_path": "571298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571298.protein.info.v11.5.txt",
		        "node_list_path": "571298.cluster.nodes.v11.5.txt",
		        "edge_list_path": "571298.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumNctc2916Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum NCTC2916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumNctc2916Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445335.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445335.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445335.clusters.proteins.v11.5.txt",
		        "sequence_path": "445335.protein.sequences.v11.5.fa",
		        "enrichment_path": "445335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445335.protein.info.v11.5.txt",
		        "node_list_path": "445335.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445335.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumOceanosedimentumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium oceanosedimentum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumOceanosedimentumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "465820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "465820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "465820.clusters.proteins.v11.5.txt",
		        "sequence_path": "465820.protein.sequences.v11.5.fa",
		        "enrichment_path": "465820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "465820.protein.info.v11.5.txt",
		        "node_list_path": "465820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "465820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanococcusSpPamc21323(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planococcus sp. PAMC21323 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusSpPamc21323", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1526927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1526927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1526927.protein.info.v11.5.txt",
		        "node_list_path": "1526927.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpJhl9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. JHL9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpJhl9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1276756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1276756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1276756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1276756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276756.protein.info.v11.5.txt",
		        "node_list_path": "1276756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1276756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XylellaFastidiosaPls229Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylella fastidiosa PLS229 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylellaFastidiosaPls229Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1444770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1444770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1444770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1444770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444770.protein.info.v11.5.txt",
		        "node_list_path": "1444770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1444770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasFuscans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas fuscans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasFuscans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "366649.protein.sequences.v11.5.fa",
		        "enrichment_path": "366649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366649.protein.info.v11.5.txt",
		        "node_list_path": "366649.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpB6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. B6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpB6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1570137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1570137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1570137.clusters.proteins.v11.5.txt",
		        "sequence_path": "1570137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570137.protein.info.v11.5.txt",
		        "node_list_path": "1570137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1570137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaPelophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina pelophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaPelophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1638984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1638984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1638984.clusters.proteins.v11.5.txt",
		        "sequence_path": "1638984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638984.protein.info.v11.5.txt",
		        "node_list_path": "1638984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1638984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EdaphobacillusLindanitoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Edaphobacillus lindanitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EdaphobacillusLindanitoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "550447.clusters.info.v11.5.txt",
		        "cluster_tree_path": "550447.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "550447.clusters.proteins.v11.5.txt",
		        "sequence_path": "550447.protein.sequences.v11.5.fa",
		        "enrichment_path": "550447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "550447.protein.info.v11.5.txt",
		        "node_list_path": "550447.cluster.nodes.v11.5.txt",
		        "edge_list_path": "550447.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpUrha0002(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. URHA0002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpUrha0002", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298867.protein.info.v11.5.txt",
		        "node_list_path": "1298867.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumMarinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumMarinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585531.protein.sequences.v11.5.fa",
		        "enrichment_path": "585531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585531.protein.info.v11.5.txt",
		        "node_list_path": "585531.protein.complete.v11.5.txt"
		    }
		]
    )()

def SmittiumCulicisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Smittium culicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmittiumCulicisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "133412.clusters.info.v11.5.txt",
		        "cluster_tree_path": "133412.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "133412.clusters.proteins.v11.5.txt",
		        "sequence_path": "133412.protein.sequences.v11.5.fa",
		        "enrichment_path": "133412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133412.protein.info.v11.5.txt",
		        "node_list_path": "133412.cluster.nodes.v11.5.txt",
		        "edge_list_path": "133412.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpSoil766Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil766 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpSoil766Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736404.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736404.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736404.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736404.protein.info.v11.5.txt",
		        "node_list_path": "1736404.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736404.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysobacterSpongiicolaDsm21749(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter spongiicola DSM 21749 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterSpongiicolaDsm21749", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122188.protein.info.v11.5.txt",
		        "node_list_path": "1122188.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807740.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807740.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807740.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807740.protein.info.v11.5.txt",
		        "node_list_path": "1807740.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807740.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusVulcanalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus vulcanalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusVulcanalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "252246.protein.sequences.v11.5.fa",
		        "enrichment_path": "252246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "252246.protein.info.v11.5.txt",
		        "node_list_path": "252246.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpBl8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. BL8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpBl8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354301.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354301.protein.info.v11.5.txt",
		        "node_list_path": "1354301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevundimonasViscosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas viscosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasViscosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "871741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "871741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "871741.clusters.proteins.v11.5.txt",
		        "sequence_path": "871741.protein.sequences.v11.5.fa",
		        "enrichment_path": "871741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871741.protein.info.v11.5.txt",
		        "node_list_path": "871741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "871741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesSalyersiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides salyersiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSalyersiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121101.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121101.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121101.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121101.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121101.protein.info.v11.5.txt",
		        "node_list_path": "1121101.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121101.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumBarchaimiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium barchaimii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumBarchaimiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420591.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420591.protein.info.v11.5.txt",
		        "node_list_path": "1420591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalogranumSalariumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halogranum salarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalogranumSalariumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210908.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210908.protein.info.v11.5.txt",
		        "node_list_path": "1210908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaSpJc230(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta sp. JC230 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaSpJc230", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1480694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1480694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1480694.protein.info.v11.5.txt",
		        "node_list_path": "1480694.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwc12715(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWC1_27_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwc12715", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802179.protein.info.v11.5.txt",
		        "node_list_path": "1802179.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacteriaceaeBacteriumB14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium B14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacteriaceaeBacteriumB14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1214065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1214065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1214065.clusters.proteins.v11.5.txt",
		        "sequence_path": "1214065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214065.protein.info.v11.5.txt",
		        "node_list_path": "1214065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1214065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RobbsiaAndropogonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Robbsia andropogonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RobbsiaAndropogonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28092.protein.sequences.v11.5.fa",
		        "enrichment_path": "28092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28092.protein.info.v11.5.txt",
		        "node_list_path": "28092.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumGw2011Gwa13413Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA1_34_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa13413Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618434.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618434.protein.info.v11.5.txt",
		        "node_list_path": "1618434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAesculapiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium aesculapii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAesculapiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1329411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1329411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1329411.clusters.proteins.v11.5.txt",
		        "sequence_path": "1329411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1329411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1329411.protein.info.v11.5.txt",
		        "node_list_path": "1329411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1329411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterSpAtcc31444(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter sp. ATCC31444 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterSpAtcc31444", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1806484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806484.protein.info.v11.5.txt",
		        "node_list_path": "1806484.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaBovisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaBovisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094491.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094491.protein.info.v11.5.txt",
		        "node_list_path": "1094491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MusPahariCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mus pahari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusPahariCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10093.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10093.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10093.clusters.proteins.v11.5.txt",
		        "sequence_path": "10093.protein.sequences.v11.5.fa",
		        "enrichment_path": "10093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10093.protein.info.v11.5.txt",
		        "node_list_path": "10093.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10093.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MariprofundusMicogutta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mariprofundus micogutta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MariprofundusMicogutta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1921010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921010.protein.info.v11.5.txt",
		        "node_list_path": "1921010.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumStBin12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium ST_bin12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumStBin12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1978760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1978760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1978760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1978760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978760.protein.info.v11.5.txt",
		        "node_list_path": "1978760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1978760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumCsp18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CSP1-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumCsp18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1640514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1640514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1640514.clusters.proteins.v11.5.txt",
		        "sequence_path": "1640514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640514.protein.info.v11.5.txt",
		        "node_list_path": "1640514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1640514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeishmaniaBraziliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leishmania braziliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeishmaniaBraziliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5660.clusters.proteins.v11.5.txt",
		        "sequence_path": "5660.protein.sequences.v11.5.fa",
		        "enrichment_path": "5660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5660.protein.info.v11.5.txt",
		        "node_list_path": "5660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusBicirculansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus bicirculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusBicirculansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1160721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1160721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1160721.clusters.proteins.v11.5.txt",
		        "sequence_path": "1160721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160721.protein.info.v11.5.txt",
		        "node_list_path": "1160721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1160721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsplowo202Full4337(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_02_FULL_43_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo202Full4337", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798357.protein.info.v11.5.txt",
		        "node_list_path": "1798357.protein.complete.v11.5.txt"
		    }
		]
    )()

def TalaromycesIslandicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces islandicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesIslandicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28573.protein.sequences.v11.5.fa",
		        "enrichment_path": "28573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28573.protein.info.v11.5.txt",
		        "node_list_path": "28573.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaeromassilibacillusSenegalensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaeromassilibacillus senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeromassilibacillusSenegalensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1673717.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673717.protein.info.v11.5.txt",
		        "node_list_path": "1673717.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParapedobacterCompostiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parapedobacter composti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParapedobacterCompostiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "623281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "623281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "623281.clusters.proteins.v11.5.txt",
		        "sequence_path": "623281.protein.sequences.v11.5.fa",
		        "enrichment_path": "623281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "623281.protein.info.v11.5.txt",
		        "node_list_path": "623281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "623281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetohalobiumArabaticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetohalobium arabaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetohalobiumArabaticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "574087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "574087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "574087.clusters.proteins.v11.5.txt",
		        "sequence_path": "574087.protein.sequences.v11.5.fa",
		        "enrichment_path": "574087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574087.protein.info.v11.5.txt",
		        "node_list_path": "574087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "574087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusHammesiiDsm16381(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hammesii DSM 16381 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHammesiiDsm16381", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423753.protein.info.v11.5.txt",
		        "node_list_path": "1423753.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibroporiaRadiculosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibroporia radiculosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibroporiaRadiculosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "599839.clusters.info.v11.5.txt",
		        "cluster_tree_path": "599839.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "599839.clusters.proteins.v11.5.txt",
		        "sequence_path": "599839.protein.sequences.v11.5.fa",
		        "enrichment_path": "599839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "599839.protein.info.v11.5.txt",
		        "node_list_path": "599839.cluster.nodes.v11.5.txt",
		        "edge_list_path": "599839.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LitoreibacterJanthinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Litoreibacter janthinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LitoreibacterJanthinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "670154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "670154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "670154.clusters.proteins.v11.5.txt",
		        "sequence_path": "670154.protein.sequences.v11.5.fa",
		        "enrichment_path": "670154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670154.protein.info.v11.5.txt",
		        "node_list_path": "670154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "670154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumWce2008(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium WCE2008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumWce2008", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945891.protein.info.v11.5.txt",
		        "node_list_path": "1945891.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasRivuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas rivuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasRivuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "648794.clusters.info.v11.5.txt",
		        "cluster_tree_path": "648794.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "648794.clusters.proteins.v11.5.txt",
		        "sequence_path": "648794.protein.sequences.v11.5.fa",
		        "enrichment_path": "648794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "648794.protein.info.v11.5.txt",
		        "node_list_path": "648794.cluster.nodes.v11.5.txt",
		        "edge_list_path": "648794.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesXiamenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesXiamenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "408015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "408015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "408015.clusters.proteins.v11.5.txt",
		        "sequence_path": "408015.protein.sequences.v11.5.fa",
		        "enrichment_path": "408015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408015.protein.info.v11.5.txt",
		        "node_list_path": "408015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "408015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnserBrachyrhynchusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anser brachyrhynchus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnserBrachyrhynchusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "132585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "132585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "132585.clusters.proteins.v11.5.txt",
		        "sequence_path": "132585.protein.sequences.v11.5.fa",
		        "enrichment_path": "132585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "132585.protein.info.v11.5.txt",
		        "node_list_path": "132585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "132585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaDispersaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea dispersa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaDispersaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59814.clusters.proteins.v11.5.txt",
		        "sequence_path": "59814.protein.sequences.v11.5.fa",
		        "enrichment_path": "59814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59814.protein.info.v11.5.txt",
		        "node_list_path": "59814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpCl6colCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. cl6col Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpCl6colCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761878.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761878.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761878.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761878.protein.info.v11.5.txt",
		        "node_list_path": "1761878.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761878.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumHydatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium hydatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumHydatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "991.clusters.proteins.v11.5.txt",
		        "sequence_path": "991.protein.sequences.v11.5.fa",
		        "enrichment_path": "991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "991.protein.info.v11.5.txt",
		        "node_list_path": "991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674848.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674848.protein.info.v11.5.txt",
		        "node_list_path": "1674848.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusSpOl(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. OL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusSpOl", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1888891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1888891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1888891.protein.info.v11.5.txt",
		        "node_list_path": "1888891.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusHaemoglobinophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemoglobinophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusHaemoglobinophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "733.clusters.proteins.v11.5.txt",
		        "sequence_path": "733.protein.sequences.v11.5.fa",
		        "enrichment_path": "733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "733.protein.info.v11.5.txt",
		        "node_list_path": "733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeuconostocMesenteroides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc mesenteroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocMesenteroides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "203120.protein.sequences.v11.5.fa",
		        "enrichment_path": "203120.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203120.protein.info.v11.5.txt",
		        "node_list_path": "203120.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaSp22iis11z7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina sp. 22IIS11z7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaSp22iis11z7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1317122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317122.protein.info.v11.5.txt",
		        "node_list_path": "1317122.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumRifcsphigho202Full4712Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_02_FULL_47_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho202Full4712Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802451.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802451.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802451.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802451.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802451.protein.info.v11.5.txt",
		        "node_list_path": "1802451.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802451.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4748Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_47_48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4748Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798381.protein.info.v11.5.txt",
		        "node_list_path": "1798381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesYeochonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces yeochonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesYeochonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449355.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449355.protein.info.v11.5.txt",
		        "node_list_path": "1449355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophilusRhizosphaeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusRhizosphaeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "492660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "492660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "492660.clusters.proteins.v11.5.txt",
		        "sequence_path": "492660.protein.sequences.v11.5.fa",
		        "enrichment_path": "492660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "492660.protein.info.v11.5.txt",
		        "node_list_path": "492660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "492660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusLutimaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius lutimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusLutimaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005928.protein.info.v11.5.txt",
		        "node_list_path": "1005928.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusLentusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lentus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusLentusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1179226.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1179226.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1179226.clusters.proteins.v11.5.txt",
		        "sequence_path": "1179226.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179226.protein.info.v11.5.txt",
		        "node_list_path": "1179226.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1179226.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GregarinaNiphandrodesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gregarina niphandrodes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GregarinaNiphandrodesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "110365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "110365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "110365.clusters.proteins.v11.5.txt",
		        "sequence_path": "110365.protein.sequences.v11.5.fa",
		        "enrichment_path": "110365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "110365.protein.info.v11.5.txt",
		        "node_list_path": "110365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "110365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GossypiumRaimondii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gossypium raimondii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GossypiumRaimondii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29730.protein.sequences.v11.5.fa",
		        "enrichment_path": "29730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29730.protein.info.v11.5.txt",
		        "node_list_path": "29730.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasSimiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas simiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSimiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "218936.protein.sequences.v11.5.fa",
		        "enrichment_path": "218936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218936.protein.info.v11.5.txt",
		        "node_list_path": "218936.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCcmMd2014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CCM_MD2014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCcmMd2014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1561022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1561022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1561022.clusters.proteins.v11.5.txt",
		        "sequence_path": "1561022.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561022.protein.info.v11.5.txt",
		        "node_list_path": "1561022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1561022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxBoronicumulansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax boronicumulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxBoronicumulansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "436515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "436515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "436515.clusters.proteins.v11.5.txt",
		        "sequence_path": "436515.protein.sequences.v11.5.fa",
		        "enrichment_path": "436515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436515.protein.info.v11.5.txt",
		        "node_list_path": "436515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "436515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaOsloensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella osloensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaOsloensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34062.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34062.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34062.clusters.proteins.v11.5.txt",
		        "sequence_path": "34062.protein.sequences.v11.5.fa",
		        "enrichment_path": "34062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34062.protein.info.v11.5.txt",
		        "node_list_path": "34062.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34062.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaEffusaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia effusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaEffusaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1077974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1077974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1077974.clusters.proteins.v11.5.txt",
		        "sequence_path": "1077974.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077974.protein.info.v11.5.txt",
		        "node_list_path": "1077974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1077974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophobacterSpDg60Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophobacter sp. DG_60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophobacterSpDg60Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703361.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703361.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703361.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703361.protein.info.v11.5.txt",
		        "node_list_path": "1703361.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703361.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSuis05zyh33Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis 05ZYH33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSuis05zyh33Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391295.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391295.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391295.clusters.proteins.v11.5.txt",
		        "sequence_path": "391295.protein.sequences.v11.5.fa",
		        "enrichment_path": "391295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391295.protein.info.v11.5.txt",
		        "node_list_path": "391295.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391295.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpLm2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. LM2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpLm2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1938605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1938605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1938605.clusters.proteins.v11.5.txt",
		        "sequence_path": "1938605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938605.protein.info.v11.5.txt",
		        "node_list_path": "1938605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1938605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycetalesBacteriumActino01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomycetales bacterium Actino_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycetalesBacteriumActino01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674805.protein.info.v11.5.txt",
		        "node_list_path": "1674805.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterAlgicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterAlgicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "443152.clusters.info.v11.5.txt",
		        "cluster_tree_path": "443152.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "443152.clusters.proteins.v11.5.txt",
		        "sequence_path": "443152.protein.sequences.v11.5.fa",
		        "enrichment_path": "443152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443152.protein.info.v11.5.txt",
		        "node_list_path": "443152.cluster.nodes.v11.5.txt",
		        "edge_list_path": "443152.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterMarensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter marensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterMarensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "543877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "543877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "543877.clusters.proteins.v11.5.txt",
		        "sequence_path": "543877.protein.sequences.v11.5.fa",
		        "enrichment_path": "543877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543877.protein.info.v11.5.txt",
		        "node_list_path": "543877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "543877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumReducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum reducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumReducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349161.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349161.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349161.clusters.proteins.v11.5.txt",
		        "sequence_path": "349161.protein.sequences.v11.5.fa",
		        "enrichment_path": "349161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349161.protein.info.v11.5.txt",
		        "node_list_path": "349161.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349161.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterVenetianus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter venetianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterVenetianus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1191460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1191460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1191460.protein.info.v11.5.txt",
		        "node_list_path": "1191460.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc13521Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_35_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc13521Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618892.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618892.protein.info.v11.5.txt",
		        "node_list_path": "1618892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaAbscessusNbrc100374Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia abscessus NBRC 100374 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAbscessusNbrc100374Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206723.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206723.protein.info.v11.5.txt",
		        "node_list_path": "1206723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporocytophagaMyxococcoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporocytophaga myxococcoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporocytophagaMyxococcoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "153721.protein.sequences.v11.5.fa",
		        "enrichment_path": "153721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "153721.protein.info.v11.5.txt",
		        "node_list_path": "153721.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaMaculosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella maculosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMaculosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122986.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122986.protein.info.v11.5.txt",
		        "node_list_path": "1122986.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaAlbaNbrc108234(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia alba NBRC 108234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAlbaNbrc108234", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210063.protein.info.v11.5.txt",
		        "node_list_path": "1210063.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGa0077540Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077540 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077540Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752202.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752202.protein.info.v11.5.txt",
		        "node_list_path": "1752202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TangfeifaniaDiversioriginum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tangfeifania diversioriginum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TangfeifaniaDiversioriginum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1168035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168035.protein.info.v11.5.txt",
		        "node_list_path": "1168035.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacteriumGwa2349Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium GWA2_34_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacteriumGwa2349Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801604.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801604.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801604.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801604.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801604.protein.info.v11.5.txt",
		        "node_list_path": "1801604.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801604.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterovibrioSpJcm19048(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio sp. JCM 19048 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioSpJcm19048", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1460642.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460642.protein.info.v11.5.txt",
		        "node_list_path": "1460642.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full3928(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_39_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full3928", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802690.protein.info.v11.5.txt",
		        "node_list_path": "1802690.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterWinghamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter winghamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterWinghamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "556267.protein.sequences.v11.5.fa",
		        "enrichment_path": "556267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556267.protein.info.v11.5.txt",
		        "node_list_path": "556267.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumScatologenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium scatologenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumScatologenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1548.clusters.proteins.v11.5.txt",
		        "sequence_path": "1548.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548.protein.info.v11.5.txt",
		        "node_list_path": "1548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpMaddingleyCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. Maddingley Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpMaddingleyCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196322.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196322.protein.info.v11.5.txt",
		        "node_list_path": "1196322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OxalobacterFormigenesOxcc13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes OXCC13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OxalobacterFormigenesOxcc13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "556269.protein.sequences.v11.5.fa",
		        "enrichment_path": "556269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556269.protein.info.v11.5.txt",
		        "node_list_path": "556269.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpM412017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. M41(2017) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpM412017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1955065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1955065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1955065.protein.info.v11.5.txt",
		        "node_list_path": "1955065.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusPsychrosaccharolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus psychrosaccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPsychrosaccharolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1174504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1174504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1174504.protein.info.v11.5.txt",
		        "node_list_path": "1174504.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhycicoccusCremeusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phycicoccus cremeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycicoccusCremeusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "587636.clusters.info.v11.5.txt",
		        "cluster_tree_path": "587636.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "587636.clusters.proteins.v11.5.txt",
		        "sequence_path": "587636.protein.sequences.v11.5.fa",
		        "enrichment_path": "587636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "587636.protein.info.v11.5.txt",
		        "node_list_path": "587636.cluster.nodes.v11.5.txt",
		        "edge_list_path": "587636.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpYr266(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. YR266 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpYr266", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884386.protein.info.v11.5.txt",
		        "node_list_path": "1884386.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNecrophorumFunduliformeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum funduliforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNecrophorumFunduliformeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095747.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095747.protein.info.v11.5.txt",
		        "node_list_path": "1095747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HahellaGanghwensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hahella ganghwensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HahellaGanghwensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121935.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121935.protein.info.v11.5.txt",
		        "node_list_path": "1121935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacterium4461Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 44-61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacterium4461Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895838.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895838.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895838.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895838.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895838.protein.info.v11.5.txt",
		        "node_list_path": "1895838.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895838.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickenellaMelleaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickenella mellea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickenellaMelleaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "50990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "50990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "50990.clusters.proteins.v11.5.txt",
		        "sequence_path": "50990.protein.sequences.v11.5.fa",
		        "enrichment_path": "50990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50990.protein.info.v11.5.txt",
		        "node_list_path": "50990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "50990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TupaiaChinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tupaia chinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TupaiaChinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246437.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246437.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246437.clusters.proteins.v11.5.txt",
		        "sequence_path": "246437.protein.sequences.v11.5.fa",
		        "enrichment_path": "246437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246437.protein.info.v11.5.txt",
		        "node_list_path": "246437.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246437.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodothermaceaeBacteriumRaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodothermaceae bacterium RA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodothermaceaeBacteriumRaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1779382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1779382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1779382.clusters.proteins.v11.5.txt",
		        "sequence_path": "1779382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1779382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1779382.protein.info.v11.5.txt",
		        "node_list_path": "1779382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1779382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LepidothrixCoronataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lepidothrix coronata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LepidothrixCoronataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "321398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "321398.clusters.proteins.v11.5.txt",
		        "sequence_path": "321398.protein.sequences.v11.5.fa",
		        "enrichment_path": "321398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321398.protein.info.v11.5.txt",
		        "node_list_path": "321398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "321398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProvidenciaRettgeriDsm1131Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia rettgeri DSM1131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaRettgeriDsm1131Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521000.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521000.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521000.clusters.proteins.v11.5.txt",
		        "sequence_path": "521000.protein.sequences.v11.5.fa",
		        "enrichment_path": "521000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521000.protein.info.v11.5.txt",
		        "node_list_path": "521000.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521000.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GaboniaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gabonia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GaboniaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1686296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1686296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1686296.clusters.proteins.v11.5.txt",
		        "sequence_path": "1686296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686296.protein.info.v11.5.txt",
		        "node_list_path": "1686296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1686296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AuxenochlorellaProtothecoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Auxenochlorella protothecoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AuxenochlorellaProtothecoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3075.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3075.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3075.clusters.proteins.v11.5.txt",
		        "sequence_path": "3075.protein.sequences.v11.5.fa",
		        "enrichment_path": "3075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3075.protein.info.v11.5.txt",
		        "node_list_path": "3075.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3075.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanococcusSpPamc21323Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planococcus sp. PAMC21323 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusSpPamc21323Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1526927.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1526927.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1526927.clusters.proteins.v11.5.txt",
		        "sequence_path": "1526927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1526927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1526927.protein.info.v11.5.txt",
		        "node_list_path": "1526927.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1526927.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrenophoraTeresFTeres01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora teres f. teres 0-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrenophoraTeresFTeres01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "861557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "861557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "861557.clusters.proteins.v11.5.txt",
		        "sequence_path": "861557.protein.sequences.v11.5.fa",
		        "enrichment_path": "861557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861557.protein.info.v11.5.txt",
		        "node_list_path": "861557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "861557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumAap38(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium AAP38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumAap38", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523418.protein.info.v11.5.txt",
		        "node_list_path": "1523418.protein.complete.v11.5.txt"
		    }
		]
    )()

def TsukamurellaTyrosinosolvensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tsukamurella tyrosinosolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TsukamurellaTyrosinosolvensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "57704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "57704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "57704.clusters.proteins.v11.5.txt",
		        "sequence_path": "57704.protein.sequences.v11.5.fa",
		        "enrichment_path": "57704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "57704.protein.info.v11.5.txt",
		        "node_list_path": "57704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "57704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassolituusOleivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassolituus oleivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassolituusOleivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298593.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298593.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298593.protein.info.v11.5.txt",
		        "node_list_path": "1298593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho201Full4115Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_41_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4115Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798598.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798598.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798598.protein.info.v11.5.txt",
		        "node_list_path": "1798598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrosporumCanisCbs113480(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microsporum canis CBS 113480 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrosporumCanisCbs113480", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "554155.protein.sequences.v11.5.fa",
		        "enrichment_path": "554155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "554155.protein.info.v11.5.txt",
		        "node_list_path": "554155.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteibacterYeojuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter yeojuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterYeojuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "345309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "345309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "345309.clusters.proteins.v11.5.txt",
		        "sequence_path": "345309.protein.sequences.v11.5.fa",
		        "enrichment_path": "345309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "345309.protein.info.v11.5.txt",
		        "node_list_path": "345309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "345309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5225(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_52_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5225", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798650.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798650.protein.info.v11.5.txt",
		        "node_list_path": "1798650.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioGalatheaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio galatheae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioGalatheaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "579748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "579748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "579748.clusters.proteins.v11.5.txt",
		        "sequence_path": "579748.protein.sequences.v11.5.fa",
		        "enrichment_path": "579748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579748.protein.info.v11.5.txt",
		        "node_list_path": "579748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "579748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanomassiliicoccalesArchaeonRumenM2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanomassiliicoccales archaeon RumEn M2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomassiliicoccalesArchaeonRumenM2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1713725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1713725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1713725.protein.info.v11.5.txt",
		        "node_list_path": "1713725.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802660.protein.info.v11.5.txt",
		        "node_list_path": "1802660.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusJurassicusNbrc107829(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus jurassicus NBRC 107829 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusJurassicusNbrc107829", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223502.protein.info.v11.5.txt",
		        "node_list_path": "1223502.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusGorillae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus gorillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusGorillae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1243662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1243662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1243662.protein.info.v11.5.txt",
		        "node_list_path": "1243662.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusLehensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus lehensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLehensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246626.protein.info.v11.5.txt",
		        "node_list_path": "1246626.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu036(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU036 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu036", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671651.protein.info.v11.5.txt",
		        "node_list_path": "1671651.protein.complete.v11.5.txt"
		    }
		]
    )()

def PalaeococcusFerrophilusDsm13482(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Palaeococcus ferrophilus DSM 13482 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PalaeococcusFerrophilusDsm13482", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "588319.protein.sequences.v11.5.fa",
		        "enrichment_path": "588319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588319.protein.info.v11.5.txt",
		        "node_list_path": "588319.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf86(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf86", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736242.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736242.protein.info.v11.5.txt",
		        "node_list_path": "1736242.protein.complete.v11.5.txt"
		    }
		]
    )()

def PucciniaCoronataVarAvenaeFSpAvenae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Puccinia coronata var. avenae f. sp. avenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PucciniaCoronataVarAvenaeFSpAvenae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "200324.protein.sequences.v11.5.fa",
		        "enrichment_path": "200324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200324.protein.info.v11.5.txt",
		        "node_list_path": "200324.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslh70737(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70737 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslh70737", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1536775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536775.protein.info.v11.5.txt",
		        "node_list_path": "1536775.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaVinsoniiBerkhoffii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella vinsonii berkhoffii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaVinsoniiBerkhoffii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094497.protein.info.v11.5.txt",
		        "node_list_path": "1094497.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyricimonasSynergisticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyricimonas synergistica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyricimonasSynergisticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121129.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121129.protein.info.v11.5.txt",
		        "node_list_path": "1121129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusMarisflavi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius marisflavi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusMarisflavi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1054996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1054996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1054996.protein.info.v11.5.txt",
		        "node_list_path": "1054996.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaliscomenobacterHydrossisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haliscomenobacter hydrossis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaliscomenobacterHydrossisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "760192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "760192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "760192.clusters.proteins.v11.5.txt",
		        "sequence_path": "760192.protein.sequences.v11.5.fa",
		        "enrichment_path": "760192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "760192.protein.info.v11.5.txt",
		        "node_list_path": "760192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "760192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpJdm601(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JDM601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpJdm601", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "875328.protein.sequences.v11.5.fa",
		        "enrichment_path": "875328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "875328.protein.info.v11.5.txt",
		        "node_list_path": "875328.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumCg10237114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_37_114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumCg10237114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805131.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805131.protein.info.v11.5.txt",
		        "node_list_path": "1805131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynergistalesBacterium5881(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synergistales bacterium 58_81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynergistalesBacterium5881", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635274.protein.info.v11.5.txt",
		        "node_list_path": "1635274.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterPyloriJ99(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori J99 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterPyloriJ99", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "85963.protein.sequences.v11.5.fa",
		        "enrichment_path": "85963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85963.protein.info.v11.5.txt",
		        "node_list_path": "85963.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumGwd23219(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWD2_32_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumGwd23219", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797679.protein.info.v11.5.txt",
		        "node_list_path": "1797679.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumSpA49(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. A49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumSpA49", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945861.protein.info.v11.5.txt",
		        "node_list_path": "1945861.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaribacterVadi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter vadi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterVadi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1774273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1774273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1774273.protein.info.v11.5.txt",
		        "node_list_path": "1774273.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusDaliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus daliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusDaliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "745820.protein.sequences.v11.5.fa",
		        "enrichment_path": "745820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745820.protein.info.v11.5.txt",
		        "node_list_path": "745820.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGuanduensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces guanduensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGuanduensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "310781.protein.sequences.v11.5.fa",
		        "enrichment_path": "310781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "310781.protein.info.v11.5.txt",
		        "node_list_path": "310781.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesIndistinctus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes indistinctus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesIndistinctus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742725.protein.sequences.v11.5.fa",
		        "enrichment_path": "742725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742725.protein.info.v11.5.txt",
		        "node_list_path": "742725.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanobacteriumSpPcc7702(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Cyanobacterium sp. PCC7702 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "CyanobacteriumSpPcc7702", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173021.protein.sequences.v11.0.fa",
		        "enrichment_path": "1173021.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1173021.protein.info.v11.0.txt",
		        "node_list_path": "1173021.protein.complete.v11.0.txt"
		    }
		]
    )()

def ProvidenciaStuartiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia stuartii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaStuartiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471874.clusters.proteins.v11.5.txt",
		        "sequence_path": "471874.protein.sequences.v11.5.fa",
		        "enrichment_path": "471874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471874.protein.info.v11.5.txt",
		        "node_list_path": "471874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HesseltinellaVesiculosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hesseltinella vesiculosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HesseltinellaVesiculosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "101127.protein.sequences.v11.5.fa",
		        "enrichment_path": "101127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101127.protein.info.v11.5.txt",
		        "node_list_path": "101127.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesScopuliridis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces scopuliridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesScopuliridis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1440053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1440053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1440053.protein.info.v11.5.txt",
		        "node_list_path": "1440053.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaSpCag105Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea sp. CAG:105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaSpCag105Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262872.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262872.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262872.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262872.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262872.protein.info.v11.5.txt",
		        "node_list_path": "1262872.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262872.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnsiferShofinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer shofinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferShofinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1850094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850094.protein.info.v11.5.txt",
		        "node_list_path": "1850094.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyadobacterSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "659014.protein.sequences.v11.5.fa",
		        "enrichment_path": "659014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "659014.protein.info.v11.5.txt",
		        "node_list_path": "659014.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCf332(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. cf332 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCf332", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761804.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761804.protein.info.v11.5.txt",
		        "node_list_path": "1761804.protein.complete.v11.5.txt"
		    }
		]
    )()

def FabibacterMisakiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fabibacter misakiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FabibacterMisakiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1563681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1563681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1563681.protein.info.v11.5.txt",
		        "node_list_path": "1563681.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSp1nla3e(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 1NLA3E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp1nla3e", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "666686.protein.sequences.v11.5.fa",
		        "enrichment_path": "666686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "666686.protein.info.v11.5.txt",
		        "node_list_path": "666686.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucunaPruriens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucuna pruriens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucunaPruriens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "157652.protein.sequences.v11.5.fa",
		        "enrichment_path": "157652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157652.protein.info.v11.5.txt",
		        "node_list_path": "157652.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4412Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_44_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4412Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802308.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802308.protein.info.v11.5.txt",
		        "node_list_path": "1802308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpS6262Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. S6-262 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpS6262Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1166340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1166340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1166340.clusters.proteins.v11.5.txt",
		        "sequence_path": "1166340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166340.protein.info.v11.5.txt",
		        "node_list_path": "1166340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1166340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpH3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. H3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpH3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1402135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1402135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1402135.protein.info.v11.5.txt",
		        "node_list_path": "1402135.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaThermophilaTm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina thermophila TM-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaThermophilaTm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "523844.clusters.info.v11.5.txt",
		        "cluster_tree_path": "523844.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "523844.clusters.proteins.v11.5.txt",
		        "sequence_path": "523844.protein.sequences.v11.5.fa",
		        "enrichment_path": "523844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523844.protein.info.v11.5.txt",
		        "node_list_path": "523844.cluster.nodes.v11.5.txt",
		        "edge_list_path": "523844.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PavoCristatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pavo cristatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PavoCristatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9049.clusters.proteins.v11.5.txt",
		        "sequence_path": "9049.protein.sequences.v11.5.fa",
		        "enrichment_path": "9049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9049.protein.info.v11.5.txt",
		        "node_list_path": "9049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumSubrubescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium subrubescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumSubrubescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1316194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1316194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1316194.clusters.proteins.v11.5.txt",
		        "sequence_path": "1316194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1316194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1316194.protein.info.v11.5.txt",
		        "node_list_path": "1316194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1316194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumNalgiovenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium nalgiovense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumNalgiovenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "60175.clusters.info.v11.5.txt",
		        "cluster_tree_path": "60175.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "60175.clusters.proteins.v11.5.txt",
		        "sequence_path": "60175.protein.sequences.v11.5.fa",
		        "enrichment_path": "60175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60175.protein.info.v11.5.txt",
		        "node_list_path": "60175.cluster.nodes.v11.5.txt",
		        "edge_list_path": "60175.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MacrostomumLignanoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Macrostomum lignano Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacrostomumLignanoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "282301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "282301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "282301.clusters.proteins.v11.5.txt",
		        "sequence_path": "282301.protein.sequences.v11.5.fa",
		        "enrichment_path": "282301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "282301.protein.info.v11.5.txt",
		        "node_list_path": "282301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "282301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumShinjukuenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium shinjukuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumShinjukuenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398694.clusters.proteins.v11.5.txt",
		        "sequence_path": "398694.protein.sequences.v11.5.fa",
		        "enrichment_path": "398694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398694.protein.info.v11.5.txt",
		        "node_list_path": "398694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKitasatonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kitasatonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKitasatonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423767.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423767.protein.info.v11.5.txt",
		        "node_list_path": "1423767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DictyoglomusTurgidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dictyoglomus turgidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DictyoglomusTurgidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "515635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "515635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "515635.clusters.proteins.v11.5.txt",
		        "sequence_path": "515635.protein.sequences.v11.5.fa",
		        "enrichment_path": "515635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515635.protein.info.v11.5.txt",
		        "node_list_path": "515635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "515635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpAls9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. ALS9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpAls9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805819.protein.info.v11.5.txt",
		        "node_list_path": "1805819.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParvimonasSpOralTaxon110StrF0139(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parvimonas sp. oral taxon 110 str. F0139 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvimonasSpOralTaxon110StrF0139", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "767100.protein.sequences.v11.5.fa",
		        "enrichment_path": "767100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767100.protein.info.v11.5.txt",
		        "node_list_path": "767100.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusSpJcm18860(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus sp. JCM 18860 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusSpJcm18860", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1306159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306159.protein.info.v11.5.txt",
		        "node_list_path": "1306159.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermocrinisSpGbs(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermocrinis sp. GBS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocrinisSpGbs", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1313265.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313265.protein.info.v11.5.txt",
		        "node_list_path": "1313265.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpMmlr14010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MMLR14_010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpMmlr14010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1898743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898743.protein.info.v11.5.txt",
		        "node_list_path": "1898743.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacterDaltoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter daltonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterDaltoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316067.clusters.proteins.v11.5.txt",
		        "sequence_path": "316067.protein.sequences.v11.5.fa",
		        "enrichment_path": "316067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316067.protein.info.v11.5.txt",
		        "node_list_path": "316067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BizioniaEchiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bizionia echini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BizioniaEchiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649333.clusters.proteins.v11.5.txt",
		        "sequence_path": "649333.protein.sequences.v11.5.fa",
		        "enrichment_path": "649333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649333.protein.info.v11.5.txt",
		        "node_list_path": "649333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaCetiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella ceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaCetiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "759620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "759620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "759620.clusters.proteins.v11.5.txt",
		        "sequence_path": "759620.protein.sequences.v11.5.fa",
		        "enrichment_path": "759620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759620.protein.info.v11.5.txt",
		        "node_list_path": "759620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "759620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusOryzisoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus oryzisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusOryzisoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1850517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1850517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1850517.clusters.proteins.v11.5.txt",
		        "sequence_path": "1850517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850517.protein.info.v11.5.txt",
		        "node_list_path": "1850517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1850517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProvidenciaAlcalifaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaAlcalifaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "520999.clusters.info.v11.0.txt",
		        "cluster_tree_path": "520999.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "520999.clusters.proteins.v11.0.txt",
		        "sequence_path": "520999.protein.sequences.v11.0.fa",
		        "enrichment_path": "520999.protein.enrichment.terms.v11.0.txt",
		        "info_path": "520999.protein.info.v11.0.txt",
		        "node_list_path": "520999.cluster.nodes.v11.0.txt",
		        "edge_list_path": "520999.protein.cluster.v11.0.txt"
		    }
		]
    )()

def DesulfobulbusPropionicusDsm2032Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus propionicus DSM 2032 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbusPropionicusDsm2032Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "577650.clusters.info.v11.5.txt",
		        "cluster_tree_path": "577650.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "577650.clusters.proteins.v11.5.txt",
		        "sequence_path": "577650.protein.sequences.v11.5.fa",
		        "enrichment_path": "577650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "577650.protein.info.v11.5.txt",
		        "node_list_path": "577650.cluster.nodes.v11.5.txt",
		        "edge_list_path": "577650.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GramellaEchinicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gramella echinicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaEchinicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121931.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121931.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121931.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121931.protein.info.v11.5.txt",
		        "node_list_path": "1121931.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121931.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrigoribacteriumSpLeaf186Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf186 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrigoribacteriumSpLeaf186Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736293.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736293.protein.info.v11.5.txt",
		        "node_list_path": "1736293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpinaciaOleracea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spinacia oleracea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpinaciaOleracea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3562.protein.sequences.v11.5.fa",
		        "enrichment_path": "3562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3562.protein.info.v11.5.txt",
		        "node_list_path": "3562.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaProfusaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella profusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaProfusaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125712.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125712.protein.info.v11.5.txt",
		        "node_list_path": "1125712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CohnellaSp6021052837(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cohnella sp. 6021052837 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CohnellaSp6021052837", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816691.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816691.protein.info.v11.5.txt",
		        "node_list_path": "1816691.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinomonasAtrocyanea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinomonas atrocyanea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinomonasAtrocyanea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37927.protein.sequences.v11.5.fa",
		        "enrichment_path": "37927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37927.protein.info.v11.5.txt",
		        "node_list_path": "37927.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusCarbonariusItem5010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus carbonarius ITEM 5010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusCarbonariusItem5010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "602072.protein.sequences.v11.5.fa",
		        "enrichment_path": "602072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "602072.protein.info.v11.5.txt",
		        "node_list_path": "602072.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesDoreiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides dorei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesDoreiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "357276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "357276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "357276.clusters.proteins.v11.5.txt",
		        "sequence_path": "357276.protein.sequences.v11.5.fa",
		        "enrichment_path": "357276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357276.protein.info.v11.5.txt",
		        "node_list_path": "357276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "357276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyronemaOmphalodesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyronema omphalodes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyronemaOmphalodesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "337075.clusters.info.v11.5.txt",
		        "cluster_tree_path": "337075.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "337075.clusters.proteins.v11.5.txt",
		        "sequence_path": "337075.protein.sequences.v11.5.fa",
		        "enrichment_path": "337075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "337075.protein.info.v11.5.txt",
		        "node_list_path": "337075.cluster.nodes.v11.5.txt",
		        "edge_list_path": "337075.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacterium4081(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 40-81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacterium4081", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895835.protein.info.v11.5.txt",
		        "node_list_path": "1895835.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhanerochaeteCarnosaHhb10118Sp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phanerochaete carnosa HHB-10118-sp graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhanerochaeteCarnosaHhb10118Sp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "650164.protein.sequences.v11.5.fa",
		        "enrichment_path": "650164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "650164.protein.info.v11.5.txt",
		        "node_list_path": "650164.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPeliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas peli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPeliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "592361.clusters.info.v11.5.txt",
		        "cluster_tree_path": "592361.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "592361.clusters.proteins.v11.5.txt",
		        "sequence_path": "592361.protein.sequences.v11.5.fa",
		        "enrichment_path": "592361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592361.protein.info.v11.5.txt",
		        "node_list_path": "592361.cluster.nodes.v11.5.txt",
		        "edge_list_path": "592361.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZootermopsisNevadensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zootermopsis nevadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZootermopsisNevadensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "136037.protein.sequences.v11.5.fa",
		        "enrichment_path": "136037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "136037.protein.info.v11.5.txt",
		        "node_list_path": "136037.protein.complete.v11.5.txt"
		    }
		]
    )()

def EchinicolaPacificaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Echinicola pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EchinicolaPacificaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121859.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121859.protein.info.v11.5.txt",
		        "node_list_path": "1121859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusLicheniformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus licheniformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLicheniformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "279010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "279010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "279010.clusters.proteins.v11.5.txt",
		        "sequence_path": "279010.protein.sequences.v11.5.fa",
		        "enrichment_path": "279010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279010.protein.info.v11.5.txt",
		        "node_list_path": "279010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "279010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumQ1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium Q-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumQ1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1492281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1492281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1492281.clusters.proteins.v11.5.txt",
		        "sequence_path": "1492281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1492281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1492281.protein.info.v11.5.txt",
		        "node_list_path": "1492281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1492281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzoarcusSpCib(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azoarcus sp. CIB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzoarcusSpCib", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "198107.protein.sequences.v11.5.fa",
		        "enrichment_path": "198107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198107.protein.info.v11.5.txt",
		        "node_list_path": "198107.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoculleusSpSdbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus sp. SDB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusSpSdbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735326.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735326.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735326.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735326.protein.info.v11.5.txt",
		        "node_list_path": "1735326.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735326.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaApsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola APS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaApsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "107806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "107806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "107806.clusters.proteins.v11.5.txt",
		        "sequence_path": "107806.protein.sequences.v11.5.fa",
		        "enrichment_path": "107806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "107806.protein.info.v11.5.txt",
		        "node_list_path": "107806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "107806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SmittiumMegazygosporumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Smittium megazygosporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmittiumMegazygosporumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "133381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "133381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "133381.clusters.proteins.v11.5.txt",
		        "sequence_path": "133381.protein.sequences.v11.5.fa",
		        "enrichment_path": "133381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133381.protein.info.v11.5.txt",
		        "node_list_path": "133381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "133381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736213.protein.info.v11.5.txt",
		        "node_list_path": "1736213.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrococcusJejuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrococcus jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrococcusJejuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "399736.clusters.info.v11.5.txt",
		        "cluster_tree_path": "399736.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "399736.clusters.proteins.v11.5.txt",
		        "sequence_path": "399736.protein.sequences.v11.5.fa",
		        "enrichment_path": "399736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399736.protein.info.v11.5.txt",
		        "node_list_path": "399736.cluster.nodes.v11.5.txt",
		        "edge_list_path": "399736.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HespelliaStercorisuisDsm15480(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hespellia stercorisuis DSM 15480 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HespelliaStercorisuisDsm15480", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121950.protein.info.v11.5.txt",
		        "node_list_path": "1121950.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyadobacterPsychrophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter psychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterPsychrophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "651661.protein.sequences.v11.5.fa",
		        "enrichment_path": "651661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "651661.protein.info.v11.5.txt",
		        "node_list_path": "651661.protein.complete.v11.5.txt"
		    }
		]
    )()

def EquusCaballusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Equus caballus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EquusCaballusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9796.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9796.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9796.clusters.proteins.v11.5.txt",
		        "sequence_path": "9796.protein.sequences.v11.5.fa",
		        "enrichment_path": "9796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9796.protein.info.v11.5.txt",
		        "node_list_path": "9796.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9796.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophilusSpTwe2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. TWE2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusSpTwe2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1662285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662285.protein.info.v11.5.txt",
		        "node_list_path": "1662285.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterSpL(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. L graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSpL", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "944547.protein.sequences.v11.5.fa",
		        "enrichment_path": "944547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944547.protein.info.v11.5.txt",
		        "node_list_path": "944547.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMicrarchaeotaArchaeonCg1025541Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_55_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1025541Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805251.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805251.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805251.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805251.protein.info.v11.5.txt",
		        "node_list_path": "1805251.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805251.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusPhoenicis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus phoenicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusPhoenicis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1476583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1476583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1476583.protein.info.v11.5.txt",
		        "node_list_path": "1476583.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867007(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867007", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1659201.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659201.protein.info.v11.5.txt",
		        "node_list_path": "1659201.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrococcusYayanosiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus yayanosii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusYayanosiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "529709.clusters.info.v11.5.txt",
		        "cluster_tree_path": "529709.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "529709.clusters.proteins.v11.5.txt",
		        "sequence_path": "529709.protein.sequences.v11.5.fa",
		        "enrichment_path": "529709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529709.protein.info.v11.5.txt",
		        "node_list_path": "529709.cluster.nodes.v11.5.txt",
		        "edge_list_path": "529709.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesUrogenitalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesUrogenitalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "103621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "103621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "103621.clusters.proteins.v11.5.txt",
		        "sequence_path": "103621.protein.sequences.v11.5.fa",
		        "enrichment_path": "103621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103621.protein.info.v11.5.txt",
		        "node_list_path": "103621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "103621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnicoccusHospitalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignicoccus hospitalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnicoccusHospitalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "453591.protein.sequences.v11.5.fa",
		        "enrichment_path": "453591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "453591.protein.info.v11.5.txt",
		        "node_list_path": "453591.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumAqs3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium AqS3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumAqs3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1732023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1732023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1732023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1732023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1732023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1732023.protein.info.v11.5.txt",
		        "node_list_path": "1732023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1732023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaLecithinolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema lecithinolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaLecithinolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321815.protein.info.v11.5.txt",
		        "node_list_path": "1321815.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrassicaRapa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brassica rapa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrassicaRapa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3711.protein.sequences.v11.5.fa",
		        "enrichment_path": "3711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3711.protein.info.v11.5.txt",
		        "node_list_path": "3711.protein.complete.v11.5.txt"
		    }
		]
    )()

def CynoglossusSemilaevis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cynoglossus semilaevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CynoglossusSemilaevis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "244447.protein.sequences.v11.5.fa",
		        "enrichment_path": "244447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244447.protein.info.v11.5.txt",
		        "node_list_path": "244447.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumAlbertimagni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium albertimagni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumAlbertimagni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1156935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156935.protein.info.v11.5.txt",
		        "node_list_path": "1156935.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735685.protein.info.v11.5.txt",
		        "node_list_path": "1735685.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassobacterStenotrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacter stenotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobacterStenotrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266809.protein.sequences.v11.5.fa",
		        "enrichment_path": "266809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266809.protein.info.v11.5.txt",
		        "node_list_path": "266809.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusColumbaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus columbae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusColumbaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121865.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121865.protein.info.v11.5.txt",
		        "node_list_path": "1121865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FriedmanniomycesEndolithicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Friedmanniomyces endolithicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FriedmanniomycesEndolithicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "329885.protein.sequences.v11.5.fa",
		        "enrichment_path": "329885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "329885.protein.info.v11.5.txt",
		        "node_list_path": "329885.protein.complete.v11.5.txt"
		    }
		]
    )()

def DiaportheAmpelina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Diaporthe ampelina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiaportheAmpelina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1214573.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214573.protein.info.v11.5.txt",
		        "node_list_path": "1214573.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumDtu084(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU084 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumDtu084", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671642.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671642.protein.info.v11.5.txt",
		        "node_list_path": "1671642.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumYrb3002Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium YRB3002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumYrb3002Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520819.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520819.protein.info.v11.5.txt",
		        "node_list_path": "1520819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumSpRoot344Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root344 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumSpRoot344Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736521.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736521.protein.info.v11.5.txt",
		        "node_list_path": "1736521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaMorhuaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella morhuae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaMorhuaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "365591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "365591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "365591.clusters.proteins.v11.5.txt",
		        "sequence_path": "365591.protein.sequences.v11.5.fa",
		        "enrichment_path": "365591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "365591.protein.info.v11.5.txt",
		        "node_list_path": "365591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "365591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumScgcAaa027G08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium SCGC AAA027-G08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumScgcAaa027G08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "938698.protein.sequences.v11.5.fa",
		        "enrichment_path": "938698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938698.protein.info.v11.5.txt",
		        "node_list_path": "938698.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerobrancaCaliforniensisDsm14826(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobranca californiensis DSM 14826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobrancaCaliforniensisDsm14826", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120989.protein.info.v11.5.txt",
		        "node_list_path": "1120989.protein.complete.v11.5.txt"
		    }
		]
    )()

def FriedmanniellaLuteola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Friedmanniella luteola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FriedmanniellaLuteola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546871.protein.sequences.v11.5.fa",
		        "enrichment_path": "546871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546871.protein.info.v11.5.txt",
		        "node_list_path": "546871.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumUlceribovisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium ulceribovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumUlceribovisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121370.protein.info.v11.5.txt",
		        "node_list_path": "1121370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KinetoplastibacteriumBlastocrithidiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium blastocrithidii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KinetoplastibacteriumBlastocrithidiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208923.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208923.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208923.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208923.protein.info.v11.5.txt",
		        "node_list_path": "1208923.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208923.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full3410Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_34_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full3410Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802205.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802205.protein.info.v11.5.txt",
		        "node_list_path": "1802205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasFimiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas fimi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasFimiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "590998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "590998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "590998.clusters.proteins.v11.5.txt",
		        "sequence_path": "590998.protein.sequences.v11.5.fa",
		        "enrichment_path": "590998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "590998.protein.info.v11.5.txt",
		        "node_list_path": "590998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "590998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaStewartiiSubspStewartiiDc283Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea stewartii subsp. stewartii DC283 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaStewartiiSubspStewartiiDc283Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "660596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "660596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "660596.clusters.proteins.v11.5.txt",
		        "sequence_path": "660596.protein.sequences.v11.5.fa",
		        "enrichment_path": "660596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660596.protein.info.v11.5.txt",
		        "node_list_path": "660596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "660596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioHydrothermalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio hydrothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioHydrothermalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121451.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121451.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121451.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121451.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121451.protein.info.v11.5.txt",
		        "node_list_path": "1121451.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121451.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrialbaceaeArchaeonTcBr11E2g8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon Tc-Br11_E2g8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaceaeArchaeonTcBr11E2g8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729464.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729464.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729464.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729464.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729464.protein.info.v11.5.txt",
		        "node_list_path": "1729464.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729464.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisRifamycinicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis rifamycinica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisRifamycinicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "287986.clusters.info.v11.5.txt",
		        "cluster_tree_path": "287986.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "287986.clusters.proteins.v11.5.txt",
		        "sequence_path": "287986.protein.sequences.v11.5.fa",
		        "enrichment_path": "287986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "287986.protein.info.v11.5.txt",
		        "node_list_path": "287986.cluster.nodes.v11.5.txt",
		        "edge_list_path": "287986.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpDd13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpDd13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777881.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777881.protein.info.v11.5.txt",
		        "node_list_path": "1777881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesRadicidentisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces radicidentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesRadicidentisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "111015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "111015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "111015.clusters.proteins.v11.5.txt",
		        "sequence_path": "111015.protein.sequences.v11.5.fa",
		        "enrichment_path": "111015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "111015.protein.info.v11.5.txt",
		        "node_list_path": "111015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "111015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaribiusSalinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribius salinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribiusSalinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313368.protein.sequences.v11.5.fa",
		        "enrichment_path": "313368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313368.protein.info.v11.5.txt",
		        "node_list_path": "313368.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumLongumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium longum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumLongumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216816.clusters.proteins.v11.5.txt",
		        "sequence_path": "216816.protein.sequences.v11.5.fa",
		        "enrichment_path": "216816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216816.protein.info.v11.5.txt",
		        "node_list_path": "216816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumGwa15235(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWA1_52_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumGwa15235", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797383.protein.info.v11.5.txt",
		        "node_list_path": "1797383.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumGwe23210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWE2_32_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumGwe23210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797681.protein.info.v11.5.txt",
		        "node_list_path": "1797681.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumRbg16439Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_43_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg16439Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802596.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802596.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802596.protein.info.v11.5.txt",
		        "node_list_path": "1802596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChoanephoraCucurbitarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Choanephora cucurbitarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChoanephoraCucurbitarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "101091.protein.sequences.v11.5.fa",
		        "enrichment_path": "101091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101091.protein.info.v11.5.txt",
		        "node_list_path": "101091.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusGraminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus graminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusGraminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "189425.protein.sequences.v11.5.fa",
		        "enrichment_path": "189425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189425.protein.info.v11.5.txt",
		        "node_list_path": "189425.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlumeriaGraminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blumeria graminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlumeriaGraminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34373.protein.sequences.v11.5.fa",
		        "enrichment_path": "34373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34373.protein.info.v11.5.txt",
		        "node_list_path": "34373.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfitibacterAlkalitoleransDsm16504(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfitibacter alkalitolerans DSM 16504 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitibacterAlkalitoleransDsm16504", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304884.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304884.protein.info.v11.5.txt",
		        "node_list_path": "1304884.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizopusDelemarCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus delemar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopusDelemarCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936053.clusters.proteins.v11.5.txt",
		        "sequence_path": "936053.protein.sequences.v11.5.fa",
		        "enrichment_path": "936053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936053.protein.info.v11.5.txt",
		        "node_list_path": "936053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusPseudofirmusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus pseudofirmus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPseudofirmusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398511.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398511.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398511.clusters.proteins.v11.5.txt",
		        "sequence_path": "398511.protein.sequences.v11.5.fa",
		        "enrichment_path": "398511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398511.protein.info.v11.5.txt",
		        "node_list_path": "398511.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398511.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TateyamariaOmphalii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tateyamaria omphalii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TateyamariaOmphalii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "299262.protein.sequences.v11.5.fa",
		        "enrichment_path": "299262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299262.protein.info.v11.5.txt",
		        "node_list_path": "299262.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSuccinicansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium succinicans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSuccinicansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1450525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1450525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1450525.clusters.proteins.v11.5.txt",
		        "sequence_path": "1450525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450525.protein.info.v11.5.txt",
		        "node_list_path": "1450525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1450525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnimonasNigrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnimonas nigrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnimonasNigrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336245.protein.info.v11.5.txt",
		        "node_list_path": "1336245.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrincolaNitratireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrincola nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrincolaNitratireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229521.protein.info.v11.5.txt",
		        "node_list_path": "1229521.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsplowo2124711(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO2_12_47_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo2124711", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798301.protein.info.v11.5.txt",
		        "node_list_path": "1798301.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterCibarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter cibarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterCibarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "282669.protein.sequences.v11.5.fa",
		        "enrichment_path": "282669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "282669.protein.info.v11.5.txt",
		        "node_list_path": "282669.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusUrinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus urinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusUrinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "866775.protein.sequences.v11.5.fa",
		        "enrichment_path": "866775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866775.protein.info.v11.5.txt",
		        "node_list_path": "866775.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaRufipogonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza rufipogon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaRufipogonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4529.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4529.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4529.clusters.proteins.v11.5.txt",
		        "sequence_path": "4529.protein.sequences.v11.5.fa",
		        "enrichment_path": "4529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4529.protein.info.v11.5.txt",
		        "node_list_path": "4529.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4529.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpRv15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. RV15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpRv15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "909626.protein.sequences.v11.5.fa",
		        "enrichment_path": "909626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "909626.protein.info.v11.5.txt",
		        "node_list_path": "909626.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophobotulusGlycolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophobotulus glycolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophobotulusGlycolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "645991.protein.sequences.v11.5.fa",
		        "enrichment_path": "645991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645991.protein.info.v11.5.txt",
		        "node_list_path": "645991.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag386Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:386 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag386Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262925.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262925.protein.info.v11.5.txt",
		        "node_list_path": "1262925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesVulgatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides vulgatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesVulgatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "435590.protein.sequences.v11.5.fa",
		        "enrichment_path": "435590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435590.protein.info.v11.5.txt",
		        "node_list_path": "435590.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpAsf356(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ASF356 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpAsf356", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "97138.protein.sequences.v11.5.fa",
		        "enrichment_path": "97138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97138.protein.info.v11.5.txt",
		        "node_list_path": "97138.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumCpb6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium CPB6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumCpb6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1572656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1572656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1572656.clusters.proteins.v11.5.txt",
		        "sequence_path": "1572656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1572656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1572656.protein.info.v11.5.txt",
		        "node_list_path": "1572656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1572656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeurosporaCrassaOr74a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neurospora crassa OR74A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeurosporaCrassaOr74a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "367110.protein.sequences.v11.5.fa",
		        "enrichment_path": "367110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "367110.protein.info.v11.5.txt",
		        "node_list_path": "367110.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumDolichum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium dolichum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumDolichum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "428127.protein.sequences.v11.5.fa",
		        "enrichment_path": "428127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428127.protein.info.v11.5.txt",
		        "node_list_path": "428127.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaMaceacherniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella maceachernii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaMaceacherniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "466.clusters.info.v11.5.txt",
		        "cluster_tree_path": "466.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "466.clusters.proteins.v11.5.txt",
		        "sequence_path": "466.protein.sequences.v11.5.fa",
		        "enrichment_path": "466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "466.protein.info.v11.5.txt",
		        "node_list_path": "466.cluster.nodes.v11.5.txt",
		        "edge_list_path": "466.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacterium1747faaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 1747FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacterium1747faaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "457421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "457421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "457421.clusters.proteins.v11.5.txt",
		        "sequence_path": "457421.protein.sequences.v11.5.fa",
		        "enrichment_path": "457421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457421.protein.info.v11.5.txt",
		        "node_list_path": "457421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "457421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasSpBhbn044(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. BHBN044 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSpBhbn044", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280947.protein.info.v11.5.txt",
		        "node_list_path": "1280947.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "455632.protein.sequences.v11.5.fa",
		        "enrichment_path": "455632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "455632.protein.info.v11.5.txt",
		        "node_list_path": "455632.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium maris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1224163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224163.protein.info.v11.5.txt",
		        "node_list_path": "1224163.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoplanesMissouriensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes missouriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesMissouriensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "512565.clusters.info.v11.5.txt",
		        "cluster_tree_path": "512565.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "512565.clusters.proteins.v11.5.txt",
		        "sequence_path": "512565.protein.sequences.v11.5.fa",
		        "enrichment_path": "512565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512565.protein.info.v11.5.txt",
		        "node_list_path": "512565.cluster.nodes.v11.5.txt",
		        "edge_list_path": "512565.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFontisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium fontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFontisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1124188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1124188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1124188.clusters.proteins.v11.5.txt",
		        "sequence_path": "1124188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1124188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1124188.protein.info.v11.5.txt",
		        "node_list_path": "1124188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1124188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaCatarrhalisBbh18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella catarrhalis BBH18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaCatarrhalisBbh18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236608.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236608.protein.info.v11.5.txt",
		        "node_list_path": "1236608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidithiobacillusFerrivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithiobacillusFerrivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743299.clusters.proteins.v11.5.txt",
		        "sequence_path": "743299.protein.sequences.v11.5.fa",
		        "enrichment_path": "743299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743299.protein.info.v11.5.txt",
		        "node_list_path": "743299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAc2029(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAc2029", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1458462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458462.protein.info.v11.5.txt",
		        "node_list_path": "1458462.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPinihumiDsm23905Jcm16419(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus pinihumi DSM 23905 JCM 16419 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPinihumiDsm23905Jcm16419", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122924.protein.info.v11.5.txt",
		        "node_list_path": "1122924.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHarrisonbacteriaBacteriumRifcsphigho202Full4216Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPHIGHO2_02_FULL_42_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsphigho202Full4216Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798404.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798404.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798404.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798404.protein.info.v11.5.txt",
		        "node_list_path": "1798404.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798404.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParascardoviaDenticolensIpla20019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parascardovia denticolens IPLA20019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParascardoviaDenticolensIpla20019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193128.protein.info.v11.5.txt",
		        "node_list_path": "1193128.protein.complete.v11.5.txt"
		    }
		]
    )()

def AestuariimicrobiumKwangyangenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aestuariimicrobium kwangyangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AestuariimicrobiumKwangyangenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120954.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120954.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120954.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120954.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120954.protein.info.v11.5.txt",
		        "node_list_path": "1120954.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120954.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpAdety(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. AdeTY graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpAdety", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1391647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391647.protein.info.v11.5.txt",
		        "node_list_path": "1391647.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumFlavescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumFlavescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776.protein.info.v11.5.txt",
		        "node_list_path": "1776.protein.complete.v11.5.txt"
		    }
		]
    )()

def LagierellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lagierella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LagierellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1689303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1689303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1689303.protein.info.v11.5.txt",
		        "node_list_path": "1689303.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPneumoniaeR6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae R6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPneumoniaeR6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "171101.clusters.info.v11.5.txt",
		        "cluster_tree_path": "171101.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "171101.clusters.proteins.v11.5.txt",
		        "sequence_path": "171101.protein.sequences.v11.5.fa",
		        "enrichment_path": "171101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "171101.protein.info.v11.5.txt",
		        "node_list_path": "171101.cluster.nodes.v11.5.txt",
		        "edge_list_path": "171101.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlsenellaUmbonataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella umbonata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaUmbonataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "604330.clusters.info.v11.5.txt",
		        "cluster_tree_path": "604330.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "604330.clusters.proteins.v11.5.txt",
		        "sequence_path": "604330.protein.sequences.v11.5.fa",
		        "enrichment_path": "604330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "604330.protein.info.v11.5.txt",
		        "node_list_path": "604330.cluster.nodes.v11.5.txt",
		        "edge_list_path": "604330.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusEllipticusCbs70779Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ellipticus CBS 707.79 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusEllipticusCbs70779Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1448320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1448320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1448320.clusters.proteins.v11.5.txt",
		        "sequence_path": "1448320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448320.protein.info.v11.5.txt",
		        "node_list_path": "1448320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1448320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerosalibacterSpNd1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerosalibacter sp. ND1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerosalibacterSpNd1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1347392.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1347392.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1347392.clusters.proteins.v11.5.txt",
		        "sequence_path": "1347392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347392.protein.info.v11.5.txt",
		        "node_list_path": "1347392.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1347392.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TilletiopsisWashingtonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tilletiopsis washingtonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TilletiopsisWashingtonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "58919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "58919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "58919.clusters.proteins.v11.5.txt",
		        "sequence_path": "58919.protein.sequences.v11.5.fa",
		        "enrichment_path": "58919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58919.protein.info.v11.5.txt",
		        "node_list_path": "58919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "58919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumKh2t8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium KH2T8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumKh2t8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855400.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855400.protein.info.v11.5.txt",
		        "node_list_path": "1855400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioCholeraeO1BiovarCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cholerae O1 biovar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCholeraeO1BiovarCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243277.clusters.proteins.v11.5.txt",
		        "sequence_path": "243277.protein.sequences.v11.5.fa",
		        "enrichment_path": "243277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243277.protein.info.v11.5.txt",
		        "node_list_path": "243277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LiberibacterAmericanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter americanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LiberibacterAmericanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1261131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261131.protein.info.v11.5.txt",
		        "node_list_path": "1261131.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf24014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_40_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf24014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797347.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797347.protein.info.v11.5.txt",
		        "node_list_path": "1797347.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylocapsaAureaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylocapsa aurea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocapsaAureaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "663610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "663610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "663610.clusters.proteins.v11.5.txt",
		        "sequence_path": "663610.protein.sequences.v11.5.fa",
		        "enrichment_path": "663610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663610.protein.info.v11.5.txt",
		        "node_list_path": "663610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "663610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TermitomycesSpJ132(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Termitomyces sp. J132 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TermitomycesSpJ132", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1306850.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306850.protein.info.v11.5.txt",
		        "node_list_path": "1306850.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterovibrioCoraliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio coralii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioCoraliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "294935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "294935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "294935.clusters.proteins.v11.5.txt",
		        "sequence_path": "294935.protein.sequences.v11.5.fa",
		        "enrichment_path": "294935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294935.protein.info.v11.5.txt",
		        "node_list_path": "294935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "294935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLk11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. LK11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLk11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1390395.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1390395.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1390395.clusters.proteins.v11.5.txt",
		        "sequence_path": "1390395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1390395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1390395.protein.info.v11.5.txt",
		        "node_list_path": "1390395.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1390395.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceaniovalibusGuishaninsulaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceaniovalibus guishaninsula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceaniovalibusGuishaninsulaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231392.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231392.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231392.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231392.protein.info.v11.5.txt",
		        "node_list_path": "1231392.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231392.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpOralTaxon431Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. oral taxon 431 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpOralTaxon431Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "712633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "712633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "712633.clusters.proteins.v11.5.txt",
		        "sequence_path": "712633.protein.sequences.v11.5.fa",
		        "enrichment_path": "712633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712633.protein.info.v11.5.txt",
		        "node_list_path": "712633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "712633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpJhl9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. JHL9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpJhl9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1276756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276756.protein.info.v11.5.txt",
		        "node_list_path": "1276756.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoniliophthoraRoreri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moniliophthora roreri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoniliophthoraRoreri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "221103.protein.sequences.v11.5.fa",
		        "enrichment_path": "221103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221103.protein.info.v11.5.txt",
		        "node_list_path": "221103.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumVulnerisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium vulneris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumVulnerisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "547163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "547163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "547163.clusters.proteins.v11.5.txt",
		        "sequence_path": "547163.protein.sequences.v11.5.fa",
		        "enrichment_path": "547163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547163.protein.info.v11.5.txt",
		        "node_list_path": "547163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "547163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevundimonasDiminutaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas diminuta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasDiminutaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "293.clusters.proteins.v11.5.txt",
		        "sequence_path": "293.protein.sequences.v11.5.fa",
		        "enrichment_path": "293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "293.protein.info.v11.5.txt",
		        "node_list_path": "293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAntri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus antri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAntri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525309.protein.sequences.v11.5.fa",
		        "enrichment_path": "525309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525309.protein.info.v11.5.txt",
		        "node_list_path": "525309.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1750560.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1750560.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1750560.clusters.proteins.v11.5.txt",
		        "sequence_path": "1750560.protein.sequences.v11.5.fa",
		        "enrichment_path": "1750560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1750560.protein.info.v11.5.txt",
		        "node_list_path": "1750560.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1750560.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFutsaiiJcm17355Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus futsaii JCM 17355 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFutsaiiJcm17355Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423818.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423818.protein.info.v11.5.txt",
		        "node_list_path": "1423818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpRac07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. RAC07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpRac07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1842537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842537.protein.info.v11.5.txt",
		        "node_list_path": "1842537.protein.complete.v11.5.txt"
		    }
		]
    )()

def AliterellaAtlanticaCena595(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aliterella atlantica CENA595 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliterellaAtlanticaCena595", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618023.protein.info.v11.5.txt",
		        "node_list_path": "1618023.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1045854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1045854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1045854.clusters.proteins.v11.5.txt",
		        "sequence_path": "1045854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045854.protein.info.v11.5.txt",
		        "node_list_path": "1045854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1045854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConiochaetaPulveraceaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coniochaeta pulveracea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConiochaetaPulveraceaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "177199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "177199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "177199.clusters.proteins.v11.5.txt",
		        "sequence_path": "177199.protein.sequences.v11.5.fa",
		        "enrichment_path": "177199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "177199.protein.info.v11.5.txt",
		        "node_list_path": "177199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "177199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnaporthiopsisPoaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnaporthiopsis poae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnaporthiopsisPoaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "148304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "148304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "148304.clusters.proteins.v11.5.txt",
		        "sequence_path": "148304.protein.sequences.v11.5.fa",
		        "enrichment_path": "148304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "148304.protein.info.v11.5.txt",
		        "node_list_path": "148304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "148304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumGwa25416(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_54_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumGwa25416", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798420.protein.info.v11.5.txt",
		        "node_list_path": "1798420.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioCincinnatiensisDsm19608(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cincinnatiensis DSM 19608 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCincinnatiensisDsm19608", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123491.protein.info.v11.5.txt",
		        "node_list_path": "1123491.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioNereis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio nereis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioNereis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "693.protein.sequences.v11.5.fa",
		        "enrichment_path": "693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693.protein.info.v11.5.txt",
		        "node_list_path": "693.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpUnccl20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. UNCCL20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpUnccl20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502773.protein.info.v11.5.txt",
		        "node_list_path": "1502773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumPaludicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium paludicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumPaludicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "300019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "300019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "300019.clusters.proteins.v11.5.txt",
		        "sequence_path": "300019.protein.sequences.v11.5.fa",
		        "enrichment_path": "300019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "300019.protein.info.v11.5.txt",
		        "node_list_path": "300019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "300019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaPoulsonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma poulsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaPoulsonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2138.protein.sequences.v11.5.fa",
		        "enrichment_path": "2138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2138.protein.info.v11.5.txt",
		        "node_list_path": "2138.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPoribacteriaBacteriumWga3g(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Poribacteria bacterium WGA-3G graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPoribacteriaBacteriumWga3g", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1104566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104566.protein.info.v11.5.txt",
		        "node_list_path": "1104566.protein.complete.v11.5.txt"
		    }
		]
    )()

def WallemiaSebiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wallemia sebi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WallemiaSebiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "148960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "148960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "148960.clusters.proteins.v11.5.txt",
		        "sequence_path": "148960.protein.sequences.v11.5.fa",
		        "enrichment_path": "148960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "148960.protein.info.v11.5.txt",
		        "node_list_path": "148960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "148960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitratireductorBasaltis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitratireductor basaltis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratireductorBasaltis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "472175.protein.sequences.v11.5.fa",
		        "enrichment_path": "472175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472175.protein.info.v11.5.txt",
		        "node_list_path": "472175.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgreiaPratensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agreia pratensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgreiaPratensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "150121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "150121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "150121.clusters.proteins.v11.5.txt",
		        "sequence_path": "150121.protein.sequences.v11.5.fa",
		        "enrichment_path": "150121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150121.protein.info.v11.5.txt",
		        "node_list_path": "150121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "150121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteusVulgarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteus vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteusVulgarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585.clusters.proteins.v11.5.txt",
		        "sequence_path": "585.protein.sequences.v11.5.fa",
		        "enrichment_path": "585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585.protein.info.v11.5.txt",
		        "node_list_path": "585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcticibacterEurypsychrophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcticibacter eurypsychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcticibacterEurypsychrophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434752.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434752.protein.info.v11.5.txt",
		        "node_list_path": "1434752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaPertussis18323(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella pertussis 18323 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaPertussis18323", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "568706.protein.sequences.v11.5.fa",
		        "enrichment_path": "568706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568706.protein.info.v11.5.txt",
		        "node_list_path": "568706.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionCpr3Bacterium4484211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR3 bacterium 4484_211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionCpr3Bacterium4484211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1968527.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1968527.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1968527.clusters.proteins.v11.5.txt",
		        "sequence_path": "1968527.protein.sequences.v11.5.fa",
		        "enrichment_path": "1968527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1968527.protein.info.v11.5.txt",
		        "node_list_path": "1968527.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1968527.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NannocystisExedens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nannocystis exedens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NannocystisExedens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "54.protein.sequences.v11.5.fa",
		        "enrichment_path": "54.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54.protein.info.v11.5.txt",
		        "node_list_path": "54.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaloranaerobacterAzorensisH53214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caloranaerobacter azorensis H53214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloranaerobacterAzorensisH53214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1156417.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1156417.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1156417.clusters.proteins.v11.5.txt",
		        "sequence_path": "1156417.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156417.protein.info.v11.5.txt",
		        "node_list_path": "1156417.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1156417.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1316444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1316444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1316444.clusters.proteins.v11.5.txt",
		        "sequence_path": "1316444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1316444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1316444.protein.info.v11.5.txt",
		        "node_list_path": "1316444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1316444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSenmaizukeiDsm21775Nbrc103853(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus senmaizukei DSM 21775 NBRC 103853 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSenmaizukeiDsm21775Nbrc103853", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423803.protein.info.v11.5.txt",
		        "node_list_path": "1423803.protein.complete.v11.5.txt"
		    }
		]
    )()

def AegilopsTauschiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aegilops tauschii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AegilopsTauschiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37682.clusters.proteins.v11.5.txt",
		        "sequence_path": "37682.protein.sequences.v11.5.fa",
		        "enrichment_path": "37682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37682.protein.info.v11.5.txt",
		        "node_list_path": "37682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesGaoshouyii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces gaoshouyii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesGaoshouyii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1960083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1960083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1960083.protein.info.v11.5.txt",
		        "node_list_path": "1960083.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrombidiumDelienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrombidium deliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrombidiumDelienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "299467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "299467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "299467.clusters.proteins.v11.5.txt",
		        "sequence_path": "299467.protein.sequences.v11.5.fa",
		        "enrichment_path": "299467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299467.protein.info.v11.5.txt",
		        "node_list_path": "299467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "299467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaMtcc5279Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida MTCC5279 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaMtcc5279Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1240350.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1240350.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1240350.clusters.proteins.v11.5.txt",
		        "sequence_path": "1240350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1240350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1240350.protein.info.v11.5.txt",
		        "node_list_path": "1240350.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1240350.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMosselii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mosselii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMosselii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1388763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1388763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1388763.protein.info.v11.5.txt",
		        "node_list_path": "1388763.protein.complete.v11.5.txt"
		    }
		]
    )()

def GynuellaSunshinyiiYc6258Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gynuella sunshinyii YC6258 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GynuellaSunshinyiiYc6258Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1445510.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1445510.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1445510.clusters.proteins.v11.5.txt",
		        "sequence_path": "1445510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1445510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1445510.protein.info.v11.5.txt",
		        "node_list_path": "1445510.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1445510.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterFetusSubspFetus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. fetus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterFetusSubspFetus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32019.protein.sequences.v11.5.fa",
		        "enrichment_path": "32019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32019.protein.info.v11.5.txt",
		        "node_list_path": "32019.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlaciecolaPallidulaDsm14239Acam615Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola pallidula DSM 14239 ACAM 615 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaPallidulaDsm14239Acam615Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121922.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121922.protein.info.v11.5.txt",
		        "node_list_path": "1121922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyalangiumMinutumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyalangium minutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyalangiumMinutumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "394096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "394096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "394096.clusters.proteins.v11.5.txt",
		        "sequence_path": "394096.protein.sequences.v11.5.fa",
		        "enrichment_path": "394096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394096.protein.info.v11.5.txt",
		        "node_list_path": "394096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "394096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBeckwithbacteriaBacteriumRbg13429(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium RBG_13_42_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumRbg13429", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797457.protein.info.v11.5.txt",
		        "node_list_path": "1797457.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSp37ma(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 37MA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp37ma", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1132442.protein.sequences.v11.5.fa",
		        "enrichment_path": "1132442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1132442.protein.info.v11.5.txt",
		        "node_list_path": "1132442.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24218(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_42_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24218", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618821.protein.info.v11.5.txt",
		        "node_list_path": "1618821.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusGlaucusCbs51665Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus glaucus CBS 516.65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusGlaucusCbs51665Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1160497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1160497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1160497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1160497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160497.protein.info.v11.5.txt",
		        "node_list_path": "1160497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1160497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SediminibacteriumSpOr53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium sp. OR53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacteriumSpOr53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "925409.clusters.info.v11.5.txt",
		        "cluster_tree_path": "925409.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "925409.clusters.proteins.v11.5.txt",
		        "sequence_path": "925409.protein.sequences.v11.5.fa",
		        "enrichment_path": "925409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "925409.protein.info.v11.5.txt",
		        "node_list_path": "925409.cluster.nodes.v11.5.txt",
		        "edge_list_path": "925409.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSp63713Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. 63-713 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSp63713Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895900.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895900.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895900.protein.info.v11.5.txt",
		        "node_list_path": "1895900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaRuckeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia ruckeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaRuckeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29486.protein.sequences.v11.5.fa",
		        "enrichment_path": "29486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29486.protein.info.v11.5.txt",
		        "node_list_path": "29486.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpOy3wo11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. OY3WO11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpOy3wo11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1835723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1835723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1835723.protein.info.v11.5.txt",
		        "node_list_path": "1835723.protein.complete.v11.5.txt"
		    }
		]
    )()

def PopulusAlbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Populus alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PopulusAlbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43335.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43335.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43335.clusters.proteins.v11.5.txt",
		        "sequence_path": "43335.protein.sequences.v11.5.fa",
		        "enrichment_path": "43335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43335.protein.info.v11.5.txt",
		        "node_list_path": "43335.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43335.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKuenenbacteriaBacteriumRifcsplowo202Full4216(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium RIFCSPLOWO2_02_FULL_42_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumRifcsplowo202Full4216", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798564.protein.info.v11.5.txt",
		        "node_list_path": "1798564.protein.complete.v11.5.txt"
		    }
		]
    )()

def OpitutusTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Opitutus terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpitutusTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "452637.protein.sequences.v11.5.fa",
		        "enrichment_path": "452637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452637.protein.info.v11.5.txt",
		        "node_list_path": "452637.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSilvensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces silvensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSilvensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1765722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765722.protein.info.v11.5.txt",
		        "node_list_path": "1765722.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumSpCf444Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. CF444 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumSpCf444Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144319.protein.info.v11.5.txt",
		        "node_list_path": "1144319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseoluteusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseoluteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseoluteusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29306.clusters.proteins.v11.5.txt",
		        "sequence_path": "29306.protein.sequences.v11.5.fa",
		        "enrichment_path": "29306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29306.protein.info.v11.5.txt",
		        "node_list_path": "29306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumVerticillioidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium verticillioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumVerticillioidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "117187.clusters.info.v11.5.txt",
		        "cluster_tree_path": "117187.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "117187.clusters.proteins.v11.5.txt",
		        "sequence_path": "117187.protein.sequences.v11.5.fa",
		        "enrichment_path": "117187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "117187.protein.info.v11.5.txt",
		        "node_list_path": "117187.cluster.nodes.v11.5.txt",
		        "edge_list_path": "117187.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusManliponensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus manliponensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusManliponensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "574376.protein.sequences.v11.5.fa",
		        "enrichment_path": "574376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574376.protein.info.v11.5.txt",
		        "node_list_path": "574376.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus pini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236976.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236976.protein.info.v11.5.txt",
		        "node_list_path": "1236976.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallionellalesBacteriumGwa26018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_60_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallionellalesBacteriumGwa26018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798247.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798247.protein.info.v11.5.txt",
		        "node_list_path": "1798247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalococcusSp197aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halococcus sp. 197A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusSp197aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1197130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1197130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1197130.clusters.proteins.v11.5.txt",
		        "sequence_path": "1197130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197130.protein.info.v11.5.txt",
		        "node_list_path": "1197130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1197130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSelenitireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus selenitireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSelenitireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "439292.protein.sequences.v11.5.fa",
		        "enrichment_path": "439292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439292.protein.info.v11.5.txt",
		        "node_list_path": "439292.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaludibacterJiangxiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paludibacter jiangxiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaludibacterJiangxiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "681398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "681398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "681398.clusters.proteins.v11.5.txt",
		        "sequence_path": "681398.protein.sequences.v11.5.fa",
		        "enrichment_path": "681398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "681398.protein.info.v11.5.txt",
		        "node_list_path": "681398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "681398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumSanguinicancriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium sanguinicancri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumSanguinicancriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "875932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "875932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "875932.clusters.proteins.v11.5.txt",
		        "sequence_path": "875932.protein.sequences.v11.5.fa",
		        "enrichment_path": "875932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "875932.protein.info.v11.5.txt",
		        "node_list_path": "875932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "875932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseobacterSpMed193Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. MED193 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterSpMed193Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314262.clusters.proteins.v11.5.txt",
		        "sequence_path": "314262.protein.sequences.v11.5.fa",
		        "enrichment_path": "314262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314262.protein.info.v11.5.txt",
		        "node_list_path": "314262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacteriumGwa2349(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium GWA2_34_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacteriumGwa2349", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801604.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801604.protein.info.v11.5.txt",
		        "node_list_path": "1801604.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumCg2303716(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium CG2_30_37_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumCg2303716", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805401.protein.info.v11.5.txt",
		        "node_list_path": "1805401.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasSpLeaf148Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Leaf148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasSpLeaf148Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736275.protein.info.v11.5.txt",
		        "node_list_path": "1736275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaVirensGv298Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma virens Gv29-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaVirensGv298Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "413071.clusters.info.v11.5.txt",
		        "cluster_tree_path": "413071.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "413071.clusters.proteins.v11.5.txt",
		        "sequence_path": "413071.protein.sequences.v11.5.fa",
		        "enrichment_path": "413071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "413071.protein.info.v11.5.txt",
		        "node_list_path": "413071.cluster.nodes.v11.5.txt",
		        "edge_list_path": "413071.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudozymaHubeiensisSy62Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma hubeiensis SY62 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudozymaHubeiensisSy62Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1305764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1305764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1305764.clusters.proteins.v11.5.txt",
		        "sequence_path": "1305764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305764.protein.info.v11.5.txt",
		        "node_list_path": "1305764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1305764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GilliamellaIntestini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gilliamella intestini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilliamellaIntestini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798183.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798183.protein.info.v11.5.txt",
		        "node_list_path": "1798183.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterGlycinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter glycinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterGlycinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582702.protein.sequences.v11.5.fa",
		        "enrichment_path": "582702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582702.protein.info.v11.5.txt",
		        "node_list_path": "582702.protein.complete.v11.5.txt"
		    }
		]
    )()

def AliivibrioSp1s175Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliivibrio sp. 1S175 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliivibrioSp1s175Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1840087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1840087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1840087.clusters.proteins.v11.5.txt",
		        "sequence_path": "1840087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1840087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1840087.protein.info.v11.5.txt",
		        "node_list_path": "1840087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1840087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasMaltophilia5bai2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia 5BAI2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasMaltophilia5bai2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1429851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1429851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1429851.clusters.proteins.v11.5.txt",
		        "sequence_path": "1429851.protein.sequences.v11.5.fa",
		        "enrichment_path": "1429851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1429851.protein.info.v11.5.txt",
		        "node_list_path": "1429851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1429851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HolosporaElegansE1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Holospora elegans E1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HolosporaElegansE1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1427503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1427503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1427503.protein.info.v11.5.txt",
		        "node_list_path": "1427503.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumHungaricum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium hungaricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumHungaricum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "454006.protein.sequences.v11.5.fa",
		        "enrichment_path": "454006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454006.protein.info.v11.5.txt",
		        "node_list_path": "454006.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag65(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag65", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262994.protein.info.v11.5.txt",
		        "node_list_path": "1262994.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusShizuokensisNbrc103103(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus shizuokensis NBRC 103103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusShizuokensisNbrc103103", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220573.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220573.protein.info.v11.5.txt",
		        "node_list_path": "1220573.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalogeometricumBorinquense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halogeometricum borinquense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalogeometricumBorinquense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469382.protein.sequences.v11.5.fa",
		        "enrichment_path": "469382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469382.protein.info.v11.5.txt",
		        "node_list_path": "469382.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusClavatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus clavatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusClavatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5057.protein.sequences.v11.5.fa",
		        "enrichment_path": "5057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5057.protein.info.v11.5.txt",
		        "node_list_path": "5057.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumMaritimumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum maritimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumMaritimumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349785.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349785.protein.info.v11.5.txt",
		        "node_list_path": "1349785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaBerlinense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema berlinense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaBerlinense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "225004.protein.sequences.v11.5.fa",
		        "enrichment_path": "225004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225004.protein.info.v11.5.txt",
		        "node_list_path": "225004.protein.complete.v11.5.txt"
		    }
		]
    )()

def NematocidaParisiiErtm3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nematocida parisii ERTm3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NematocidaParisiiErtm3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935791.protein.sequences.v11.5.fa",
		        "enrichment_path": "935791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935791.protein.info.v11.5.txt",
		        "node_list_path": "935791.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinomicrobiumOceani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinomicrobium oceani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinomicrobiumOceani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150368.protein.info.v11.5.txt",
		        "node_list_path": "1150368.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807739.protein.info.v11.5.txt",
		        "node_list_path": "1807739.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlycomycesSambucusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glycomyces sambucus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlycomycesSambucusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "380244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "380244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "380244.clusters.proteins.v11.5.txt",
		        "sequence_path": "380244.protein.sequences.v11.5.fa",
		        "enrichment_path": "380244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380244.protein.info.v11.5.txt",
		        "node_list_path": "380244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "380244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPortieraAleyrodidarumBtBHrsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portiera aleyrodidarum BT-B-HRs Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPortieraAleyrodidarumBtBHrsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206109.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206109.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206109.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206109.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206109.protein.info.v11.5.txt",
		        "node_list_path": "1206109.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206109.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumSpRoot495Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root495 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumSpRoot495Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736550.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736550.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736550.protein.info.v11.5.txt",
		        "node_list_path": "1736550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_01_FULL_44_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798407.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798407.protein.info.v11.5.txt",
		        "node_list_path": "1798407.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasMontana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas montana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasMontana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1843236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1843236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1843236.protein.info.v11.5.txt",
		        "node_list_path": "1843236.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumVenenatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium venenatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumVenenatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56646.protein.sequences.v11.5.fa",
		        "enrichment_path": "56646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56646.protein.info.v11.5.txt",
		        "node_list_path": "56646.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumGwa25416Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_54_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumGwa25416Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798420.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798420.protein.info.v11.5.txt",
		        "node_list_path": "1798420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NipponiaNippon(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nipponia nippon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NipponiaNippon", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "128390.protein.sequences.v11.5.fa",
		        "enrichment_path": "128390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "128390.protein.info.v11.5.txt",
		        "node_list_path": "128390.protein.complete.v11.5.txt"
		    }
		]
    )()

def MuricaudaLutaonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Muricauda lutaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuricaudaLutaonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "516051.protein.sequences.v11.5.fa",
		        "enrichment_path": "516051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "516051.protein.info.v11.5.txt",
		        "node_list_path": "516051.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaDentiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria dentiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaDentiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "194197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "194197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "194197.clusters.proteins.v11.5.txt",
		        "sequence_path": "194197.protein.sequences.v11.5.fa",
		        "enrichment_path": "194197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "194197.protein.info.v11.5.txt",
		        "node_list_path": "194197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "194197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnteractinococcusHelveticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enteractinococcus helveticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnteractinococcusHelveticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1837282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1837282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1837282.protein.info.v11.5.txt",
		        "node_list_path": "1837282.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusTerreusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus terreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusTerreusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33178.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33178.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33178.clusters.proteins.v11.5.txt",
		        "sequence_path": "33178.protein.sequences.v11.5.fa",
		        "enrichment_path": "33178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33178.protein.info.v11.5.txt",
		        "node_list_path": "33178.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33178.protein.cluster.v11.5.txt"
		    }
		]
    )()

def Bacterium3363Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium 336/3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Bacterium3363Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1664068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1664068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1664068.clusters.proteins.v11.5.txt",
		        "sequence_path": "1664068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1664068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1664068.protein.info.v11.5.txt",
		        "node_list_path": "1664068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1664068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaMucosaC102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria mucosa C102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaMucosaC102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "435832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "435832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "435832.clusters.proteins.v11.5.txt",
		        "sequence_path": "435832.protein.sequences.v11.5.fa",
		        "enrichment_path": "435832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435832.protein.info.v11.5.txt",
		        "node_list_path": "435832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "435832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChiloSuppressalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chilo suppressalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChiloSuppressalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "168631.protein.sequences.v11.5.fa",
		        "enrichment_path": "168631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "168631.protein.info.v11.5.txt",
		        "node_list_path": "168631.protein.complete.v11.5.txt"
		    }
		]
    )()

def DenitrovibrioAcetiphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Denitrovibrio acetiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DenitrovibrioAcetiphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "522772.protein.sequences.v11.5.fa",
		        "enrichment_path": "522772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "522772.protein.info.v11.5.txt",
		        "node_list_path": "522772.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolimonasVariicolorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solimonas variicoloris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolimonasVariicolorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123256.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123256.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123256.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123256.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123256.protein.info.v11.5.txt",
		        "node_list_path": "1123256.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123256.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGeothermarchaeotaArchaeonJdfr13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Geothermarchaeota archaeon JdFR-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGeothermarchaeotaArchaeonJdfr13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935120.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935120.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935120.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935120.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935120.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935120.protein.info.v11.5.txt",
		        "node_list_path": "1935120.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935120.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanococcusDonghaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planococcus donghaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusDonghaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "933115.protein.sequences.v11.5.fa",
		        "enrichment_path": "933115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933115.protein.info.v11.5.txt",
		        "node_list_path": "933115.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmodiumKnowlesiStrainHCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium knowlesi strain H Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumKnowlesiStrainHCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5851.clusters.proteins.v11.5.txt",
		        "sequence_path": "5851.protein.sequences.v11.5.fa",
		        "enrichment_path": "5851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5851.protein.info.v11.5.txt",
		        "node_list_path": "5851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaHelicoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma helicoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaHelicoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216938.protein.sequences.v11.5.fa",
		        "enrichment_path": "216938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216938.protein.info.v11.5.txt",
		        "node_list_path": "216938.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemmobacterAquatilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmobacter aquatilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmobacterAquatilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "933059.protein.sequences.v11.5.fa",
		        "enrichment_path": "933059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933059.protein.info.v11.5.txt",
		        "node_list_path": "933059.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumGw2011Gwa1409Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium GW2011_GWA1_40_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumGw2011Gwa1409Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618408.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618408.protein.info.v11.5.txt",
		        "node_list_path": "1618408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterNectarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter nectaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterNectarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392540.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392540.protein.info.v11.5.txt",
		        "node_list_path": "1392540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho201Full3615(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_36_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3615", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798586.protein.info.v11.5.txt",
		        "node_list_path": "1798586.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumNovocastrenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium novocastrense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumNovocastrenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59813.clusters.proteins.v11.5.txt",
		        "sequence_path": "59813.protein.sequences.v11.5.fa",
		        "enrichment_path": "59813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59813.protein.info.v11.5.txt",
		        "node_list_path": "59813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicaulisSpBbd199110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. BBD 1991-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicaulisSpBbd199110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852617.protein.info.v11.5.txt",
		        "node_list_path": "1852617.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifcsplowo212Full6540Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO2_12_FULL_65_40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo212Full6540Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797569.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797569.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797569.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797569.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797569.protein.info.v11.5.txt",
		        "node_list_path": "1797569.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797569.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JeotgalibacaSpPts2502Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalibaca sp. PTS2502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalibacaSpPts2502Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1903686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1903686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1903686.clusters.proteins.v11.5.txt",
		        "sequence_path": "1903686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903686.protein.info.v11.5.txt",
		        "node_list_path": "1903686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1903686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerracidiphilusGabretensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terracidiphilus gabretensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerracidiphilusGabretensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577687.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577687.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577687.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577687.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577687.protein.info.v11.5.txt",
		        "node_list_path": "1577687.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577687.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPneumoniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPneumoniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "722438.clusters.info.v11.5.txt",
		        "cluster_tree_path": "722438.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "722438.clusters.proteins.v11.5.txt",
		        "sequence_path": "722438.protein.sequences.v11.5.fa",
		        "enrichment_path": "722438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "722438.protein.info.v11.5.txt",
		        "node_list_path": "722438.cluster.nodes.v11.5.txt",
		        "edge_list_path": "722438.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonCsp11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon CSP1-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonCsp11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1640512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1640512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1640512.clusters.proteins.v11.5.txt",
		        "sequence_path": "1640512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640512.protein.info.v11.5.txt",
		        "node_list_path": "1640512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1640512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterLapidarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter lapidarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterLapidarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1908237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908237.protein.info.v11.5.txt",
		        "node_list_path": "1908237.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpOy3wo11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. OY3WO11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpOy3wo11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1835723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1835723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1835723.clusters.proteins.v11.5.txt",
		        "sequence_path": "1835723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1835723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1835723.protein.info.v11.5.txt",
		        "node_list_path": "1835723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1835723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XylonaHeveaeTc161(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xylona heveae TC161 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylonaHeveaeTc161", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1328760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1328760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1328760.protein.info.v11.5.txt",
		        "node_list_path": "1328760.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0330Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0330Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "653386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "653386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "653386.clusters.proteins.v11.5.txt",
		        "sequence_path": "653386.protein.sequences.v11.5.fa",
		        "enrichment_path": "653386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "653386.protein.info.v11.5.txt",
		        "node_list_path": "653386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "653386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPseudoalcaligenesKf707(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes KF707 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPseudoalcaligenesKf707", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1149133.protein.sequences.v11.5.fa",
		        "enrichment_path": "1149133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1149133.protein.info.v11.5.txt",
		        "node_list_path": "1149133.protein.complete.v11.5.txt"
		    }
		]
    )()

def CnuibacterPhyscomitrellae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cnuibacter physcomitrellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CnuibacterPhyscomitrellae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619308.protein.info.v11.5.txt",
		        "node_list_path": "1619308.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpPcc7502Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpPcc7502Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173263.protein.info.v11.5.txt",
		        "node_list_path": "1173263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaTransvalensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia transvalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaTransvalensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206744.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206744.protein.info.v11.5.txt",
		        "node_list_path": "1206744.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaAldovae67083(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia aldovae 670-83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaAldovae67083", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1453495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453495.protein.info.v11.5.txt",
		        "node_list_path": "1453495.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrypanosomaBrucei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma brucei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrypanosomaBrucei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5691.protein.sequences.v11.5.fa",
		        "enrichment_path": "5691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5691.protein.info.v11.5.txt",
		        "node_list_path": "5691.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanococcusMaripaludisC6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusMaripaludisC6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "444158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "444158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "444158.clusters.proteins.v11.5.txt",
		        "sequence_path": "444158.protein.sequences.v11.5.fa",
		        "enrichment_path": "444158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444158.protein.info.v11.5.txt",
		        "node_list_path": "444158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "444158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinophagaNiabensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga niabensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaNiabensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "536979.clusters.info.v11.5.txt",
		        "cluster_tree_path": "536979.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "536979.clusters.proteins.v11.5.txt",
		        "sequence_path": "536979.protein.sequences.v11.5.fa",
		        "enrichment_path": "536979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "536979.protein.info.v11.5.txt",
		        "node_list_path": "536979.cluster.nodes.v11.5.txt",
		        "edge_list_path": "536979.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1306947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306947.protein.info.v11.5.txt",
		        "node_list_path": "1306947.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetallosphaeraHakonensisJcm8857Dsm7519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metallosphaera hakonensis JCM 8857 DSM 7519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetallosphaeraHakonensisJcm8857Dsm7519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293036.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293036.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293036.protein.info.v11.5.txt",
		        "node_list_path": "1293036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IntestinimonasButyriciproducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Intestinimonas butyriciproducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntestinimonasButyriciproducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1297617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1297617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1297617.clusters.proteins.v11.5.txt",
		        "sequence_path": "1297617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297617.protein.info.v11.5.txt",
		        "node_list_path": "1297617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1297617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GrifolaFrondosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Grifola frondosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GrifolaFrondosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5627.protein.sequences.v11.5.fa",
		        "enrichment_path": "5627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5627.protein.info.v11.5.txt",
		        "node_list_path": "5627.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterLitoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterLitoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314225.protein.sequences.v11.5.fa",
		        "enrichment_path": "314225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314225.protein.info.v11.5.txt",
		        "node_list_path": "314225.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaeBacteriumDg1235(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobiae bacterium DG1235 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaeBacteriumDg1235", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "382464.protein.sequences.v11.5.fa",
		        "enrichment_path": "382464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "382464.protein.info.v11.5.txt",
		        "node_list_path": "382464.protein.complete.v11.5.txt"
		    }
		]
    )()

def VolvoxCarteriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Volvox carteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VolvoxCarteriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3067.clusters.proteins.v11.5.txt",
		        "sequence_path": "3067.protein.sequences.v11.5.fa",
		        "enrichment_path": "3067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3067.protein.info.v11.5.txt",
		        "node_list_path": "3067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasTaeanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas taeanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasTaeanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "284577.protein.sequences.v11.5.fa",
		        "enrichment_path": "284577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284577.protein.info.v11.5.txt",
		        "node_list_path": "284577.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifoxyc2Full4316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYC2_FULL_43_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyc2Full4316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801808.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801808.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801808.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801808.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801808.protein.info.v11.5.txt",
		        "node_list_path": "1801808.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801808.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenimonasCompostiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas composti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenimonasCompostiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121013.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121013.protein.info.v11.5.txt",
		        "node_list_path": "1121013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwe132154(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWE1_32_154 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwe132154", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802184.protein.info.v11.5.txt",
		        "node_list_path": "1802184.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrovirgaLupini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microvirga lupini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaLupini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "420324.protein.sequences.v11.5.fa",
		        "enrichment_path": "420324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420324.protein.info.v11.5.txt",
		        "node_list_path": "420324.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusLacisalsiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus lacisalsi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusLacisalsiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121929.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121929.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121929.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121929.protein.info.v11.5.txt",
		        "node_list_path": "1121929.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121929.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudocercosporaFijiensisCirad86Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudocercospora fijiensis CIRAD86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudocercosporaFijiensisCirad86Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "383855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "383855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "383855.clusters.proteins.v11.5.txt",
		        "sequence_path": "383855.protein.sequences.v11.5.fa",
		        "enrichment_path": "383855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "383855.protein.info.v11.5.txt",
		        "node_list_path": "383855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "383855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusBataviensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus bataviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusBataviensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1117379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1117379.clusters.proteins.v11.5.txt",
		        "sequence_path": "1117379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117379.protein.info.v11.5.txt",
		        "node_list_path": "1117379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1117379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermosinusCarboxydivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermosinus carboxydivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosinusCarboxydivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "401526.protein.sequences.v11.5.fa",
		        "enrichment_path": "401526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "401526.protein.info.v11.5.txt",
		        "node_list_path": "401526.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4521(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFCSPLOWO2_02_FULL_45_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4521", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797989.protein.info.v11.5.txt",
		        "node_list_path": "1797989.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusCelericrescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus celericrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusCelericrescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "227598.protein.sequences.v11.5.fa",
		        "enrichment_path": "227598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227598.protein.info.v11.5.txt",
		        "node_list_path": "227598.protein.complete.v11.5.txt"
		    }
		]
    )()

def RappaportIsraeliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rappaport israeli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RappaportIsraeliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1839807.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1839807.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1839807.clusters.proteins.v11.5.txt",
		        "sequence_path": "1839807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1839807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1839807.protein.info.v11.5.txt",
		        "node_list_path": "1839807.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1839807.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusDysgalactiaeEquisimilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae equisimilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDysgalactiaeEquisimilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "759913.protein.sequences.v11.5.fa",
		        "enrichment_path": "759913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759913.protein.info.v11.5.txt",
		        "node_list_path": "759913.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalanaerobiumCongolense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halanaerobium congolense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaerobiumCongolense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "54121.protein.sequences.v11.5.fa",
		        "enrichment_path": "54121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54121.protein.info.v11.5.txt",
		        "node_list_path": "54121.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumRbg164519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RBG_16_45_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumRbg164519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817747.protein.info.v11.5.txt",
		        "node_list_path": "1817747.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumMageritenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium mageritense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumMageritenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1209984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1209984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1209984.clusters.proteins.v11.5.txt",
		        "sequence_path": "1209984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1209984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1209984.protein.info.v11.5.txt",
		        "node_list_path": "1209984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1209984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRaymondbacteriaBacteriumRifoxyc2Full5021(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Raymondbacteria bacterium RIFOXYC2_FULL_50_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRaymondbacteriaBacteriumRifoxyc2Full5021", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817889.protein.info.v11.5.txt",
		        "node_list_path": "1817889.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusCapitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus capitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusCapitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "435838.clusters.info.v11.5.txt",
		        "cluster_tree_path": "435838.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "435838.clusters.proteins.v11.5.txt",
		        "sequence_path": "435838.protein.sequences.v11.5.fa",
		        "enrichment_path": "435838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435838.protein.info.v11.5.txt",
		        "node_list_path": "435838.cluster.nodes.v11.5.txt",
		        "edge_list_path": "435838.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospinaeBacteriumRifcsplowo2123915(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospinae bacterium RIFCSPLOWO2_12_39_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospinaeBacteriumRifcsplowo2123915", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801689.protein.info.v11.5.txt",
		        "node_list_path": "1801689.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanococcusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planococcus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499687.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499687.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499687.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499687.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499687.protein.info.v11.5.txt",
		        "node_list_path": "1499687.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499687.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpUnccl117(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNCCL117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpUnccl117", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502764.protein.info.v11.5.txt",
		        "node_list_path": "1502764.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumPh28Bin88Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium PH28_bin88 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumPh28Bin88Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1605376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1605376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1605376.clusters.proteins.v11.5.txt",
		        "sequence_path": "1605376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1605376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1605376.protein.info.v11.5.txt",
		        "node_list_path": "1605376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1605376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumRifoxyb1Full5412(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFOXYB1_FULL_54_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifoxyb1Full5412", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802559.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802559.protein.info.v11.5.txt",
		        "node_list_path": "1802559.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifoxyb2Full4645(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFOXYB2_FULL_46_45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2Full4645", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802582.protein.info.v11.5.txt",
		        "node_list_path": "1802582.protein.complete.v11.5.txt"
		    }
		]
    )()

def CycloclasticusSpP1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. P1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CycloclasticusSpP1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "385025.protein.sequences.v11.5.fa",
		        "enrichment_path": "385025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "385025.protein.info.v11.5.txt",
		        "node_list_path": "385025.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMuproteobacteriaBacteriumRbg166411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_64_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817758.protein.info.v11.5.txt",
		        "node_list_path": "1817758.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalodesulfurarchaeumFormicicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halodesulfurarchaeum formicicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalodesulfurarchaeumFormicicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1873524.protein.sequences.v11.5.fa",
		        "enrichment_path": "1873524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1873524.protein.info.v11.5.txt",
		        "node_list_path": "1873524.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyaloperonosporaArabidopsidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyaloperonospora arabidopsidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyaloperonosporaArabidopsidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272952.protein.sequences.v11.5.fa",
		        "enrichment_path": "272952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272952.protein.info.v11.5.txt",
		        "node_list_path": "272952.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerovibrioLipolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerovibrio lipolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerovibrioLipolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408423.protein.info.v11.5.txt",
		        "node_list_path": "1408423.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrococcusFuriosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus furiosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusFuriosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "186497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "186497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "186497.clusters.proteins.v11.5.txt",
		        "sequence_path": "186497.protein.sequences.v11.5.fa",
		        "enrichment_path": "186497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "186497.protein.info.v11.5.txt",
		        "node_list_path": "186497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "186497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag177(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:177 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag177", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262952.protein.info.v11.5.txt",
		        "node_list_path": "1262952.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSpDm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. DM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSpDm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1597955.protein.sequences.v11.5.fa",
		        "enrichment_path": "1597955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1597955.protein.info.v11.5.txt",
		        "node_list_path": "1597955.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacillusMinor202(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus minor 202 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusMinor202", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "591023.protein.sequences.v11.5.fa",
		        "enrichment_path": "591023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591023.protein.info.v11.5.txt",
		        "node_list_path": "591023.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterNorwichensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter norwichensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterNorwichensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121957.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121957.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121957.protein.info.v11.5.txt",
		        "node_list_path": "1121957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSpGwe1629(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. GWE1_62_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSpGwe1629", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802374.protein.info.v11.5.txt",
		        "node_list_path": "1802374.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusHemicellulosilyticusJcm9152Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus hemicellulosilyticus JCM 9152 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHemicellulosilyticusJcm9152Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236971.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236971.protein.info.v11.5.txt",
		        "node_list_path": "1236971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasFlavigena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas flavigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasFlavigena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "446466.protein.sequences.v11.5.fa",
		        "enrichment_path": "446466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446466.protein.info.v11.5.txt",
		        "node_list_path": "446466.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlterileibacteriumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alterileibacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlterileibacteriumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1870997.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870997.protein.info.v11.5.txt",
		        "node_list_path": "1870997.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseomonasStagniDsm19981Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas stagni DSM 19981 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseomonasStagniDsm19981Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123062.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123062.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123062.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123062.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123062.protein.info.v11.5.txt",
		        "node_list_path": "1123062.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123062.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyricimonasSynergistica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyricimonas synergistica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyricimonasSynergistica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121129.protein.info.v11.5.txt",
		        "node_list_path": "1121129.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprococcusSpCag782(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus sp. CAG:782 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprococcusSpCag782", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262863.protein.info.v11.5.txt",
		        "node_list_path": "1262863.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterPhenanthrenivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter phenanthrenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterPhenanthrenivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930171.protein.sequences.v11.5.fa",
		        "enrichment_path": "930171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930171.protein.info.v11.5.txt",
		        "node_list_path": "930171.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaOsloensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella osloensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaOsloensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34062.protein.sequences.v11.5.fa",
		        "enrichment_path": "34062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34062.protein.info.v11.5.txt",
		        "node_list_path": "34062.protein.complete.v11.5.txt"
		    }
		]
    )()

def TidjanibacterMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tidjanibacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TidjanibacterMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871003.protein.info.v11.5.txt",
		        "node_list_path": "1871003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpS23321Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. S23321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpS23321Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "335659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "335659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "335659.clusters.proteins.v11.5.txt",
		        "sequence_path": "335659.protein.sequences.v11.5.fa",
		        "enrichment_path": "335659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335659.protein.info.v11.5.txt",
		        "node_list_path": "335659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "335659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusSpOtCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. OT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusSpOtCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "913865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "913865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "913865.clusters.proteins.v11.5.txt",
		        "sequence_path": "913865.protein.sequences.v11.5.fa",
		        "enrichment_path": "913865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913865.protein.info.v11.5.txt",
		        "node_list_path": "913865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "913865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaHaemolyticaM42548(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica M42548 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaHaemolyticaM42548", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1316932.protein.sequences.v11.5.fa",
		        "enrichment_path": "1316932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1316932.protein.info.v11.5.txt",
		        "node_list_path": "1316932.protein.complete.v11.5.txt"
		    }
		]
    )()

def HammondiaHammondiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hammondia hammondi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HammondiaHammondiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "99158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "99158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "99158.clusters.proteins.v11.5.txt",
		        "sequence_path": "99158.protein.sequences.v11.5.fa",
		        "enrichment_path": "99158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "99158.protein.info.v11.5.txt",
		        "node_list_path": "99158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "99158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSp6622Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. 66-22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSp6622Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895753.protein.info.v11.5.txt",
		        "node_list_path": "1895753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloarculaRubripromontorii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula rubripromontorii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaRubripromontorii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1705562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705562.protein.info.v11.5.txt",
		        "node_list_path": "1705562.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpEp60837Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. EP60837 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpEp60837Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855519.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855519.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855519.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855519.protein.info.v11.5.txt",
		        "node_list_path": "1855519.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855519.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaPekkanenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia pekkanenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaPekkanenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288385.protein.info.v11.5.txt",
		        "node_list_path": "1288385.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho201Full4016(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_40_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4016", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798595.protein.info.v11.5.txt",
		        "node_list_path": "1798595.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisSpCnt312Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. CNT312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisSpCnt312Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1137268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1137268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1137268.clusters.proteins.v11.5.txt",
		        "sequence_path": "1137268.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137268.protein.info.v11.5.txt",
		        "node_list_path": "1137268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1137268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4415Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_12_FULL_44_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4415Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798364.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798364.protein.info.v11.5.txt",
		        "node_list_path": "1798364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSullaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sullae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSullaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041146.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041146.protein.info.v11.5.txt",
		        "node_list_path": "1041146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioXiamenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioXiamenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "861298.protein.sequences.v11.5.fa",
		        "enrichment_path": "861298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861298.protein.info.v11.5.txt",
		        "node_list_path": "861298.protein.complete.v11.5.txt"
		    }
		]
    )()

def HamadaeaTsunoensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hamadaea tsunoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HamadaeaTsunoensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121946.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121946.protein.info.v11.5.txt",
		        "node_list_path": "1121946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusBogoriensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus bogoriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusBogoriensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408424.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408424.protein.info.v11.5.txt",
		        "node_list_path": "1408424.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHdn1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HdN1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHdn1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83406.clusters.proteins.v11.5.txt",
		        "sequence_path": "83406.protein.sequences.v11.5.fa",
		        "enrichment_path": "83406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83406.protein.info.v11.5.txt",
		        "node_list_path": "83406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4520Fw2644(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4520 (FW-2644) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4520Fw2644", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420915.protein.info.v11.5.txt",
		        "node_list_path": "1420915.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodniusProlixusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodnius prolixus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodniusProlixusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13249.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13249.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13249.clusters.proteins.v11.5.txt",
		        "sequence_path": "13249.protein.sequences.v11.5.fa",
		        "enrichment_path": "13249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13249.protein.info.v11.5.txt",
		        "node_list_path": "13249.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13249.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylosarcinaLacusLw14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylosarcina lacus LW14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylosarcinaLacusLw14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1114263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1114263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1114263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1114263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114263.protein.info.v11.5.txt",
		        "node_list_path": "1114263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1114263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumHiltneriN3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum hiltneri N3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumHiltneriN3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262470.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262470.protein.info.v11.5.txt",
		        "node_list_path": "1262470.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteocatellaSphenisciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteocatella sphenisci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteocatellaSphenisciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123009.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123009.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123009.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123009.protein.info.v11.5.txt",
		        "node_list_path": "1123009.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123009.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMicrarchaeotaArchaeonCg1025115(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_51_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1025115", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805249.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805249.protein.info.v11.5.txt",
		        "node_list_path": "1805249.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedMethanoculleusSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Methanoculleus sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedMethanoculleusSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "183762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "183762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "183762.clusters.proteins.v11.5.txt",
		        "sequence_path": "183762.protein.sequences.v11.5.fa",
		        "enrichment_path": "183762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "183762.protein.info.v11.5.txt",
		        "node_list_path": "183762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "183762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalopigerSpIih3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halopiger sp. IIH3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalopigerSpIih3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293048.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293048.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293048.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293048.protein.info.v11.5.txt",
		        "node_list_path": "1293048.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293048.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumHispalenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium hispalense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumHispalenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "491205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "491205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "491205.clusters.proteins.v11.5.txt",
		        "sequence_path": "491205.protein.sequences.v11.5.fa",
		        "enrichment_path": "491205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "491205.protein.info.v11.5.txt",
		        "node_list_path": "491205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "491205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsplowo201Full4531Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPLOWO2_01_FULL_45_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsplowo201Full4531Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797545.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797545.protein.info.v11.5.txt",
		        "node_list_path": "1797545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaAmylovora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia amylovora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaAmylovora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665029.protein.sequences.v11.5.fa",
		        "enrichment_path": "665029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665029.protein.info.v11.5.txt",
		        "node_list_path": "665029.protein.complete.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpAs2mBin001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. AS2M-Bin001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpAs2mBin001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1764958.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1764958.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1764958.clusters.proteins.v11.5.txt",
		        "sequence_path": "1764958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1764958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1764958.protein.info.v11.5.txt",
		        "node_list_path": "1764958.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1764958.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomicrostromaGlucosiphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomicrostroma glucosiphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomicrostromaGlucosiphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1684307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1684307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1684307.clusters.proteins.v11.5.txt",
		        "sequence_path": "1684307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1684307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1684307.protein.info.v11.5.txt",
		        "node_list_path": "1684307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1684307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAlcaligenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alcaligenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAlcaligenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43263.clusters.proteins.v11.5.txt",
		        "sequence_path": "43263.protein.sequences.v11.5.fa",
		        "enrichment_path": "43263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43263.protein.info.v11.5.txt",
		        "node_list_path": "43263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacterSp24Yea8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter sp. 24-YEA-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterSp24Yea8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884310.protein.info.v11.5.txt",
		        "node_list_path": "1884310.protein.complete.v11.5.txt"
		    }
		]
    )()

def PandoraeaThiooxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea thiooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaThiooxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445709.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445709.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445709.clusters.proteins.v11.5.txt",
		        "sequence_path": "445709.protein.sequences.v11.5.fa",
		        "enrichment_path": "445709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445709.protein.info.v11.5.txt",
		        "node_list_path": "445709.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445709.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusOkhensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus okhensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusOkhensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "333138.protein.sequences.v11.5.fa",
		        "enrichment_path": "333138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "333138.protein.info.v11.5.txt",
		        "node_list_path": "333138.protein.complete.v11.5.txt"
		    }
		]
    )()

def CadophoraSpDse1049Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cadophora sp. DSE1049 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CadophoraSpDse1049Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1485229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1485229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1485229.clusters.proteins.v11.5.txt",
		        "sequence_path": "1485229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1485229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1485229.protein.info.v11.5.txt",
		        "node_list_path": "1485229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1485229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusDysgalactiaeAtcc27957(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae ATCC27957 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDysgalactiaeAtcc27957", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "663952.protein.sequences.v11.5.fa",
		        "enrichment_path": "663952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663952.protein.info.v11.5.txt",
		        "node_list_path": "663952.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaOchraceaF0287(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea F0287 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaOchraceaF0287", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "873517.protein.sequences.v11.5.fa",
		        "enrichment_path": "873517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "873517.protein.info.v11.5.txt",
		        "node_list_path": "873517.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeferribacterDesulfuricans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deferribacter desulfuricans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeferribacterDesulfuricans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "639282.protein.sequences.v11.5.fa",
		        "enrichment_path": "639282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "639282.protein.info.v11.5.txt",
		        "node_list_path": "639282.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4218(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4218 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4218", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977880.protein.info.v11.5.txt",
		        "node_list_path": "1977880.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactucaSativaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactuca sativa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactucaSativaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4236.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4236.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4236.clusters.proteins.v11.5.txt",
		        "sequence_path": "4236.protein.sequences.v11.5.fa",
		        "enrichment_path": "4236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4236.protein.info.v11.5.txt",
		        "node_list_path": "4236.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4236.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumTestudinorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium testudinoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumTestudinorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "136857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "136857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "136857.clusters.proteins.v11.5.txt",
		        "sequence_path": "136857.protein.sequences.v11.5.fa",
		        "enrichment_path": "136857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "136857.protein.info.v11.5.txt",
		        "node_list_path": "136857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "136857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumFrediiNgr234Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii NGR234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumFrediiNgr234Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "394.clusters.proteins.v11.5.txt",
		        "sequence_path": "394.protein.sequences.v11.5.fa",
		        "enrichment_path": "394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394.protein.info.v11.5.txt",
		        "node_list_path": "394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesTuricensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces turicensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesTuricensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883077.protein.sequences.v11.5.fa",
		        "enrichment_path": "883077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883077.protein.info.v11.5.txt",
		        "node_list_path": "883077.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobotrysOligospora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobotrys oligospora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobotrysOligospora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13349.protein.sequences.v11.5.fa",
		        "enrichment_path": "13349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13349.protein.info.v11.5.txt",
		        "node_list_path": "13349.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaromonasNaphthalenivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas naphthalenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasNaphthalenivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "365044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "365044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "365044.clusters.proteins.v11.5.txt",
		        "sequence_path": "365044.protein.sequences.v11.5.fa",
		        "enrichment_path": "365044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "365044.protein.info.v11.5.txt",
		        "node_list_path": "365044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "365044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobulbusJaponicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbusJaponicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121403.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121403.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121403.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121403.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121403.protein.info.v11.5.txt",
		        "node_list_path": "1121403.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121403.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudacidovoraxSpRu35e(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudacidovorax sp. RU35E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudacidovoraxSpRu35e", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907403.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907403.protein.info.v11.5.txt",
		        "node_list_path": "1907403.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporolituusThermophilusDsm23256Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporolituus thermophilus DSM 23256 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolituusThermophilusDsm23256Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123285.protein.info.v11.5.txt",
		        "node_list_path": "1123285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeocallimastixCaliforniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neocallimastix californiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeocallimastixCaliforniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1754190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1754190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1754190.protein.info.v11.5.txt",
		        "node_list_path": "1754190.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumMagnum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium magnum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumMagnum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1692.protein.info.v11.5.txt",
		        "node_list_path": "1692.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusSpMv1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus sp. MV1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusSpMv1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219626.protein.info.v11.5.txt",
		        "node_list_path": "1219626.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureimonasSpAu22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpAu22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1638162.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1638162.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1638162.clusters.proteins.v11.5.txt",
		        "sequence_path": "1638162.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638162.protein.info.v11.5.txt",
		        "node_list_path": "1638162.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1638162.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedTermiteGroup1BacteriumPhylotypeRsD17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Termite group 1 bacterium phylotype Rs-D17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedTermiteGroup1BacteriumPhylotypeRsD17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471821.clusters.proteins.v11.5.txt",
		        "sequence_path": "471821.protein.sequences.v11.5.fa",
		        "enrichment_path": "471821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471821.protein.info.v11.5.txt",
		        "node_list_path": "471821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetalesBacteriumSpiro05(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetalesBacteriumSpiro05", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674861.protein.info.v11.5.txt",
		        "node_list_path": "1674861.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full509b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_50_9b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full509b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798682.protein.info.v11.5.txt",
		        "node_list_path": "1798682.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlaviramulusIchthyoenteri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flaviramulus ichthyoenteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlaviramulusIchthyoenteri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380600.protein.info.v11.5.txt",
		        "node_list_path": "1380600.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumXueshanenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium xueshanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumXueshanenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935223.clusters.proteins.v11.5.txt",
		        "sequence_path": "935223.protein.sequences.v11.5.fa",
		        "enrichment_path": "935223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935223.protein.info.v11.5.txt",
		        "node_list_path": "935223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumE1BontCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum E1 BoNT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumE1BontCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "536233.clusters.info.v11.5.txt",
		        "cluster_tree_path": "536233.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "536233.clusters.proteins.v11.5.txt",
		        "sequence_path": "536233.protein.sequences.v11.5.fa",
		        "enrichment_path": "536233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "536233.protein.info.v11.5.txt",
		        "node_list_path": "536233.cluster.nodes.v11.5.txt",
		        "edge_list_path": "536233.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4315bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_01_FULL_43_15b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4315bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797513.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797513.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797513.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797513.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797513.protein.info.v11.5.txt",
		        "node_list_path": "1797513.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797513.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyclobacteriumLianum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacterium lianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyclobacteriumLianum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "388280.protein.sequences.v11.5.fa",
		        "enrichment_path": "388280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388280.protein.info.v11.5.txt",
		        "node_list_path": "388280.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovermiculusHalophilusDsm18834(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovermiculus halophilus DSM 18834 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovermiculusHalophilusDsm18834", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121433.protein.info.v11.5.txt",
		        "node_list_path": "1121433.protein.complete.v11.5.txt"
		    }
		]
    )()

def DictyocaulusViviparusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dictyocaulus viviparus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DictyocaulusViviparusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29172.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29172.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29172.clusters.proteins.v11.5.txt",
		        "sequence_path": "29172.protein.sequences.v11.5.fa",
		        "enrichment_path": "29172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29172.protein.info.v11.5.txt",
		        "node_list_path": "29172.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29172.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DysgonomonasHofstadiiJcm17038(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas hofstadii JCM 17038 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasHofstadiiJcm17038", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298597.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298597.protein.info.v11.5.txt",
		        "node_list_path": "1298597.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeferrisomaCaminiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deferrisoma camini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeferrisomaCaminiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125863.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125863.protein.info.v11.5.txt",
		        "node_list_path": "1125863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GasterosteusAculeatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gasterosteus aculeatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GasterosteusAculeatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69293.clusters.proteins.v11.5.txt",
		        "sequence_path": "69293.protein.sequences.v11.5.fa",
		        "enrichment_path": "69293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69293.protein.info.v11.5.txt",
		        "node_list_path": "69293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumRubrisubalbicansM1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum rubrisubalbicans M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumRubrisubalbicansM1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1078773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1078773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1078773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1078773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078773.protein.info.v11.5.txt",
		        "node_list_path": "1078773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1078773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumVariabile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium variabile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumVariabile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "858619.protein.sequences.v11.5.fa",
		        "enrichment_path": "858619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "858619.protein.info.v11.5.txt",
		        "node_list_path": "858619.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterSyzygii9h2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter syzygii 9H-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterSyzygii9h2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231343.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231343.protein.info.v11.5.txt",
		        "node_list_path": "1231343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpKm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. KM-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpKm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "590061.protein.sequences.v11.5.fa",
		        "enrichment_path": "590061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "590061.protein.info.v11.5.txt",
		        "node_list_path": "590061.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkelbacteriaBacteriumCg2304320Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium CG2_30_43_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumCg2304320Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805038.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805038.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805038.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805038.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805038.protein.info.v11.5.txt",
		        "node_list_path": "1805038.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805038.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSpOk283(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK283 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSpOk283", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881049.protein.info.v11.5.txt",
		        "node_list_path": "1881049.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf231(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf231 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf231", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736301.protein.info.v11.5.txt",
		        "node_list_path": "1736301.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumGwf1657(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium GWF1_65_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumGwf1657", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802013.protein.info.v11.5.txt",
		        "node_list_path": "1802013.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumWanjuenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium wanjuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumWanjuenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "356305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "356305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "356305.clusters.proteins.v11.5.txt",
		        "sequence_path": "356305.protein.sequences.v11.5.fa",
		        "enrichment_path": "356305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "356305.protein.info.v11.5.txt",
		        "node_list_path": "356305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "356305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaMannitolilytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia mannitolilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaMannitolilytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "105219.protein.sequences.v11.5.fa",
		        "enrichment_path": "105219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105219.protein.info.v11.5.txt",
		        "node_list_path": "105219.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumPaludicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium paludicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumPaludicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "300019.protein.sequences.v11.5.fa",
		        "enrichment_path": "300019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "300019.protein.info.v11.5.txt",
		        "node_list_path": "300019.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBreveCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium breve Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBreveCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326426.clusters.proteins.v11.5.txt",
		        "sequence_path": "326426.protein.sequences.v11.5.fa",
		        "enrichment_path": "326426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326426.protein.info.v11.5.txt",
		        "node_list_path": "326426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacillusMinor202Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus minor 202 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusMinor202Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "591023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "591023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "591023.clusters.proteins.v11.5.txt",
		        "sequence_path": "591023.protein.sequences.v11.5.fa",
		        "enrichment_path": "591023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591023.protein.info.v11.5.txt",
		        "node_list_path": "591023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "591023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CucumisSativusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cucumis sativus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CucumisSativusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3659.clusters.proteins.v11.5.txt",
		        "sequence_path": "3659.protein.sequences.v11.5.fa",
		        "enrichment_path": "3659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3659.protein.info.v11.5.txt",
		        "node_list_path": "3659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolemyaVelesianaGillSymbiont(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solemya velesiana gill symbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolemyaVelesianaGillSymbiont", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1918948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918948.protein.info.v11.5.txt",
		        "node_list_path": "1918948.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpCmr5c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CMR5c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpCmr5c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658630.protein.sequences.v11.5.fa",
		        "enrichment_path": "658630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658630.protein.info.v11.5.txt",
		        "node_list_path": "658630.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusKribbensisDsm17871(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus kribbensis DSM 17871 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusKribbensisDsm17871", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121092.protein.info.v11.5.txt",
		        "node_list_path": "1121092.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrialbaChahannaoensisJcm10990(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrialba chahannaoensis JCM 10990 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaChahannaoensisJcm10990", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227492.protein.info.v11.5.txt",
		        "node_list_path": "1227492.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo212Full6820Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_12_FULL_68_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212Full6820Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797505.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797505.protein.info.v11.5.txt",
		        "node_list_path": "1797505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CordycepsSpRao2017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps sp. RAO-2017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CordycepsSpRao2017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2004951.protein.sequences.v11.5.fa",
		        "enrichment_path": "2004951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2004951.protein.info.v11.5.txt",
		        "node_list_path": "2004951.protein.complete.v11.5.txt"
		    }
		]
    )()

def GaldieriaSulphurariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Galdieria sulphuraria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GaldieriaSulphurariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "130081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "130081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "130081.clusters.proteins.v11.5.txt",
		        "sequence_path": "130081.protein.sequences.v11.5.fa",
		        "enrichment_path": "130081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "130081.protein.info.v11.5.txt",
		        "node_list_path": "130081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "130081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnatzschineriaLarvae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignatzschineria larvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnatzschineriaLarvae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111732.protein.info.v11.5.txt",
		        "node_list_path": "1111732.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusNodensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nodensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusNodensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423775.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423775.protein.info.v11.5.txt",
		        "node_list_path": "1423775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicaulisAlexandriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicaulis alexandrii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicaulisAlexandriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122613.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122613.protein.info.v11.5.txt",
		        "node_list_path": "1122613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolineaTardivitalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptolinea tardivitalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolineaTardivitalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "229920.protein.sequences.v11.5.fa",
		        "enrichment_path": "229920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229920.protein.info.v11.5.txt",
		        "node_list_path": "229920.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumKhcpx20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium KHCPX20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumKhcpx20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855375.protein.info.v11.5.txt",
		        "node_list_path": "1855375.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpP11g5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. P11G5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpP11g5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1699624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1699624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1699624.protein.info.v11.5.txt",
		        "node_list_path": "1699624.protein.complete.v11.5.txt"
		    }
		]
    )()

def CamelliaSinensisVarSinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Camellia sinensis var. sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CamelliaSinensisVarSinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "542762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "542762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "542762.clusters.proteins.v11.5.txt",
		        "sequence_path": "542762.protein.sequences.v11.5.fa",
		        "enrichment_path": "542762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "542762.protein.info.v11.5.txt",
		        "node_list_path": "542762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "542762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpMm124(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. MM124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpMm124", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1342299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1342299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1342299.protein.info.v11.5.txt",
		        "node_list_path": "1342299.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaUreaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina ureae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaUreaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123290.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123290.protein.info.v11.5.txt",
		        "node_list_path": "1123290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaHolmesii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella holmesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaHolmesii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1247649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1247649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1247649.protein.info.v11.5.txt",
		        "node_list_path": "1247649.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo202Full4011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_02_FULL_40_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo202Full4011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797732.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797732.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797732.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797732.protein.info.v11.5.txt",
		        "node_list_path": "1797732.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797732.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasDiversaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas diversa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasDiversaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1268237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1268237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1268237.clusters.proteins.v11.5.txt",
		        "sequence_path": "1268237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268237.protein.info.v11.5.txt",
		        "node_list_path": "1268237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1268237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNd2006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium ND2006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNd2006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410628.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410628.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410628.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410628.protein.info.v11.5.txt",
		        "node_list_path": "1410628.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410628.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterSpGwa24521Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. GWA2_45_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterSpGwa24521Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801989.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801989.protein.info.v11.5.txt",
		        "node_list_path": "1801989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermosiphoSp1063Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosipho sp. 1063 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosiphoSp1063Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1462747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1462747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1462747.clusters.proteins.v11.5.txt",
		        "sequence_path": "1462747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462747.protein.info.v11.5.txt",
		        "node_list_path": "1462747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1462747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillatorialesCyanobacteriumCg2304421(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium CG2_30_44_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillatorialesCyanobacteriumCg2304421", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805292.protein.info.v11.5.txt",
		        "node_list_path": "1805292.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCarsonellaRuddiiHcIsolateThao2000(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii HC isolate Thao2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCarsonellaRuddiiHcIsolateThao2000", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1202538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202538.protein.info.v11.5.txt",
		        "node_list_path": "1202538.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwb13910b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_10b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13910b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618573.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618573.protein.info.v11.5.txt",
		        "node_list_path": "1618573.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumEpidermidicanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium epidermidicanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumEpidermidicanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1050174.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1050174.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1050174.clusters.proteins.v11.5.txt",
		        "sequence_path": "1050174.protein.sequences.v11.5.fa",
		        "enrichment_path": "1050174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1050174.protein.info.v11.5.txt",
		        "node_list_path": "1050174.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1050174.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButtiauxellaFerragutiaeAtcc51602(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buttiauxella ferragutiae ATCC 51602 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButtiauxellaFerragutiaeAtcc51602", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354252.protein.info.v11.5.txt",
		        "node_list_path": "1354252.protein.complete.v11.5.txt"
		    }
		]
    )()

def BibersteiniaTrehalosiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bibersteinia trehalosi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BibersteiniaTrehalosiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263831.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263831.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263831.protein.info.v11.5.txt",
		        "node_list_path": "1263831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcanobacteriumPhocaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcanobacterium phocae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcanobacteriumPhocaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "131112.clusters.info.v11.5.txt",
		        "cluster_tree_path": "131112.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "131112.clusters.proteins.v11.5.txt",
		        "sequence_path": "131112.protein.sequences.v11.5.fa",
		        "enrichment_path": "131112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "131112.protein.info.v11.5.txt",
		        "node_list_path": "131112.cluster.nodes.v11.5.txt",
		        "edge_list_path": "131112.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RomboutsiaLituseburensisDsm797Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Romboutsia lituseburensis DSM 797 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RomboutsiaLituseburensisDsm797Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121325.protein.info.v11.5.txt",
		        "node_list_path": "1121325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpUmwwyCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UMWWY Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpUmwwyCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1370121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1370121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1370121.clusters.proteins.v11.5.txt",
		        "sequence_path": "1370121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1370121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1370121.protein.info.v11.5.txt",
		        "node_list_path": "1370121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1370121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubellimicrobiumMesophilumDsm19309Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubellimicrobium mesophilum DSM 19309 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubellimicrobiumMesophilumDsm19309Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "442562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "442562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "442562.clusters.proteins.v11.5.txt",
		        "sequence_path": "442562.protein.sequences.v11.5.fa",
		        "enrichment_path": "442562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "442562.protein.info.v11.5.txt",
		        "node_list_path": "442562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "442562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HypsizygusMarmoreusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hypsizygus marmoreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HypsizygusMarmoreusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39966.clusters.proteins.v11.5.txt",
		        "sequence_path": "39966.protein.sequences.v11.5.fa",
		        "enrichment_path": "39966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39966.protein.info.v11.5.txt",
		        "node_list_path": "39966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesOceani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces oceani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesOceani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1075402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1075402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1075402.protein.info.v11.5.txt",
		        "node_list_path": "1075402.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium688Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 68-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium688Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895817.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895817.protein.info.v11.5.txt",
		        "node_list_path": "1895817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MuscaDomesticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Musca domestica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuscaDomesticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7370.clusters.proteins.v11.5.txt",
		        "sequence_path": "7370.protein.sequences.v11.5.fa",
		        "enrichment_path": "7370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7370.protein.info.v11.5.txt",
		        "node_list_path": "7370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpRac01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. RAC01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpRac01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1842533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1842533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1842533.clusters.proteins.v11.5.txt",
		        "sequence_path": "1842533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842533.protein.info.v11.5.txt",
		        "node_list_path": "1842533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1842533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanimonasSpGk1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanimonas sp. GK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanimonasSpGk1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "511062.clusters.info.v11.5.txt",
		        "cluster_tree_path": "511062.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "511062.clusters.proteins.v11.5.txt",
		        "sequence_path": "511062.protein.sequences.v11.5.fa",
		        "enrichment_path": "511062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511062.protein.info.v11.5.txt",
		        "node_list_path": "511062.cluster.nodes.v11.5.txt",
		        "edge_list_path": "511062.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GonapodyaProliferaJel478(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gonapodya prolifera JEL478 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GonapodyaProliferaJel478", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1344416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1344416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1344416.protein.info.v11.5.txt",
		        "node_list_path": "1344416.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumNoncentrifugensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium noncentrifugens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumNoncentrifugensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1128970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1128970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1128970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1128970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128970.protein.info.v11.5.txt",
		        "node_list_path": "1128970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1128970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaMarthiiFslS4120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria marthii FSL S4-120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaMarthiiFslS4120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "702457.protein.sequences.v11.5.fa",
		        "enrichment_path": "702457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702457.protein.info.v11.5.txt",
		        "node_list_path": "702457.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlishewanellaAgriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alishewanella agri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlishewanellaAgriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1195246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1195246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1195246.clusters.proteins.v11.5.txt",
		        "sequence_path": "1195246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1195246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1195246.protein.info.v11.5.txt",
		        "node_list_path": "1195246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1195246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlmg11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALMg11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlmg11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158165.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158165.protein.info.v11.5.txt",
		        "node_list_path": "1158165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmataSpIil30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmata sp. IIL30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmataSpIil30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210884.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210884.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210884.protein.info.v11.5.txt",
		        "node_list_path": "1210884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharothrixSyringae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharothrix syringae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharothrixSyringae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "103733.protein.sequences.v11.5.fa",
		        "enrichment_path": "103733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103733.protein.info.v11.5.txt",
		        "node_list_path": "103733.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSpRoot685(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. Root685 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpRoot685", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736587.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736587.protein.info.v11.5.txt",
		        "node_list_path": "1736587.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusXenolissoclinumPacificiensisL6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Xenolissoclinum pacificiensis L6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusXenolissoclinumPacificiensisL6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1401685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1401685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1401685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1401685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401685.protein.info.v11.5.txt",
		        "node_list_path": "1401685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1401685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesNeuiiBvs029a5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces neuii BVS029A5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesNeuiiBvs029a5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888439.protein.sequences.v11.5.fa",
		        "enrichment_path": "888439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888439.protein.info.v11.5.txt",
		        "node_list_path": "888439.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrueperellaBernardiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trueperella bernardiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrueperellaBernardiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59561.clusters.proteins.v11.5.txt",
		        "sequence_path": "59561.protein.sequences.v11.5.fa",
		        "enrichment_path": "59561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59561.protein.info.v11.5.txt",
		        "node_list_path": "59561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaHispanicaCri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia hispanica CRI graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaHispanicaCri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1417229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1417229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1417229.protein.info.v11.5.txt",
		        "node_list_path": "1417229.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumOxysporumFo5176Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum Fo5176 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumOxysporumFo5176Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "660025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "660025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "660025.clusters.proteins.v11.5.txt",
		        "sequence_path": "660025.protein.sequences.v11.5.fa",
		        "enrichment_path": "660025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660025.protein.info.v11.5.txt",
		        "node_list_path": "660025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "660025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSoil736Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil736 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSoil736Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736395.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736395.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736395.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736395.protein.info.v11.5.txt",
		        "node_list_path": "1736395.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736395.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioInopinatusDsm10711(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio inopinatus DSM 10711 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioInopinatusDsm10711", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121453.protein.info.v11.5.txt",
		        "node_list_path": "1121453.protein.complete.v11.5.txt"
		    }
		]
    )()

def OreniaMarismortui(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Orenia marismortui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OreniaMarismortui", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926561.protein.sequences.v11.5.fa",
		        "enrichment_path": "926561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926561.protein.info.v11.5.txt",
		        "node_list_path": "926561.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusShacheensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus shacheensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusShacheensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1649580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1649580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1649580.clusters.proteins.v11.5.txt",
		        "sequence_path": "1649580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1649580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1649580.protein.info.v11.5.txt",
		        "node_list_path": "1649580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1649580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumGraminicolaM1001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum graminicola M1.001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumGraminicolaM1001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "645133.clusters.info.v11.5.txt",
		        "cluster_tree_path": "645133.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "645133.clusters.proteins.v11.5.txt",
		        "sequence_path": "645133.protein.sequences.v11.5.fa",
		        "enrichment_path": "645133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645133.protein.info.v11.5.txt",
		        "node_list_path": "645133.cluster.nodes.v11.5.txt",
		        "edge_list_path": "645133.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwf24618(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWF2_46_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwf24618", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618540.protein.info.v11.5.txt",
		        "node_list_path": "1618540.protein.complete.v11.5.txt"
		    }
		]
    )()

def CephaloticoccusPrimus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cephaloticoccus primus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CephaloticoccusPrimus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1548207.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548207.protein.info.v11.5.txt",
		        "node_list_path": "1548207.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumPlexicaudatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium plexicaudatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumPlexicaudatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235802.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235802.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235802.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235802.protein.info.v11.5.txt",
		        "node_list_path": "1235802.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235802.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasPaucimobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas paucimobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasPaucimobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13689.protein.sequences.v11.5.fa",
		        "enrichment_path": "13689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13689.protein.info.v11.5.txt",
		        "node_list_path": "13689.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpZxy2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ZXY-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpZxy2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1806905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806905.protein.info.v11.5.txt",
		        "node_list_path": "1806905.protein.complete.v11.5.txt"
		    }
		]
    )()

def OligotrophaCarboxidovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oligotropha carboxidovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OligotrophaCarboxidovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "504832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "504832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "504832.clusters.proteins.v11.5.txt",
		        "sequence_path": "504832.protein.sequences.v11.5.fa",
		        "enrichment_path": "504832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504832.protein.info.v11.5.txt",
		        "node_list_path": "504832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "504832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacterium13220cm2628(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium 13_2_20CM_2_62_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacterium13220cm2628", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805272.protein.info.v11.5.txt",
		        "node_list_path": "1805272.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusSendaiensisNbrc100866Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus sendaiensis NBRC 100866 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusSendaiensisNbrc100866Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220572.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220572.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220572.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220572.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220572.protein.info.v11.5.txt",
		        "node_list_path": "1220572.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220572.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EndolissoclinumFaulkneriL5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Endolissoclinum faulkneri L5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndolissoclinumFaulkneriL5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1401328.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401328.protein.info.v11.5.txt",
		        "node_list_path": "1401328.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4520Fw2644Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4520 (FW-2644) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4520Fw2644Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420915.protein.info.v11.5.txt",
		        "node_list_path": "1420915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumHydrocarbonoxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium hydrocarbonoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumHydrocarbonoxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "273678.protein.sequences.v11.5.fa",
		        "enrichment_path": "273678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273678.protein.info.v11.5.txt",
		        "node_list_path": "273678.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasCannabisPvPhaseoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas cannabis pv. phaseoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCannabisPvPhaseoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1885902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1885902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1885902.protein.info.v11.5.txt",
		        "node_list_path": "1885902.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSenegalimassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus senegalimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSenegalimassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1737426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1737426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1737426.protein.info.v11.5.txt",
		        "node_list_path": "1737426.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag1060Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:1060 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag1060Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262734.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262734.protein.info.v11.5.txt",
		        "node_list_path": "1262734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaAkCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ak Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaAkCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005090.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005090.protein.info.v11.5.txt",
		        "node_list_path": "1005090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumShinjukuense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium shinjukuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumShinjukuense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398694.protein.sequences.v11.5.fa",
		        "enrichment_path": "398694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398694.protein.info.v11.5.txt",
		        "node_list_path": "398694.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfococcusSp4484241Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfococcus sp. 4484_241 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfococcusSp4484241Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1968522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1968522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1968522.clusters.proteins.v11.5.txt",
		        "sequence_path": "1968522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1968522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1968522.protein.info.v11.5.txt",
		        "node_list_path": "1968522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1968522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotorhabdusLuminescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photorhabdus luminescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotorhabdusLuminescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243265.protein.sequences.v11.5.fa",
		        "enrichment_path": "243265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243265.protein.info.v11.5.txt",
		        "node_list_path": "243265.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusHayakitensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hayakitensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHayakitensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423755.protein.info.v11.5.txt",
		        "node_list_path": "1423755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262832.protein.info.v11.5.txt",
		        "node_list_path": "1262832.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesStephensiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles stephensi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesStephensiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "30069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "30069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "30069.clusters.proteins.v11.5.txt",
		        "sequence_path": "30069.protein.sequences.v11.5.fa",
		        "enrichment_path": "30069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30069.protein.info.v11.5.txt",
		        "node_list_path": "30069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "30069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaPaludivivensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella paludivivens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaPaludivivensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122990.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122990.protein.info.v11.5.txt",
		        "node_list_path": "1122990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterSpAf1028(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. AF1028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSpAf1028", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1355368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1355368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1355368.protein.info.v11.5.txt",
		        "node_list_path": "1355368.protein.complete.v11.5.txt"
		    }
		]
    )()

def GiardiaIntestinalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Giardia intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GiardiaIntestinalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5741.clusters.proteins.v11.5.txt",
		        "sequence_path": "5741.protein.sequences.v11.5.fa",
		        "enrichment_path": "5741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5741.protein.info.v11.5.txt",
		        "node_list_path": "5741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAfermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium afermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAfermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "38286.protein.sequences.v11.5.fa",
		        "enrichment_path": "38286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38286.protein.info.v11.5.txt",
		        "node_list_path": "38286.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetragenococcusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetragenococcus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetragenococcusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "945021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "945021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "945021.clusters.proteins.v11.5.txt",
		        "sequence_path": "945021.protein.sequences.v11.5.fa",
		        "enrichment_path": "945021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "945021.protein.info.v11.5.txt",
		        "node_list_path": "945021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "945021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaSpinosisporaDsm44797Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia spinosispora DSM 44797 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaSpinosisporaDsm44797Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123025.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123025.protein.info.v11.5.txt",
		        "node_list_path": "1123025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho201Full3826Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_38_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3826Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798591.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798591.protein.info.v11.5.txt",
		        "node_list_path": "1798591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EdwardsiellaTardaAtcc15947Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Edwardsiella tarda ATCC15947 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EdwardsiellaTardaAtcc15947Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "667121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "667121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "667121.clusters.proteins.v11.5.txt",
		        "sequence_path": "667121.protein.sequences.v11.5.fa",
		        "enrichment_path": "667121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667121.protein.info.v11.5.txt",
		        "node_list_path": "667121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "667121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsplowo212Full6316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPLOWO2_12_FULL_63_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212Full6316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801871.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801871.protein.info.v11.5.txt",
		        "node_list_path": "1801871.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElsinoeAustralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elsinoe australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElsinoeAustralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40998.clusters.proteins.v11.5.txt",
		        "sequence_path": "40998.protein.sequences.v11.5.fa",
		        "enrichment_path": "40998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40998.protein.info.v11.5.txt",
		        "node_list_path": "40998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HistophilusSomni2336Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Histophilus somni 2336 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HistophilusSomni2336Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "228400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "228400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "228400.clusters.proteins.v11.5.txt",
		        "sequence_path": "228400.protein.sequences.v11.5.fa",
		        "enrichment_path": "228400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228400.protein.info.v11.5.txt",
		        "node_list_path": "228400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "228400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AerococcusSuis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus suis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusSuis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "371602.protein.sequences.v11.5.fa",
		        "enrichment_path": "371602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "371602.protein.info.v11.5.txt",
		        "node_list_path": "371602.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzonexusHydrophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azonexus hydrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzonexusHydrophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "418702.protein.sequences.v11.5.fa",
		        "enrichment_path": "418702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "418702.protein.info.v11.5.txt",
		        "node_list_path": "418702.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumLaevaniformansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium laevaniformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumLaevaniformansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36807.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36807.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36807.clusters.proteins.v11.5.txt",
		        "sequence_path": "36807.protein.sequences.v11.5.fa",
		        "enrichment_path": "36807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36807.protein.info.v11.5.txt",
		        "node_list_path": "36807.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36807.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphaeroformaArctica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphaeroforma arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaeroformaArctica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "72019.protein.sequences.v11.5.fa",
		        "enrichment_path": "72019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72019.protein.info.v11.5.txt",
		        "node_list_path": "72019.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerolineaeBacteriumUtcfx2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium UTCFX2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaeBacteriumUtcfx2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1961101.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961101.protein.info.v11.5.txt",
		        "node_list_path": "1961101.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesMassiliensis4401292Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces massiliensis 4401292 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesMassiliensis4401292Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1167628.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1167628.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1167628.clusters.proteins.v11.5.txt",
		        "sequence_path": "1167628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1167628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1167628.protein.info.v11.5.txt",
		        "node_list_path": "1167628.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1167628.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKisonensisF0435Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kisonensis F0435 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKisonensisF0435Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "797516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "797516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "797516.clusters.proteins.v11.5.txt",
		        "sequence_path": "797516.protein.sequences.v11.5.fa",
		        "enrichment_path": "797516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797516.protein.info.v11.5.txt",
		        "node_list_path": "797516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "797516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRedseaS12B4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium REDSEA-S12_B4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRedseaS12B4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811664.protein.info.v11.5.txt",
		        "node_list_path": "1811664.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumGw2011Gwc24418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWC2_44_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwc24418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618392.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618392.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618392.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618392.protein.info.v11.5.txt",
		        "node_list_path": "1618392.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618392.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaExalbida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia exalbida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaExalbida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206729.protein.info.v11.5.txt",
		        "node_list_path": "1206729.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumSpMs4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. MS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumSpMs4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120746.protein.sequences.v11.0.fa",
		        "enrichment_path": "1120746.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1120746.protein.info.v11.0.txt",
		        "node_list_path": "1120746.protein.complete.v11.0.txt"
		    }
		]
    )()

def LactobacillusHammesiiDsm16381Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hammesii DSM 16381 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHammesiiDsm16381Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423753.protein.info.v11.5.txt",
		        "node_list_path": "1423753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobiumLuteolum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium luteolum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumLuteolum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "319225.protein.sequences.v11.5.fa",
		        "enrichment_path": "319225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319225.protein.info.v11.5.txt",
		        "node_list_path": "319225.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaBelliiOsu85389(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia bellii OSU85389 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaBelliiOsu85389", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391896.protein.sequences.v11.5.fa",
		        "enrichment_path": "391896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391896.protein.info.v11.5.txt",
		        "node_list_path": "391896.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermogemmatisporaSpPm5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermogemmatispora sp. PM5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermogemmatisporaSpPm5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1382306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1382306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1382306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1382306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382306.protein.info.v11.5.txt",
		        "node_list_path": "1382306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1382306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasSpMor2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. Mor2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSpMor2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906738.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906738.protein.info.v11.5.txt",
		        "node_list_path": "1906738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBlackburnbacteriaBacteriumRifcsphigho212Full4113bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_12_FULL_41_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho212Full4113bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797517.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797517.protein.info.v11.5.txt",
		        "node_list_path": "1797517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag1320Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1320 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag1320Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262922.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262922.protein.info.v11.5.txt",
		        "node_list_path": "1262922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf198Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf198 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf198Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736299.protein.info.v11.5.txt",
		        "node_list_path": "1736299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpFb24Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. FB24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpFb24Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290399.clusters.proteins.v11.5.txt",
		        "sequence_path": "290399.protein.sequences.v11.5.fa",
		        "enrichment_path": "290399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290399.protein.info.v11.5.txt",
		        "node_list_path": "290399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSinopsychrotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sinopsychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSinopsychrotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "604089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "604089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "604089.clusters.proteins.v11.5.txt",
		        "sequence_path": "604089.protein.sequences.v11.5.fa",
		        "enrichment_path": "604089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "604089.protein.info.v11.5.txt",
		        "node_list_path": "604089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "604089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpNb68(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. NB68 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpNb68", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1342302.protein.sequences.v11.5.fa",
		        "enrichment_path": "1342302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1342302.protein.info.v11.5.txt",
		        "node_list_path": "1342302.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumDesmolans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium desmolans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumDesmolans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408437.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408437.protein.info.v11.5.txt",
		        "node_list_path": "1408437.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExophialaDermatitidisNihUt8656Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exophiala dermatitidis NIH/UT8656 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaDermatitidisNihUt8656Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "858893.clusters.info.v11.5.txt",
		        "cluster_tree_path": "858893.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "858893.clusters.proteins.v11.5.txt",
		        "sequence_path": "858893.protein.sequences.v11.5.fa",
		        "enrichment_path": "858893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "858893.protein.info.v11.5.txt",
		        "node_list_path": "858893.cluster.nodes.v11.5.txt",
		        "edge_list_path": "858893.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterXylinusNbrc15237(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus NBRC 15237 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterXylinusNbrc15237", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220579.protein.info.v11.5.txt",
		        "node_list_path": "1220579.protein.complete.v11.5.txt"
		    }
		]
    )()

def MalusDomestica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Malus domestica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalusDomestica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3750.protein.sequences.v11.5.fa",
		        "enrichment_path": "3750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3750.protein.info.v11.5.txt",
		        "node_list_path": "3750.protein.complete.v11.5.txt"
		    }
		]
    )()

def CanisLupusFamiliarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Canis lupus familiaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CanisLupusFamiliarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9615.clusters.proteins.v11.5.txt",
		        "sequence_path": "9615.protein.sequences.v11.5.fa",
		        "enrichment_path": "9615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9615.protein.info.v11.5.txt",
		        "node_list_path": "9615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphopichiaBurtoniiNrrlY1933(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphopichia burtonii NRRL Y-1933 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphopichiaBurtoniiNrrlY1933", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "984485.protein.sequences.v11.5.fa",
		        "enrichment_path": "984485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "984485.protein.info.v11.5.txt",
		        "node_list_path": "984485.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaSpR11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. R11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaSpR11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "439497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "439497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "439497.clusters.proteins.v11.5.txt",
		        "sequence_path": "439497.protein.sequences.v11.5.fa",
		        "enrichment_path": "439497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439497.protein.info.v11.5.txt",
		        "node_list_path": "439497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "439497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaueraLinaloolentisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera linaloolentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraLinaloolentisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123367.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123367.protein.info.v11.5.txt",
		        "node_list_path": "1123367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAd3010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AD3010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAd3010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410621.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410621.protein.info.v11.5.txt",
		        "node_list_path": "1410621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioVulgarisHildenborough(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio vulgaris Hildenborough graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioVulgarisHildenborough", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "882.protein.sequences.v11.5.fa",
		        "enrichment_path": "882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882.protein.info.v11.5.txt",
		        "node_list_path": "882.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArabidopsisLyrata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arabidopsis lyrata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArabidopsisLyrata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59689.protein.sequences.v11.5.fa",
		        "enrichment_path": "59689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59689.protein.info.v11.5.txt",
		        "node_list_path": "59689.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaCarneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia carnea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaCarneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206726.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206726.protein.info.v11.5.txt",
		        "node_list_path": "1206726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpCag1963641(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CAG:196_36_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpCag1963641", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896966.protein.info.v11.5.txt",
		        "node_list_path": "1896966.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaAquaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaAquaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1416759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1416759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1416759.clusters.proteins.v11.5.txt",
		        "sequence_path": "1416759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416759.protein.info.v11.5.txt",
		        "node_list_path": "1416759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1416759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterXylosoxidansNbrc15126(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans NBRC15126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterXylosoxidansNbrc15126", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216976.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216976.protein.info.v11.5.txt",
		        "node_list_path": "1216976.protein.complete.v11.5.txt"
		    }
		]
    )()

def SteroidobacterDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Steroidobacter denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SteroidobacterDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "465721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "465721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "465721.clusters.proteins.v11.5.txt",
		        "sequence_path": "465721.protein.sequences.v11.5.fa",
		        "enrichment_path": "465721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "465721.protein.info.v11.5.txt",
		        "node_list_path": "465721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "465721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyphaciaMuris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syphacia muris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyphaciaMuris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "451379.protein.sequences.v11.5.fa",
		        "enrichment_path": "451379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "451379.protein.info.v11.5.txt",
		        "node_list_path": "451379.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollimonasSpOk307Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collimonas sp. OK307 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollimonasSpOk307Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801620.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801620.protein.info.v11.5.txt",
		        "node_list_path": "1801620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriaSymbiontBfo1OfFrankliniellaOccidentalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo1 of Frankliniella occidentalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriaSymbiontBfo1OfFrankliniellaOccidentalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1628855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1628855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1628855.clusters.proteins.v11.5.txt",
		        "sequence_path": "1628855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628855.protein.info.v11.5.txt",
		        "node_list_path": "1628855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1628855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaSusongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia susongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaSusongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1515439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1515439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1515439.protein.info.v11.5.txt",
		        "node_list_path": "1515439.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasIndicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasIndicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "941907.clusters.info.v11.5.txt",
		        "cluster_tree_path": "941907.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "941907.clusters.proteins.v11.5.txt",
		        "sequence_path": "941907.protein.sequences.v11.5.fa",
		        "enrichment_path": "941907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "941907.protein.info.v11.5.txt",
		        "node_list_path": "941907.cluster.nodes.v11.5.txt",
		        "edge_list_path": "941907.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaMegalochromosomataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia megalochromosomata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaMegalochromosomataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1399969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1399969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1399969.clusters.proteins.v11.5.txt",
		        "sequence_path": "1399969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399969.protein.info.v11.5.txt",
		        "node_list_path": "1399969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1399969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaQuintanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella quintana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaQuintanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "283165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "283165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "283165.clusters.proteins.v11.5.txt",
		        "sequence_path": "283165.protein.sequences.v11.5.fa",
		        "enrichment_path": "283165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283165.protein.info.v11.5.txt",
		        "node_list_path": "283165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "283165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterPullorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pullorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterPullorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "537972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "537972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "537972.clusters.proteins.v11.5.txt",
		        "sequence_path": "537972.protein.sequences.v11.5.fa",
		        "enrichment_path": "537972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537972.protein.info.v11.5.txt",
		        "node_list_path": "537972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "537972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeoglobusAhangariCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geoglobus ahangari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeoglobusAhangariCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "113653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "113653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "113653.clusters.proteins.v11.5.txt",
		        "sequence_path": "113653.protein.sequences.v11.5.fa",
		        "enrichment_path": "113653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113653.protein.info.v11.5.txt",
		        "node_list_path": "113653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "113653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumRifcsphigho202Full4712(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_02_FULL_47_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho202Full4712", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802451.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802451.protein.info.v11.5.txt",
		        "node_list_path": "1802451.protein.complete.v11.5.txt"
		    }
		]
    )()

def AhrensiaSp13gom1096mCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ahrensia sp. 13GOM1096m Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AhrensiaSp13gom1096mCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380380.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380380.protein.info.v11.5.txt",
		        "node_list_path": "1380380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpBpaa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. BPAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpBpaa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229512.protein.info.v11.5.txt",
		        "node_list_path": "1229512.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylopilaSpM107(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylopila sp. M107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylopilaSpM107", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1101190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101190.protein.info.v11.5.txt",
		        "node_list_path": "1101190.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusEquigenerosi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus equigenerosi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusEquigenerosi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "417373.protein.sequences.v11.5.fa",
		        "enrichment_path": "417373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "417373.protein.info.v11.5.txt",
		        "node_list_path": "417373.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonosporascusSpMc138b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. MC13-8B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSpMc138b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2211646.protein.sequences.v11.5.fa",
		        "enrichment_path": "2211646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2211646.protein.info.v11.5.txt",
		        "node_list_path": "2211646.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesNourseiAtcc11455(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces noursei ATCC 11455 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesNourseiAtcc11455", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316284.protein.sequences.v11.5.fa",
		        "enrichment_path": "316284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316284.protein.info.v11.5.txt",
		        "node_list_path": "316284.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag545(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:545 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag545", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262742.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262742.protein.info.v11.5.txt",
		        "node_list_path": "1262742.protein.complete.v11.5.txt"
		    }
		]
    )()

def JiangellaAlkaliphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jiangella alkaliphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JiangellaAlkaliphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "419479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "419479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "419479.clusters.proteins.v11.5.txt",
		        "sequence_path": "419479.protein.sequences.v11.5.fa",
		        "enrichment_path": "419479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419479.protein.info.v11.5.txt",
		        "node_list_path": "419479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "419479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MameliellaAlbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mameliella alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MameliellaAlbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "561184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "561184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "561184.clusters.proteins.v11.5.txt",
		        "sequence_path": "561184.protein.sequences.v11.5.fa",
		        "enrichment_path": "561184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561184.protein.info.v11.5.txt",
		        "node_list_path": "561184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "561184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusSp6c8Div0013(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sp. 6C8_DIV0013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSp6c8Div0013", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1987385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1987385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1987385.protein.info.v11.5.txt",
		        "node_list_path": "1987385.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnabaenaVariabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anabaena variabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabaenaVariabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "240292.protein.sequences.v11.5.fa",
		        "enrichment_path": "240292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240292.protein.info.v11.5.txt",
		        "node_list_path": "240292.protein.complete.v11.5.txt"
		    }
		]
    )()

def TamlanaSedimentorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tamlana sedimentorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TamlanaSedimentorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1435349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1435349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1435349.clusters.proteins.v11.5.txt",
		        "sequence_path": "1435349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1435349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1435349.protein.info.v11.5.txt",
		        "node_list_path": "1435349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1435349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAle6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAle6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1266908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266908.protein.info.v11.5.txt",
		        "node_list_path": "1266908.protein.complete.v11.5.txt"
		    }
		]
    )()

def IntrasporangiumFlavumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Intrasporangium flavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntrasporangiumFlavumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1428657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1428657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1428657.clusters.proteins.v11.5.txt",
		        "sequence_path": "1428657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1428657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1428657.protein.info.v11.5.txt",
		        "node_list_path": "1428657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1428657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DanausPlexippus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Danaus plexippus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DanausPlexippus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13037.protein.sequences.v11.5.fa",
		        "enrichment_path": "13037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13037.protein.info.v11.5.txt",
		        "node_list_path": "13037.protein.complete.v11.5.txt"
		    }
		]
    )()

def PirellulaStaleyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pirellula staleyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PirellulaStaleyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "530564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "530564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "530564.clusters.proteins.v11.5.txt",
		        "sequence_path": "530564.protein.sequences.v11.5.fa",
		        "enrichment_path": "530564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "530564.protein.info.v11.5.txt",
		        "node_list_path": "530564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "530564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronococcusOccultus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronococcus occultus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronococcusOccultus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "694430.protein.sequences.v11.5.fa",
		        "enrichment_path": "694430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694430.protein.info.v11.5.txt",
		        "node_list_path": "694430.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaAlbicansSc5314(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida albicans SC5314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaAlbicansSc5314", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "237561.protein.sequences.v11.5.fa",
		        "enrichment_path": "237561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237561.protein.info.v11.5.txt",
		        "node_list_path": "237561.protein.complete.v11.5.txt"
		    }
		]
    )()

def MediterraneaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mediterranea massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MediterraneaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841865.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841865.protein.info.v11.5.txt",
		        "node_list_path": "1841865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaSpMd25a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sp. MD25a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaSpMd25a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1889913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889913.protein.info.v11.5.txt",
		        "node_list_path": "1889913.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasMonteiliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas monteilii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMonteiliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "76759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "76759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "76759.clusters.proteins.v11.5.txt",
		        "sequence_path": "76759.protein.sequences.v11.5.fa",
		        "enrichment_path": "76759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76759.protein.info.v11.5.txt",
		        "node_list_path": "76759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "76759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentinusTigrinusAlcf2ss16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentinus tigrinus ALCF2SS1-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentinusTigrinusAlcf2ss16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1328759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1328759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1328759.protein.info.v11.5.txt",
		        "node_list_path": "1328759.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaSp9145(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia sp. 9145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaSp9145", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500895.protein.info.v11.5.txt",
		        "node_list_path": "1500895.protein.complete.v11.5.txt"
		    }
		]
    )()

def PucciniaGraminisFSpTriticiCrl75367003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Puccinia graminis f. sp. tritici CRL 75-36-700-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PucciniaGraminisFSpTriticiCrl75367003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "418459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "418459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "418459.clusters.proteins.v11.5.txt",
		        "sequence_path": "418459.protein.sequences.v11.5.fa",
		        "enrichment_path": "418459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "418459.protein.info.v11.5.txt",
		        "node_list_path": "418459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "418459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaueraLinaloolentis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thauera linaloolentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraLinaloolentis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123367.protein.info.v11.5.txt",
		        "node_list_path": "1123367.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpC448Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. C448 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpC448Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1177594.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1177594.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1177594.clusters.proteins.v11.5.txt",
		        "sequence_path": "1177594.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177594.protein.info.v11.5.txt",
		        "node_list_path": "1177594.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1177594.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AvibacteriumParagallinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AvibacteriumParagallinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "728.clusters.info.v11.5.txt",
		        "cluster_tree_path": "728.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "728.clusters.proteins.v11.5.txt",
		        "sequence_path": "728.protein.sequences.v11.5.fa",
		        "enrichment_path": "728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "728.protein.info.v11.5.txt",
		        "node_list_path": "728.cluster.nodes.v11.5.txt",
		        "edge_list_path": "728.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumCsp17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium CSP1-7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumCsp17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1576480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1576480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1576480.clusters.proteins.v11.5.txt",
		        "sequence_path": "1576480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1576480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1576480.protein.info.v11.5.txt",
		        "node_list_path": "1576480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1576480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnobacteriumBovis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnobacterium bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnobacteriumBovis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "140626.protein.sequences.v11.5.fa",
		        "enrichment_path": "140626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "140626.protein.info.v11.5.txt",
		        "node_list_path": "140626.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacterium6626(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 66-26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacterium6626", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895727.protein.info.v11.5.txt",
		        "node_list_path": "1895727.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumGjE10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GJ-E10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumGjE10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1469502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1469502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1469502.clusters.proteins.v11.5.txt",
		        "sequence_path": "1469502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469502.protein.info.v11.5.txt",
		        "node_list_path": "1469502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1469502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumRbg163414Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RBG_16_34_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumRbg163414Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798433.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798433.protein.info.v11.5.txt",
		        "node_list_path": "1798433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLeaf262Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf262 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLeaf262Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736312.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736312.protein.info.v11.5.txt",
		        "node_list_path": "1736312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VirgibacillusHalodenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus halodenitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusHalodenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196028.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196028.protein.info.v11.5.txt",
		        "node_list_path": "1196028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAlkylphenolia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alkylphenolia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAlkylphenolia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "237609.protein.sequences.v11.5.fa",
		        "enrichment_path": "237609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237609.protein.info.v11.5.txt",
		        "node_list_path": "237609.protein.complete.v11.5.txt"
		    }
		]
    )()

def PongoAbelii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pongo abelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PongoAbelii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9601.protein.sequences.v11.5.fa",
		        "enrichment_path": "9601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9601.protein.info.v11.5.txt",
		        "node_list_path": "9601.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaPatagoniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichinella patagoniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaPatagoniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "990121.protein.sequences.v11.5.fa",
		        "enrichment_path": "990121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990121.protein.info.v11.5.txt",
		        "node_list_path": "990121.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaHigoensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia higoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaHigoensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206730.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206730.protein.info.v11.5.txt",
		        "node_list_path": "1206730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNasuiaDeltocephalinicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nasuia deltocephalinicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNasuiaDeltocephalinicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1160784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160784.protein.info.v11.5.txt",
		        "node_list_path": "1160784.protein.complete.v11.5.txt"
		    }
		]
    )()

def HoldemaniaFiliformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Holdemania filiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoldemaniaFiliformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "545696.protein.sequences.v11.5.fa",
		        "enrichment_path": "545696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545696.protein.info.v11.5.txt",
		        "node_list_path": "545696.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterDaqiaonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter daqiaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterDaqiaonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "650891.protein.sequences.v11.5.fa",
		        "enrichment_path": "650891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "650891.protein.info.v11.5.txt",
		        "node_list_path": "650891.protein.complete.v11.5.txt"
		    }
		]
    )()

def LichtheimiaCorymbiferaJmrcFsu9682Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lichtheimia corymbifera JMRC:FSU:9682 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LichtheimiaCorymbiferaJmrcFsu9682Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263082.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263082.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263082.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263082.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263082.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263082.protein.info.v11.5.txt",
		        "node_list_path": "1263082.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263082.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonlabensMarinusS108Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens marinus S1-08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensMarinusS108Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1454201.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1454201.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1454201.clusters.proteins.v11.5.txt",
		        "sequence_path": "1454201.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454201.protein.info.v11.5.txt",
		        "node_list_path": "1454201.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1454201.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnochordaPilosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnochorda pilosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnochordaPilosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1555112.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1555112.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1555112.clusters.proteins.v11.5.txt",
		        "sequence_path": "1555112.protein.sequences.v11.5.fa",
		        "enrichment_path": "1555112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1555112.protein.info.v11.5.txt",
		        "node_list_path": "1555112.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1555112.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumChungbukenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium chungbukense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumChungbukenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56193.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56193.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56193.clusters.proteins.v11.5.txt",
		        "sequence_path": "56193.protein.sequences.v11.5.fa",
		        "enrichment_path": "56193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56193.protein.info.v11.5.txt",
		        "node_list_path": "56193.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56193.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24610Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_46_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24610Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618835.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618835.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618835.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618835.protein.info.v11.5.txt",
		        "node_list_path": "1618835.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618835.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesLavenduligriseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces lavenduligriseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesLavenduligriseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67315.protein.sequences.v11.5.fa",
		        "enrichment_path": "67315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67315.protein.info.v11.5.txt",
		        "node_list_path": "67315.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag492(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:492 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag492", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262813.protein.info.v11.5.txt",
		        "node_list_path": "1262813.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParachlamydiaceaeBacteriumHsT3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parachlamydiaceae bacterium HS-T3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParachlamydiaceaeBacteriumHsT3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314958.protein.info.v11.5.txt",
		        "node_list_path": "1314958.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSp103mfCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 103mf Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp103mfCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761751.protein.info.v11.5.txt",
		        "node_list_path": "1761751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifoxya2Full3621(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFOXYA2_FULL_36_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxya2Full3621", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802572.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802572.protein.info.v11.5.txt",
		        "node_list_path": "1802572.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSubtilisSubspSpizizeniiTuB10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. spizizenii TU-B-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSubtilisSubspSpizizeniiTuB10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1052585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1052585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1052585.clusters.proteins.v11.5.txt",
		        "sequence_path": "1052585.protein.sequences.v11.5.fa",
		        "enrichment_path": "1052585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1052585.protein.info.v11.5.txt",
		        "node_list_path": "1052585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1052585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyadobacterKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "408657.protein.sequences.v11.5.fa",
		        "enrichment_path": "408657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408657.protein.info.v11.5.txt",
		        "node_list_path": "408657.protein.complete.v11.5.txt"
		    }
		]
    )()

def SuccinispiraMobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Succinispira mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuccinispiraMobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1069080.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1069080.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1069080.clusters.proteins.v11.5.txt",
		        "sequence_path": "1069080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069080.protein.info.v11.5.txt",
		        "node_list_path": "1069080.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1069080.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporosarcinaSpEur3222(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina sp. EUR3222 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaSpEur3222", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1305836.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305836.protein.info.v11.5.txt",
		        "node_list_path": "1305836.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrrellaDioscoreae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Orrella dioscoreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrrellaDioscoreae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1851544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1851544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1851544.protein.info.v11.5.txt",
		        "node_list_path": "1851544.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpHmsc065f10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. HMSC065F10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpHmsc065f10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739394.protein.info.v11.5.txt",
		        "node_list_path": "1739394.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaChersina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora chersina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaChersina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47854.protein.sequences.v11.5.fa",
		        "enrichment_path": "47854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47854.protein.info.v11.5.txt",
		        "node_list_path": "47854.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpRoot209(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. Root209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpRoot209", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736490.protein.info.v11.5.txt",
		        "node_list_path": "1736490.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrnithinimicrobiumSpCnj824Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ornithinimicrobium sp. CNJ-824 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithinimicrobiumSpCnj824Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1904966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1904966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1904966.clusters.proteins.v11.5.txt",
		        "sequence_path": "1904966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904966.protein.info.v11.5.txt",
		        "node_list_path": "1904966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1904966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPurpureusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces purpureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPurpureusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1054860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1054860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1054860.clusters.proteins.v11.5.txt",
		        "sequence_path": "1054860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1054860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1054860.protein.info.v11.5.txt",
		        "node_list_path": "1054860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1054860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwe13228Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWE1_32_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwe13228Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618760.protein.info.v11.5.txt",
		        "node_list_path": "1618760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumJejuenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium jejuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumJejuenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445960.clusters.proteins.v11.5.txt",
		        "sequence_path": "445960.protein.sequences.v11.5.fa",
		        "enrichment_path": "445960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445960.protein.info.v11.5.txt",
		        "node_list_path": "445960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaAraiiNbrc100433Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia araii NBRC 100433 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaAraiiNbrc100433Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1073574.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1073574.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1073574.clusters.proteins.v11.5.txt",
		        "sequence_path": "1073574.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073574.protein.info.v11.5.txt",
		        "node_list_path": "1073574.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1073574.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpOk602(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ok602 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpOk602", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761898.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761898.protein.info.v11.5.txt",
		        "node_list_path": "1761898.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterUreolyticusRigs9880Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter ureolyticus RIGS 9880 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterUreolyticusRigs9880Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1032069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1032069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1032069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1032069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1032069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1032069.protein.info.v11.5.txt",
		        "node_list_path": "1032069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1032069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumSpAf4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumSpAf4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1325735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325735.protein.info.v11.5.txt",
		        "node_list_path": "1325735.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelosinusPropionicusDsm13327Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus propionicus DSM 13327 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelosinusPropionicusDsm13327Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123291.protein.info.v11.5.txt",
		        "node_list_path": "1123291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanimonasSpGk1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanimonas sp. GK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanimonasSpGk1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "511062.protein.sequences.v11.5.fa",
		        "enrichment_path": "511062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511062.protein.info.v11.5.txt",
		        "node_list_path": "511062.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSanguinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSanguinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33051.clusters.proteins.v11.5.txt",
		        "sequence_path": "33051.protein.sequences.v11.5.fa",
		        "enrichment_path": "33051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33051.protein.info.v11.5.txt",
		        "node_list_path": "33051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusObscuribacterPhosphatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Obscuribacter phosphatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusObscuribacterPhosphatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906157.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906157.protein.info.v11.5.txt",
		        "node_list_path": "1906157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasRhizosphaeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasRhizosphaeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216142.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216142.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216142.clusters.proteins.v11.5.txt",
		        "sequence_path": "216142.protein.sequences.v11.5.fa",
		        "enrichment_path": "216142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216142.protein.info.v11.5.txt",
		        "node_list_path": "216142.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216142.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferAgarilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer agarilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferAgarilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1042377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1042377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1042377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1042377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042377.protein.info.v11.5.txt",
		        "node_list_path": "1042377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1042377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioSpUcdFrssp1630Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. UCD-FRSSP16_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpUcdFrssp1630Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1853258.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1853258.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1853258.clusters.proteins.v11.5.txt",
		        "sequence_path": "1853258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1853258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1853258.protein.info.v11.5.txt",
		        "node_list_path": "1853258.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1853258.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4226(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_42_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4226", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797729.protein.info.v11.5.txt",
		        "node_list_path": "1797729.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrackiellaOedipodisDsm13743Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brackiella oedipodis DSM 13743 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrackiellaOedipodisDsm13743Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121118.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121118.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121118.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121118.protein.info.v11.5.txt",
		        "node_list_path": "1121118.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121118.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAlgidicarnis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium algidicarnis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAlgidicarnis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37659.protein.sequences.v11.5.fa",
		        "enrichment_path": "37659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37659.protein.info.v11.5.txt",
		        "node_list_path": "37659.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasRubra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasRubra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634430.protein.sequences.v11.5.fa",
		        "enrichment_path": "634430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634430.protein.info.v11.5.txt",
		        "node_list_path": "634430.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCoyleae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium coyleae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCoyleae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53374.protein.sequences.v11.5.fa",
		        "enrichment_path": "53374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53374.protein.info.v11.5.txt",
		        "node_list_path": "53374.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchwartziaSuccinivoransDsm10502Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schwartzia succinivorans DSM 10502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchwartziaSuccinivoransDsm10502Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123243.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123243.protein.info.v11.5.txt",
		        "node_list_path": "1123243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesMarseillensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces marseillensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesMarseillensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852376.protein.info.v11.5.txt",
		        "node_list_path": "1852376.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterTyphloniusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter typhlonius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterTyphloniusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "76936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "76936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "76936.clusters.proteins.v11.5.txt",
		        "sequence_path": "76936.protein.sequences.v11.5.fa",
		        "enrichment_path": "76936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76936.protein.info.v11.5.txt",
		        "node_list_path": "76936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "76936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KitasatosporaAzaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora azatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaAzaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449346.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449346.protein.info.v11.5.txt",
		        "node_list_path": "1449346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterCurvus52592Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter curvus 525.92 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterCurvus52592Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "360105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "360105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "360105.clusters.proteins.v11.5.txt",
		        "sequence_path": "360105.protein.sequences.v11.5.fa",
		        "enrichment_path": "360105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360105.protein.info.v11.5.txt",
		        "node_list_path": "360105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "360105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonasSpRw2a1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. RW2A1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasSpRw2a1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1917158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1917158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1917158.clusters.proteins.v11.5.txt",
		        "sequence_path": "1917158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917158.protein.info.v11.5.txt",
		        "node_list_path": "1917158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1917158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BeijerinckiaMobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Beijerinckia mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeijerinckiaMobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "231434.protein.sequences.v11.5.fa",
		        "enrichment_path": "231434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "231434.protein.info.v11.5.txt",
		        "node_list_path": "231434.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisB6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis B6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisB6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "365659.protein.sequences.v11.5.fa",
		        "enrichment_path": "365659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "365659.protein.info.v11.5.txt",
		        "node_list_path": "365659.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumFrediiUsda257(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii USDA257 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumFrediiUsda257", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1185652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185652.protein.info.v11.5.txt",
		        "node_list_path": "1185652.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasJinjuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas jinjuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasJinjuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "198616.protein.sequences.v11.5.fa",
		        "enrichment_path": "198616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198616.protein.info.v11.5.txt",
		        "node_list_path": "198616.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArabidopsisLyrataSubspLyrata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arabidopsis lyrata subsp. lyrata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArabidopsisLyrataSubspLyrata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "81972.protein.sequences.v11.5.fa",
		        "enrichment_path": "81972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81972.protein.info.v11.5.txt",
		        "node_list_path": "81972.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpHgb0020Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. HGB0020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpHgb0020Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1078086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1078086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1078086.clusters.proteins.v11.5.txt",
		        "sequence_path": "1078086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078086.protein.info.v11.5.txt",
		        "node_list_path": "1078086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1078086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpJccCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. JCC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpJccCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1414720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1414720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1414720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1414720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414720.protein.info.v11.5.txt",
		        "node_list_path": "1414720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1414720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlj16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlj16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158762.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158762.protein.info.v11.5.txt",
		        "node_list_path": "1158762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusUvarumCbs121591(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus uvarum CBS 121591 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusUvarumCbs121591", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1448315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448315.protein.info.v11.5.txt",
		        "node_list_path": "1448315.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlautiaSpYl58(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blautia sp. YL58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaSpYl58", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1796616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796616.protein.info.v11.5.txt",
		        "node_list_path": "1796616.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasDiminuta4704Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas diminuta 4704 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasDiminuta4704Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035191.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035191.protein.info.v11.5.txt",
		        "node_list_path": "1035191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerrapeneCarolinaTriunguisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terrapene carolina triunguis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrapeneCarolinaTriunguisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2587831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2587831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2587831.clusters.proteins.v11.5.txt",
		        "sequence_path": "2587831.protein.sequences.v11.5.fa",
		        "enrichment_path": "2587831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2587831.protein.info.v11.5.txt",
		        "node_list_path": "2587831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2587831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TumebacillusFlagellatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tumebacillus flagellatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TumebacillusFlagellatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157490.protein.info.v11.5.txt",
		        "node_list_path": "1157490.protein.complete.v11.5.txt"
		    }
		]
    )()

def WenyingzhuangiaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wenyingzhuangia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WenyingzhuangiaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1195760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1195760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1195760.protein.info.v11.5.txt",
		        "node_list_path": "1195760.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasIssachenkoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas issachenkonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasIssachenkoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "152297.clusters.info.v11.5.txt",
		        "cluster_tree_path": "152297.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "152297.clusters.proteins.v11.5.txt",
		        "sequence_path": "152297.protein.sequences.v11.5.fa",
		        "enrichment_path": "152297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "152297.protein.info.v11.5.txt",
		        "node_list_path": "152297.cluster.nodes.v11.5.txt",
		        "edge_list_path": "152297.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsphigho201Full4213Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO2_01_FULL_42_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201Full4213Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802617.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802617.protein.info.v11.5.txt",
		        "node_list_path": "1802617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolfiporiaCocosMd104Ss10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wolfiporia cocos MD-104 SS10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolfiporiaCocosMd104Ss10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742152.protein.sequences.v11.5.fa",
		        "enrichment_path": "742152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742152.protein.info.v11.5.txt",
		        "node_list_path": "742152.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxPacificusW115Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax pacificus W11-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxPacificusW115Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391936.clusters.proteins.v11.5.txt",
		        "sequence_path": "391936.protein.sequences.v11.5.fa",
		        "enrichment_path": "391936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391936.protein.info.v11.5.txt",
		        "node_list_path": "391936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaSeriolaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia seriolae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSeriolaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37332.clusters.proteins.v11.5.txt",
		        "sequence_path": "37332.protein.sequences.v11.5.fa",
		        "enrichment_path": "37332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37332.protein.info.v11.5.txt",
		        "node_list_path": "37332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JatrophaCurcasCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jatropha curcas Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JatrophaCurcasCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "180498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "180498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "180498.clusters.proteins.v11.5.txt",
		        "sequence_path": "180498.protein.sequences.v11.5.fa",
		        "enrichment_path": "180498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180498.protein.info.v11.5.txt",
		        "node_list_path": "180498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "180498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EdhazardiaAedisUsnm41457(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Edhazardia aedis USNM 41457 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EdhazardiaAedisUsnm41457", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1003232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1003232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1003232.protein.info.v11.5.txt",
		        "node_list_path": "1003232.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobaculumParvum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobaculum parvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobaculumParvum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "517417.protein.sequences.v11.5.fa",
		        "enrichment_path": "517417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "517417.protein.info.v11.5.txt",
		        "node_list_path": "517417.protein.complete.v11.5.txt"
		    }
		]
    )()

def CardiniumEndosymbiontCeper1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cardinium endosymbiont cEper1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CardiniumEndosymbiontCeper1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231626.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231626.protein.info.v11.5.txt",
		        "node_list_path": "1231626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusHordeiDsm19519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hordei DSM 19519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHordeiDsm19519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423759.protein.info.v11.5.txt",
		        "node_list_path": "1423759.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumFrisingenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum frisingense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumFrisingenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "864073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "864073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "864073.clusters.proteins.v11.5.txt",
		        "sequence_path": "864073.protein.sequences.v11.5.fa",
		        "enrichment_path": "864073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864073.protein.info.v11.5.txt",
		        "node_list_path": "864073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "864073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaludisphaeraBorealisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paludisphaera borealis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaludisphaeraBorealisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1387353.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1387353.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1387353.clusters.proteins.v11.5.txt",
		        "sequence_path": "1387353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387353.protein.info.v11.5.txt",
		        "node_list_path": "1387353.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1387353.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioRhizosphaeraeDsm18581(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio rhizosphaerae DSM 18581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioRhizosphaeraeDsm18581", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123497.protein.info.v11.5.txt",
		        "node_list_path": "1123497.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPsychrotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPsychrotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1112217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112217.protein.info.v11.5.txt",
		        "node_list_path": "1112217.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpCm6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. CM6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpCm6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936580.protein.sequences.v11.5.fa",
		        "enrichment_path": "936580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936580.protein.info.v11.5.txt",
		        "node_list_path": "936580.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrospiraPlatensisYzCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrospira platensis YZ Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrospiraPlatensisYzCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1738638.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1738638.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1738638.clusters.proteins.v11.5.txt",
		        "sequence_path": "1738638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1738638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1738638.protein.info.v11.5.txt",
		        "node_list_path": "1738638.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1738638.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumTumefaciensF2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens F2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumTumefaciensF2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1050720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1050720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1050720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1050720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1050720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1050720.protein.info.v11.5.txt",
		        "node_list_path": "1050720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1050720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobiusGelatinovorusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassobius gelatinovorus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobiusGelatinovorusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53501.clusters.proteins.v11.5.txt",
		        "sequence_path": "53501.protein.sequences.v11.5.fa",
		        "enrichment_path": "53501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53501.protein.info.v11.5.txt",
		        "node_list_path": "53501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HordeumVulgare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hordeum vulgare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HordeumVulgare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4513.protein.sequences.v11.5.fa",
		        "enrichment_path": "4513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4513.protein.info.v11.5.txt",
		        "node_list_path": "4513.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpathasporaSpJa1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spathaspora sp. JA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpathasporaSpJa1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2028339.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2028339.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2028339.clusters.proteins.v11.5.txt",
		        "sequence_path": "2028339.protein.sequences.v11.5.fa",
		        "enrichment_path": "2028339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2028339.protein.info.v11.5.txt",
		        "node_list_path": "2028339.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2028339.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMerionis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus merionis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMerionis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123308.protein.info.v11.5.txt",
		        "node_list_path": "1123308.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesMisionensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces misionensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesMisionensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67331.protein.sequences.v11.5.fa",
		        "enrichment_path": "67331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67331.protein.info.v11.5.txt",
		        "node_list_path": "67331.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterCurvatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter curvatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterCurvatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "49547.protein.sequences.v11.5.fa",
		        "enrichment_path": "49547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "49547.protein.info.v11.5.txt",
		        "node_list_path": "49547.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriTs44(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri TS44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriTs44", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "477228.protein.sequences.v11.5.fa",
		        "enrichment_path": "477228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477228.protein.info.v11.5.txt",
		        "node_list_path": "477228.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliellaAfzeliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borreliella afzelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliellaAfzeliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29518.clusters.proteins.v11.5.txt",
		        "sequence_path": "29518.protein.sequences.v11.5.fa",
		        "enrichment_path": "29518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29518.protein.info.v11.5.txt",
		        "node_list_path": "29518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonadalesBacteriumEhc05Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium EhC05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonadalesBacteriumEhc05Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849171.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849171.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849171.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849171.protein.info.v11.5.txt",
		        "node_list_path": "1849171.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849171.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAvicenniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces avicenniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAvicenniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "500153.protein.sequences.v11.5.fa",
		        "enrichment_path": "500153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500153.protein.info.v11.5.txt",
		        "node_list_path": "500153.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110053Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110053 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110053Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1570342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1570342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1570342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1570342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570342.protein.info.v11.5.txt",
		        "node_list_path": "1570342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1570342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumOryziradicis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium oryziradicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumOryziradicis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1867956.protein.sequences.v11.5.fa",
		        "enrichment_path": "1867956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1867956.protein.info.v11.5.txt",
		        "node_list_path": "1867956.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumSpRoot236Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root236 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumSpRoot236Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736498.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736498.protein.info.v11.5.txt",
		        "node_list_path": "1736498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaGallisepticumS6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum S6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaGallisepticumS6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1006581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1006581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1006581.protein.info.v11.5.txt",
		        "node_list_path": "1006581.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinospirillumInsulareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinospirillum insulare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinospirillumInsulareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122211.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122211.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122211.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122211.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122211.protein.info.v11.5.txt",
		        "node_list_path": "1122211.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122211.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenibacterCertesiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenibacter certesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenibacterCertesiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121011.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121011.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121011.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121011.protein.info.v11.5.txt",
		        "node_list_path": "1121011.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121011.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusPastoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus pastoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusPastoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59919.protein.sequences.v11.5.fa",
		        "enrichment_path": "59919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59919.protein.info.v11.5.txt",
		        "node_list_path": "59919.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpNfr12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpNfr12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566261.protein.info.v11.5.txt",
		        "node_list_path": "1566261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylothermusHellenicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylothermus hellenicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylothermusHellenicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "591019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "591019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "591019.clusters.proteins.v11.5.txt",
		        "sequence_path": "591019.protein.sequences.v11.5.fa",
		        "enrichment_path": "591019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591019.protein.info.v11.5.txt",
		        "node_list_path": "591019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "591019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusJeotgaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusJeotgaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "129985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "129985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "129985.clusters.proteins.v11.5.txt",
		        "sequence_path": "129985.protein.sequences.v11.5.fa",
		        "enrichment_path": "129985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "129985.protein.info.v11.5.txt",
		        "node_list_path": "129985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "129985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpNfr07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpNfr07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566262.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566262.protein.info.v11.5.txt",
		        "node_list_path": "1566262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3719Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_02_FULL_37_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3719Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802072.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802072.protein.info.v11.5.txt",
		        "node_list_path": "1802072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrococcusSpNa2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus sp. NA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusSpNa2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "342949.clusters.info.v11.5.txt",
		        "cluster_tree_path": "342949.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "342949.clusters.proteins.v11.5.txt",
		        "sequence_path": "342949.protein.sequences.v11.5.fa",
		        "enrichment_path": "342949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342949.protein.info.v11.5.txt",
		        "node_list_path": "342949.cluster.nodes.v11.5.txt",
		        "edge_list_path": "342949.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterLutiphocae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter lutiphocae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterLutiphocae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123033.protein.info.v11.5.txt",
		        "node_list_path": "1123033.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoranellaEndobiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moranella endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoranellaEndobiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "903503.clusters.info.v11.5.txt",
		        "cluster_tree_path": "903503.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "903503.clusters.proteins.v11.5.txt",
		        "sequence_path": "903503.protein.sequences.v11.5.fa",
		        "enrichment_path": "903503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903503.protein.info.v11.5.txt",
		        "node_list_path": "903503.cluster.nodes.v11.5.txt",
		        "edge_list_path": "903503.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusGonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus gonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusGonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "198467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "198467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "198467.clusters.proteins.v11.5.txt",
		        "sequence_path": "198467.protein.sequences.v11.5.fa",
		        "enrichment_path": "198467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198467.protein.info.v11.5.txt",
		        "node_list_path": "198467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "198467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpYk2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. YK2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpYk2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1860096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860096.protein.info.v11.5.txt",
		        "node_list_path": "1860096.protein.complete.v11.5.txt"
		    }
		]
    )()

def RunellaSlithyformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Runella slithyformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RunellaSlithyformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "761193.clusters.info.v11.5.txt",
		        "cluster_tree_path": "761193.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "761193.clusters.proteins.v11.5.txt",
		        "sequence_path": "761193.protein.sequences.v11.5.fa",
		        "enrichment_path": "761193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "761193.protein.info.v11.5.txt",
		        "node_list_path": "761193.cluster.nodes.v11.5.txt",
		        "edge_list_path": "761193.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaSpTnd4ek4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. TND4EK4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpTnd4ek4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907408.protein.info.v11.5.txt",
		        "node_list_path": "1907408.protein.complete.v11.5.txt"
		    }
		]
    )()

def EquusAsinusAsinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Equus asinus asinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EquusAsinusAsinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83772.protein.sequences.v11.5.fa",
		        "enrichment_path": "83772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83772.protein.info.v11.5.txt",
		        "node_list_path": "83772.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwa2378Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_37_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa2378Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619036.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619036.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619036.protein.info.v11.5.txt",
		        "node_list_path": "1619036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermocrinisRuber(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermocrinis ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocrinisRuber", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "932678.protein.sequences.v11.5.fa",
		        "enrichment_path": "932678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932678.protein.info.v11.5.txt",
		        "node_list_path": "932678.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaFairfieldensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella fairfieldensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaFairfieldensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408444.protein.info.v11.5.txt",
		        "node_list_path": "1408444.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAbawacabacteriaBacteriumRbg164210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Abawacabacteria bacterium RBG_16_42_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAbawacabacteriaBacteriumRbg164210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817814.protein.info.v11.5.txt",
		        "node_list_path": "1817814.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusUreilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus ureilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusUreilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "531814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "531814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "531814.clusters.proteins.v11.5.txt",
		        "sequence_path": "531814.protein.sequences.v11.5.fa",
		        "enrichment_path": "531814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "531814.protein.info.v11.5.txt",
		        "node_list_path": "531814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "531814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodovulumSpNi22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. NI22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovulumSpNi22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1469613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1469613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1469613.clusters.proteins.v11.5.txt",
		        "sequence_path": "1469613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469613.protein.info.v11.5.txt",
		        "node_list_path": "1469613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1469613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu023Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu023Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671649.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671649.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671649.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671649.protein.info.v11.5.txt",
		        "node_list_path": "1671649.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671649.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloferulaStellataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloferula stellata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloferulaStellataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "876269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "876269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "876269.clusters.proteins.v11.5.txt",
		        "sequence_path": "876269.protein.sequences.v11.5.fa",
		        "enrichment_path": "876269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "876269.protein.info.v11.5.txt",
		        "node_list_path": "876269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "876269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RothiaNasimurium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rothia nasimurium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RothiaNasimurium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "85336.protein.sequences.v11.5.fa",
		        "enrichment_path": "85336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85336.protein.info.v11.5.txt",
		        "node_list_path": "85336.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu036Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU036 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu036Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671651.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671651.protein.info.v11.5.txt",
		        "node_list_path": "1671651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LabrenziaAggregata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Labrenzia aggregata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrenziaAggregata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "384765.protein.sequences.v11.5.fa",
		        "enrichment_path": "384765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "384765.protein.info.v11.5.txt",
		        "node_list_path": "384765.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaMelliferum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma melliferum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaMelliferum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1129368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1129368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1129368.protein.info.v11.5.txt",
		        "node_list_path": "1129368.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumQ1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium Q-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumQ1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1492281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1492281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1492281.protein.info.v11.5.txt",
		        "node_list_path": "1492281.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumImcc3088(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium IMCC3088 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumImcc3088", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "876044.protein.sequences.v11.5.fa",
		        "enrichment_path": "876044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "876044.protein.info.v11.5.txt",
		        "node_list_path": "876044.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenovibrioSpMa26Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenovibrio sp. MA2-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenovibrioSpMa26Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449087.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449087.protein.info.v11.5.txt",
		        "node_list_path": "1449087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinosynnemaSpAli144(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinosynnema sp. ALI-1.44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinosynnemaSpAli144", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1933779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933779.protein.info.v11.5.txt",
		        "node_list_path": "1933779.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumUterequi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium uterequi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumUterequi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1072256.protein.sequences.v11.5.fa",
		        "enrichment_path": "1072256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1072256.protein.info.v11.5.txt",
		        "node_list_path": "1072256.protein.complete.v11.5.txt"
		    }
		]
    )()

def SunxiuqiniaDokdonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sunxiuqinia dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SunxiuqiniaDokdonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1409788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1409788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1409788.protein.info.v11.5.txt",
		        "node_list_path": "1409788.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomonasSpFbcdCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas sp. FBCd Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomonasSpFbcdCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158292.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158292.protein.info.v11.5.txt",
		        "node_list_path": "1158292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4534bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_01_FULL_45_34b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4534bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802320.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802320.protein.info.v11.5.txt",
		        "node_list_path": "1802320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpRoot133(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. Root133 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpRoot133", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736455.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736455.protein.info.v11.5.txt",
		        "node_list_path": "1736455.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumParaoxydans77mftsu32Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium paraoxydans 77MFTsu32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumParaoxydans77mftsu32Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1151126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1151126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1151126.clusters.proteins.v11.5.txt",
		        "sequence_path": "1151126.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151126.protein.info.v11.5.txt",
		        "node_list_path": "1151126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1151126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArachidicoccusSpBs20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arachidicoccus sp. BS20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArachidicoccusSpBs20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1850526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850526.protein.info.v11.5.txt",
		        "node_list_path": "1850526.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSp233421I1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 23342-1-I1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSp233421I1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1524831.protein.sequences.v11.5.fa",
		        "enrichment_path": "1524831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1524831.protein.info.v11.5.txt",
		        "node_list_path": "1524831.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylosinusSpLw4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylosinus sp. LW4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylosinusSpLw4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "136993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "136993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "136993.clusters.proteins.v11.5.txt",
		        "sequence_path": "136993.protein.sequences.v11.5.fa",
		        "enrichment_path": "136993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "136993.protein.info.v11.5.txt",
		        "node_list_path": "136993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "136993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterButzleriRm4018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter butzleri RM4018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterButzleriRm4018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "367737.protein.sequences.v11.5.fa",
		        "enrichment_path": "367737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "367737.protein.info.v11.5.txt",
		        "node_list_path": "367737.protein.complete.v11.5.txt"
		    }
		]
    )()

def JonesiaQuinghaiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jonesia quinghaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JonesiaQuinghaiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122130.protein.info.v11.5.txt",
		        "node_list_path": "1122130.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpAb215(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB215 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpAb215", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841861.protein.info.v11.5.txt",
		        "node_list_path": "1841861.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumCiceriBiovar(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium ciceri biovar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumCiceriBiovar", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765698.protein.sequences.v11.5.fa",
		        "enrichment_path": "765698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765698.protein.info.v11.5.txt",
		        "node_list_path": "765698.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCfSaccharolyticumK10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] cf. saccharolyticum K10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCfSaccharolyticumK10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717608.protein.sequences.v11.5.fa",
		        "enrichment_path": "717608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717608.protein.info.v11.5.txt",
		        "node_list_path": "717608.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndocarponPusillum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Endocarpon pusillum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndocarponPusillum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "364733.protein.sequences.v11.5.fa",
		        "enrichment_path": "364733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "364733.protein.info.v11.5.txt",
		        "node_list_path": "364733.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "394264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "394264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "394264.clusters.proteins.v11.5.txt",
		        "sequence_path": "394264.protein.sequences.v11.5.fa",
		        "enrichment_path": "394264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394264.protein.info.v11.5.txt",
		        "node_list_path": "394264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "394264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeon13140cm3386Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon 13_1_40CM_3_38_6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeon13140cm3386Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805390.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805390.protein.info.v11.5.txt",
		        "node_list_path": "1805390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpHb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. HB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpHb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1678678.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678678.protein.info.v11.5.txt",
		        "node_list_path": "1678678.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeniophoraSpContCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peniophora sp. CONT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeniophoraSpContCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314672.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314672.protein.info.v11.5.txt",
		        "node_list_path": "1314672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaCepacia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia cepacia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaCepacia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "292.protein.sequences.v11.5.fa",
		        "enrichment_path": "292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292.protein.info.v11.5.txt",
		        "node_list_path": "292.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumJeikeiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium jeikeium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumJeikeiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "306537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "306537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "306537.clusters.proteins.v11.5.txt",
		        "sequence_path": "306537.protein.sequences.v11.5.fa",
		        "enrichment_path": "306537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306537.protein.info.v11.5.txt",
		        "node_list_path": "306537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "306537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb241528n17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241_528N17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb241528n17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1471456.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1471456.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1471456.clusters.proteins.v11.5.txt",
		        "sequence_path": "1471456.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471456.protein.info.v11.5.txt",
		        "node_list_path": "1471456.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1471456.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesFarautiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles farauti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesFarautiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69004.clusters.proteins.v11.5.txt",
		        "sequence_path": "69004.protein.sequences.v11.5.fa",
		        "enrichment_path": "69004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69004.protein.info.v11.5.txt",
		        "node_list_path": "69004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrachipleistophoraHominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trachipleistophora hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrachipleistophoraHominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "72359.protein.sequences.v11.5.fa",
		        "enrichment_path": "72359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72359.protein.info.v11.5.txt",
		        "node_list_path": "72359.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesJeddahensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces jeddahensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesJeddahensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1716141.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1716141.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1716141.clusters.proteins.v11.5.txt",
		        "sequence_path": "1716141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1716141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1716141.protein.info.v11.5.txt",
		        "node_list_path": "1716141.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1716141.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumMaltaromaticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium maltaromaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumMaltaromaticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1234679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1234679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1234679.clusters.proteins.v11.5.txt",
		        "sequence_path": "1234679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234679.protein.info.v11.5.txt",
		        "node_list_path": "1234679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1234679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxyc2Full3412Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYC2_FULL_34_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyc2Full3412Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797971.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797971.protein.info.v11.5.txt",
		        "node_list_path": "1797971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NectriaHaematococcaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nectria haematococca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NectriaHaematococcaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "140110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "140110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "140110.clusters.proteins.v11.5.txt",
		        "sequence_path": "140110.protein.sequences.v11.5.fa",
		        "enrichment_path": "140110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "140110.protein.info.v11.5.txt",
		        "node_list_path": "140110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "140110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusDrentensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus drentensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusDrentensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "220684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "220684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "220684.clusters.proteins.v11.5.txt",
		        "sequence_path": "220684.protein.sequences.v11.5.fa",
		        "enrichment_path": "220684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220684.protein.info.v11.5.txt",
		        "node_list_path": "220684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "220684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumSpRoot472d3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root472D3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumSpRoot472d3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736540.protein.info.v11.5.txt",
		        "node_list_path": "1736540.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonadaceaeBacteriumCg1026018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium CG1_02_60_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonadaceaeBacteriumCg1026018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805088.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805088.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805088.protein.info.v11.5.txt",
		        "node_list_path": "1805088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RothiaMucilaginosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rothia mucilaginosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RothiaMucilaginosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "680646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "680646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "680646.clusters.proteins.v11.5.txt",
		        "sequence_path": "680646.protein.sequences.v11.5.fa",
		        "enrichment_path": "680646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "680646.protein.info.v11.5.txt",
		        "node_list_path": "680646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "680646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusEquiDsm15833Jcm10991(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus equi DSM 15833 JCM 10991 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusEquiDsm15833Jcm10991", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423740.protein.info.v11.5.txt",
		        "node_list_path": "1423740.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumUreilyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium ureilyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumUreilyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "373668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "373668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "373668.clusters.proteins.v11.5.txt",
		        "sequence_path": "373668.protein.sequences.v11.5.fa",
		        "enrichment_path": "373668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "373668.protein.info.v11.5.txt",
		        "node_list_path": "373668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "373668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastochlorisViridisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastochloris viridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastochlorisViridisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1079.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1079.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1079.clusters.proteins.v11.5.txt",
		        "sequence_path": "1079.protein.sequences.v11.5.fa",
		        "enrichment_path": "1079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1079.protein.info.v11.5.txt",
		        "node_list_path": "1079.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1079.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesJohnsoniiDsm18315(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides johnsonii DSM 18315 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesJohnsoniiDsm18315", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "537006.protein.sequences.v11.5.fa",
		        "enrichment_path": "537006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537006.protein.info.v11.5.txt",
		        "node_list_path": "537006.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot1203Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1203 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot1203Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736427.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736427.protein.info.v11.5.txt",
		        "node_list_path": "1736427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpUnccl117Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNCCL117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpUnccl117Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502764.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502764.protein.info.v11.5.txt",
		        "node_list_path": "1502764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "985665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "985665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "985665.clusters.proteins.v11.5.txt",
		        "sequence_path": "985665.protein.sequences.v11.5.fa",
		        "enrichment_path": "985665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985665.protein.info.v11.5.txt",
		        "node_list_path": "985665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "985665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifoxya2Full4315(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYA2_FULL_43_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxya2Full4315", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801648.protein.info.v11.5.txt",
		        "node_list_path": "1801648.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24227Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_42_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24227Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619049.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619049.protein.info.v11.5.txt",
		        "node_list_path": "1619049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaCitrea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora citrea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaCitrea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47855.protein.sequences.v11.5.fa",
		        "enrichment_path": "47855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47855.protein.info.v11.5.txt",
		        "node_list_path": "47855.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelosinusSpUfo1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus sp. UFO1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelosinusSpUfo1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "484770.protein.sequences.v11.5.fa",
		        "enrichment_path": "484770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484770.protein.info.v11.5.txt",
		        "node_list_path": "484770.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaSpJc4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema sp. JC4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSpJc4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1124982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1124982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1124982.protein.info.v11.5.txt",
		        "node_list_path": "1124982.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyclobacteriumHalophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacterium halophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyclobacteriumHalophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1416801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416801.protein.info.v11.5.txt",
		        "node_list_path": "1416801.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlochmanniaPennsylvanicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia pennsylvanicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlochmanniaPennsylvanicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "291272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "291272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "291272.clusters.proteins.v11.5.txt",
		        "sequence_path": "291272.protein.sequences.v11.5.fa",
		        "enrichment_path": "291272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "291272.protein.info.v11.5.txt",
		        "node_list_path": "291272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "291272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033734.protein.info.v11.5.txt",
		        "node_list_path": "1033734.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriCcug29243(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri CCUG 29243 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriCcug29243", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196835.protein.info.v11.5.txt",
		        "node_list_path": "1196835.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumGwf23610Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWF2_36_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumGwf23610Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797682.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797682.protein.info.v11.5.txt",
		        "node_list_path": "1797682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslr50345Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR50345 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslr50345Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1536770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1536770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1536770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1536770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536770.protein.info.v11.5.txt",
		        "node_list_path": "1536770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1536770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusHerbarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus herbarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusHerbarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120972.protein.info.v11.5.txt",
		        "node_list_path": "1120972.protein.complete.v11.5.txt"
		    }
		]
    )()

def NoviherbaspirillumSpRoot189Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Noviherbaspirillum sp. Root189 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NoviherbaspirillumSpRoot189Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736487.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736487.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736487.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736487.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736487.protein.info.v11.5.txt",
		        "node_list_path": "1736487.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736487.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfuromonasThiophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromonas thiophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromonasThiophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "57664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "57664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "57664.clusters.proteins.v11.5.txt",
		        "sequence_path": "57664.protein.sequences.v11.5.fa",
		        "enrichment_path": "57664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "57664.protein.info.v11.5.txt",
		        "node_list_path": "57664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "57664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoniliophthoraRoreriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moniliophthora roreri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoniliophthoraRoreriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "221103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "221103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "221103.clusters.proteins.v11.5.txt",
		        "sequence_path": "221103.protein.sequences.v11.5.fa",
		        "enrichment_path": "221103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221103.protein.info.v11.5.txt",
		        "node_list_path": "221103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "221103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumCasei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium casei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumCasei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229781.protein.info.v11.5.txt",
		        "node_list_path": "1229781.protein.complete.v11.5.txt"
		    }
		]
    )()

def KosakoniaCowaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kosakonia cowanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KosakoniaCowaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "208223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "208223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "208223.clusters.proteins.v11.5.txt",
		        "sequence_path": "208223.protein.sequences.v11.5.fa",
		        "enrichment_path": "208223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208223.protein.info.v11.5.txt",
		        "node_list_path": "208223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "208223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesDavawensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces davawensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesDavawensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1214101.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214101.protein.info.v11.5.txt",
		        "node_list_path": "1214101.protein.complete.v11.5.txt"
		    }
		]
    )()

def FacklamiaIgnavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Facklamia ignava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FacklamiaIgnavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883112.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883112.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883112.clusters.proteins.v11.5.txt",
		        "sequence_path": "883112.protein.sequences.v11.5.fa",
		        "enrichment_path": "883112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883112.protein.info.v11.5.txt",
		        "node_list_path": "883112.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883112.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConchiformibiusSteedae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Conchiformibius steedae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConchiformibiusSteedae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121352.protein.info.v11.5.txt",
		        "node_list_path": "1121352.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumScatologenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium scatologenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumScatologenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1548.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548.protein.info.v11.5.txt",
		        "node_list_path": "1548.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParafilimonasTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parafilimonas terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParafilimonasTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1465490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1465490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1465490.clusters.proteins.v11.5.txt",
		        "sequence_path": "1465490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1465490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1465490.protein.info.v11.5.txt",
		        "node_list_path": "1465490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1465490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophothermusLipocalidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophothermus lipocalidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophothermusLipocalidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "643648.clusters.info.v11.5.txt",
		        "cluster_tree_path": "643648.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "643648.clusters.proteins.v11.5.txt",
		        "sequence_path": "643648.protein.sequences.v11.5.fa",
		        "enrichment_path": "643648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "643648.protein.info.v11.5.txt",
		        "node_list_path": "643648.cluster.nodes.v11.5.txt",
		        "edge_list_path": "643648.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumRifcsplowo212Full3712(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RIFCSPLOWO2_12_FULL_37_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumRifcsplowo212Full3712", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797365.protein.info.v11.5.txt",
		        "node_list_path": "1797365.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumSpT3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum sp. T3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumSpT3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1194088.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194088.protein.info.v11.5.txt",
		        "node_list_path": "1194088.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSubsaxonicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium subsaxonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSubsaxonicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121898.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121898.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121898.protein.info.v11.5.txt",
		        "node_list_path": "1121898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwb13613Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWB1_36_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwb13613Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802174.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802174.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802174.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802174.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802174.protein.info.v11.5.txt",
		        "node_list_path": "1802174.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802174.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShimiaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shimia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShimiaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321267.protein.sequences.v11.5.fa",
		        "enrichment_path": "321267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321267.protein.info.v11.5.txt",
		        "node_list_path": "321267.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumCg1023721Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium CG1_02_37_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumCg1023721Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805145.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805145.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805145.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805145.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805145.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805145.protein.info.v11.5.txt",
		        "node_list_path": "1805145.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805145.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4515Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_01_FULL_45_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4515Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802132.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802132.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802132.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802132.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802132.protein.info.v11.5.txt",
		        "node_list_path": "1802132.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802132.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_40_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797715.protein.info.v11.5.txt",
		        "node_list_path": "1797715.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4516(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_12_FULL_45_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4516", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802315.protein.info.v11.5.txt",
		        "node_list_path": "1802315.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumRifcsplowo202Full4019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPLOWO2_02_FULL_40_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsplowo202Full4019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797229.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797229.protein.info.v11.5.txt",
		        "node_list_path": "1797229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaPsittaci6bcCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia psittaci 6BC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaPsittaci6bcCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "331636.clusters.info.v11.5.txt",
		        "cluster_tree_path": "331636.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "331636.clusters.proteins.v11.5.txt",
		        "sequence_path": "331636.protein.sequences.v11.5.fa",
		        "enrichment_path": "331636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331636.protein.info.v11.5.txt",
		        "node_list_path": "331636.cluster.nodes.v11.5.txt",
		        "edge_list_path": "331636.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNasuiaDeltocephalinicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nasuia deltocephalinicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNasuiaDeltocephalinicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1160784.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1160784.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1160784.clusters.proteins.v11.5.txt",
		        "sequence_path": "1160784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160784.protein.info.v11.5.txt",
		        "node_list_path": "1160784.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1160784.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSp627(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. 627 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSp627", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1501391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1501391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1501391.protein.info.v11.5.txt",
		        "node_list_path": "1501391.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferSpZgt114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer sp. ZGT114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferSpZgt114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1685377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685377.protein.info.v11.5.txt",
		        "node_list_path": "1685377.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanobacillusDamuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus damuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusDamuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "937928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "937928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "937928.clusters.proteins.v11.5.txt",
		        "sequence_path": "937928.protein.sequences.v11.5.fa",
		        "enrichment_path": "937928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937928.protein.info.v11.5.txt",
		        "node_list_path": "937928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "937928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonasTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "673548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "673548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "673548.clusters.proteins.v11.5.txt",
		        "sequence_path": "673548.protein.sequences.v11.5.fa",
		        "enrichment_path": "673548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "673548.protein.info.v11.5.txt",
		        "node_list_path": "673548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "673548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPhocaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus phocaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPhocaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776378.protein.info.v11.5.txt",
		        "node_list_path": "1776378.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesocestoidesCorti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesocestoides corti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesocestoidesCorti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53468.protein.sequences.v11.5.fa",
		        "enrichment_path": "53468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53468.protein.info.v11.5.txt",
		        "node_list_path": "53468.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumIriomotense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium iriomotense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumIriomotense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1536641.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536641.protein.info.v11.5.txt",
		        "node_list_path": "1536641.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchistosomaJaponicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma japonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaJaponicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6182.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6182.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6182.clusters.proteins.v11.5.txt",
		        "sequence_path": "6182.protein.sequences.v11.5.fa",
		        "enrichment_path": "6182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6182.protein.info.v11.5.txt",
		        "node_list_path": "6182.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6182.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobacterSpRoot404(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root404 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobacterSpRoot404", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736528.protein.info.v11.5.txt",
		        "node_list_path": "1736528.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeyerozymaGuilliermondiiAtcc6260Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meyerozyma guilliermondii ATCC 6260 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeyerozymaGuilliermondiiAtcc6260Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "294746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "294746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "294746.clusters.proteins.v11.5.txt",
		        "sequence_path": "294746.protein.sequences.v11.5.fa",
		        "enrichment_path": "294746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294746.protein.info.v11.5.txt",
		        "node_list_path": "294746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "294746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisSpAc466(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC466 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisSpAc466", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1282362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282362.protein.info.v11.5.txt",
		        "node_list_path": "1282362.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusCandidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus candidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusCandidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "41067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "41067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "41067.clusters.proteins.v11.5.txt",
		        "sequence_path": "41067.protein.sequences.v11.5.fa",
		        "enrichment_path": "41067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41067.protein.info.v11.5.txt",
		        "node_list_path": "41067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "41067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusWakoensisJcm9140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus wakoensis JCM 9140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusWakoensisJcm9140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236970.protein.info.v11.5.txt",
		        "node_list_path": "1236970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColobusAngolensisPalliatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colobus angolensis palliatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColobusAngolensisPalliatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "336983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "336983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "336983.clusters.proteins.v11.5.txt",
		        "sequence_path": "336983.protein.sequences.v11.5.fa",
		        "enrichment_path": "336983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336983.protein.info.v11.5.txt",
		        "node_list_path": "336983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "336983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumBarkeri2011R4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium barkeri 2011-R4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumBarkeri2011R4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1197720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197720.protein.info.v11.5.txt",
		        "node_list_path": "1197720.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumYim77505Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium YIM77505 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumYim77505Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1411123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1411123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1411123.clusters.proteins.v11.5.txt",
		        "sequence_path": "1411123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1411123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1411123.protein.info.v11.5.txt",
		        "node_list_path": "1411123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1411123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EgrettaGarzetta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Egretta garzetta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EgrettaGarzetta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "188379.protein.sequences.v11.5.fa",
		        "enrichment_path": "188379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188379.protein.info.v11.5.txt",
		        "node_list_path": "188379.protein.complete.v11.5.txt"
		    }
		]
    )()

def MortierellaVerticillata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mortierella verticillata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MortierellaVerticillata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "78898.protein.sequences.v11.5.fa",
		        "enrichment_path": "78898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78898.protein.info.v11.5.txt",
		        "node_list_path": "78898.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg165418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_54_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg165418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797648.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797648.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797648.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797648.protein.info.v11.5.txt",
		        "node_list_path": "1797648.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797648.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquimarinaSp22iis11z7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina sp. 22IIS11z7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaSp22iis11z7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1317122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1317122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1317122.clusters.proteins.v11.5.txt",
		        "sequence_path": "1317122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317122.protein.info.v11.5.txt",
		        "node_list_path": "1317122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1317122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaSpDiamant(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia sp. Diamant graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaSpDiamant", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1444711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444711.protein.info.v11.5.txt",
		        "node_list_path": "1444711.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag272Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:272 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag272Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263015.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263015.protein.info.v11.5.txt",
		        "node_list_path": "1263015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaAbortusLlg(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia abortus LLG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaAbortusLlg", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1003238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1003238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1003238.protein.info.v11.5.txt",
		        "node_list_path": "1003238.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcaceaeBacteriumCm5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium CM5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcaceaeBacteriumCm5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "796940.clusters.info.v11.5.txt",
		        "cluster_tree_path": "796940.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "796940.clusters.proteins.v11.5.txt",
		        "sequence_path": "796940.protein.sequences.v11.5.fa",
		        "enrichment_path": "796940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796940.protein.info.v11.5.txt",
		        "node_list_path": "796940.cluster.nodes.v11.5.txt",
		        "edge_list_path": "796940.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizopusDelemarRa99880(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus delemar RA 99-880 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopusDelemarRa99880", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246409.protein.sequences.v11.5.fa",
		        "enrichment_path": "246409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246409.protein.info.v11.5.txt",
		        "node_list_path": "246409.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriA1501(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri A1501 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriA1501", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "379731.protein.sequences.v11.5.fa",
		        "enrichment_path": "379731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "379731.protein.info.v11.5.txt",
		        "node_list_path": "379731.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpArh5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ARh5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpArh5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158183.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158183.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158183.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158183.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158183.protein.info.v11.5.txt",
		        "node_list_path": "1158183.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158183.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag702Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:702 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag702Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262747.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262747.protein.info.v11.5.txt",
		        "node_list_path": "1262747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesGenomospCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales genomosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesGenomospCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "699246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "699246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "699246.clusters.proteins.v11.5.txt",
		        "sequence_path": "699246.protein.sequences.v11.5.fa",
		        "enrichment_path": "699246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "699246.protein.info.v11.5.txt",
		        "node_list_path": "699246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "699246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_53_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802389.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802389.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802389.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802389.protein.info.v11.5.txt",
		        "node_list_path": "1802389.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802389.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UreaplasmaUrealyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ureaplasma urealyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UreaplasmaUrealyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "565575.protein.sequences.v11.5.fa",
		        "enrichment_path": "565575.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565575.protein.info.v11.5.txt",
		        "node_list_path": "565575.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaIowae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma iowae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaIowae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1048830.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048830.protein.info.v11.5.txt",
		        "node_list_path": "1048830.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurvibacterDelicatusNbrc14919Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter delicatus NBRC 14919 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurvibacterDelicatusNbrc14919Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349763.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349763.protein.info.v11.5.txt",
		        "node_list_path": "1349763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesFlavochromogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavochromogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesFlavochromogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68199.protein.sequences.v11.5.fa",
		        "enrichment_path": "68199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68199.protein.info.v11.5.txt",
		        "node_list_path": "68199.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSpTg39aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. TG39a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpTg39aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415755.protein.info.v11.5.txt",
		        "node_list_path": "1415755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EmilianiaHuxleyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Emiliania huxleyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmilianiaHuxleyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2903.clusters.proteins.v11.5.txt",
		        "sequence_path": "2903.protein.sequences.v11.5.fa",
		        "enrichment_path": "2903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2903.protein.info.v11.5.txt",
		        "node_list_path": "2903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasCapeferrum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas capeferrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCapeferrum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1495066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495066.protein.info.v11.5.txt",
		        "node_list_path": "1495066.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidibacillusFerrooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidibacillus ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidibacillusFerrooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1765683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1765683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1765683.clusters.proteins.v11.5.txt",
		        "sequence_path": "1765683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765683.protein.info.v11.5.txt",
		        "node_list_path": "1765683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1765683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusFlavefaciensFd1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens FD1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusFlavefaciensFd1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641112.protein.sequences.v11.5.fa",
		        "enrichment_path": "641112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641112.protein.info.v11.5.txt",
		        "node_list_path": "641112.protein.complete.v11.5.txt"
		    }
		]
    )()

def OligellaUrethralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oligella urethralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OligellaUrethralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1401065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1401065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1401065.clusters.proteins.v11.5.txt",
		        "sequence_path": "1401065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401065.protein.info.v11.5.txt",
		        "node_list_path": "1401065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1401065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusArthromitusSpSfbTurkeyCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arthromitus sp. SFB-turkey Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusArthromitusSpSfbTurkeyCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1840217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1840217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1840217.clusters.proteins.v11.5.txt",
		        "sequence_path": "1840217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1840217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1840217.protein.info.v11.5.txt",
		        "node_list_path": "1840217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1840217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusVanfongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus vanfongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusVanfongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120968.protein.info.v11.5.txt",
		        "node_list_path": "1120968.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaSusongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia susongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaSusongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1515439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1515439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1515439.clusters.proteins.v11.5.txt",
		        "sequence_path": "1515439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1515439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1515439.protein.info.v11.5.txt",
		        "node_list_path": "1515439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1515439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MahellaAustraliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mahella australiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MahellaAustraliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "697281.protein.sequences.v11.5.fa",
		        "enrichment_path": "697281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "697281.protein.info.v11.5.txt",
		        "node_list_path": "697281.protein.complete.v11.5.txt"
		    }
		]
    )()

def VanderwaltozymaPolysporaDsm70294(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vanderwaltozyma polyspora DSM 70294 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VanderwaltozymaPolysporaDsm70294", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "436907.protein.sequences.v11.5.fa",
		        "enrichment_path": "436907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436907.protein.info.v11.5.txt",
		        "node_list_path": "436907.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgreiaSpLeaf244Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agreia sp. Leaf244 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgreiaSpLeaf244Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736305.protein.info.v11.5.txt",
		        "node_list_path": "1736305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAzambacteriaBacteriumRifcsplowo201Full4625(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPLOWO2_01_FULL_46_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsplowo201Full4625", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797298.protein.info.v11.5.txt",
		        "node_list_path": "1797298.protein.complete.v11.5.txt"
		    }
		]
    )()

def BotrytisPorriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Botrytis porri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotrytisPorriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "87229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "87229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "87229.clusters.proteins.v11.5.txt",
		        "sequence_path": "87229.protein.sequences.v11.5.fa",
		        "enrichment_path": "87229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "87229.protein.info.v11.5.txt",
		        "node_list_path": "87229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "87229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraInadaiSerovarLymeStr10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira inadai serovar Lyme str. 10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraInadaiSerovarLymeStr10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1049790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1049790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1049790.protein.info.v11.5.txt",
		        "node_list_path": "1049790.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpWcc10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. WCC10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpWcc10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855343.protein.info.v11.5.txt",
		        "node_list_path": "1855343.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermosulfidibacterTakaiiAbi70s6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermosulfidibacter takaii ABI70S6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosulfidibacterTakaiiAbi70s6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298851.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298851.protein.info.v11.5.txt",
		        "node_list_path": "1298851.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrochothrixCampestrisFslF61037(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brochothrix campestris FSL F6-1037 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrochothrixCampestrisFslF61037", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265861.protein.info.v11.5.txt",
		        "node_list_path": "1265861.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesIsraelii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces israelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesIsraelii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120944.protein.info.v11.5.txt",
		        "node_list_path": "1120944.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumScindensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium scindens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumScindensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411468.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411468.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411468.clusters.proteins.v11.5.txt",
		        "sequence_path": "411468.protein.sequences.v11.5.fa",
		        "enrichment_path": "411468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411468.protein.info.v11.5.txt",
		        "node_list_path": "411468.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411468.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SlackiaHeliotrinireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Slackia heliotrinireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SlackiaHeliotrinireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471855.clusters.proteins.v11.5.txt",
		        "sequence_path": "471855.protein.sequences.v11.5.fa",
		        "enrichment_path": "471855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471855.protein.info.v11.5.txt",
		        "node_list_path": "471855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporisoriumReilianum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporisorium reilianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporisoriumReilianum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "72558.protein.sequences.v11.5.fa",
		        "enrichment_path": "72558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72558.protein.info.v11.5.txt",
		        "node_list_path": "72558.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoxodontaAfricana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loxodonta africana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoxodontaAfricana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9785.protein.sequences.v11.5.fa",
		        "enrichment_path": "9785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9785.protein.info.v11.5.txt",
		        "node_list_path": "9785.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobacterSpRoot29(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobacterSpRoot29", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736511.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736511.protein.info.v11.5.txt",
		        "node_list_path": "1736511.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumLotiCj3symCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti CJ3sym Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumLotiCj3symCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1040982.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1040982.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1040982.clusters.proteins.v11.5.txt",
		        "sequence_path": "1040982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1040982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1040982.protein.info.v11.5.txt",
		        "node_list_path": "1040982.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1040982.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumJeoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium jeonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumJeoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266749.clusters.proteins.v11.5.txt",
		        "sequence_path": "266749.protein.sequences.v11.5.fa",
		        "enrichment_path": "266749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266749.protein.info.v11.5.txt",
		        "node_list_path": "266749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaOakridgensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella oakridgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaOakridgensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1268635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268635.protein.info.v11.5.txt",
		        "node_list_path": "1268635.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusCoryniformisSubspCoryniformisCect5711(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis subsp. coryniformis CECT 5711 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCoryniformisSubspCoryniformisCect5711", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1185325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185325.protein.info.v11.5.txt",
		        "node_list_path": "1185325.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445961.protein.sequences.v11.5.fa",
		        "enrichment_path": "445961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445961.protein.info.v11.5.txt",
		        "node_list_path": "445961.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaLongbeachae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella longbeachae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaLongbeachae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "661367.protein.sequences.v11.5.fa",
		        "enrichment_path": "661367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "661367.protein.info.v11.5.txt",
		        "node_list_path": "661367.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaTaylorii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella taylorii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaTaylorii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094560.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094560.protein.info.v11.5.txt",
		        "node_list_path": "1094560.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusBovis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusBovis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1616788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1616788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1616788.protein.info.v11.5.txt",
		        "node_list_path": "1616788.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaSpCf038Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. CF038 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpCf038Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881045.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881045.protein.info.v11.5.txt",
		        "node_list_path": "1881045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GilliamellaApicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gilliamella apicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilliamellaApicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196095.protein.info.v11.5.txt",
		        "node_list_path": "1196095.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium4393Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 43-93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium4393Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895924.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895924.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895924.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895924.protein.info.v11.5.txt",
		        "node_list_path": "1895924.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895924.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoproteusSpJchs4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoproteus sp. JCHS_4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoproteusSpJchs4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1714258.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1714258.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1714258.clusters.proteins.v11.5.txt",
		        "sequence_path": "1714258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714258.protein.info.v11.5.txt",
		        "node_list_path": "1714258.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1714258.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CriblamydiaSequanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Criblamydia sequanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CriblamydiaSequanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437425.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437425.protein.info.v11.5.txt",
		        "node_list_path": "1437425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EggerthellaSpYy7918Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eggerthella sp. YY7918 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthellaSpYy7918Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "502558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "502558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "502558.clusters.proteins.v11.5.txt",
		        "sequence_path": "502558.protein.sequences.v11.5.fa",
		        "enrichment_path": "502558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502558.protein.info.v11.5.txt",
		        "node_list_path": "502558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "502558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodovulumSulfidophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sulfidophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovulumSulfidophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1188256.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1188256.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1188256.clusters.proteins.v11.5.txt",
		        "sequence_path": "1188256.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188256.protein.info.v11.5.txt",
		        "node_list_path": "1188256.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1188256.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesCongonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides congonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCongonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871006.protein.info.v11.5.txt",
		        "node_list_path": "1871006.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaLiquefaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia liquefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaLiquefaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "614.clusters.info.v11.5.txt",
		        "cluster_tree_path": "614.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "614.clusters.proteins.v11.5.txt",
		        "sequence_path": "614.protein.sequences.v11.5.fa",
		        "enrichment_path": "614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "614.protein.info.v11.5.txt",
		        "node_list_path": "614.cluster.nodes.v11.5.txt",
		        "edge_list_path": "614.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArabisAlpina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arabis alpina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArabisAlpina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "50452.protein.sequences.v11.5.fa",
		        "enrichment_path": "50452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50452.protein.info.v11.5.txt",
		        "node_list_path": "50452.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpPamc26554Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. PAMC 26554 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpPamc26554Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1484116.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1484116.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1484116.clusters.proteins.v11.5.txt",
		        "sequence_path": "1484116.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484116.protein.info.v11.5.txt",
		        "node_list_path": "1484116.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1484116.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobiArchaeonJdfr42(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobi archaeon JdFR-42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobiArchaeonJdfr42", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935016.protein.info.v11.5.txt",
		        "node_list_path": "1935016.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesFragilis3112(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis 3112 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFragilis3112", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "457424.protein.sequences.v11.5.fa",
		        "enrichment_path": "457424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457424.protein.info.v11.5.txt",
		        "node_list_path": "457424.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterArilaitensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter arilaitensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterArilaitensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "861360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "861360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "861360.clusters.proteins.v11.5.txt",
		        "sequence_path": "861360.protein.sequences.v11.5.fa",
		        "enrichment_path": "861360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861360.protein.info.v11.5.txt",
		        "node_list_path": "861360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "861360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumFlorentinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium florentinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumFlorentinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "292462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "292462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "292462.clusters.proteins.v11.5.txt",
		        "sequence_path": "292462.protein.sequences.v11.5.fa",
		        "enrichment_path": "292462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292462.protein.info.v11.5.txt",
		        "node_list_path": "292462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "292462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaTularensisNovicidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella tularensis novicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaTularensisNovicidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "676032.clusters.info.v11.5.txt",
		        "cluster_tree_path": "676032.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "676032.clusters.proteins.v11.5.txt",
		        "sequence_path": "676032.protein.sequences.v11.5.fa",
		        "enrichment_path": "676032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "676032.protein.info.v11.5.txt",
		        "node_list_path": "676032.cluster.nodes.v11.5.txt",
		        "edge_list_path": "676032.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoxiellaBurnetiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coxiella burnetii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoxiellaBurnetiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "227377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "227377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "227377.clusters.proteins.v11.5.txt",
		        "sequence_path": "227377.protein.sequences.v11.5.fa",
		        "enrichment_path": "227377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227377.protein.info.v11.5.txt",
		        "node_list_path": "227377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "227377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaBannensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia bannensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaBannensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218075.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218075.protein.info.v11.5.txt",
		        "node_list_path": "1218075.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumAvidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium avidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumAvidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1170318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1170318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1170318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1170318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1170318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1170318.protein.info.v11.5.txt",
		        "node_list_path": "1170318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1170318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumNepotum397(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium nepotum 39/7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumNepotum397", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1368418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1368418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1368418.protein.info.v11.5.txt",
		        "node_list_path": "1368418.protein.complete.v11.5.txt"
		    }
		]
    )()

def AliicoccusPersicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aliicoccus persicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliicoccusPersicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930138.protein.sequences.v11.5.fa",
		        "enrichment_path": "930138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930138.protein.info.v11.5.txt",
		        "node_list_path": "930138.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh8109Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8109 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh8109Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "166314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "166314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "166314.clusters.proteins.v11.5.txt",
		        "sequence_path": "166314.protein.sequences.v11.5.fa",
		        "enrichment_path": "166314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "166314.protein.info.v11.5.txt",
		        "node_list_path": "166314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "166314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GopherusAgassizii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gopherus agassizii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GopherusAgassizii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "38772.protein.sequences.v11.5.fa",
		        "enrichment_path": "38772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38772.protein.info.v11.5.txt",
		        "node_list_path": "38772.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf343Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf343 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf343Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736345.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736345.protein.info.v11.5.txt",
		        "node_list_path": "1736345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChthoniobacterFlavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chthoniobacter flavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChthoniobacterFlavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "497964.protein.sequences.v11.5.fa",
		        "enrichment_path": "497964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "497964.protein.info.v11.5.txt",
		        "node_list_path": "497964.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpMste9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. MSTE9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpMste9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1105031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1105031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1105031.protein.info.v11.5.txt",
		        "node_list_path": "1105031.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwa26924Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_69_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwa26924Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797927.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797927.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797927.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797927.protein.info.v11.5.txt",
		        "node_list_path": "1797927.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797927.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusKribbensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus kribbensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusKribbensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "172713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "172713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "172713.clusters.proteins.v11.5.txt",
		        "sequence_path": "172713.protein.sequences.v11.5.fa",
		        "enrichment_path": "172713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "172713.protein.info.v11.5.txt",
		        "node_list_path": "172713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "172713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinophagaceaeBacteriumPmp191f(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium PMP191F graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaceaeBacteriumPmp191f", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1691979.protein.sequences.v11.5.fa",
		        "enrichment_path": "1691979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1691979.protein.info.v11.5.txt",
		        "node_list_path": "1691979.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacterium13140cm2607(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_1_40CM_2_60_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacterium13140cm2607", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803443.protein.info.v11.5.txt",
		        "node_list_path": "1803443.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCl2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CL2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCl2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499684.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499684.protein.info.v11.5.txt",
		        "node_list_path": "1499684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMohnii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mohnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMohnii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "395600.protein.sequences.v11.5.fa",
		        "enrichment_path": "395600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395600.protein.info.v11.5.txt",
		        "node_list_path": "395600.protein.complete.v11.5.txt"
		    }
		]
    )()

def MacrococcusCaseolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Macrococcus caseolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacrococcusCaseolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "458233.clusters.info.v11.5.txt",
		        "cluster_tree_path": "458233.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "458233.clusters.proteins.v11.5.txt",
		        "sequence_path": "458233.protein.sequences.v11.5.fa",
		        "enrichment_path": "458233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "458233.protein.info.v11.5.txt",
		        "node_list_path": "458233.cluster.nodes.v11.5.txt",
		        "edge_list_path": "458233.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioCholeraeO1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Vibrio cholerae O1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCholeraeO1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243277.clusters.info.v11.0.txt",
		        "cluster_tree_path": "243277.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "243277.clusters.proteins.v11.0.txt",
		        "sequence_path": "243277.protein.sequences.v11.0.fa",
		        "enrichment_path": "243277.protein.enrichment.terms.v11.0.txt",
		        "info_path": "243277.protein.info.v11.0.txt",
		        "node_list_path": "243277.cluster.nodes.v11.0.txt",
		        "edge_list_path": "243277.protein.cluster.v11.0.txt"
		    }
		]
    )()

def DechloromonasAgitata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dechloromonas agitata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DechloromonasAgitata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304883.protein.info.v11.5.txt",
		        "node_list_path": "1304883.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArachidicoccusRhizosphaerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arachidicoccus rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArachidicoccusRhizosphaerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "551991.protein.sequences.v11.5.fa",
		        "enrichment_path": "551991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551991.protein.info.v11.5.txt",
		        "node_list_path": "551991.protein.complete.v11.5.txt"
		    }
		]
    )()

def RikenellaMicrofususCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rikenella microfusus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RikenellaMicrofususCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "880526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "880526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "880526.clusters.proteins.v11.5.txt",
		        "sequence_path": "880526.protein.sequences.v11.5.fa",
		        "enrichment_path": "880526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880526.protein.info.v11.5.txt",
		        "node_list_path": "880526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "880526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MalusBaccataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Malus baccata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalusBaccataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "106549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "106549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "106549.clusters.proteins.v11.5.txt",
		        "sequence_path": "106549.protein.sequences.v11.5.fa",
		        "enrichment_path": "106549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106549.protein.info.v11.5.txt",
		        "node_list_path": "106549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "106549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PneumocystisMurina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis murina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PneumocystisMurina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "263815.protein.sequences.v11.5.fa",
		        "enrichment_path": "263815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263815.protein.info.v11.5.txt",
		        "node_list_path": "263815.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgaricusBisporus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agaricus bisporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgaricusBisporus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5341.protein.sequences.v11.5.fa",
		        "enrichment_path": "5341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5341.protein.info.v11.5.txt",
		        "node_list_path": "5341.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterPametensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pametensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterPametensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408442.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408442.protein.info.v11.5.txt",
		        "node_list_path": "1408442.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpUrha0041Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. URHA0041 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpUrha0041Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380346.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380346.protein.info.v11.5.txt",
		        "node_list_path": "1380346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanotorrisIgneusKol5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanotorris igneus Kol 5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanotorrisIgneusKol5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "880724.protein.sequences.v11.5.fa",
		        "enrichment_path": "880724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880724.protein.info.v11.5.txt",
		        "node_list_path": "880724.protein.complete.v11.5.txt"
		    }
		]
    )()

def PucciniaGraminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Puccinia graminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PucciniaGraminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5297.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5297.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5297.clusters.proteins.v11.5.txt",
		        "sequence_path": "5297.protein.sequences.v11.5.fa",
		        "enrichment_path": "5297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5297.protein.info.v11.5.txt",
		        "node_list_path": "5297.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5297.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlebsiellaOxytoca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella oxytoca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaOxytoca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "571.protein.sequences.v11.5.fa",
		        "enrichment_path": "571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571.protein.info.v11.5.txt",
		        "node_list_path": "571.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpBolea5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. BoleA5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpBolea5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157637.protein.info.v11.5.txt",
		        "node_list_path": "1157637.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycetocolaMiduiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycetocola miduiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycetocolaMiduiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "995034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "995034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "995034.clusters.proteins.v11.5.txt",
		        "sequence_path": "995034.protein.sequences.v11.5.fa",
		        "enrichment_path": "995034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "995034.protein.info.v11.5.txt",
		        "node_list_path": "995034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "995034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterGhanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter ghanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterGhanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "431306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "431306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "431306.clusters.proteins.v11.5.txt",
		        "sequence_path": "431306.protein.sequences.v11.5.fa",
		        "enrichment_path": "431306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431306.protein.info.v11.5.txt",
		        "node_list_path": "431306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "431306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NesiotobacterExalbescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nesiotobacter exalbescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesiotobacterExalbescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "197461.protein.sequences.v11.5.fa",
		        "enrichment_path": "197461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "197461.protein.info.v11.5.txt",
		        "node_list_path": "197461.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseoaurantiacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseoaurantiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseoaurantiacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "996637.protein.sequences.v11.5.fa",
		        "enrichment_path": "996637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "996637.protein.info.v11.5.txt",
		        "node_list_path": "996637.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioZosteraeDsm11974Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio zosterae DSM 11974 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioZosteraeDsm11974Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121467.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121467.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121467.protein.info.v11.5.txt",
		        "node_list_path": "1121467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpAtcc31555(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. ATCC31555 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpAtcc31555", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "194867.protein.sequences.v11.5.fa",
		        "enrichment_path": "194867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "194867.protein.info.v11.5.txt",
		        "node_list_path": "194867.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc13817Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_38_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc13817Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618896.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618896.protein.info.v11.5.txt",
		        "node_list_path": "1618896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSchindleri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter schindleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSchindleri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "108981.protein.sequences.v11.5.fa",
		        "enrichment_path": "108981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "108981.protein.info.v11.5.txt",
		        "node_list_path": "108981.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorallococcusCoralloides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corallococcus coralloides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorallococcusCoralloides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144275.protein.info.v11.5.txt",
		        "node_list_path": "1144275.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiobacillusDenitrificansAtcc25259Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus denitrificans ATCC25259 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusDenitrificansAtcc25259Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "292415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "292415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "292415.clusters.proteins.v11.5.txt",
		        "sequence_path": "292415.protein.sequences.v11.5.fa",
		        "enrichment_path": "292415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292415.protein.info.v11.5.txt",
		        "node_list_path": "292415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "292415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycesLimnophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces limnophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycesLimnophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521674.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521674.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521674.clusters.proteins.v11.5.txt",
		        "sequence_path": "521674.protein.sequences.v11.5.fa",
		        "enrichment_path": "521674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521674.protein.info.v11.5.txt",
		        "node_list_path": "521674.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521674.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaAnimalorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria animaloris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaAnimalorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326522.clusters.proteins.v11.5.txt",
		        "sequence_path": "326522.protein.sequences.v11.5.fa",
		        "enrichment_path": "326522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326522.protein.info.v11.5.txt",
		        "node_list_path": "326522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColwelliaSpPamc20917Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia sp. PAMC 20917 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaSpPamc20917Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816218.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816218.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816218.protein.info.v11.5.txt",
		        "node_list_path": "1816218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrigoribacteriumSpLeaf164Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf164 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrigoribacteriumSpLeaf164Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736282.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736282.protein.info.v11.5.txt",
		        "node_list_path": "1736282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XylariaHypoxylon(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xylaria hypoxylon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylariaHypoxylon", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37992.protein.sequences.v11.5.fa",
		        "enrichment_path": "37992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37992.protein.info.v11.5.txt",
		        "node_list_path": "37992.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesSpAsf519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides sp. ASF519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesSpAsf519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235803.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235803.protein.info.v11.5.txt",
		        "node_list_path": "1235803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaSpBmg51109Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia sp. BMG51109 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSpBmg51109Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1056816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1056816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1056816.clusters.proteins.v11.5.txt",
		        "sequence_path": "1056816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1056816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1056816.protein.info.v11.5.txt",
		        "node_list_path": "1056816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1056816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumRifcsplowo212Full6015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_12_FULL_60_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo212Full6015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798653.protein.info.v11.5.txt",
		        "node_list_path": "1798653.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusPasteuriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus pasteuri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusPasteuriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45972.clusters.proteins.v11.5.txt",
		        "sequence_path": "45972.protein.sequences.v11.5.fa",
		        "enrichment_path": "45972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45972.protein.info.v11.5.txt",
		        "node_list_path": "45972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusPseudoporcinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pseudoporcinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPseudoporcinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "910313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "910313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "910313.clusters.proteins.v11.5.txt",
		        "sequence_path": "910313.protein.sequences.v11.5.fa",
		        "enrichment_path": "910313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "910313.protein.info.v11.5.txt",
		        "node_list_path": "910313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "910313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseomonasStagniDsm19981(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas stagni DSM 19981 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseomonasStagniDsm19981", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123062.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123062.protein.info.v11.5.txt",
		        "node_list_path": "1123062.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanobacillusKimchiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus kimchii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusKimchiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1238184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1238184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1238184.clusters.proteins.v11.5.txt",
		        "sequence_path": "1238184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238184.protein.info.v11.5.txt",
		        "node_list_path": "1238184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1238184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaGranulosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga granulosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaGranulosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641143.protein.sequences.v11.5.fa",
		        "enrichment_path": "641143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641143.protein.info.v11.5.txt",
		        "node_list_path": "641143.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAnimalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium animalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAnimalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "552531.protein.sequences.v11.5.fa",
		        "enrichment_path": "552531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "552531.protein.info.v11.5.txt",
		        "node_list_path": "552531.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPinihumiDsm23905Jcm16419Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus pinihumi DSM 23905 JCM 16419 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPinihumiDsm23905Jcm16419Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122924.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122924.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122924.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122924.protein.info.v11.5.txt",
		        "node_list_path": "1122924.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122924.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpJ33(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. J33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJ33", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935836.protein.sequences.v11.5.fa",
		        "enrichment_path": "935836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935836.protein.info.v11.5.txt",
		        "node_list_path": "935836.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpLeaf26(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. Leaf26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpLeaf26", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735693.protein.info.v11.5.txt",
		        "node_list_path": "1735693.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumMt11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium mt11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumMt11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1686289.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1686289.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1686289.clusters.proteins.v11.5.txt",
		        "sequence_path": "1686289.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686289.protein.info.v11.5.txt",
		        "node_list_path": "1686289.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1686289.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaW619(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida W619 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaW619", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "390235.protein.sequences.v11.5.fa",
		        "enrichment_path": "390235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390235.protein.info.v11.5.txt",
		        "node_list_path": "390235.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacterium4423(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 44-23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacterium4423", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895927.protein.info.v11.5.txt",
		        "node_list_path": "1895927.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesBacteriumOlb23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates bacterium OLB23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesBacteriumOlb23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617429.protein.info.v11.5.txt",
		        "node_list_path": "1617429.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumSpMh3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. MH3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumSpMh3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1399115.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1399115.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1399115.clusters.proteins.v11.5.txt",
		        "sequence_path": "1399115.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399115.protein.info.v11.5.txt",
		        "node_list_path": "1399115.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1399115.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpNies3755Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. NIES-3755 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpNies3755Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752064.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752064.protein.info.v11.5.txt",
		        "node_list_path": "1752064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobulbusMediterraneusDsm13871Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus mediterraneus DSM 13871 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbusMediterraneusDsm13871Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121404.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121404.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121404.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121404.protein.info.v11.5.txt",
		        "node_list_path": "1121404.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121404.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSpDm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. DM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSpDm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1597955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1597955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1597955.clusters.proteins.v11.5.txt",
		        "sequence_path": "1597955.protein.sequences.v11.5.fa",
		        "enrichment_path": "1597955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1597955.protein.info.v11.5.txt",
		        "node_list_path": "1597955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1597955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DefluviitaleaPhaphyphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Defluviitalea phaphyphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DefluviitaleaPhaphyphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1473580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1473580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1473580.clusters.proteins.v11.5.txt",
		        "sequence_path": "1473580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1473580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1473580.protein.info.v11.5.txt",
		        "node_list_path": "1473580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1473580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusThorarchaeotaArchaeonAb25Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thorarchaeota archaeon AB_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThorarchaeotaArchaeonAb25Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1837170.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1837170.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1837170.clusters.proteins.v11.5.txt",
		        "sequence_path": "1837170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1837170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1837170.protein.info.v11.5.txt",
		        "node_list_path": "1837170.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1837170.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumHydrothermale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum hydrothermale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumHydrothermale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121428.protein.info.v11.5.txt",
		        "node_list_path": "1121428.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAdlerbacteriaBacteriumRifcsphigho202Full5217Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPHIGHO2_02_FULL_52_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsphigho202Full5217Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797240.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797240.protein.info.v11.5.txt",
		        "node_list_path": "1797240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasOryzihabitansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas oryzihabitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasOryzihabitansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47885.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47885.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47885.clusters.proteins.v11.5.txt",
		        "sequence_path": "47885.protein.sequences.v11.5.fa",
		        "enrichment_path": "47885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47885.protein.info.v11.5.txt",
		        "node_list_path": "47885.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47885.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SuhomycesTanzawaensisNrrlY17324(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Suhomyces tanzawaensis NRRL Y-17324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuhomycesTanzawaensisNrrlY17324", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "984487.protein.sequences.v11.5.fa",
		        "enrichment_path": "984487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "984487.protein.info.v11.5.txt",
		        "node_list_path": "984487.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyxosarcinaSpGi1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myxosarcina sp. GI1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxosarcinaSpGi1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1541065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1541065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1541065.clusters.proteins.v11.5.txt",
		        "sequence_path": "1541065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1541065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1541065.protein.info.v11.5.txt",
		        "node_list_path": "1541065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1541065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesToyocaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces toyocaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesToyocaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "55952.protein.sequences.v11.5.fa",
		        "enrichment_path": "55952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55952.protein.info.v11.5.txt",
		        "node_list_path": "55952.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlumeriaGraminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blumeria graminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlumeriaGraminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34373.clusters.proteins.v11.5.txt",
		        "sequence_path": "34373.protein.sequences.v11.5.fa",
		        "enrichment_path": "34373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34373.protein.info.v11.5.txt",
		        "node_list_path": "34373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsplowo212Full4630Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPLOWO2_12_FULL_46_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212Full4630Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801867.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801867.protein.info.v11.5.txt",
		        "node_list_path": "1801867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassospiraLucentensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira lucentensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraLucentensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "168935.protein.sequences.v11.5.fa",
		        "enrichment_path": "168935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "168935.protein.info.v11.5.txt",
		        "node_list_path": "168935.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa23827(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_38_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa23827", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618812.protein.info.v11.5.txt",
		        "node_list_path": "1618812.protein.complete.v11.5.txt"
		    }
		]
    )()

def SediminibacillusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacillusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "482461.clusters.info.v11.5.txt",
		        "cluster_tree_path": "482461.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "482461.clusters.proteins.v11.5.txt",
		        "sequence_path": "482461.protein.sequences.v11.5.fa",
		        "enrichment_path": "482461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "482461.protein.info.v11.5.txt",
		        "node_list_path": "482461.cluster.nodes.v11.5.txt",
		        "edge_list_path": "482461.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpChd6a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. CHD6a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpChd6a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1643452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643452.protein.info.v11.5.txt",
		        "node_list_path": "1643452.protein.complete.v11.5.txt"
		    }
		]
    )()

def NicotianaTabacumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nicotiana tabacum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NicotianaTabacumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4097.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4097.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4097.clusters.proteins.v11.5.txt",
		        "sequence_path": "4097.protein.sequences.v11.5.fa",
		        "enrichment_path": "4097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4097.protein.info.v11.5.txt",
		        "node_list_path": "4097.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4097.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpBp7605(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. Bp7605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpBp7605", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1740163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1740163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1740163.protein.info.v11.5.txt",
		        "node_list_path": "1740163.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpEpsl27(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. EPSL27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpEpsl27", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1745378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1745378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1745378.protein.info.v11.5.txt",
		        "node_list_path": "1745378.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyricimonasVirosaDsm23226Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyricimonas virosa DSM 23226 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyricimonasVirosaDsm23226Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121130.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121130.protein.info.v11.5.txt",
		        "node_list_path": "1121130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentisphaeraAraneosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaera araneosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraAraneosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313628.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313628.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313628.clusters.proteins.v11.5.txt",
		        "sequence_path": "313628.protein.sequences.v11.5.fa",
		        "enrichment_path": "313628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313628.protein.info.v11.5.txt",
		        "node_list_path": "313628.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313628.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCadaverisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cadaveris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCadaverisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280692.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280692.protein.info.v11.5.txt",
		        "node_list_path": "1280692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParamicrosporidiumSaccamoebaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paramicrosporidium saccamoebae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParamicrosporidiumSaccamoebaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246581.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246581.protein.info.v11.5.txt",
		        "node_list_path": "1246581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchaaliaMeyeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schaalia meyeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchaaliaMeyeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52773.protein.sequences.v11.5.fa",
		        "enrichment_path": "52773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52773.protein.info.v11.5.txt",
		        "node_list_path": "52773.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifoxyc2Full398(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYC2_FULL_39_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyc2Full398", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798702.protein.info.v11.5.txt",
		        "node_list_path": "1798702.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpQxt31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. QXT-31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpQxt31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1357915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1357915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1357915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1357915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357915.protein.info.v11.5.txt",
		        "node_list_path": "1357915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1357915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFrigidimaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium frigidimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFrigidimaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262320.protein.sequences.v11.5.fa",
		        "enrichment_path": "262320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262320.protein.info.v11.5.txt",
		        "node_list_path": "262320.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9322(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9322 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9322", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "167550.protein.sequences.v11.5.fa",
		        "enrichment_path": "167550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167550.protein.info.v11.5.txt",
		        "node_list_path": "167550.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpLeaf160(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf160 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpLeaf160", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736280.protein.info.v11.5.txt",
		        "node_list_path": "1736280.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSphenisciDsm44792Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sphenisci DSM 44792 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSphenisciDsm44792Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437874.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437874.protein.info.v11.5.txt",
		        "node_list_path": "1437874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioFibrisolvens164(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens 16/4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioFibrisolvens164", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "657324.protein.sequences.v11.5.fa",
		        "enrichment_path": "657324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657324.protein.info.v11.5.txt",
		        "node_list_path": "657324.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_10b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802517.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802517.protein.info.v11.5.txt",
		        "node_list_path": "1802517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp7016Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 70-16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp7016Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895785.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895785.protein.info.v11.5.txt",
		        "node_list_path": "1895785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumStationisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium stationis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumStationisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1705.clusters.proteins.v11.5.txt",
		        "sequence_path": "1705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705.protein.info.v11.5.txt",
		        "node_list_path": "1705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesLuteocolor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces luteocolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesLuteocolor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "285500.protein.sequences.v11.5.fa",
		        "enrichment_path": "285500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285500.protein.info.v11.5.txt",
		        "node_list_path": "285500.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaBovoculiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma bovoculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaBovoculiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743966.clusters.proteins.v11.5.txt",
		        "sequence_path": "743966.protein.sequences.v11.5.fa",
		        "enrichment_path": "743966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743966.protein.info.v11.5.txt",
		        "node_list_path": "743966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumSg841Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium SG8_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumSg841Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703391.protein.info.v11.5.txt",
		        "node_list_path": "1703391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg2304418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_44_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805318.protein.info.v11.5.txt",
		        "node_list_path": "1805318.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaloramatorMitchellensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caloramator mitchellensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloramatorMitchellensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "908809.protein.sequences.v11.5.fa",
		        "enrichment_path": "908809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908809.protein.info.v11.5.txt",
		        "node_list_path": "908809.protein.complete.v11.5.txt"
		    }
		]
    )()

def VitrellaBrassicaformisCcmp3155(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vitrella brassicaformis CCMP3155 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VitrellaBrassicaformisCcmp3155", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1169540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169540.protein.info.v11.5.txt",
		        "node_list_path": "1169540.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusParaplantarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paraplantarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParaplantarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "60520.protein.sequences.v11.5.fa",
		        "enrichment_path": "60520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60520.protein.info.v11.5.txt",
		        "node_list_path": "60520.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaribacterAtrinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter atrinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterAtrinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1333662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333662.protein.info.v11.5.txt",
		        "node_list_path": "1333662.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaGerundensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia gerundensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaGerundensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619313.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619313.protein.info.v11.5.txt",
		        "node_list_path": "1619313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodomicrobiumVannieliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodomicrobium vannielii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodomicrobiumVannieliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "648757.clusters.info.v11.5.txt",
		        "cluster_tree_path": "648757.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "648757.clusters.proteins.v11.5.txt",
		        "sequence_path": "648757.protein.sequences.v11.5.fa",
		        "enrichment_path": "648757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "648757.protein.info.v11.5.txt",
		        "node_list_path": "648757.cluster.nodes.v11.5.txt",
		        "edge_list_path": "648757.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaSpAt9b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. At9b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpAt9b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "592316.protein.sequences.v11.5.fa",
		        "enrichment_path": "592316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592316.protein.info.v11.5.txt",
		        "node_list_path": "592316.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalisaetaLonga(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salisaeta longa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalisaetaLonga", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089550.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089550.protein.info.v11.5.txt",
		        "node_list_path": "1089550.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNbrc109706Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NBRC 109706 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNbrc109706Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1550035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1550035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1550035.clusters.proteins.v11.5.txt",
		        "sequence_path": "1550035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550035.protein.info.v11.5.txt",
		        "node_list_path": "1550035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1550035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MogibacteriumSpCm50(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mogibacterium sp. CM50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MogibacteriumSpCm50", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936375.protein.sequences.v11.5.fa",
		        "enrichment_path": "936375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936375.protein.info.v11.5.txt",
		        "node_list_path": "936375.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitis2F0392Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis 2 F0392 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitis2F0392Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "768726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "768726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "768726.clusters.proteins.v11.5.txt",
		        "sequence_path": "768726.protein.sequences.v11.5.fa",
		        "enrichment_path": "768726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768726.protein.info.v11.5.txt",
		        "node_list_path": "768726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "768726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlammeovirgaSpMy04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flammeovirga sp. MY04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlammeovirgaSpMy04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1191459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1191459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1191459.clusters.proteins.v11.5.txt",
		        "sequence_path": "1191459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1191459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1191459.protein.info.v11.5.txt",
		        "node_list_path": "1191459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1191459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumGwa24115Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium GWA2_41_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumGwa24115Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801814.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801814.protein.info.v11.5.txt",
		        "node_list_path": "1801814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalegentibacterFlavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter flavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterFlavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "287099.protein.sequences.v11.5.fa",
		        "enrichment_path": "287099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "287099.protein.info.v11.5.txt",
		        "node_list_path": "287099.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpMilost1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. MilosT1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpMilost1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "90813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "90813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "90813.clusters.proteins.v11.5.txt",
		        "sequence_path": "90813.protein.sequences.v11.5.fa",
		        "enrichment_path": "90813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90813.protein.info.v11.5.txt",
		        "node_list_path": "90813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "90813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasThermotoleransDsm14292Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas thermotolerans DSM 14292 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasThermotoleransDsm14292Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123021.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123021.protein.info.v11.5.txt",
		        "node_list_path": "1123021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotodesmusKatoptron(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photodesmus katoptron graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotodesmusKatoptron", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28176.protein.sequences.v11.5.fa",
		        "enrichment_path": "28176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28176.protein.info.v11.5.txt",
		        "node_list_path": "28176.protein.complete.v11.5.txt"
		    }
		]
    )()

def SuccinivibrionaceaeBacteriumWg1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Succinivibrionaceae bacterium WG-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuccinivibrionaceaeBacteriumWg1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "758828.protein.sequences.v11.5.fa",
		        "enrichment_path": "758828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758828.protein.info.v11.5.txt",
		        "node_list_path": "758828.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4921Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_01_FULL_49_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4921Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802135.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802135.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802135.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802135.protein.info.v11.5.txt",
		        "node_list_path": "1802135.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802135.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLambdaproteobacteriaBacteriumRifoxyd1Full5627(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lambdaproteobacteria bacterium RIFOXYD1_FULL_56_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLambdaproteobacteriaBacteriumRifoxyd1Full5627", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817770.protein.info.v11.5.txt",
		        "node_list_path": "1817770.protein.complete.v11.5.txt"
		    }
		]
    )()

def PalaeococcusFerrophilusDsm13482Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Palaeococcus ferrophilus DSM 13482 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PalaeococcusFerrophilusDsm13482Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "588319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "588319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "588319.clusters.proteins.v11.5.txt",
		        "sequence_path": "588319.protein.sequences.v11.5.fa",
		        "enrichment_path": "588319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588319.protein.info.v11.5.txt",
		        "node_list_path": "588319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "588319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSpCag435Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:435 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpCag435Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262695.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262695.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262695.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262695.protein.info.v11.5.txt",
		        "node_list_path": "1262695.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262695.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WilliamsiaSp1135Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Williamsia sp. 1135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WilliamsiaSp1135Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1889262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1889262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1889262.clusters.proteins.v11.5.txt",
		        "sequence_path": "1889262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889262.protein.info.v11.5.txt",
		        "node_list_path": "1889262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1889262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwd24214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWD2_42_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwd24214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618944.protein.info.v11.5.txt",
		        "node_list_path": "1618944.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaMonocytogenesEgde(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria monocytogenes EGDe graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaMonocytogenesEgde", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "169963.protein.sequences.v11.5.fa",
		        "enrichment_path": "169963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "169963.protein.info.v11.5.txt",
		        "node_list_path": "169963.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZhouiaAmylolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zhouia amylolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZhouiaAmylolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1286632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1286632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1286632.clusters.proteins.v11.5.txt",
		        "sequence_path": "1286632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286632.protein.info.v11.5.txt",
		        "node_list_path": "1286632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1286632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanothrixSoehngeniiGp6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothrix soehngenii GP6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothrixSoehngeniiGp6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "990316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "990316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "990316.clusters.proteins.v11.5.txt",
		        "sequence_path": "990316.protein.sequences.v11.5.fa",
		        "enrichment_path": "990316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990316.protein.info.v11.5.txt",
		        "node_list_path": "990316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "990316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaSpMccc1a10513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sp. MCCC1A10513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaSpMccc1a10513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1517416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1517416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1517416.clusters.proteins.v11.5.txt",
		        "sequence_path": "1517416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1517416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1517416.protein.info.v11.5.txt",
		        "node_list_path": "1517416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1517416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TessaracoccusFlavescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusFlavescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "399497.protein.sequences.v11.5.fa",
		        "enrichment_path": "399497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399497.protein.info.v11.5.txt",
		        "node_list_path": "399497.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumGw2011Gwa24711b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWA2_47_11b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwa24711b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618358.protein.info.v11.5.txt",
		        "node_list_path": "1618358.protein.complete.v11.5.txt"
		    }
		]
    )()

def PuniceispirillumMarinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Puniceispirillum marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PuniceispirillumMarinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "488538.protein.sequences.v11.5.fa",
		        "enrichment_path": "488538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "488538.protein.info.v11.5.txt",
		        "node_list_path": "488538.protein.complete.v11.5.txt"
		    }
		]
    )()

def PanaeolusCyanescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Panaeolus cyanescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PanaeolusCyanescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "181874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "181874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "181874.clusters.proteins.v11.5.txt",
		        "sequence_path": "181874.protein.sequences.v11.5.fa",
		        "enrichment_path": "181874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "181874.protein.info.v11.5.txt",
		        "node_list_path": "181874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "181874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DendroctonusPonderosaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dendroctonus ponderosae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DendroctonusPonderosaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "77166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "77166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "77166.clusters.proteins.v11.5.txt",
		        "sequence_path": "77166.protein.sequences.v11.5.fa",
		        "enrichment_path": "77166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77166.protein.info.v11.5.txt",
		        "node_list_path": "77166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "77166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalioglobusPacificusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halioglobus pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalioglobusPacificusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930806.clusters.proteins.v11.5.txt",
		        "sequence_path": "930806.protein.sequences.v11.5.fa",
		        "enrichment_path": "930806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930806.protein.info.v11.5.txt",
		        "node_list_path": "930806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumRifcsplowo212Full317Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium RIFCSPLOWO2_12_FULL_31_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumRifcsplowo212Full317Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798015.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798015.protein.info.v11.5.txt",
		        "node_list_path": "1798015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetraodonNigroviridisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetraodon nigroviridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetraodonNigroviridisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "99883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "99883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "99883.clusters.proteins.v11.5.txt",
		        "sequence_path": "99883.protein.sequences.v11.5.fa",
		        "enrichment_path": "99883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "99883.protein.info.v11.5.txt",
		        "node_list_path": "99883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "99883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterTyphlonius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter typhlonius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterTyphlonius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "76936.protein.sequences.v11.5.fa",
		        "enrichment_path": "76936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76936.protein.info.v11.5.txt",
		        "node_list_path": "76936.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraBorgpeterseniiSerovarPomonaStr200901868Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii serovar Pomona str. 200901868 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraBorgpeterseniiSerovarPomonaStr200901868Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1192866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1192866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1192866.clusters.proteins.v11.5.txt",
		        "sequence_path": "1192866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192866.protein.info.v11.5.txt",
		        "node_list_path": "1192866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1192866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MelissococcusPlutoniusAtcc35311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Melissococcus plutonius ATCC 35311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MelissococcusPlutoniusAtcc35311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "940190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "940190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "940190.clusters.proteins.v11.5.txt",
		        "sequence_path": "940190.protein.sequences.v11.5.fa",
		        "enrichment_path": "940190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "940190.protein.info.v11.5.txt",
		        "node_list_path": "940190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "940190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NosocomiicoccusSpNp2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nosocomiicoccus sp. NP2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NosocomiicoccusSpNp2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232430.protein.info.v11.5.txt",
		        "node_list_path": "1232430.protein.complete.v11.5.txt"
		    }
		]
    )()

def BarnesiellaViscericolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Barnesiella viscericola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BarnesiellaViscericolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "880074.clusters.info.v11.5.txt",
		        "cluster_tree_path": "880074.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "880074.clusters.proteins.v11.5.txt",
		        "sequence_path": "880074.protein.sequences.v11.5.fa",
		        "enrichment_path": "880074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880074.protein.info.v11.5.txt",
		        "node_list_path": "880074.cluster.nodes.v11.5.txt",
		        "edge_list_path": "880074.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerophagaThermohalophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerophaga thermohalophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerophagaThermohalophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "886379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "886379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "886379.clusters.proteins.v11.5.txt",
		        "sequence_path": "886379.protein.sequences.v11.5.fa",
		        "enrichment_path": "886379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "886379.protein.info.v11.5.txt",
		        "node_list_path": "886379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "886379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VitrellaBrassicaformisCcmp3155Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vitrella brassicaformis CCMP3155 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VitrellaBrassicaformisCcmp3155Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1169540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1169540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1169540.clusters.proteins.v11.5.txt",
		        "sequence_path": "1169540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169540.protein.info.v11.5.txt",
		        "node_list_path": "1169540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1169540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSoleaferreaMassiliensisAp7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Soleaferrea massiliensis AP7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSoleaferreaMassiliensisAp7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211843.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211843.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211843.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211843.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211843.protein.info.v11.5.txt",
		        "node_list_path": "1211843.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211843.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioLegalliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio legallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioLegalliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "571438.clusters.info.v11.5.txt",
		        "cluster_tree_path": "571438.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "571438.clusters.proteins.v11.5.txt",
		        "sequence_path": "571438.protein.sequences.v11.5.fa",
		        "enrichment_path": "571438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571438.protein.info.v11.5.txt",
		        "node_list_path": "571438.cluster.nodes.v11.5.txt",
		        "edge_list_path": "571438.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpErv7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. ERV7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpErv7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1322334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1322334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1322334.protein.info.v11.5.txt",
		        "node_list_path": "1322334.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyroidesOdoratimimusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myroides odoratimimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyroidesOdoratimimusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1416760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1416760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1416760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1416760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416760.protein.info.v11.5.txt",
		        "node_list_path": "1416760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1416760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaSpErvv1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia sp. ErVv1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaSpErvv1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1603299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603299.protein.info.v11.5.txt",
		        "node_list_path": "1603299.protein.complete.v11.5.txt"
		    }
		]
    )()

def KineosporiaAurantiacaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kineosporia aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KineosporiaAurantiacaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1306174.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1306174.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1306174.clusters.proteins.v11.5.txt",
		        "sequence_path": "1306174.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306174.protein.info.v11.5.txt",
		        "node_list_path": "1306174.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1306174.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMuralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus muralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMuralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264697.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264697.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264697.clusters.proteins.v11.5.txt",
		        "sequence_path": "264697.protein.sequences.v11.5.fa",
		        "enrichment_path": "264697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264697.protein.info.v11.5.txt",
		        "node_list_path": "264697.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264697.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobiumChlorochromatii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium chlorochromatii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumChlorochromatii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "340177.protein.sequences.v11.5.fa",
		        "enrichment_path": "340177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340177.protein.info.v11.5.txt",
		        "node_list_path": "340177.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaTransvalensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia transvalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaTransvalensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206744.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206744.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206744.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206744.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206744.protein.info.v11.5.txt",
		        "node_list_path": "1206744.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206744.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusAssamensisDsm18201Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus assamensis DSM 18201 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusAssamensisDsm18201Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122916.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122916.protein.info.v11.5.txt",
		        "node_list_path": "1122916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonasCompostiDsm21721Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas composti DSM 21721 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasCompostiDsm21721Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121349.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121349.protein.info.v11.5.txt",
		        "node_list_path": "1121349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichinellaSpT6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichinella sp. T6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaSpT6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "92179.protein.sequences.v11.5.fa",
		        "enrichment_path": "92179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92179.protein.info.v11.5.txt",
		        "node_list_path": "92179.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifcsplowo212Full6140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO2_12_FULL_61_40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo212Full6140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797566.protein.info.v11.5.txt",
		        "node_list_path": "1797566.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSubrutilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces subrutilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSubrutilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36818.protein.sequences.v11.5.fa",
		        "enrichment_path": "36818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36818.protein.info.v11.5.txt",
		        "node_list_path": "36818.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisAlbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisAlbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1205910.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1205910.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1205910.clusters.proteins.v11.5.txt",
		        "sequence_path": "1205910.protein.sequences.v11.5.fa",
		        "enrichment_path": "1205910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1205910.protein.info.v11.5.txt",
		        "node_list_path": "1205910.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1205910.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaRhizoxinica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia rhizoxinica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaRhizoxinica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "882378.protein.sequences.v11.5.fa",
		        "enrichment_path": "882378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882378.protein.info.v11.5.txt",
		        "node_list_path": "882378.protein.complete.v11.5.txt"
		    }
		]
    )()

def KandleriaVitulina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kandleria vitulina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KandleriaVitulina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410658.protein.info.v11.5.txt",
		        "node_list_path": "1410658.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsplowo202Full5117Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_02_FULL_51_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo202Full5117Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802284.protein.info.v11.5.txt",
		        "node_list_path": "1802284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumLeiognathiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumLeiognathiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553611.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553611.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553611.clusters.proteins.v11.5.txt",
		        "sequence_path": "553611.protein.sequences.v11.5.fa",
		        "enrichment_path": "553611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553611.protein.info.v11.5.txt",
		        "node_list_path": "553611.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553611.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaBeijingensisNbrc16342(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia beijingensis NBRC 16342 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaBeijingensisNbrc16342", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210068.protein.info.v11.5.txt",
		        "node_list_path": "1210068.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioLitoralisDsm11393Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio litoralis DSM 11393 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioLitoralisDsm11393Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121455.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121455.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121455.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121455.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121455.protein.info.v11.5.txt",
		        "node_list_path": "1121455.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121455.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaEburnea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora eburnea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaEburnea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "227316.protein.sequences.v11.5.fa",
		        "enrichment_path": "227316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227316.protein.info.v11.5.txt",
		        "node_list_path": "227316.protein.complete.v11.5.txt"
		    }
		]
    )()

def OdobenusRosmarusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Odobenus rosmarus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OdobenusRosmarusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9707.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9707.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9707.clusters.proteins.v11.5.txt",
		        "sequence_path": "9707.protein.sequences.v11.5.fa",
		        "enrichment_path": "9707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9707.protein.info.v11.5.txt",
		        "node_list_path": "9707.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9707.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumVivaxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium vivax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumVivaxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5855.clusters.proteins.v11.5.txt",
		        "sequence_path": "5855.protein.sequences.v11.5.fa",
		        "enrichment_path": "5855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5855.protein.info.v11.5.txt",
		        "node_list_path": "5855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrenothrixSpD3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crenothrix sp. D3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenothrixSpD3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1880899.protein.sequences.v11.5.fa",
		        "enrichment_path": "1880899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1880899.protein.info.v11.5.txt",
		        "node_list_path": "1880899.protein.complete.v11.5.txt"
		    }
		]
    )()

def MiscellaneousCrenarchaeotaGroup6ArchaeonAd81Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return miscellaneous Crenarchaeota group-6 archaeon AD8-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MiscellaneousCrenarchaeotaGroup6ArchaeonAd81Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1685126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1685126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1685126.clusters.proteins.v11.5.txt",
		        "sequence_path": "1685126.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685126.protein.info.v11.5.txt",
		        "node_list_path": "1685126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1685126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrobaculumNeutrophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum neutrophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumNeutrophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "444157.protein.sequences.v11.5.fa",
		        "enrichment_path": "444157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444157.protein.info.v11.5.txt",
		        "node_list_path": "444157.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasSpLeaf131Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Leaf131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasSpLeaf131Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736270.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736270.protein.info.v11.5.txt",
		        "node_list_path": "1736270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyosynoviaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyosynoviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyosynoviaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29559.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29559.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29559.clusters.proteins.v11.5.txt",
		        "sequence_path": "29559.protein.sequences.v11.5.fa",
		        "enrichment_path": "29559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29559.protein.info.v11.5.txt",
		        "node_list_path": "29559.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29559.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LewinellaSp4g2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lewinella sp. 4G2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LewinellaSp4g2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803372.protein.info.v11.5.txt",
		        "node_list_path": "1803372.protein.complete.v11.5.txt"
		    }
		]
    )()

def RathayibacterOskolensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rathayibacter oskolensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RathayibacterOskolensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1891671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1891671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1891671.clusters.proteins.v11.5.txt",
		        "sequence_path": "1891671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891671.protein.info.v11.5.txt",
		        "node_list_path": "1891671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1891671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacteriumSpPsu2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium sp. PSU-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacteriumSpPsu2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930849.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930849.protein.info.v11.5.txt",
		        "node_list_path": "1930849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomonasBhubaneswarensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas bhubaneswarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomonasBhubaneswarensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "339866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "339866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "339866.clusters.proteins.v11.5.txt",
		        "sequence_path": "339866.protein.sequences.v11.5.fa",
		        "enrichment_path": "339866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "339866.protein.info.v11.5.txt",
		        "node_list_path": "339866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "339866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusPorci(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus porci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPorci", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123315.protein.info.v11.5.txt",
		        "node_list_path": "1123315.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusVelezensisTrigocor1448(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus velezensis TrigoCor1448 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusVelezensisTrigocor1448", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449088.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449088.protein.info.v11.5.txt",
		        "node_list_path": "1449088.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusAnimalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus animalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAnimalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1605.clusters.proteins.v11.5.txt",
		        "sequence_path": "1605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1605.protein.info.v11.5.txt",
		        "node_list_path": "1605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusWakoensisJcm9140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus wakoensis JCM 9140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusWakoensisJcm9140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236970.protein.info.v11.5.txt",
		        "node_list_path": "1236970.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaDonostiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia donostiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaDonostiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1538463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1538463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1538463.protein.info.v11.5.txt",
		        "node_list_path": "1538463.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChelatococcusSpGw1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chelatococcus sp. GW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelatococcusSpGw1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211115.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211115.protein.info.v11.5.txt",
		        "node_list_path": "1211115.protein.complete.v11.5.txt"
		    }
		]
    )()

def BathymodiolusAzoricusThioautotrophicGillSymbiontCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bathymodiolus azoricus thioautotrophic gill symbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BathymodiolusAzoricusThioautotrophicGillSymbiontCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "235205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "235205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "235205.clusters.proteins.v11.5.txt",
		        "sequence_path": "235205.protein.sequences.v11.5.fa",
		        "enrichment_path": "235205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "235205.protein.info.v11.5.txt",
		        "node_list_path": "235205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "235205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaAsperellumCbs43397(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma asperellum CBS 433.97 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaAsperellumCbs43397", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1042311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042311.protein.info.v11.5.txt",
		        "node_list_path": "1042311.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfobacteriumHveragerdense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium hveragerdense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfobacteriumHveragerdense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123372.protein.info.v11.5.txt",
		        "node_list_path": "1123372.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumJaponicumUt26sCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium japonicum UT26S Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumJaponicumUt26sCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "452662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "452662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "452662.clusters.proteins.v11.5.txt",
		        "sequence_path": "452662.protein.sequences.v11.5.fa",
		        "enrichment_path": "452662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452662.protein.info.v11.5.txt",
		        "node_list_path": "452662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "452662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumVaccaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium vaccae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumVaccaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1194972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1194972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1194972.clusters.proteins.v11.5.txt",
		        "sequence_path": "1194972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194972.protein.info.v11.5.txt",
		        "node_list_path": "1194972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1194972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag1024(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag1024", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262770.protein.info.v11.5.txt",
		        "node_list_path": "1262770.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp10819081(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1081908.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp10819081", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834066.protein.info.v11.5.txt",
		        "node_list_path": "1834066.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobacterGummiphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobacter gummiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobacterGummiphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "946333.protein.sequences.v11.5.fa",
		        "enrichment_path": "946333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946333.protein.info.v11.5.txt",
		        "node_list_path": "946333.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhoenixDactylifera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phoenix dactylifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhoenixDactylifera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42345.protein.sequences.v11.5.fa",
		        "enrichment_path": "42345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42345.protein.info.v11.5.txt",
		        "node_list_path": "42345.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpMsmb0266Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. MSMB0266 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpMsmb0266Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1637837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1637837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1637837.clusters.proteins.v11.5.txt",
		        "sequence_path": "1637837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1637837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1637837.protein.info.v11.5.txt",
		        "node_list_path": "1637837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1637837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKimchiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kimchiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKimchiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "993692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "993692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "993692.clusters.proteins.v11.5.txt",
		        "sequence_path": "993692.protein.sequences.v11.5.fa",
		        "enrichment_path": "993692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "993692.protein.info.v11.5.txt",
		        "node_list_path": "993692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "993692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerrabacterSpRoot85Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terrabacter sp. Root85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrabacterSpRoot85Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736603.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736603.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736603.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736603.protein.info.v11.5.txt",
		        "node_list_path": "1736603.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736603.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasEutropha(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas eutropha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasEutropha", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "335283.protein.sequences.v11.5.fa",
		        "enrichment_path": "335283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335283.protein.info.v11.5.txt",
		        "node_list_path": "335283.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeorhizobiumGalegaeOrientalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorhizobiumGalegaeOrientalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1028800.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028800.protein.info.v11.5.txt",
		        "node_list_path": "1028800.protein.complete.v11.5.txt"
		    }
		]
    )()

def KocuriaPolarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kocuria polaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaPolarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "136273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "136273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "136273.clusters.proteins.v11.5.txt",
		        "sequence_path": "136273.protein.sequences.v11.5.fa",
		        "enrichment_path": "136273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "136273.protein.info.v11.5.txt",
		        "node_list_path": "136273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "136273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanothermobacterThermautotrophicusStrDeltaHCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter thermautotrophicus str. Delta H Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermobacterThermautotrophicusStrDeltaHCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "187420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "187420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "187420.clusters.proteins.v11.5.txt",
		        "sequence_path": "187420.protein.sequences.v11.5.fa",
		        "enrichment_path": "187420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "187420.protein.info.v11.5.txt",
		        "node_list_path": "187420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "187420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaWallisiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea wallisii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaWallisiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1076551.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1076551.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1076551.clusters.proteins.v11.5.txt",
		        "sequence_path": "1076551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076551.protein.info.v11.5.txt",
		        "node_list_path": "1076551.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1076551.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaminicellaSporogenesDsm14501Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caminicella sporogenes DSM 14501 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaminicellaSporogenesDsm14501Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121266.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121266.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121266.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121266.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121266.protein.info.v11.5.txt",
		        "node_list_path": "1121266.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121266.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusPasteurii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pasteurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPasteurii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423790.protein.info.v11.5.txt",
		        "node_list_path": "1423790.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusRotaiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus rotai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusRotaiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118060.clusters.proteins.v11.5.txt",
		        "sequence_path": "118060.protein.sequences.v11.5.fa",
		        "enrichment_path": "118060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118060.protein.info.v11.5.txt",
		        "node_list_path": "118060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsplowo202Full468Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_02_FULL_46_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo202Full468Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797879.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797879.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797879.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797879.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797879.protein.info.v11.5.txt",
		        "node_list_path": "1797879.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797879.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaMaculosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella maculosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMaculosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122986.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122986.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122986.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122986.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122986.protein.info.v11.5.txt",
		        "node_list_path": "1122986.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122986.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSulfaticallidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sulfaticallidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSulfaticallidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "387631.protein.sequences.v11.5.fa",
		        "enrichment_path": "387631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "387631.protein.info.v11.5.txt",
		        "node_list_path": "387631.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusHarei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus harei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusHarei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "908338.protein.sequences.v11.5.fa",
		        "enrichment_path": "908338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908338.protein.info.v11.5.txt",
		        "node_list_path": "908338.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp351mftsu51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 351MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp351mftsu51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1172180.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172180.protein.info.v11.5.txt",
		        "node_list_path": "1172180.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarineGroupIThaumarchaeoteScgcAb629i23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote SCGC AB629I23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineGroupIThaumarchaeoteScgcAb629i23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131266.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131266.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131266.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131266.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131266.protein.info.v11.5.txt",
		        "node_list_path": "1131266.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131266.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FodinicurvataSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fodinicurvata sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FodinicurvataSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "570952.protein.sequences.v11.5.fa",
		        "enrichment_path": "570952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570952.protein.info.v11.5.txt",
		        "node_list_path": "570952.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaXyliCtcb07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia xyli CTCB07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaXyliCtcb07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "281090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "281090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "281090.clusters.proteins.v11.5.txt",
		        "sequence_path": "281090.protein.sequences.v11.5.fa",
		        "enrichment_path": "281090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "281090.protein.info.v11.5.txt",
		        "node_list_path": "281090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "281090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterLarvaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter larvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterLarvaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1789224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1789224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1789224.clusters.proteins.v11.5.txt",
		        "sequence_path": "1789224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1789224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1789224.protein.info.v11.5.txt",
		        "node_list_path": "1789224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1789224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TeredinibacterTurneraeT7902Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Teredinibacter turnerae T7902 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TeredinibacterTurneraeT7902Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1056820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1056820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1056820.clusters.proteins.v11.5.txt",
		        "sequence_path": "1056820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1056820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1056820.protein.info.v11.5.txt",
		        "node_list_path": "1056820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1056820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumKa00251Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KA00251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumKa00251Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1497953.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1497953.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1497953.clusters.proteins.v11.5.txt",
		        "sequence_path": "1497953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1497953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1497953.protein.info.v11.5.txt",
		        "node_list_path": "1497953.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1497953.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalibacterSaccharofermentansDsm14828Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacter saccharofermentans DSM 14828 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacterSaccharofermentansDsm14828Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120975.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120975.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120975.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120975.protein.info.v11.5.txt",
		        "node_list_path": "1120975.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120975.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMethanolicusMga3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus methanolicus MGA3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMethanolicusMga3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "796606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "796606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "796606.clusters.proteins.v11.5.txt",
		        "sequence_path": "796606.protein.sequences.v11.5.fa",
		        "enrichment_path": "796606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796606.protein.info.v11.5.txt",
		        "node_list_path": "796606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "796606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterCrystallopoietesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter crystallopoietes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterCrystallopoietesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37928.clusters.proteins.v11.5.txt",
		        "sequence_path": "37928.protein.sequences.v11.5.fa",
		        "enrichment_path": "37928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37928.protein.info.v11.5.txt",
		        "node_list_path": "37928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BeggiatoaAlba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Beggiatoa alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeggiatoaAlba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "395493.protein.sequences.v11.5.fa",
		        "enrichment_path": "395493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395493.protein.info.v11.5.txt",
		        "node_list_path": "395493.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumCallitrichos(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium callitrichos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumCallitrichos", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437609.protein.info.v11.5.txt",
		        "node_list_path": "1437609.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaplasmaCentrale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma centrale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaplasmaCentrale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "574556.protein.sequences.v11.5.fa",
		        "enrichment_path": "574556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574556.protein.info.v11.5.txt",
		        "node_list_path": "574556.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasFloridensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas floridensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasFloridensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1843580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1843580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1843580.clusters.proteins.v11.5.txt",
		        "sequence_path": "1843580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1843580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1843580.protein.info.v11.5.txt",
		        "node_list_path": "1843580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1843580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterPasteurianus3p3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus 3P3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterPasteurianus3p3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "940282.protein.sequences.v11.5.fa",
		        "enrichment_path": "940282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "940282.protein.info.v11.5.txt",
		        "node_list_path": "940282.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpAt4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. AT4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpAt4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720194.protein.info.v11.5.txt",
		        "node_list_path": "1720194.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidothermusCellulolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidothermus cellulolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidothermusCellulolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351607.clusters.proteins.v11.5.txt",
		        "sequence_path": "351607.protein.sequences.v11.5.fa",
		        "enrichment_path": "351607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351607.protein.info.v11.5.txt",
		        "node_list_path": "351607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRifcsplowo202Full6721Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO2_02_FULL_67_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202Full6721Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797183.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797183.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797183.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797183.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797183.protein.info.v11.5.txt",
		        "node_list_path": "1797183.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797183.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaTropicalisMya3404Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida tropicalis MYA-3404 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaTropicalisMya3404Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "294747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "294747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "294747.clusters.proteins.v11.5.txt",
		        "sequence_path": "294747.protein.sequences.v11.5.fa",
		        "enrichment_path": "294747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294747.protein.info.v11.5.txt",
		        "node_list_path": "294747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "294747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAngulatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium angulatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAngulatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "518635.protein.sequences.v11.5.fa",
		        "enrichment_path": "518635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "518635.protein.info.v11.5.txt",
		        "node_list_path": "518635.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacterSphaeroides241(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter sphaeroides 241 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterSphaeroides241", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272943.protein.sequences.v11.5.fa",
		        "enrichment_path": "272943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272943.protein.info.v11.5.txt",
		        "node_list_path": "272943.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesScopuliridisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces scopuliridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesScopuliridisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1440053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1440053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1440053.clusters.proteins.v11.5.txt",
		        "sequence_path": "1440053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1440053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1440053.protein.info.v11.5.txt",
		        "node_list_path": "1440053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1440053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacteraceaeBacteriumGwc25844(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_58_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacteraceaeBacteriumGwc25844", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798318.protein.info.v11.5.txt",
		        "node_list_path": "1798318.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumGallinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumGallinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449338.protein.info.v11.5.txt",
		        "node_list_path": "1449338.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellvibrionaceaeBacteriumBs12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrionaceae bacterium Bs12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrionaceaeBacteriumBs12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304902.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304902.protein.info.v11.5.txt",
		        "node_list_path": "1304902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaParamesenteroides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella paramesenteroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaParamesenteroides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585506.protein.sequences.v11.5.fa",
		        "enrichment_path": "585506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585506.protein.info.v11.5.txt",
		        "node_list_path": "585506.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa15613(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA1_56_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa15613", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618803.protein.info.v11.5.txt",
		        "node_list_path": "1618803.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSp10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. 10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSp10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158294.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158294.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158294.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158294.protein.info.v11.5.txt",
		        "node_list_path": "1158294.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158294.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaceaeBacteriumKbs89Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS89 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs89Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267534.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267534.protein.info.v11.5.txt",
		        "node_list_path": "1267534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusNovofumigatusIbt16806(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus novofumigatus IBT 16806 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusNovofumigatusIbt16806", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392255.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392255.protein.info.v11.5.txt",
		        "node_list_path": "1392255.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaSymbioticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia symbiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSymbioticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "568817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "568817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "568817.clusters.proteins.v11.5.txt",
		        "sequence_path": "568817.protein.sequences.v11.5.fa",
		        "enrichment_path": "568817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568817.protein.info.v11.5.txt",
		        "node_list_path": "568817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "568817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsphigho202Full4912Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_49_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full4912Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802271.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802271.protein.info.v11.5.txt",
		        "node_list_path": "1802271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095769.protein.info.v11.5.txt",
		        "node_list_path": "1095769.protein.complete.v11.5.txt"
		    }
		]
    )()

def SedimentitaleaNanhaiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sedimentitalea nanhaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SedimentitaleaNanhaiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999627.protein.sequences.v11.5.fa",
		        "enrichment_path": "999627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999627.protein.info.v11.5.txt",
		        "node_list_path": "999627.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusGobiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus gobiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusGobiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "745776.clusters.info.v11.5.txt",
		        "cluster_tree_path": "745776.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "745776.clusters.proteins.v11.5.txt",
		        "sequence_path": "745776.protein.sequences.v11.5.fa",
		        "enrichment_path": "745776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745776.protein.info.v11.5.txt",
		        "node_list_path": "745776.cluster.nodes.v11.5.txt",
		        "edge_list_path": "745776.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TenacibaculumMesophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum mesophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumMesophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "104268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "104268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "104268.clusters.proteins.v11.5.txt",
		        "sequence_path": "104268.protein.sequences.v11.5.fa",
		        "enrichment_path": "104268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104268.protein.info.v11.5.txt",
		        "node_list_path": "104268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "104268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5520Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_55_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5520Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798497.protein.info.v11.5.txt",
		        "node_list_path": "1798497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WilliamsiaSterculiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Williamsia sterculiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WilliamsiaSterculiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1344003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1344003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1344003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1344003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1344003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1344003.protein.info.v11.5.txt",
		        "node_list_path": "1344003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1344003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetalesBacteriumSpiro05Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetalesBacteriumSpiro05Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674861.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674861.protein.info.v11.5.txt",
		        "node_list_path": "1674861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifoxyc12Full6523Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFOXYC12_FULL_65_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifoxyc12Full6523Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797572.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797572.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797572.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797572.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797572.protein.info.v11.5.txt",
		        "node_list_path": "1797572.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797572.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EchinopsTelfairi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Echinops telfairi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EchinopsTelfairi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9371.protein.sequences.v11.5.fa",
		        "enrichment_path": "9371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9371.protein.info.v11.5.txt",
		        "node_list_path": "9371.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusJenseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusJenseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "109790.clusters.info.v11.5.txt",
		        "cluster_tree_path": "109790.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "109790.clusters.proteins.v11.5.txt",
		        "sequence_path": "109790.protein.sequences.v11.5.fa",
		        "enrichment_path": "109790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109790.protein.info.v11.5.txt",
		        "node_list_path": "109790.cluster.nodes.v11.5.txt",
		        "edge_list_path": "109790.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAkl11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. AKL11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAkl11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "545264.protein.sequences.v11.5.fa",
		        "enrichment_path": "545264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545264.protein.info.v11.5.txt",
		        "node_list_path": "545264.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumViciae248Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae 248 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumViciae248Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936136.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936136.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936136.clusters.proteins.v11.5.txt",
		        "sequence_path": "936136.protein.sequences.v11.5.fa",
		        "enrichment_path": "936136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936136.protein.info.v11.5.txt",
		        "node_list_path": "936136.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936136.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaSubspEntericaSerovarTyphimuriumStrLt2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. enterica serovar Typhimurium str. LT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaSubspEntericaSerovarTyphimuriumStrLt2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "99287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "99287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "99287.clusters.proteins.v11.5.txt",
		        "sequence_path": "99287.protein.sequences.v11.5.fa",
		        "enrichment_path": "99287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "99287.protein.info.v11.5.txt",
		        "node_list_path": "99287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "99287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeratitisCapitataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ceratitis capitata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeratitisCapitataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7213.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7213.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7213.clusters.proteins.v11.5.txt",
		        "sequence_path": "7213.protein.sequences.v11.5.fa",
		        "enrichment_path": "7213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7213.protein.info.v11.5.txt",
		        "node_list_path": "7213.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7213.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnicoccusIslandicusDsm13165(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignicoccus islandicus DSM 13165 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnicoccusIslandicusDsm13165", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "940295.protein.sequences.v11.5.fa",
		        "enrichment_path": "940295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "940295.protein.info.v11.5.txt",
		        "node_list_path": "940295.protein.complete.v11.5.txt"
		    }
		]
    )()

def RothiaDentocariosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rothia dentocariosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RothiaDentocariosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762948.clusters.proteins.v11.5.txt",
		        "sequence_path": "762948.protein.sequences.v11.5.fa",
		        "enrichment_path": "762948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762948.protein.info.v11.5.txt",
		        "node_list_path": "762948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophobacteralesBacteriumDelta02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophobacterales bacterium Delta_02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophobacteralesBacteriumDelta02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674896.protein.info.v11.5.txt",
		        "node_list_path": "1674896.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapsellaRubellaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capsella rubella Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsellaRubellaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "81985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "81985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "81985.clusters.proteins.v11.5.txt",
		        "sequence_path": "81985.protein.sequences.v11.5.fa",
		        "enrichment_path": "81985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81985.protein.info.v11.5.txt",
		        "node_list_path": "81985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "81985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumMar2010188(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium MAR_2010_188 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumMar2010188", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1250295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250295.protein.info.v11.5.txt",
		        "node_list_path": "1250295.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusConstellatusPharyngisC1050(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus constellatus pharyngis C1050 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusConstellatusPharyngisC1050", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "862969.protein.sequences.v11.5.fa",
		        "enrichment_path": "862969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862969.protein.info.v11.5.txt",
		        "node_list_path": "862969.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaSp52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dorea sp. 52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaSp52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235798.protein.info.v11.5.txt",
		        "node_list_path": "1235798.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesViolaceusniger(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces violaceusniger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesViolaceusniger", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "653045.protein.sequences.v11.5.fa",
		        "enrichment_path": "653045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "653045.protein.info.v11.5.txt",
		        "node_list_path": "653045.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSanguinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSanguinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1545044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1545044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1545044.clusters.proteins.v11.5.txt",
		        "sequence_path": "1545044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545044.protein.info.v11.5.txt",
		        "node_list_path": "1545044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1545044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpPstaah124Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. PsTaAH124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpPstaah124Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157638.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157638.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157638.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157638.protein.info.v11.5.txt",
		        "node_list_path": "1157638.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157638.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaMeleagridis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma meleagridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaMeleagridis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29561.protein.sequences.v11.5.fa",
		        "enrichment_path": "29561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29561.protein.info.v11.5.txt",
		        "node_list_path": "29561.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaPneumoniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia pneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaPneumoniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206737.protein.info.v11.5.txt",
		        "node_list_path": "1206737.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAnginosusC1051Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus C1051 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAnginosusC1051Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "862970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "862970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "862970.clusters.proteins.v11.5.txt",
		        "sequence_path": "862970.protein.sequences.v11.5.fa",
		        "enrichment_path": "862970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862970.protein.info.v11.5.txt",
		        "node_list_path": "862970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "862970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BerkelbacteriaBacteriumGw2011Gwa13910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011_GWA1_39_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BerkelbacteriaBacteriumGw2011Gwa13910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618332.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618332.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618332.protein.info.v11.5.txt",
		        "node_list_path": "1618332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FukomysDamarensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fukomys damarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FukomysDamarensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "885580.protein.sequences.v11.5.fa",
		        "enrichment_path": "885580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "885580.protein.info.v11.5.txt",
		        "node_list_path": "885580.protein.complete.v11.5.txt"
		    }
		]
    )()

def RathayibacterSpLeaf296Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rathayibacter sp. Leaf296 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RathayibacterSpLeaf296Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736327.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736327.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736327.protein.info.v11.5.txt",
		        "node_list_path": "1736327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCurvatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus curvatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCurvatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1074451.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1074451.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1074451.clusters.proteins.v11.5.txt",
		        "sequence_path": "1074451.protein.sequences.v11.5.fa",
		        "enrichment_path": "1074451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1074451.protein.info.v11.5.txt",
		        "node_list_path": "1074451.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1074451.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusGriffiniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus griffiniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusGriffiniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351672.protein.sequences.v11.5.fa",
		        "enrichment_path": "351672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351672.protein.info.v11.5.txt",
		        "node_list_path": "351672.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMycoplasmaHaemominutumBirmingham1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemominutum Birmingham 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMycoplasmaHaemominutumBirmingham1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1116213.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1116213.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1116213.clusters.proteins.v11.5.txt",
		        "sequence_path": "1116213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116213.protein.info.v11.5.txt",
		        "node_list_path": "1116213.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1116213.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RugosibacterAromaticivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rugosibacter aromaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RugosibacterAromaticivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1565605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1565605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1565605.protein.info.v11.5.txt",
		        "node_list_path": "1565605.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeofusicoccumParvumUcrnp2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neofusicoccum parvum UCRNP2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeofusicoccumParvumUcrnp2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1287680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1287680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1287680.clusters.proteins.v11.5.txt",
		        "sequence_path": "1287680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287680.protein.info.v11.5.txt",
		        "node_list_path": "1287680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1287680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DichelobacterNodosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dichelobacter nodosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DichelobacterNodosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246195.clusters.proteins.v11.5.txt",
		        "sequence_path": "246195.protein.sequences.v11.5.fa",
		        "enrichment_path": "246195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246195.protein.info.v11.5.txt",
		        "node_list_path": "246195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesCulicifaciesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles culicifacies Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesCulicifaciesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "139723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "139723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "139723.clusters.proteins.v11.5.txt",
		        "sequence_path": "139723.protein.sequences.v11.5.fa",
		        "enrichment_path": "139723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "139723.protein.info.v11.5.txt",
		        "node_list_path": "139723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "139723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionKazanBacteriumGw2011Gwa15015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium GW2011_GWA1_50_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionKazanBacteriumGw2011Gwa15015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1620412.protein.sequences.v11.5.fa",
		        "enrichment_path": "1620412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1620412.protein.info.v11.5.txt",
		        "node_list_path": "1620412.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosopelagicusBrevisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosopelagicus brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosopelagicusBrevisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410606.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410606.protein.info.v11.5.txt",
		        "node_list_path": "1410606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiaceaeBacteriumGa0074131(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobiaceae bacterium Ga0074131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiaceaeBacteriumGa0074131", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752203.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752203.protein.info.v11.5.txt",
		        "node_list_path": "1752203.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag83Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag83Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262992.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262992.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262992.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262992.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262992.protein.info.v11.5.txt",
		        "node_list_path": "1262992.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262992.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumGrantiiDsm8605Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium grantii DSM 8605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumGrantiiDsm8605Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121316.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121316.protein.info.v11.5.txt",
		        "node_list_path": "1121316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysobacterSpRoot96Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterSpRoot96Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736612.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736612.protein.info.v11.5.txt",
		        "node_list_path": "1736612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FerrimonasSenticiiDsm18821Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas senticii DSM 18821 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrimonasSenticiiDsm18821Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121880.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121880.protein.info.v11.5.txt",
		        "node_list_path": "1121880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaPseudotuberculosis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia pseudotuberculosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaPseudotuberculosis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "633.protein.sequences.v11.5.fa",
		        "enrichment_path": "633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633.protein.info.v11.5.txt",
		        "node_list_path": "633.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag678(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:678 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag678", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262831.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262831.protein.info.v11.5.txt",
		        "node_list_path": "1262831.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwb14314(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_43_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb14314", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618578.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618578.protein.info.v11.5.txt",
		        "node_list_path": "1618578.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpRc2d(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Rc2d graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpRc2d", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855321.protein.info.v11.5.txt",
		        "node_list_path": "1855321.protein.complete.v11.5.txt"
		    }
		]
    )()

def HericiumAlpestre(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hericium alpestre graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HericiumAlpestre", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "135208.protein.sequences.v11.5.fa",
		        "enrichment_path": "135208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "135208.protein.info.v11.5.txt",
		        "node_list_path": "135208.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumMarinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumMarinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397696.protein.info.v11.5.txt",
		        "node_list_path": "1397696.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisTolypomycina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis tolypomycina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisTolypomycina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "208445.protein.sequences.v11.5.fa",
		        "enrichment_path": "208445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208445.protein.info.v11.5.txt",
		        "node_list_path": "208445.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirulinaMajorPcc6313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirulina major PCC 6313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirulinaMajorPcc6313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "129961.protein.sequences.v11.5.fa",
		        "enrichment_path": "129961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "129961.protein.info.v11.5.txt",
		        "node_list_path": "129961.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusFaeciumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusFaeciumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1352.clusters.proteins.v11.5.txt",
		        "sequence_path": "1352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1352.protein.info.v11.5.txt",
		        "node_list_path": "1352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnh099Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNH099 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnh099Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1137269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1137269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1137269.clusters.proteins.v11.5.txt",
		        "sequence_path": "1137269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137269.protein.info.v11.5.txt",
		        "node_list_path": "1137269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1137269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioLegallii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio legallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioLegallii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "571438.protein.sequences.v11.5.fa",
		        "enrichment_path": "571438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571438.protein.info.v11.5.txt",
		        "node_list_path": "571438.protein.complete.v11.5.txt"
		    }
		]
    )()

def AurantimonasCoralicidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aurantimonas coralicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AurantimonasCoralicidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "182270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "182270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "182270.clusters.proteins.v11.5.txt",
		        "sequence_path": "182270.protein.sequences.v11.5.fa",
		        "enrichment_path": "182270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "182270.protein.info.v11.5.txt",
		        "node_list_path": "182270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "182270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VignaAngularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vigna angularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VignaAngularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3914.protein.sequences.v11.5.fa",
		        "enrichment_path": "3914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3914.protein.info.v11.5.txt",
		        "node_list_path": "3914.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYonathbacteriaBacteriumRifoxyd1Full5236(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFOXYD1_FULL_52_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifoxyd1Full5236", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802730.protein.info.v11.5.txt",
		        "node_list_path": "1802730.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumIntracellulare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium intracellulare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumIntracellulare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "487521.protein.sequences.v11.5.fa",
		        "enrichment_path": "487521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487521.protein.info.v11.5.txt",
		        "node_list_path": "487521.protein.complete.v11.5.txt"
		    }
		]
    )()

def MitsuokellaMultacida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mitsuokella multacida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MitsuokellaMultacida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "500635.protein.sequences.v11.5.fa",
		        "enrichment_path": "500635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500635.protein.info.v11.5.txt",
		        "node_list_path": "500635.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumFuchskuhlense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium fuchskuhlense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumFuchskuhlense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117702.protein.info.v11.5.txt",
		        "node_list_path": "1117702.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColeofasciculusChthonoplastesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coleofasciculus chthonoplastes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColeofasciculusChthonoplastesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118168.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118168.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118168.clusters.proteins.v11.5.txt",
		        "sequence_path": "118168.protein.sequences.v11.5.fa",
		        "enrichment_path": "118168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118168.protein.info.v11.5.txt",
		        "node_list_path": "118168.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118168.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpKordi49Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpKordi49Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585423.clusters.proteins.v11.5.txt",
		        "sequence_path": "585423.protein.sequences.v11.5.fa",
		        "enrichment_path": "585423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585423.protein.info.v11.5.txt",
		        "node_list_path": "585423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterInsolitus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter insolitus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterInsolitus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "217204.protein.sequences.v11.5.fa",
		        "enrichment_path": "217204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "217204.protein.info.v11.5.txt",
		        "node_list_path": "217204.protein.complete.v11.5.txt"
		    }
		]
    )()

def HoefleaSpBal378Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hoeflea sp. BAL378 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoefleaSpBal378Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1547437.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1547437.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1547437.clusters.proteins.v11.5.txt",
		        "sequence_path": "1547437.protein.sequences.v11.5.fa",
		        "enrichment_path": "1547437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1547437.protein.info.v11.5.txt",
		        "node_list_path": "1547437.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1547437.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiopsisListeriNbrc13360(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis listeri NBRC 13360 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisListeriNbrc13360", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348637.protein.info.v11.5.txt",
		        "node_list_path": "1348637.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaFusca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella fusca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaFusca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236517.protein.info.v11.5.txt",
		        "node_list_path": "1236517.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaConfusa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella confusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaConfusa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1127131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127131.protein.info.v11.5.txt",
		        "node_list_path": "1127131.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSubtilisSubspInaquosorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. inaquosorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSubtilisSubspInaquosorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "483913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "483913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "483913.clusters.proteins.v11.5.txt",
		        "sequence_path": "483913.protein.sequences.v11.5.fa",
		        "enrichment_path": "483913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483913.protein.info.v11.5.txt",
		        "node_list_path": "483913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "483913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioProteoclasticusP6b7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus P6B7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioProteoclasticusP6b7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410650.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410650.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410650.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410650.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410650.protein.info.v11.5.txt",
		        "node_list_path": "1410650.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410650.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusSiccatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus siccatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusSiccatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1137991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137991.protein.info.v11.5.txt",
		        "node_list_path": "1137991.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumBohemicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium bohemicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumBohemicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56425.clusters.proteins.v11.5.txt",
		        "sequence_path": "56425.protein.sequences.v11.5.fa",
		        "enrichment_path": "56425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56425.protein.info.v11.5.txt",
		        "node_list_path": "56425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeyerozymaGuilliermondiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meyerozyma guilliermondii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeyerozymaGuilliermondiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4929.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4929.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4929.clusters.proteins.v11.5.txt",
		        "sequence_path": "4929.protein.sequences.v11.5.fa",
		        "enrichment_path": "4929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4929.protein.info.v11.5.txt",
		        "node_list_path": "4929.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4929.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlammeovirgaceaeBacterium311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flammeovirgaceae bacterium 311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlammeovirgaceaeBacterium311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1257021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1257021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1257021.protein.info.v11.5.txt",
		        "node_list_path": "1257021.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802516.protein.info.v11.5.txt",
		        "node_list_path": "1802516.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterGossypiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter gossypii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterGossypiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "551996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "551996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "551996.clusters.proteins.v11.5.txt",
		        "sequence_path": "551996.protein.sequences.v11.5.fa",
		        "enrichment_path": "551996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551996.protein.info.v11.5.txt",
		        "node_list_path": "551996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "551996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyellaThiooxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyella thiooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaThiooxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445710.protein.sequences.v11.5.fa",
		        "enrichment_path": "445710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445710.protein.info.v11.5.txt",
		        "node_list_path": "445710.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerrimonasMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrimonasMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "299255.protein.sequences.v11.5.fa",
		        "enrichment_path": "299255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299255.protein.info.v11.5.txt",
		        "node_list_path": "299255.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlmg11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALMg11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlmg11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158165.protein.info.v11.5.txt",
		        "node_list_path": "1158165.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpOr444Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. OR444 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpOr444Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1076525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1076525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1076525.clusters.proteins.v11.5.txt",
		        "sequence_path": "1076525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076525.protein.info.v11.5.txt",
		        "node_list_path": "1076525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1076525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871013.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871013.protein.info.v11.5.txt",
		        "node_list_path": "1871013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitratiruptorSpSb1552Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitratiruptor sp. SB1552 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratiruptorSpSb1552Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "387092.clusters.info.v11.5.txt",
		        "cluster_tree_path": "387092.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "387092.clusters.proteins.v11.5.txt",
		        "sequence_path": "387092.protein.sequences.v11.5.fa",
		        "enrichment_path": "387092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "387092.protein.info.v11.5.txt",
		        "node_list_path": "387092.cluster.nodes.v11.5.txt",
		        "edge_list_path": "387092.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NioellaNitratireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nioella nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NioellaNitratireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1287720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1287720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1287720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1287720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287720.protein.info.v11.5.txt",
		        "node_list_path": "1287720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1287720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacterium9401234(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9401234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacterium9401234", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "938288.protein.sequences.v11.5.fa",
		        "enrichment_path": "938288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938288.protein.info.v11.5.txt",
		        "node_list_path": "938288.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasPhaseoliPvDieffenbachiaeLmg695Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas phaseoli pv. dieffenbachiae LMG 695 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasPhaseoliPvDieffenbachiaeLmg695Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437877.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437877.protein.info.v11.5.txt",
		        "node_list_path": "1437877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaritimibacterSpHl12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maritimibacter sp. HL-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaritimibacterSpHl12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1162418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1162418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1162418.protein.info.v11.5.txt",
		        "node_list_path": "1162418.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSp123mfchir2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 123MFChir2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp123mfchir2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1169144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169144.protein.info.v11.5.txt",
		        "node_list_path": "1169144.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkelbacteriaBacteriumRifoxya2Full4310Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFOXYA2_FULL_43_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifoxya2Full4310Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797472.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797472.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797472.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797472.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797472.protein.info.v11.5.txt",
		        "node_list_path": "1797472.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797472.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpH20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpH20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267981.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267981.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267981.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267981.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267981.protein.info.v11.5.txt",
		        "node_list_path": "1267981.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267981.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CohnellaSp6021052837Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cohnella sp. 6021052837 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CohnellaSp6021052837Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816691.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816691.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816691.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816691.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816691.protein.info.v11.5.txt",
		        "node_list_path": "1816691.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816691.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaVeroralisDsm19559Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella veroralis DSM19559 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaVeroralisDsm19559Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122993.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122993.protein.info.v11.5.txt",
		        "node_list_path": "1122993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262833.protein.info.v11.5.txt",
		        "node_list_path": "1262833.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicroterricolaViridariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microterricola viridarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicroterricolaViridariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "412690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "412690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "412690.clusters.proteins.v11.5.txt",
		        "sequence_path": "412690.protein.sequences.v11.5.fa",
		        "enrichment_path": "412690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "412690.protein.info.v11.5.txt",
		        "node_list_path": "412690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "412690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBifermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium bifermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBifermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1391646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391646.protein.info.v11.5.txt",
		        "node_list_path": "1391646.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterWoluwensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter woluwensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterWoluwensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "156980.protein.sequences.v11.5.fa",
		        "enrichment_path": "156980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156980.protein.info.v11.5.txt",
		        "node_list_path": "156980.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumNor53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium NOR53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumNor53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "566466.protein.sequences.v11.5.fa",
		        "enrichment_path": "566466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "566466.protein.info.v11.5.txt",
		        "node_list_path": "566466.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumSwingsiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium swingsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumSwingsiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "680026.clusters.info.v11.5.txt",
		        "cluster_tree_path": "680026.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "680026.clusters.proteins.v11.5.txt",
		        "sequence_path": "680026.protein.sequences.v11.5.fa",
		        "enrichment_path": "680026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "680026.protein.info.v11.5.txt",
		        "node_list_path": "680026.cluster.nodes.v11.5.txt",
		        "edge_list_path": "680026.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseofuscus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseofuscus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseofuscus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "146922.protein.sequences.v11.5.fa",
		        "enrichment_path": "146922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146922.protein.info.v11.5.txt",
		        "node_list_path": "146922.protein.complete.v11.5.txt"
		    }
		]
    )()

def CordycepsFumosoroseaArsef2679(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps fumosorosea ARSEF 2679 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CordycepsFumosoroseaArsef2679", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1081104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081104.protein.info.v11.5.txt",
		        "node_list_path": "1081104.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaSiccaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sicca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSiccaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "547045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "547045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "547045.clusters.proteins.v11.5.txt",
		        "sequence_path": "547045.protein.sequences.v11.5.fa",
		        "enrichment_path": "547045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547045.protein.info.v11.5.txt",
		        "node_list_path": "547045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "547045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicroplitisDemolitor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microplitis demolitor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicroplitisDemolitor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69319.protein.sequences.v11.5.fa",
		        "enrichment_path": "69319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69319.protein.info.v11.5.txt",
		        "node_list_path": "69319.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanospirillumBeijerinckiiDsm7166(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum beijerinckii DSM 7166 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanospirillumBeijerinckiiDsm7166", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122616.protein.info.v11.5.txt",
		        "node_list_path": "1122616.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsphigho212Full4412bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_12_FULL_44_12b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho212Full4412bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802755.protein.info.v11.5.txt",
		        "node_list_path": "1802755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusNaphthalenovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus naphthalenovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusNaphthalenovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "162209.protein.sequences.v11.5.fa",
		        "enrichment_path": "162209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "162209.protein.info.v11.5.txt",
		        "node_list_path": "162209.protein.complete.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpScgB11wgaEpuloa1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. SCG-B11WGA-EpuloA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpScgB11wgaEpuloa1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1710701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1710701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1710701.clusters.proteins.v11.5.txt",
		        "sequence_path": "1710701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1710701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1710701.protein.info.v11.5.txt",
		        "node_list_path": "1710701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1710701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHtcc2080(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2080 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHtcc2080", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "247639.protein.sequences.v11.5.fa",
		        "enrichment_path": "247639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247639.protein.info.v11.5.txt",
		        "node_list_path": "247639.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetschnikowiaSpJcm33374(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metschnikowia sp. JCM 33374 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetschnikowiaSpJcm33374", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2562755.protein.sequences.v11.5.fa",
		        "enrichment_path": "2562755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2562755.protein.info.v11.5.txt",
		        "node_list_path": "2562755.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraSpHjCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira sp. HJ Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraSpHjCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1616823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1616823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1616823.clusters.proteins.v11.5.txt",
		        "sequence_path": "1616823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1616823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1616823.protein.info.v11.5.txt",
		        "node_list_path": "1616823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1616823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CottopercaGobio(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cottoperca gobio graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CottopercaGobio", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56716.protein.sequences.v11.5.fa",
		        "enrichment_path": "56716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56716.protein.info.v11.5.txt",
		        "node_list_path": "56716.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterLusitanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter lusitanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterLusitanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1503925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1503925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1503925.protein.info.v11.5.txt",
		        "node_list_path": "1503925.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorhodospiraHalophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorhodospira halophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorhodospiraHalophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349124.protein.sequences.v11.5.fa",
		        "enrichment_path": "349124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349124.protein.info.v11.5.txt",
		        "node_list_path": "349124.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermocladiumSpEchBCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermocladium sp. ECH_B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocladiumSpEchBCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1714261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1714261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1714261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1714261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714261.protein.info.v11.5.txt",
		        "node_list_path": "1714261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1714261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusSpD1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus sp. D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusSpD1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "72304.protein.sequences.v11.5.fa",
		        "enrichment_path": "72304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72304.protein.info.v11.5.txt",
		        "node_list_path": "72304.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsplowo202Full4714Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_02_FULL_47_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo202Full4714Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802129.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802129.protein.info.v11.5.txt",
		        "node_list_path": "1802129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoccidioidesImmitisRmscc3703Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis RMSCC 3703 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesImmitisRmscc3703Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "454286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "454286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "454286.clusters.proteins.v11.5.txt",
		        "sequence_path": "454286.protein.sequences.v11.5.fa",
		        "enrichment_path": "454286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454286.protein.info.v11.5.txt",
		        "node_list_path": "454286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "454286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumRifcsphigho212Full6614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_66_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho212Full6614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797225.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797225.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797225.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797225.protein.info.v11.5.txt",
		        "node_list_path": "1797225.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797225.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNcu2d2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NCu2D-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNcu2d2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1608473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608473.protein.info.v11.5.txt",
		        "node_list_path": "1608473.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidocellaFacilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidocella facilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidocellaFacilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408419.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408419.protein.info.v11.5.txt",
		        "node_list_path": "1408419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpCb0101(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. CB0101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpCb0101", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "232348.protein.sequences.v11.5.fa",
		        "enrichment_path": "232348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "232348.protein.info.v11.5.txt",
		        "node_list_path": "232348.protein.complete.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaG002(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola G002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaG002", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1009858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009858.protein.info.v11.5.txt",
		        "node_list_path": "1009858.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_45_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802707.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802707.protein.info.v11.5.txt",
		        "node_list_path": "1802707.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpHot20860m813i02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. HOT208_60m_813I02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpHot20860m813i02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1961091.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1961091.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1961091.clusters.proteins.v11.5.txt",
		        "sequence_path": "1961091.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961091.protein.info.v11.5.txt",
		        "node_list_path": "1961091.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1961091.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterIndonesiensis5h1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter indonesiensis 5H-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterIndonesiensis5h1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231340.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231340.protein.info.v11.5.txt",
		        "node_list_path": "1231340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PucciniaSorghi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Puccinia sorghi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PucciniaSorghi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "27349.protein.sequences.v11.5.fa",
		        "enrichment_path": "27349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27349.protein.info.v11.5.txt",
		        "node_list_path": "27349.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusFlavefaciensFd1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens FD1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusFlavefaciensFd1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641112.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641112.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641112.clusters.proteins.v11.5.txt",
		        "sequence_path": "641112.protein.sequences.v11.5.fa",
		        "enrichment_path": "641112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641112.protein.info.v11.5.txt",
		        "node_list_path": "641112.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641112.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidaminococcusSpCag542Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidaminococcus sp. CAG:542 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminococcusSpCag542Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262687.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262687.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262687.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262687.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262687.protein.info.v11.5.txt",
		        "node_list_path": "1262687.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262687.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesMediterraneensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides mediterraneensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesMediterraneensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841856.protein.info.v11.5.txt",
		        "node_list_path": "1841856.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoplasmatalesArchaeonAPlasmaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon A-plasma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmatalesArchaeonAPlasmaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "667135.clusters.info.v11.5.txt",
		        "cluster_tree_path": "667135.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "667135.clusters.proteins.v11.5.txt",
		        "sequence_path": "667135.protein.sequences.v11.5.fa",
		        "enrichment_path": "667135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667135.protein.info.v11.5.txt",
		        "node_list_path": "667135.cluster.nodes.v11.5.txt",
		        "edge_list_path": "667135.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterCurvus52592(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter curvus 525.92 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterCurvus52592", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "360105.protein.sequences.v11.5.fa",
		        "enrichment_path": "360105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360105.protein.info.v11.5.txt",
		        "node_list_path": "360105.protein.complete.v11.5.txt"
		    }
		]
    )()

def AphanomycesInvadansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aphanomyces invadans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AphanomycesInvadansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "157072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "157072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "157072.clusters.proteins.v11.5.txt",
		        "sequence_path": "157072.protein.sequences.v11.5.fa",
		        "enrichment_path": "157072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157072.protein.info.v11.5.txt",
		        "node_list_path": "157072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "157072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanomethylicusMesodigestum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomethylicus mesodigestum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanomethylicusMesodigestum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1867258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1867258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1867258.protein.info.v11.5.txt",
		        "node_list_path": "1867258.protein.complete.v11.5.txt"
		    }
		]
    )()

def KiloniellaLaminariae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kiloniella laminariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KiloniellaLaminariae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122135.protein.info.v11.5.txt",
		        "node_list_path": "1122135.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusBovieniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus bovienii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusBovieniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "406818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "406818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "406818.clusters.proteins.v11.5.txt",
		        "sequence_path": "406818.protein.sequences.v11.5.fa",
		        "enrichment_path": "406818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406818.protein.info.v11.5.txt",
		        "node_list_path": "406818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "406818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrapisisporaPhaffiiCbs4417Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora phaffii CBS 4417 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrapisisporaPhaffiiCbs4417Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071381.protein.info.v11.5.txt",
		        "node_list_path": "1071381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpSynace01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. SynAce01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpSynace01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1916956.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1916956.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1916956.clusters.proteins.v11.5.txt",
		        "sequence_path": "1916956.protein.sequences.v11.5.fa",
		        "enrichment_path": "1916956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1916956.protein.info.v11.5.txt",
		        "node_list_path": "1916956.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1916956.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterTerrenusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter terrenus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterTerrenusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629124.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629124.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629124.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629124.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629124.protein.info.v11.5.txt",
		        "node_list_path": "1629124.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629124.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumHassiacum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium hassiacum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumHassiacum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122247.protein.info.v11.5.txt",
		        "node_list_path": "1122247.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusSpA40(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus sp. A40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusSpA40", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945863.protein.info.v11.5.txt",
		        "node_list_path": "1945863.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlautiaStali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plautia stali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlautiaStali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "891974.protein.sequences.v11.5.fa",
		        "enrichment_path": "891974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "891974.protein.info.v11.5.txt",
		        "node_list_path": "891974.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasCampestrisVesicatoria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris vesicatoria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCampestrisVesicatoria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316273.protein.sequences.v11.5.fa",
		        "enrichment_path": "316273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316273.protein.info.v11.5.txt",
		        "node_list_path": "316273.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterConcisusAtcc51562Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter concisus ATCC51562 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterConcisusAtcc51562Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1242969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1242969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1242969.clusters.proteins.v11.5.txt",
		        "sequence_path": "1242969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1242969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1242969.protein.info.v11.5.txt",
		        "node_list_path": "1242969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1242969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoplasmatalesArchaeonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmatalesArchaeonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1054217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1054217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1054217.clusters.proteins.v11.5.txt",
		        "sequence_path": "1054217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1054217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1054217.protein.info.v11.5.txt",
		        "node_list_path": "1054217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1054217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusMoraviensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus moraviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusMoraviensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158609.protein.info.v11.5.txt",
		        "node_list_path": "1158609.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesLutiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides luti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesLutiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1297750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1297750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1297750.clusters.proteins.v11.5.txt",
		        "sequence_path": "1297750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297750.protein.info.v11.5.txt",
		        "node_list_path": "1297750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1297750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPacebacteriaBacteriumCg2303639(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium CG2_30_36_39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacebacteriaBacteriumCg2303639", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805300.protein.info.v11.5.txt",
		        "node_list_path": "1805300.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867004Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867004Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1659198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1659198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1659198.clusters.proteins.v11.5.txt",
		        "sequence_path": "1659198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659198.protein.info.v11.5.txt",
		        "node_list_path": "1659198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1659198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSp4425(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. 44-25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSp4425", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895794.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895794.protein.info.v11.5.txt",
		        "node_list_path": "1895794.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgreiaSpLeaf210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agreia sp. Leaf210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgreiaSpLeaf210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735682.protein.info.v11.5.txt",
		        "node_list_path": "1735682.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusSpEp1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sp. EP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSpEp1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1591054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1591054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1591054.clusters.proteins.v11.5.txt",
		        "sequence_path": "1591054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1591054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1591054.protein.info.v11.5.txt",
		        "node_list_path": "1591054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1591054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloligellaHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloligella halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloligellaHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1177755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177755.protein.info.v11.5.txt",
		        "node_list_path": "1177755.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpSoil797Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil797 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpSoil797Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736413.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736413.protein.info.v11.5.txt",
		        "node_list_path": "1736413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumGilvumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium gilvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumGilvumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1130080.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1130080.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1130080.clusters.proteins.v11.5.txt",
		        "sequence_path": "1130080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1130080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1130080.protein.info.v11.5.txt",
		        "node_list_path": "1130080.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1130080.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaFloridensisFslS101187(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria floridensis FSL S10-1187 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaFloridensisFslS101187", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265817.protein.info.v11.5.txt",
		        "node_list_path": "1265817.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerrovumSpZ31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrovum sp. Z-31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrovumSpZ31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1789004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1789004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1789004.clusters.proteins.v11.5.txt",
		        "sequence_path": "1789004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1789004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1789004.protein.info.v11.5.txt",
		        "node_list_path": "1789004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1789004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumRifoxyc12Full6016Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium RIFOXYC12_FULL_60_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumRifoxyc12Full6016Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798582.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798582.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798582.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798582.protein.info.v11.5.txt",
		        "node_list_path": "1798582.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798582.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumElkaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumElkaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29448.clusters.proteins.v11.5.txt",
		        "sequence_path": "29448.protein.sequences.v11.5.fa",
		        "enrichment_path": "29448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29448.protein.info.v11.5.txt",
		        "node_list_path": "29448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PanicumMiliaceum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Panicum miliaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PanicumMiliaceum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4540.protein.sequences.v11.5.fa",
		        "enrichment_path": "4540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4540.protein.info.v11.5.txt",
		        "node_list_path": "4540.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaeCc1417(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1417 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaeCc1417", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1357272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357272.protein.info.v11.5.txt",
		        "node_list_path": "1357272.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirulinaMajorPcc6313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirulina major PCC 6313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirulinaMajorPcc6313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "129961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "129961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "129961.clusters.proteins.v11.5.txt",
		        "sequence_path": "129961.protein.sequences.v11.5.fa",
		        "enrichment_path": "129961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "129961.protein.info.v11.5.txt",
		        "node_list_path": "129961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "129961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterEqui(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter equi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterEqui", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1324350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1324350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1324350.protein.info.v11.5.txt",
		        "node_list_path": "1324350.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuricibacterSanguinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Turicibacter sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuricibacterSanguinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "702450.protein.sequences.v11.5.fa",
		        "enrichment_path": "702450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702450.protein.info.v11.5.txt",
		        "node_list_path": "702450.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShuttleworthiaSpMsx8bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shuttleworthia sp. MSX8B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShuttleworthiaSpMsx8bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936574.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936574.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936574.clusters.proteins.v11.5.txt",
		        "sequence_path": "936574.protein.sequences.v11.5.fa",
		        "enrichment_path": "936574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936574.protein.info.v11.5.txt",
		        "node_list_path": "936574.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936574.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926285.protein.info.v11.5.txt",
		        "node_list_path": "1926285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidianusHospitalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidianus hospitalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidianusHospitalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "933801.protein.sequences.v11.5.fa",
		        "enrichment_path": "933801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933801.protein.info.v11.5.txt",
		        "node_list_path": "933801.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3815(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_38_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3815", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801752.protein.info.v11.5.txt",
		        "node_list_path": "1801752.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronomonasSpCba1134Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronomonas sp. CBA1134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronomonasSpCba1134Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906246.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906246.protein.info.v11.5.txt",
		        "node_list_path": "1906246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorObsidiansis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor obsidiansis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorObsidiansis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "608506.protein.sequences.v11.5.fa",
		        "enrichment_path": "608506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "608506.protein.info.v11.5.txt",
		        "node_list_path": "608506.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpH20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpH20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267981.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267981.protein.info.v11.5.txt",
		        "node_list_path": "1267981.protein.complete.v11.5.txt"
		    }
		]
    )()

def SneathiellaGlossodoripedisJcm23214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sneathiella glossodoripedis JCM 23214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SneathiellaGlossodoripedisJcm23214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236958.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236958.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236958.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236958.protein.info.v11.5.txt",
		        "node_list_path": "1236958.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236958.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeiothermusTimidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus timidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusTimidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122223.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122223.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122223.protein.info.v11.5.txt",
		        "node_list_path": "1122223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27264(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27264 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27264", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1850362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850362.protein.info.v11.5.txt",
		        "node_list_path": "1850362.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacterium4787Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium 47-87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacterium4787Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895828.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895828.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895828.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895828.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895828.protein.info.v11.5.txt",
		        "node_list_path": "1895828.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895828.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophagaThiooxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga thiooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaThiooxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "392484.protein.sequences.v11.5.fa",
		        "enrichment_path": "392484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392484.protein.info.v11.5.txt",
		        "node_list_path": "392484.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnserBrachyrhynchus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anser brachyrhynchus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnserBrachyrhynchus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "132585.protein.sequences.v11.5.fa",
		        "enrichment_path": "132585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "132585.protein.info.v11.5.txt",
		        "node_list_path": "132585.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylomonasSpLw13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas sp. LW13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasSpLw13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "107637.protein.sequences.v11.5.fa",
		        "enrichment_path": "107637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "107637.protein.info.v11.5.txt",
		        "node_list_path": "107637.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedArchaeonA07hn63(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HN63 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedArchaeonA07hn63", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1412873.protein.sequences.v11.5.fa",
		        "enrichment_path": "1412873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1412873.protein.info.v11.5.txt",
		        "node_list_path": "1412873.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaSpImhCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. IMH Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpImhCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267600.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267600.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267600.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267600.protein.info.v11.5.txt",
		        "node_list_path": "1267600.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267600.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674849.protein.info.v11.5.txt",
		        "node_list_path": "1674849.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterFetusSubspVenerealis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. venerealis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterFetusSubspVenerealis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32020.protein.sequences.v11.5.fa",
		        "enrichment_path": "32020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32020.protein.info.v11.5.txt",
		        "node_list_path": "32020.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaJejuensisNbrc103114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia jejuensis NBRC 103114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaJejuensisNbrc103114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210088.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210088.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210088.protein.info.v11.5.txt",
		        "node_list_path": "1210088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumGw2011Gwd23842Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium GW2011_GWD2_38_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumGw2011Gwd23842Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618637.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618637.protein.info.v11.5.txt",
		        "node_list_path": "1618637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterArsenitoxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter arsenitoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterArsenitoxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "477184.protein.sequences.v11.5.fa",
		        "enrichment_path": "477184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477184.protein.info.v11.5.txt",
		        "node_list_path": "477184.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpFc2018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. FC2018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpFc2018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410617.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410617.protein.info.v11.5.txt",
		        "node_list_path": "1410617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumCg1023251Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium CG1_02_32_51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumCg1023251Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805238.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805238.protein.info.v11.5.txt",
		        "node_list_path": "1805238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnasPlatyrhynchosPlatyrhynchos(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anas platyrhynchos platyrhynchos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnasPlatyrhynchosPlatyrhynchos", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8840.protein.sequences.v11.5.fa",
		        "enrichment_path": "8840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8840.protein.info.v11.5.txt",
		        "node_list_path": "8840.protein.complete.v11.5.txt"
		    }
		]
    )()

def HippeaSpKm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hippea sp. KM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HippeaSpKm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "944481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "944481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "944481.clusters.proteins.v11.5.txt",
		        "sequence_path": "944481.protein.sequences.v11.5.fa",
		        "enrichment_path": "944481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944481.protein.info.v11.5.txt",
		        "node_list_path": "944481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "944481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasFungiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas fungiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasFungiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1137284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137284.protein.info.v11.5.txt",
		        "node_list_path": "1137284.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDesulfofervidusAuxiliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desulfofervidus auxilii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDesulfofervidusAuxiliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1621989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1621989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1621989.clusters.proteins.v11.5.txt",
		        "sequence_path": "1621989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1621989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1621989.protein.info.v11.5.txt",
		        "node_list_path": "1621989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1621989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusManasiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus manasiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusManasiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "586413.protein.sequences.v11.5.fa",
		        "enrichment_path": "586413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "586413.protein.info.v11.5.txt",
		        "node_list_path": "586413.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShinellaSpHzn7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shinella sp. HZN7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShinellaSpHzn7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "879274.protein.sequences.v11.5.fa",
		        "enrichment_path": "879274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879274.protein.info.v11.5.txt",
		        "node_list_path": "879274.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumSgBin7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SG_bin7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumSgBin7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1827384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1827384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1827384.clusters.proteins.v11.5.txt",
		        "sequence_path": "1827384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827384.protein.info.v11.5.txt",
		        "node_list_path": "1827384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1827384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaPorcinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema porcinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPorcinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "261392.clusters.info.v11.5.txt",
		        "cluster_tree_path": "261392.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "261392.clusters.proteins.v11.5.txt",
		        "sequence_path": "261392.protein.sequences.v11.5.fa",
		        "enrichment_path": "261392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "261392.protein.info.v11.5.txt",
		        "node_list_path": "261392.cluster.nodes.v11.5.txt",
		        "edge_list_path": "261392.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JannaschiaRubraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaRubraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "282197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "282197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "282197.clusters.proteins.v11.5.txt",
		        "sequence_path": "282197.protein.sequences.v11.5.fa",
		        "enrichment_path": "282197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "282197.protein.info.v11.5.txt",
		        "node_list_path": "282197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "282197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraSantarosaiSerovarShermaniStrLt821(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira santarosai serovar Shermani str. LT 821 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraSantarosaiSerovarShermaniStrLt821", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "758847.protein.sequences.v11.5.fa",
		        "enrichment_path": "758847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758847.protein.info.v11.5.txt",
		        "node_list_path": "758847.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmodiumBerghei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium berghei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumBerghei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5821.protein.sequences.v11.5.fa",
		        "enrichment_path": "5821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5821.protein.info.v11.5.txt",
		        "node_list_path": "5821.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterYangtzensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter yangtzensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterYangtzensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1743159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1743159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1743159.clusters.proteins.v11.5.txt",
		        "sequence_path": "1743159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743159.protein.info.v11.5.txt",
		        "node_list_path": "1743159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1743159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnhydrobacterAerosaccus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enhydrobacter aerosaccus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnhydrobacterAerosaccus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553217.protein.sequences.v11.5.fa",
		        "enrichment_path": "553217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553217.protein.info.v11.5.txt",
		        "node_list_path": "553217.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesIncarnatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces incarnatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesIncarnatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665007.clusters.proteins.v11.5.txt",
		        "sequence_path": "665007.protein.sequences.v11.5.fa",
		        "enrichment_path": "665007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665007.protein.info.v11.5.txt",
		        "node_list_path": "665007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanomicrobiaArchaeonDtu008(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanomicrobia archaeon DTU008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomicrobiaArchaeonDtu008", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1675034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1675034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1675034.protein.info.v11.5.txt",
		        "node_list_path": "1675034.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaLitorale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma litorale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaLitorale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216942.protein.sequences.v11.5.fa",
		        "enrichment_path": "216942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216942.protein.info.v11.5.txt",
		        "node_list_path": "216942.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpMum116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MUM 116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpMum116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1678002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1678002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1678002.clusters.proteins.v11.5.txt",
		        "sequence_path": "1678002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678002.protein.info.v11.5.txt",
		        "node_list_path": "1678002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1678002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellvibrioGilvus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio gilvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioGilvus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "593907.protein.sequences.v11.5.fa",
		        "enrichment_path": "593907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "593907.protein.info.v11.5.txt",
		        "node_list_path": "593907.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusShapirobacteriaBacteriumGw2011Gwf23720(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium GW2011_GWF2_37_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusShapirobacteriaBacteriumGw2011Gwf23720", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618492.protein.info.v11.5.txt",
		        "node_list_path": "1618492.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumChromiireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium chromiireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumChromiireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "225345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "225345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "225345.clusters.proteins.v11.5.txt",
		        "sequence_path": "225345.protein.sequences.v11.5.fa",
		        "enrichment_path": "225345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225345.protein.info.v11.5.txt",
		        "node_list_path": "225345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "225345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DehalococcoidiaBacteriumSm23282Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoidia bacterium SM23_28_2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalococcoidiaBacteriumSm23282Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703396.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703396.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703396.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703396.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703396.protein.info.v11.5.txt",
		        "node_list_path": "1703396.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703396.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "592050.protein.sequences.v11.5.fa",
		        "enrichment_path": "592050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592050.protein.info.v11.5.txt",
		        "node_list_path": "592050.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiumSpGas474Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. GAS474 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiumSpGas474Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882831.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882831.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882831.protein.info.v11.5.txt",
		        "node_list_path": "1882831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EdwardsiellaIctaluriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Edwardsiella ictaluri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EdwardsiellaIctaluriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67780.clusters.proteins.v11.5.txt",
		        "sequence_path": "67780.protein.sequences.v11.5.fa",
		        "enrichment_path": "67780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67780.protein.info.v11.5.txt",
		        "node_list_path": "67780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioRenipiscariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio renipiscarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioRenipiscariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461322.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461322.protein.info.v11.5.txt",
		        "node_list_path": "1461322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusHesperidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus hesperidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusHesperidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "89784.clusters.info.v11.5.txt",
		        "cluster_tree_path": "89784.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "89784.clusters.proteins.v11.5.txt",
		        "sequence_path": "89784.protein.sequences.v11.5.fa",
		        "enrichment_path": "89784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89784.protein.info.v11.5.txt",
		        "node_list_path": "89784.cluster.nodes.v11.5.txt",
		        "edge_list_path": "89784.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterGandensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter gandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterGandensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1443941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1443941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1443941.clusters.proteins.v11.5.txt",
		        "sequence_path": "1443941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443941.protein.info.v11.5.txt",
		        "node_list_path": "1443941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1443941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusSpYr651Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. YR651 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusSpYr651Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855315.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855315.protein.info.v11.5.txt",
		        "node_list_path": "1855315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusWasatchensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus wasatchensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusWasatchensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1335616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1335616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1335616.clusters.proteins.v11.5.txt",
		        "sequence_path": "1335616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1335616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1335616.protein.info.v11.5.txt",
		        "node_list_path": "1335616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1335616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumImcc14465(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium IMCC14465 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumImcc14465", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220535.protein.info.v11.5.txt",
		        "node_list_path": "1220535.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinivibrioCosticolaSubspAlcaliphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio costicola subsp. alcaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivibrioCosticolaSubspAlcaliphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272773.protein.sequences.v11.5.fa",
		        "enrichment_path": "272773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272773.protein.info.v11.5.txt",
		        "node_list_path": "272773.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCoyleaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium coyleae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCoyleaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53374.clusters.proteins.v11.5.txt",
		        "sequence_path": "53374.protein.sequences.v11.5.fa",
		        "enrichment_path": "53374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53374.protein.info.v11.5.txt",
		        "node_list_path": "53374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeraceosorusGuamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ceraceosorus guamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeraceosorusGuamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1522189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522189.protein.info.v11.5.txt",
		        "node_list_path": "1522189.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermophagusXiamenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermophagus xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermophagusXiamenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "385682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "385682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "385682.clusters.proteins.v11.5.txt",
		        "sequence_path": "385682.protein.sequences.v11.5.fa",
		        "enrichment_path": "385682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "385682.protein.info.v11.5.txt",
		        "node_list_path": "385682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "385682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSabinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sabinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSabinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1268072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268072.protein.info.v11.5.txt",
		        "node_list_path": "1268072.protein.complete.v11.5.txt"
		    }
		]
    )()

def SingulisphaeraSpGp187(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Singulisphaera sp. GP187 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SingulisphaeraSpGp187", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882752.protein.info.v11.5.txt",
		        "node_list_path": "1882752.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg16488Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_48_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg16488Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797641.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797641.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797641.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797641.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797641.protein.info.v11.5.txt",
		        "node_list_path": "1797641.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797641.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClavicepsPurpurea201(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Claviceps purpurea 20.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavicepsPurpurea201", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111077.protein.info.v11.5.txt",
		        "node_list_path": "1111077.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetalesBacterium4484113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 4484_113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetalesBacterium4484113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1956161.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1956161.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1956161.clusters.proteins.v11.5.txt",
		        "sequence_path": "1956161.protein.sequences.v11.5.fa",
		        "enrichment_path": "1956161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1956161.protein.info.v11.5.txt",
		        "node_list_path": "1956161.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1956161.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpG5847(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. G5847 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpG5847", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1179777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179777.protein.info.v11.5.txt",
		        "node_list_path": "1179777.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag127(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:127 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag127", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262774.protein.info.v11.5.txt",
		        "node_list_path": "1262774.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClunioMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clunio marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClunioMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "568069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "568069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "568069.clusters.proteins.v11.5.txt",
		        "sequence_path": "568069.protein.sequences.v11.5.fa",
		        "enrichment_path": "568069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568069.protein.info.v11.5.txt",
		        "node_list_path": "568069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "568069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteimonasHuabeiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas huabeiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteimonasHuabeiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1442599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1442599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1442599.clusters.proteins.v11.5.txt",
		        "sequence_path": "1442599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1442599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1442599.protein.info.v11.5.txt",
		        "node_list_path": "1442599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1442599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusElgii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus elgii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusElgii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1007103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007103.protein.info.v11.5.txt",
		        "node_list_path": "1007103.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegasphaeraElsdeniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera elsdenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraElsdeniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1064535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1064535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1064535.clusters.proteins.v11.5.txt",
		        "sequence_path": "1064535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1064535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1064535.protein.info.v11.5.txt",
		        "node_list_path": "1064535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1064535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LewinellaPersicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lewinella persica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LewinellaPersicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122179.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122179.protein.info.v11.5.txt",
		        "node_list_path": "1122179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumFalsenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium falsenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumFalsenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1451189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1451189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1451189.protein.info.v11.5.txt",
		        "node_list_path": "1451189.protein.complete.v11.5.txt"
		    }
		]
    )()

def SorangiineaeBacteriumNic37a2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sorangiineae bacterium NIC37A_2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SorangiineaeBacteriumNic37a2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1970199.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970199.protein.info.v11.5.txt",
		        "node_list_path": "1970199.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110051(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110051 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110051", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1570340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570340.protein.info.v11.5.txt",
		        "node_list_path": "1570340.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSpSk02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSpSk02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1453999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1453999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1453999.clusters.proteins.v11.5.txt",
		        "sequence_path": "1453999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453999.protein.info.v11.5.txt",
		        "node_list_path": "1453999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1453999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo202Full4011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_02_FULL_40_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo202Full4011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797732.protein.info.v11.5.txt",
		        "node_list_path": "1797732.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprobacillusSpCag605(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus sp. CAG:605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprobacillusSpCag605", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262855.protein.info.v11.5.txt",
		        "node_list_path": "1262855.protein.complete.v11.5.txt"
		    }
		]
    )()

def CriibacteriumBergeronii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Criibacterium bergeronii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CriibacteriumBergeronii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871336.protein.info.v11.5.txt",
		        "node_list_path": "1871336.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusTaiwanensisDsm21401Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus taiwanensis DSM 21401 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusTaiwanensisDsm21401Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423809.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423809.protein.info.v11.5.txt",
		        "node_list_path": "1423809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpBs2016(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BS-2016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpBs2016", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907766.protein.info.v11.5.txt",
		        "node_list_path": "1907766.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumLuteumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium luteum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumLuteumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1638988.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1638988.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1638988.clusters.proteins.v11.5.txt",
		        "sequence_path": "1638988.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638988.protein.info.v11.5.txt",
		        "node_list_path": "1638988.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1638988.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasRivuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas rivuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasRivuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "648794.protein.sequences.v11.5.fa",
		        "enrichment_path": "648794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "648794.protein.info.v11.5.txt",
		        "node_list_path": "648794.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterAntarcticusDsm21422(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter antarcticus DSM 21422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterAntarcticusDsm21422", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122191.protein.info.v11.5.txt",
		        "node_list_path": "1122191.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucosisporaMaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucosispora maris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucosisporaMaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "263358.protein.sequences.v11.5.fa",
		        "enrichment_path": "263358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263358.protein.info.v11.5.txt",
		        "node_list_path": "263358.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp360mftsu51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 360MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp360mftsu51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1172186.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1172186.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1172186.clusters.proteins.v11.5.txt",
		        "sequence_path": "1172186.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172186.protein.info.v11.5.txt",
		        "node_list_path": "1172186.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1172186.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesChristyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles christyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesChristyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43041.protein.sequences.v11.5.fa",
		        "enrichment_path": "43041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43041.protein.info.v11.5.txt",
		        "node_list_path": "43041.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonasTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "673548.protein.sequences.v11.5.fa",
		        "enrichment_path": "673548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "673548.protein.info.v11.5.txt",
		        "node_list_path": "673548.protein.complete.v11.5.txt"
		    }
		]
    )()

def EikenellaSpHmsc073a11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eikenella sp. HMSC073A11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EikenellaSpHmsc073a11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739535.protein.info.v11.5.txt",
		        "node_list_path": "1739535.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasUenonis603(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis 603 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasUenonis603", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596327.protein.sequences.v11.5.fa",
		        "enrichment_path": "596327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596327.protein.info.v11.5.txt",
		        "node_list_path": "596327.protein.complete.v11.5.txt"
		    }
		]
    )()

def BeijerinckiaIndicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Beijerinckia indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeijerinckiaIndicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "395963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "395963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "395963.clusters.proteins.v11.5.txt",
		        "sequence_path": "395963.protein.sequences.v11.5.fa",
		        "enrichment_path": "395963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395963.protein.info.v11.5.txt",
		        "node_list_path": "395963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "395963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaMontpellierensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella montpellierensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaMontpellierensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1401067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401067.protein.info.v11.5.txt",
		        "node_list_path": "1401067.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumYrb3002(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium YRB3002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumYrb3002", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520819.protein.info.v11.5.txt",
		        "node_list_path": "1520819.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpH7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. H7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpH7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882399.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882399.protein.info.v11.5.txt",
		        "node_list_path": "1882399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag762(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:762 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag762", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262837.protein.info.v11.5.txt",
		        "node_list_path": "1262837.protein.complete.v11.5.txt"
		    }
		]
    )()

def KutzneriaSp744Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kutzneria sp. 744 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KutzneriaSp744Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "345341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "345341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "345341.clusters.proteins.v11.5.txt",
		        "sequence_path": "345341.protein.sequences.v11.5.fa",
		        "enrichment_path": "345341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "345341.protein.info.v11.5.txt",
		        "node_list_path": "345341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "345341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusChisholmbacteriaBacteriumRifcsplowo201Full5028(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPLOWO2_01_FULL_50_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsplowo201Full5028", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797594.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797594.protein.info.v11.5.txt",
		        "node_list_path": "1797594.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinimicrobiumTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinimicrobium terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinimicrobiumTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123234.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123234.protein.info.v11.5.txt",
		        "node_list_path": "1123234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioRumoiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio rumoiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioRumoiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1188252.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1188252.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1188252.clusters.proteins.v11.5.txt",
		        "sequence_path": "1188252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188252.protein.info.v11.5.txt",
		        "node_list_path": "1188252.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1188252.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAmyloliquefaciensDc12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens DC-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAmyloliquefaciensDc12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1198291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1198291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1198291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1198291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198291.protein.info.v11.5.txt",
		        "node_list_path": "1198291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1198291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConiosporiumApollinisCbs100218Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coniosporium apollinis CBS 100218 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConiosporiumApollinisCbs100218Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1168221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1168221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1168221.clusters.proteins.v11.5.txt",
		        "sequence_path": "1168221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168221.protein.info.v11.5.txt",
		        "node_list_path": "1168221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1168221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LomentosporaProlificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lomentospora prolificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LomentosporaProlificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "41688.protein.sequences.v11.5.fa",
		        "enrichment_path": "41688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41688.protein.info.v11.5.txt",
		        "node_list_path": "41688.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumJeotgaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumJeotgaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "545534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "545534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "545534.clusters.proteins.v11.5.txt",
		        "sequence_path": "545534.protein.sequences.v11.5.fa",
		        "enrichment_path": "545534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545534.protein.info.v11.5.txt",
		        "node_list_path": "545534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "545534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurimonasSpGwf2378(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. GWF2_37_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasSpGwf2378", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802250.protein.info.v11.5.txt",
		        "node_list_path": "1802250.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusThermokryptusMobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thermokryptus mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThermokryptusMobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1643428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1643428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1643428.clusters.proteins.v11.5.txt",
		        "sequence_path": "1643428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643428.protein.info.v11.5.txt",
		        "node_list_path": "1643428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1643428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BhargavaeaGinsengiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bhargavaea ginsengi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BhargavaeaGinsengiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426757.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426757.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426757.clusters.proteins.v11.5.txt",
		        "sequence_path": "426757.protein.sequences.v11.5.fa",
		        "enrichment_path": "426757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426757.protein.info.v11.5.txt",
		        "node_list_path": "426757.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426757.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopirellulaIslandicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopirellula islandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopirellulaIslandicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "595434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "595434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "595434.clusters.proteins.v11.5.txt",
		        "sequence_path": "595434.protein.sequences.v11.5.fa",
		        "enrichment_path": "595434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595434.protein.info.v11.5.txt",
		        "node_list_path": "595434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "595434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellvibrioMixtusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio mixtus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioMixtusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1209072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1209072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1209072.clusters.proteins.v11.5.txt",
		        "sequence_path": "1209072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1209072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1209072.protein.info.v11.5.txt",
		        "node_list_path": "1209072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1209072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychroflexusTorquis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychroflexus torquis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroflexusTorquis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313595.protein.sequences.v11.5.fa",
		        "enrichment_path": "313595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313595.protein.info.v11.5.txt",
		        "node_list_path": "313595.protein.complete.v11.5.txt"
		    }
		]
    )()

def HippeaAlviniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hippea alviniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HippeaAlviniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "944480.protein.sequences.v11.5.fa",
		        "enrichment_path": "944480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944480.protein.info.v11.5.txt",
		        "node_list_path": "944480.protein.complete.v11.5.txt"
		    }
		]
    )()

def TriticumAestivumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Triticum aestivum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TriticumAestivumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4565.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4565.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4565.clusters.proteins.v11.5.txt",
		        "sequence_path": "4565.protein.sequences.v11.5.fa",
		        "enrichment_path": "4565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4565.protein.info.v11.5.txt",
		        "node_list_path": "4565.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4565.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ReichenbachiellaAgariperforansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Reichenbachiella agariperforans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ReichenbachiellaAgariperforansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "156994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "156994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "156994.clusters.proteins.v11.5.txt",
		        "sequence_path": "156994.protein.sequences.v11.5.fa",
		        "enrichment_path": "156994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156994.protein.info.v11.5.txt",
		        "node_list_path": "156994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "156994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsplowo201Full3334(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_01_FULL_33_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo201Full3334", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798685.protein.info.v11.5.txt",
		        "node_list_path": "1798685.protein.complete.v11.5.txt"
		    }
		]
    )()

def JannaschiaDonghaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia donghaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaDonghaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "420998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "420998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "420998.clusters.proteins.v11.5.txt",
		        "sequence_path": "420998.protein.sequences.v11.5.fa",
		        "enrichment_path": "420998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420998.protein.info.v11.5.txt",
		        "node_list_path": "420998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "420998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaEnterocoliticaLc20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica LC20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaEnterocoliticaLc20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1443113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1443113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1443113.clusters.proteins.v11.5.txt",
		        "sequence_path": "1443113.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443113.protein.info.v11.5.txt",
		        "node_list_path": "1443113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1443113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EcheneisNaucratesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Echeneis naucrates Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EcheneisNaucratesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "173247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "173247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "173247.clusters.proteins.v11.5.txt",
		        "sequence_path": "173247.protein.sequences.v11.5.fa",
		        "enrichment_path": "173247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "173247.protein.info.v11.5.txt",
		        "node_list_path": "173247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "173247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteribacillusPersepolensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteribacillus persepolensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteribacillusPersepolensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "568899.protein.sequences.v11.5.fa",
		        "enrichment_path": "568899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568899.protein.info.v11.5.txt",
		        "node_list_path": "568899.protein.complete.v11.5.txt"
		    }
		]
    )()

def CatabacterHongkongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catabacter hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatabacterHongkongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "270498.protein.sequences.v11.5.fa",
		        "enrichment_path": "270498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "270498.protein.info.v11.5.txt",
		        "node_list_path": "270498.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaYakubaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila yakuba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaYakubaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7245.clusters.proteins.v11.5.txt",
		        "sequence_path": "7245.protein.sequences.v11.5.fa",
		        "enrichment_path": "7245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7245.protein.info.v11.5.txt",
		        "node_list_path": "7245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MastigocladusLaminosusUu774Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mastigocladus laminosus UU774 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MastigocladusLaminosusUu774Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1594576.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1594576.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1594576.clusters.proteins.v11.5.txt",
		        "sequence_path": "1594576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1594576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1594576.protein.info.v11.5.txt",
		        "node_list_path": "1594576.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1594576.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaAtypicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella atypica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaAtypicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39777.clusters.proteins.v11.5.txt",
		        "sequence_path": "39777.protein.sequences.v11.5.fa",
		        "enrichment_path": "39777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39777.protein.info.v11.5.txt",
		        "node_list_path": "39777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMinutissimumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium minutissimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMinutissimumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "38301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "38301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "38301.clusters.proteins.v11.5.txt",
		        "sequence_path": "38301.protein.sequences.v11.5.fa",
		        "enrichment_path": "38301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38301.protein.info.v11.5.txt",
		        "node_list_path": "38301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "38301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenococcusSpPcc7305(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenococcus sp. PCC7305 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenococcusSpPcc7305", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "102125.protein.sequences.v11.5.fa",
		        "enrichment_path": "102125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102125.protein.info.v11.5.txt",
		        "node_list_path": "102125.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumSpScadcCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. SCADC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumSpScadcCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1537915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1537915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1537915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1537915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1537915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1537915.protein.info.v11.5.txt",
		        "node_list_path": "1537915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1537915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicolaSociusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicola socius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicolaSociusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "404433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "404433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "404433.clusters.proteins.v11.5.txt",
		        "sequence_path": "404433.protein.sequences.v11.5.fa",
		        "enrichment_path": "404433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "404433.protein.info.v11.5.txt",
		        "node_list_path": "404433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "404433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterPersiciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter persici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterPersiciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1076596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1076596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1076596.clusters.proteins.v11.5.txt",
		        "sequence_path": "1076596.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076596.protein.info.v11.5.txt",
		        "node_list_path": "1076596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1076596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacteriumXylanolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium xylanolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacteriumXylanolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "858215.clusters.info.v11.5.txt",
		        "cluster_tree_path": "858215.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "858215.clusters.proteins.v11.5.txt",
		        "sequence_path": "858215.protein.sequences.v11.5.fa",
		        "enrichment_path": "858215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "858215.protein.info.v11.5.txt",
		        "node_list_path": "858215.cluster.nodes.v11.5.txt",
		        "edge_list_path": "858215.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OreniaMarismortuiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Orenia marismortui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OreniaMarismortuiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926561.clusters.proteins.v11.5.txt",
		        "sequence_path": "926561.protein.sequences.v11.5.fa",
		        "enrichment_path": "926561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926561.protein.info.v11.5.txt",
		        "node_list_path": "926561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpYe71(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. YE71 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpYe71", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "244362.protein.sequences.v11.5.fa",
		        "enrichment_path": "244362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244362.protein.info.v11.5.txt",
		        "node_list_path": "244362.protein.complete.v11.5.txt"
		    }
		]
    )()

def BizioniaEchini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bizionia echini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BizioniaEchini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649333.protein.sequences.v11.5.fa",
		        "enrichment_path": "649333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649333.protein.info.v11.5.txt",
		        "node_list_path": "649333.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1814128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1814128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1814128.protein.info.v11.5.txt",
		        "node_list_path": "1814128.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifcsplowo201Full5410Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO2_01_FULL_54_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201Full5410Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797945.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797945.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797945.protein.info.v11.5.txt",
		        "node_list_path": "1797945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LoktanellaCinnabarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella cinnabarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaCinnabarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1337093.protein.sequences.v11.5.fa",
		        "enrichment_path": "1337093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1337093.protein.info.v11.5.txt",
		        "node_list_path": "1337093.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoramibacterAlactolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoramibacter alactolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoramibacterAlactolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "887929.clusters.info.v11.5.txt",
		        "cluster_tree_path": "887929.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "887929.clusters.proteins.v11.5.txt",
		        "sequence_path": "887929.protein.sequences.v11.5.fa",
		        "enrichment_path": "887929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "887929.protein.info.v11.5.txt",
		        "node_list_path": "887929.cluster.nodes.v11.5.txt",
		        "edge_list_path": "887929.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterCrescentusCb15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter crescentus CB15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterCrescentusCb15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "190650.protein.sequences.v11.5.fa",
		        "enrichment_path": "190650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190650.protein.info.v11.5.txt",
		        "node_list_path": "190650.protein.complete.v11.5.txt"
		    }
		]
    )()

def PneumocystisMurinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis murina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PneumocystisMurinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "263815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "263815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "263815.clusters.proteins.v11.5.txt",
		        "sequence_path": "263815.protein.sequences.v11.5.fa",
		        "enrichment_path": "263815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263815.protein.info.v11.5.txt",
		        "node_list_path": "263815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "263815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrassicaRapaSubspPekinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brassica rapa subsp. pekinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrassicaRapaSubspPekinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "51351.protein.sequences.v11.5.fa",
		        "enrichment_path": "51351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51351.protein.info.v11.5.txt",
		        "node_list_path": "51351.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusGnavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus gnavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusGnavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411470.protein.sequences.v11.5.fa",
		        "enrichment_path": "411470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411470.protein.info.v11.5.txt",
		        "node_list_path": "411470.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaOralisHga0225(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oralis HGA0225 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOralisHga0225", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203550.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203550.protein.info.v11.5.txt",
		        "node_list_path": "1203550.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSp21mfcrub11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. 21MFCrub1.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSp21mfcrub11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798223.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798223.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798223.protein.info.v11.5.txt",
		        "node_list_path": "1798223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusInfantisAtcc700779Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis ATCC700779 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusInfantisAtcc700779Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "889204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "889204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "889204.clusters.proteins.v11.5.txt",
		        "sequence_path": "889204.protein.sequences.v11.5.fa",
		        "enrichment_path": "889204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "889204.protein.info.v11.5.txt",
		        "node_list_path": "889204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "889204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuegeriaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "639004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "639004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "639004.clusters.proteins.v11.5.txt",
		        "sequence_path": "639004.protein.sequences.v11.5.fa",
		        "enrichment_path": "639004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "639004.protein.info.v11.5.txt",
		        "node_list_path": "639004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "639004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatelliglobosisporaKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catelliglobosispora koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatelliglobosisporaKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121272.protein.info.v11.5.txt",
		        "node_list_path": "1121272.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiameybacterMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Niameybacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiameybacterMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658108.protein.info.v11.5.txt",
		        "node_list_path": "1658108.protein.complete.v11.5.txt"
		    }
		]
    )()

def EikenellaCorrodensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eikenella corrodens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EikenellaCorrodensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "539.clusters.info.v11.5.txt",
		        "cluster_tree_path": "539.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "539.clusters.proteins.v11.5.txt",
		        "sequence_path": "539.protein.sequences.v11.5.fa",
		        "enrichment_path": "539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "539.protein.info.v11.5.txt",
		        "node_list_path": "539.cluster.nodes.v11.5.txt",
		        "edge_list_path": "539.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIs1496Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1496 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIs1496Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1772284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1772284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1772284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1772284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772284.protein.info.v11.5.txt",
		        "node_list_path": "1772284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1772284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpK90mixCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. K90mix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpK90mixCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "396595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "396595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "396595.clusters.proteins.v11.5.txt",
		        "sequence_path": "396595.protein.sequences.v11.5.fa",
		        "enrichment_path": "396595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396595.protein.info.v11.5.txt",
		        "node_list_path": "396595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "396595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumRifoxyd12Full4821(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFOXYD12_FULL_48_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifoxyd12Full4821", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802562.protein.info.v11.5.txt",
		        "node_list_path": "1802562.protein.complete.v11.5.txt"
		    }
		]
    )()

def DipodomysOrdii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dipodomys ordii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DipodomysOrdii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10020.protein.sequences.v11.5.fa",
		        "enrichment_path": "10020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10020.protein.info.v11.5.txt",
		        "node_list_path": "10020.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScytonemaSpHk05(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scytonema sp. HK-05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScytonemaSpHk05", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1137095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137095.protein.info.v11.5.txt",
		        "node_list_path": "1137095.protein.complete.v11.5.txt"
		    }
		]
    )()

def KriegellaAquimarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kriegella aquimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KriegellaAquimarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "192904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "192904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "192904.clusters.proteins.v11.5.txt",
		        "sequence_path": "192904.protein.sequences.v11.5.fa",
		        "enrichment_path": "192904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192904.protein.info.v11.5.txt",
		        "node_list_path": "192904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "192904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZygosaccharomycesBailiiClib213Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zygosaccharomyces bailii CLIB 213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZygosaccharomycesBailiiClib213Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1333698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1333698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1333698.clusters.proteins.v11.5.txt",
		        "sequence_path": "1333698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333698.protein.info.v11.5.txt",
		        "node_list_path": "1333698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1333698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpUnccl10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. UNCCL10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpUnccl10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449058.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449058.protein.info.v11.5.txt",
		        "node_list_path": "1449058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpFobrc9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. FOBRC9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpFobrc9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936573.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936573.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936573.clusters.proteins.v11.5.txt",
		        "sequence_path": "936573.protein.sequences.v11.5.fa",
		        "enrichment_path": "936573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936573.protein.info.v11.5.txt",
		        "node_list_path": "936573.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936573.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GranulicatellaAdiacensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Granulicatella adiacens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicatellaAdiacensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "638301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "638301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "638301.clusters.proteins.v11.5.txt",
		        "sequence_path": "638301.protein.sequences.v11.5.fa",
		        "enrichment_path": "638301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "638301.protein.info.v11.5.txt",
		        "node_list_path": "638301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "638301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasPorphyraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas porphyrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasPorphyraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "187330.clusters.info.v11.5.txt",
		        "cluster_tree_path": "187330.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "187330.clusters.proteins.v11.5.txt",
		        "sequence_path": "187330.protein.sequences.v11.5.fa",
		        "enrichment_path": "187330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "187330.protein.info.v11.5.txt",
		        "node_list_path": "187330.cluster.nodes.v11.5.txt",
		        "edge_list_path": "187330.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAnthracisStrAmesAncestorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis str. Ames Ancestor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAnthracisStrAmesAncestorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "261594.clusters.info.v11.5.txt",
		        "cluster_tree_path": "261594.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "261594.clusters.proteins.v11.5.txt",
		        "sequence_path": "261594.protein.sequences.v11.5.fa",
		        "enrichment_path": "261594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "261594.protein.info.v11.5.txt",
		        "node_list_path": "261594.cluster.nodes.v11.5.txt",
		        "edge_list_path": "261594.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProvidenciaAlcalifaciensDsm30120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens DSM 30120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaAlcalifaciensDsm30120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "520999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "520999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "520999.clusters.proteins.v11.5.txt",
		        "sequence_path": "520999.protein.sequences.v11.5.fa",
		        "enrichment_path": "520999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "520999.protein.info.v11.5.txt",
		        "node_list_path": "520999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "520999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AhrensiaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ahrensia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AhrensiaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1514904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1514904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1514904.clusters.proteins.v11.5.txt",
		        "sequence_path": "1514904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1514904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1514904.protein.info.v11.5.txt",
		        "node_list_path": "1514904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1514904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumThalassiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium thalassium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumThalassiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426701.clusters.proteins.v11.5.txt",
		        "sequence_path": "426701.protein.sequences.v11.5.fa",
		        "enrichment_path": "426701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426701.protein.info.v11.5.txt",
		        "node_list_path": "426701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ToxocaraCanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Toxocara canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ToxocaraCanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6265.protein.sequences.v11.5.fa",
		        "enrichment_path": "6265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6265.protein.info.v11.5.txt",
		        "node_list_path": "6265.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf24266Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_42_66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf24266Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797351.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797351.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797351.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797351.protein.info.v11.5.txt",
		        "node_list_path": "1797351.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797351.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BiomphalariaGlabrataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Biomphalaria glabrata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BiomphalariaGlabrataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6526.clusters.proteins.v11.5.txt",
		        "sequence_path": "6526.protein.sequences.v11.5.fa",
		        "enrichment_path": "6526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6526.protein.info.v11.5.txt",
		        "node_list_path": "6526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AminicenantesBacteriumAaa252a02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium AAA252A02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "AminicenantesBacteriumAaa252a02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1047013.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1047013.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1047013.clusters.proteins.v11.0.txt",
		        "sequence_path": "1047013.protein.sequences.v11.0.fa",
		        "enrichment_path": "1047013.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1047013.protein.info.v11.0.txt",
		        "node_list_path": "1047013.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1047013.protein.cluster.v11.0.txt"
		    }
		]
    )()

def LeisingeraSpAngM1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leisingera sp. ANG-M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraSpAngM1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577895.protein.info.v11.5.txt",
		        "node_list_path": "1577895.protein.complete.v11.5.txt"
		    }
		]
    )()

def FervidobacteriumGondwanenseDsm13020(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium gondwanense DSM 13020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidobacteriumGondwanenseDsm13020", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121883.protein.info.v11.5.txt",
		        "node_list_path": "1121883.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumCeb3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium CEB3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumCeb3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999898.clusters.proteins.v11.5.txt",
		        "sequence_path": "999898.protein.sequences.v11.5.fa",
		        "enrichment_path": "999898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999898.protein.info.v11.5.txt",
		        "node_list_path": "999898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusAnaerobiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusAnaerobiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261.protein.info.v11.5.txt",
		        "node_list_path": "1261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NesterenkoniaSpFCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. F Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesterenkoniaSpFCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "795955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "795955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "795955.clusters.proteins.v11.5.txt",
		        "sequence_path": "795955.protein.sequences.v11.5.fa",
		        "enrichment_path": "795955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "795955.protein.info.v11.5.txt",
		        "node_list_path": "795955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "795955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PygocentrusNattereri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pygocentrus nattereri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PygocentrusNattereri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42514.protein.sequences.v11.5.fa",
		        "enrichment_path": "42514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42514.protein.info.v11.5.txt",
		        "node_list_path": "42514.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrypanosomaBruceiBruceiTreu927Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma brucei brucei TREU927 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrypanosomaBruceiBruceiTreu927Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "185431.clusters.info.v11.5.txt",
		        "cluster_tree_path": "185431.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "185431.clusters.proteins.v11.5.txt",
		        "sequence_path": "185431.protein.sequences.v11.5.fa",
		        "enrichment_path": "185431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "185431.protein.info.v11.5.txt",
		        "node_list_path": "185431.cluster.nodes.v11.5.txt",
		        "edge_list_path": "185431.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocellaArvoryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanocella arvoryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocellaArvoryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351160.protein.sequences.v11.5.fa",
		        "enrichment_path": "351160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351160.protein.info.v11.5.txt",
		        "node_list_path": "351160.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumLp2a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium LP2A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumLp2a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "478741.protein.sequences.v11.5.fa",
		        "enrichment_path": "478741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "478741.protein.info.v11.5.txt",
		        "node_list_path": "478741.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurimonasSpRifoxyd12Full3339Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFOXYD12_FULL_33_39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasSpRifoxyd12Full3339Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802259.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802259.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802259.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802259.protein.info.v11.5.txt",
		        "node_list_path": "1802259.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802259.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg166615Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_66_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg166615Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797847.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797847.protein.info.v11.5.txt",
		        "node_list_path": "1797847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacterKorlensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter korlensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterKorlensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "400092.protein.sequences.v11.5.fa",
		        "enrichment_path": "400092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400092.protein.info.v11.5.txt",
		        "node_list_path": "400092.protein.complete.v11.5.txt"
		    }
		]
    )()

def OdobenusRosmarusDivergens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Odobenus rosmarus divergens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OdobenusRosmarusDivergens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9708.protein.sequences.v11.5.fa",
		        "enrichment_path": "9708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9708.protein.info.v11.5.txt",
		        "node_list_path": "9708.protein.complete.v11.5.txt"
		    }
		]
    )()

def FructobacillusFructosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fructobacillus fructosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FructobacillusFructosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930946.protein.sequences.v11.5.fa",
		        "enrichment_path": "930946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930946.protein.info.v11.5.txt",
		        "node_list_path": "930946.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumClostridioformeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Clostridium clostridioforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumClostridioformeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742735.clusters.info.v11.0.txt",
		        "cluster_tree_path": "742735.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "742735.clusters.proteins.v11.0.txt",
		        "sequence_path": "742735.protein.sequences.v11.0.fa",
		        "enrichment_path": "742735.protein.enrichment.terms.v11.0.txt",
		        "info_path": "742735.protein.info.v11.0.txt",
		        "node_list_path": "742735.cluster.nodes.v11.0.txt",
		        "edge_list_path": "742735.protein.cluster.v11.0.txt"
		    }
		]
    )()

def SynechococcusSpCb0205(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. CB0205 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpCb0205", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "232363.protein.sequences.v11.5.fa",
		        "enrichment_path": "232363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "232363.protein.info.v11.5.txt",
		        "node_list_path": "232363.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc3789(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC3789 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc3789", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217714.protein.info.v11.5.txt",
		        "node_list_path": "1217714.protein.complete.v11.5.txt"
		    }
		]
    )()

def GilliamellaBombicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gilliamella bombicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilliamellaBombicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798182.protein.info.v11.5.txt",
		        "node_list_path": "1798182.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag30730263(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:307_30_263 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag30730263", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896987.protein.info.v11.5.txt",
		        "node_list_path": "1896987.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanobacteriumSpIppasB1200(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanobacterium sp. IPPAS B-1200 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobacteriumSpIppasB1200", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1562720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1562720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1562720.protein.info.v11.5.txt",
		        "node_list_path": "1562720.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf24131(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_41_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf24131", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797348.protein.info.v11.5.txt",
		        "node_list_path": "1797348.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusicatenibacterSaccharivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusicatenibacter saccharivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusicatenibacterSaccharivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150298.protein.info.v11.5.txt",
		        "node_list_path": "1150298.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLambdaproteobacteriaBacteriumRifoxyd2Full5016(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lambdaproteobacteria bacterium RIFOXYD2_FULL_50_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLambdaproteobacteriaBacteriumRifoxyd2Full5016", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817772.protein.info.v11.5.txt",
		        "node_list_path": "1817772.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinopolysporaSaharensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora saharensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolysporaSaharensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "995062.clusters.info.v11.5.txt",
		        "cluster_tree_path": "995062.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "995062.clusters.proteins.v11.5.txt",
		        "sequence_path": "995062.protein.sequences.v11.5.fa",
		        "enrichment_path": "995062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "995062.protein.info.v11.5.txt",
		        "node_list_path": "995062.cluster.nodes.v11.5.txt",
		        "edge_list_path": "995062.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumRimaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium rimae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumRimaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553184.clusters.proteins.v11.5.txt",
		        "sequence_path": "553184.protein.sequences.v11.5.fa",
		        "enrichment_path": "553184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553184.protein.info.v11.5.txt",
		        "node_list_path": "553184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumVanbaalenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium vanbaalenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumVanbaalenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "350058.protein.sequences.v11.5.fa",
		        "enrichment_path": "350058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "350058.protein.info.v11.5.txt",
		        "node_list_path": "350058.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaDenticolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema denticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaDenticolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243275.clusters.proteins.v11.5.txt",
		        "sequence_path": "243275.protein.sequences.v11.5.fa",
		        "enrichment_path": "243275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243275.protein.info.v11.5.txt",
		        "node_list_path": "243275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WinkiaNeuii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Winkia neuii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinkiaNeuii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33007.protein.sequences.v11.5.fa",
		        "enrichment_path": "33007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33007.protein.info.v11.5.txt",
		        "node_list_path": "33007.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanktothrixSpPcc11201Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planktothrix sp. PCC 11201 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktothrixSpPcc11201Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729650.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729650.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729650.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729650.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729650.protein.info.v11.5.txt",
		        "node_list_path": "1729650.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729650.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CohnellaPanacarviGsoil349Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cohnella panacarvi Gsoil 349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CohnellaPanacarviGsoil349Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "979226.clusters.info.v11.5.txt",
		        "cluster_tree_path": "979226.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "979226.clusters.proteins.v11.5.txt",
		        "sequence_path": "979226.protein.sequences.v11.5.fa",
		        "enrichment_path": "979226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "979226.protein.info.v11.5.txt",
		        "node_list_path": "979226.cluster.nodes.v11.5.txt",
		        "edge_list_path": "979226.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RisungbinellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Risungbinella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RisungbinellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1329796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1329796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1329796.protein.info.v11.5.txt",
		        "node_list_path": "1329796.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumG11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium G11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumG11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1200747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1200747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1200747.clusters.proteins.v11.5.txt",
		        "sequence_path": "1200747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200747.protein.info.v11.5.txt",
		        "node_list_path": "1200747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1200747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpScn6214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SCN 62-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpScn6214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660099.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660099.protein.info.v11.5.txt",
		        "node_list_path": "1660099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentzeaAlbidocapillata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentzea albidocapillata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentzeaAlbidocapillata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40571.protein.sequences.v11.5.fa",
		        "enrichment_path": "40571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40571.protein.info.v11.5.txt",
		        "node_list_path": "40571.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNecrophorumFunduliforme(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum funduliforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNecrophorumFunduliforme", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095747.protein.info.v11.5.txt",
		        "node_list_path": "1095747.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesFaecichinchillae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides faecichinchillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFaecichinchillae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "871325.protein.sequences.v11.5.fa",
		        "enrichment_path": "871325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871325.protein.info.v11.5.txt",
		        "node_list_path": "871325.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumEfficiens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium efficiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumEfficiens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "196164.protein.sequences.v11.5.fa",
		        "enrichment_path": "196164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "196164.protein.info.v11.5.txt",
		        "node_list_path": "196164.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrocebusMurinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microcebus murinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrocebusMurinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "30608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "30608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "30608.clusters.proteins.v11.5.txt",
		        "sequence_path": "30608.protein.sequences.v11.5.fa",
		        "enrichment_path": "30608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30608.protein.info.v11.5.txt",
		        "node_list_path": "30608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "30608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterVenetianusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter venetianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterVenetianusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1191460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1191460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1191460.clusters.proteins.v11.5.txt",
		        "sequence_path": "1191460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1191460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1191460.protein.info.v11.5.txt",
		        "node_list_path": "1191460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1191460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPortnoybacteriaBacteriumRbg19ftCombo367Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RBG_19FT_COMBO_36_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRbg19ftCombo367Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801992.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801992.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801992.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801992.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801992.protein.info.v11.5.txt",
		        "node_list_path": "1801992.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801992.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapsellaGrandiflora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capsella grandiflora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsellaGrandiflora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264402.protein.sequences.v11.5.fa",
		        "enrichment_path": "264402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264402.protein.info.v11.5.txt",
		        "node_list_path": "264402.protein.complete.v11.5.txt"
		    }
		]
    )()

def NioellaSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nioella sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NioellaSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1912092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912092.protein.info.v11.5.txt",
		        "node_list_path": "1912092.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaPertussis18323Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella pertussis 18323 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaPertussis18323Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "568706.clusters.info.v11.5.txt",
		        "cluster_tree_path": "568706.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "568706.clusters.proteins.v11.5.txt",
		        "sequence_path": "568706.protein.sequences.v11.5.fa",
		        "enrichment_path": "568706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568706.protein.info.v11.5.txt",
		        "node_list_path": "568706.cluster.nodes.v11.5.txt",
		        "edge_list_path": "568706.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1023915Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_39_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023915Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805304.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805304.protein.info.v11.5.txt",
		        "node_list_path": "1805304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusPimensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus pimensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusPimensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926554.protein.sequences.v11.5.fa",
		        "enrichment_path": "926554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926554.protein.info.v11.5.txt",
		        "node_list_path": "926554.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptonychotesWeddelliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptonychotes weddellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptonychotesWeddelliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9713.clusters.proteins.v11.5.txt",
		        "sequence_path": "9713.protein.sequences.v11.5.fa",
		        "enrichment_path": "9713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9713.protein.info.v11.5.txt",
		        "node_list_path": "9713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaApista(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea apista graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaApista", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93218.protein.sequences.v11.5.fa",
		        "enrichment_path": "93218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93218.protein.info.v11.5.txt",
		        "node_list_path": "93218.protein.complete.v11.5.txt"
		    }
		]
    )()

def NanoarchaeumEquitansKin4M(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nanoarchaeum equitans Kin4-M graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NanoarchaeumEquitansKin4M", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "228908.protein.sequences.v11.5.fa",
		        "enrichment_path": "228908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228908.protein.info.v11.5.txt",
		        "node_list_path": "228908.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusSpYim77859Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. YIM77859 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusSpYim77859Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1540221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1540221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1540221.clusters.proteins.v11.5.txt",
		        "sequence_path": "1540221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1540221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1540221.protein.info.v11.5.txt",
		        "node_list_path": "1540221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1540221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichechusManatusLatirostris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichechus manatus latirostris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichechusManatusLatirostris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "127582.protein.sequences.v11.5.fa",
		        "enrichment_path": "127582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "127582.protein.info.v11.5.txt",
		        "node_list_path": "127582.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumA4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium A4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumA4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "397291.protein.sequences.v11.5.fa",
		        "enrichment_path": "397291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397291.protein.info.v11.5.txt",
		        "node_list_path": "397291.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaDenticariosiJcm15641(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella denticariosi JCM 15641 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaDenticariosiJcm15641", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298594.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298594.protein.info.v11.5.txt",
		        "node_list_path": "1298594.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscovopsisWeberiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escovopsis weberi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscovopsisWeberiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "150374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "150374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "150374.clusters.proteins.v11.5.txt",
		        "sequence_path": "150374.protein.sequences.v11.5.fa",
		        "enrichment_path": "150374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150374.protein.info.v11.5.txt",
		        "node_list_path": "150374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "150374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CephalotusFollicularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cephalotus follicularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CephalotusFollicularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3775.clusters.proteins.v11.5.txt",
		        "sequence_path": "3775.protein.sequences.v11.5.fa",
		        "enrichment_path": "3775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3775.protein.info.v11.5.txt",
		        "node_list_path": "3775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalogeometricumLimi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halogeometricum limi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalogeometricumLimi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "555875.protein.sequences.v11.5.fa",
		        "enrichment_path": "555875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555875.protein.info.v11.5.txt",
		        "node_list_path": "555875.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusAcidoterrestris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidoterrestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusAcidoterrestris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1356854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1356854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1356854.protein.info.v11.5.txt",
		        "node_list_path": "1356854.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZetaProteobacteriumScgcAb137C09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return zeta proteobacterium SCGC AB-137-C09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaProteobacteriumScgcAb137C09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131284.protein.info.v11.5.txt",
		        "node_list_path": "1131284.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaMorhuae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella morhuae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaMorhuae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "365591.protein.sequences.v11.5.fa",
		        "enrichment_path": "365591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "365591.protein.info.v11.5.txt",
		        "node_list_path": "365591.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorNaganoensisNa10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor naganoensis NA10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorNaganoensisNa10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1387569.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387569.protein.info.v11.5.txt",
		        "node_list_path": "1387569.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasLuteoviolaceaBAtcc29581Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas luteoviolacea B  ATCC 29581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasLuteoviolaceaBAtcc29581Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1268239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1268239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1268239.clusters.proteins.v11.5.txt",
		        "sequence_path": "1268239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268239.protein.info.v11.5.txt",
		        "node_list_path": "1268239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1268239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSp10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSp10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1101191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1101191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1101191.clusters.proteins.v11.5.txt",
		        "sequence_path": "1101191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101191.protein.info.v11.5.txt",
		        "node_list_path": "1101191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1101191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParastagonosporaNodorumSn15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parastagonospora nodorum SN15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParastagonosporaNodorumSn15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321614.clusters.info.v11.5.txt",
		        "cluster_tree_path": "321614.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "321614.clusters.proteins.v11.5.txt",
		        "sequence_path": "321614.protein.sequences.v11.5.fa",
		        "enrichment_path": "321614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321614.protein.info.v11.5.txt",
		        "node_list_path": "321614.cluster.nodes.v11.5.txt",
		        "edge_list_path": "321614.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfatirhabdiumButyrativoransDsm18734Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfatirhabdium butyrativorans DSM 18734 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfatirhabdiumButyrativoransDsm18734Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121394.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121394.protein.info.v11.5.txt",
		        "node_list_path": "1121394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusSp10a9Div0425Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sp. 10A9_DIV0425 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSp10a9Div0425Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1987383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1987383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1987383.clusters.proteins.v11.5.txt",
		        "sequence_path": "1987383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1987383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1987383.protein.info.v11.5.txt",
		        "node_list_path": "1987383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1987383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomaduraMacraNbrc14102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura macra NBRC 14102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraMacraNbrc14102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220564.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220564.protein.info.v11.5.txt",
		        "node_list_path": "1220564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumSgBin7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SG_bin7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumSgBin7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1827384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827384.protein.info.v11.5.txt",
		        "node_list_path": "1827384.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScalinduaBrodaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scalindua brodae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScalinduaBrodaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "237368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "237368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "237368.clusters.proteins.v11.5.txt",
		        "sequence_path": "237368.protein.sequences.v11.5.fa",
		        "enrichment_path": "237368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237368.protein.info.v11.5.txt",
		        "node_list_path": "237368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "237368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumStBin14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium ST_bin14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumStBin14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1978762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978762.protein.info.v11.5.txt",
		        "node_list_path": "1978762.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAromaticivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium aromaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAromaticivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1440774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1440774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1440774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1440774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1440774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1440774.protein.info.v11.5.txt",
		        "node_list_path": "1440774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1440774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifoxyd1Full4714Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFOXYD1_FULL_47_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifoxyd1Full4714Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798533.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798533.protein.info.v11.5.txt",
		        "node_list_path": "1798533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumKbs146(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium KBS146 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumKbs146", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "639030.protein.sequences.v11.5.fa",
		        "enrichment_path": "639030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "639030.protein.info.v11.5.txt",
		        "node_list_path": "639030.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychroflexusHalocasei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychroflexus halocasei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroflexusHalocasei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "908615.protein.sequences.v11.5.fa",
		        "enrichment_path": "908615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908615.protein.info.v11.5.txt",
		        "node_list_path": "908615.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusCanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusCanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "214095.protein.sequences.v11.5.fa",
		        "enrichment_path": "214095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "214095.protein.info.v11.5.txt",
		        "node_list_path": "214095.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaludibacterPropionicigenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paludibacter propionicigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaludibacterPropionicigenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "694427.protein.sequences.v11.5.fa",
		        "enrichment_path": "694427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694427.protein.info.v11.5.txt",
		        "node_list_path": "694427.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaSpOralTaxon212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. oral taxon 212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaSpOralTaxon212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "712357.clusters.info.v11.5.txt",
		        "cluster_tree_path": "712357.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "712357.clusters.proteins.v11.5.txt",
		        "sequence_path": "712357.protein.sequences.v11.5.fa",
		        "enrichment_path": "712357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712357.protein.info.v11.5.txt",
		        "node_list_path": "712357.cluster.nodes.v11.5.txt",
		        "edge_list_path": "712357.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusFaecalisAtcc29212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecalis ATCC29212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusFaecalisAtcc29212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1201292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1201292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1201292.protein.info.v11.5.txt",
		        "node_list_path": "1201292.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807752.protein.info.v11.5.txt",
		        "node_list_path": "1807752.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifoxyd12Full5516(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12_FULL_55_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12Full5516", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797904.protein.info.v11.5.txt",
		        "node_list_path": "1797904.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkelbacteriaBacteriumCg2303944Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium CG2_30_39_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumCg2303944Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805037.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805037.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805037.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805037.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805037.protein.info.v11.5.txt",
		        "node_list_path": "1805037.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805037.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMuproteobacteriaBacteriumRbg166534(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_65_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166534", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817760.protein.info.v11.5.txt",
		        "node_list_path": "1817760.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhyllobacteriumSpUnc302mfcol52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. UNC302MFCol52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhyllobacteriumSpUnc302mfcol52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449065.protein.info.v11.5.txt",
		        "node_list_path": "1449065.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrobaculumOguniense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum oguniense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumOguniense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "698757.protein.sequences.v11.5.fa",
		        "enrichment_path": "698757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698757.protein.info.v11.5.txt",
		        "node_list_path": "698757.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseiflexusSpRs1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseiflexus sp. RS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseiflexusSpRs1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "357808.clusters.info.v11.5.txt",
		        "cluster_tree_path": "357808.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "357808.clusters.proteins.v11.5.txt",
		        "sequence_path": "357808.protein.sequences.v11.5.fa",
		        "enrichment_path": "357808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357808.protein.info.v11.5.txt",
		        "node_list_path": "357808.cluster.nodes.v11.5.txt",
		        "edge_list_path": "357808.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LoktanellaSpS4079Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella sp. S4079 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaSpS4079Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "579483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "579483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "579483.clusters.proteins.v11.5.txt",
		        "sequence_path": "579483.protein.sequences.v11.5.fa",
		        "enrichment_path": "579483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579483.protein.info.v11.5.txt",
		        "node_list_path": "579483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "579483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusBombicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus bombicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBombicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1505723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1505723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1505723.clusters.proteins.v11.5.txt",
		        "sequence_path": "1505723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505723.protein.info.v11.5.txt",
		        "node_list_path": "1505723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1505723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonadaceaeBacteriumH1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonadaceaeBacteriumH1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658779.protein.info.v11.5.txt",
		        "node_list_path": "1658779.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalipigerMucosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salipiger mucosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalipigerMucosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123237.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123237.protein.info.v11.5.txt",
		        "node_list_path": "1123237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumLuteumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium luteum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumLuteumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33881.clusters.proteins.v11.5.txt",
		        "sequence_path": "33881.protein.sequences.v11.5.fa",
		        "enrichment_path": "33881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33881.protein.info.v11.5.txt",
		        "node_list_path": "33881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerticilliumAlfalfae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verticillium alfalfae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerticilliumAlfalfae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1051613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051613.protein.info.v11.5.txt",
		        "node_list_path": "1051613.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpathiphylli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter spathiphylli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpathiphylli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163407.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163407.protein.info.v11.5.txt",
		        "node_list_path": "1163407.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaPunctata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryza punctata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaPunctata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4537.protein.sequences.v11.5.fa",
		        "enrichment_path": "4537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4537.protein.info.v11.5.txt",
		        "node_list_path": "4537.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusFaecalisAtcc29212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecalis ATCC29212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusFaecalisAtcc29212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1201292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1201292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1201292.clusters.proteins.v11.5.txt",
		        "sequence_path": "1201292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1201292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1201292.protein.info.v11.5.txt",
		        "node_list_path": "1201292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1201292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevundimonasAveniformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas aveniformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasAveniformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121123.protein.info.v11.5.txt",
		        "node_list_path": "1121123.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchistosomaBovis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaBovis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6184.protein.sequences.v11.5.fa",
		        "enrichment_path": "6184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6184.protein.info.v11.5.txt",
		        "node_list_path": "6184.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSulciaMuelleriCari(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri CARI graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSulciaMuelleriCari", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "706194.protein.sequences.v11.5.fa",
		        "enrichment_path": "706194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706194.protein.info.v11.5.txt",
		        "node_list_path": "706194.protein.complete.v11.5.txt"
		    }
		]
    )()

def FabibacterPacificus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fabibacter pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FabibacterPacificus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267423.protein.info.v11.5.txt",
		        "node_list_path": "1267423.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedArchaeonA07hb70(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HB70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedArchaeonA07hb70", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1412872.protein.sequences.v11.5.fa",
		        "enrichment_path": "1412872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1412872.protein.info.v11.5.txt",
		        "node_list_path": "1412872.protein.complete.v11.5.txt"
		    }
		]
    )()

def RouxiellaChamberiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rouxiella chamberiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RouxiellaChamberiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1513468.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1513468.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1513468.clusters.proteins.v11.5.txt",
		        "sequence_path": "1513468.protein.sequences.v11.5.fa",
		        "enrichment_path": "1513468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1513468.protein.info.v11.5.txt",
		        "node_list_path": "1513468.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1513468.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9515(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9515 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9515", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "167542.protein.sequences.v11.5.fa",
		        "enrichment_path": "167542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167542.protein.info.v11.5.txt",
		        "node_list_path": "167542.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo202Full6319(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_02_FULL_63_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202Full6319", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797486.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797486.protein.info.v11.5.txt",
		        "node_list_path": "1797486.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSp651059Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-1059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSp651059Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895860.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895860.protein.info.v11.5.txt",
		        "node_list_path": "1895860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaMultivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia multivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaMultivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "395019.protein.sequences.v11.5.fa",
		        "enrichment_path": "395019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395019.protein.info.v11.5.txt",
		        "node_list_path": "395019.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusSydowiiCbs59365Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sydowii CBS 593.65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusSydowiiCbs59365Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1036612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1036612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1036612.clusters.proteins.v11.5.txt",
		        "sequence_path": "1036612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036612.protein.info.v11.5.txt",
		        "node_list_path": "1036612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1036612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElizabethkingiaAnophelisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elizabethkingia anophelis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElizabethkingiaAnophelisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1338011.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1338011.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1338011.clusters.proteins.v11.5.txt",
		        "sequence_path": "1338011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1338011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1338011.protein.info.v11.5.txt",
		        "node_list_path": "1338011.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1338011.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacillusFlagellatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacillus flagellatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacillusFlagellatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "265072.protein.sequences.v11.5.fa",
		        "enrichment_path": "265072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265072.protein.info.v11.5.txt",
		        "node_list_path": "265072.protein.complete.v11.5.txt"
		    }
		]
    )()

def AminobacteriumColombiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aminobacterium colombiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminobacteriumColombiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "572547.protein.sequences.v11.5.fa",
		        "enrichment_path": "572547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572547.protein.info.v11.5.txt",
		        "node_list_path": "572547.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedBlautiaSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Blautia sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedBlautiaSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765821.clusters.proteins.v11.5.txt",
		        "sequence_path": "765821.protein.sequences.v11.5.fa",
		        "enrichment_path": "765821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765821.protein.info.v11.5.txt",
		        "node_list_path": "765821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumIliopiscariumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium iliopiscarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumIliopiscariumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56192.clusters.proteins.v11.5.txt",
		        "sequence_path": "56192.protein.sequences.v11.5.fa",
		        "enrichment_path": "56192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56192.protein.info.v11.5.txt",
		        "node_list_path": "56192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LatimeriaChalumnae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Latimeria chalumnae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LatimeriaChalumnae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7897.protein.sequences.v11.5.fa",
		        "enrichment_path": "7897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7897.protein.info.v11.5.txt",
		        "node_list_path": "7897.protein.complete.v11.5.txt"
		    }
		]
    )()

def SanguibacterMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SanguibacterMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "285351.clusters.info.v11.5.txt",
		        "cluster_tree_path": "285351.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "285351.clusters.proteins.v11.5.txt",
		        "sequence_path": "285351.protein.sequences.v11.5.fa",
		        "enrichment_path": "285351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285351.protein.info.v11.5.txt",
		        "node_list_path": "285351.cluster.nodes.v11.5.txt",
		        "edge_list_path": "285351.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonCaspThauma1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon casp-thauma1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonCaspThauma1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1661711.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1661711.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1661711.clusters.proteins.v11.5.txt",
		        "sequence_path": "1661711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661711.protein.info.v11.5.txt",
		        "node_list_path": "1661711.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1661711.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FaecalibacteriumPrausnitziiA2165Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii A2165 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibacteriumPrausnitziiA2165Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411483.clusters.proteins.v11.5.txt",
		        "sequence_path": "411483.protein.sequences.v11.5.fa",
		        "enrichment_path": "411483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411483.protein.info.v11.5.txt",
		        "node_list_path": "411483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnanasComosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ananas comosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnanasComosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4615.protein.sequences.v11.5.fa",
		        "enrichment_path": "4615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4615.protein.info.v11.5.txt",
		        "node_list_path": "4615.protein.complete.v11.5.txt"
		    }
		]
    )()

def TieghemosteliumLacteumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tieghemostelium lacteum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TieghemosteliumLacteumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "361077.clusters.info.v11.5.txt",
		        "cluster_tree_path": "361077.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "361077.clusters.proteins.v11.5.txt",
		        "sequence_path": "361077.protein.sequences.v11.5.fa",
		        "enrichment_path": "361077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "361077.protein.info.v11.5.txt",
		        "node_list_path": "361077.cluster.nodes.v11.5.txt",
		        "edge_list_path": "361077.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BotryotiniaNarcissicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Botryotinia narcissicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotryotiniaNarcissicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "278944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "278944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "278944.clusters.proteins.v11.5.txt",
		        "sequence_path": "278944.protein.sequences.v11.5.fa",
		        "enrichment_path": "278944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278944.protein.info.v11.5.txt",
		        "node_list_path": "278944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "278944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCaseinilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus caseinilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCaseinilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1503961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1503961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1503961.clusters.proteins.v11.5.txt",
		        "sequence_path": "1503961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1503961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1503961.protein.info.v11.5.txt",
		        "node_list_path": "1503961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1503961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FerrovumSpJa12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrovum sp. JA12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrovumSpJa12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1356299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1356299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1356299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1356299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1356299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1356299.protein.info.v11.5.txt",
		        "node_list_path": "1356299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1356299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumUrealyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium urealyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumUrealyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "504474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "504474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "504474.clusters.proteins.v11.5.txt",
		        "sequence_path": "504474.protein.sequences.v11.5.fa",
		        "enrichment_path": "504474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504474.protein.info.v11.5.txt",
		        "node_list_path": "504474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "504474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucorCircinelloidesFCircinelloides1006phl(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. circinelloides 1006PhL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucorCircinelloidesFCircinelloides1006phl", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220926.protein.info.v11.5.txt",
		        "node_list_path": "1220926.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumIntermedium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium intermedium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumIntermedium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28445.protein.sequences.v11.5.fa",
		        "enrichment_path": "28445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28445.protein.info.v11.5.txt",
		        "node_list_path": "28445.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpMa2016(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. MA2016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpMa2016", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408310.protein.info.v11.5.txt",
		        "node_list_path": "1408310.protein.complete.v11.5.txt"
		    }
		]
    )()

def SetariaItalica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Setaria italica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SetariaItalica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4555.protein.sequences.v11.5.fa",
		        "enrichment_path": "4555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4555.protein.info.v11.5.txt",
		        "node_list_path": "4555.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiastellaYeongjuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Niastella yeongjuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiastellaYeongjuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "354355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "354355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "354355.clusters.proteins.v11.5.txt",
		        "sequence_path": "354355.protein.sequences.v11.5.fa",
		        "enrichment_path": "354355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "354355.protein.info.v11.5.txt",
		        "node_list_path": "354355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "354355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusVestibularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus vestibularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusVestibularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "904306.protein.sequences.v11.5.fa",
		        "enrichment_path": "904306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904306.protein.info.v11.5.txt",
		        "node_list_path": "904306.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParamormyropsKingsleyae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paramormyrops kingsleyae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParamormyropsKingsleyae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1676925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676925.protein.info.v11.5.txt",
		        "node_list_path": "1676925.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasAmylolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas amylolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasAmylolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1859457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1859457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1859457.protein.info.v11.5.txt",
		        "node_list_path": "1859457.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaWashoeensis0850475Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella washoeensis 085-0475 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaWashoeensis0850475Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094564.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094564.protein.info.v11.5.txt",
		        "node_list_path": "1094564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterSpR4368Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter sp. R4368 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterSpR4368Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1166130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1166130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1166130.clusters.proteins.v11.5.txt",
		        "sequence_path": "1166130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166130.protein.info.v11.5.txt",
		        "node_list_path": "1166130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1166130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterMilleraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter millerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterMilleraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "230361.clusters.info.v11.5.txt",
		        "cluster_tree_path": "230361.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "230361.clusters.proteins.v11.5.txt",
		        "sequence_path": "230361.protein.sequences.v11.5.fa",
		        "enrichment_path": "230361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "230361.protein.info.v11.5.txt",
		        "node_list_path": "230361.cluster.nodes.v11.5.txt",
		        "edge_list_path": "230361.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf231Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf231 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf231Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736301.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736301.protein.info.v11.5.txt",
		        "node_list_path": "1736301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosococcusOceani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosococcus oceani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosococcusOceani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "323261.protein.sequences.v11.5.fa",
		        "enrichment_path": "323261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323261.protein.info.v11.5.txt",
		        "node_list_path": "323261.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParapedobacterKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parapedobacter koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParapedobacterKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "332977.protein.sequences.v11.5.fa",
		        "enrichment_path": "332977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332977.protein.info.v11.5.txt",
		        "node_list_path": "332977.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusApodemi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus apodemi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusApodemi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423724.protein.info.v11.5.txt",
		        "node_list_path": "1423724.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpKordi100Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpKordi100Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280380.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280380.protein.info.v11.5.txt",
		        "node_list_path": "1280380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaribacterDokdonensisDsw5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter dokdonensis DSW-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterDokdonensisDsw5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1300348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300348.protein.info.v11.5.txt",
		        "node_list_path": "1300348.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifoxyb1Full4711(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFOXYB1_FULL_47_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifoxyb1Full4711", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798401.protein.info.v11.5.txt",
		        "node_list_path": "1798401.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4113b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_02_FULL_41_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4113b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798409.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798409.protein.info.v11.5.txt",
		        "node_list_path": "1798409.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaPolysacchareaNs342Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea NS342 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaPolysacchareaNs342Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "933269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "933269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "933269.clusters.proteins.v11.5.txt",
		        "sequence_path": "933269.protein.sequences.v11.5.fa",
		        "enrichment_path": "933269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933269.protein.info.v11.5.txt",
		        "node_list_path": "933269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "933269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudorhodobacterWandonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodobacter wandonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodobacterWandonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120568.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120568.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120568.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120568.protein.info.v11.5.txt",
		        "node_list_path": "1120568.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120568.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaeromassilibacillusSpMarseilleP3371(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaeromassilibacillus sp. Marseille-P3371 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeromassilibacillusSpMarseilleP3371", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1944639.protein.sequences.v11.5.fa",
		        "enrichment_path": "1944639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1944639.protein.info.v11.5.txt",
		        "node_list_path": "1944639.protein.complete.v11.5.txt"
		    }
		]
    )()

def RikenellaceaeBacteriumDtu002Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium DTU002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RikenellaceaeBacteriumDtu002Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671665.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671665.protein.info.v11.5.txt",
		        "node_list_path": "1671665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SanguibacterSpLeaf3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter sp. Leaf3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SanguibacterSpLeaf3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736209.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736209.protein.info.v11.5.txt",
		        "node_list_path": "1736209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumUndicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium undicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumUndicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1370122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1370122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1370122.protein.info.v11.5.txt",
		        "node_list_path": "1370122.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag617Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:617 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag617Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262933.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262933.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262933.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262933.protein.info.v11.5.txt",
		        "node_list_path": "1262933.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262933.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlaesserellaParasuisSh0165(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glaesserella parasuis SH0165 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaesserellaParasuisSh0165", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "557723.protein.sequences.v11.5.fa",
		        "enrichment_path": "557723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "557723.protein.info.v11.5.txt",
		        "node_list_path": "557723.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychroserpensSpHelI66(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens sp. Hel_I_66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroserpensSpHelI66", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1250004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250004.protein.info.v11.5.txt",
		        "node_list_path": "1250004.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusLacusDsm15449(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus lacus DSM 15449 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusLacusDsm15449", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121420.protein.info.v11.5.txt",
		        "node_list_path": "1121420.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptobacillusNotomytis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptobacillus notomytis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptobacillusNotomytis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1712031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1712031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1712031.protein.info.v11.5.txt",
		        "node_list_path": "1712031.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodomicrobiumVannielii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodomicrobium vannielii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodomicrobiumVannielii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "648757.protein.sequences.v11.5.fa",
		        "enrichment_path": "648757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "648757.protein.info.v11.5.txt",
		        "node_list_path": "648757.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusChristenseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus christensenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusChristenseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "87541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "87541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "87541.clusters.proteins.v11.5.txt",
		        "sequence_path": "87541.protein.sequences.v11.5.fa",
		        "enrichment_path": "87541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "87541.protein.info.v11.5.txt",
		        "node_list_path": "87541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "87541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerotruncusRubiinfantisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerotruncus rubiinfantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotruncusRubiinfantisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720200.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720200.protein.info.v11.5.txt",
		        "node_list_path": "1720200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesCattleya(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces cattleya graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCattleya", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1003195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1003195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1003195.protein.info.v11.5.txt",
		        "node_list_path": "1003195.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfopilaAestuariiDsm18488Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfopila aestuarii DSM 18488 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfopilaAestuariiDsm18488Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121416.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121416.protein.info.v11.5.txt",
		        "node_list_path": "1121416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NanohaloarchaeaArchaeonSg9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon SG9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NanohaloarchaeaArchaeonSg9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1737403.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1737403.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1737403.clusters.proteins.v11.5.txt",
		        "sequence_path": "1737403.protein.sequences.v11.5.fa",
		        "enrichment_path": "1737403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1737403.protein.info.v11.5.txt",
		        "node_list_path": "1737403.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1737403.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaHellenica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella hellenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaHellenica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46256.protein.sequences.v11.5.fa",
		        "enrichment_path": "46256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46256.protein.info.v11.5.txt",
		        "node_list_path": "46256.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetraodonNigroviridis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetraodon nigroviridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetraodonNigroviridis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "99883.protein.sequences.v11.5.fa",
		        "enrichment_path": "99883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "99883.protein.info.v11.5.txt",
		        "node_list_path": "99883.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemmobacterNectariphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmobacter nectariphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmobacterNectariphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121271.protein.info.v11.5.txt",
		        "node_list_path": "1121271.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSulciaMuelleriGwssCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri GWSS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSulciaMuelleriGwssCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "444179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "444179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "444179.clusters.proteins.v11.5.txt",
		        "sequence_path": "444179.protein.sequences.v11.5.fa",
		        "enrichment_path": "444179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444179.protein.info.v11.5.txt",
		        "node_list_path": "444179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "444179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsaiaPlatycodiJcm25414Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asaia platycodi JCM 25414 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsaiaPlatycodiJcm25414Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236525.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236525.protein.info.v11.5.txt",
		        "node_list_path": "1236525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChiloscylliumPunctatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chiloscyllium punctatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChiloscylliumPunctatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "137246.protein.sequences.v11.5.fa",
		        "enrichment_path": "137246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137246.protein.info.v11.5.txt",
		        "node_list_path": "137246.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacterium4484213Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484213Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1968528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1968528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1968528.clusters.proteins.v11.5.txt",
		        "sequence_path": "1968528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1968528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1968528.protein.info.v11.5.txt",
		        "node_list_path": "1968528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1968528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasExtremaustralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas extremaustralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasExtremaustralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117958.protein.info.v11.5.txt",
		        "node_list_path": "1117958.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloterricolaOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloterricola oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloterricolaOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1495050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495050.protein.info.v11.5.txt",
		        "node_list_path": "1495050.protein.complete.v11.5.txt"
		    }
		]
    )()

def CalditerrivibrioNitroreducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Calditerrivibrio nitroreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalditerrivibrioNitroreducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "768670.protein.sequences.v11.5.fa",
		        "enrichment_path": "768670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768670.protein.info.v11.5.txt",
		        "node_list_path": "768670.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanocellaPaludicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanocella paludicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocellaPaludicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "304371.protein.sequences.v11.5.fa",
		        "enrichment_path": "304371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "304371.protein.info.v11.5.txt",
		        "node_list_path": "304371.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermofilumPendens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum pendens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermofilumPendens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "368408.protein.sequences.v11.5.fa",
		        "enrichment_path": "368408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "368408.protein.info.v11.5.txt",
		        "node_list_path": "368408.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpKle1755Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. KLE1755 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpKle1755Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1226325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1226325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1226325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1226325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1226325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1226325.protein.info.v11.5.txt",
		        "node_list_path": "1226325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1226325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumAphoticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium aphoticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumAphoticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "754436.protein.sequences.v11.5.fa",
		        "enrichment_path": "754436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754436.protein.info.v11.5.txt",
		        "node_list_path": "754436.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3925Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3925Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802521.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802521.protein.info.v11.5.txt",
		        "node_list_path": "1802521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OctadecabacterArcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Octadecabacter arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OctadecabacterArcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391616.protein.sequences.v11.5.fa",
		        "enrichment_path": "391616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391616.protein.info.v11.5.txt",
		        "node_list_path": "391616.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloropiconPrimus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloropicon primus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloropiconPrimus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1764295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1764295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1764295.protein.info.v11.5.txt",
		        "node_list_path": "1764295.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumSeropedicaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum seropedicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumSeropedicaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "757424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "757424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "757424.clusters.proteins.v11.5.txt",
		        "sequence_path": "757424.protein.sequences.v11.5.fa",
		        "enrichment_path": "757424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "757424.protein.info.v11.5.txt",
		        "node_list_path": "757424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "757424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumRiyadhense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium riyadhense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumRiyadhense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "486698.protein.sequences.v11.5.fa",
		        "enrichment_path": "486698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "486698.protein.info.v11.5.txt",
		        "node_list_path": "486698.protein.complete.v11.5.txt"
		    }
		]
    )()

def DuganellaSpCf517(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. CF517 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpCf517", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881038.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881038.protein.info.v11.5.txt",
		        "node_list_path": "1881038.protein.complete.v11.5.txt"
		    }
		]
    )()

def LunatimonasLonarensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lunatimonas lonarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LunatimonasLonarensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232681.protein.info.v11.5.txt",
		        "node_list_path": "1232681.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlossinaBrevipalpis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glossina brevipalpis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlossinaBrevipalpis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37001.protein.sequences.v11.5.fa",
		        "enrichment_path": "37001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37001.protein.info.v11.5.txt",
		        "node_list_path": "37001.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPhoceense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium phoceense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPhoceense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1686286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686286.protein.info.v11.5.txt",
		        "node_list_path": "1686286.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusWarneriSg1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus warneri SG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusWarneriSg1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1194526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194526.protein.info.v11.5.txt",
		        "node_list_path": "1194526.protein.complete.v11.5.txt"
		    }
		]
    )()

def AkkermansiaSpCag344(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Akkermansia sp. CAG:344 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AkkermansiaSpCag344", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262691.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262691.protein.info.v11.5.txt",
		        "node_list_path": "1262691.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeiothermusSilvanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus silvanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusSilvanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "526227.protein.sequences.v11.5.fa",
		        "enrichment_path": "526227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526227.protein.info.v11.5.txt",
		        "node_list_path": "526227.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumConspicuum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium conspicuum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumConspicuum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44010.protein.sequences.v11.5.fa",
		        "enrichment_path": "44010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44010.protein.info.v11.5.txt",
		        "node_list_path": "44010.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychroserpensSpPamc27130(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens sp. PAMC27130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroserpensSpPamc27130", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1484460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484460.protein.info.v11.5.txt",
		        "node_list_path": "1484460.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa14021Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA1_40_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa14021Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618784.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618784.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618784.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618784.protein.info.v11.5.txt",
		        "node_list_path": "1618784.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618784.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpRoot480Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. Root480 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpRoot480Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736542.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736542.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736542.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736542.protein.info.v11.5.txt",
		        "node_list_path": "1736542.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736542.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpongiibacterSpImcc21906(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spongiibacter sp. IMCC21906 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpongiibacterSpImcc21906", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1620392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1620392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1620392.protein.info.v11.5.txt",
		        "node_list_path": "1620392.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastococcusEndophyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus endophyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusEndophyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "673521.protein.sequences.v11.5.fa",
		        "enrichment_path": "673521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "673521.protein.info.v11.5.txt",
		        "node_list_path": "673521.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumGw2011Gwa24110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWA2_41_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwa24110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618977.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618977.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618977.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618977.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618977.protein.info.v11.5.txt",
		        "node_list_path": "1618977.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618977.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobaculumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobaculumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "202789.clusters.info.v11.5.txt",
		        "cluster_tree_path": "202789.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "202789.clusters.proteins.v11.5.txt",
		        "sequence_path": "202789.protein.sequences.v11.5.fa",
		        "enrichment_path": "202789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202789.protein.info.v11.5.txt",
		        "node_list_path": "202789.cluster.nodes.v11.5.txt",
		        "edge_list_path": "202789.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionCpr2BacteriumGw2011Gwc23935Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR2 bacterium GW2011_GWC2_39_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionCpr2BacteriumGw2011Gwc23935Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618346.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618346.protein.info.v11.5.txt",
		        "node_list_path": "1618346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrococcalesBacterium7064Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 70-64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcalesBacterium7064Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895789.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895789.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895789.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895789.protein.info.v11.5.txt",
		        "node_list_path": "1895789.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895789.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasRuthenicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas ruthenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasRuthenicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216007.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216007.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216007.protein.info.v11.5.txt",
		        "node_list_path": "1216007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrinemaAltunenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrinema altunense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrinemaAltunenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "222984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "222984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "222984.clusters.proteins.v11.5.txt",
		        "sequence_path": "222984.protein.sequences.v11.5.fa",
		        "enrichment_path": "222984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "222984.protein.info.v11.5.txt",
		        "node_list_path": "222984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "222984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AphanomycesAstaciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aphanomyces astaci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AphanomycesAstaciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "112090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "112090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "112090.clusters.proteins.v11.5.txt",
		        "sequence_path": "112090.protein.sequences.v11.5.fa",
		        "enrichment_path": "112090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112090.protein.info.v11.5.txt",
		        "node_list_path": "112090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "112090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumPlataniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium platani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumPlataniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "427683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "427683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "427683.clusters.proteins.v11.5.txt",
		        "sequence_path": "427683.protein.sequences.v11.5.fa",
		        "enrichment_path": "427683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "427683.protein.info.v11.5.txt",
		        "node_list_path": "427683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "427683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuaniaAlbidiflava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruania albidiflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuaniaAlbidiflava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123065.protein.info.v11.5.txt",
		        "node_list_path": "1123065.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrococcusAbyssiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus abyssi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusAbyssiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272844.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272844.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272844.clusters.proteins.v11.5.txt",
		        "sequence_path": "272844.protein.sequences.v11.5.fa",
		        "enrichment_path": "272844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272844.protein.info.v11.5.txt",
		        "node_list_path": "272844.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272844.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumTimonianumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium timonianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumTimonianumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805473.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805473.protein.info.v11.5.txt",
		        "node_list_path": "1805473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumKashiwanohensePv202Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium kashiwanohense PV20-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumKashiwanohensePv202Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1447716.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1447716.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1447716.clusters.proteins.v11.5.txt",
		        "sequence_path": "1447716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1447716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1447716.protein.info.v11.5.txt",
		        "node_list_path": "1447716.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1447716.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BeauveriaBassianaD15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Beauveria bassiana D1-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeauveriaBassianaD15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1245745.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1245745.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1245745.clusters.proteins.v11.5.txt",
		        "sequence_path": "1245745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245745.protein.info.v11.5.txt",
		        "node_list_path": "1245745.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1245745.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumAb4001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium AB4001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumAb4001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410638.protein.info.v11.5.txt",
		        "node_list_path": "1410638.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesRoseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRoseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66430.protein.sequences.v11.5.fa",
		        "enrichment_path": "66430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66430.protein.info.v11.5.txt",
		        "node_list_path": "66430.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp7016(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 70-16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp7016", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895785.protein.info.v11.5.txt",
		        "node_list_path": "1895785.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumSibiricum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sibiricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumSibiricum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262543.protein.sequences.v11.5.fa",
		        "enrichment_path": "262543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262543.protein.info.v11.5.txt",
		        "node_list_path": "262543.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrovirgaAerilata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microvirga aerilata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaAerilata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "670292.protein.sequences.v11.5.fa",
		        "enrichment_path": "670292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670292.protein.info.v11.5.txt",
		        "node_list_path": "670292.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoclavibacterSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoclavibacter soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoclavibacterSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123013.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123013.protein.info.v11.5.txt",
		        "node_list_path": "1123013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaSp348mftsu51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia sp. 348MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSp348mftsu51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1172185.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172185.protein.info.v11.5.txt",
		        "node_list_path": "1172185.protein.complete.v11.5.txt"
		    }
		]
    )()

def NectriaHaematococcaMpvi77134Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Nectria] haematococca mpVI 77-13-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NectriaHaematococcaMpvi77134Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "660122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "660122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "660122.clusters.proteins.v11.5.txt",
		        "sequence_path": "660122.protein.sequences.v11.5.fa",
		        "enrichment_path": "660122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660122.protein.info.v11.5.txt",
		        "node_list_path": "660122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "660122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpScgC07wgaEpuloa2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. SCG-C07WGA-EpuloA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpScgC07wgaEpuloa2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1712378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1712378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1712378.clusters.proteins.v11.5.txt",
		        "sequence_path": "1712378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1712378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1712378.protein.info.v11.5.txt",
		        "node_list_path": "1712378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1712378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LishizheniaTianjinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lishizhenia tianjinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LishizheniaTianjinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "477690.protein.sequences.v11.5.fa",
		        "enrichment_path": "477690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477690.protein.info.v11.5.txt",
		        "node_list_path": "477690.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovirgulaThermocuniculiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovirgula thermocuniculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovirgulaThermocuniculiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121468.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121468.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121468.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121468.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121468.protein.info.v11.5.txt",
		        "node_list_path": "1121468.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121468.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusCuniculi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus cuniculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusCuniculi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1432788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432788.protein.info.v11.5.txt",
		        "node_list_path": "1432788.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronobacteriumTexcoconense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronobacterium texcoconense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronobacteriumTexcoconense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095778.protein.info.v11.5.txt",
		        "node_list_path": "1095778.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumGloeosporioidesCg14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum gloeosporioides Cg-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumGloeosporioidesCg14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1237896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1237896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1237896.clusters.proteins.v11.5.txt",
		        "sequence_path": "1237896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1237896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1237896.protein.info.v11.5.txt",
		        "node_list_path": "1237896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1237896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpCmr5cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CMR5c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpCmr5cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658630.clusters.proteins.v11.5.txt",
		        "sequence_path": "658630.protein.sequences.v11.5.fa",
		        "enrichment_path": "658630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658630.protein.info.v11.5.txt",
		        "node_list_path": "658630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioZosteraeDsm11974(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio zosterae DSM 11974 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioZosteraeDsm11974", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121467.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121467.protein.info.v11.5.txt",
		        "node_list_path": "1121467.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpMarseilleP2415(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. Marseille-P2415 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpMarseilleP2415", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805471.protein.info.v11.5.txt",
		        "node_list_path": "1805471.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85201452450Sch5900713(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852014-52450_SCH5900713 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85201452450Sch5900713", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834116.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834116.protein.info.v11.5.txt",
		        "node_list_path": "1834116.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophilaceaeBacteriumCg10262390(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophilaceae bacterium CG1_02_62_390 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophilaceaeBacteriumCg10262390", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805218.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805218.protein.info.v11.5.txt",
		        "node_list_path": "1805218.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfovibrioYellowstonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio yellowstonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfovibrioYellowstonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "289376.protein.sequences.v11.5.fa",
		        "enrichment_path": "289376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "289376.protein.info.v11.5.txt",
		        "node_list_path": "289376.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasCanorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas canoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasCanorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36875.clusters.proteins.v11.5.txt",
		        "sequence_path": "36875.protein.sequences.v11.5.fa",
		        "enrichment_path": "36875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36875.protein.info.v11.5.txt",
		        "node_list_path": "36875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumAquatileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium aquatile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumAquatileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1453498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1453498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1453498.clusters.proteins.v11.5.txt",
		        "sequence_path": "1453498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453498.protein.info.v11.5.txt",
		        "node_list_path": "1453498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1453498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumSpScn6914(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. SCN 69-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumSpScn6914", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660128.protein.info.v11.5.txt",
		        "node_list_path": "1660128.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastomycesDermatitidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces dermatitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomycesDermatitidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5039.protein.sequences.v11.5.fa",
		        "enrichment_path": "5039.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5039.protein.info.v11.5.txt",
		        "node_list_path": "5039.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusHerbarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus herbarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHerbarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1670446.protein.sequences.v11.5.fa",
		        "enrichment_path": "1670446.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1670446.protein.info.v11.5.txt",
		        "node_list_path": "1670446.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassilimaliaeMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilimaliae massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassilimaliaeMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852384.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852384.protein.info.v11.5.txt",
		        "node_list_path": "1852384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumArcisJcm13916(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum arcis JCM 13916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumArcisJcm13916", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230455.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230455.protein.info.v11.5.txt",
		        "node_list_path": "1230455.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterSpAap60(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. AAP60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterSpAap60", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523423.protein.info.v11.5.txt",
		        "node_list_path": "1523423.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinopolysporaHalophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora halophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolysporaHalophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089546.protein.info.v11.5.txt",
		        "node_list_path": "1089546.protein.complete.v11.5.txt"
		    }
		]
    )()

def EsoxLucius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Esox lucius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EsoxLucius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8010.protein.sequences.v11.5.fa",
		        "enrichment_path": "8010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8010.protein.info.v11.5.txt",
		        "node_list_path": "8010.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeisingeraCaeruleaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leisingera caerulea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraCaeruleaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999549.clusters.proteins.v11.5.txt",
		        "sequence_path": "999549.protein.sequences.v11.5.fa",
		        "enrichment_path": "999549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999549.protein.info.v11.5.txt",
		        "node_list_path": "999549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DomibacillusTundraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus tundrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusTundraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1587527.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1587527.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1587527.clusters.proteins.v11.5.txt",
		        "sequence_path": "1587527.protein.sequences.v11.5.fa",
		        "enrichment_path": "1587527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1587527.protein.info.v11.5.txt",
		        "node_list_path": "1587527.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1587527.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrateuriaSpSoil773Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frateuria sp. Soil773 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrateuriaSpSoil773Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736407.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736407.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736407.protein.info.v11.5.txt",
		        "node_list_path": "1736407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterItalicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter italicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterItalicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "580331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "580331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "580331.clusters.proteins.v11.5.txt",
		        "sequence_path": "580331.protein.sequences.v11.5.fa",
		        "enrichment_path": "580331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "580331.protein.info.v11.5.txt",
		        "node_list_path": "580331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "580331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumIndicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium indicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumIndicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122238.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122238.protein.info.v11.5.txt",
		        "node_list_path": "1122238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OenococcusKitaharaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oenococcus kitaharae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OenococcusKitaharaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1045004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1045004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1045004.clusters.proteins.v11.5.txt",
		        "sequence_path": "1045004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045004.protein.info.v11.5.txt",
		        "node_list_path": "1045004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1045004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwa26223Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_62_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwa26223Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797924.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797924.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797924.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797924.protein.info.v11.5.txt",
		        "node_list_path": "1797924.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797924.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSuisYs72Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis YS72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSuisYs72Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1214217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1214217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1214217.clusters.proteins.v11.5.txt",
		        "sequence_path": "1214217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214217.protein.info.v11.5.txt",
		        "node_list_path": "1214217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1214217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumVaccae95051Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium vaccae 95051 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumVaccae95051Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354275.protein.info.v11.5.txt",
		        "node_list_path": "1354275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaritimibacterAlkaliphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maritimibacter alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaritimibacterAlkaliphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314271.clusters.proteins.v11.5.txt",
		        "sequence_path": "314271.protein.sequences.v11.5.fa",
		        "enrichment_path": "314271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314271.protein.info.v11.5.txt",
		        "node_list_path": "314271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysobacterSpA03Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter sp. A03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterSpA03Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1199154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1199154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1199154.clusters.proteins.v11.5.txt",
		        "sequence_path": "1199154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1199154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1199154.protein.info.v11.5.txt",
		        "node_list_path": "1199154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1199154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoplasmatalesArchaeon(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmatalesArchaeon", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1054217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1054217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1054217.protein.info.v11.5.txt",
		        "node_list_path": "1054217.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndocarponPusillumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Endocarpon pusillum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndocarponPusillumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "364733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "364733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "364733.clusters.proteins.v11.5.txt",
		        "sequence_path": "364733.protein.sequences.v11.5.fa",
		        "enrichment_path": "364733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "364733.protein.info.v11.5.txt",
		        "node_list_path": "364733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "364733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaSpAu1208(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. AU1208 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSpAu1208", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235457.protein.info.v11.5.txt",
		        "node_list_path": "1235457.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnsiferSpBr816(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. BR816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferSpBr816", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1057002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1057002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1057002.protein.info.v11.5.txt",
		        "node_list_path": "1057002.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpLeaf225Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. Leaf225 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpLeaf225Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736300.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736300.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736300.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736300.protein.info.v11.5.txt",
		        "node_list_path": "1736300.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736300.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpBm10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. BM10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpBm10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1529069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1529069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1529069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1529069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1529069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1529069.protein.info.v11.5.txt",
		        "node_list_path": "1529069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1529069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasOryzaeOryzicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae oryzicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasOryzaeOryzicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "383407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "383407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "383407.clusters.proteins.v11.5.txt",
		        "sequence_path": "383407.protein.sequences.v11.5.fa",
		        "enrichment_path": "383407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "383407.protein.info.v11.5.txt",
		        "node_list_path": "383407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "383407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeosporaCaninumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neospora caninum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeosporaCaninumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29176.clusters.proteins.v11.5.txt",
		        "sequence_path": "29176.protein.sequences.v11.5.fa",
		        "enrichment_path": "29176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29176.protein.info.v11.5.txt",
		        "node_list_path": "29176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumGp2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium GP2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumGp2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807746.protein.info.v11.5.txt",
		        "node_list_path": "1807746.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumCg23070394Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_70_394 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumCg23070394Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805279.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805279.protein.info.v11.5.txt",
		        "node_list_path": "1805279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BotrytisElliptica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Botrytis elliptica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotrytisElliptica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "278938.protein.sequences.v11.5.fa",
		        "enrichment_path": "278938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278938.protein.info.v11.5.txt",
		        "node_list_path": "278938.protein.complete.v11.5.txt"
		    }
		]
    )()

def ApostichopusJaponicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Apostichopus japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApostichopusJaponicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "307972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "307972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "307972.clusters.proteins.v11.5.txt",
		        "sequence_path": "307972.protein.sequences.v11.5.fa",
		        "enrichment_path": "307972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "307972.protein.info.v11.5.txt",
		        "node_list_path": "307972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "307972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyphellophoraEuropaea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyphellophora europaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyphellophoraEuropaea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "293227.protein.sequences.v11.5.fa",
		        "enrichment_path": "293227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "293227.protein.info.v11.5.txt",
		        "node_list_path": "293227.protein.complete.v11.5.txt"
		    }
		]
    )()

def XylophilusSpLeaf220(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xylophilus sp. Leaf220 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylophilusSpLeaf220", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735686.protein.info.v11.5.txt",
		        "node_list_path": "1735686.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylosinusSpLw3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylosinus sp. LW3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylosinusSpLw3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "107635.protein.sequences.v11.5.fa",
		        "enrichment_path": "107635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "107635.protein.info.v11.5.txt",
		        "node_list_path": "107635.protein.complete.v11.5.txt"
		    }
		]
    )()

def BipolarisSorokinianaNd90prCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris sorokiniana ND90Pr Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisSorokinianaNd90prCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665912.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665912.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665912.clusters.proteins.v11.5.txt",
		        "sequence_path": "665912.protein.sequences.v11.5.fa",
		        "enrichment_path": "665912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665912.protein.info.v11.5.txt",
		        "node_list_path": "665912.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665912.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HoefleaOleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hoeflea olei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoefleaOleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1480615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1480615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1480615.clusters.proteins.v11.5.txt",
		        "sequence_path": "1480615.protein.sequences.v11.5.fa",
		        "enrichment_path": "1480615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1480615.protein.info.v11.5.txt",
		        "node_list_path": "1480615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1480615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacterKumamotonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter kumamotonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterKumamotonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "354243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "354243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "354243.clusters.proteins.v11.5.txt",
		        "sequence_path": "354243.protein.sequences.v11.5.fa",
		        "enrichment_path": "354243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "354243.protein.info.v11.5.txt",
		        "node_list_path": "354243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "354243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpKo116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. KO116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpKo116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1504981.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504981.protein.info.v11.5.txt",
		        "node_list_path": "1504981.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpAedCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. AED Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpAedCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423323.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423323.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423323.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423323.protein.info.v11.5.txt",
		        "node_list_path": "1423323.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423323.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EremotheciumGossypiiAtcc10895(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium gossypii ATCC 10895 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremotheciumGossypiiAtcc10895", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "284811.protein.sequences.v11.5.fa",
		        "enrichment_path": "284811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284811.protein.info.v11.5.txt",
		        "node_list_path": "284811.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoplasmatalesArchaeonSm150Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon SM1-50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmatalesArchaeonSm150Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803815.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803815.protein.info.v11.5.txt",
		        "node_list_path": "1803815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaMikamiiNbrc108933Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia mikamii NBRC 108933 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaMikamiiNbrc108933Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223548.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223548.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223548.protein.info.v11.5.txt",
		        "node_list_path": "1223548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusPlurextorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus plurextorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPlurextorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123314.protein.info.v11.5.txt",
		        "node_list_path": "1123314.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaFermentansM64Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma fermentans M64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaFermentansM64Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "943945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "943945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "943945.clusters.proteins.v11.5.txt",
		        "sequence_path": "943945.protein.sequences.v11.5.fa",
		        "enrichment_path": "943945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "943945.protein.info.v11.5.txt",
		        "node_list_path": "943945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "943945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusObscuribacterPhosphatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Obscuribacter phosphatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusObscuribacterPhosphatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906157.protein.info.v11.5.txt",
		        "node_list_path": "1906157.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp2817(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 28_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp2817", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896981.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896981.protein.info.v11.5.txt",
		        "node_list_path": "1896981.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConchiformibiusKuhniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Conchiformibius kuhniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConchiformibiusKuhniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121351.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121351.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121351.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121351.protein.info.v11.5.txt",
		        "node_list_path": "1121351.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121351.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlsenellaSpF0356Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella sp. F0356 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaSpF0356Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "661087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "661087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "661087.clusters.proteins.v11.5.txt",
		        "sequence_path": "661087.protein.sequences.v11.5.fa",
		        "enrichment_path": "661087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "661087.protein.info.v11.5.txt",
		        "node_list_path": "661087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "661087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BerkelbacteriaBacteriumGw2011Gwe13912(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011_GWE1_39_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BerkelbacteriaBacteriumGw2011Gwe13912", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618337.protein.info.v11.5.txt",
		        "node_list_path": "1618337.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpRoot420Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root420 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpRoot420Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736533.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736533.protein.info.v11.5.txt",
		        "node_list_path": "1736533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioGenomosp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio genomosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioGenomosp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1187848.protein.sequences.v11.5.fa",
		        "enrichment_path": "1187848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1187848.protein.info.v11.5.txt",
		        "node_list_path": "1187848.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurovumRiftiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum riftiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurovumRiftiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1630136.protein.sequences.v11.5.fa",
		        "enrichment_path": "1630136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1630136.protein.info.v11.5.txt",
		        "node_list_path": "1630136.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmphilophusCitrinellusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amphilophus citrinellus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphilophusCitrinellusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61819.clusters.proteins.v11.5.txt",
		        "sequence_path": "61819.protein.sequences.v11.5.fa",
		        "enrichment_path": "61819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61819.protein.info.v11.5.txt",
		        "node_list_path": "61819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MusSpicilegus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mus spicilegus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusSpicilegus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10103.protein.sequences.v11.5.fa",
		        "enrichment_path": "10103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10103.protein.info.v11.5.txt",
		        "node_list_path": "10103.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaitozymaPodzolicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saitozyma podzolica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaitozymaPodzolicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1890683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1890683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1890683.clusters.proteins.v11.5.txt",
		        "sequence_path": "1890683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1890683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1890683.protein.info.v11.5.txt",
		        "node_list_path": "1890683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1890683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TolypocladiumCapitatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tolypocladium capitatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolypocladiumCapitatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45235.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45235.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45235.clusters.proteins.v11.5.txt",
		        "sequence_path": "45235.protein.sequences.v11.5.fa",
		        "enrichment_path": "45235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45235.protein.info.v11.5.txt",
		        "node_list_path": "45235.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45235.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAltiarchaealesArchaeonImc4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Altiarchaeales archaeon IMC4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAltiarchaealesArchaeonImc4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1878999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1878999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1878999.clusters.proteins.v11.5.txt",
		        "sequence_path": "1878999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1878999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1878999.protein.info.v11.5.txt",
		        "node_list_path": "1878999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1878999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeitlerinemaSpBbd19919(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geitlerinema sp. BBD 1991-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeitlerinemaSpBbd19919", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1643526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643526.protein.info.v11.5.txt",
		        "node_list_path": "1643526.protein.complete.v11.5.txt"
		    }
		]
    )()

def RalstoniaSolanacearumPo82(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum Po82 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSolanacearumPo82", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1031711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1031711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1031711.protein.info.v11.5.txt",
		        "node_list_path": "1031711.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalodesulfovibrioSpirochaetisodalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halodesulfovibrio spirochaetisodalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalodesulfovibrioSpirochaetisodalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1560234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1560234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1560234.clusters.proteins.v11.5.txt",
		        "sequence_path": "1560234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1560234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1560234.protein.info.v11.5.txt",
		        "node_list_path": "1560234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1560234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopostipesSuicloacalisDsm15692Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopostipes suicloacalis DSM 15692 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopostipesSuicloacalisDsm15692Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121025.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121025.protein.info.v11.5.txt",
		        "node_list_path": "1121025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterNitratireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterNitratireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1137280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1137280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1137280.clusters.proteins.v11.5.txt",
		        "sequence_path": "1137280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137280.protein.info.v11.5.txt",
		        "node_list_path": "1137280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1137280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpYr768Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. YR768 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpYr768Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884365.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884365.protein.info.v11.5.txt",
		        "node_list_path": "1884365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpK4410Mgs306(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. K4410.MGS-306 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpK4410Mgs306", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1637501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1637501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1637501.protein.info.v11.5.txt",
		        "node_list_path": "1637501.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoecheraStrictaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Boechera stricta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoecheraStrictaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "72658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "72658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "72658.clusters.proteins.v11.5.txt",
		        "sequence_path": "72658.protein.sequences.v11.5.fa",
		        "enrichment_path": "72658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72658.protein.info.v11.5.txt",
		        "node_list_path": "72658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "72658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeisingeraAquimarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leisingera aquimarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraAquimarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999611.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999611.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999611.clusters.proteins.v11.5.txt",
		        "sequence_path": "999611.protein.sequences.v11.5.fa",
		        "enrichment_path": "999611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999611.protein.info.v11.5.txt",
		        "node_list_path": "999611.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999611.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "988821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "988821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "988821.clusters.proteins.v11.5.txt",
		        "sequence_path": "988821.protein.sequences.v11.5.fa",
		        "enrichment_path": "988821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "988821.protein.info.v11.5.txt",
		        "node_list_path": "988821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "988821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusSpPh9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. PH9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusSpPh9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118055.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118055.protein.info.v11.5.txt",
		        "node_list_path": "1118055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaAldovae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia aldovae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaAldovae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "527002.protein.sequences.v11.5.fa",
		        "enrichment_path": "527002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "527002.protein.info.v11.5.txt",
		        "node_list_path": "527002.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMicrarchaeotaArchaeonRbg16369(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon RBG_16_36_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonRbg16369", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801632.protein.info.v11.5.txt",
		        "node_list_path": "1801632.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasNitrosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas nitrosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasNitrosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52442.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52442.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52442.clusters.proteins.v11.5.txt",
		        "sequence_path": "52442.protein.sequences.v11.5.fa",
		        "enrichment_path": "52442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52442.protein.info.v11.5.txt",
		        "node_list_path": "52442.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52442.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpP32eCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P32E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpP32eCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349434.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349434.protein.info.v11.5.txt",
		        "node_list_path": "1349434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusDestructans2063121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus destructans 20631-21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusDestructans2063121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658429.clusters.proteins.v11.5.txt",
		        "sequence_path": "658429.protein.sequences.v11.5.fa",
		        "enrichment_path": "658429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658429.protein.info.v11.5.txt",
		        "node_list_path": "658429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UrsusArctosHorribilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ursus arctos horribilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UrsusArctosHorribilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "116960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "116960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "116960.clusters.proteins.v11.5.txt",
		        "sequence_path": "116960.protein.sequences.v11.5.fa",
		        "enrichment_path": "116960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "116960.protein.info.v11.5.txt",
		        "node_list_path": "116960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "116960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRifoxya1Full3614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYA1_FULL_36_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRifoxya1Full3614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797391.protein.info.v11.5.txt",
		        "node_list_path": "1797391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SparusAurata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sparus aurata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SparusAurata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8175.protein.sequences.v11.5.fa",
		        "enrichment_path": "8175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8175.protein.info.v11.5.txt",
		        "node_list_path": "8175.protein.complete.v11.5.txt"
		    }
		]
    )()

def WenzhouxiangellaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wenzhouxiangella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WenzhouxiangellaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1579979.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579979.protein.info.v11.5.txt",
		        "node_list_path": "1579979.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaOxidasica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina oxidasica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaOxidasica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "676199.protein.sequences.v11.5.fa",
		        "enrichment_path": "676199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "676199.protein.info.v11.5.txt",
		        "node_list_path": "676199.protein.complete.v11.5.txt"
		    }
		]
    )()

def KyrpidiaTusciae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kyrpidia tusciae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KyrpidiaTusciae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "562970.protein.sequences.v11.5.fa",
		        "enrichment_path": "562970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562970.protein.info.v11.5.txt",
		        "node_list_path": "562970.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaTamiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella tamiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaTamiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094558.protein.info.v11.5.txt",
		        "node_list_path": "1094558.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumCg2304417(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium CG2_30_44_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumCg2304417", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805324.protein.info.v11.5.txt",
		        "node_list_path": "1805324.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpOsyseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. OSYSE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpOsyseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196323.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196323.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196323.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196323.protein.info.v11.5.txt",
		        "node_list_path": "1196323.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196323.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyorhinisGdl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis GDL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyorhinisGdl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1129369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1129369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1129369.clusters.proteins.v11.5.txt",
		        "sequence_path": "1129369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1129369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1129369.protein.info.v11.5.txt",
		        "node_list_path": "1129369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1129369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaSpDsm18164(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. DSM 18164 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpDsm18164", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881058.protein.info.v11.5.txt",
		        "node_list_path": "1881058.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag1185Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1185 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag1185Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262921.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262921.protein.info.v11.5.txt",
		        "node_list_path": "1262921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CricetulusGriseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cricetulus griseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CricetulusGriseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10029.protein.sequences.v11.5.fa",
		        "enrichment_path": "10029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10029.protein.info.v11.5.txt",
		        "node_list_path": "10029.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerocolumnaJejuensisDsm15929Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerocolumna jejuensis DSM 15929 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerocolumnaJejuensisDsm15929Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121322.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121322.protein.info.v11.5.txt",
		        "node_list_path": "1121322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NesterenkoniaJeotgali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesterenkoniaJeotgali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "317018.protein.sequences.v11.5.fa",
		        "enrichment_path": "317018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317018.protein.info.v11.5.txt",
		        "node_list_path": "317018.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsphigho201Full3637(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_01_FULL_36_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho201Full3637", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797758.protein.info.v11.5.txt",
		        "node_list_path": "1797758.protein.complete.v11.5.txt"
		    }
		]
    )()

def VagococcusPenaeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vagococcus penaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VagococcusPenaeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "633807.clusters.info.v11.5.txt",
		        "cluster_tree_path": "633807.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "633807.clusters.proteins.v11.5.txt",
		        "sequence_path": "633807.protein.sequences.v11.5.fa",
		        "enrichment_path": "633807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633807.protein.info.v11.5.txt",
		        "node_list_path": "633807.cluster.nodes.v11.5.txt",
		        "edge_list_path": "633807.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisSk564Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK564 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisSk564Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585203.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585203.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585203.clusters.proteins.v11.5.txt",
		        "sequence_path": "585203.protein.sequences.v11.5.fa",
		        "enrichment_path": "585203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585203.protein.info.v11.5.txt",
		        "node_list_path": "585203.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585203.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AfipiaSpRoot123d2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. Root123D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaSpRoot123d2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736436.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736436.protein.info.v11.5.txt",
		        "node_list_path": "1736436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAnguilliseptica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas anguilliseptica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAnguilliseptica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53406.protein.sequences.v11.5.fa",
		        "enrichment_path": "53406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53406.protein.info.v11.5.txt",
		        "node_list_path": "53406.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAustralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAustralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888833.protein.sequences.v11.5.fa",
		        "enrichment_path": "888833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888833.protein.info.v11.5.txt",
		        "node_list_path": "888833.protein.complete.v11.5.txt"
		    }
		]
    )()

def Sar324ClusterBacteriumSar324Ctd7bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return SAR324 cluster bacterium SAR324-CTD7B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar324ClusterBacteriumSar324Ctd7bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1795556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1795556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1795556.clusters.proteins.v11.5.txt",
		        "sequence_path": "1795556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795556.protein.info.v11.5.txt",
		        "node_list_path": "1795556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1795556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrialbaHulunbeirensisJcm10989Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialba hulunbeirensis JCM 10989 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaHulunbeirensisJcm10989Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227493.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227493.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227493.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227493.protein.info.v11.5.txt",
		        "node_list_path": "1227493.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227493.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpicoccumNigrumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epicoccum nigrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpicoccumNigrumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "105696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "105696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "105696.clusters.proteins.v11.5.txt",
		        "sequence_path": "105696.protein.sequences.v11.5.fa",
		        "enrichment_path": "105696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105696.protein.info.v11.5.txt",
		        "node_list_path": "105696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "105696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesKanasensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces kanasensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesKanasensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936756.clusters.proteins.v11.5.txt",
		        "sequence_path": "936756.protein.sequences.v11.5.fa",
		        "enrichment_path": "936756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936756.protein.info.v11.5.txt",
		        "node_list_path": "936756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpUnc280mftsu51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UNC280MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpUnc280mftsu51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449048.protein.info.v11.5.txt",
		        "node_list_path": "1449048.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpKrmcy2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. KRMCY2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpKrmcy2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304865.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304865.protein.info.v11.5.txt",
		        "node_list_path": "1304865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfomicrobiumApsheronum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium apsheronum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfomicrobiumApsheronum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52560.protein.sequences.v11.5.fa",
		        "enrichment_path": "52560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52560.protein.info.v11.5.txt",
		        "node_list_path": "52560.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNk4a179Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A179 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNk4a179Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "877424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "877424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "877424.clusters.proteins.v11.5.txt",
		        "sequence_path": "877424.protein.sequences.v11.5.fa",
		        "enrichment_path": "877424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877424.protein.info.v11.5.txt",
		        "node_list_path": "877424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "877424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAzambacteriaBacteriumRifoxyb1Full4033Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFOXYB1_FULL_40_33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifoxyb1Full4033Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797308.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797308.protein.info.v11.5.txt",
		        "node_list_path": "1797308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4016bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_40_16b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4016bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797714.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797714.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797714.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797714.protein.info.v11.5.txt",
		        "node_list_path": "1797714.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797714.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSomeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas somerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSomeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122975.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122975.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122975.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122975.protein.info.v11.5.txt",
		        "node_list_path": "1122975.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122975.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusFasciansLmg3625(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus fascians LMG 3625 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusFasciansLmg3625", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1443905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443905.protein.info.v11.5.txt",
		        "node_list_path": "1443905.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusArciformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus arciformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusArciformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "482827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "482827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "482827.clusters.proteins.v11.5.txt",
		        "sequence_path": "482827.protein.sequences.v11.5.fa",
		        "enrichment_path": "482827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "482827.protein.info.v11.5.txt",
		        "node_list_path": "482827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "482827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PapillibacterCinnamivoransDsm12816(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Papillibacter cinnamivorans DSM 12816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PapillibacterCinnamivoransDsm12816", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122930.protein.info.v11.5.txt",
		        "node_list_path": "1122930.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4028Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_01_FULL_40_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4028Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798406.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798406.protein.info.v11.5.txt",
		        "node_list_path": "1798406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusHemicellulosilyticusJcm9152(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus hemicellulosilyticus JCM 9152 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHemicellulosilyticusJcm9152", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236971.protein.info.v11.5.txt",
		        "node_list_path": "1236971.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumGa0077548Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077548 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumGa0077548Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752226.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752226.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752226.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752226.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752226.protein.info.v11.5.txt",
		        "node_list_path": "1752226.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752226.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg136114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_61_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg136114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797834.protein.info.v11.5.txt",
		        "node_list_path": "1797834.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolobacteriumMooreiDsm22971Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solobacterium moorei DSM22971 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolobacteriumMooreiDsm22971Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123263.protein.info.v11.5.txt",
		        "node_list_path": "1123263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaInsecticola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia insecticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaInsecticola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "758793.protein.sequences.v11.5.fa",
		        "enrichment_path": "758793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758793.protein.info.v11.5.txt",
		        "node_list_path": "758793.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSegnicrescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter segnicrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSegnicrescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "430453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "430453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "430453.clusters.proteins.v11.5.txt",
		        "sequence_path": "430453.protein.sequences.v11.5.fa",
		        "enrichment_path": "430453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "430453.protein.info.v11.5.txt",
		        "node_list_path": "430453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "430453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc5054(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 5054 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc5054", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977877.protein.info.v11.5.txt",
		        "node_list_path": "1977877.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusRubeinfantisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus rubeinfantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusRubeinfantisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720199.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720199.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720199.protein.info.v11.5.txt",
		        "node_list_path": "1720199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumSgBin8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SG_bin8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumSgBin8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1827387.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1827387.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1827387.clusters.proteins.v11.5.txt",
		        "sequence_path": "1827387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827387.protein.info.v11.5.txt",
		        "node_list_path": "1827387.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1827387.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacterIntestinalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterIntestinalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28122.clusters.proteins.v11.5.txt",
		        "sequence_path": "28122.protein.sequences.v11.5.fa",
		        "enrichment_path": "28122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28122.protein.info.v11.5.txt",
		        "node_list_path": "28122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBaumanniiAtcc17978Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii ATCC 17978 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBaumanniiAtcc17978Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "400667.clusters.info.v11.5.txt",
		        "cluster_tree_path": "400667.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "400667.clusters.proteins.v11.5.txt",
		        "sequence_path": "400667.protein.sequences.v11.5.fa",
		        "enrichment_path": "400667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400667.protein.info.v11.5.txt",
		        "node_list_path": "400667.cluster.nodes.v11.5.txt",
		        "edge_list_path": "400667.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusRugosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus rugosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusRugosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "981369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "981369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "981369.clusters.proteins.v11.5.txt",
		        "sequence_path": "981369.protein.sequences.v11.5.fa",
		        "enrichment_path": "981369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981369.protein.info.v11.5.txt",
		        "node_list_path": "981369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "981369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumMediterraneense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium mediterraneense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumMediterraneense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805472.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805472.protein.info.v11.5.txt",
		        "node_list_path": "1805472.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLeaf155(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf155 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLeaf155", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736278.protein.info.v11.5.txt",
		        "node_list_path": "1736278.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScytalidiumLignicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scytalidium lignicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScytalidiumLignicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5539.protein.sequences.v11.5.fa",
		        "enrichment_path": "5539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5539.protein.info.v11.5.txt",
		        "node_list_path": "5539.protein.complete.v11.5.txt"
		    }
		]
    )()

def NakamurellaMultipartitaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nakamurella multipartita Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NakamurellaMultipartitaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "479431.clusters.info.v11.5.txt",
		        "cluster_tree_path": "479431.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "479431.clusters.proteins.v11.5.txt",
		        "sequence_path": "479431.protein.sequences.v11.5.fa",
		        "enrichment_path": "479431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479431.protein.info.v11.5.txt",
		        "node_list_path": "479431.cluster.nodes.v11.5.txt",
		        "edge_list_path": "479431.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaS16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida S16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaS16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1042876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042876.protein.info.v11.5.txt",
		        "node_list_path": "1042876.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchaaliaRadingaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schaalia radingae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchaaliaRadingaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "131110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "131110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "131110.clusters.proteins.v11.5.txt",
		        "sequence_path": "131110.protein.sequences.v11.5.fa",
		        "enrichment_path": "131110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "131110.protein.info.v11.5.txt",
		        "node_list_path": "131110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "131110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliagarivoransTaiwanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliagarivorans taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliagarivoransTaiwanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120970.protein.info.v11.5.txt",
		        "node_list_path": "1120970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaSocranskiiParedisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema socranskii paredis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSocranskiiParedisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125701.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125701.protein.info.v11.5.txt",
		        "node_list_path": "1125701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonasSpScn6556Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas sp. SCN 65-56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasSpScn6556Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660095.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660095.protein.info.v11.5.txt",
		        "node_list_path": "1660095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaKoehleraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella koehlerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaKoehleraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1134510.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1134510.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1134510.clusters.proteins.v11.5.txt",
		        "sequence_path": "1134510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134510.protein.info.v11.5.txt",
		        "node_list_path": "1134510.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1134510.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpOv608(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. OV608 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpOv608", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882768.protein.info.v11.5.txt",
		        "node_list_path": "1882768.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpNml130628Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML130628 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpNml130628Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906333.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906333.protein.info.v11.5.txt",
		        "node_list_path": "1906333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporolactobacillusVineae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus vineae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolactobacillusVineae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123284.protein.info.v11.5.txt",
		        "node_list_path": "1123284.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusHamsteri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hamsteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHamsteri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423754.protein.info.v11.5.txt",
		        "node_list_path": "1423754.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesemziaIncerta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desemzia incerta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesemziaIncerta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "82801.protein.sequences.v11.5.fa",
		        "enrichment_path": "82801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82801.protein.info.v11.5.txt",
		        "node_list_path": "82801.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaTuberum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia tuberum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaTuberum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "157910.protein.sequences.v11.5.fa",
		        "enrichment_path": "157910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157910.protein.info.v11.5.txt",
		        "node_list_path": "157910.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteralesBacteriumRifcsphigho202Full62130(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium RIFCSPHIGHO2_02_FULL_62_130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteralesBacteriumRifcsphigho202Full62130", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802014.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802014.protein.info.v11.5.txt",
		        "node_list_path": "1802014.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfuricurvumSpRifrc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. RIFRC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricurvumSpRifrc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1249480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249480.protein.info.v11.5.txt",
		        "node_list_path": "1249480.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChristensenellaTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Christensenella timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChristensenellaTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816678.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816678.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816678.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816678.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816678.protein.info.v11.5.txt",
		        "node_list_path": "1816678.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816678.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChoiromycesVenosus1206131(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Choiromyces venosus 120613-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChoiromycesVenosus1206131", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336337.protein.info.v11.5.txt",
		        "node_list_path": "1336337.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrilusPlanipennisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrilus planipennis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrilusPlanipennisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "224129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "224129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "224129.clusters.proteins.v11.5.txt",
		        "sequence_path": "224129.protein.sequences.v11.5.fa",
		        "enrichment_path": "224129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224129.protein.info.v11.5.txt",
		        "node_list_path": "224129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "224129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerpulaLacrymansVarLacrymansS73(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serpula lacrymans var. lacrymans S7.3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerpulaLacrymansVarLacrymansS73", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936435.protein.sequences.v11.5.fa",
		        "enrichment_path": "936435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936435.protein.info.v11.5.txt",
		        "node_list_path": "936435.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerruconisGallopavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verruconis gallopava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerruconisGallopavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "253628.clusters.info.v11.5.txt",
		        "cluster_tree_path": "253628.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "253628.clusters.proteins.v11.5.txt",
		        "sequence_path": "253628.protein.sequences.v11.5.fa",
		        "enrichment_path": "253628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "253628.protein.info.v11.5.txt",
		        "node_list_path": "253628.cluster.nodes.v11.5.txt",
		        "edge_list_path": "253628.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpMt2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpMt2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499680.protein.info.v11.5.txt",
		        "node_list_path": "1499680.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasPhyllosphaerae52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas phyllosphaerae 52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasPhyllosphaerae52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1090318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1090318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1090318.protein.info.v11.5.txt",
		        "node_list_path": "1090318.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinicoccusCarnicancriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus carnicancri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusCarnicancriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235755.protein.info.v11.5.txt",
		        "node_list_path": "1235755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3811Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_38_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3811Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802060.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802060.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802060.protein.info.v11.5.txt",
		        "node_list_path": "1802060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FuerstiaMarisgermanicae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fuerstia marisgermanicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FuerstiaMarisgermanicae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1891926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891926.protein.info.v11.5.txt",
		        "node_list_path": "1891926.protein.complete.v11.5.txt"
		    }
		]
    )()

def BeutenbergiaCavernae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Beutenbergia cavernae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeutenbergiaCavernae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471853.protein.sequences.v11.5.fa",
		        "enrichment_path": "471853.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471853.protein.info.v11.5.txt",
		        "node_list_path": "471853.protein.complete.v11.5.txt"
		    }
		]
    )()

def CynaraCardunculusVarScolymusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cynara cardunculus var. scolymus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CynaraCardunculusVarScolymusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59895.clusters.proteins.v11.5.txt",
		        "sequence_path": "59895.protein.sequences.v11.5.fa",
		        "enrichment_path": "59895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59895.protein.info.v11.5.txt",
		        "node_list_path": "59895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseomonasSpB5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas sp. B5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseomonasSpB5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217720.protein.info.v11.5.txt",
		        "node_list_path": "1217720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElizabethkingiaMeningoseptica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elizabethkingia meningoseptica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElizabethkingiaMeningoseptica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216967.protein.info.v11.5.txt",
		        "node_list_path": "1216967.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumKh1t2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium KH1T2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumKh1t2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855374.protein.info.v11.5.txt",
		        "node_list_path": "1855374.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantholopsHodgsoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantholops hodgsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantholopsHodgsoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59538.clusters.proteins.v11.5.txt",
		        "sequence_path": "59538.protein.sequences.v11.5.fa",
		        "enrichment_path": "59538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59538.protein.info.v11.5.txt",
		        "node_list_path": "59538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldanaerobiusFijiensisDsm17918(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldanaerobius fijiensis DSM 17918 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldanaerobiusFijiensisDsm17918", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121256.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121256.protein.info.v11.5.txt",
		        "node_list_path": "1121256.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaliaeetusLeucocephalusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haliaeetus leucocephalus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaliaeetusLeucocephalusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52644.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52644.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52644.clusters.proteins.v11.5.txt",
		        "sequence_path": "52644.protein.sequences.v11.5.fa",
		        "enrichment_path": "52644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52644.protein.info.v11.5.txt",
		        "node_list_path": "52644.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52644.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumMizutaii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium mizutaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumMizutaii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1010.protein.info.v11.5.txt",
		        "node_list_path": "1010.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcaryochlorisMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acaryochloris marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcaryochlorisMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "329726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "329726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "329726.clusters.proteins.v11.5.txt",
		        "sequence_path": "329726.protein.sequences.v11.5.fa",
		        "enrichment_path": "329726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "329726.protein.info.v11.5.txt",
		        "node_list_path": "329726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "329726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaePhaseolicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae phaseolicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaePhaseolicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264730.protein.sequences.v11.5.fa",
		        "enrichment_path": "264730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264730.protein.info.v11.5.txt",
		        "node_list_path": "264730.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeanutWitchesbroomCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peanut witchesbroom Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeanutWitchesbroomCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1163385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1163385.clusters.proteins.v11.5.txt",
		        "sequence_path": "1163385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163385.protein.info.v11.5.txt",
		        "node_list_path": "1163385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1163385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HistoplasmaCapsulatumH88(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum H88 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HistoplasmaCapsulatumH88", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "544711.protein.sequences.v11.5.fa",
		        "enrichment_path": "544711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "544711.protein.info.v11.5.txt",
		        "node_list_path": "544711.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumGw2011Gwa2447(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWA2_44_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwa2447", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619057.protein.info.v11.5.txt",
		        "node_list_path": "1619057.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4422(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_44_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4422", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802697.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802697.protein.info.v11.5.txt",
		        "node_list_path": "1802697.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioXylanivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio xylanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioXylanivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "185007.protein.sequences.v11.5.fa",
		        "enrichment_path": "185007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "185007.protein.info.v11.5.txt",
		        "node_list_path": "185007.protein.complete.v11.5.txt"
		    }
		]
    )()

def ApostasiaShenzhenica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Apostasia shenzhenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApostasiaShenzhenica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1088818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1088818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1088818.protein.info.v11.5.txt",
		        "node_list_path": "1088818.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumGwf25093Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_50_93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumGwf25093Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798574.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798574.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798574.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798574.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798574.protein.info.v11.5.txt",
		        "node_list_path": "1798574.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798574.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpPr090111t3t6aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PR090111T3T6A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpPr090111t3t6aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "685778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "685778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "685778.clusters.proteins.v11.5.txt",
		        "sequence_path": "685778.protein.sequences.v11.5.fa",
		        "enrichment_path": "685778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "685778.protein.info.v11.5.txt",
		        "node_list_path": "685778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "685778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalinemaSpCaciam70dCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalinema sp. CACIAM 70d Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalinemaSpCaciam70dCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1934309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1934309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1934309.clusters.proteins.v11.5.txt",
		        "sequence_path": "1934309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934309.protein.info.v11.5.txt",
		        "node_list_path": "1934309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1934309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacteriumSpDl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium sp. DL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacteriumSpDl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "751944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "751944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "751944.clusters.proteins.v11.5.txt",
		        "sequence_path": "751944.protein.sequences.v11.5.fa",
		        "enrichment_path": "751944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "751944.protein.info.v11.5.txt",
		        "node_list_path": "751944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "751944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumSpScn6119Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. SCN 61-19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumSpScn6119Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660088.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660088.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660088.protein.info.v11.5.txt",
		        "node_list_path": "1660088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacterialesBacterium5955Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteriales bacterium 59-55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacterialesBacterium5955Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895690.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895690.protein.info.v11.5.txt",
		        "node_list_path": "1895690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusMoraviensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus moraviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusMoraviensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158609.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158609.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158609.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158609.protein.info.v11.5.txt",
		        "node_list_path": "1158609.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158609.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpGhaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Gha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpGhaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855318.protein.info.v11.5.txt",
		        "node_list_path": "1855318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaMultilocaleAtcc49900Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma multilocale ATCC 49900 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaMultilocaleAtcc49900Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278299.protein.info.v11.5.txt",
		        "node_list_path": "1278299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThecamonasTrahensAtcc50062(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thecamonas trahens ATCC 50062 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThecamonasTrahensAtcc50062", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "461836.protein.sequences.v11.5.fa",
		        "enrichment_path": "461836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "461836.protein.info.v11.5.txt",
		        "node_list_path": "461836.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBrocadiaSpUtamx1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sp. UTAMX1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBrocadiaSpUtamx1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1961113.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961113.protein.info.v11.5.txt",
		        "node_list_path": "1961113.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpNio1057Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. NIO-1057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpNio1057Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "993071.clusters.info.v11.5.txt",
		        "cluster_tree_path": "993071.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "993071.clusters.proteins.v11.5.txt",
		        "sequence_path": "993071.protein.sequences.v11.5.fa",
		        "enrichment_path": "993071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "993071.protein.info.v11.5.txt",
		        "node_list_path": "993071.cluster.nodes.v11.5.txt",
		        "edge_list_path": "993071.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AstatotilapiaCallipteraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Astatotilapia calliptera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AstatotilapiaCallipteraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8154.clusters.proteins.v11.5.txt",
		        "sequence_path": "8154.protein.sequences.v11.5.fa",
		        "enrichment_path": "8154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8154.protein.info.v11.5.txt",
		        "node_list_path": "8154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterLarvae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter larvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterLarvae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1789224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1789224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1789224.protein.info.v11.5.txt",
		        "node_list_path": "1789224.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusFastidiosusNbrc101226Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus fastidiosus NBRC 101226 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusFastidiosusNbrc101226Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348628.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348628.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348628.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348628.protein.info.v11.5.txt",
		        "node_list_path": "1348628.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348628.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaSocranskiiParedis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema socranskii paredis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSocranskiiParedis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125701.protein.info.v11.5.txt",
		        "node_list_path": "1125701.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1306947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1306947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1306947.clusters.proteins.v11.5.txt",
		        "sequence_path": "1306947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306947.protein.info.v11.5.txt",
		        "node_list_path": "1306947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1306947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalothiobacillusNeapolitanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halothiobacillus neapolitanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalothiobacillusNeapolitanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "555778.protein.sequences.v11.5.fa",
		        "enrichment_path": "555778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555778.protein.info.v11.5.txt",
		        "node_list_path": "555778.protein.complete.v11.5.txt"
		    }
		]
    )()

def MizugakiibacterSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mizugakiibacter sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MizugakiibacterSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1475481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1475481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1475481.protein.info.v11.5.txt",
		        "node_list_path": "1475481.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrinickiaCaryophylli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trinickia caryophylli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrinickiaCaryophylli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28094.protein.sequences.v11.5.fa",
		        "enrichment_path": "28094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28094.protein.info.v11.5.txt",
		        "node_list_path": "28094.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpOhsuiii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. OHSUIII graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpOhsuiii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1297865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297865.protein.info.v11.5.txt",
		        "node_list_path": "1297865.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarnimonasNigrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnimonas nigrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnimonasNigrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336245.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336245.protein.info.v11.5.txt",
		        "node_list_path": "1336245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpAcc21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. ACC21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpAcc21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1161413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1161413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1161413.protein.info.v11.5.txt",
		        "node_list_path": "1161413.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusBoritoleransDsm17298Jcm18970(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus boritolerans DSM 17298 JCM 18970 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusBoritoleransDsm17298Jcm18970", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120964.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120964.protein.info.v11.5.txt",
		        "node_list_path": "1120964.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaAsaccharolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia asaccharolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaAsaccharolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123024.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123024.protein.info.v11.5.txt",
		        "node_list_path": "1123024.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpheniscorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium spheniscorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpheniscorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "185761.protein.sequences.v11.5.fa",
		        "enrichment_path": "185761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "185761.protein.info.v11.5.txt",
		        "node_list_path": "185761.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobaculaToluolicaTol2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacula toluolica Tol2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobaculaToluolicaTol2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "651182.protein.sequences.v11.5.fa",
		        "enrichment_path": "651182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "651182.protein.info.v11.5.txt",
		        "node_list_path": "651182.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusTerrigenaDsm22685Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus terrigena DSM 22685 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusTerrigenaDsm22685Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120967.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120967.protein.info.v11.5.txt",
		        "node_list_path": "1120967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiO157H7StrSakai(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli O157:H7 str. Sakai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiO157H7StrSakai", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "386585.protein.sequences.v11.5.fa",
		        "enrichment_path": "386585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "386585.protein.info.v11.5.txt",
		        "node_list_path": "386585.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaBissettii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia bissettii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaBissettii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521010.protein.sequences.v11.5.fa",
		        "enrichment_path": "521010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521010.protein.info.v11.5.txt",
		        "node_list_path": "521010.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAle23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAle23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265495.protein.info.v11.5.txt",
		        "node_list_path": "1265495.protein.complete.v11.5.txt"
		    }
		]
    )()

def FaecalibacteriumSpCag7458120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium sp. CAG:74_58_120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibacteriumSpCag7458120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897005.protein.info.v11.5.txt",
		        "node_list_path": "1897005.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanotheceSpPcc7822Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7822 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanotheceSpPcc7822Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "497965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "497965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "497965.clusters.proteins.v11.5.txt",
		        "sequence_path": "497965.protein.sequences.v11.5.fa",
		        "enrichment_path": "497965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "497965.protein.info.v11.5.txt",
		        "node_list_path": "497965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "497965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedEubacteriumSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Eubacterium sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedEubacteriumSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "165185.clusters.info.v11.5.txt",
		        "cluster_tree_path": "165185.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "165185.clusters.proteins.v11.5.txt",
		        "sequence_path": "165185.protein.sequences.v11.5.fa",
		        "enrichment_path": "165185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "165185.protein.info.v11.5.txt",
		        "node_list_path": "165185.cluster.nodes.v11.5.txt",
		        "edge_list_path": "165185.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GardnerellaVaginalis6119v5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis 6119V5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GardnerellaVaginalis6119v5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "698961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "698961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "698961.clusters.proteins.v11.5.txt",
		        "sequence_path": "698961.protein.sequences.v11.5.fa",
		        "enrichment_path": "698961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698961.protein.info.v11.5.txt",
		        "node_list_path": "698961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "698961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JeotgalibacillusMalaysiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalibacillus malaysiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalibacillusMalaysiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1508404.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1508404.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1508404.clusters.proteins.v11.5.txt",
		        "sequence_path": "1508404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1508404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1508404.protein.info.v11.5.txt",
		        "node_list_path": "1508404.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1508404.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IsoptericolaDokdonensisDs3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Isoptericola dokdonensis DS-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IsoptericolaDokdonensisDs3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1300344.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300344.protein.info.v11.5.txt",
		        "node_list_path": "1300344.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaMicans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella micans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMicans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883158.protein.sequences.v11.5.fa",
		        "enrichment_path": "883158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883158.protein.info.v11.5.txt",
		        "node_list_path": "883158.protein.complete.v11.5.txt"
		    }
		]
    )()

def HoldemanellaBiformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Holdemanella biformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoldemanellaBiformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "518637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "518637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "518637.clusters.proteins.v11.5.txt",
		        "sequence_path": "518637.protein.sequences.v11.5.fa",
		        "enrichment_path": "518637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "518637.protein.info.v11.5.txt",
		        "node_list_path": "518637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "518637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloarculaSpCba1127Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula sp. CBA1127 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaSpCba1127Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1765055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1765055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1765055.clusters.proteins.v11.5.txt",
		        "sequence_path": "1765055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765055.protein.info.v11.5.txt",
		        "node_list_path": "1765055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1765055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasCampaniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas campaniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasCampaniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "213554.protein.sequences.v11.5.fa",
		        "enrichment_path": "213554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "213554.protein.info.v11.5.txt",
		        "node_list_path": "213554.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacteriumBakii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacterium bakii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacteriumBakii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52689.protein.sequences.v11.5.fa",
		        "enrichment_path": "52689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52689.protein.info.v11.5.txt",
		        "node_list_path": "52689.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlbidovulumXiamenenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Albidovulum xiamenense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlbidovulumXiamenenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "990712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "990712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "990712.clusters.proteins.v11.5.txt",
		        "sequence_path": "990712.protein.sequences.v11.5.fa",
		        "enrichment_path": "990712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990712.protein.info.v11.5.txt",
		        "node_list_path": "990712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "990712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VulgatibacterIncomptusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vulgatibacter incomptus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulgatibacterIncomptusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1391653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1391653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1391653.clusters.proteins.v11.5.txt",
		        "sequence_path": "1391653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391653.protein.info.v11.5.txt",
		        "node_list_path": "1391653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1391653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterMallensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter mallensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterMallensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "652787.protein.sequences.v11.5.fa",
		        "enrichment_path": "652787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "652787.protein.info.v11.5.txt",
		        "node_list_path": "652787.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusCricetiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus criceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusCricetiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "873449.clusters.info.v11.5.txt",
		        "cluster_tree_path": "873449.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "873449.clusters.proteins.v11.5.txt",
		        "sequence_path": "873449.protein.sequences.v11.5.fa",
		        "enrichment_path": "873449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "873449.protein.info.v11.5.txt",
		        "node_list_path": "873449.cluster.nodes.v11.5.txt",
		        "edge_list_path": "873449.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaLoescheiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella loescheii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaLoescheiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122985.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122985.protein.info.v11.5.txt",
		        "node_list_path": "1122985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpFobrc6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. FOBRC6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpFobrc6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936572.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936572.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936572.clusters.proteins.v11.5.txt",
		        "sequence_path": "936572.protein.sequences.v11.5.fa",
		        "enrichment_path": "936572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936572.protein.info.v11.5.txt",
		        "node_list_path": "936572.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936572.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumRifcsplowo201Full4925(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFCSPLOWO2_01_FULL_49_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifcsplowo201Full4925", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797261.protein.info.v11.5.txt",
		        "node_list_path": "1797261.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4105(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC4105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4105", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217703.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217703.protein.info.v11.5.txt",
		        "node_list_path": "1217703.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpUnc267mfsha11m11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UNC267MFSha1.1M11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpUnc267mfsha11m11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502745.protein.info.v11.5.txt",
		        "node_list_path": "1502745.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwt2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwt2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896224.protein.info.v11.5.txt",
		        "node_list_path": "1896224.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho201Full4115(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_41_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4115", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798598.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798598.protein.info.v11.5.txt",
		        "node_list_path": "1798598.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonadaceaeBacteriumCg2303812(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium CG2_30_38_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonadaceaeBacteriumCg2303812", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805325.protein.info.v11.5.txt",
		        "node_list_path": "1805325.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumGbs2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium GBS-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumGbs2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1662109.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662109.protein.info.v11.5.txt",
		        "node_list_path": "1662109.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseburiaSpCag1004157Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:10041_57 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSpCag1004157Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897016.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897016.protein.info.v11.5.txt",
		        "node_list_path": "1897016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpUnc378mfCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. UNC378MF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpUnc378mfCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502748.protein.info.v11.5.txt",
		        "node_list_path": "1502748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachanceaMirantinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachancea mirantina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachanceaMirantinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230905.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230905.protein.info.v11.5.txt",
		        "node_list_path": "1230905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FervidicellaMetallireducensAeb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fervidicella metallireducens AeB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidicellaMetallireducensAeb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1403537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403537.protein.info.v11.5.txt",
		        "node_list_path": "1403537.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaApis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella apis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaApis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1686310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686310.protein.info.v11.5.txt",
		        "node_list_path": "1686310.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterOrnithocolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter ornithocola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterOrnithocolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1848766.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1848766.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1848766.clusters.proteins.v11.5.txt",
		        "sequence_path": "1848766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848766.protein.info.v11.5.txt",
		        "node_list_path": "1848766.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1848766.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidithiobacillusCaldus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus caldus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithiobacillusCaldus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "637389.protein.sequences.v11.5.fa",
		        "enrichment_path": "637389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637389.protein.info.v11.5.txt",
		        "node_list_path": "637389.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDesantisbacteriaBacteriumCg1023846(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG1_02_38_46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg1023846", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817893.protein.info.v11.5.txt",
		        "node_list_path": "1817893.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusDiolivoransDsm14421(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus diolivorans DSM 14421 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusDiolivoransDsm14421", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423739.protein.info.v11.5.txt",
		        "node_list_path": "1423739.protein.complete.v11.5.txt"
		    }
		]
    )()

def TolypothrixBouteilleiVb521301Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tolypothrix bouteillei VB521301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolypothrixBouteilleiVb521301Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1479485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1479485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1479485.clusters.proteins.v11.5.txt",
		        "sequence_path": "1479485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479485.protein.info.v11.5.txt",
		        "node_list_path": "1479485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1479485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumGelidilacusDsm15343Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium gelidilacus DSM 15343 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumGelidilacusDsm15343Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121891.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121891.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121891.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121891.protein.info.v11.5.txt",
		        "node_list_path": "1121891.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121891.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PurpureocilliumLilacinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Purpureocillium lilacinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PurpureocilliumLilacinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33203.protein.sequences.v11.5.fa",
		        "enrichment_path": "33203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33203.protein.info.v11.5.txt",
		        "node_list_path": "33203.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharothrixSpCb00851(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharothrix sp. CB00851 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharothrixSpCb00851", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1835005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1835005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1835005.protein.info.v11.5.txt",
		        "node_list_path": "1835005.protein.complete.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterNamhicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter namhicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterNamhicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "645517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "645517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "645517.clusters.proteins.v11.5.txt",
		        "sequence_path": "645517.protein.sequences.v11.5.fa",
		        "enrichment_path": "645517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645517.protein.info.v11.5.txt",
		        "node_list_path": "645517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "645517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodoferaxKoreenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodoferax koreense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodoferaxKoreenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1842727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1842727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1842727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1842727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842727.protein.info.v11.5.txt",
		        "node_list_path": "1842727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1842727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachyspiraHyodysenteriae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira hyodysenteriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraHyodysenteriae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "565034.protein.sequences.v11.5.fa",
		        "enrichment_path": "565034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565034.protein.info.v11.5.txt",
		        "node_list_path": "565034.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhyllobacteriumSpYr620(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. YR620 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhyllobacteriumSpYr620", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881066.protein.info.v11.5.txt",
		        "node_list_path": "1881066.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumRbg164410(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_44_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg164410", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802597.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802597.protein.info.v11.5.txt",
		        "node_list_path": "1802597.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizoclosmatiumGlobosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizoclosmatium globosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizoclosmatiumGlobosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "329046.protein.sequences.v11.5.fa",
		        "enrichment_path": "329046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "329046.protein.info.v11.5.txt",
		        "node_list_path": "329046.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterRadioresistens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter radioresistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterRadioresistens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575589.protein.sequences.v11.5.fa",
		        "enrichment_path": "575589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575589.protein.info.v11.5.txt",
		        "node_list_path": "575589.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfatiglansAniliniDsm4660(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfatiglans anilini DSM 4660 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfatiglansAniliniDsm4660", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121399.protein.info.v11.5.txt",
		        "node_list_path": "1121399.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusDelbrueckiiAtcc11842Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii ATCC11842 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusDelbrueckiiAtcc11842Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "390333.clusters.info.v11.0.txt",
		        "cluster_tree_path": "390333.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "390333.clusters.proteins.v11.0.txt",
		        "sequence_path": "390333.protein.sequences.v11.0.fa",
		        "enrichment_path": "390333.protein.enrichment.terms.v11.0.txt",
		        "info_path": "390333.protein.info.v11.0.txt",
		        "node_list_path": "390333.cluster.nodes.v11.0.txt",
		        "edge_list_path": "390333.protein.cluster.v11.0.txt"
		    }
		]
    )()

def NitrosomonasMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "917.protein.sequences.v11.5.fa",
		        "enrichment_path": "917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "917.protein.info.v11.5.txt",
		        "node_list_path": "917.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfuribacillusAlkaliarsenatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfuribacillus alkaliarsenatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuribacillusAlkaliarsenatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "766136.protein.sequences.v11.5.fa",
		        "enrichment_path": "766136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "766136.protein.info.v11.5.txt",
		        "node_list_path": "766136.protein.complete.v11.5.txt"
		    }
		]
    )()

def BotryotiniaCalthae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Botryotinia calthae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotryotiniaCalthae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "38488.protein.sequences.v11.5.fa",
		        "enrichment_path": "38488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38488.protein.info.v11.5.txt",
		        "node_list_path": "38488.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTaa040(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA040 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTaa040", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288083.protein.info.v11.5.txt",
		        "node_list_path": "1288083.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaAurantiaca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaAurantiaca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236508.protein.info.v11.5.txt",
		        "node_list_path": "1236508.protein.complete.v11.5.txt"
		    }
		]
    )()

def AuriculariopsisAmplaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Auriculariopsis ampla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AuriculariopsisAmplaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "97359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "97359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "97359.clusters.proteins.v11.5.txt",
		        "sequence_path": "97359.protein.sequences.v11.5.fa",
		        "enrichment_path": "97359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97359.protein.info.v11.5.txt",
		        "node_list_path": "97359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "97359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumSpZwu0011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium sp. ZWU0011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumSpZwu0011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1339243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1339243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1339243.clusters.proteins.v11.5.txt",
		        "sequence_path": "1339243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1339243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1339243.protein.info.v11.5.txt",
		        "node_list_path": "1339243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1339243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminiclostridiumHungateiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminiclostridium hungatei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminiclostridiumHungateiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "48256.clusters.info.v11.5.txt",
		        "cluster_tree_path": "48256.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "48256.clusters.proteins.v11.5.txt",
		        "sequence_path": "48256.protein.sequences.v11.5.fa",
		        "enrichment_path": "48256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48256.protein.info.v11.5.txt",
		        "node_list_path": "48256.cluster.nodes.v11.5.txt",
		        "edge_list_path": "48256.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IntrasporangiumOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Intrasporangium oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntrasporangiumOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1386089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1386089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1386089.clusters.proteins.v11.5.txt",
		        "sequence_path": "1386089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1386089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1386089.protein.info.v11.5.txt",
		        "node_list_path": "1386089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1386089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CylindrospermopsisRaciborskiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cylindrospermopsis raciborskii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CylindrospermopsisRaciborskiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "533240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "533240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "533240.clusters.proteins.v11.5.txt",
		        "sequence_path": "533240.protein.sequences.v11.5.fa",
		        "enrichment_path": "533240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "533240.protein.info.v11.5.txt",
		        "node_list_path": "533240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "533240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AbsidiaGlaucaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Absidia glauca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AbsidiaGlaucaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4829.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4829.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4829.clusters.proteins.v11.5.txt",
		        "sequence_path": "4829.protein.sequences.v11.5.fa",
		        "enrichment_path": "4829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4829.protein.info.v11.5.txt",
		        "node_list_path": "4829.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4829.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyclobacteriumQasimiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacterium qasimii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyclobacteriumQasimiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641524.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641524.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641524.clusters.proteins.v11.5.txt",
		        "sequence_path": "641524.protein.sequences.v11.5.fa",
		        "enrichment_path": "641524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641524.protein.info.v11.5.txt",
		        "node_list_path": "641524.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641524.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0337Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0337 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0337Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "706439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "706439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "706439.clusters.proteins.v11.5.txt",
		        "sequence_path": "706439.protein.sequences.v11.5.fa",
		        "enrichment_path": "706439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706439.protein.info.v11.5.txt",
		        "node_list_path": "706439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "706439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumGwf24352Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWF2_43_52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumGwf24352Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801847.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801847.protein.info.v11.5.txt",
		        "node_list_path": "1801847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifoxyb2Full3713Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFOXYB2_FULL_37_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2Full3713Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802579.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802579.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802579.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802579.protein.info.v11.5.txt",
		        "node_list_path": "1802579.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802579.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacteraceaeBacteriumCg1023614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacteraceae bacterium CG1_02_36_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacteraceaeBacteriumCg1023614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805214.protein.info.v11.5.txt",
		        "node_list_path": "1805214.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpOrs3428Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3428 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpOrs3428Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "540997.clusters.info.v11.5.txt",
		        "cluster_tree_path": "540997.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "540997.clusters.proteins.v11.5.txt",
		        "sequence_path": "540997.protein.sequences.v11.5.fa",
		        "enrichment_path": "540997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "540997.protein.info.v11.5.txt",
		        "node_list_path": "540997.cluster.nodes.v11.5.txt",
		        "edge_list_path": "540997.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrococcalesBacterium7064(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 70-64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcalesBacterium7064", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895789.protein.info.v11.5.txt",
		        "node_list_path": "1895789.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusTurcosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus turcosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusTurcosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1245748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1245748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1245748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1245748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245748.protein.info.v11.5.txt",
		        "node_list_path": "1245748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1245748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpAtexabd23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. ATexABD23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpAtexabd23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157635.protein.info.v11.5.txt",
		        "node_list_path": "1157635.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetschnikowiaAffPulcherrima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metschnikowia aff. pulcherrima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetschnikowiaAffPulcherrima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2163413.protein.sequences.v11.5.fa",
		        "enrichment_path": "2163413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2163413.protein.info.v11.5.txt",
		        "node_list_path": "2163413.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCoelicolorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces coelicolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCoelicolorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "100226.clusters.info.v11.5.txt",
		        "cluster_tree_path": "100226.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "100226.clusters.proteins.v11.5.txt",
		        "sequence_path": "100226.protein.sequences.v11.5.fa",
		        "enrichment_path": "100226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "100226.protein.info.v11.5.txt",
		        "node_list_path": "100226.cluster.nodes.v11.5.txt",
		        "edge_list_path": "100226.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "574651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "574651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "574651.clusters.proteins.v11.5.txt",
		        "sequence_path": "574651.protein.sequences.v11.5.fa",
		        "enrichment_path": "574651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574651.protein.info.v11.5.txt",
		        "node_list_path": "574651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "574651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_34_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618477.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618477.protein.info.v11.5.txt",
		        "node_list_path": "1618477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumCch11D2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium CCH11-D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumCch11D2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1768801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1768801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1768801.clusters.proteins.v11.5.txt",
		        "sequence_path": "1768801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768801.protein.info.v11.5.txt",
		        "node_list_path": "1768801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1768801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CordycepsConfragosaRcef1005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps confragosa RCEF 1005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CordycepsConfragosaRcef1005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1081108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081108.protein.info.v11.5.txt",
		        "node_list_path": "1081108.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumUasb340(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium UASB340 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumUasb340", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1655310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655310.protein.info.v11.5.txt",
		        "node_list_path": "1655310.protein.complete.v11.5.txt"
		    }
		]
    )()

def AccipiterNisus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Accipiter nisus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AccipiterNisus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "211598.protein.sequences.v11.5.fa",
		        "enrichment_path": "211598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211598.protein.info.v11.5.txt",
		        "node_list_path": "211598.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinivibrioSharmensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio sharmensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivibrioSharmensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "390883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "390883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "390883.clusters.proteins.v11.5.txt",
		        "sequence_path": "390883.protein.sequences.v11.5.fa",
		        "enrichment_path": "390883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390883.protein.info.v11.5.txt",
		        "node_list_path": "390883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "390883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanomethylicusOleusabulum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomethylicus oleusabulum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanomethylicusOleusabulum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1867260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1867260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1867260.protein.info.v11.5.txt",
		        "node_list_path": "1867260.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenolepisDiminuta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenolepis diminuta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenolepisDiminuta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6216.protein.sequences.v11.5.fa",
		        "enrichment_path": "6216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6216.protein.info.v11.5.txt",
		        "node_list_path": "6216.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterNyackensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter nyackensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterNyackensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "475255.protein.sequences.v11.5.fa",
		        "enrichment_path": "475255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "475255.protein.info.v11.5.txt",
		        "node_list_path": "475255.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpErgs101(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ERGS1:01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpErgs101", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1704044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1704044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1704044.protein.info.v11.5.txt",
		        "node_list_path": "1704044.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSp112Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 1_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSp112Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566278.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566278.protein.info.v11.5.txt",
		        "node_list_path": "1566278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusMelliventrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus melliventris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMelliventrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218507.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218507.protein.info.v11.5.txt",
		        "node_list_path": "1218507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobisporaSpGmku363Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbispora sp. GMKU363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobisporaSpGmku363Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "718014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "718014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "718014.clusters.proteins.v11.5.txt",
		        "sequence_path": "718014.protein.sequences.v11.5.fa",
		        "enrichment_path": "718014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "718014.protein.info.v11.5.txt",
		        "node_list_path": "718014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "718014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidothermusCellulolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidothermus cellulolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidothermusCellulolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351607.protein.sequences.v11.5.fa",
		        "enrichment_path": "351607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351607.protein.info.v11.5.txt",
		        "node_list_path": "351607.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisPotensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis potens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisPotensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "570268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "570268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "570268.clusters.proteins.v11.5.txt",
		        "sequence_path": "570268.protein.sequences.v11.5.fa",
		        "enrichment_path": "570268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570268.protein.info.v11.5.txt",
		        "node_list_path": "570268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "570268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterHepaticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter hepaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterHepaticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1813019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1813019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1813019.clusters.proteins.v11.5.txt",
		        "sequence_path": "1813019.protein.sequences.v11.5.fa",
		        "enrichment_path": "1813019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1813019.protein.info.v11.5.txt",
		        "node_list_path": "1813019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1813019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumAcnesKpa171202Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes KPA171202 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumAcnesKpa171202Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "267747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "267747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "267747.clusters.proteins.v11.5.txt",
		        "sequence_path": "267747.protein.sequences.v11.5.fa",
		        "enrichment_path": "267747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267747.protein.info.v11.5.txt",
		        "node_list_path": "267747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "267747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpNk3a76(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. NK3A76 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpNk3a76", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "877411.protein.sequences.v11.5.fa",
		        "enrichment_path": "877411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877411.protein.info.v11.5.txt",
		        "node_list_path": "877411.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaHelvetica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia helvetica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaHelvetica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144888.protein.info.v11.5.txt",
		        "node_list_path": "1144888.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoriobacteriaceaeBacteriumBv3ac1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium BV3Ac1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacteriaceaeBacteriumBv3ac1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111135.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111135.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111135.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111135.protein.info.v11.5.txt",
		        "node_list_path": "1111135.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111135.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaSpAna3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. ANA3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSpAna3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "94122.protein.sequences.v11.5.fa",
		        "enrichment_path": "94122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94122.protein.info.v11.5.txt",
		        "node_list_path": "94122.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpPcc6312(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC6312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpPcc6312", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "195253.protein.sequences.v11.5.fa",
		        "enrichment_path": "195253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195253.protein.info.v11.5.txt",
		        "node_list_path": "195253.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocFallax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc fallax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocFallax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "907931.protein.sequences.v11.5.fa",
		        "enrichment_path": "907931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "907931.protein.info.v11.5.txt",
		        "node_list_path": "907931.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotaleaMetallivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermotalea metallivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotaleaMetallivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "520762.protein.sequences.v11.5.fa",
		        "enrichment_path": "520762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "520762.protein.info.v11.5.txt",
		        "node_list_path": "520762.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumPseudolongumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumPseudolongumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "31954.clusters.info.v11.5.txt",
		        "cluster_tree_path": "31954.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "31954.clusters.proteins.v11.5.txt",
		        "sequence_path": "31954.protein.sequences.v11.5.fa",
		        "enrichment_path": "31954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31954.protein.info.v11.5.txt",
		        "node_list_path": "31954.cluster.nodes.v11.5.txt",
		        "edge_list_path": "31954.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAbietaniphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas abietaniphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAbietaniphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "89065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "89065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "89065.clusters.proteins.v11.5.txt",
		        "sequence_path": "89065.protein.sequences.v11.5.fa",
		        "enrichment_path": "89065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89065.protein.info.v11.5.txt",
		        "node_list_path": "89065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "89065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EdaphobacillusLindanitolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Edaphobacillus lindanitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EdaphobacillusLindanitolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "550447.protein.sequences.v11.5.fa",
		        "enrichment_path": "550447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "550447.protein.info.v11.5.txt",
		        "node_list_path": "550447.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaParapsilosisCdc317Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida parapsilosis CDC317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaParapsilosisCdc317Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "578454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "578454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "578454.clusters.proteins.v11.5.txt",
		        "sequence_path": "578454.protein.sequences.v11.5.fa",
		        "enrichment_path": "578454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578454.protein.info.v11.5.txt",
		        "node_list_path": "578454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "578454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1640685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1640685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1640685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1640685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640685.protein.info.v11.5.txt",
		        "node_list_path": "1640685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1640685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalogeometricumLimiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halogeometricum limi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalogeometricumLimiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "555875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "555875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "555875.clusters.proteins.v11.5.txt",
		        "sequence_path": "555875.protein.sequences.v11.5.fa",
		        "enrichment_path": "555875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555875.protein.info.v11.5.txt",
		        "node_list_path": "555875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "555875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JannaschiaSpCcs1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia sp. CCS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaSpCcs1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290400.clusters.proteins.v11.5.txt",
		        "sequence_path": "290400.protein.sequences.v11.5.fa",
		        "enrichment_path": "290400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290400.protein.info.v11.5.txt",
		        "node_list_path": "290400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumSpCag439(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium sp. CAG:439 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumSpCag439", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262899.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262899.protein.info.v11.5.txt",
		        "node_list_path": "1262899.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumGlycines(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium glycines graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumGlycines", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "551990.protein.sequences.v11.5.fa",
		        "enrichment_path": "551990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551990.protein.info.v11.5.txt",
		        "node_list_path": "551990.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacteriumMelA1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium MEL.A1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacteriumMelA1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1899017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1899017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1899017.protein.info.v11.5.txt",
		        "node_list_path": "1899017.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumUreilyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium ureilyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumUreilyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "373668.protein.sequences.v11.5.fa",
		        "enrichment_path": "373668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "373668.protein.info.v11.5.txt",
		        "node_list_path": "373668.protein.complete.v11.5.txt"
		    }
		]
    )()

def FaecalicoccusPleomorphus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Faecalicoccus pleomorphus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalicoccusPleomorphus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123313.protein.info.v11.5.txt",
		        "node_list_path": "1123313.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumTrichothecenolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium trichothecenolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumTrichothecenolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69370.protein.sequences.v11.5.fa",
		        "enrichment_path": "69370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69370.protein.info.v11.5.txt",
		        "node_list_path": "69370.protein.complete.v11.5.txt"
		    }
		]
    )()

def TyzzerellaNexilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tyzzerella nexilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TyzzerellaNexilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "500632.protein.sequences.v11.5.fa",
		        "enrichment_path": "500632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500632.protein.info.v11.5.txt",
		        "node_list_path": "500632.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusIbericusCbs121593(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ibericus CBS 121593 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusIbericusCbs121593", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1448316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448316.protein.info.v11.5.txt",
		        "node_list_path": "1448316.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusThermoamylovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus thermoamylovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusThermoamylovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35841.protein.sequences.v11.5.fa",
		        "enrichment_path": "35841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35841.protein.info.v11.5.txt",
		        "node_list_path": "35841.protein.complete.v11.5.txt"
		    }
		]
    )()

def OttowiaSpOralTaxon894Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ottowia sp. oral taxon 894 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OttowiaSpOralTaxon894Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658672.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658672.protein.info.v11.5.txt",
		        "node_list_path": "1658672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JiulongibacterSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jiulongibacter sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JiulongibacterSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1605367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1605367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1605367.clusters.proteins.v11.5.txt",
		        "sequence_path": "1605367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1605367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1605367.protein.info.v11.5.txt",
		        "node_list_path": "1605367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1605367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GigasporaRosea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gigaspora rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GigasporaRosea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44941.protein.sequences.v11.5.fa",
		        "enrichment_path": "44941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44941.protein.info.v11.5.txt",
		        "node_list_path": "44941.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaeromycesRobustus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaeromyces robustus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeromycesRobustus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1754192.protein.sequences.v11.5.fa",
		        "enrichment_path": "1754192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1754192.protein.info.v11.5.txt",
		        "node_list_path": "1754192.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusVeneficusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus veneficus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusVeneficusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "693661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "693661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "693661.clusters.proteins.v11.5.txt",
		        "sequence_path": "693661.protein.sequences.v11.5.fa",
		        "enrichment_path": "693661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693661.protein.info.v11.5.txt",
		        "node_list_path": "693661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "693661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesMobaraensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces mobaraensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesMobaraensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223523.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223523.protein.info.v11.5.txt",
		        "node_list_path": "1223523.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobiumSpKb01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium sp. KB01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumSpKb01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1917528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917528.protein.info.v11.5.txt",
		        "node_list_path": "1917528.protein.complete.v11.5.txt"
		    }
		]
    )()

def VicugnaPacos(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vicugna pacos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VicugnaPacos", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "30538.protein.sequences.v11.5.fa",
		        "enrichment_path": "30538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30538.protein.info.v11.5.txt",
		        "node_list_path": "30538.protein.complete.v11.5.txt"
		    }
		]
    )()

def BariatricusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bariatricus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BariatricusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1745713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1745713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1745713.protein.info.v11.5.txt",
		        "node_list_path": "1745713.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosocosmicusExaquare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosocosmicus exaquare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosocosmicusExaquare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1826872.protein.sequences.v11.5.fa",
		        "enrichment_path": "1826872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1826872.protein.info.v11.5.txt",
		        "node_list_path": "1826872.protein.complete.v11.5.txt"
		    }
		]
    )()

def RalstoniaEutrophaJmp134Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia eutropha JMP134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaEutrophaJmp134Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264198.clusters.proteins.v11.5.txt",
		        "sequence_path": "264198.protein.sequences.v11.5.fa",
		        "enrichment_path": "264198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264198.protein.info.v11.5.txt",
		        "node_list_path": "264198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg135819Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_58_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg135819Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797832.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797832.protein.info.v11.5.txt",
		        "node_list_path": "1797832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpKh1p2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. kh1p2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpKh1p2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761883.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761883.protein.info.v11.5.txt",
		        "node_list_path": "1761883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudaminobacterManganicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudaminobacter manganicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudaminobacterManganicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1873176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1873176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1873176.clusters.proteins.v11.5.txt",
		        "sequence_path": "1873176.protein.sequences.v11.5.fa",
		        "enrichment_path": "1873176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1873176.protein.info.v11.5.txt",
		        "node_list_path": "1873176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1873176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumScgcAaa300K03Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium SCGC AAA300-K03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumScgcAaa300K03Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "939909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "939909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "939909.clusters.proteins.v11.5.txt",
		        "sequence_path": "939909.protein.sequences.v11.5.fa",
		        "enrichment_path": "939909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939909.protein.info.v11.5.txt",
		        "node_list_path": "939909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "939909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag180(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:180 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag180", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262882.protein.info.v11.5.txt",
		        "node_list_path": "1262882.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanotheceSpPcc8801Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC8801 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanotheceSpPcc8801Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "41431.clusters.info.v11.5.txt",
		        "cluster_tree_path": "41431.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "41431.clusters.proteins.v11.5.txt",
		        "sequence_path": "41431.protein.sequences.v11.5.fa",
		        "enrichment_path": "41431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41431.protein.info.v11.5.txt",
		        "node_list_path": "41431.cluster.nodes.v11.5.txt",
		        "edge_list_path": "41431.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrrhodermaNoxiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrrhoderma noxium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrrhodermaNoxiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2282107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2282107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2282107.clusters.proteins.v11.5.txt",
		        "sequence_path": "2282107.protein.sequences.v11.5.fa",
		        "enrichment_path": "2282107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2282107.protein.info.v11.5.txt",
		        "node_list_path": "2282107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2282107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MongoliimonasTerrestris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mongoliimonas terrestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MongoliimonasTerrestris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1709001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1709001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1709001.protein.info.v11.5.txt",
		        "node_list_path": "1709001.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaSpCag105(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dorea sp. CAG:105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaSpCag105", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262872.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262872.protein.info.v11.5.txt",
		        "node_list_path": "1262872.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobacterSpOv335Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobacter sp. OV335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobacterSpOv335Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500264.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500264.protein.info.v11.5.txt",
		        "node_list_path": "1500264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterPontiacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter pontiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterPontiacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "60137.protein.sequences.v11.5.fa",
		        "enrichment_path": "60137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60137.protein.info.v11.5.txt",
		        "node_list_path": "60137.protein.complete.v11.5.txt"
		    }
		]
    )()

def DanionellaTranslucida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Danionella translucida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DanionellaTranslucida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "623744.protein.sequences.v11.5.fa",
		        "enrichment_path": "623744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "623744.protein.info.v11.5.txt",
		        "node_list_path": "623744.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpIcm47(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. ICM47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpIcm47", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936548.protein.sequences.v11.5.fa",
		        "enrichment_path": "936548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936548.protein.info.v11.5.txt",
		        "node_list_path": "936548.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesBicolorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces bicolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesBicolorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66874.clusters.proteins.v11.5.txt",
		        "sequence_path": "66874.protein.sequences.v11.5.fa",
		        "enrichment_path": "66874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66874.protein.info.v11.5.txt",
		        "node_list_path": "66874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpOk048Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. OK048 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpOk048Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882761.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882761.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882761.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882761.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882761.protein.info.v11.5.txt",
		        "node_list_path": "1882761.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882761.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseorubiginosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseorubiginosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseorubiginosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67304.clusters.proteins.v11.5.txt",
		        "sequence_path": "67304.protein.sequences.v11.5.fa",
		        "enrichment_path": "67304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67304.protein.info.v11.5.txt",
		        "node_list_path": "67304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellvibrioSpPealriverCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio sp. pealriver Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioSpPealriverCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1622269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1622269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1622269.clusters.proteins.v11.5.txt",
		        "sequence_path": "1622269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622269.protein.info.v11.5.txt",
		        "node_list_path": "1622269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1622269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusSp10a9Div0425(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sp. 10A9_DIV0425 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSp10a9Div0425", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1987383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1987383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1987383.protein.info.v11.5.txt",
		        "node_list_path": "1987383.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpWchac010034(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. WCHAc010034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpWchac010034", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1879049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1879049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1879049.protein.info.v11.5.txt",
		        "node_list_path": "1879049.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylococcusCapsulatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylococcus capsulatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylococcusCapsulatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243233.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243233.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243233.clusters.proteins.v11.5.txt",
		        "sequence_path": "243233.protein.sequences.v11.5.fa",
		        "enrichment_path": "243233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243233.protein.info.v11.5.txt",
		        "node_list_path": "243233.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243233.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaMoravicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella moravica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaMoravicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122165.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122165.protein.info.v11.5.txt",
		        "node_list_path": "1122165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzotobacterBeijerinckiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azotobacter beijerinckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzotobacterBeijerinckiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "170623.clusters.info.v11.5.txt",
		        "cluster_tree_path": "170623.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "170623.clusters.proteins.v11.5.txt",
		        "sequence_path": "170623.protein.sequences.v11.5.fa",
		        "enrichment_path": "170623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "170623.protein.info.v11.5.txt",
		        "node_list_path": "170623.cluster.nodes.v11.5.txt",
		        "edge_list_path": "170623.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27225Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27225 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27225Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1743144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1743144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1743144.clusters.proteins.v11.5.txt",
		        "sequence_path": "1743144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743144.protein.info.v11.5.txt",
		        "node_list_path": "1743144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1743144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesAlbimanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles albimanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesAlbimanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7167.protein.sequences.v11.5.fa",
		        "enrichment_path": "7167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7167.protein.info.v11.5.txt",
		        "node_list_path": "7167.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpEc33(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ec33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpEc33", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "189753.protein.sequences.v11.5.fa",
		        "enrichment_path": "189753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189753.protein.info.v11.5.txt",
		        "node_list_path": "189753.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumFructicolaNaraGc5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum fructicola Nara gc5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumFructicolaNaraGc5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1213859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1213859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1213859.clusters.proteins.v11.5.txt",
		        "sequence_path": "1213859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1213859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1213859.protein.info.v11.5.txt",
		        "node_list_path": "1213859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1213859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitratiruptorSpSb1552(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitratiruptor sp. SB1552 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratiruptorSpSb1552", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "387092.protein.sequences.v11.5.fa",
		        "enrichment_path": "387092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "387092.protein.info.v11.5.txt",
		        "node_list_path": "387092.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpTb64Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. TB64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpTb64Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1938600.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1938600.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1938600.clusters.proteins.v11.5.txt",
		        "sequence_path": "1938600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938600.protein.info.v11.5.txt",
		        "node_list_path": "1938600.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1938600.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynergistalesBacterium5881Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synergistales bacterium 58_81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynergistalesBacterium5881Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635274.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635274.protein.info.v11.5.txt",
		        "node_list_path": "1635274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MotiliproteusSpMsk221(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Motiliproteus sp. MSK22-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MotiliproteusSpMsk221", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897630.protein.info.v11.5.txt",
		        "node_list_path": "1897630.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterJunii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter junii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterJunii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40215.protein.sequences.v11.5.fa",
		        "enrichment_path": "40215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40215.protein.info.v11.5.txt",
		        "node_list_path": "40215.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioDesulfuricansAtcc27774(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans ATCC27774 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioDesulfuricansAtcc27774", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525146.protein.sequences.v11.5.fa",
		        "enrichment_path": "525146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525146.protein.info.v11.5.txt",
		        "node_list_path": "525146.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioJasicidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio jasicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioJasicidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280001.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280001.protein.info.v11.5.txt",
		        "node_list_path": "1280001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumSpAgr2158Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. AGR2158 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumSpAgr2158Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280675.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280675.protein.info.v11.5.txt",
		        "node_list_path": "1280675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NaumovozymaCastellii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma castellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NaumovozymaCastellii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "27288.protein.sequences.v11.5.fa",
		        "enrichment_path": "27288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27288.protein.info.v11.5.txt",
		        "node_list_path": "27288.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumUndae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium undae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumUndae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397693.protein.info.v11.5.txt",
		        "node_list_path": "1397693.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division ZIXI graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379698.protein.info.v11.5.txt",
		        "node_list_path": "1379698.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomassariellaVexataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomassariella vexata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomassariellaVexataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1141098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1141098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1141098.clusters.proteins.v11.5.txt",
		        "sequence_path": "1141098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141098.protein.info.v11.5.txt",
		        "node_list_path": "1141098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1141098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeleagrisGallopavoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meleagris gallopavo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeleagrisGallopavoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9103.clusters.proteins.v11.5.txt",
		        "sequence_path": "9103.protein.sequences.v11.5.fa",
		        "enrichment_path": "9103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9103.protein.info.v11.5.txt",
		        "node_list_path": "9103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProsthecochlorisSpCib2401Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prosthecochloris sp. CIB 2401 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProsthecochlorisSpCib2401Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1868325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1868325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1868325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1868325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1868325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1868325.protein.info.v11.5.txt",
		        "node_list_path": "1868325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1868325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4122(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_41_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4122", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802067.protein.info.v11.5.txt",
		        "node_list_path": "1802067.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonBa2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon BA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonBa2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1700836.protein.sequences.v11.5.fa",
		        "enrichment_path": "1700836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1700836.protein.info.v11.5.txt",
		        "node_list_path": "1700836.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSymbiosumWal14673(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium symbiosum WAL14673 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSymbiosumWal14673", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742741.protein.sequences.v11.5.fa",
		        "enrichment_path": "742741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742741.protein.info.v11.5.txt",
		        "node_list_path": "742741.protein.complete.v11.5.txt"
		    }
		]
    )()

def WilliamsiaSterculiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Williamsia sterculiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WilliamsiaSterculiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1344003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1344003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1344003.protein.info.v11.5.txt",
		        "node_list_path": "1344003.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioAerogenesCect7868Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio aerogenes CECT 7868 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioAerogenesCect7868Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216006.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216006.protein.info.v11.5.txt",
		        "node_list_path": "1216006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CutibacteriumAvidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cutibacterium avidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CutibacteriumAvidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33010.clusters.proteins.v11.5.txt",
		        "sequence_path": "33010.protein.sequences.v11.5.fa",
		        "enrichment_path": "33010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33010.protein.info.v11.5.txt",
		        "node_list_path": "33010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SuccinatimonasSpCag777Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Succinatimonas sp. CAG:777 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuccinatimonasSpCag777Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262974.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262974.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262974.protein.info.v11.5.txt",
		        "node_list_path": "1262974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumStriatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium striatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumStriatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525268.clusters.proteins.v11.5.txt",
		        "sequence_path": "525268.protein.sequences.v11.5.fa",
		        "enrichment_path": "525268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525268.protein.info.v11.5.txt",
		        "node_list_path": "525268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZunongwangiaMangrovi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zunongwangia mangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZunongwangiaMangrovi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1334022.protein.sequences.v11.5.fa",
		        "enrichment_path": "1334022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1334022.protein.info.v11.5.txt",
		        "node_list_path": "1334022.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusUrinalis228597(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus urinalis 228597 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusUrinalis228597", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "764291.protein.sequences.v11.5.fa",
		        "enrichment_path": "764291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "764291.protein.info.v11.5.txt",
		        "node_list_path": "764291.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumBrasilianumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium brasilianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumBrasilianumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "104259.clusters.info.v11.5.txt",
		        "cluster_tree_path": "104259.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "104259.clusters.proteins.v11.5.txt",
		        "sequence_path": "104259.protein.sequences.v11.5.fa",
		        "enrichment_path": "104259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104259.protein.info.v11.5.txt",
		        "node_list_path": "104259.cluster.nodes.v11.5.txt",
		        "edge_list_path": "104259.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumScrofulaceumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium scrofulaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumScrofulaceumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1783.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1783.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1783.clusters.proteins.v11.5.txt",
		        "sequence_path": "1783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1783.protein.info.v11.5.txt",
		        "node_list_path": "1783.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1783.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaVinsoniiBerkhoffiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella vinsonii berkhoffii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaVinsoniiBerkhoffiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094497.protein.info.v11.5.txt",
		        "node_list_path": "1094497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterLudwigii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter ludwigii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterLudwigii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "299767.protein.sequences.v11.5.fa",
		        "enrichment_path": "299767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299767.protein.info.v11.5.txt",
		        "node_list_path": "299767.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumRifcsplowo212Full3515(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RIFCSPLOWO2_12_FULL_35_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumRifcsplowo212Full3515", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797364.protein.info.v11.5.txt",
		        "node_list_path": "1797364.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag38(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag38", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262889.protein.info.v11.5.txt",
		        "node_list_path": "1262889.protein.complete.v11.5.txt"
		    }
		]
    )()

def BaumanniaCicadellinicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Baumannia cicadellinicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BaumanniaCicadellinicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "186490.protein.sequences.v11.5.fa",
		        "enrichment_path": "186490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "186490.protein.info.v11.5.txt",
		        "node_list_path": "186490.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacteriumSpCba1132(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium sp. CBA1132 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacteriumSpCba1132", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1765057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765057.protein.info.v11.5.txt",
		        "node_list_path": "1765057.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPunonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas punonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPunonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220495.protein.info.v11.5.txt",
		        "node_list_path": "1220495.protein.complete.v11.5.txt"
		    }
		]
    )()

def ManacusVitellinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Manacus vitellinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ManacusVitellinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "328815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "328815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "328815.clusters.proteins.v11.5.txt",
		        "sequence_path": "328815.protein.sequences.v11.5.fa",
		        "enrichment_path": "328815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "328815.protein.info.v11.5.txt",
		        "node_list_path": "328815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "328815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanithermusProfundus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanithermus profundus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanithermusProfundus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "670487.protein.sequences.v11.5.fa",
		        "enrichment_path": "670487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670487.protein.info.v11.5.txt",
		        "node_list_path": "670487.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpVer3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. Ver3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpVer3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "466088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "466088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "466088.clusters.proteins.v11.5.txt",
		        "sequence_path": "466088.protein.sequences.v11.5.fa",
		        "enrichment_path": "466088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "466088.protein.info.v11.5.txt",
		        "node_list_path": "466088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "466088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TheileriaParva(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Theileria parva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheileriaParva", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5875.protein.sequences.v11.5.fa",
		        "enrichment_path": "5875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5875.protein.info.v11.5.txt",
		        "node_list_path": "5875.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeomonachusSchauinslandiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neomonachus schauinslandi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeomonachusSchauinslandiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29088.clusters.proteins.v11.5.txt",
		        "sequence_path": "29088.protein.sequences.v11.5.fa",
		        "enrichment_path": "29088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29088.protein.info.v11.5.txt",
		        "node_list_path": "29088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaSpLeaf50Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. Leaf50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpLeaf50Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736223.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736223.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736223.protein.info.v11.5.txt",
		        "node_list_path": "1736223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusLacrimalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus lacrimalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusLacrimalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596330.protein.sequences.v11.5.fa",
		        "enrichment_path": "596330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596330.protein.info.v11.5.txt",
		        "node_list_path": "596330.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumRedseaS02B3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium REDSEA-S02_B3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumRedseaS02B3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811619.protein.info.v11.5.txt",
		        "node_list_path": "1811619.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpGa0074129Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Ga0074129 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpGa0074129Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752219.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752219.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752219.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752219.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752219.protein.info.v11.5.txt",
		        "node_list_path": "1752219.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752219.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SubdoligranulumSp4354a2faaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Subdoligranulum sp. 4354A2FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SubdoligranulumSp4354a2faaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665956.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665956.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665956.clusters.proteins.v11.5.txt",
		        "sequence_path": "665956.protein.sequences.v11.5.fa",
		        "enrichment_path": "665956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665956.protein.info.v11.5.txt",
		        "node_list_path": "665956.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665956.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpNs7484(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. NS-7484 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpNs7484", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834161.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834161.protein.info.v11.5.txt",
		        "node_list_path": "1834161.protein.complete.v11.5.txt"
		    }
		]
    )()

def MerdimonasFaecis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Merdimonas faecis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MerdimonasFaecis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1653435.protein.sequences.v11.5.fa",
		        "enrichment_path": "1653435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1653435.protein.info.v11.5.txt",
		        "node_list_path": "1653435.protein.complete.v11.5.txt"
		    }
		]
    )()

def StrigamiaMaritimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Strigamia maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrigamiaMaritimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "126957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "126957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "126957.clusters.proteins.v11.5.txt",
		        "sequence_path": "126957.protein.sequences.v11.5.fa",
		        "enrichment_path": "126957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "126957.protein.info.v11.5.txt",
		        "node_list_path": "126957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "126957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpadixCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas spadix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpadixCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1045855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1045855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1045855.clusters.proteins.v11.5.txt",
		        "sequence_path": "1045855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045855.protein.info.v11.5.txt",
		        "node_list_path": "1045855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1045855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc034a01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC034A01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc034a01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739295.protein.info.v11.5.txt",
		        "node_list_path": "1739295.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonadaceaeBacteriumUrha0028Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium URHA0028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonadaceaeBacteriumUrha0028Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298913.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298913.protein.info.v11.5.txt",
		        "node_list_path": "1298913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmanitaThiersiiSkay4041Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amanita thiersii Skay4041 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmanitaThiersiiSkay4041Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "703135.clusters.info.v11.5.txt",
		        "cluster_tree_path": "703135.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "703135.clusters.proteins.v11.5.txt",
		        "sequence_path": "703135.protein.sequences.v11.5.fa",
		        "enrichment_path": "703135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "703135.protein.info.v11.5.txt",
		        "node_list_path": "703135.cluster.nodes.v11.5.txt",
		        "edge_list_path": "703135.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprobacillusSp8254bfaaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus sp. 8_2_54BFAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprobacillusSp8254bfaaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469597.clusters.proteins.v11.5.txt",
		        "sequence_path": "469597.protein.sequences.v11.5.fa",
		        "enrichment_path": "469597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469597.protein.info.v11.5.txt",
		        "node_list_path": "469597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterovibrioCalviensisDsm14347(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio calviensis DSM 14347 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioCalviensisDsm14347", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121867.protein.info.v11.5.txt",
		        "node_list_path": "1121867.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinibacillusKushneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinibacillus kushneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinibacillusKushneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "237682.protein.sequences.v11.5.fa",
		        "enrichment_path": "237682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237682.protein.info.v11.5.txt",
		        "node_list_path": "237682.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinarchaeumSpHarchtbsk1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinarchaeum sp. HarchtBsk1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinarchaeumSpHarchtbsk1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1333523.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333523.protein.info.v11.5.txt",
		        "node_list_path": "1333523.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpRu33cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. RU33C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpRu33cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907398.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907398.protein.info.v11.5.txt",
		        "node_list_path": "1907398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSp6610(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 66-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSp6610", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895848.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895848.protein.info.v11.5.txt",
		        "node_list_path": "1895848.protein.complete.v11.5.txt"
		    }
		]
    )()

def JeongeupiaSpUsm3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jeongeupia sp. USM3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeongeupiaSpUsm3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906741.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906741.protein.info.v11.5.txt",
		        "node_list_path": "1906741.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpUrha0041(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. URHA0041 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpUrha0041", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380346.protein.info.v11.5.txt",
		        "node_list_path": "1380346.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusRaffinolactisNbrc100932Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis NBRC 100932 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusRaffinolactisNbrc100932Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348633.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348633.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348633.protein.info.v11.5.txt",
		        "node_list_path": "1348633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusPerolensDsm12744Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus perolens DSM 12744 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPerolensDsm12744Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423792.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423792.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423792.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423792.protein.info.v11.5.txt",
		        "node_list_path": "1423792.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423792.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesAcidifaciensJcm10556(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides acidifaciens JCM 10556 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesAcidifaciensJcm10556", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235814.protein.info.v11.5.txt",
		        "node_list_path": "1235814.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobacteriaceaeArchaeon41258Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacteriaceae archaeon 41_258 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriaceaeArchaeon41258Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635284.protein.info.v11.5.txt",
		        "node_list_path": "1635284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgreiaSpLeaf244(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agreia sp. Leaf244 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgreiaSpLeaf244", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736305.protein.info.v11.5.txt",
		        "node_list_path": "1736305.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZymophilusRaffinosivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zymophilus raffinosivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymophilusRaffinosivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123511.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123511.protein.info.v11.5.txt",
		        "node_list_path": "1123511.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesVietnamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces vietnamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesVietnamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "362257.protein.sequences.v11.5.fa",
		        "enrichment_path": "362257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362257.protein.info.v11.5.txt",
		        "node_list_path": "362257.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaTimonensisCris5cb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella timonensis CRIS5CB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaTimonensisCris5cb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679189.clusters.proteins.v11.5.txt",
		        "sequence_path": "679189.protein.sequences.v11.5.fa",
		        "enrichment_path": "679189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679189.protein.info.v11.5.txt",
		        "node_list_path": "679189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumVerruco04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium Verruco_04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumVerruco04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674916.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674916.protein.info.v11.5.txt",
		        "node_list_path": "1674916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumSpMe1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. ME-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumSpMe1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1639348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1639348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1639348.protein.info.v11.5.txt",
		        "node_list_path": "1639348.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE183Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E183 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE183Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834129.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834129.protein.info.v11.5.txt",
		        "node_list_path": "1834129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PowellomycesHirtus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Powellomyces hirtus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PowellomycesHirtus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "109895.protein.sequences.v11.5.fa",
		        "enrichment_path": "109895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109895.protein.info.v11.5.txt",
		        "node_list_path": "109895.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusCoprophilusNbrc100603(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus coprophilus NBRC 100603 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusCoprophilusNbrc100603", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219011.protein.info.v11.5.txt",
		        "node_list_path": "1219011.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4028(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_01_FULL_40_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4028", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798406.protein.info.v11.5.txt",
		        "node_list_path": "1798406.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusBrasiliensisCbs101740Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus brasiliensis CBS 101740 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusBrasiliensisCbs101740Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "767769.clusters.info.v11.5.txt",
		        "cluster_tree_path": "767769.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "767769.clusters.proteins.v11.5.txt",
		        "sequence_path": "767769.protein.sequences.v11.5.fa",
		        "enrichment_path": "767769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767769.protein.info.v11.5.txt",
		        "node_list_path": "767769.cluster.nodes.v11.5.txt",
		        "edge_list_path": "767769.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusMalefermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus malefermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMalefermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122149.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122149.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122149.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122149.protein.info.v11.5.txt",
		        "node_list_path": "1122149.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122149.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpCag956Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:956 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpCag956Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262908.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262908.protein.info.v11.5.txt",
		        "node_list_path": "1262908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CladophialophoraPsammophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora psammophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CladophialophoraPsammophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1182553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182553.protein.info.v11.5.txt",
		        "node_list_path": "1182553.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSp103dpr2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 103DPR2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSp103dpr2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1678129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1678129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1678129.clusters.proteins.v11.5.txt",
		        "sequence_path": "1678129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678129.protein.info.v11.5.txt",
		        "node_list_path": "1678129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1678129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaCanadenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma canadense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaCanadenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29554.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29554.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29554.clusters.proteins.v11.5.txt",
		        "sequence_path": "29554.protein.sequences.v11.5.fa",
		        "enrichment_path": "29554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29554.protein.info.v11.5.txt",
		        "node_list_path": "29554.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29554.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GramellaForsetii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gramella forsetii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaForsetii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411154.protein.sequences.v11.5.fa",
		        "enrichment_path": "411154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411154.protein.info.v11.5.txt",
		        "node_list_path": "411154.protein.complete.v11.5.txt"
		    }
		]
    )()

def GottschalkiaPurinilyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gottschalkia purinilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GottschalkiaPurinilyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1503.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1503.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1503.clusters.proteins.v11.5.txt",
		        "sequence_path": "1503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1503.protein.info.v11.5.txt",
		        "node_list_path": "1503.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1503.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodonellumIkkaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodonellum ikkaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodonellumIkkaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "336829.protein.sequences.v11.5.fa",
		        "enrichment_path": "336829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336829.protein.info.v11.5.txt",
		        "node_list_path": "336829.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmillariaSolidipes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Armillaria solidipes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmillariaSolidipes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1076256.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076256.protein.info.v11.5.txt",
		        "node_list_path": "1076256.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumSpCf444(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. CF444 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumSpCf444", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144319.protein.info.v11.5.txt",
		        "node_list_path": "1144319.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpiritivorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium spiritivorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpiritivorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525373.clusters.proteins.v11.5.txt",
		        "sequence_path": "525373.protein.sequences.v11.5.fa",
		        "enrichment_path": "525373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525373.protein.info.v11.5.txt",
		        "node_list_path": "525373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpHmsc077f02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. HMSC077F02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpHmsc077f02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739529.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739529.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739529.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739529.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739529.protein.info.v11.5.txt",
		        "node_list_path": "1739529.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739529.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TolumonasAuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tolumonas auensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolumonasAuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "595494.protein.sequences.v11.5.fa",
		        "enrichment_path": "595494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595494.protein.info.v11.5.txt",
		        "node_list_path": "595494.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytophthoraMegakaryaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora megakarya Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraMegakaryaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4795.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4795.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4795.clusters.proteins.v11.5.txt",
		        "sequence_path": "4795.protein.sequences.v11.5.fa",
		        "enrichment_path": "4795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4795.protein.info.v11.5.txt",
		        "node_list_path": "4795.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4795.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterLignolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter lignolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterLignolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "701347.clusters.info.v11.5.txt",
		        "cluster_tree_path": "701347.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "701347.clusters.proteins.v11.5.txt",
		        "sequence_path": "701347.protein.sequences.v11.5.fa",
		        "enrichment_path": "701347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "701347.protein.info.v11.5.txt",
		        "node_list_path": "701347.cluster.nodes.v11.5.txt",
		        "edge_list_path": "701347.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4518Fw2643Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4518 (FW-2643) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4518Fw2643Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420913.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420913.protein.info.v11.5.txt",
		        "node_list_path": "1420913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full4424bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_44_24b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full4424bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802526.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802526.protein.info.v11.5.txt",
		        "node_list_path": "1802526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumP6a3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium P6A3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumP6a3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410630.protein.info.v11.5.txt",
		        "node_list_path": "1410630.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpSoil805Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil805 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpSoil805Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736416.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736416.protein.info.v11.5.txt",
		        "node_list_path": "1736416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfarculaceaeBacteriumJdfr97Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfarculaceae bacterium JdFR-97 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfarculaceaeBacteriumJdfr97Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935136.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935136.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935136.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935136.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935136.protein.info.v11.5.txt",
		        "node_list_path": "1935136.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935136.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraParasitica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora parasitica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraParasitica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4792.protein.sequences.v11.5.fa",
		        "enrichment_path": "4792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4792.protein.info.v11.5.txt",
		        "node_list_path": "4792.protein.complete.v11.5.txt"
		    }
		]
    )()

def VombatusUrsinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vombatus ursinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VombatusUrsinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29139.protein.sequences.v11.5.fa",
		        "enrichment_path": "29139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29139.protein.info.v11.5.txt",
		        "node_list_path": "29139.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloceanibacterCaenitepidiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloceanibacter caenitepidi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloceanibacterCaenitepidiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1384459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1384459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1384459.clusters.proteins.v11.5.txt",
		        "sequence_path": "1384459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384459.protein.info.v11.5.txt",
		        "node_list_path": "1384459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1384459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GramellaFlavaJlt2011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gramella flava JLT2011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaFlavaJlt2011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229726.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229726.protein.info.v11.5.txt",
		        "node_list_path": "1229726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusOralisUo5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis Uo5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOralisUo5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "927666.protein.sequences.v11.5.fa",
		        "enrichment_path": "927666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927666.protein.info.v11.5.txt",
		        "node_list_path": "927666.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConsotaellaSalsifontisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Consotaella salsifontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConsotaellaSalsifontisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1365950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1365950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1365950.clusters.proteins.v11.5.txt",
		        "sequence_path": "1365950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1365950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1365950.protein.info.v11.5.txt",
		        "node_list_path": "1365950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1365950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LongisporaAlbida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Longispora albida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LongisporaAlbida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122182.protein.info.v11.5.txt",
		        "node_list_path": "1122182.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLloydbacteriaBacteriumRifcsphigho201Full4120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_01_FULL_41_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho201Full4120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798657.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798657.protein.info.v11.5.txt",
		        "node_list_path": "1798657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterCupressi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter cupressi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterCupressi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1045773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045773.protein.info.v11.5.txt",
		        "node_list_path": "1045773.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichococcusCollinsiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichococcus collinsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichococcusCollinsiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "157076.clusters.info.v11.5.txt",
		        "cluster_tree_path": "157076.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "157076.clusters.proteins.v11.5.txt",
		        "sequence_path": "157076.protein.sequences.v11.5.fa",
		        "enrichment_path": "157076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157076.protein.info.v11.5.txt",
		        "node_list_path": "157076.cluster.nodes.v11.5.txt",
		        "edge_list_path": "157076.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusContaminans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus contaminans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusContaminans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945662.protein.info.v11.5.txt",
		        "node_list_path": "1945662.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpBms12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BMS12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpBms12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1796033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796033.protein.info.v11.5.txt",
		        "node_list_path": "1796033.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumSpJcm19050Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium sp. JCM 19050 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumSpJcm19050Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1460644.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1460644.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1460644.clusters.proteins.v11.5.txt",
		        "sequence_path": "1460644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460644.protein.info.v11.5.txt",
		        "node_list_path": "1460644.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1460644.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichomonasVaginalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichomonas vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichomonasVaginalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5722.clusters.proteins.v11.5.txt",
		        "sequence_path": "5722.protein.sequences.v11.5.fa",
		        "enrichment_path": "5722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5722.protein.info.v11.5.txt",
		        "node_list_path": "5722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycetocolaSaprophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycetocola saprophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycetocolaSaprophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "76636.protein.sequences.v11.5.fa",
		        "enrichment_path": "76636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76636.protein.info.v11.5.txt",
		        "node_list_path": "76636.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShimwelliaBlattaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shimwellia blattae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShimwelliaBlattaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "630626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "630626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "630626.clusters.proteins.v11.5.txt",
		        "sequence_path": "630626.protein.sequences.v11.5.fa",
		        "enrichment_path": "630626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "630626.protein.info.v11.5.txt",
		        "node_list_path": "630626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "630626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumFallaxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium fallax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumFallaxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1793.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1793.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1793.clusters.proteins.v11.5.txt",
		        "sequence_path": "1793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1793.protein.info.v11.5.txt",
		        "node_list_path": "1793.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1793.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesnuesiellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desnuesiella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesnuesiellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1650662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1650662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1650662.protein.info.v11.5.txt",
		        "node_list_path": "1650662.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpKnhs214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpKnhs214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1540257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1540257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1540257.protein.info.v11.5.txt",
		        "node_list_path": "1540257.protein.complete.v11.5.txt"
		    }
		]
    )()

def DomibacillusRobiginosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus robiginosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusRobiginosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071054.protein.info.v11.5.txt",
		        "node_list_path": "1071054.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfonatronumThioautotrophicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronum thioautotrophicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronumThioautotrophicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "617001.protein.sequences.v11.5.fa",
		        "enrichment_path": "617001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "617001.protein.info.v11.5.txt",
		        "node_list_path": "617001.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3714Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_37_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3714Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798276.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798276.protein.info.v11.5.txt",
		        "node_list_path": "1798276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcanthochromisPolyacanthusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acanthochromis polyacanthus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcanthochromisPolyacanthusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "80966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "80966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "80966.clusters.proteins.v11.5.txt",
		        "sequence_path": "80966.protein.sequences.v11.5.fa",
		        "enrichment_path": "80966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80966.protein.info.v11.5.txt",
		        "node_list_path": "80966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "80966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumDtu037(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium DTU037 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumDtu037", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671662.protein.info.v11.5.txt",
		        "node_list_path": "1671662.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoffeaCanephoraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coffea canephora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoffeaCanephoraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "49390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "49390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "49390.clusters.proteins.v11.5.txt",
		        "sequence_path": "49390.protein.sequences.v11.5.fa",
		        "enrichment_path": "49390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "49390.protein.info.v11.5.txt",
		        "node_list_path": "49390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "49390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterInsulaenigraeNctc12927Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter insulaenigrae NCTC 12927 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterInsulaenigraeNctc12927Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1031564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1031564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1031564.clusters.proteins.v11.5.txt",
		        "sequence_path": "1031564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1031564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1031564.protein.info.v11.5.txt",
		        "node_list_path": "1031564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1031564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterSpAf1440Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. AF1440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSpAf1440Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1355374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1355374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1355374.clusters.proteins.v11.5.txt",
		        "sequence_path": "1355374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1355374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1355374.protein.info.v11.5.txt",
		        "node_list_path": "1355374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1355374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgibacterLectus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algibacter lectus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgibacterLectus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "221126.protein.sequences.v11.5.fa",
		        "enrichment_path": "221126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221126.protein.info.v11.5.txt",
		        "node_list_path": "221126.protein.complete.v11.5.txt"
		    }
		]
    )()

def GayadomonasJoobiniege(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gayadomonas joobiniege graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GayadomonasJoobiniege", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1046714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046714.protein.info.v11.5.txt",
		        "node_list_path": "1046714.protein.complete.v11.5.txt"
		    }
		]
    )()

def GrimontiaCeler(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Grimontia celer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GrimontiaCeler", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1796497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796497.protein.info.v11.5.txt",
		        "node_list_path": "1796497.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusMulundensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus mulundensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusMulundensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1810919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1810919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1810919.protein.info.v11.5.txt",
		        "node_list_path": "1810919.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonadaceaeBacteriumBs31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonadaceae bacterium Bs31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonadaceaeBacteriumBs31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304903.protein.info.v11.5.txt",
		        "node_list_path": "1304903.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmborellaTrichopoda(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amborella trichopoda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmborellaTrichopoda", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13333.protein.sequences.v11.5.fa",
		        "enrichment_path": "13333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13333.protein.info.v11.5.txt",
		        "node_list_path": "13333.protein.complete.v11.5.txt"
		    }
		]
    )()

def ImtechellaHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Imtechella halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ImtechellaHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "946077.clusters.info.v11.5.txt",
		        "cluster_tree_path": "946077.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "946077.clusters.proteins.v11.5.txt",
		        "sequence_path": "946077.protein.sequences.v11.5.fa",
		        "enrichment_path": "946077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946077.protein.info.v11.5.txt",
		        "node_list_path": "946077.cluster.nodes.v11.5.txt",
		        "edge_list_path": "946077.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MastacembelusArmatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mastacembelus armatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MastacembelusArmatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "205130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "205130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "205130.clusters.proteins.v11.5.txt",
		        "sequence_path": "205130.protein.sequences.v11.5.fa",
		        "enrichment_path": "205130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "205130.protein.info.v11.5.txt",
		        "node_list_path": "205130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "205130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MacrococcusCaseolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Macrococcus caseolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacrococcusCaseolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "458233.protein.sequences.v11.5.fa",
		        "enrichment_path": "458233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "458233.protein.info.v11.5.txt",
		        "node_list_path": "458233.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonB262(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B26-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB262", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1779371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1779371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1779371.protein.info.v11.5.txt",
		        "node_list_path": "1779371.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrateuriaAurantiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frateuria aurantia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrateuriaAurantiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "767434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "767434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "767434.clusters.proteins.v11.5.txt",
		        "sequence_path": "767434.protein.sequences.v11.5.fa",
		        "enrichment_path": "767434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767434.protein.info.v11.5.txt",
		        "node_list_path": "767434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "767434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpB13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. b13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpB13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761774.protein.info.v11.5.txt",
		        "node_list_path": "1761774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaSpinosisporaDsm44797(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia spinosispora DSM 44797 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaSpinosisporaDsm44797", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123025.protein.info.v11.5.txt",
		        "node_list_path": "1123025.protein.complete.v11.5.txt"
		    }
		]
    )()

def SideroxydansSpGwf25914(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sideroxydans sp. GWF2_59_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SideroxydansSpGwf25914", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802154.protein.info.v11.5.txt",
		        "node_list_path": "1802154.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusRivorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus rivorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusRivorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762845.clusters.proteins.v11.5.txt",
		        "sequence_path": "762845.protein.sequences.v11.5.fa",
		        "enrichment_path": "762845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762845.protein.info.v11.5.txt",
		        "node_list_path": "762845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5630(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_56_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5630", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798499.protein.info.v11.5.txt",
		        "node_list_path": "1798499.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5411bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_54_11b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5411bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798494.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798494.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798494.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798494.protein.info.v11.5.txt",
		        "node_list_path": "1798494.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798494.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaPalleroniiNbrc102513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga palleronii NBRC 102513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaPalleroniiNbrc102513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349791.protein.info.v11.5.txt",
		        "node_list_path": "1349791.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRoot1433d1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root1433D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRoot1433d1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736463.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736463.protein.info.v11.5.txt",
		        "node_list_path": "1736463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LoktanellaSpDsm29012Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella sp. DSM 29012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaSpDsm29012Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881056.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881056.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881056.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881056.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881056.protein.info.v11.5.txt",
		        "node_list_path": "1881056.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881056.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumSpBs2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. BS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumSpBs2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936550.clusters.proteins.v11.5.txt",
		        "sequence_path": "936550.protein.sequences.v11.5.fa",
		        "enrichment_path": "936550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936550.protein.info.v11.5.txt",
		        "node_list_path": "936550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumDenitrificansDsm15936(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium denitrificans DSM 15936 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumDenitrificansDsm15936", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121888.protein.info.v11.5.txt",
		        "node_list_path": "1121888.protein.complete.v11.5.txt"
		    }
		]
    )()

def KwoniellaPiniCbs10737(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella pini CBS 10737 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KwoniellaPiniCbs10737", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1296096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296096.protein.info.v11.5.txt",
		        "node_list_path": "1296096.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidocellaAminolytica101Dsm11237(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidocella aminolytica 101 DSM 11237 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidocellaAminolytica101Dsm11237", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120923.protein.info.v11.5.txt",
		        "node_list_path": "1120923.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesCryophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces cryophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesCryophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "866546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "866546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "866546.clusters.proteins.v11.5.txt",
		        "sequence_path": "866546.protein.sequences.v11.5.fa",
		        "enrichment_path": "866546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866546.protein.info.v11.5.txt",
		        "node_list_path": "866546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "866546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFrumentiDsm13145(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus frumenti DSM 13145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFrumentiDsm13145", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423746.protein.info.v11.5.txt",
		        "node_list_path": "1423746.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusInfantis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusInfantis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68892.protein.sequences.v11.5.fa",
		        "enrichment_path": "68892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68892.protein.info.v11.5.txt",
		        "node_list_path": "68892.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterPsychrophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter psychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterPsychrophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1826909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1826909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1826909.protein.info.v11.5.txt",
		        "node_list_path": "1826909.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpFxanac1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. FxanaC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpFxanac1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157640.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157640.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157640.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157640.protein.info.v11.5.txt",
		        "node_list_path": "1157640.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157640.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpPamc26554(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. PAMC 26554 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpPamc26554", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1484116.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484116.protein.info.v11.5.txt",
		        "node_list_path": "1484116.protein.complete.v11.5.txt"
		    }
		]
    )()

def BotrytisCinereaT4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Botrytis cinerea T4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotrytisCinereaT4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999810.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999810.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999810.clusters.proteins.v11.5.txt",
		        "sequence_path": "999810.protein.sequences.v11.5.fa",
		        "enrichment_path": "999810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999810.protein.info.v11.5.txt",
		        "node_list_path": "999810.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999810.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermaerobacterMarianensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermaerobacter marianensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermaerobacterMarianensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644966.protein.sequences.v11.5.fa",
		        "enrichment_path": "644966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644966.protein.info.v11.5.txt",
		        "node_list_path": "644966.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSp117Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. 117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSp117Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125973.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125973.protein.info.v11.5.txt",
		        "node_list_path": "1125973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AotusNancymaae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aotus nancymaae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AotusNancymaae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37293.protein.sequences.v11.5.fa",
		        "enrichment_path": "37293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37293.protein.info.v11.5.txt",
		        "node_list_path": "37293.protein.complete.v11.5.txt"
		    }
		]
    )()

def NonlabensSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "319236.protein.sequences.v11.5.fa",
		        "enrichment_path": "319236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319236.protein.info.v11.5.txt",
		        "node_list_path": "319236.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioTritoniusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio tritonius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioTritoniusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1435069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1435069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1435069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1435069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1435069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1435069.protein.info.v11.5.txt",
		        "node_list_path": "1435069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1435069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaAraiiNbrc100433(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia araii NBRC 100433 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaAraiiNbrc100433", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1073574.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073574.protein.info.v11.5.txt",
		        "node_list_path": "1073574.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanococcusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planococcus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499687.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499687.protein.info.v11.5.txt",
		        "node_list_path": "1499687.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLatescibacterAnaerobiusScgcAaa252E07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Latescibacter anaerobius SCGC AAA252-E07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLatescibacterAnaerobiusScgcAaa252E07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "910047.clusters.info.v11.5.txt",
		        "cluster_tree_path": "910047.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "910047.clusters.proteins.v11.5.txt",
		        "sequence_path": "910047.protein.sequences.v11.5.fa",
		        "enrichment_path": "910047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "910047.protein.info.v11.5.txt",
		        "node_list_path": "910047.cluster.nodes.v11.5.txt",
		        "edge_list_path": "910047.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpUnccl28Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UNCCL28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpUnccl28Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502752.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502752.protein.info.v11.5.txt",
		        "node_list_path": "1502752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumLotiUsda3471Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti USDA3471 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumLotiUsda3471Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1040983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1040983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1040983.clusters.proteins.v11.5.txt",
		        "sequence_path": "1040983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1040983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1040983.protein.info.v11.5.txt",
		        "node_list_path": "1040983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1040983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzospirillumHalopraeferensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum halopraeferens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumHalopraeferensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121033.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121033.protein.info.v11.5.txt",
		        "node_list_path": "1121033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumHqm9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium HQM9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumHqm9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "980584.clusters.info.v11.5.txt",
		        "cluster_tree_path": "980584.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "980584.clusters.proteins.v11.5.txt",
		        "sequence_path": "980584.protein.sequences.v11.5.fa",
		        "enrichment_path": "980584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "980584.protein.info.v11.5.txt",
		        "node_list_path": "980584.cluster.nodes.v11.5.txt",
		        "edge_list_path": "980584.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusPersicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus persicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPersicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930146.clusters.proteins.v11.5.txt",
		        "sequence_path": "930146.protein.sequences.v11.5.fa",
		        "enrichment_path": "930146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930146.protein.info.v11.5.txt",
		        "node_list_path": "930146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychromicrobiumLacuslunae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychromicrobium lacuslunae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychromicrobiumLacuslunae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618207.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618207.protein.info.v11.5.txt",
		        "node_list_path": "1618207.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParvimonasMicraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parvimonas micra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvimonasMicraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411465.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411465.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411465.clusters.proteins.v11.5.txt",
		        "sequence_path": "411465.protein.sequences.v11.5.fa",
		        "enrichment_path": "411465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411465.protein.info.v11.5.txt",
		        "node_list_path": "411465.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411465.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumRifcsplowo202Full4710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPLOWO2_02_FULL_47_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsplowo202Full4710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802465.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802465.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802465.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802465.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802465.protein.info.v11.5.txt",
		        "node_list_path": "1802465.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802465.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSp135mfcol51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 135MFCol51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSp135mfcol51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158050.protein.info.v11.5.txt",
		        "node_list_path": "1158050.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichodermaVirensGv298(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma virens Gv29-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaVirensGv298", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "413071.protein.sequences.v11.5.fa",
		        "enrichment_path": "413071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "413071.protein.info.v11.5.txt",
		        "node_list_path": "413071.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhascolarctobacteriumSuccinatutensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phascolarctobacterium succinatutens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhascolarctobacteriumSuccinatutensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "626940.clusters.info.v11.5.txt",
		        "cluster_tree_path": "626940.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "626940.clusters.proteins.v11.5.txt",
		        "sequence_path": "626940.protein.sequences.v11.5.fa",
		        "enrichment_path": "626940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626940.protein.info.v11.5.txt",
		        "node_list_path": "626940.cluster.nodes.v11.5.txt",
		        "edge_list_path": "626940.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaLansingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella lansingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaLansingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122164.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122164.protein.info.v11.5.txt",
		        "node_list_path": "1122164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkaliphilusPeptidifermentansDsm18978(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkaliphilus peptidifermentans DSM 18978 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkaliphilusPeptidifermentansDsm18978", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120976.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120976.protein.info.v11.5.txt",
		        "node_list_path": "1120976.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaBelliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia bellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaBelliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33990.clusters.proteins.v11.5.txt",
		        "sequence_path": "33990.protein.sequences.v11.5.fa",
		        "enrichment_path": "33990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33990.protein.info.v11.5.txt",
		        "node_list_path": "33990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TenacibaculumDicentrarchiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum dicentrarchi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumDicentrarchiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "669041.clusters.info.v11.5.txt",
		        "cluster_tree_path": "669041.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "669041.clusters.proteins.v11.5.txt",
		        "sequence_path": "669041.protein.sequences.v11.5.fa",
		        "enrichment_path": "669041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "669041.protein.info.v11.5.txt",
		        "node_list_path": "669041.cluster.nodes.v11.5.txt",
		        "edge_list_path": "669041.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumAeronauticumDsm10349Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum aeronauticum DSM 10349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumAeronauticumDsm10349Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121421.protein.info.v11.5.txt",
		        "node_list_path": "1121421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHimb30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HIMB30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHimb30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "751994.protein.sequences.v11.0.fa",
		        "enrichment_path": "751994.protein.enrichment.terms.v11.0.txt",
		        "info_path": "751994.protein.info.v11.0.txt",
		        "node_list_path": "751994.protein.complete.v11.0.txt"
		    }
		]
    )()

def MeiraMiltonrushiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meira miltonrushii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiraMiltonrushiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280837.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280837.protein.info.v11.5.txt",
		        "node_list_path": "1280837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmanitaThiersiiSkay4041(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amanita thiersii Skay4041 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmanitaThiersiiSkay4041", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "703135.protein.sequences.v11.5.fa",
		        "enrichment_path": "703135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "703135.protein.info.v11.5.txt",
		        "node_list_path": "703135.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronolimnobiusInnermongolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronolimnobius innermongolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronolimnobiusInnermongolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227499.protein.info.v11.5.txt",
		        "node_list_path": "1227499.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisColoradensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis coloradensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisColoradensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "76021.protein.sequences.v11.5.fa",
		        "enrichment_path": "76021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76021.protein.info.v11.5.txt",
		        "node_list_path": "76021.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp4414Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 44_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp4414Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896984.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896984.protein.info.v11.5.txt",
		        "node_list_path": "1896984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnq509(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNQ-509 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnq509", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "444103.protein.sequences.v11.5.fa",
		        "enrichment_path": "444103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444103.protein.info.v11.5.txt",
		        "node_list_path": "444103.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterMucosalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter mucosalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterMucosalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "202.clusters.proteins.v11.5.txt",
		        "sequence_path": "202.protein.sequences.v11.5.fa",
		        "enrichment_path": "202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202.protein.info.v11.5.txt",
		        "node_list_path": "202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EntamoebaHistolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Entamoeba histolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EntamoebaHistolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5759.protein.sequences.v11.5.fa",
		        "enrichment_path": "5759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5759.protein.info.v11.5.txt",
		        "node_list_path": "5759.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumTumefaciensCcnwgs0286(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens CCNWGS0286 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumTumefaciensCcnwgs0286", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1082932.protein.sequences.v11.5.fa",
		        "enrichment_path": "1082932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1082932.protein.info.v11.5.txt",
		        "node_list_path": "1082932.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhascolarctobacteriumSpCag266Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phascolarctobacterium sp. CAG266 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhascolarctobacteriumSpCag266Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262915.protein.info.v11.5.txt",
		        "node_list_path": "1262915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfatatorAutotrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfatator autotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfatatorAutotrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1795632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795632.protein.info.v11.5.txt",
		        "node_list_path": "1795632.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacteriumUtbcd1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium UTBCD1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacteriumUtbcd1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1961110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1961110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1961110.clusters.proteins.v11.5.txt",
		        "sequence_path": "1961110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961110.protein.info.v11.5.txt",
		        "node_list_path": "1961110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1961110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaribacterSpHeli7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter sp. HelI7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterSpHeli7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1249997.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1249997.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1249997.clusters.proteins.v11.5.txt",
		        "sequence_path": "1249997.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249997.protein.info.v11.5.txt",
		        "node_list_path": "1249997.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1249997.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoritellaViscosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moritella viscosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoritellaViscosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "80854.protein.sequences.v11.5.fa",
		        "enrichment_path": "80854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80854.protein.info.v11.5.txt",
		        "node_list_path": "80854.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospirillumRubrum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillum rubrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillumRubrum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "269796.protein.sequences.v11.5.fa",
		        "enrichment_path": "269796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269796.protein.info.v11.5.txt",
		        "node_list_path": "269796.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfTrichogrammaPretiosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Trichogramma pretiosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfTrichogrammaPretiosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "125593.protein.sequences.v11.5.fa",
		        "enrichment_path": "125593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "125593.protein.info.v11.5.txt",
		        "node_list_path": "125593.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaSpDb56(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. DB56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpDb56", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094755.protein.info.v11.5.txt",
		        "node_list_path": "1094755.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidiplasmaSpMba1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidiplasma sp. MBA-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidiplasmaSpMba1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293648.protein.info.v11.5.txt",
		        "node_list_path": "1293648.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumDivergensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium divergens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumDivergensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449336.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449336.protein.info.v11.5.txt",
		        "node_list_path": "1449336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParvularculaSpBbd199113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parvularcula sp. BBD 1991-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvularculaSpBbd199113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852618.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852618.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852618.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852618.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852618.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852618.protein.info.v11.5.txt",
		        "node_list_path": "1852618.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852618.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporolactobacillusTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolactobacillusTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1444306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444306.protein.info.v11.5.txt",
		        "node_list_path": "1444306.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSyngnathidarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium syngnathidarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSyngnathidarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1908205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1908205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1908205.clusters.proteins.v11.5.txt",
		        "sequence_path": "1908205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908205.protein.info.v11.5.txt",
		        "node_list_path": "1908205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1908205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAmmoniagenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium ammoniagenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAmmoniagenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649754.protein.sequences.v11.5.fa",
		        "enrichment_path": "649754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649754.protein.info.v11.5.txt",
		        "node_list_path": "649754.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraAlkalitoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira alkalitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraAlkalitoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293890.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293890.protein.info.v11.5.txt",
		        "node_list_path": "1293890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasOryzaeOryzicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae oryzicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasOryzaeOryzicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "383407.protein.sequences.v11.5.fa",
		        "enrichment_path": "383407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "383407.protein.info.v11.5.txt",
		        "node_list_path": "383407.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterArcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterArcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "259536.protein.sequences.v11.5.fa",
		        "enrichment_path": "259536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "259536.protein.info.v11.5.txt",
		        "node_list_path": "259536.protein.complete.v11.5.txt"
		    }
		]
    )()

def RheinheimeraSalexigens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera salexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraSalexigens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1628148.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628148.protein.info.v11.5.txt",
		        "node_list_path": "1628148.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpRit357Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. RIT357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpRit357Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1470593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1470593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1470593.clusters.proteins.v11.5.txt",
		        "sequence_path": "1470593.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470593.protein.info.v11.5.txt",
		        "node_list_path": "1470593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1470593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasPituitosaNbrc102491Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas pituitosa NBRC 102491 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasPituitosaNbrc102491Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219051.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219051.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219051.protein.info.v11.5.txt",
		        "node_list_path": "1219051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusAnginosusF0211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus F0211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAnginosusF0211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "706437.protein.sequences.v11.5.fa",
		        "enrichment_path": "706437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706437.protein.info.v11.5.txt",
		        "node_list_path": "706437.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioMexicanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio mexicanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioMexicanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1004326.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1004326.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1004326.clusters.proteins.v11.5.txt",
		        "sequence_path": "1004326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004326.protein.info.v11.5.txt",
		        "node_list_path": "1004326.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1004326.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MixiaOsmundae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mixia osmundae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MixiaOsmundae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34349.protein.sequences.v11.5.fa",
		        "enrichment_path": "34349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34349.protein.info.v11.5.txt",
		        "node_list_path": "34349.protein.complete.v11.5.txt"
		    }
		]
    )()

def UrocitellusParryii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Urocitellus parryii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UrocitellusParryii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9999.protein.sequences.v11.5.fa",
		        "enrichment_path": "9999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9999.protein.info.v11.5.txt",
		        "node_list_path": "9999.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSomaliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces somaliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSomaliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1134445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134445.protein.info.v11.5.txt",
		        "node_list_path": "1134445.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldibacillusDebilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldibacillus debilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldibacillusDebilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "301148.protein.sequences.v11.5.fa",
		        "enrichment_path": "301148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "301148.protein.info.v11.5.txt",
		        "node_list_path": "301148.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusAlbusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusAlbusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "105425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "105425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "105425.clusters.proteins.v11.5.txt",
		        "sequence_path": "105425.protein.sequences.v11.5.fa",
		        "enrichment_path": "105425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105425.protein.info.v11.5.txt",
		        "node_list_path": "105425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "105425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumSpLk11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium sp. LK11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumSpLk11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1628212.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1628212.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1628212.clusters.proteins.v11.5.txt",
		        "sequence_path": "1628212.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628212.protein.info.v11.5.txt",
		        "node_list_path": "1628212.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1628212.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls149(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS149 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls149", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463885.protein.info.v11.5.txt",
		        "node_list_path": "1463885.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSpRoot635(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. Root635 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpRoot635", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736575.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736575.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736575.protein.info.v11.5.txt",
		        "node_list_path": "1736575.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesPluripotens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces pluripotens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPluripotens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1355015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1355015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1355015.protein.info.v11.5.txt",
		        "node_list_path": "1355015.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisTaihuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis taihuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisTaihuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "260084.protein.sequences.v11.5.fa",
		        "enrichment_path": "260084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "260084.protein.info.v11.5.txt",
		        "node_list_path": "260084.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674849.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674849.protein.info.v11.5.txt",
		        "node_list_path": "1674849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloprofundusMarisrubriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloprofundus marisrubri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloprofundusMarisrubriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1514971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1514971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1514971.clusters.proteins.v11.5.txt",
		        "sequence_path": "1514971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1514971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1514971.protein.info.v11.5.txt",
		        "node_list_path": "1514971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1514971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674842.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674842.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674842.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674842.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674842.protein.info.v11.5.txt",
		        "node_list_path": "1674842.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674842.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaCalifornicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma californicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaCalifornicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2113.clusters.proteins.v11.5.txt",
		        "sequence_path": "2113.protein.sequences.v11.5.fa",
		        "enrichment_path": "2113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2113.protein.info.v11.5.txt",
		        "node_list_path": "2113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTuberculosisH37rv(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis H37Rv graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTuberculosisH37rv", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83332.protein.sequences.v11.5.fa",
		        "enrichment_path": "83332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83332.protein.info.v11.5.txt",
		        "node_list_path": "83332.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphaerulinaMusivaSo2202(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphaerulina musiva SO2202 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerulinaMusivaSo2202", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "692275.protein.sequences.v11.5.fa",
		        "enrichment_path": "692275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "692275.protein.info.v11.5.txt",
		        "node_list_path": "692275.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsplowo201Full4732Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_47_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full4732Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802277.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802277.protein.info.v11.5.txt",
		        "node_list_path": "1802277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChiloscylliumPunctatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chiloscyllium punctatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChiloscylliumPunctatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "137246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "137246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "137246.clusters.proteins.v11.5.txt",
		        "sequence_path": "137246.protein.sequences.v11.5.fa",
		        "enrichment_path": "137246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137246.protein.info.v11.5.txt",
		        "node_list_path": "137246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "137246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat26652(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-26652 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat26652", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1684141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1684141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1684141.protein.info.v11.5.txt",
		        "node_list_path": "1684141.protein.complete.v11.5.txt"
		    }
		]
    )()

def GrimontiaCelerCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Grimontia celer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GrimontiaCelerCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1796497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1796497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1796497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1796497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796497.protein.info.v11.5.txt",
		        "node_list_path": "1796497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1796497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusMarincolaHl49(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus marincola HL49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusMarincolaHl49", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1305737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305737.protein.info.v11.5.txt",
		        "node_list_path": "1305737.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumSpCag815Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium sp. CAG:815 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumSpCag815Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262901.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262901.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262901.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262901.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262901.protein.info.v11.5.txt",
		        "node_list_path": "1262901.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262901.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesDarlingiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles darlingi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesDarlingiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43151.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43151.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43151.clusters.proteins.v11.5.txt",
		        "sequence_path": "43151.protein.sequences.v11.5.fa",
		        "enrichment_path": "43151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43151.protein.info.v11.5.txt",
		        "node_list_path": "43151.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43151.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full4120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_41_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full4120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798283.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798283.protein.info.v11.5.txt",
		        "node_list_path": "1798283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrovirgaSpBsc39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microvirga sp. BSC39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaSpBsc39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1549810.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1549810.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1549810.clusters.proteins.v11.5.txt",
		        "sequence_path": "1549810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1549810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1549810.protein.info.v11.5.txt",
		        "node_list_path": "1549810.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1549810.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5236Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_52_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5236Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798510.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798510.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798510.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798510.protein.info.v11.5.txt",
		        "node_list_path": "1798510.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798510.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSp263SspcCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. 263_SSPC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSp263SspcCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1579343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1579343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1579343.clusters.proteins.v11.5.txt",
		        "sequence_path": "1579343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579343.protein.info.v11.5.txt",
		        "node_list_path": "1579343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1579343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAmylovorus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus amylovorus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAmylovorus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1604.protein.sequences.v11.5.fa",
		        "enrichment_path": "1604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1604.protein.info.v11.5.txt",
		        "node_list_path": "1604.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumDiazoefficiens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium diazoefficiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumDiazoefficiens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "224911.protein.sequences.v11.5.fa",
		        "enrichment_path": "224911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224911.protein.info.v11.5.txt",
		        "node_list_path": "224911.protein.complete.v11.5.txt"
		    }
		]
    )()

def RobiginitaleaBiformataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Robiginitalea biformata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RobiginitaleaBiformataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313596.clusters.proteins.v11.5.txt",
		        "sequence_path": "313596.protein.sequences.v11.5.fa",
		        "enrichment_path": "313596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313596.protein.info.v11.5.txt",
		        "node_list_path": "313596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SediminicolaSpYik13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sediminicola sp. YIK13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminicolaSpYik13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1453352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453352.protein.info.v11.5.txt",
		        "node_list_path": "1453352.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusObesiPh1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus obesi ph1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusObesiPh1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118062.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118062.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118062.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118062.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118062.protein.info.v11.5.txt",
		        "node_list_path": "1118062.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118062.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanolobusTindariusDsm2278(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus tindarius DSM 2278 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolobusTindariusDsm2278", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1090322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1090322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1090322.protein.info.v11.5.txt",
		        "node_list_path": "1090322.protein.complete.v11.5.txt"
		    }
		]
    )()

def NafulsellaTurpanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nafulsella turpanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NafulsellaTurpanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1124780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1124780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1124780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1124780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1124780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1124780.protein.info.v11.5.txt",
		        "node_list_path": "1124780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1124780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacterTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1788.protein.info.v11.5.txt",
		        "node_list_path": "1788.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaApisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella apis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaApisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1686310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1686310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1686310.clusters.proteins.v11.5.txt",
		        "sequence_path": "1686310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686310.protein.info.v11.5.txt",
		        "node_list_path": "1686310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1686310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpNfr13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. NFR13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpNfr13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566285.protein.info.v11.5.txt",
		        "node_list_path": "1566285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomicrobiumMukohataei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomicrobium mukohataei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomicrobiumMukohataei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "485914.protein.sequences.v11.5.fa",
		        "enrichment_path": "485914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485914.protein.info.v11.5.txt",
		        "node_list_path": "485914.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumColicanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium colicanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumColicanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999411.protein.sequences.v11.5.fa",
		        "enrichment_path": "999411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999411.protein.info.v11.5.txt",
		        "node_list_path": "999411.protein.complete.v11.5.txt"
		    }
		]
    )()

def KordiaZhangzhouensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kordia zhangzhouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KordiaZhangzhouensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1620405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1620405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1620405.clusters.proteins.v11.5.txt",
		        "sequence_path": "1620405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1620405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1620405.protein.info.v11.5.txt",
		        "node_list_path": "1620405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1620405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmigerFormicilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmiger formicilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmigerFormicilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "745368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "745368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "745368.clusters.proteins.v11.5.txt",
		        "sequence_path": "745368.protein.sequences.v11.5.fa",
		        "enrichment_path": "745368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745368.protein.info.v11.5.txt",
		        "node_list_path": "745368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "745368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LaceyellaSacchari(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Laceyella sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LaceyellaSacchari", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1341151.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341151.protein.info.v11.5.txt",
		        "node_list_path": "1341151.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesIntestinalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesIntestinalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471870.protein.sequences.v11.5.fa",
		        "enrichment_path": "471870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471870.protein.info.v11.5.txt",
		        "node_list_path": "471870.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorticoccusHydrocarbonoclasticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porticoccus hydrocarbonoclasticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorticoccusHydrocarbonoclasticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415778.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415778.protein.info.v11.5.txt",
		        "node_list_path": "1415778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRbg134613Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_13_46_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg134613Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802479.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802479.protein.info.v11.5.txt",
		        "node_list_path": "1802479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwb11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWB11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwb11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896202.protein.info.v11.5.txt",
		        "node_list_path": "1896202.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSphaerophysaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sphaerophysae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSphaerophysaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "690417.clusters.info.v11.5.txt",
		        "cluster_tree_path": "690417.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "690417.clusters.proteins.v11.5.txt",
		        "sequence_path": "690417.protein.sequences.v11.5.fa",
		        "enrichment_path": "690417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690417.protein.info.v11.5.txt",
		        "node_list_path": "690417.cluster.nodes.v11.5.txt",
		        "edge_list_path": "690417.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasRuminantiumLactilytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium lactilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasRuminantiumLactilytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "927704.protein.sequences.v11.5.fa",
		        "enrichment_path": "927704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927704.protein.info.v11.5.txt",
		        "node_list_path": "927704.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThraustothecaClavataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thraustotheca clavata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThraustothecaClavataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "74557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "74557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "74557.clusters.proteins.v11.5.txt",
		        "sequence_path": "74557.protein.sequences.v11.5.fa",
		        "enrichment_path": "74557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74557.protein.info.v11.5.txt",
		        "node_list_path": "74557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "74557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusCapitisSubspCapitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus capitis subsp. capitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusCapitisSubspCapitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "72758.protein.sequences.v11.5.fa",
		        "enrichment_path": "72758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72758.protein.info.v11.5.txt",
		        "node_list_path": "72758.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaHermanniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia hermannii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaHermanniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1115512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1115512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1115512.clusters.proteins.v11.5.txt",
		        "sequence_path": "1115512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1115512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1115512.protein.info.v11.5.txt",
		        "node_list_path": "1115512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1115512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TsukamurellaSp1534(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tsukamurella sp. 1534 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TsukamurellaSp1534", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1151061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151061.protein.info.v11.5.txt",
		        "node_list_path": "1151061.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArenibacterTroitsensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenibacter troitsensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenibacterTroitsensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "188872.clusters.info.v11.5.txt",
		        "cluster_tree_path": "188872.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "188872.clusters.proteins.v11.5.txt",
		        "sequence_path": "188872.protein.sequences.v11.5.fa",
		        "enrichment_path": "188872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188872.protein.info.v11.5.txt",
		        "node_list_path": "188872.cluster.nodes.v11.5.txt",
		        "edge_list_path": "188872.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChroococcidiopsisThermalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chroococcidiopsis thermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChroococcidiopsisThermalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "251229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "251229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "251229.clusters.proteins.v11.5.txt",
		        "sequence_path": "251229.protein.sequences.v11.5.fa",
		        "enrichment_path": "251229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "251229.protein.info.v11.5.txt",
		        "node_list_path": "251229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "251229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPneumoniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPneumoniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "722438.protein.sequences.v11.5.fa",
		        "enrichment_path": "722438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "722438.protein.info.v11.5.txt",
		        "node_list_path": "722438.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc3832Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 3832 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc3832Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977874.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977874.protein.info.v11.5.txt",
		        "node_list_path": "1977874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsplowo201Full3821(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_38_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3821", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798620.protein.info.v11.5.txt",
		        "node_list_path": "1798620.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudovibrioSpTunPsc045I4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. Tun.PSC04-5.I4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioSpTunPsc045I4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798213.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798213.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798213.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798213.protein.info.v11.5.txt",
		        "node_list_path": "1798213.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798213.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PleomorphomonasKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pleomorphomonas koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PleomorphomonasKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122962.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122962.protein.info.v11.5.txt",
		        "node_list_path": "1122962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpLup30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. LUP30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpLup30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1890285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1890285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1890285.protein.info.v11.5.txt",
		        "node_list_path": "1890285.protein.complete.v11.5.txt"
		    }
		]
    )()

def PetrotogaMobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Petrotoga mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PetrotogaMobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "403833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "403833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "403833.clusters.proteins.v11.5.txt",
		        "sequence_path": "403833.protein.sequences.v11.5.fa",
		        "enrichment_path": "403833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "403833.protein.info.v11.5.txt",
		        "node_list_path": "403833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "403833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpLeaf264Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf264 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpLeaf264Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736314.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736314.protein.info.v11.5.txt",
		        "node_list_path": "1736314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumGwc24544(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWC2_45_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumGwc24544", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801952.protein.info.v11.5.txt",
		        "node_list_path": "1801952.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumRifcsplowo201Full4519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPLOWO2_01_FULL_45_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsplowo201Full4519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802557.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802557.protein.info.v11.5.txt",
		        "node_list_path": "1802557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumWg36Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium WG36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumWg36Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229485.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1229485.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1229485.clusters.proteins.v11.0.txt",
		        "sequence_path": "1229485.protein.sequences.v11.0.fa",
		        "enrichment_path": "1229485.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1229485.protein.info.v11.0.txt",
		        "node_list_path": "1229485.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1229485.protein.cluster.v11.0.txt"
		    }
		]
    )()

def PaenibacillusCurdlanolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus curdlanolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusCurdlanolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717606.clusters.proteins.v11.5.txt",
		        "sequence_path": "717606.protein.sequences.v11.5.fa",
		        "enrichment_path": "717606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717606.protein.info.v11.5.txt",
		        "node_list_path": "717606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterIndonesiensis5h1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter indonesiensis 5H-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterIndonesiensis5h1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231340.protein.info.v11.5.txt",
		        "node_list_path": "1231340.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermofilumUzonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum uzonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermofilumUzonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1550241.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1550241.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1550241.clusters.proteins.v11.5.txt",
		        "sequence_path": "1550241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550241.protein.info.v11.5.txt",
		        "node_list_path": "1550241.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1550241.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterPiechaudiiHle(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii HLE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterPiechaudiiHle", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1156919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156919.protein.info.v11.5.txt",
		        "node_list_path": "1156919.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpGa0074138(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. Ga0074138 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpGa0074138", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752217.protein.info.v11.5.txt",
		        "node_list_path": "1752217.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusBovimastitidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus bovimastitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusBovimastitidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1856638.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1856638.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1856638.clusters.proteins.v11.5.txt",
		        "sequence_path": "1856638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1856638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1856638.protein.info.v11.5.txt",
		        "node_list_path": "1856638.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1856638.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachymonasChironomi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachymonas chironomi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachymonasChironomi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121116.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121116.protein.info.v11.5.txt",
		        "node_list_path": "1121116.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpX12014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. X1(2014) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpX12014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1565991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1565991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1565991.protein.info.v11.5.txt",
		        "node_list_path": "1565991.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycetosporaChiangmaiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomycetospora chiangmaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycetosporaChiangmaiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120948.protein.info.v11.5.txt",
		        "node_list_path": "1120948.protein.complete.v11.5.txt"
		    }
		]
    )()

def NannizziaGypseaCbs118893Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nannizzia gypsea CBS 118893 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NannizziaGypseaCbs118893Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "535722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "535722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "535722.clusters.proteins.v11.5.txt",
		        "sequence_path": "535722.protein.sequences.v11.5.fa",
		        "enrichment_path": "535722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "535722.protein.info.v11.5.txt",
		        "node_list_path": "535722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "535722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaloramatorMitchellensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caloramator mitchellensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloramatorMitchellensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "908809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "908809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "908809.clusters.proteins.v11.5.txt",
		        "sequence_path": "908809.protein.sequences.v11.5.fa",
		        "enrichment_path": "908809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908809.protein.info.v11.5.txt",
		        "node_list_path": "908809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "908809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RomboutsiaTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Romboutsia timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RomboutsiaTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776391.protein.info.v11.5.txt",
		        "node_list_path": "1776391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesMangrovisoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces mangrovisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesMangrovisoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1428628.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1428628.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1428628.clusters.proteins.v11.5.txt",
		        "sequence_path": "1428628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1428628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1428628.protein.info.v11.5.txt",
		        "node_list_path": "1428628.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1428628.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslr7277Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR7277 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslr7277Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227352.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227352.protein.info.v11.5.txt",
		        "node_list_path": "1227352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3815(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_38_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3815", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797794.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797794.protein.info.v11.5.txt",
		        "node_list_path": "1797794.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpJsc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. JSC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpJsc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1487953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1487953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1487953.protein.info.v11.5.txt",
		        "node_list_path": "1487953.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho201Full4010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_40_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798593.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798593.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798593.protein.info.v11.5.txt",
		        "node_list_path": "1798593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JiangellaGansuensisDsm44835Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jiangella gansuensis DSM 44835 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JiangellaGansuensisDsm44835Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "987045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "987045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "987045.clusters.proteins.v11.5.txt",
		        "sequence_path": "987045.protein.sequences.v11.5.fa",
		        "enrichment_path": "987045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "987045.protein.info.v11.5.txt",
		        "node_list_path": "987045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "987045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterSulfurreducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter sulfurreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterSulfurreducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243231.clusters.proteins.v11.5.txt",
		        "sequence_path": "243231.protein.sequences.v11.5.fa",
		        "enrichment_path": "243231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243231.protein.info.v11.5.txt",
		        "node_list_path": "243231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalegentibacterSpHeli6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter sp. HelI6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterSpHeli6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1250278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1250278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1250278.clusters.proteins.v11.5.txt",
		        "sequence_path": "1250278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250278.protein.info.v11.5.txt",
		        "node_list_path": "1250278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1250278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumFujikuroiImi58289(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium fujikuroi IMI 58289 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumFujikuroiImi58289", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1279085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1279085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1279085.protein.info.v11.5.txt",
		        "node_list_path": "1279085.protein.complete.v11.5.txt"
		    }
		]
    )()

def AggregatibacterActinomycetemcomitansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterActinomycetemcomitansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "714.clusters.info.v11.5.txt",
		        "cluster_tree_path": "714.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "714.clusters.proteins.v11.5.txt",
		        "sequence_path": "714.protein.sequences.v11.5.fa",
		        "enrichment_path": "714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "714.protein.info.v11.5.txt",
		        "node_list_path": "714.cluster.nodes.v11.5.txt",
		        "edge_list_path": "714.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAviumParatuberculosisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium avium paratuberculosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAviumParatuberculosisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "262316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "262316.clusters.proteins.v11.5.txt",
		        "sequence_path": "262316.protein.sequences.v11.5.fa",
		        "enrichment_path": "262316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262316.protein.info.v11.5.txt",
		        "node_list_path": "262316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "262316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassiosiraOceanicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassiosira oceanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassiosiraOceanicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "159749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "159749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "159749.clusters.proteins.v11.5.txt",
		        "sequence_path": "159749.protein.sequences.v11.5.fa",
		        "enrichment_path": "159749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "159749.protein.info.v11.5.txt",
		        "node_list_path": "159749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "159749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAmyloliquefaciensDc12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens DC-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAmyloliquefaciensDc12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1198291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198291.protein.info.v11.5.txt",
		        "node_list_path": "1198291.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121364.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121364.protein.info.v11.5.txt",
		        "node_list_path": "1121364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf399Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf399 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf399Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736364.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736364.protein.info.v11.5.txt",
		        "node_list_path": "1736364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1301100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1301100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1301100.protein.info.v11.5.txt",
		        "node_list_path": "1301100.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwb14412Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWB1_44_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwb14412Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618748.protein.info.v11.5.txt",
		        "node_list_path": "1618748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCelatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium celatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCelatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "545697.clusters.info.v11.5.txt",
		        "cluster_tree_path": "545697.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "545697.clusters.proteins.v11.5.txt",
		        "sequence_path": "545697.protein.sequences.v11.5.fa",
		        "enrichment_path": "545697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545697.protein.info.v11.5.txt",
		        "node_list_path": "545697.cluster.nodes.v11.5.txt",
		        "edge_list_path": "545697.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrellaAestuarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrella aestuarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrellaAestuarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1166018.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1166018.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1166018.clusters.proteins.v11.5.txt",
		        "sequence_path": "1166018.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166018.protein.info.v11.5.txt",
		        "node_list_path": "1166018.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1166018.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrnithinibacillusScapharcaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ornithinibacillus scapharcae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithinibacillusScapharcaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "981383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "981383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "981383.clusters.proteins.v11.5.txt",
		        "sequence_path": "981383.protein.sequences.v11.5.fa",
		        "enrichment_path": "981383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981383.protein.info.v11.5.txt",
		        "node_list_path": "981383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "981383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlj24(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlj24", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "545276.protein.sequences.v11.5.fa",
		        "enrichment_path": "545276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545276.protein.info.v11.5.txt",
		        "node_list_path": "545276.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp21311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2131.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp21311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855346.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855346.protein.info.v11.5.txt",
		        "node_list_path": "1855346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprococcusEutactusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus eutactus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprococcusEutactusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411474.clusters.proteins.v11.5.txt",
		        "sequence_path": "411474.protein.sequences.v11.5.fa",
		        "enrichment_path": "411474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411474.protein.info.v11.5.txt",
		        "node_list_path": "411474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaeMaculicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae maculicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaeMaculicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "629265.protein.sequences.v11.5.fa",
		        "enrichment_path": "629265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "629265.protein.info.v11.5.txt",
		        "node_list_path": "629265.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorhabdusUtahensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorhabdus utahensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorhabdusUtahensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "519442.clusters.info.v11.5.txt",
		        "cluster_tree_path": "519442.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "519442.clusters.proteins.v11.5.txt",
		        "sequence_path": "519442.protein.sequences.v11.5.fa",
		        "enrichment_path": "519442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519442.protein.info.v11.5.txt",
		        "node_list_path": "519442.cluster.nodes.v11.5.txt",
		        "edge_list_path": "519442.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorientalisSpIm1011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorientalis sp. IM1011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorientalisSpIm1011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1932360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1932360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1932360.protein.info.v11.5.txt",
		        "node_list_path": "1932360.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallionellalesBacteriumGwa25518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_55_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallionellalesBacteriumGwa25518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798244.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798244.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798244.protein.info.v11.5.txt",
		        "node_list_path": "1798244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonomuraeaPusillaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea pusilla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaPusillaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46177.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46177.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46177.clusters.proteins.v11.5.txt",
		        "sequence_path": "46177.protein.sequences.v11.5.fa",
		        "enrichment_path": "46177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46177.protein.info.v11.5.txt",
		        "node_list_path": "46177.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46177.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylosinusSpLw3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylosinus sp. LW3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylosinusSpLw3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "107635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "107635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "107635.clusters.proteins.v11.5.txt",
		        "sequence_path": "107635.protein.sequences.v11.5.fa",
		        "enrichment_path": "107635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "107635.protein.info.v11.5.txt",
		        "node_list_path": "107635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "107635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClavibacterMichiganensisSepedonicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis sepedonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavibacterMichiganensisSepedonicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "31964.protein.sequences.v11.5.fa",
		        "enrichment_path": "31964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31964.protein.info.v11.5.txt",
		        "node_list_path": "31964.protein.complete.v11.5.txt"
		    }
		]
    )()

def RothiaSpNd6we1aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rothia sp. ND6WE1A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RothiaSpNd6we1aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1848190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1848190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1848190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1848190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848190.protein.info.v11.5.txt",
		        "node_list_path": "1848190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1848190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonadaceaeBacteriumCg1026018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium CG1_02_60_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonadaceaeBacteriumCg1026018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805088.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805088.protein.info.v11.5.txt",
		        "node_list_path": "1805088.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaricaulisMaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maricaulis maris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaricaulisMaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "394221.protein.sequences.v11.5.fa",
		        "enrichment_path": "394221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394221.protein.info.v11.5.txt",
		        "node_list_path": "394221.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioAlginolyticus40bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus 40B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioAlginolyticus40bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "674977.clusters.info.v11.5.txt",
		        "cluster_tree_path": "674977.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "674977.clusters.proteins.v11.5.txt",
		        "sequence_path": "674977.protein.sequences.v11.5.fa",
		        "enrichment_path": "674977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "674977.protein.info.v11.5.txt",
		        "node_list_path": "674977.cluster.nodes.v11.5.txt",
		        "edge_list_path": "674977.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanobacteriumAponinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanobacterium aponinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobacteriumAponinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "755178.clusters.info.v11.5.txt",
		        "cluster_tree_path": "755178.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "755178.clusters.proteins.v11.5.txt",
		        "sequence_path": "755178.protein.sequences.v11.5.fa",
		        "enrichment_path": "755178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "755178.protein.info.v11.5.txt",
		        "node_list_path": "755178.cluster.nodes.v11.5.txt",
		        "edge_list_path": "755178.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu024Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu024Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1676160.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1676160.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1676160.clusters.proteins.v11.5.txt",
		        "sequence_path": "1676160.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676160.protein.info.v11.5.txt",
		        "node_list_path": "1676160.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1676160.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumGw2011Gwb24136(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWB2_41_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwb24136", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618982.protein.info.v11.5.txt",
		        "node_list_path": "1618982.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpA2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. A2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpA2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "298701.protein.sequences.v11.5.fa",
		        "enrichment_path": "298701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "298701.protein.info.v11.5.txt",
		        "node_list_path": "298701.protein.complete.v11.5.txt"
		    }
		]
    )()

def AphanomycesInvadans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aphanomyces invadans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AphanomycesInvadans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "157072.protein.sequences.v11.5.fa",
		        "enrichment_path": "157072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157072.protein.info.v11.5.txt",
		        "node_list_path": "157072.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelobacterCarbinolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter carbinolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelobacterCarbinolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "338963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "338963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "338963.clusters.proteins.v11.5.txt",
		        "sequence_path": "338963.protein.sequences.v11.5.fa",
		        "enrichment_path": "338963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "338963.protein.info.v11.5.txt",
		        "node_list_path": "338963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "338963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesPyogenesJcm10003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides pyogenes JCM10003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesPyogenesJcm10003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235813.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235813.protein.info.v11.5.txt",
		        "node_list_path": "1235813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OkibacteriumFritillariae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Okibacterium fritillariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OkibacteriumFritillariae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "123320.protein.sequences.v11.5.fa",
		        "enrichment_path": "123320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "123320.protein.info.v11.5.txt",
		        "node_list_path": "123320.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpR1200b2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. R1200B2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpR1200b2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1509405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1509405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1509405.clusters.proteins.v11.5.txt",
		        "sequence_path": "1509405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1509405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1509405.protein.info.v11.5.txt",
		        "node_list_path": "1509405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1509405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterIndicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterIndicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1341679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341679.protein.info.v11.5.txt",
		        "node_list_path": "1341679.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndozoicomonasMontiporaeCl33Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas montiporae CL-33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndozoicomonasMontiporaeCl33Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "570277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "570277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "570277.clusters.proteins.v11.5.txt",
		        "sequence_path": "570277.protein.sequences.v11.5.fa",
		        "enrichment_path": "570277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570277.protein.info.v11.5.txt",
		        "node_list_path": "570277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "570277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EctocarpusSiliculosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ectocarpus siliculosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctocarpusSiliculosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2880.protein.sequences.v11.5.fa",
		        "enrichment_path": "2880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2880.protein.info.v11.5.txt",
		        "node_list_path": "2880.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrobaculumSpWp30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum sp. WP30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumSpWp30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227555.protein.info.v11.5.txt",
		        "node_list_path": "1227555.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumThermoresistibile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium thermoresistibile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumThermoresistibile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1078020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078020.protein.info.v11.5.txt",
		        "node_list_path": "1078020.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaGrimesii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia grimesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaGrimesii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "82995.protein.sequences.v11.5.fa",
		        "enrichment_path": "82995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82995.protein.info.v11.5.txt",
		        "node_list_path": "82995.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaSpWwm596(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina sp. WWM596 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaSpWwm596", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434103.protein.info.v11.5.txt",
		        "node_list_path": "1434103.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumPuniceum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium puniceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPuniceum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29367.protein.sequences.v11.5.fa",
		        "enrichment_path": "29367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29367.protein.info.v11.5.txt",
		        "node_list_path": "29367.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumKansasii732Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii 732 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumKansasii732Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1299327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1299327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1299327.clusters.proteins.v11.5.txt",
		        "sequence_path": "1299327.protein.sequences.v11.5.fa",
		        "enrichment_path": "1299327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1299327.protein.info.v11.5.txt",
		        "node_list_path": "1299327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1299327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterJejuni81176(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter jejuni 81176 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterJejuni81176", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "354242.protein.sequences.v11.5.fa",
		        "enrichment_path": "354242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "354242.protein.info.v11.5.txt",
		        "node_list_path": "354242.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterCrystallopoietes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter crystallopoietes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterCrystallopoietes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37928.protein.sequences.v11.5.fa",
		        "enrichment_path": "37928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37928.protein.info.v11.5.txt",
		        "node_list_path": "37928.protein.complete.v11.5.txt"
		    }
		]
    )()

def TsukamurellaPseudospumaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tsukamurella pseudospumae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TsukamurellaPseudospumaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "239498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "239498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "239498.clusters.proteins.v11.5.txt",
		        "sequence_path": "239498.protein.sequences.v11.5.fa",
		        "enrichment_path": "239498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "239498.protein.info.v11.5.txt",
		        "node_list_path": "239498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "239498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph899(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH899 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph899", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217710.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217710.protein.info.v11.5.txt",
		        "node_list_path": "1217710.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCalifornicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces californicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCalifornicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67281.protein.sequences.v11.5.fa",
		        "enrichment_path": "67281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67281.protein.info.v11.5.txt",
		        "node_list_path": "67281.protein.complete.v11.5.txt"
		    }
		]
    )()

def KnoelliaAerolataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Knoellia aerolata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KnoelliaAerolataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385519.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385519.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385519.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385519.protein.info.v11.5.txt",
		        "node_list_path": "1385519.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385519.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusDelbrueckiiBulgaricusAtcc11842Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii bulgaricus ATCC 11842 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusDelbrueckiiBulgaricusAtcc11842Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "390333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "390333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "390333.clusters.proteins.v11.5.txt",
		        "sequence_path": "390333.protein.sequences.v11.5.fa",
		        "enrichment_path": "390333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390333.protein.info.v11.5.txt",
		        "node_list_path": "390333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "390333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterConcisusAtcc51562(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter concisus ATCC51562 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterConcisusAtcc51562", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1242969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1242969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1242969.protein.info.v11.5.txt",
		        "node_list_path": "1242969.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpS17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. S17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpS17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1007104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007104.protein.info.v11.5.txt",
		        "node_list_path": "1007104.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusNubinhibensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius nubinhibens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusNubinhibensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "89187.clusters.info.v11.5.txt",
		        "cluster_tree_path": "89187.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "89187.clusters.proteins.v11.5.txt",
		        "sequence_path": "89187.protein.sequences.v11.5.fa",
		        "enrichment_path": "89187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89187.protein.info.v11.5.txt",
		        "node_list_path": "89187.cluster.nodes.v11.5.txt",
		        "edge_list_path": "89187.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumPseudolongum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumPseudolongum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "31954.protein.sequences.v11.5.fa",
		        "enrichment_path": "31954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31954.protein.info.v11.5.txt",
		        "node_list_path": "31954.protein.complete.v11.5.txt"
		    }
		]
    )()

def CosenzaeaMyxofaciensAtcc19692Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cosenzaea myxofaciens ATCC 19692 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CosenzaeaMyxofaciensAtcc19692Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354337.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354337.protein.info.v11.5.txt",
		        "node_list_path": "1354337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaAtypicaAcs049vsch6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella atypica ACS049VSch6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaAtypicaAcs049vsch6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "866776.clusters.info.v11.5.txt",
		        "cluster_tree_path": "866776.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "866776.clusters.proteins.v11.5.txt",
		        "sequence_path": "866776.protein.sequences.v11.5.fa",
		        "enrichment_path": "866776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866776.protein.info.v11.5.txt",
		        "node_list_path": "866776.cluster.nodes.v11.5.txt",
		        "edge_list_path": "866776.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRhodolunaPlanktonicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rhodoluna planktonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRhodolunaPlanktonicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "535712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "535712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "535712.clusters.proteins.v11.5.txt",
		        "sequence_path": "535712.protein.sequences.v11.5.fa",
		        "enrichment_path": "535712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "535712.protein.info.v11.5.txt",
		        "node_list_path": "535712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "535712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophagaThiooxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga thiooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaThiooxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "392484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "392484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "392484.clusters.proteins.v11.5.txt",
		        "sequence_path": "392484.protein.sequences.v11.5.fa",
		        "enrichment_path": "392484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392484.protein.info.v11.5.txt",
		        "node_list_path": "392484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "392484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerpetosiphonAurantiacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herpetosiphon aurantiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerpetosiphonAurantiacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316274.protein.sequences.v11.5.fa",
		        "enrichment_path": "316274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316274.protein.info.v11.5.txt",
		        "node_list_path": "316274.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsphigho202Full4011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO2_02_FULL_40_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho202Full4011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797858.protein.info.v11.5.txt",
		        "node_list_path": "1797858.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag440(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag440", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262807.protein.info.v11.5.txt",
		        "node_list_path": "1262807.protein.complete.v11.5.txt"
		    }
		]
    )()

def DufoureaNovaeangliae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dufourea novaeangliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DufoureaNovaeangliae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "178035.protein.sequences.v11.5.fa",
		        "enrichment_path": "178035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178035.protein.info.v11.5.txt",
		        "node_list_path": "178035.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcanthamoebaCastellaniiStrNeffCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acanthamoeba castellanii str. Neff Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcanthamoebaCastellaniiStrNeffCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1257118.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1257118.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1257118.clusters.proteins.v11.5.txt",
		        "sequence_path": "1257118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1257118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1257118.protein.info.v11.5.txt",
		        "node_list_path": "1257118.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1257118.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusLentusNbrc16444Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus lentus NBRC 16444 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLentusNbrc16444Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348624.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348624.protein.info.v11.5.txt",
		        "node_list_path": "1348624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacterTundripaludumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacter tundripaludum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacterTundripaludumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "697282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "697282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "697282.clusters.proteins.v11.5.txt",
		        "sequence_path": "697282.protein.sequences.v11.5.fa",
		        "enrichment_path": "697282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "697282.protein.info.v11.5.txt",
		        "node_list_path": "697282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "697282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CicerArietinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cicer arietinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CicerArietinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3827.protein.sequences.v11.5.fa",
		        "enrichment_path": "3827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3827.protein.info.v11.5.txt",
		        "node_list_path": "3827.protein.complete.v11.5.txt"
		    }
		]
    )()

def TesticulariaCyperiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Testicularia cyperi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TesticulariaCyperiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882483.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882483.protein.info.v11.5.txt",
		        "node_list_path": "1882483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanimonasSmirnovii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanimonas smirnovii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanimonasSmirnovii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1279015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1279015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1279015.protein.info.v11.5.txt",
		        "node_list_path": "1279015.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpF0262Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0262 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpF0262Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "608534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "608534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "608534.clusters.proteins.v11.5.txt",
		        "sequence_path": "608534.protein.sequences.v11.5.fa",
		        "enrichment_path": "608534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "608534.protein.info.v11.5.txt",
		        "node_list_path": "608534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "608534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusTibetensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus tibetensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusTibetensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "336292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "336292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "336292.clusters.proteins.v11.5.txt",
		        "sequence_path": "336292.protein.sequences.v11.5.fa",
		        "enrichment_path": "336292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336292.protein.info.v11.5.txt",
		        "node_list_path": "336292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "336292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DoreaLongicatenaDsm13814Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea longicatena DSM13814 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaLongicatenaDsm13814Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411462.clusters.proteins.v11.5.txt",
		        "sequence_path": "411462.protein.sequences.v11.5.fa",
		        "enrichment_path": "411462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411462.protein.info.v11.5.txt",
		        "node_list_path": "411462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonasMacleodiiDeepCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Deep Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasMacleodiiDeepCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314275.clusters.proteins.v11.5.txt",
		        "sequence_path": "314275.protein.sequences.v11.5.fa",
		        "enrichment_path": "314275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314275.protein.info.v11.5.txt",
		        "node_list_path": "314275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusIntermedius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus intermedius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusIntermedius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1141106.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141106.protein.info.v11.5.txt",
		        "node_list_path": "1141106.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaVaviloviae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea vaviloviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaVaviloviae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1526658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1526658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1526658.protein.info.v11.5.txt",
		        "node_list_path": "1526658.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwa26223(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_62_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwa26223", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797924.protein.info.v11.5.txt",
		        "node_list_path": "1797924.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeotrichumCandidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geotrichum candidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeotrichumCandidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173061.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173061.protein.info.v11.5.txt",
		        "node_list_path": "1173061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerticilliumDahliae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verticillium dahliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerticilliumDahliae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "27337.protein.sequences.v11.5.fa",
		        "enrichment_path": "27337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27337.protein.info.v11.5.txt",
		        "node_list_path": "27337.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoniliophthoraPerniciosaFa553(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moniliophthora perniciosa FA553 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoniliophthoraPerniciosaFa553", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "554373.protein.sequences.v11.5.fa",
		        "enrichment_path": "554373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "554373.protein.info.v11.5.txt",
		        "node_list_path": "554373.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumNor53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium NOR53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumNor53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "566466.clusters.info.v11.5.txt",
		        "cluster_tree_path": "566466.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "566466.clusters.proteins.v11.5.txt",
		        "sequence_path": "566466.protein.sequences.v11.5.fa",
		        "enrichment_path": "566466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "566466.protein.info.v11.5.txt",
		        "node_list_path": "566466.cluster.nodes.v11.5.txt",
		        "edge_list_path": "566466.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110054Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110054 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110054Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1570343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1570343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1570343.clusters.proteins.v11.5.txt",
		        "sequence_path": "1570343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570343.protein.info.v11.5.txt",
		        "node_list_path": "1570343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1570343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumGonidiaformansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium gonidiaformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumGonidiaformansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469615.clusters.proteins.v11.5.txt",
		        "sequence_path": "469615.protein.sequences.v11.5.fa",
		        "enrichment_path": "469615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469615.protein.info.v11.5.txt",
		        "node_list_path": "469615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GallaecimonasPentaromativoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallaecimonas pentaromativorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallaecimonasPentaromativoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "584787.clusters.info.v11.5.txt",
		        "cluster_tree_path": "584787.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "584787.clusters.proteins.v11.5.txt",
		        "sequence_path": "584787.protein.sequences.v11.5.fa",
		        "enrichment_path": "584787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "584787.protein.info.v11.5.txt",
		        "node_list_path": "584787.cluster.nodes.v11.5.txt",
		        "edge_list_path": "584787.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaAcidipaludisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia acidipaludis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaAcidipaludisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218074.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218074.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218074.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218074.protein.info.v11.5.txt",
		        "node_list_path": "1218074.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218074.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu073(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU073 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu073", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671657.protein.info.v11.5.txt",
		        "node_list_path": "1671657.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSp2kl27(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 2KL-27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSp2kl27", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1100705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1100705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1100705.protein.info.v11.5.txt",
		        "node_list_path": "1100705.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumNiameyense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium niameyense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumNiameyense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1622073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622073.protein.info.v11.5.txt",
		        "node_list_path": "1622073.protein.complete.v11.5.txt"
		    }
		]
    )()

def PectobacteriumBrasilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium brasiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumBrasilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "180957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "180957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "180957.clusters.proteins.v11.5.txt",
		        "sequence_path": "180957.protein.sequences.v11.5.fa",
		        "enrichment_path": "180957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180957.protein.info.v11.5.txt",
		        "node_list_path": "180957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "180957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PanicumVirgatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Panicum virgatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PanicumVirgatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "38727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "38727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "38727.clusters.proteins.v11.5.txt",
		        "sequence_path": "38727.protein.sequences.v11.5.fa",
		        "enrichment_path": "38727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38727.protein.info.v11.5.txt",
		        "node_list_path": "38727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "38727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSacchari(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSacchari", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1399419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399419.protein.info.v11.5.txt",
		        "node_list_path": "1399419.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfobacteriumHydrogeniphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium hydrogeniphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfobacteriumHydrogeniphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "161156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "161156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "161156.clusters.proteins.v11.5.txt",
		        "sequence_path": "161156.protein.sequences.v11.5.fa",
		        "enrichment_path": "161156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161156.protein.info.v11.5.txt",
		        "node_list_path": "161156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "161156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OstreococcusLucimarinusCce9901(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ostreococcus lucimarinus CCE9901 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OstreococcusLucimarinusCce9901", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "436017.protein.sequences.v11.5.fa",
		        "enrichment_path": "436017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436017.protein.info.v11.5.txt",
		        "node_list_path": "436017.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumMola814(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium MOLA814 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumMola814", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408164.protein.info.v11.5.txt",
		        "node_list_path": "1408164.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovibacillusThermophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novibacillus thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovibacillusThermophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1471761.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471761.protein.info.v11.5.txt",
		        "node_list_path": "1471761.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpBiwako01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. BIWAKO-01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpBiwako01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "506668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "506668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "506668.clusters.proteins.v11.5.txt",
		        "sequence_path": "506668.protein.sequences.v11.5.fa",
		        "enrichment_path": "506668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "506668.protein.info.v11.5.txt",
		        "node_list_path": "506668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "506668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyroidesInjenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myroides injenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyroidesInjenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1008457.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1008457.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1008457.clusters.proteins.v11.5.txt",
		        "sequence_path": "1008457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1008457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1008457.protein.info.v11.5.txt",
		        "node_list_path": "1008457.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1008457.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EdwardsiellaTardaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Edwardsiella tarda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EdwardsiellaTardaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "636.clusters.info.v11.5.txt",
		        "cluster_tree_path": "636.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "636.clusters.proteins.v11.5.txt",
		        "sequence_path": "636.protein.sequences.v11.5.fa",
		        "enrichment_path": "636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "636.protein.info.v11.5.txt",
		        "node_list_path": "636.cluster.nodes.v11.5.txt",
		        "edge_list_path": "636.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterSpYe315(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter sp. YE315 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterSpYe315", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1609968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1609968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1609968.protein.info.v11.5.txt",
		        "node_list_path": "1609968.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesJenseniiJcm1364Nbrc14755Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides jensenii JCM 1364 NBRC 14755 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesJenseniiJcm1364Nbrc14755Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1303683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1303683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1303683.clusters.proteins.v11.5.txt",
		        "sequence_path": "1303683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1303683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1303683.protein.info.v11.5.txt",
		        "node_list_path": "1303683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1303683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalviaSplendens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salvia splendens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalviaSplendens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "180675.protein.sequences.v11.5.fa",
		        "enrichment_path": "180675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180675.protein.info.v11.5.txt",
		        "node_list_path": "180675.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanocellaPaludicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocella paludicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocellaPaludicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "304371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "304371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "304371.clusters.proteins.v11.5.txt",
		        "sequence_path": "304371.protein.sequences.v11.5.fa",
		        "enrichment_path": "304371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "304371.protein.info.v11.5.txt",
		        "node_list_path": "304371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "304371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusKrulwichiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus krulwichiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusKrulwichiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "199441.protein.sequences.v11.5.fa",
		        "enrichment_path": "199441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "199441.protein.info.v11.5.txt",
		        "node_list_path": "199441.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSepticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium septicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSepticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504.protein.info.v11.5.txt",
		        "node_list_path": "1504.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterSpRoot96(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterSpRoot96", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736612.protein.info.v11.5.txt",
		        "node_list_path": "1736612.protein.complete.v11.5.txt"
		    }
		]
    )()

def DialisterMicraerophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dialister micraerophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterMicraerophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888062.protein.sequences.v11.5.fa",
		        "enrichment_path": "888062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888062.protein.info.v11.5.txt",
		        "node_list_path": "888062.protein.complete.v11.5.txt"
		    }
		]
    )()

def Sar86ClusterBacteriumSar86e(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium SAR86E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar86ClusterBacteriumSar86e", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208365.protein.info.v11.5.txt",
		        "node_list_path": "1208365.protein.complete.v11.5.txt"
		    }
		]
    )()

def RamlibacterTataouinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ramlibacter tataouinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RamlibacterTataouinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "365046.protein.sequences.v11.5.fa",
		        "enrichment_path": "365046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "365046.protein.info.v11.5.txt",
		        "node_list_path": "365046.protein.complete.v11.5.txt"
		    }
		]
    )()

def ViridibacillusArviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Viridibacillus arvi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ViridibacillusArviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "263475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "263475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "263475.clusters.proteins.v11.5.txt",
		        "sequence_path": "263475.protein.sequences.v11.5.fa",
		        "enrichment_path": "263475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263475.protein.info.v11.5.txt",
		        "node_list_path": "263475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "263475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OxalobacterFormigenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OxalobacterFormigenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "847.protein.sequences.v11.5.fa",
		        "enrichment_path": "847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "847.protein.info.v11.5.txt",
		        "node_list_path": "847.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpPhil15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. Phil15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpPhil15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930000.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930000.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930000.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930000.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930000.protein.info.v11.5.txt",
		        "node_list_path": "1930000.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930000.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807742.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807742.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807742.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807742.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807742.protein.info.v11.5.txt",
		        "node_list_path": "1807742.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807742.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAbawacabacteriaBacteriumRbg164210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Abawacabacteria bacterium RBG_16_42_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAbawacabacteriaBacteriumRbg164210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817814.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817814.protein.info.v11.5.txt",
		        "node_list_path": "1817814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomaduraLatinaNbrc106108(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura latina NBRC 106108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraLatinaNbrc106108", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220563.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220563.protein.info.v11.5.txt",
		        "node_list_path": "1220563.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumSp46296Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum sp. 46_296 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumSp46296Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635262.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635262.protein.info.v11.5.txt",
		        "node_list_path": "1635262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSp9096Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. 9096 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSp9096Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500894.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500894.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500894.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500894.protein.info.v11.5.txt",
		        "node_list_path": "1500894.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500894.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpAe2015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE2015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpAe2015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280663.protein.info.v11.5.txt",
		        "node_list_path": "1280663.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastomycesSilveraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces silverae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomycesSilveraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2060906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2060906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2060906.clusters.proteins.v11.5.txt",
		        "sequence_path": "2060906.protein.sequences.v11.5.fa",
		        "enrichment_path": "2060906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2060906.protein.info.v11.5.txt",
		        "node_list_path": "2060906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2060906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SedimentisphaeraSalicampi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sedimentisphaera salicampi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SedimentisphaeraSalicampi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1941349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1941349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1941349.protein.info.v11.5.txt",
		        "node_list_path": "1941349.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaAnanassae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila ananassae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaAnanassae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7217.protein.sequences.v11.5.fa",
		        "enrichment_path": "7217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7217.protein.info.v11.5.txt",
		        "node_list_path": "7217.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlj11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlj11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158760.protein.info.v11.5.txt",
		        "node_list_path": "1158760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph809Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH809 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph809Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217713.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217713.protein.info.v11.5.txt",
		        "node_list_path": "1217713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynesporaCassiicolaPhilippines(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynespora cassiicola Philippines graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynesporaCassiicolaPhilippines", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1448308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448308.protein.info.v11.5.txt",
		        "node_list_path": "1448308.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterPiscatoriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter piscatorii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterPiscatoriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "554343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "554343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "554343.clusters.proteins.v11.5.txt",
		        "sequence_path": "554343.protein.sequences.v11.5.fa",
		        "enrichment_path": "554343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "554343.protein.info.v11.5.txt",
		        "node_list_path": "554343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "554343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumVaginae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium vaginae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumVaginae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "82135.protein.sequences.v11.5.fa",
		        "enrichment_path": "82135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82135.protein.info.v11.5.txt",
		        "node_list_path": "82135.protein.complete.v11.5.txt"
		    }
		]
    )()

def SkermaniaPiniformisNbrc15059(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Skermania piniformis NBRC 15059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SkermaniaPiniformisNbrc15059", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223536.protein.info.v11.5.txt",
		        "node_list_path": "1223536.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalyomorphaHalysCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halyomorpha halys Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalyomorphaHalysCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235990.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235990.protein.info.v11.5.txt",
		        "node_list_path": "1235990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSulciaMuelleriSmdsemCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri SMDSEM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSulciaMuelleriSmdsemCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "595499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "595499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "595499.clusters.proteins.v11.5.txt",
		        "sequence_path": "595499.protein.sequences.v11.5.fa",
		        "enrichment_path": "595499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595499.protein.info.v11.5.txt",
		        "node_list_path": "595499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "595499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusSpFf7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus sp. FF7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusSpFf7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461579.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461579.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461579.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461579.protein.info.v11.5.txt",
		        "node_list_path": "1461579.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461579.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusFlavithermusTno09006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus TNO09006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusFlavithermusTno09006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267580.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267580.protein.info.v11.5.txt",
		        "node_list_path": "1267580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag924(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:924 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag924", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262938.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262938.protein.info.v11.5.txt",
		        "node_list_path": "1262938.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSolisilvaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus solisilvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSolisilvaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1516104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1516104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1516104.clusters.proteins.v11.5.txt",
		        "sequence_path": "1516104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1516104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1516104.protein.info.v11.5.txt",
		        "node_list_path": "1516104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1516104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoplasmaFlorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesoplasma florum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoplasmaFlorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "265311.clusters.info.v11.5.txt",
		        "cluster_tree_path": "265311.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "265311.clusters.proteins.v11.5.txt",
		        "sequence_path": "265311.protein.sequences.v11.5.fa",
		        "enrichment_path": "265311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265311.protein.info.v11.5.txt",
		        "node_list_path": "265311.cluster.nodes.v11.5.txt",
		        "edge_list_path": "265311.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusIndicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusIndicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "540747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "540747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "540747.clusters.proteins.v11.5.txt",
		        "sequence_path": "540747.protein.sequences.v11.5.fa",
		        "enrichment_path": "540747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "540747.protein.info.v11.5.txt",
		        "node_list_path": "540747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "540747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PusillimonasSpT77(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pusillimonas sp. T77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PusillimonasSpT77", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1007105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007105.protein.info.v11.5.txt",
		        "node_list_path": "1007105.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSulciaMuelleriCariCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri CARI Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSulciaMuelleriCariCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "706194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "706194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "706194.clusters.proteins.v11.5.txt",
		        "sequence_path": "706194.protein.sequences.v11.5.fa",
		        "enrichment_path": "706194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706194.protein.info.v11.5.txt",
		        "node_list_path": "706194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "706194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaBusckii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila busckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaBusckii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "30019.protein.sequences.v11.5.fa",
		        "enrichment_path": "30019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30019.protein.info.v11.5.txt",
		        "node_list_path": "30019.protein.complete.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaUaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaUaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005057.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005057.protein.info.v11.5.txt",
		        "node_list_path": "1005057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonlabensMarinusS108(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens marinus S1-08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensMarinusS108", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1454201.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454201.protein.info.v11.5.txt",
		        "node_list_path": "1454201.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3815Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_38_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3815Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797794.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797794.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797794.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797794.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797794.protein.info.v11.5.txt",
		        "node_list_path": "1797794.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797794.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArsenophonusEndosymbiontCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arsenophonus endosymbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArsenophonusEndosymbiontCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1247024.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1247024.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1247024.clusters.proteins.v11.5.txt",
		        "sequence_path": "1247024.protein.sequences.v11.5.fa",
		        "enrichment_path": "1247024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1247024.protein.info.v11.5.txt",
		        "node_list_path": "1247024.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1247024.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumJaponicum22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum 22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumJaponicum22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304877.protein.info.v11.5.txt",
		        "node_list_path": "1304877.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrococcusSpHmsc067e09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micrococcus sp. HMSC067E09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcusSpHmsc067e09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739367.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739367.protein.info.v11.5.txt",
		        "node_list_path": "1739367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9314(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9314", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "167548.protein.sequences.v11.5.fa",
		        "enrichment_path": "167548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167548.protein.info.v11.5.txt",
		        "node_list_path": "167548.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpNfr03(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpNfr03", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566263.protein.info.v11.5.txt",
		        "node_list_path": "1566263.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlammeovirgaceaeBacterium311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flammeovirgaceae bacterium 311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlammeovirgaceaeBacterium311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1257021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1257021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1257021.clusters.proteins.v11.5.txt",
		        "sequence_path": "1257021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1257021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1257021.protein.info.v11.5.txt",
		        "node_list_path": "1257021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1257021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AerococcusSuisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus suis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusSuisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "371602.clusters.info.v11.5.txt",
		        "cluster_tree_path": "371602.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "371602.clusters.proteins.v11.5.txt",
		        "sequence_path": "371602.protein.sequences.v11.5.fa",
		        "enrichment_path": "371602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "371602.protein.info.v11.5.txt",
		        "node_list_path": "371602.cluster.nodes.v11.5.txt",
		        "edge_list_path": "371602.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PromicromonosporaKroppenstedtiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Promicromonospora kroppenstedtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PromicromonosporaKroppenstedtiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926564.clusters.proteins.v11.5.txt",
		        "sequence_path": "926564.protein.sequences.v11.5.fa",
		        "enrichment_path": "926564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926564.protein.info.v11.5.txt",
		        "node_list_path": "926564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusGp2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus GP2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusGp2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59925.protein.sequences.v11.5.fa",
		        "enrichment_path": "59925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59925.protein.info.v11.5.txt",
		        "node_list_path": "59925.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumMarinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumMarinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216594.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216594.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216594.clusters.proteins.v11.5.txt",
		        "sequence_path": "216594.protein.sequences.v11.5.fa",
		        "enrichment_path": "216594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216594.protein.info.v11.5.txt",
		        "node_list_path": "216594.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216594.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseobacterLitoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterLitoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391595.clusters.proteins.v11.5.txt",
		        "sequence_path": "391595.protein.sequences.v11.5.fa",
		        "enrichment_path": "391595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391595.protein.info.v11.5.txt",
		        "node_list_path": "391595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumCaspActino5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium casp-actino5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumCaspActino5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1661702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661702.protein.info.v11.5.txt",
		        "node_list_path": "1661702.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarivitaHallyeonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marivita hallyeonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivitaHallyeonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "996342.protein.sequences.v11.5.fa",
		        "enrichment_path": "996342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "996342.protein.info.v11.5.txt",
		        "node_list_path": "996342.protein.complete.v11.5.txt"
		    }
		]
    )()

def DickeyaSpNcppb569(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya sp. NCPPB569 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaSpNcppb569", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "568768.protein.sequences.v11.5.fa",
		        "enrichment_path": "568768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568768.protein.info.v11.5.txt",
		        "node_list_path": "568768.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasConfluentisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas confluentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasConfluentisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1656094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1656094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1656094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1656094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1656094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1656094.protein.info.v11.5.txt",
		        "node_list_path": "1656094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1656094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpArh5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ARh5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpArh5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158183.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158183.protein.info.v11.5.txt",
		        "node_list_path": "1158183.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasGingivalisAtcc33277(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis ATCC33277 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasGingivalisAtcc33277", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "431947.protein.sequences.v11.5.fa",
		        "enrichment_path": "431947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431947.protein.info.v11.5.txt",
		        "node_list_path": "431947.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpTcuHl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TCU-HL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpTcuHl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1856685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1856685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1856685.protein.info.v11.5.txt",
		        "node_list_path": "1856685.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpBh333Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. BH-3-3-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpBh333Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906742.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906742.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906742.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906742.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906742.protein.info.v11.5.txt",
		        "node_list_path": "1906742.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906742.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpAsbs410(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ASBs410 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpAsbs410", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304866.protein.info.v11.5.txt",
		        "node_list_path": "1304866.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobacterSpOv335(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobacter sp. OV335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobacterSpOv335", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500264.protein.info.v11.5.txt",
		        "node_list_path": "1500264.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumRifoxyd12Full4821Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFOXYD12_FULL_48_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifoxyd12Full4821Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802562.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802562.protein.info.v11.5.txt",
		        "node_list_path": "1802562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpDoa9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. DOA9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpDoa9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1126627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1126627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1126627.clusters.proteins.v11.5.txt",
		        "sequence_path": "1126627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1126627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1126627.protein.info.v11.5.txt",
		        "node_list_path": "1126627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1126627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumAcidaminophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium acidaminophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumAcidaminophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1286171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286171.protein.info.v11.5.txt",
		        "node_list_path": "1286171.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagirhabdusAlkalitoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagirhabdus alkalitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagirhabdusAlkalitoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1612202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1612202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1612202.clusters.proteins.v11.5.txt",
		        "sequence_path": "1612202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1612202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1612202.protein.info.v11.5.txt",
		        "node_list_path": "1612202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1612202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobiumSpGbchlb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium sp. GBChlB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumSpGbchlb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1519464.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519464.protein.info.v11.5.txt",
		        "node_list_path": "1519464.protein.complete.v11.5.txt"
		    }
		]
    )()

def NisaeaDenitrificansDsm18348(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nisaea denitrificans DSM 18348 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NisaeaDenitrificansDsm18348", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122607.protein.info.v11.5.txt",
		        "node_list_path": "1122607.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumGw2011Gwd23842(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium GW2011_GWD2_38_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumGw2011Gwd23842", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618637.protein.info.v11.5.txt",
		        "node_list_path": "1618637.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGhanaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces ghanaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGhanaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "566461.protein.sequences.v11.5.fa",
		        "enrichment_path": "566461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "566461.protein.info.v11.5.txt",
		        "node_list_path": "566461.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaeBacteriumGwa25015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium GWA2_50_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaeBacteriumGwa25015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797595.protein.info.v11.5.txt",
		        "node_list_path": "1797595.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphaeroformaArcticaJp610Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaeroforma arctica JP610 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaeroformaArcticaJp610Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "667725.clusters.info.v11.5.txt",
		        "cluster_tree_path": "667725.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "667725.clusters.proteins.v11.5.txt",
		        "sequence_path": "667725.protein.sequences.v11.5.fa",
		        "enrichment_path": "667725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667725.protein.info.v11.5.txt",
		        "node_list_path": "667725.cluster.nodes.v11.5.txt",
		        "edge_list_path": "667725.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MacrophominaPhaseolinaMs6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Macrophomina phaseolina MS6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacrophominaPhaseolinaMs6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1126212.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1126212.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1126212.clusters.proteins.v11.5.txt",
		        "sequence_path": "1126212.protein.sequences.v11.5.fa",
		        "enrichment_path": "1126212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1126212.protein.info.v11.5.txt",
		        "node_list_path": "1126212.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1126212.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnsiferAlkalisoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer alkalisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferAlkalisoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752398.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752398.protein.info.v11.5.txt",
		        "node_list_path": "1752398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpKm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. KM-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpKm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "590061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "590061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "590061.clusters.proteins.v11.5.txt",
		        "sequence_path": "590061.protein.sequences.v11.5.fa",
		        "enrichment_path": "590061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "590061.protein.info.v11.5.txt",
		        "node_list_path": "590061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "590061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinimonasKoreensisDsm17726(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinimonas koreensis DSM 17726 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinimonasKoreensisDsm17726", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121278.protein.info.v11.5.txt",
		        "node_list_path": "1121278.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusHarenaeDsm16969Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus harenae DSM 16969 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusHarenaeDsm16969Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122920.protein.info.v11.5.txt",
		        "node_list_path": "1122920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StigmatellaAurantiaca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stigmatella aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StigmatellaAurantiaca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "378806.protein.sequences.v11.5.fa",
		        "enrichment_path": "378806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "378806.protein.info.v11.5.txt",
		        "node_list_path": "378806.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc078h07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC078H07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc078h07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739379.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739379.protein.info.v11.5.txt",
		        "node_list_path": "1739379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxTemperans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax temperans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxTemperans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "80878.protein.sequences.v11.5.fa",
		        "enrichment_path": "80878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80878.protein.info.v11.5.txt",
		        "node_list_path": "80878.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnidentifiedEubacteriumScb49Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return unidentified eubacterium SCB49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnidentifiedEubacteriumScb49Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "50743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "50743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "50743.clusters.proteins.v11.5.txt",
		        "sequence_path": "50743.protein.sequences.v11.5.fa",
		        "enrichment_path": "50743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50743.protein.info.v11.5.txt",
		        "node_list_path": "50743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "50743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterPyloriJ99Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori J99 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterPyloriJ99Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "85963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "85963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "85963.clusters.proteins.v11.5.txt",
		        "sequence_path": "85963.protein.sequences.v11.5.fa",
		        "enrichment_path": "85963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85963.protein.info.v11.5.txt",
		        "node_list_path": "85963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "85963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisColoradensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis coloradensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisColoradensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "76021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "76021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "76021.clusters.proteins.v11.5.txt",
		        "sequence_path": "76021.protein.sequences.v11.5.fa",
		        "enrichment_path": "76021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76021.protein.info.v11.5.txt",
		        "node_list_path": "76021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "76021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg166022(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_60_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg166022", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797656.protein.info.v11.5.txt",
		        "node_list_path": "1797656.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesShahiiWal8301Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes shahii WAL 8301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesShahiiWal8301Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717959.clusters.proteins.v11.5.txt",
		        "sequence_path": "717959.protein.sequences.v11.5.fa",
		        "enrichment_path": "717959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717959.protein.info.v11.5.txt",
		        "node_list_path": "717959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MameliellaAlba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mameliella alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MameliellaAlba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "561184.protein.sequences.v11.5.fa",
		        "enrichment_path": "561184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561184.protein.info.v11.5.txt",
		        "node_list_path": "561184.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusGilvusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus gilvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusGilvusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158614.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158614.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158614.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158614.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158614.protein.info.v11.5.txt",
		        "node_list_path": "1158614.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158614.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsphigho201Full4522Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_01_FULL_45_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho201Full4522Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802114.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802114.protein.info.v11.5.txt",
		        "node_list_path": "1802114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlterileibacteriumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alterileibacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlterileibacteriumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1870997.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1870997.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1870997.clusters.proteins.v11.5.txt",
		        "sequence_path": "1870997.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870997.protein.info.v11.5.txt",
		        "node_list_path": "1870997.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1870997.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanoplanusLimicolaDsm2279(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanoplanus limicola DSM 2279 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoplanusLimicolaDsm2279", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "937775.protein.sequences.v11.5.fa",
		        "enrichment_path": "937775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937775.protein.info.v11.5.txt",
		        "node_list_path": "937775.protein.complete.v11.5.txt"
		    }
		]
    )()

def RufibacterRuber(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rufibacter ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RufibacterRuber", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1783499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1783499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1783499.protein.info.v11.5.txt",
		        "node_list_path": "1783499.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4226Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_42_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4226Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797729.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797729.protein.info.v11.5.txt",
		        "node_list_path": "1797729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusVelezensisYauB9601Y2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus velezensis YAU B9601-Y2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusVelezensisYauB9601Y2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1155777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1155777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1155777.clusters.proteins.v11.5.txt",
		        "sequence_path": "1155777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1155777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1155777.protein.info.v11.5.txt",
		        "node_list_path": "1155777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1155777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaPneumoniaeTw183Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae TW183 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaPneumoniaeTw183Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "182082.clusters.info.v11.5.txt",
		        "cluster_tree_path": "182082.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "182082.clusters.proteins.v11.5.txt",
		        "sequence_path": "182082.protein.sequences.v11.5.fa",
		        "enrichment_path": "182082.protein.enrichment.terms.v11.5.txt",
		        "info_path": "182082.protein.info.v11.5.txt",
		        "node_list_path": "182082.cluster.nodes.v11.5.txt",
		        "edge_list_path": "182082.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSpRoot413d1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. Root413D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpRoot413d1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736531.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736531.protein.info.v11.5.txt",
		        "node_list_path": "1736531.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926286.protein.info.v11.5.txt",
		        "node_list_path": "1926286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetarhiziumRileyiRcef4871(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium rileyi RCEF 4871 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetarhiziumRileyiRcef4871", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1081105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081105.protein.info.v11.5.txt",
		        "node_list_path": "1081105.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioFairfieldensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio fairfieldensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioFairfieldensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44742.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44742.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44742.clusters.proteins.v11.5.txt",
		        "sequence_path": "44742.protein.sequences.v11.5.fa",
		        "enrichment_path": "44742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44742.protein.info.v11.5.txt",
		        "node_list_path": "44742.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44742.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRifcsplowo212Full6819(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO2_12_FULL_68_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212Full6819", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797194.protein.info.v11.5.txt",
		        "node_list_path": "1797194.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedCandidatusPoseidonialesArchaeon(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Candidatus Poseidoniales archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedCandidatusPoseidonialesArchaeon", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "274854.protein.sequences.v11.5.fa",
		        "enrichment_path": "274854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "274854.protein.info.v11.5.txt",
		        "node_list_path": "274854.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumStBin14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium ST_bin14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumStBin14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1978762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1978762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1978762.clusters.proteins.v11.5.txt",
		        "sequence_path": "1978762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978762.protein.info.v11.5.txt",
		        "node_list_path": "1978762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1978762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumVaginaePb189t14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium vaginae PB189T14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumVaginaePb189t14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "866774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "866774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "866774.clusters.proteins.v11.5.txt",
		        "sequence_path": "866774.protein.sequences.v11.5.fa",
		        "enrichment_path": "866774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866774.protein.info.v11.5.txt",
		        "node_list_path": "866774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "866774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DiplodiaSeriataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Diplodia seriata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiplodiaSeriataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "420778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "420778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "420778.clusters.proteins.v11.5.txt",
		        "sequence_path": "420778.protein.sequences.v11.5.fa",
		        "enrichment_path": "420778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420778.protein.info.v11.5.txt",
		        "node_list_path": "420778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "420778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyriculariaOryzae7015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyricularia oryzae 70-15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyriculariaOryzae7015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "242507.protein.sequences.v11.5.fa",
		        "enrichment_path": "242507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "242507.protein.info.v11.5.txt",
		        "node_list_path": "242507.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonosporascusSpCrb83(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. CRB-8-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSpCrb83", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2211644.protein.sequences.v11.5.fa",
		        "enrichment_path": "2211644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2211644.protein.info.v11.5.txt",
		        "node_list_path": "2211644.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf6677Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF6677 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf6677Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463879.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463879.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463879.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463879.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463879.protein.info.v11.5.txt",
		        "node_list_path": "1463879.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463879.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanomicrobiumMobile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanomicrobium mobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomicrobiumMobile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "694440.protein.sequences.v11.5.fa",
		        "enrichment_path": "694440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694440.protein.info.v11.5.txt",
		        "node_list_path": "694440.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "397288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "397288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "397288.clusters.proteins.v11.5.txt",
		        "sequence_path": "397288.protein.sequences.v11.5.fa",
		        "enrichment_path": "397288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397288.protein.info.v11.5.txt",
		        "node_list_path": "397288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "397288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesRubidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces rubidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRubidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "310780.protein.sequences.v11.5.fa",
		        "enrichment_path": "310780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "310780.protein.info.v11.5.txt",
		        "node_list_path": "310780.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLcm4573(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. LCM 4573 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLcm4573", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1848291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848291.protein.info.v11.5.txt",
		        "node_list_path": "1848291.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudorhodobacterAntarcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodobacter antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodobacterAntarcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1077947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077947.protein.info.v11.5.txt",
		        "node_list_path": "1077947.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrassicaNapusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brassica napus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrassicaNapusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3708.clusters.proteins.v11.5.txt",
		        "sequence_path": "3708.protein.sequences.v11.5.fa",
		        "enrichment_path": "3708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3708.protein.info.v11.5.txt",
		        "node_list_path": "3708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanohalophilusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanohalophilusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2177.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2177.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2177.clusters.proteins.v11.5.txt",
		        "sequence_path": "2177.protein.sequences.v11.5.fa",
		        "enrichment_path": "2177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2177.protein.info.v11.5.txt",
		        "node_list_path": "2177.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2177.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumScgcAaa027n21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium SCGC AAA027N21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumScgcAaa027n21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "938709.protein.sequences.v11.5.fa",
		        "enrichment_path": "938709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938709.protein.info.v11.5.txt",
		        "node_list_path": "938709.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwf26230Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWF2_62_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwf26230Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797939.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797939.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797939.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797939.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797939.protein.info.v11.5.txt",
		        "node_list_path": "1797939.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797939.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSp6357(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. 63-57 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSp6357", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895751.protein.info.v11.5.txt",
		        "node_list_path": "1895751.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "639004.protein.sequences.v11.5.fa",
		        "enrichment_path": "639004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "639004.protein.info.v11.5.txt",
		        "node_list_path": "639004.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumOxysporumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumOxysporumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5507.clusters.proteins.v11.5.txt",
		        "sequence_path": "5507.protein.sequences.v11.5.fa",
		        "enrichment_path": "5507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5507.protein.info.v11.5.txt",
		        "node_list_path": "5507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumSpJ15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium sp. J15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumSpJ15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "265901.protein.sequences.v11.5.fa",
		        "enrichment_path": "265901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265901.protein.info.v11.5.txt",
		        "node_list_path": "265901.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "284581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "284581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "284581.clusters.proteins.v11.5.txt",
		        "sequence_path": "284581.protein.sequences.v11.5.fa",
		        "enrichment_path": "284581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284581.protein.info.v11.5.txt",
		        "node_list_path": "284581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "284581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanococcusKocuriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planococcus kocurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusKocuriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1374.clusters.proteins.v11.5.txt",
		        "sequence_path": "1374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1374.protein.info.v11.5.txt",
		        "node_list_path": "1374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CronobacterDublinensisSubspDublinensisLmg23823Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. dublinensis LMG 23823 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CronobacterDublinensisSubspDublinensisLmg23823Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1159554.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1159554.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1159554.clusters.proteins.v11.5.txt",
		        "sequence_path": "1159554.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159554.protein.info.v11.5.txt",
		        "node_list_path": "1159554.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1159554.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumRifoxya2Full4620(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium RIFOXYA2_FULL_46_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumRifoxya2Full4620", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817727.protein.info.v11.5.txt",
		        "node_list_path": "1817727.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumDenitrificansAtcc51888Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium denitrificans ATCC51888 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumDenitrificansAtcc51888Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582899.clusters.proteins.v11.5.txt",
		        "sequence_path": "582899.protein.sequences.v11.5.fa",
		        "enrichment_path": "582899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582899.protein.info.v11.5.txt",
		        "node_list_path": "582899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychroflexusSalariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychroflexus salarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroflexusSalariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1155689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1155689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1155689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1155689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1155689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1155689.protein.info.v11.5.txt",
		        "node_list_path": "1155689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1155689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ApisMelliferaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Apis mellifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApisMelliferaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7460.clusters.proteins.v11.5.txt",
		        "sequence_path": "7460.protein.sequences.v11.5.fa",
		        "enrichment_path": "7460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7460.protein.info.v11.5.txt",
		        "node_list_path": "7460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifoxyd12Full5624(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12_FULL_56_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12Full5624", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797905.protein.info.v11.5.txt",
		        "node_list_path": "1797905.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaSicca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sicca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSicca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "547045.protein.sequences.v11.5.fa",
		        "enrichment_path": "547045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547045.protein.info.v11.5.txt",
		        "node_list_path": "547045.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpRedseaS34B3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. REDSEA-S34_B3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpRedseaS34B3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811533.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811533.protein.info.v11.5.txt",
		        "node_list_path": "1811533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FonsecaeaErecta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fonsecaea erecta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FonsecaeaErecta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1367422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1367422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1367422.protein.info.v11.5.txt",
		        "node_list_path": "1367422.protein.complete.v11.5.txt"
		    }
		]
    )()

def LongisporaAlbidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Longispora albida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LongisporaAlbidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122182.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122182.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122182.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122182.protein.info.v11.5.txt",
		        "node_list_path": "1122182.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122182.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLloydbacteriaBacteriumRifcsphigho201Full4120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_01_FULL_41_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho201Full4120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798657.protein.info.v11.5.txt",
		        "node_list_path": "1798657.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpRoot1471(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root1471 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpRoot1471", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736469.protein.info.v11.5.txt",
		        "node_list_path": "1736469.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusNatl1aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus NATL1A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusNatl1aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "167555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "167555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "167555.clusters.proteins.v11.5.txt",
		        "sequence_path": "167555.protein.sequences.v11.5.fa",
		        "enrichment_path": "167555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167555.protein.info.v11.5.txt",
		        "node_list_path": "167555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "167555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EctothiorhodospiraMagna(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ectothiorhodospira magna graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctothiorhodospiraMagna", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "867345.protein.sequences.v11.5.fa",
		        "enrichment_path": "867345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867345.protein.info.v11.5.txt",
		        "node_list_path": "867345.protein.complete.v11.5.txt"
		    }
		]
    )()

def PontibacterActiniarumDsm19842Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter actiniarum DSM 19842 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterActiniarumDsm19842Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "709015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "709015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "709015.clusters.proteins.v11.5.txt",
		        "sequence_path": "709015.protein.sequences.v11.5.fa",
		        "enrichment_path": "709015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709015.protein.info.v11.5.txt",
		        "node_list_path": "709015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "709015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusEapokensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus eapokensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusEapokensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1873482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1873482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1873482.clusters.proteins.v11.5.txt",
		        "sequence_path": "1873482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1873482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1873482.protein.info.v11.5.txt",
		        "node_list_path": "1873482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1873482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CetobacteriumSpZor0034(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cetobacterium sp. ZOR0034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CetobacteriumSpZor0034", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1339239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1339239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1339239.protein.info.v11.5.txt",
		        "node_list_path": "1339239.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalodesulfovibrioSpirochaetisodalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halodesulfovibrio spirochaetisodalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalodesulfovibrioSpirochaetisodalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1560234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1560234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1560234.protein.info.v11.5.txt",
		        "node_list_path": "1560234.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterHormaecheiSubspSteigerwaltiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. steigerwaltii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterHormaecheiSubspSteigerwaltiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "299766.clusters.info.v11.5.txt",
		        "cluster_tree_path": "299766.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "299766.clusters.proteins.v11.5.txt",
		        "sequence_path": "299766.protein.sequences.v11.5.fa",
		        "enrichment_path": "299766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299766.protein.info.v11.5.txt",
		        "node_list_path": "299766.cluster.nodes.v11.5.txt",
		        "edge_list_path": "299766.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinithermusHydrothermalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinithermus hydrothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinithermusHydrothermalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "869210.clusters.info.v11.5.txt",
		        "cluster_tree_path": "869210.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "869210.clusters.proteins.v11.5.txt",
		        "sequence_path": "869210.protein.sequences.v11.5.fa",
		        "enrichment_path": "869210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869210.protein.info.v11.5.txt",
		        "node_list_path": "869210.cluster.nodes.v11.5.txt",
		        "edge_list_path": "869210.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifcsplowo202Full6764(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO2_02_FULL_67_64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo202Full6764", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797564.protein.info.v11.5.txt",
		        "node_list_path": "1797564.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArabisAlpinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arabis alpina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArabisAlpinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "50452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "50452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "50452.clusters.proteins.v11.5.txt",
		        "sequence_path": "50452.protein.sequences.v11.5.fa",
		        "enrichment_path": "50452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50452.protein.info.v11.5.txt",
		        "node_list_path": "50452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "50452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAurimucosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium aurimucosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAurimucosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "548476.protein.sequences.v11.5.fa",
		        "enrichment_path": "548476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "548476.protein.info.v11.5.txt",
		        "node_list_path": "548476.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaTerpenica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia terpenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaTerpenica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "455432.protein.sequences.v11.5.fa",
		        "enrichment_path": "455432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "455432.protein.info.v11.5.txt",
		        "node_list_path": "455432.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetranychusUrticaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetranychus urticae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetranychusUrticaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32264.clusters.proteins.v11.5.txt",
		        "sequence_path": "32264.protein.sequences.v11.5.fa",
		        "enrichment_path": "32264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32264.protein.info.v11.5.txt",
		        "node_list_path": "32264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumUlceransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium ulcerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumUlceransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "362242.clusters.info.v11.5.txt",
		        "cluster_tree_path": "362242.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "362242.clusters.proteins.v11.5.txt",
		        "sequence_path": "362242.protein.sequences.v11.5.fa",
		        "enrichment_path": "362242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362242.protein.info.v11.5.txt",
		        "node_list_path": "362242.cluster.nodes.v11.5.txt",
		        "edge_list_path": "362242.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaludibacterSp4717(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paludibacter sp. 47-17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaludibacterSp4717", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895899.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895899.protein.info.v11.5.txt",
		        "node_list_path": "1895899.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumP7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium P7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumP7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1200751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200751.protein.info.v11.5.txt",
		        "node_list_path": "1200751.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumCg2304142(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_41_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumCg2304142", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805277.protein.info.v11.5.txt",
		        "node_list_path": "1805277.protein.complete.v11.5.txt"
		    }
		]
    )()

def OidiumNeolycopersiciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oidium neolycopersici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OidiumNeolycopersiciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "212602.clusters.info.v11.5.txt",
		        "cluster_tree_path": "212602.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "212602.clusters.proteins.v11.5.txt",
		        "sequence_path": "212602.protein.sequences.v11.5.fa",
		        "enrichment_path": "212602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "212602.protein.info.v11.5.txt",
		        "node_list_path": "212602.cluster.nodes.v11.5.txt",
		        "edge_list_path": "212602.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpIbunCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. IBUN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpIbunCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1042326.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1042326.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1042326.clusters.proteins.v11.5.txt",
		        "sequence_path": "1042326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042326.protein.info.v11.5.txt",
		        "node_list_path": "1042326.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1042326.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfatibacillumAlkenivoransDsm16219(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans DSM 16219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfatibacillumAlkenivoransDsm16219", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121393.protein.info.v11.5.txt",
		        "node_list_path": "1121393.protein.complete.v11.5.txt"
		    }
		]
    )()

def CladophialophoraPsammophilaCbs110553(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora psammophila CBS 110553 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CladophialophoraPsammophilaCbs110553", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1182543.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182543.protein.info.v11.5.txt",
		        "node_list_path": "1182543.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryptobacteriumCurtum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptobacterium curtum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptobacteriumCurtum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469378.protein.sequences.v11.5.fa",
		        "enrichment_path": "469378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469378.protein.info.v11.5.txt",
		        "node_list_path": "469378.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteibacterSpUncmf331sha31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter sp. UNCMF331Sha3.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterSpUncmf331sha31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502760.protein.info.v11.5.txt",
		        "node_list_path": "1502760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisFribergensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis fribergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisFribergensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1515612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1515612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1515612.protein.info.v11.5.txt",
		        "node_list_path": "1515612.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasSalmonicidaSubspSalmonicidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. salmonicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSalmonicidaSubspSalmonicidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29491.clusters.proteins.v11.5.txt",
		        "sequence_path": "29491.protein.sequences.v11.5.fa",
		        "enrichment_path": "29491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29491.protein.info.v11.5.txt",
		        "node_list_path": "29491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidiphiliumSpCag727(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidiphilium sp. CAG:727 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidiphiliumSpCag727", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262689.protein.info.v11.5.txt",
		        "node_list_path": "1262689.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSpAc3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. AC-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSpAc3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1680467.protein.sequences.v11.5.fa",
		        "enrichment_path": "1680467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1680467.protein.info.v11.5.txt",
		        "node_list_path": "1680467.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpEhn03(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. EhN03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpEhn03", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849358.protein.info.v11.5.txt",
		        "node_list_path": "1849358.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccoglossusKowalevskii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccoglossus kowalevskii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccoglossusKowalevskii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10224.protein.sequences.v11.5.fa",
		        "enrichment_path": "10224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10224.protein.info.v11.5.txt",
		        "node_list_path": "10224.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemmatimonadaceaeBacterium4484173(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadaceae bacterium 4484_173 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonadaceaeBacterium4484173", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1956166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1956166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1956166.protein.info.v11.5.txt",
		        "node_list_path": "1956166.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtopobiumVaginaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium vaginae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumVaginaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "82135.clusters.info.v11.5.txt",
		        "cluster_tree_path": "82135.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "82135.clusters.proteins.v11.5.txt",
		        "sequence_path": "82135.protein.sequences.v11.5.fa",
		        "enrichment_path": "82135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82135.protein.info.v11.5.txt",
		        "node_list_path": "82135.cluster.nodes.v11.5.txt",
		        "edge_list_path": "82135.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrovirgaLupiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microvirga lupini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaLupiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "420324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "420324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "420324.clusters.proteins.v11.5.txt",
		        "sequence_path": "420324.protein.sequences.v11.5.fa",
		        "enrichment_path": "420324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420324.protein.info.v11.5.txt",
		        "node_list_path": "420324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "420324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EhrlichiaSpHf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia sp. HF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EhrlichiaSpHf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391036.protein.sequences.v11.5.fa",
		        "enrichment_path": "391036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391036.protein.info.v11.5.txt",
		        "node_list_path": "391036.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusKakegawensisNbrc103104(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus kakegawensis NBRC 103104 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusKakegawensisNbrc103104", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220571.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220571.protein.info.v11.5.txt",
		        "node_list_path": "1220571.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusPaucivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paucivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPaucivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "616990.protein.sequences.v11.5.fa",
		        "enrichment_path": "616990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "616990.protein.info.v11.5.txt",
		        "node_list_path": "616990.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoproteusTenax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoproteus tenax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoproteusTenax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "768679.protein.sequences.v11.5.fa",
		        "enrichment_path": "768679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768679.protein.info.v11.5.txt",
		        "node_list_path": "768679.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslh7689Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH7689 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslh7689Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227349.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227349.protein.info.v11.5.txt",
		        "node_list_path": "1227349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrobacterSpMgh106Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sp. MGH106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterSpMgh106Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1686381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1686381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1686381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1686381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686381.protein.info.v11.5.txt",
		        "node_list_path": "1686381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1686381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhascolarctosCinereusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phascolarctos cinereus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhascolarctosCinereusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "38626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "38626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "38626.clusters.proteins.v11.5.txt",
		        "sequence_path": "38626.protein.sequences.v11.5.fa",
		        "enrichment_path": "38626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38626.protein.info.v11.5.txt",
		        "node_list_path": "38626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "38626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumFalseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium falsenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumFalseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1451189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1451189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1451189.clusters.proteins.v11.5.txt",
		        "sequence_path": "1451189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1451189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1451189.protein.info.v11.5.txt",
		        "node_list_path": "1451189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1451189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzospirillumThiophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum thiophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumThiophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "528244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "528244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "528244.clusters.proteins.v11.5.txt",
		        "sequence_path": "528244.protein.sequences.v11.5.fa",
		        "enrichment_path": "528244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "528244.protein.info.v11.5.txt",
		        "node_list_path": "528244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "528244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaCeti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella ceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaCeti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "759620.protein.sequences.v11.5.fa",
		        "enrichment_path": "759620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759620.protein.info.v11.5.txt",
		        "node_list_path": "759620.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusSpHmsc06h08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus sp. HMSC06H08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusSpHmsc06h08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1581129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581129.protein.info.v11.5.txt",
		        "node_list_path": "1581129.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaematobacterMissouriensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haematobacter missouriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaematobacterMissouriensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "366616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "366616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "366616.clusters.proteins.v11.5.txt",
		        "sequence_path": "366616.protein.sequences.v11.5.fa",
		        "enrichment_path": "366616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366616.protein.info.v11.5.txt",
		        "node_list_path": "366616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "366616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumMfb021(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MFB021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumMfb021", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1492922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1492922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1492922.protein.info.v11.5.txt",
		        "node_list_path": "1492922.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo2024111Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_02_41_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo2024111Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797731.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797731.protein.info.v11.5.txt",
		        "node_list_path": "1797731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterCibinongensis4h1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter cibinongensis 4H-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterCibinongensis4h1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231339.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231339.protein.info.v11.5.txt",
		        "node_list_path": "1231339.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSzechwanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides szechwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSzechwanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005944.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005944.protein.info.v11.5.txt",
		        "node_list_path": "1005944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolyporusBrumalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polyporus brumalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolyporusBrumalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "139420.protein.sequences.v11.5.fa",
		        "enrichment_path": "139420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "139420.protein.info.v11.5.txt",
		        "node_list_path": "139420.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaRhamnosiphilaNbrc108938Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia rhamnosiphila NBRC 108938 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaRhamnosiphilaNbrc108938Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223547.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223547.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223547.protein.info.v11.5.txt",
		        "node_list_path": "1223547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurovumSpFs083Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum sp. FS08-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurovumSpFs083Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1539065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1539065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1539065.clusters.proteins.v11.5.txt",
		        "sequence_path": "1539065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1539065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1539065.protein.info.v11.5.txt",
		        "node_list_path": "1539065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1539065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2055.clusters.proteins.v11.5.txt",
		        "sequence_path": "2055.protein.sequences.v11.5.fa",
		        "enrichment_path": "2055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2055.protein.info.v11.5.txt",
		        "node_list_path": "2055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrasphaeraJenkinsiiBen74Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera jenkinsii Ben 74 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrasphaeraJenkinsiiBen74Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193518.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193518.protein.info.v11.5.txt",
		        "node_list_path": "1193518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumAap81b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium AAP81b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumAap81b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523432.protein.info.v11.5.txt",
		        "node_list_path": "1523432.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxKonjaci(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax konjaci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxKonjaci", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32040.protein.sequences.v11.5.fa",
		        "enrichment_path": "32040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32040.protein.info.v11.5.txt",
		        "node_list_path": "32040.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyperthermusButylicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyperthermus butylicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyperthermusButylicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "415426.protein.sequences.v11.5.fa",
		        "enrichment_path": "415426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "415426.protein.info.v11.5.txt",
		        "node_list_path": "415426.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumSpSo1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. SO1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumSpSo1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1244869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1244869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1244869.clusters.proteins.v11.5.txt",
		        "sequence_path": "1244869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1244869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1244869.protein.info.v11.5.txt",
		        "node_list_path": "1244869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1244869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ApteryxRowi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Apteryx rowi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApteryxRowi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "308060.protein.sequences.v11.5.fa",
		        "enrichment_path": "308060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "308060.protein.info.v11.5.txt",
		        "node_list_path": "308060.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusHimalayensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus himalayensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusHimalayensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1888195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1888195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1888195.protein.info.v11.5.txt",
		        "node_list_path": "1888195.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasHengshuiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas hengshuiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasHengshuiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1609977.protein.sequences.v11.5.fa",
		        "enrichment_path": "1609977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1609977.protein.info.v11.5.txt",
		        "node_list_path": "1609977.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumYannicii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium yannicii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumYannicii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1194165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194165.protein.info.v11.5.txt",
		        "node_list_path": "1194165.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpW7784Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. W7784 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpW7784Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227272.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227272.protein.info.v11.5.txt",
		        "node_list_path": "1227272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CheloniaMydasCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chelonia mydas Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CheloniaMydasCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8469.clusters.proteins.v11.5.txt",
		        "sequence_path": "8469.protein.sequences.v11.5.fa",
		        "enrichment_path": "8469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8469.protein.info.v11.5.txt",
		        "node_list_path": "8469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BizioniaSpApa3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bizionia sp. APA-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BizioniaSpApa3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1861784.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1861784.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1861784.clusters.proteins.v11.5.txt",
		        "sequence_path": "1861784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1861784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1861784.protein.info.v11.5.txt",
		        "node_list_path": "1861784.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1861784.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1659197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1659197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1659197.clusters.proteins.v11.5.txt",
		        "sequence_path": "1659197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659197.protein.info.v11.5.txt",
		        "node_list_path": "1659197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1659197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterAquaticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter aquaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterAquaticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354303.protein.info.v11.5.txt",
		        "node_list_path": "1354303.protein.complete.v11.5.txt"
		    }
		]
    )()

def PongoAbeliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pongo abelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PongoAbeliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9601.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9601.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9601.clusters.proteins.v11.5.txt",
		        "sequence_path": "9601.protein.sequences.v11.5.fa",
		        "enrichment_path": "9601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9601.protein.info.v11.5.txt",
		        "node_list_path": "9601.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9601.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EndosymbiontOfBathymodiolusSeptemdierumStrMyojinKnoll(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Bathymodiolus septemdierum str. Myojin knoll graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndosymbiontOfBathymodiolusSeptemdierumStrMyojinKnoll", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1303921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1303921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1303921.protein.info.v11.5.txt",
		        "node_list_path": "1303921.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCampbellbacteriaBacteriumGw2011Od13428(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium GW2011_OD1_34_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumGw2011Od13428", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618633.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618633.protein.info.v11.5.txt",
		        "node_list_path": "1618633.protein.complete.v11.5.txt"
		    }
		]
    )()

def MillionellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Millionella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MillionellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871023.protein.info.v11.5.txt",
		        "node_list_path": "1871023.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClupeaHarengus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clupea harengus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClupeaHarengus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7950.protein.sequences.v11.5.fa",
		        "enrichment_path": "7950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7950.protein.info.v11.5.txt",
		        "node_list_path": "7950.protein.complete.v11.5.txt"
		    }
		]
    )()

def RiesiaPediculicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Riesia pediculicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RiesiaPediculicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "515618.clusters.info.v11.5.txt",
		        "cluster_tree_path": "515618.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "515618.clusters.proteins.v11.5.txt",
		        "sequence_path": "515618.protein.sequences.v11.5.fa",
		        "enrichment_path": "515618.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515618.protein.info.v11.5.txt",
		        "node_list_path": "515618.cluster.nodes.v11.5.txt",
		        "edge_list_path": "515618.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PragiaFontiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pragia fontium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PragiaFontiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "82985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "82985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "82985.clusters.proteins.v11.5.txt",
		        "sequence_path": "82985.protein.sequences.v11.5.fa",
		        "enrichment_path": "82985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82985.protein.info.v11.5.txt",
		        "node_list_path": "82985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "82985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSp6378(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 63-78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSp6378", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895859.protein.info.v11.5.txt",
		        "node_list_path": "1895859.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumColicanisDsm13634(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium colicanis DSM 13634 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumColicanisDsm13634", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121305.protein.info.v11.5.txt",
		        "node_list_path": "1121305.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloferaxMucosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloferax mucosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloferaxMucosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "662479.protein.sequences.v11.5.fa",
		        "enrichment_path": "662479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "662479.protein.info.v11.5.txt",
		        "node_list_path": "662479.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizopogonVesiculosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizopogon vesiculosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopogonVesiculosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "180088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "180088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "180088.clusters.proteins.v11.5.txt",
		        "sequence_path": "180088.protein.sequences.v11.5.fa",
		        "enrichment_path": "180088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180088.protein.info.v11.5.txt",
		        "node_list_path": "180088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "180088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpAcs4054(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS4054 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpAcs4054", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834119.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834119.protein.info.v11.5.txt",
		        "node_list_path": "1834119.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanithermusProfundusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanithermus profundus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanithermusProfundusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "670487.clusters.info.v11.5.txt",
		        "cluster_tree_path": "670487.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "670487.clusters.proteins.v11.5.txt",
		        "sequence_path": "670487.protein.sequences.v11.5.fa",
		        "enrichment_path": "670487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670487.protein.info.v11.5.txt",
		        "node_list_path": "670487.cluster.nodes.v11.5.txt",
		        "edge_list_path": "670487.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeospirillumFulvumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeospirillum fulvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeospirillumFulvumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1316936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1316936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1316936.clusters.proteins.v11.5.txt",
		        "sequence_path": "1316936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1316936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1316936.protein.info.v11.5.txt",
		        "node_list_path": "1316936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1316936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidibacillusFerrooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidibacillus ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidibacillusFerrooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1765683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765683.protein.info.v11.5.txt",
		        "node_list_path": "1765683.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterCloacaeEcwsu1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae EcWSU1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterCloacaeEcwsu1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1045856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045856.protein.info.v11.5.txt",
		        "node_list_path": "1045856.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpFobrc6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. FOBRC6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpFobrc6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936572.protein.sequences.v11.5.fa",
		        "enrichment_path": "936572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936572.protein.info.v11.5.txt",
		        "node_list_path": "936572.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaSpD27Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea sp. D27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaSpD27Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658665.clusters.proteins.v11.5.txt",
		        "sequence_path": "658665.protein.sequences.v11.5.fa",
		        "enrichment_path": "658665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658665.protein.info.v11.5.txt",
		        "node_list_path": "658665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesemziaIncertaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desemzia incerta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesemziaIncertaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "82801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "82801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "82801.clusters.proteins.v11.5.txt",
		        "sequence_path": "82801.protein.sequences.v11.5.fa",
		        "enrichment_path": "82801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82801.protein.info.v11.5.txt",
		        "node_list_path": "82801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "82801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChamaesiphonMinutus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chamaesiphon minutus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChamaesiphonMinutus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173020.protein.info.v11.5.txt",
		        "node_list_path": "1173020.protein.complete.v11.5.txt"
		    }
		]
    )()

def SimplicispiraPsychrophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Simplicispira psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SimplicispiraPsychrophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123255.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123255.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123255.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123255.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123255.protein.info.v11.5.txt",
		        "node_list_path": "1123255.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123255.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAlcalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus alcalophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAlcalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218173.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218173.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218173.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218173.protein.info.v11.5.txt",
		        "node_list_path": "1218173.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218173.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674846.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674846.protein.info.v11.5.txt",
		        "node_list_path": "1674846.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthobacterAutotrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthobacter autotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthobacterAutotrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "78245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "78245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "78245.clusters.proteins.v11.5.txt",
		        "sequence_path": "78245.protein.sequences.v11.5.fa",
		        "enrichment_path": "78245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78245.protein.info.v11.5.txt",
		        "node_list_path": "78245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "78245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaCaldaria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema caldaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaCaldaria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "744872.protein.sequences.v11.5.fa",
		        "enrichment_path": "744872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "744872.protein.info.v11.5.txt",
		        "node_list_path": "744872.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmodiumFalciparum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium falciparum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumFalciparum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5833.protein.sequences.v11.5.fa",
		        "enrichment_path": "5833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5833.protein.info.v11.5.txt",
		        "node_list_path": "5833.protein.complete.v11.5.txt"
		    }
		]
    )()

def AccumulibacterSpBa93(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Accumulibacter sp. BA93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AccumulibacterSpBa93", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1454004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454004.protein.info.v11.5.txt",
		        "node_list_path": "1454004.protein.complete.v11.5.txt"
		    }
		]
    )()

def HirschiaBaltica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hirschia baltica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HirschiaBaltica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582402.protein.sequences.v11.5.fa",
		        "enrichment_path": "582402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582402.protein.info.v11.5.txt",
		        "node_list_path": "582402.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycetalesBacteriumActino02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomycetales bacterium Actino_02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycetalesBacteriumActino02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674809.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674809.protein.info.v11.5.txt",
		        "node_list_path": "1674809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlwc3773Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3773 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlwc3773Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463936.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463936.protein.info.v11.5.txt",
		        "node_list_path": "1463936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusNautiliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus nautili Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusNautiliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "195522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "195522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "195522.clusters.proteins.v11.5.txt",
		        "sequence_path": "195522.protein.sequences.v11.5.fa",
		        "enrichment_path": "195522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195522.protein.info.v11.5.txt",
		        "node_list_path": "195522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "195522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylothermusHellenicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylothermus hellenicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylothermusHellenicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "591019.protein.sequences.v11.5.fa",
		        "enrichment_path": "591019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591019.protein.info.v11.5.txt",
		        "node_list_path": "591019.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpMb2005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MB2005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpMb2005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280678.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280678.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280678.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280678.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280678.protein.info.v11.5.txt",
		        "node_list_path": "1280678.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280678.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GracilibacillusKekensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus kekensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusKekensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1027249.protein.sequences.v11.5.fa",
		        "enrichment_path": "1027249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1027249.protein.info.v11.5.txt",
		        "node_list_path": "1027249.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumMurisUcdAy4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium muris UCD-AY4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumMurisUcdAy4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1249481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1249481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1249481.clusters.proteins.v11.5.txt",
		        "sequence_path": "1249481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249481.protein.info.v11.5.txt",
		        "node_list_path": "1249481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1249481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoduganellaViolaceinigraDsm15887(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoduganella violaceinigra DSM 15887 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoduganellaViolaceinigraDsm15887", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121480.protein.info.v11.5.txt",
		        "node_list_path": "1121480.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseinatronobacterThiooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseinatronobacter thiooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseinatronobacterThiooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "121821.protein.sequences.v11.5.fa",
		        "enrichment_path": "121821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121821.protein.info.v11.5.txt",
		        "node_list_path": "121821.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKomeilibacteriaBacteriumRifcsplowo201Full4510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_01_FULL_45_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo201Full4510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798550.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798550.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798550.protein.info.v11.5.txt",
		        "node_list_path": "1798550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldivirgaMaquilingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldivirga maquilingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldivirgaMaquilingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "397948.protein.sequences.v11.5.fa",
		        "enrichment_path": "397948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397948.protein.info.v11.5.txt",
		        "node_list_path": "397948.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumHlucca01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium HLUCCA01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumHlucca01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1666909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1666909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1666909.clusters.proteins.v11.5.txt",
		        "sequence_path": "1666909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666909.protein.info.v11.5.txt",
		        "node_list_path": "1666909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1666909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermotogaSp5064Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga sp. 50_64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaSp5064Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635259.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635259.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635259.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635259.protein.info.v11.5.txt",
		        "node_list_path": "1635259.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635259.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot268(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root268 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot268", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736506.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736506.protein.info.v11.5.txt",
		        "node_list_path": "1736506.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinivibrioProteolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio proteolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivibrioProteolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "334715.clusters.info.v11.5.txt",
		        "cluster_tree_path": "334715.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "334715.clusters.proteins.v11.5.txt",
		        "sequence_path": "334715.protein.sequences.v11.5.fa",
		        "enrichment_path": "334715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334715.protein.info.v11.5.txt",
		        "node_list_path": "334715.cluster.nodes.v11.5.txt",
		        "edge_list_path": "334715.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArsenicicoccusSpOralTaxon190Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arsenicicoccus sp. oral taxon 190 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArsenicicoccusSpOralTaxon190Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658671.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658671.protein.info.v11.5.txt",
		        "node_list_path": "1658671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WickerhamomycesCiferrii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamomyces ciferrii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WickerhamomycesCiferrii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041607.protein.info.v11.5.txt",
		        "node_list_path": "1041607.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPneumoniaeTigr4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae TIGR4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPneumoniaeTigr4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "170187.protein.sequences.v11.5.fa",
		        "enrichment_path": "170187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "170187.protein.info.v11.5.txt",
		        "node_list_path": "170187.protein.complete.v11.5.txt"
		    }
		]
    )()

def RunellaLimosaDsm17973(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Runella limosa DSM 17973 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RunellaLimosaDsm17973", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123077.protein.info.v11.5.txt",
		        "node_list_path": "1123077.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidihalobacterFerrooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidihalobacter ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidihalobacterFerrooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1765967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1765967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1765967.clusters.proteins.v11.5.txt",
		        "sequence_path": "1765967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765967.protein.info.v11.5.txt",
		        "node_list_path": "1765967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1765967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LewinellaAgarilyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lewinella agarilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LewinellaAgarilyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "478744.clusters.info.v11.5.txt",
		        "cluster_tree_path": "478744.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "478744.clusters.proteins.v11.5.txt",
		        "sequence_path": "478744.protein.sequences.v11.5.fa",
		        "enrichment_path": "478744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "478744.protein.info.v11.5.txt",
		        "node_list_path": "478744.cluster.nodes.v11.5.txt",
		        "edge_list_path": "478744.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaChinhatensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia chinhatensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaChinhatensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "429727.protein.sequences.v11.5.fa",
		        "enrichment_path": "429727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "429727.protein.info.v11.5.txt",
		        "node_list_path": "429727.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumEstertheticumSubspEstertheticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium estertheticum subsp. estertheticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumEstertheticumSubspEstertheticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1552.protein.info.v11.5.txt",
		        "node_list_path": "1552.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermofilumSp1910bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum sp. 1910b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermofilumSp1910bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1365176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1365176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1365176.clusters.proteins.v11.5.txt",
		        "sequence_path": "1365176.protein.sequences.v11.5.fa",
		        "enrichment_path": "1365176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1365176.protein.info.v11.5.txt",
		        "node_list_path": "1365176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1365176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa23710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_37_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa23710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618810.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618810.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618810.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618810.protein.info.v11.5.txt",
		        "node_list_path": "1618810.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618810.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMp13118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MP131-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMp13118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1857892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1857892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1857892.clusters.proteins.v11.5.txt",
		        "sequence_path": "1857892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1857892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1857892.protein.info.v11.5.txt",
		        "node_list_path": "1857892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1857892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSchindleriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter schindleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSchindleriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "108981.clusters.info.v11.5.txt",
		        "cluster_tree_path": "108981.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "108981.clusters.proteins.v11.5.txt",
		        "sequence_path": "108981.protein.sequences.v11.5.fa",
		        "enrichment_path": "108981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "108981.protein.info.v11.5.txt",
		        "node_list_path": "108981.cluster.nodes.v11.5.txt",
		        "edge_list_path": "108981.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumTerrigena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium terrigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumTerrigena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "402734.protein.sequences.v11.5.fa",
		        "enrichment_path": "402734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402734.protein.info.v11.5.txt",
		        "node_list_path": "402734.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaGladioli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia gladioli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaGladioli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999541.protein.sequences.v11.5.fa",
		        "enrichment_path": "999541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999541.protein.info.v11.5.txt",
		        "node_list_path": "999541.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxEbreus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax ebreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxEbreus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "535289.protein.sequences.v11.5.fa",
		        "enrichment_path": "535289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "535289.protein.info.v11.5.txt",
		        "node_list_path": "535289.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpHm582(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. HM58-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpHm582", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1778770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1778770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1778770.protein.info.v11.5.txt",
		        "node_list_path": "1778770.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterPersici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter persici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterPersici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1076596.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076596.protein.info.v11.5.txt",
		        "node_list_path": "1076596.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaSpAg1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. Ag1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpAg1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1524467.protein.sequences.v11.5.fa",
		        "enrichment_path": "1524467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1524467.protein.info.v11.5.txt",
		        "node_list_path": "1524467.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusTigurinusAz3a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus tigurinus AZ3a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusTigurinusAz3a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1282664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282664.protein.info.v11.5.txt",
		        "node_list_path": "1282664.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrotusOchrogaster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microtus ochrogaster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrotusOchrogaster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "79684.protein.sequences.v11.5.fa",
		        "enrichment_path": "79684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79684.protein.info.v11.5.txt",
		        "node_list_path": "79684.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSciuri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sciuri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSciuri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232666.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232666.protein.info.v11.5.txt",
		        "node_list_path": "1232666.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydraVulgarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydra vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydraVulgarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6087.clusters.proteins.v11.5.txt",
		        "sequence_path": "6087.protein.sequences.v11.5.fa",
		        "enrichment_path": "6087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6087.protein.info.v11.5.txt",
		        "node_list_path": "6087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFuscovaginae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fuscovaginae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFuscovaginae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "50340.protein.sequences.v11.5.fa",
		        "enrichment_path": "50340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50340.protein.info.v11.5.txt",
		        "node_list_path": "50340.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusEiseniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus eiseniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusEiseniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762947.protein.sequences.v11.5.fa",
		        "enrichment_path": "762947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762947.protein.info.v11.5.txt",
		        "node_list_path": "762947.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpGa1841Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1841 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpGa1841Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834154.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834154.protein.info.v11.5.txt",
		        "node_list_path": "1834154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarboxydothermusHydrogenoformansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carboxydothermus hydrogenoformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarboxydothermusHydrogenoformansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246194.clusters.proteins.v11.5.txt",
		        "sequence_path": "246194.protein.sequences.v11.5.fa",
		        "enrichment_path": "246194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246194.protein.info.v11.5.txt",
		        "node_list_path": "246194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalostagnicolaSpA56Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halostagnicola sp. A56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalostagnicolaSpA56Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1495067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1495067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1495067.clusters.proteins.v11.5.txt",
		        "sequence_path": "1495067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495067.protein.info.v11.5.txt",
		        "node_list_path": "1495067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1495067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrobacterSp302Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sp. 302 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterSp302Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469595.clusters.proteins.v11.5.txt",
		        "sequence_path": "469595.protein.sequences.v11.5.fa",
		        "enrichment_path": "469595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469595.protein.info.v11.5.txt",
		        "node_list_path": "469595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodesmiumErythraeumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichodesmium erythraeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodesmiumErythraeumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "203124.clusters.info.v11.5.txt",
		        "cluster_tree_path": "203124.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "203124.clusters.proteins.v11.5.txt",
		        "sequence_path": "203124.protein.sequences.v11.5.fa",
		        "enrichment_path": "203124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203124.protein.info.v11.5.txt",
		        "node_list_path": "203124.cluster.nodes.v11.5.txt",
		        "edge_list_path": "203124.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacterium4632Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 46-32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacterium4632Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895839.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895839.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895839.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895839.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895839.protein.info.v11.5.txt",
		        "node_list_path": "1895839.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895839.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121897.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121897.protein.info.v11.5.txt",
		        "node_list_path": "1121897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterRectus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter rectus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterRectus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553218.protein.sequences.v11.5.fa",
		        "enrichment_path": "553218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553218.protein.info.v11.5.txt",
		        "node_list_path": "553218.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorNaganoensisNa10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor naganoensis NA10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorNaganoensisNa10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1387569.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1387569.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1387569.clusters.proteins.v11.5.txt",
		        "sequence_path": "1387569.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387569.protein.info.v11.5.txt",
		        "node_list_path": "1387569.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1387569.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TenuibacillusMultivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenuibacillus multivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenuibacillusMultivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "237069.protein.sequences.v11.5.fa",
		        "enrichment_path": "237069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237069.protein.info.v11.5.txt",
		        "node_list_path": "237069.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaOulorumJcm14966(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oulorum JCM14966 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOulorumJcm14966", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236497.protein.info.v11.5.txt",
		        "node_list_path": "1236497.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalogenimonasSpWbc2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalogenimonas sp. WBC-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalogenimonasSpWbc2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "943347.clusters.info.v11.5.txt",
		        "cluster_tree_path": "943347.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "943347.clusters.proteins.v11.5.txt",
		        "sequence_path": "943347.protein.sequences.v11.5.fa",
		        "enrichment_path": "943347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "943347.protein.info.v11.5.txt",
		        "node_list_path": "943347.cluster.nodes.v11.5.txt",
		        "edge_list_path": "943347.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosovibrioTenuisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosovibrio tenuis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosovibrioTenuisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1233.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1233.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1233.clusters.proteins.v11.5.txt",
		        "sequence_path": "1233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1233.protein.info.v11.5.txt",
		        "node_list_path": "1233.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1233.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaeTomatoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae tomato Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaeTomatoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "223283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "223283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "223283.clusters.proteins.v11.5.txt",
		        "sequence_path": "223283.protein.sequences.v11.5.fa",
		        "enrichment_path": "223283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223283.protein.info.v11.5.txt",
		        "node_list_path": "223283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "223283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassotaleaSpNd16a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassotalea sp. ND16A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassotaleaSpNd16a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1535422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1535422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1535422.protein.info.v11.5.txt",
		        "node_list_path": "1535422.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnt372(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT372 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnt372", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1169154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169154.protein.info.v11.5.txt",
		        "node_list_path": "1169154.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFragiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fragi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFragiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1136138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1136138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1136138.clusters.proteins.v11.5.txt",
		        "sequence_path": "1136138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1136138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1136138.protein.info.v11.5.txt",
		        "node_list_path": "1136138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1136138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpHgf2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. HGF2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpHgf2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "908340.protein.sequences.v11.5.fa",
		        "enrichment_path": "908340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908340.protein.info.v11.5.txt",
		        "node_list_path": "908340.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellamassiliaTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotellamassilia timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellamassiliaTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852370.protein.info.v11.5.txt",
		        "node_list_path": "1852370.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc14514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_45_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc14514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618915.protein.info.v11.5.txt",
		        "node_list_path": "1618915.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacterium628Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 62-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacterium628Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895708.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895708.protein.info.v11.5.txt",
		        "node_list_path": "1895708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UrinicoccusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Urinicoccus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UrinicoccusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1723382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1723382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1723382.protein.info.v11.5.txt",
		        "node_list_path": "1723382.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaviaPorcellusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cavia porcellus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaviaPorcellusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10141.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10141.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10141.clusters.proteins.v11.5.txt",
		        "sequence_path": "10141.protein.sequences.v11.5.fa",
		        "enrichment_path": "10141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10141.protein.info.v11.5.txt",
		        "node_list_path": "10141.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10141.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaGratiana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella gratiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaGratiana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45066.protein.sequences.v11.5.fa",
		        "enrichment_path": "45066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45066.protein.info.v11.5.txt",
		        "node_list_path": "45066.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaMelanogasterCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila melanogaster Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaMelanogasterCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7227.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7227.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7227.clusters.proteins.v11.5.txt",
		        "sequence_path": "7227.protein.sequences.v11.5.fa",
		        "enrichment_path": "7227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7227.protein.info.v11.5.txt",
		        "node_list_path": "7227.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7227.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PiromycesSpE2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Piromyces sp. E2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiromycesSpE2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "73868.clusters.info.v11.5.txt",
		        "cluster_tree_path": "73868.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "73868.clusters.proteins.v11.5.txt",
		        "sequence_path": "73868.protein.sequences.v11.5.fa",
		        "enrichment_path": "73868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "73868.protein.info.v11.5.txt",
		        "node_list_path": "73868.cluster.nodes.v11.5.txt",
		        "edge_list_path": "73868.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaLascolaiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella lascolaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaLascolaiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776379.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776379.protein.info.v11.5.txt",
		        "node_list_path": "1776379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuegeriaSpR11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. R11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaSpR11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "439497.protein.sequences.v11.5.fa",
		        "enrichment_path": "439497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439497.protein.info.v11.5.txt",
		        "node_list_path": "439497.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumVanbaaleniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium vanbaalenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumVanbaaleniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "350058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "350058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "350058.clusters.proteins.v11.5.txt",
		        "sequence_path": "350058.protein.sequences.v11.5.fa",
		        "enrichment_path": "350058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "350058.protein.info.v11.5.txt",
		        "node_list_path": "350058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "350058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumOlb17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium OLB17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumOlb17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617423.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617423.protein.info.v11.5.txt",
		        "node_list_path": "1617423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsphigho201Full388Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_01_FULL_38_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho201Full388Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797760.protein.info.v11.5.txt",
		        "node_list_path": "1797760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumTerpenotabidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium terpenotabidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumTerpenotabidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1200352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200352.protein.info.v11.5.txt",
		        "node_list_path": "1200352.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpMbes04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. MBES04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpMbes04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206458.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206458.protein.info.v11.5.txt",
		        "node_list_path": "1206458.protein.complete.v11.5.txt"
		    }
		]
    )()

def CanisLupusFamiliaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Canis lupus familiaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CanisLupusFamiliaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9615.protein.sequences.v11.5.fa",
		        "enrichment_path": "9615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9615.protein.info.v11.5.txt",
		        "node_list_path": "9615.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpUmwgjCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UMWGJ Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpUmwgjCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1370120.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1370120.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1370120.clusters.proteins.v11.5.txt",
		        "sequence_path": "1370120.protein.sequences.v11.5.fa",
		        "enrichment_path": "1370120.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1370120.protein.info.v11.5.txt",
		        "node_list_path": "1370120.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1370120.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpFw510T8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. FW510-T8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpFw510T8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1524463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1524463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1524463.protein.info.v11.5.txt",
		        "node_list_path": "1524463.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumGwc2579Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWC2_57_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumGwc2579Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801698.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801698.protein.info.v11.5.txt",
		        "node_list_path": "1801698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumIliopiscarium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium iliopiscarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumIliopiscarium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56192.protein.sequences.v11.5.fa",
		        "enrichment_path": "56192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56192.protein.info.v11.5.txt",
		        "node_list_path": "56192.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumFormosense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium formosense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumFormosense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "236814.protein.sequences.v11.5.fa",
		        "enrichment_path": "236814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "236814.protein.info.v11.5.txt",
		        "node_list_path": "236814.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusGenomosp3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus genomosp. 3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusGenomosp3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1921421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1921421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1921421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1921421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921421.protein.info.v11.5.txt",
		        "node_list_path": "1921421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1921421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerosalibacterSpMarseilleP3206Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerosalibacter sp. Marseille-P3206 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerosalibacterSpMarseilleP3206Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871005.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871005.protein.info.v11.5.txt",
		        "node_list_path": "1871005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusMarincolaDsm16067(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus marincola DSM16067 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusMarincolaDsm16067", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120966.protein.info.v11.5.txt",
		        "node_list_path": "1120966.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumBeibuenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium beibuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumBeibuenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1406840.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1406840.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1406840.clusters.proteins.v11.5.txt",
		        "sequence_path": "1406840.protein.sequences.v11.5.fa",
		        "enrichment_path": "1406840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1406840.protein.info.v11.5.txt",
		        "node_list_path": "1406840.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1406840.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpWp9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. WP9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpWp9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500263.protein.info.v11.5.txt",
		        "node_list_path": "1500263.protein.complete.v11.5.txt"
		    }
		]
    )()

def LacinutrixSpPamc27137(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix sp. PAMC27137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixSpPamc27137", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1469557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469557.protein.info.v11.5.txt",
		        "node_list_path": "1469557.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrococcusSpHmsc067e09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micrococcus sp. HMSC067E09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcusSpHmsc067e09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739367.protein.info.v11.5.txt",
		        "node_list_path": "1739367.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZimmermannellaAlbaNbrc15616(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Zimmermannella] alba NBRC 15616 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZimmermannellaAlbaNbrc15616", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349786.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349786.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349786.protein.info.v11.5.txt",
		        "node_list_path": "1349786.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSeoulensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces seoulensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSeoulensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "73044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "73044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "73044.clusters.proteins.v11.5.txt",
		        "sequence_path": "73044.protein.sequences.v11.5.fa",
		        "enrichment_path": "73044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "73044.protein.info.v11.5.txt",
		        "node_list_path": "73044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "73044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetalesBacteriumSpiro02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetalesBacteriumSpiro02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674858.protein.info.v11.5.txt",
		        "node_list_path": "1674858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumMarinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumMarinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216594.protein.sequences.v11.5.fa",
		        "enrichment_path": "216594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216594.protein.info.v11.5.txt",
		        "node_list_path": "216594.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwa25611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_56_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa25611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619044.protein.info.v11.5.txt",
		        "node_list_path": "1619044.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusPanisDsm6035Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus panis DSM 6035 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPanisDsm6035Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423782.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423782.protein.info.v11.5.txt",
		        "node_list_path": "1423782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesJohnsoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides johnsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesJohnsoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999419.clusters.proteins.v11.5.txt",
		        "sequence_path": "999419.protein.sequences.v11.5.fa",
		        "enrichment_path": "999419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999419.protein.info.v11.5.txt",
		        "node_list_path": "999419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DickeyaSpDw0440Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya sp. DW 0440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaSpDw0440Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1225785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1225785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1225785.clusters.proteins.v11.5.txt",
		        "sequence_path": "1225785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225785.protein.info.v11.5.txt",
		        "node_list_path": "1225785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1225785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSulfonivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sulfonivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSulfonivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "121290.protein.sequences.v11.5.fa",
		        "enrichment_path": "121290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121290.protein.info.v11.5.txt",
		        "node_list_path": "121290.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaSpAl04100510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. AL041005-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaSpAl04100510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445576.protein.sequences.v11.5.fa",
		        "enrichment_path": "445576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445576.protein.info.v11.5.txt",
		        "node_list_path": "445576.protein.complete.v11.5.txt"
		    }
		]
    )()

def StylophoraPistillataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stylophora pistillata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StylophoraPistillataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "50429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "50429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "50429.clusters.proteins.v11.5.txt",
		        "sequence_path": "50429.protein.sequences.v11.5.fa",
		        "enrichment_path": "50429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50429.protein.info.v11.5.txt",
		        "node_list_path": "50429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "50429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaoerskoviaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraoerskovia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaoerskoviaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122933.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122933.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122933.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122933.protein.info.v11.5.txt",
		        "node_list_path": "1122933.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122933.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaFarcinica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia farcinica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaFarcinica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "247156.protein.sequences.v11.5.fa",
		        "enrichment_path": "247156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247156.protein.info.v11.5.txt",
		        "node_list_path": "247156.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusFlavefaciensAe3010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens AE3010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusFlavefaciensAe3010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1384066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384066.protein.info.v11.5.txt",
		        "node_list_path": "1384066.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasSpNm166Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm166 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasSpNm166Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881054.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881054.protein.info.v11.5.txt",
		        "node_list_path": "1881054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MonodelphisDomestica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monodelphis domestica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonodelphisDomestica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13616.protein.sequences.v11.5.fa",
		        "enrichment_path": "13616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13616.protein.info.v11.5.txt",
		        "node_list_path": "13616.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumMesophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum mesophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumMesophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "104268.protein.sequences.v11.5.fa",
		        "enrichment_path": "104268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104268.protein.info.v11.5.txt",
		        "node_list_path": "104268.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCarsonellaRuddiiHcIsolateThao2000Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii HC isolate Thao2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCarsonellaRuddiiHcIsolateThao2000Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1202538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1202538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1202538.clusters.proteins.v11.5.txt",
		        "sequence_path": "1202538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202538.protein.info.v11.5.txt",
		        "node_list_path": "1202538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1202538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CucumibacterMarinusDsm18995Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cucumibacter marinus DSM 18995 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CucumibacterMarinusDsm18995Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "422296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "422296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "422296.clusters.proteins.v11.5.txt",
		        "sequence_path": "422296.protein.sequences.v11.5.fa",
		        "enrichment_path": "422296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "422296.protein.info.v11.5.txt",
		        "node_list_path": "422296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "422296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSulphureusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sulphureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSulphureusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123321.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123321.protein.info.v11.5.txt",
		        "node_list_path": "1123321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumLowii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium lowii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumLowii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1544413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1544413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1544413.protein.info.v11.5.txt",
		        "node_list_path": "1544413.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesMassiliensisB84634(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis B84634 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesMassiliensisB84634", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121098.protein.info.v11.5.txt",
		        "node_list_path": "1121098.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaMontpellierensisDsm17217Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella montpellierensis DSM 17217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaMontpellierensisDsm17217Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123490.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123490.protein.info.v11.5.txt",
		        "node_list_path": "1123490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmigerFormicilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmiger formicilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmigerFormicilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "745368.protein.sequences.v11.5.fa",
		        "enrichment_path": "745368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745368.protein.info.v11.5.txt",
		        "node_list_path": "745368.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaGirerdii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma girerdii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaGirerdii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1318617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1318617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1318617.protein.info.v11.5.txt",
		        "node_list_path": "1318617.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlaciecolaPsychrophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaPsychrophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1129794.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1129794.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1129794.clusters.proteins.v11.5.txt",
		        "sequence_path": "1129794.protein.sequences.v11.5.fa",
		        "enrichment_path": "1129794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1129794.protein.info.v11.5.txt",
		        "node_list_path": "1129794.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1129794.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaTyphiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica Typhi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaTyphiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "220341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "220341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "220341.clusters.proteins.v11.5.txt",
		        "sequence_path": "220341.protein.sequences.v11.5.fa",
		        "enrichment_path": "220341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220341.protein.info.v11.5.txt",
		        "node_list_path": "220341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "220341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusThermophilusLmg18311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus LMG18311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusThermophilusLmg18311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264199.clusters.proteins.v11.5.txt",
		        "sequence_path": "264199.protein.sequences.v11.5.fa",
		        "enrichment_path": "264199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264199.protein.info.v11.5.txt",
		        "node_list_path": "264199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpSat1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. SAT1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpSat1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849967.protein.info.v11.5.txt",
		        "node_list_path": "1849967.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusMacroidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus macroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusMacroidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33935.clusters.proteins.v11.5.txt",
		        "sequence_path": "33935.protein.sequences.v11.5.fa",
		        "enrichment_path": "33935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33935.protein.info.v11.5.txt",
		        "node_list_path": "33935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkelbacteriaBacteriumRifcsphigho212Full369Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFCSPHIGHO2_12_FULL_36_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifcsphigho212Full369Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797469.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797469.protein.info.v11.5.txt",
		        "node_list_path": "1797469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HebelomaCylindrosporumH7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hebeloma cylindrosporum h7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HebelomaCylindrosporumH7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "686832.protein.sequences.v11.5.fa",
		        "enrichment_path": "686832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686832.protein.info.v11.5.txt",
		        "node_list_path": "686832.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExophialaSpinifera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exophiala spinifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaSpinifera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "91928.protein.sequences.v11.5.fa",
		        "enrichment_path": "91928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91928.protein.info.v11.5.txt",
		        "node_list_path": "91928.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaMojavensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila mojavensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaMojavensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7230.protein.sequences.v11.5.fa",
		        "enrichment_path": "7230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7230.protein.info.v11.5.txt",
		        "node_list_path": "7230.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProlixibacterBellariivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prolixibacter bellariivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProlixibacterBellariivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408473.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408473.protein.info.v11.5.txt",
		        "node_list_path": "1408473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BigelowiellaNatans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bigelowiella natans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BigelowiellaNatans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "227086.protein.sequences.v11.5.fa",
		        "enrichment_path": "227086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227086.protein.info.v11.5.txt",
		        "node_list_path": "227086.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusHalosaccharovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus halosaccharovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHalosaccharovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930124.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930124.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930124.clusters.proteins.v11.5.txt",
		        "sequence_path": "930124.protein.sequences.v11.5.fa",
		        "enrichment_path": "930124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930124.protein.info.v11.5.txt",
		        "node_list_path": "930124.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930124.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRoot682Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root682 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRoot682Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736586.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736586.protein.info.v11.5.txt",
		        "node_list_path": "1736586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpLtsp885Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LTSP885 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpLtsp885Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619232.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619232.protein.info.v11.5.txt",
		        "node_list_path": "1619232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumVariumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium varium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumVariumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469618.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469618.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469618.clusters.proteins.v11.5.txt",
		        "sequence_path": "469618.protein.sequences.v11.5.fa",
		        "enrichment_path": "469618.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469618.protein.info.v11.5.txt",
		        "node_list_path": "469618.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469618.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumScgcAaa288G21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA288-G21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumScgcAaa288G21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "939324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "939324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "939324.clusters.proteins.v11.5.txt",
		        "sequence_path": "939324.protein.sequences.v11.5.fa",
		        "enrichment_path": "939324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939324.protein.info.v11.5.txt",
		        "node_list_path": "939324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "939324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FaecalibaculumRodentiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalibaculum rodentium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibaculumRodentiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1702221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1702221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1702221.clusters.proteins.v11.5.txt",
		        "sequence_path": "1702221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1702221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1702221.protein.info.v11.5.txt",
		        "node_list_path": "1702221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1702221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpheniscorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium spheniscorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpheniscorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "185761.clusters.info.v11.5.txt",
		        "cluster_tree_path": "185761.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "185761.clusters.proteins.v11.5.txt",
		        "sequence_path": "185761.protein.sequences.v11.5.fa",
		        "enrichment_path": "185761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "185761.protein.info.v11.5.txt",
		        "node_list_path": "185761.cluster.nodes.v11.5.txt",
		        "edge_list_path": "185761.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FaecalitaleaCylindroidesT287Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalitalea cylindroides T2-87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalitaleaCylindroidesT287Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717960.clusters.proteins.v11.5.txt",
		        "sequence_path": "717960.protein.sequences.v11.5.fa",
		        "enrichment_path": "717960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717960.protein.info.v11.5.txt",
		        "node_list_path": "717960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterDaecheongensisDsm21074Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter daecheongensis DSM 21074 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterDaecheongensisDsm21074Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121955.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121955.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121955.protein.info.v11.5.txt",
		        "node_list_path": "1121955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCb02488(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB02488 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCb02488", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703920.protein.info.v11.5.txt",
		        "node_list_path": "1703920.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsphigho201Full4815(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO2_01_FULL_48_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201Full4815", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802619.protein.info.v11.5.txt",
		        "node_list_path": "1802619.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSpSk01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSpSk01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1457154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1457154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1457154.protein.info.v11.5.txt",
		        "node_list_path": "1457154.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumChlorophyti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum chlorophyti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumChlorophyti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "708187.protein.sequences.v11.5.fa",
		        "enrichment_path": "708187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "708187.protein.info.v11.5.txt",
		        "node_list_path": "708187.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanicolaSp22iis11gCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola sp. 22IIS11g Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaSp22iis11gCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461694.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461694.protein.info.v11.5.txt",
		        "node_list_path": "1461694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesUrogenitalisDsm15434Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis DSM15434 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesUrogenitalisDsm15434Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525246.clusters.proteins.v11.5.txt",
		        "sequence_path": "525246.protein.sequences.v11.5.fa",
		        "enrichment_path": "525246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525246.protein.info.v11.5.txt",
		        "node_list_path": "525246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixibacteriaBacteriumSm23733Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_73_3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm23733Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703427.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703427.protein.info.v11.5.txt",
		        "node_list_path": "1703427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsphigho202Full5118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO2_02_FULL_51_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202Full5118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801823.protein.info.v11.5.txt",
		        "node_list_path": "1801823.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpAb3007Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. AB3007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpAb3007Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392487.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392487.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392487.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392487.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392487.protein.info.v11.5.txt",
		        "node_list_path": "1392487.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392487.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitratifractorSalsuginisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitratifractor salsuginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratifractorSalsuginisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "749222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "749222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "749222.clusters.proteins.v11.5.txt",
		        "sequence_path": "749222.protein.sequences.v11.5.fa",
		        "enrichment_path": "749222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "749222.protein.info.v11.5.txt",
		        "node_list_path": "749222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "749222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobisporaSpAtccPta5024(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbispora sp. ATCC PTA-5024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobisporaSpAtccPta5024", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316330.protein.sequences.v11.5.fa",
		        "enrichment_path": "316330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316330.protein.info.v11.5.txt",
		        "node_list_path": "316330.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaGladioliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia gladioli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaGladioliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999541.clusters.proteins.v11.5.txt",
		        "sequence_path": "999541.protein.sequences.v11.5.fa",
		        "enrichment_path": "999541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999541.protein.info.v11.5.txt",
		        "node_list_path": "999541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifoxyb1Full4015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYB1_FULL_40_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyb1Full4015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798697.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798697.protein.info.v11.5.txt",
		        "node_list_path": "1798697.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusPumilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus pumilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPumilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "315750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "315750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "315750.clusters.proteins.v11.5.txt",
		        "sequence_path": "315750.protein.sequences.v11.5.fa",
		        "enrichment_path": "315750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "315750.protein.info.v11.5.txt",
		        "node_list_path": "315750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "315750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcusMaripaludisC6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusMaripaludisC6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "444158.protein.sequences.v11.5.fa",
		        "enrichment_path": "444158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444158.protein.info.v11.5.txt",
		        "node_list_path": "444158.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumKa00251(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KA00251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumKa00251", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1497953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1497953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1497953.protein.info.v11.5.txt",
		        "node_list_path": "1497953.protein.complete.v11.5.txt"
		    }
		]
    )()

def StoquefichusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stoquefichus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StoquefichusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211844.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211844.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211844.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211844.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211844.protein.info.v11.5.txt",
		        "node_list_path": "1211844.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211844.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusLindneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus lindneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusLindneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53444.protein.sequences.v11.5.fa",
		        "enrichment_path": "53444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53444.protein.info.v11.5.txt",
		        "node_list_path": "53444.protein.complete.v11.5.txt"
		    }
		]
    )()

def TalaromycesMarneffei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces marneffei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesMarneffei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37727.protein.sequences.v11.5.fa",
		        "enrichment_path": "37727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37727.protein.info.v11.5.txt",
		        "node_list_path": "37727.protein.complete.v11.5.txt"
		    }
		]
    )()

def GrosmanniaClavigeraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Grosmannia clavigera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GrosmanniaClavigeraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "226899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "226899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "226899.clusters.proteins.v11.5.txt",
		        "sequence_path": "226899.protein.sequences.v11.5.fa",
		        "enrichment_path": "226899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226899.protein.info.v11.5.txt",
		        "node_list_path": "226899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "226899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DialisterSpCag357(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dialister sp. CAG:357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterSpCag357", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262869.protein.info.v11.5.txt",
		        "node_list_path": "1262869.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophomonasPalmitaticaJcm14374(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas palmitatica JCM 14374 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophomonasPalmitaticaJcm14374", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1294023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294023.protein.info.v11.5.txt",
		        "node_list_path": "1294023.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusHominisSk119(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus hominis SK119 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusHominisSk119", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "629742.protein.sequences.v11.5.fa",
		        "enrichment_path": "629742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "629742.protein.info.v11.5.txt",
		        "node_list_path": "629742.protein.complete.v11.5.txt"
		    }
		]
    )()

def LiberibacterCrescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter crescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LiberibacterCrescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1215343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1215343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1215343.clusters.proteins.v11.5.txt",
		        "sequence_path": "1215343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215343.protein.info.v11.5.txt",
		        "node_list_path": "1215343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1215343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMerionisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus merionis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMerionisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123308.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123308.protein.info.v11.5.txt",
		        "node_list_path": "1123308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PiliocolobusTephrosceles(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Piliocolobus tephrosceles graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiliocolobusTephrosceles", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "591936.protein.sequences.v11.5.fa",
		        "enrichment_path": "591936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591936.protein.info.v11.5.txt",
		        "node_list_path": "591936.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyaloperonosporaArabidopsidisEmoy2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyaloperonospora arabidopsidis Emoy2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyaloperonosporaArabidopsidisEmoy2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "559515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "559515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "559515.clusters.proteins.v11.5.txt",
		        "sequence_path": "559515.protein.sequences.v11.5.fa",
		        "enrichment_path": "559515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559515.protein.info.v11.5.txt",
		        "node_list_path": "559515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "559515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassospiraAustralica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira australica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraAustralica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1528106.protein.sequences.v11.5.fa",
		        "enrichment_path": "1528106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1528106.protein.info.v11.5.txt",
		        "node_list_path": "1528106.protein.complete.v11.5.txt"
		    }
		]
    )()

def FomitopsisPinicolaFp58527Ss1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fomitopsis pinicola FP-58527 SS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FomitopsisPinicolaFp58527Ss1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743788.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743788.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743788.clusters.proteins.v11.5.txt",
		        "sequence_path": "743788.protein.sequences.v11.5.fa",
		        "enrichment_path": "743788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743788.protein.info.v11.5.txt",
		        "node_list_path": "743788.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743788.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_35_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618478.protein.info.v11.5.txt",
		        "node_list_path": "1618478.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacterium4337(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 43-37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacterium4337", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895707.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895707.protein.info.v11.5.txt",
		        "node_list_path": "1895707.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasNitroreducensHbp1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens HBP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasNitroreducensHbp1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437882.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437882.protein.info.v11.5.txt",
		        "node_list_path": "1437882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSpSk11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSpSk11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1454000.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454000.protein.info.v11.5.txt",
		        "node_list_path": "1454000.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrueperaRadiovictrix(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Truepera radiovictrix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrueperaRadiovictrix", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649638.protein.sequences.v11.5.fa",
		        "enrichment_path": "649638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649638.protein.info.v11.5.txt",
		        "node_list_path": "649638.protein.complete.v11.5.txt"
		    }
		]
    )()

def CallithrixJacchusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Callithrix jacchus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CallithrixJacchusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9483.clusters.proteins.v11.5.txt",
		        "sequence_path": "9483.protein.sequences.v11.5.fa",
		        "enrichment_path": "9483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9483.protein.info.v11.5.txt",
		        "node_list_path": "9483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaSpOoc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Ooc graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaSpOoc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "100901.protein.sequences.v11.0.fa",
		        "enrichment_path": "100901.protein.enrichment.terms.v11.0.txt",
		        "info_path": "100901.protein.info.v11.0.txt",
		        "node_list_path": "100901.protein.complete.v11.0.txt"
		    }
		]
    )()

def HalapricumSalinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halapricum salinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalapricumSalinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1457250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1457250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1457250.protein.info.v11.5.txt",
		        "node_list_path": "1457250.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinicoccusSpYb142Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus sp. YB14-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusSpYb142Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1572701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1572701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1572701.clusters.proteins.v11.5.txt",
		        "sequence_path": "1572701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1572701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1572701.protein.info.v11.5.txt",
		        "node_list_path": "1572701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1572701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumEhc02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium EhC02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumEhc02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849170.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849170.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849170.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849170.protein.info.v11.5.txt",
		        "node_list_path": "1849170.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849170.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurovumSpArCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum sp. AR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurovumSpArCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1165841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1165841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1165841.clusters.proteins.v11.5.txt",
		        "sequence_path": "1165841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1165841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1165841.protein.info.v11.5.txt",
		        "node_list_path": "1165841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1165841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VitreoscillaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vitreoscilla massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VitreoscillaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1689272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1689272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1689272.protein.info.v11.5.txt",
		        "node_list_path": "1689272.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAdp1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ADP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAdp1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "62977.clusters.info.v11.5.txt",
		        "cluster_tree_path": "62977.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "62977.clusters.proteins.v11.5.txt",
		        "sequence_path": "62977.protein.sequences.v11.5.fa",
		        "enrichment_path": "62977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62977.protein.info.v11.5.txt",
		        "node_list_path": "62977.cluster.nodes.v11.5.txt",
		        "edge_list_path": "62977.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodocyclaceaeBacteriumPaddy1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodocyclaceae bacterium Paddy-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodocyclaceaeBacteriumPaddy1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1691980.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1691980.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1691980.clusters.proteins.v11.5.txt",
		        "sequence_path": "1691980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1691980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1691980.protein.info.v11.5.txt",
		        "node_list_path": "1691980.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1691980.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KocuriaVarians(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kocuria varians graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaVarians", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1272.protein.info.v11.5.txt",
		        "node_list_path": "1272.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryobacteriumLevicorallinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryobacterium levicorallinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryobacteriumLevicorallinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "995038.protein.sequences.v11.5.fa",
		        "enrichment_path": "995038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "995038.protein.info.v11.5.txt",
		        "node_list_path": "995038.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinibacteriumSpPamc21357Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinibacterium sp. PAMC 21357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinibacteriumSpPamc21357Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1112215.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1112215.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1112215.clusters.proteins.v11.5.txt",
		        "sequence_path": "1112215.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112215.protein.info.v11.5.txt",
		        "node_list_path": "1112215.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1112215.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonasPusillaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonas pusilla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonasPusillaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "38833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "38833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "38833.clusters.proteins.v11.5.txt",
		        "sequence_path": "38833.protein.sequences.v11.5.fa",
		        "enrichment_path": "38833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38833.protein.info.v11.5.txt",
		        "node_list_path": "38833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "38833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusHenryi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus henryi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusHenryi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123304.protein.info.v11.5.txt",
		        "node_list_path": "1123304.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaLacustrisZ7289Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina lacustris Z-7289 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaLacustrisZ7289Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434111.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434111.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434111.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434111.protein.info.v11.5.txt",
		        "node_list_path": "1434111.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434111.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProsthecochlorisAestuarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prosthecochloris aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProsthecochlorisAestuarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290512.protein.sequences.v11.5.fa",
		        "enrichment_path": "290512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290512.protein.info.v11.5.txt",
		        "node_list_path": "290512.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaHigoensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia higoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaHigoensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206730.protein.info.v11.5.txt",
		        "node_list_path": "1206730.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporomusaOvata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporomusa ovata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporomusaOvata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123288.protein.info.v11.5.txt",
		        "node_list_path": "1123288.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaPseudoobscura(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila pseudoobscura graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaPseudoobscura", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7237.protein.sequences.v11.5.fa",
		        "enrichment_path": "7237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7237.protein.info.v11.5.txt",
		        "node_list_path": "7237.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifoxyb12Full5810(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYB12_FULL_58_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyb12Full5810", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802418.protein.info.v11.5.txt",
		        "node_list_path": "1802418.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShigellaFlexneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shigella flexneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShigellaFlexneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "198214.protein.sequences.v11.5.fa",
		        "enrichment_path": "198214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198214.protein.info.v11.5.txt",
		        "node_list_path": "198214.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudozobelliaThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudozobellia thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudozobelliaThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "192903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "192903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "192903.clusters.proteins.v11.5.txt",
		        "sequence_path": "192903.protein.sequences.v11.5.fa",
		        "enrichment_path": "192903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192903.protein.info.v11.5.txt",
		        "node_list_path": "192903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "192903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosovibrioTenuis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosovibrio tenuis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosovibrioTenuis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1233.protein.info.v11.5.txt",
		        "node_list_path": "1233.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumCg2304012Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium CG2_30_40_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumCg2304012Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805402.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805402.protein.info.v11.5.txt",
		        "node_list_path": "1805402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarineActinobacteriumMedacidiG2a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G2A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineActinobacteriumMedacidiG2a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1550400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550400.protein.info.v11.5.txt",
		        "node_list_path": "1550400.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu087(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU087 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu087", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1676158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676158.protein.info.v11.5.txt",
		        "node_list_path": "1676158.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAc2028Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAc2028Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408321.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408321.protein.info.v11.5.txt",
		        "node_list_path": "1408321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpBal3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. BAL3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpBal3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391600.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391600.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391600.clusters.proteins.v11.5.txt",
		        "sequence_path": "391600.protein.sequences.v11.5.fa",
		        "enrichment_path": "391600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391600.protein.info.v11.5.txt",
		        "node_list_path": "391600.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391600.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalofilumOchraceum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halofilum ochraceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalofilumOchraceum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1611323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1611323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1611323.protein.info.v11.5.txt",
		        "node_list_path": "1611323.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpNku1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. NkU-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpNku1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095009.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095009.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095009.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095009.protein.info.v11.5.txt",
		        "node_list_path": "1095009.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095009.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PetrimonasMucosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Petrimonas mucosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PetrimonasMucosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1642646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1642646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1642646.clusters.proteins.v11.5.txt",
		        "sequence_path": "1642646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1642646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1642646.protein.info.v11.5.txt",
		        "node_list_path": "1642646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1642646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumDiphtheriaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium diphtheriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumDiphtheriaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "698964.clusters.info.v11.5.txt",
		        "cluster_tree_path": "698964.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "698964.clusters.proteins.v11.5.txt",
		        "sequence_path": "698964.protein.sequences.v11.5.fa",
		        "enrichment_path": "698964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698964.protein.info.v11.5.txt",
		        "node_list_path": "698964.cluster.nodes.v11.5.txt",
		        "edge_list_path": "698964.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesIakyrus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces iakyrus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesIakyrus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68219.protein.sequences.v11.5.fa",
		        "enrichment_path": "68219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68219.protein.info.v11.5.txt",
		        "node_list_path": "68219.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaSpCny236Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia sp. CNY236 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSpCny236Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1169152.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1169152.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1169152.clusters.proteins.v11.5.txt",
		        "sequence_path": "1169152.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169152.protein.info.v11.5.txt",
		        "node_list_path": "1169152.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1169152.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasEntomophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas entomophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasEntomophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "384676.protein.sequences.v11.5.fa",
		        "enrichment_path": "384676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "384676.protein.info.v11.5.txt",
		        "node_list_path": "384676.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaPertussisTohamaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella pertussis Tohama Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaPertussisTohamaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "257313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "257313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "257313.clusters.proteins.v11.5.txt",
		        "sequence_path": "257313.protein.sequences.v11.5.fa",
		        "enrichment_path": "257313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "257313.protein.info.v11.5.txt",
		        "node_list_path": "257313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "257313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeeuwenhoekiellaSpMar2009132Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella sp. MAR2009132 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeeuwenhoekiellaSpMar2009132Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392489.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392489.protein.info.v11.5.txt",
		        "node_list_path": "1392489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeolectaIrregularisDah3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neolecta irregularis DAH-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeolectaIrregularisDah3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1198029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1198029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1198029.clusters.proteins.v11.5.txt",
		        "sequence_path": "1198029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198029.protein.info.v11.5.txt",
		        "node_list_path": "1198029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1198029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NostocSpPcc7120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocSpPcc7120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "103690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "103690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "103690.clusters.proteins.v11.5.txt",
		        "sequence_path": "103690.protein.sequences.v11.5.fa",
		        "enrichment_path": "103690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103690.protein.info.v11.5.txt",
		        "node_list_path": "103690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "103690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsplowo212Full4712(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPLOWO2_12_FULL_47_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsplowo212Full4712", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817849.protein.info.v11.5.txt",
		        "node_list_path": "1817849.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassobiumSpR2a62(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassobium sp. R2A62 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobiumSpR2a62", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "633131.protein.sequences.v11.5.fa",
		        "enrichment_path": "633131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633131.protein.info.v11.5.txt",
		        "node_list_path": "633131.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmphibacillusJilinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amphibacillus jilinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphibacillusJilinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "562743.protein.sequences.v11.5.fa",
		        "enrichment_path": "562743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562743.protein.info.v11.5.txt",
		        "node_list_path": "562743.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpOk494Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. OK494 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpOk494Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500306.protein.info.v11.5.txt",
		        "node_list_path": "1500306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusNigrescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus nigrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusNigrescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1070870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1070870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1070870.clusters.proteins.v11.5.txt",
		        "sequence_path": "1070870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1070870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1070870.protein.info.v11.5.txt",
		        "node_list_path": "1070870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1070870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeuconostocPseudomesenteroidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc pseudomesenteroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocPseudomesenteroidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1154757.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1154757.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1154757.clusters.proteins.v11.5.txt",
		        "sequence_path": "1154757.protein.sequences.v11.5.fa",
		        "enrichment_path": "1154757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1154757.protein.info.v11.5.txt",
		        "node_list_path": "1154757.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1154757.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolibacterUsitatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solibacter usitatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolibacterUsitatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "234267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "234267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "234267.clusters.proteins.v11.5.txt",
		        "sequence_path": "234267.protein.sequences.v11.5.fa",
		        "enrichment_path": "234267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "234267.protein.info.v11.5.txt",
		        "node_list_path": "234267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "234267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanobisporaRosea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planobispora rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanobisporaRosea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35762.protein.sequences.v11.5.fa",
		        "enrichment_path": "35762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35762.protein.info.v11.5.txt",
		        "node_list_path": "35762.protein.complete.v11.5.txt"
		    }
		]
    )()

def SegniliparusRotundusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Segniliparus rotundus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SegniliparusRotundusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "640132.clusters.info.v11.5.txt",
		        "cluster_tree_path": "640132.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "640132.clusters.proteins.v11.5.txt",
		        "sequence_path": "640132.protein.sequences.v11.5.fa",
		        "enrichment_path": "640132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640132.protein.info.v11.5.txt",
		        "node_list_path": "640132.cluster.nodes.v11.5.txt",
		        "edge_list_path": "640132.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShimwelliaBlattae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shimwellia blattae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShimwelliaBlattae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "630626.protein.sequences.v11.5.fa",
		        "enrichment_path": "630626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "630626.protein.info.v11.5.txt",
		        "node_list_path": "630626.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaConchae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria conchae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaConchae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "981384.protein.sequences.v11.5.fa",
		        "enrichment_path": "981384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981384.protein.info.v11.5.txt",
		        "node_list_path": "981384.protein.complete.v11.5.txt"
		    }
		]
    )()

def PiscirickettsiaSalmonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Piscirickettsia salmonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiscirickettsiaSalmonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238.protein.info.v11.5.txt",
		        "node_list_path": "1238.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumBact13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumBact13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674827.protein.info.v11.5.txt",
		        "node_list_path": "1674827.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1934998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934998.protein.info.v11.5.txt",
		        "node_list_path": "1934998.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloquadratumSpJ07hqx50(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloquadratum sp. J07HQX50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloquadratumSpJ07hqx50", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1238426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238426.protein.info.v11.5.txt",
		        "node_list_path": "1238426.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterFiliformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter filiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterFiliformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "55758.protein.sequences.v11.5.fa",
		        "enrichment_path": "55758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55758.protein.info.v11.5.txt",
		        "node_list_path": "55758.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldanaerobiusPolysaccharolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldanaerobius polysaccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldanaerobiusPolysaccharolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935948.protein.sequences.v11.5.fa",
		        "enrichment_path": "935948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935948.protein.info.v11.5.txt",
		        "node_list_path": "935948.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpUrhd0069(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. URHD0069 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpUrhd0069", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380355.protein.info.v11.5.txt",
		        "node_list_path": "1380355.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesScabieiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces scabiei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesScabieiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "680198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "680198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "680198.clusters.proteins.v11.5.txt",
		        "sequence_path": "680198.protein.sequences.v11.5.fa",
		        "enrichment_path": "680198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "680198.protein.info.v11.5.txt",
		        "node_list_path": "680198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "680198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32002.protein.sequences.v11.5.fa",
		        "enrichment_path": "32002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32002.protein.info.v11.5.txt",
		        "node_list_path": "32002.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaSubspIndicaSerovar61425Z10127Str1121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. indica serovar 6,14,25:z10:1,(2),7 str. 1121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaSubspIndicaSerovar61425Z10127Str1121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173950.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173950.protein.info.v11.5.txt",
		        "node_list_path": "1173950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSp174mfsha11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 174MFSha1.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSp174mfsha11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502749.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502749.protein.info.v11.5.txt",
		        "node_list_path": "1502749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterLwoffiiNctc5866(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii NCTC 5866 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterLwoffiiNctc5866", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "981327.protein.sequences.v11.5.fa",
		        "enrichment_path": "981327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981327.protein.info.v11.5.txt",
		        "node_list_path": "981327.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCarsonellaRuddiiPcIsolateNhv(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii PC isolate NHV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCarsonellaRuddiiPcIsolateNhv", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1202540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202540.protein.info.v11.5.txt",
		        "node_list_path": "1202540.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSolincola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium solincola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSolincola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "510955.protein.sequences.v11.5.fa",
		        "enrichment_path": "510955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "510955.protein.info.v11.5.txt",
		        "node_list_path": "510955.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMycetoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium mycetoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMycetoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "38302.clusters.info.v11.5.txt",
		        "cluster_tree_path": "38302.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "38302.clusters.proteins.v11.5.txt",
		        "sequence_path": "38302.protein.sequences.v11.5.fa",
		        "enrichment_path": "38302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38302.protein.info.v11.5.txt",
		        "node_list_path": "38302.cluster.nodes.v11.5.txt",
		        "edge_list_path": "38302.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag389(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:389 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag389", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262801.protein.info.v11.5.txt",
		        "node_list_path": "1262801.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusRambelliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus rambellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusRambelliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "308745.clusters.info.v11.5.txt",
		        "cluster_tree_path": "308745.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "308745.clusters.proteins.v11.5.txt",
		        "sequence_path": "308745.protein.sequences.v11.5.fa",
		        "enrichment_path": "308745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "308745.protein.info.v11.5.txt",
		        "node_list_path": "308745.cluster.nodes.v11.5.txt",
		        "edge_list_path": "308745.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylocystisSpAtcc49242Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylocystis sp. ATCC49242 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocystisSpAtcc49242Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "622637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "622637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "622637.clusters.proteins.v11.5.txt",
		        "sequence_path": "622637.protein.sequences.v11.5.fa",
		        "enrichment_path": "622637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "622637.protein.info.v11.5.txt",
		        "node_list_path": "622637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "622637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpBh211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. BH-2-1-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpBh211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1905847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1905847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1905847.protein.info.v11.5.txt",
		        "node_list_path": "1905847.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylomonasSpDh1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas sp. DH-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasSpDh1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1727196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1727196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1727196.clusters.proteins.v11.5.txt",
		        "sequence_path": "1727196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1727196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1727196.protein.info.v11.5.txt",
		        "node_list_path": "1727196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1727196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriumCapsulatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacterium capsulatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriumCapsulatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "240015.protein.sequences.v11.5.fa",
		        "enrichment_path": "240015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240015.protein.info.v11.5.txt",
		        "node_list_path": "240015.protein.complete.v11.5.txt"
		    }
		]
    )()

def MerionesUnguiculatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meriones unguiculatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MerionesUnguiculatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10047.protein.sequences.v11.5.fa",
		        "enrichment_path": "10047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10047.protein.info.v11.5.txt",
		        "node_list_path": "10047.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumPiscinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium piscinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumPiscinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "686831.protein.sequences.v11.5.fa",
		        "enrichment_path": "686831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686831.protein.info.v11.5.txt",
		        "node_list_path": "686831.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumParaffinicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium paraffinicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumParaffinicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53378.clusters.proteins.v11.5.txt",
		        "sequence_path": "53378.protein.sequences.v11.5.fa",
		        "enrichment_path": "53378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53378.protein.info.v11.5.txt",
		        "node_list_path": "53378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp292mf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 292MF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp292mf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1151122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151122.protein.info.v11.5.txt",
		        "node_list_path": "1151122.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetallosphaeraCuprinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metallosphaera cuprina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetallosphaeraCuprinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1006006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1006006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1006006.clusters.proteins.v11.5.txt",
		        "sequence_path": "1006006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1006006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1006006.protein.info.v11.5.txt",
		        "node_list_path": "1006006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1006006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumMagnumDsm2767(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium magnum DSM 2767 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumMagnumDsm2767", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121326.protein.info.v11.5.txt",
		        "node_list_path": "1121326.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumFunditum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium funditum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumFunditum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449337.protein.info.v11.5.txt",
		        "node_list_path": "1449337.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpPcc7335Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpPcc7335Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "91464.clusters.info.v11.5.txt",
		        "cluster_tree_path": "91464.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "91464.clusters.proteins.v11.5.txt",
		        "sequence_path": "91464.protein.sequences.v11.5.fa",
		        "enrichment_path": "91464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91464.protein.info.v11.5.txt",
		        "node_list_path": "91464.cluster.nodes.v11.5.txt",
		        "edge_list_path": "91464.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasSp25b141(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. 25B141 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSp25b141", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280946.protein.info.v11.5.txt",
		        "node_list_path": "1280946.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusCrassostreae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus crassostreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusCrassostreae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1763538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1763538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1763538.protein.info.v11.5.txt",
		        "node_list_path": "1763538.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaGallisepticumF(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum F graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaGallisepticumF", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "708616.protein.sequences.v11.5.fa",
		        "enrichment_path": "708616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "708616.protein.info.v11.5.txt",
		        "node_list_path": "708616.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkelbacteriaBacteriumCg2303944(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium CG2_30_39_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumCg2303944", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805037.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805037.protein.info.v11.5.txt",
		        "node_list_path": "1805037.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiorhodospiraSibirica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiorhodospira sibirica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiorhodospiraSibirica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765914.protein.sequences.v11.5.fa",
		        "enrichment_path": "765914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765914.protein.info.v11.5.txt",
		        "node_list_path": "765914.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotaleaPsychrophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotalea psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotaleaPsychrophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "177439.protein.sequences.v11.5.fa",
		        "enrichment_path": "177439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "177439.protein.info.v11.5.txt",
		        "node_list_path": "177439.protein.complete.v11.5.txt"
		    }
		]
    )()

def NanohaloarchaeaArchaeonB1Br10U2g19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon B1-Br10_U2g19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NanohaloarchaeaArchaeonB1Br10U2g19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729454.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729454.protein.info.v11.5.txt",
		        "node_list_path": "1729454.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumCommune(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium commune graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumCommune", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1505727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505727.protein.info.v11.5.txt",
		        "node_list_path": "1505727.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterNecessariusAsymbioticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius asymbioticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterNecessariusAsymbioticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "312153.protein.sequences.v11.5.fa",
		        "enrichment_path": "312153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "312153.protein.info.v11.5.txt",
		        "node_list_path": "312153.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF3808Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-3808 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF3808Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1391699.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1391699.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1391699.clusters.proteins.v11.5.txt",
		        "sequence_path": "1391699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391699.protein.info.v11.5.txt",
		        "node_list_path": "1391699.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1391699.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterAnodireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter anodireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterAnodireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1340425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1340425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1340425.protein.info.v11.5.txt",
		        "node_list_path": "1340425.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseobacterSpGai101Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. GAI101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterSpGai101Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391589.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391589.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391589.clusters.proteins.v11.5.txt",
		        "sequence_path": "391589.protein.sequences.v11.5.fa",
		        "enrichment_path": "391589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391589.protein.info.v11.5.txt",
		        "node_list_path": "391589.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391589.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulosilyticumSpI15g10i2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulosilyticum sp. I15G10I2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulosilyticumSpI15g10i2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1892843.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1892843.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1892843.clusters.proteins.v11.5.txt",
		        "sequence_path": "1892843.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892843.protein.info.v11.5.txt",
		        "node_list_path": "1892843.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1892843.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterSputorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sputorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSputorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32024.protein.sequences.v11.5.fa",
		        "enrichment_path": "32024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32024.protein.info.v11.5.txt",
		        "node_list_path": "32024.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaMultisaccharivoraxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella multisaccharivorax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMultisaccharivoraxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "688246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "688246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "688246.clusters.proteins.v11.5.txt",
		        "sequence_path": "688246.protein.sequences.v11.5.fa",
		        "enrichment_path": "688246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688246.protein.info.v11.5.txt",
		        "node_list_path": "688246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "688246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCaseiDsm20011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus casei DSM20011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCaseiDsm20011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423732.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423732.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423732.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423732.protein.info.v11.5.txt",
		        "node_list_path": "1423732.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423732.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSpHmsc075b08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. HMSC075B08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSpHmsc075b08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739525.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739525.protein.info.v11.5.txt",
		        "node_list_path": "1739525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SoonwooaBuanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Soonwooa buanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SoonwooaBuanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "619805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "619805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "619805.clusters.proteins.v11.5.txt",
		        "sequence_path": "619805.protein.sequences.v11.5.fa",
		        "enrichment_path": "619805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "619805.protein.info.v11.5.txt",
		        "node_list_path": "619805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "619805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerasakiellaPusillaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terasakiella pusilla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerasakiellaPusillaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123355.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123355.protein.info.v11.5.txt",
		        "node_list_path": "1123355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AfipiaSp6413Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. 64-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaSp6413Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895701.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895701.protein.info.v11.5.txt",
		        "node_list_path": "1895701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarmoricolaSpUrhb0036Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marmoricola sp. URHB0036 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarmoricolaSpUrhb0036Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298863.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298863.protein.info.v11.5.txt",
		        "node_list_path": "1298863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRiflebacteriaBacteriumGwc2508(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riflebacteria bacterium GWC2_50_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRiflebacteriaBacteriumGwc2508", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817874.protein.info.v11.5.txt",
		        "node_list_path": "1817874.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionCpr3BacteriumGw2011Gwf23518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR3 bacterium GW2011_GWF2_35_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionCpr3BacteriumGw2011Gwf23518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618350.protein.info.v11.5.txt",
		        "node_list_path": "1618350.protein.complete.v11.5.txt"
		    }
		]
    )()

def CognatiyooniaSediminumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cognatiyoonia sediminum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CognatiyooniaSediminumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1508389.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1508389.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1508389.clusters.proteins.v11.5.txt",
		        "sequence_path": "1508389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1508389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1508389.protein.info.v11.5.txt",
		        "node_list_path": "1508389.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1508389.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusBataviensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus bataviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusBataviensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117379.protein.info.v11.5.txt",
		        "node_list_path": "1117379.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSyntrophoarchaeumCaldariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Syntrophoarchaeum caldarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSyntrophoarchaeumCaldariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1838285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1838285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1838285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1838285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1838285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1838285.protein.info.v11.5.txt",
		        "node_list_path": "1838285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1838285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterDongtanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter dongtanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterDongtanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "692370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "692370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "692370.clusters.proteins.v11.5.txt",
		        "sequence_path": "692370.protein.sequences.v11.5.fa",
		        "enrichment_path": "692370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "692370.protein.info.v11.5.txt",
		        "node_list_path": "692370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "692370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusSpRitPiF(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sp. RIT-PI-f graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSpRitPiF", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1690244.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690244.protein.info.v11.5.txt",
		        "node_list_path": "1690244.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollimonasFungivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collimonas fungivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollimonasFungivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005048.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005048.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005048.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005048.protein.info.v11.5.txt",
		        "node_list_path": "1005048.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005048.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EikenellaCorrodens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eikenella corrodens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EikenellaCorrodens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "539.protein.sequences.v11.5.fa",
		        "enrichment_path": "539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "539.protein.info.v11.5.txt",
		        "node_list_path": "539.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSp7392(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. 73-92 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSp7392", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895740.protein.info.v11.5.txt",
		        "node_list_path": "1895740.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumRifcsplowo201Full4825Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFCSPLOWO2_01_FULL_48_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifcsplowo201Full4825Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797259.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797259.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797259.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797259.protein.info.v11.5.txt",
		        "node_list_path": "1797259.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797259.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacillusSpJf8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. JF8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusSpJf8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1345697.protein.sequences.v11.5.fa",
		        "enrichment_path": "1345697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1345697.protein.info.v11.5.txt",
		        "node_list_path": "1345697.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusShizuokensisNbrc103103Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus shizuokensis NBRC 103103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusShizuokensisNbrc103103Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220573.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220573.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220573.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220573.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220573.protein.info.v11.5.txt",
		        "node_list_path": "1220573.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220573.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastococcusSpUrhd0036(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus sp. URHD0036 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusSpUrhd0036", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380356.protein.info.v11.5.txt",
		        "node_list_path": "1380356.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaProfusa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella profusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaProfusa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125712.protein.info.v11.5.txt",
		        "node_list_path": "1125712.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumRifcsplowo212Full6015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_12_FULL_60_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo212Full6015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798653.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798653.protein.info.v11.5.txt",
		        "node_list_path": "1798653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeleribacterHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Celeribacter halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeleribacterHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "576117.protein.sequences.v11.5.fa",
		        "enrichment_path": "576117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "576117.protein.info.v11.5.txt",
		        "node_list_path": "576117.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "253839.clusters.info.v11.5.txt",
		        "cluster_tree_path": "253839.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "253839.clusters.proteins.v11.5.txt",
		        "sequence_path": "253839.protein.sequences.v11.5.fa",
		        "enrichment_path": "253839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "253839.protein.info.v11.5.txt",
		        "node_list_path": "253839.cluster.nodes.v11.5.txt",
		        "edge_list_path": "253839.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KitasatosporaGriseola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora griseola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaGriseola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2064.protein.sequences.v11.5.fa",
		        "enrichment_path": "2064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2064.protein.info.v11.5.txt",
		        "node_list_path": "2064.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraKueneniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira kuenenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraKueneniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1168067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1168067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1168067.clusters.proteins.v11.5.txt",
		        "sequence_path": "1168067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168067.protein.info.v11.5.txt",
		        "node_list_path": "1168067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1168067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PersephonellaSpIf05l8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Persephonella sp. IF05L8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PersephonellaSpIf05l8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158338.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158338.protein.info.v11.5.txt",
		        "node_list_path": "1158338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasDaqiaonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas daqiaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasDaqiaonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "650850.protein.sequences.v11.5.fa",
		        "enrichment_path": "650850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "650850.protein.info.v11.5.txt",
		        "node_list_path": "650850.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwf24212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWF2_42_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwf24212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797824.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797824.protein.info.v11.5.txt",
		        "node_list_path": "1797824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyopneumoniaeJCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae J Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyopneumoniaeJCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "262719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "262719.clusters.proteins.v11.5.txt",
		        "sequence_path": "262719.protein.sequences.v11.5.fa",
		        "enrichment_path": "262719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262719.protein.info.v11.5.txt",
		        "node_list_path": "262719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "262719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParasutterellaExcrementihominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parasutterella excrementihominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParasutterellaExcrementihominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762966.clusters.proteins.v11.5.txt",
		        "sequence_path": "762966.protein.sequences.v11.5.fa",
		        "enrichment_path": "762966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762966.protein.info.v11.5.txt",
		        "node_list_path": "762966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AneurinibacillusTerranovensisDsm18919Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aneurinibacillus terranovensis DSM 18919 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AneurinibacillusTerranovensisDsm18919Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121002.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121002.protein.info.v11.5.txt",
		        "node_list_path": "1121002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActibacteriumMucosumKctc23349(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actibacterium mucosum KCTC 23349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActibacteriumMucosumKctc23349", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1454373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454373.protein.info.v11.5.txt",
		        "node_list_path": "1454373.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag144Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:144 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag144Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262736.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262736.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262736.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262736.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262736.protein.info.v11.5.txt",
		        "node_list_path": "1262736.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262736.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhinocladiellaMackenzieiCbs65093Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhinocladiella mackenziei CBS 650.93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhinocladiellaMackenzieiCbs65093Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1442369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1442369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1442369.clusters.proteins.v11.5.txt",
		        "sequence_path": "1442369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1442369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1442369.protein.info.v11.5.txt",
		        "node_list_path": "1442369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1442369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsphigho202Full4611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO2_02_FULL_46_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202Full4611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801820.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801820.protein.info.v11.5.txt",
		        "node_list_path": "1801820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpilithonimonasSpFh1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas sp. FH1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpilithonimonasSpFh1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1233951.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1233951.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1233951.clusters.proteins.v11.5.txt",
		        "sequence_path": "1233951.protein.sequences.v11.5.fa",
		        "enrichment_path": "1233951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1233951.protein.info.v11.5.txt",
		        "node_list_path": "1233951.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1233951.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumSpCag815(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium sp. CAG:815 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumSpCag815", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262901.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262901.protein.info.v11.5.txt",
		        "node_list_path": "1262901.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMacauensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus macauensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMacauensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196324.protein.info.v11.5.txt",
		        "node_list_path": "1196324.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterAlimentarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter alimentarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterAlimentarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "261164.protein.sequences.v11.5.fa",
		        "enrichment_path": "261164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "261164.protein.info.v11.5.txt",
		        "node_list_path": "261164.protein.complete.v11.5.txt"
		    }
		]
    )()

def EikenellaSpHmsc073a11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eikenella sp. HMSC073A11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EikenellaSpHmsc073a11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739535.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739535.protein.info.v11.5.txt",
		        "node_list_path": "1739535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FormosaSpHel3A148Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Formosa sp. Hel3_A1_48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaSpHel3A148Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336795.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336795.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336795.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336795.protein.info.v11.5.txt",
		        "node_list_path": "1336795.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336795.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArachisHypogaeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arachis hypogaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArachisHypogaeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3818.clusters.proteins.v11.5.txt",
		        "sequence_path": "3818.protein.sequences.v11.5.fa",
		        "enrichment_path": "3818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3818.protein.info.v11.5.txt",
		        "node_list_path": "3818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaProteobacteriumAap99(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return beta proteobacterium AAP99 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaProteobacteriumAap99", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523428.protein.info.v11.5.txt",
		        "node_list_path": "1523428.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterSpYs13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter sp. YS13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterSpYs13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1511746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1511746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1511746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1511746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1511746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1511746.protein.info.v11.5.txt",
		        "node_list_path": "1511746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1511746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GallionellaCapsiferriformans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallionella capsiferriformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallionellaCapsiferriformans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "395494.protein.sequences.v11.5.fa",
		        "enrichment_path": "395494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395494.protein.info.v11.5.txt",
		        "node_list_path": "395494.protein.complete.v11.5.txt"
		    }
		]
    )()

def PoeciliaMexicanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Poecilia mexicana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PoeciliaMexicanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "48701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "48701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "48701.clusters.proteins.v11.5.txt",
		        "sequence_path": "48701.protein.sequences.v11.5.fa",
		        "enrichment_path": "48701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48701.protein.info.v11.5.txt",
		        "node_list_path": "48701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "48701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeyerozymaSpJa9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meyerozyma sp. JA9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeyerozymaSpJa9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2028340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2028340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2028340.clusters.proteins.v11.5.txt",
		        "sequence_path": "2028340.protein.sequences.v11.5.fa",
		        "enrichment_path": "2028340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2028340.protein.info.v11.5.txt",
		        "node_list_path": "2028340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2028340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacillusBorstelensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus borstelensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusBorstelensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1444309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444309.protein.info.v11.5.txt",
		        "node_list_path": "1444309.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusChoshinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus choshinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusChoshinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "54911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "54911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "54911.clusters.proteins.v11.5.txt",
		        "sequence_path": "54911.protein.sequences.v11.5.fa",
		        "enrichment_path": "54911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54911.protein.info.v11.5.txt",
		        "node_list_path": "54911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "54911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumPalustreCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium palustre Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumPalustreCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121288.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121288.protein.info.v11.5.txt",
		        "node_list_path": "1121288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychroflexusGondwanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychroflexus gondwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroflexusGondwanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1189619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1189619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1189619.clusters.proteins.v11.5.txt",
		        "sequence_path": "1189619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1189619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1189619.protein.info.v11.5.txt",
		        "node_list_path": "1189619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1189619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CladophialophoraImmunda(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora immunda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CladophialophoraImmunda", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "569365.protein.sequences.v11.5.fa",
		        "enrichment_path": "569365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "569365.protein.info.v11.5.txt",
		        "node_list_path": "569365.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterNosocomialisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter nosocomialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterNosocomialisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "106654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "106654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "106654.clusters.proteins.v11.5.txt",
		        "sequence_path": "106654.protein.sequences.v11.5.fa",
		        "enrichment_path": "106654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106654.protein.info.v11.5.txt",
		        "node_list_path": "106654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "106654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemellaAsaccharolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella asaccharolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaAsaccharolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "502393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "502393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "502393.clusters.proteins.v11.5.txt",
		        "sequence_path": "502393.protein.sequences.v11.5.fa",
		        "enrichment_path": "502393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502393.protein.info.v11.5.txt",
		        "node_list_path": "502393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "502393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaTemeraria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia temeraria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaTemeraria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777137.protein.info.v11.5.txt",
		        "node_list_path": "1777137.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag386(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:386 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag386", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262925.protein.info.v11.5.txt",
		        "node_list_path": "1262925.protein.complete.v11.5.txt"
		    }
		]
    )()

def PythiumIwayamaiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pythium iwayamai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PythiumIwayamaiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "115417.clusters.info.v11.5.txt",
		        "cluster_tree_path": "115417.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "115417.clusters.proteins.v11.5.txt",
		        "sequence_path": "115417.protein.sequences.v11.5.fa",
		        "enrichment_path": "115417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115417.protein.info.v11.5.txt",
		        "node_list_path": "115417.cluster.nodes.v11.5.txt",
		        "edge_list_path": "115417.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillatorialesCyanobacteriumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillatorialesCyanobacteriumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "864702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "864702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "864702.clusters.proteins.v11.5.txt",
		        "sequence_path": "864702.protein.sequences.v11.5.fa",
		        "enrichment_path": "864702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864702.protein.info.v11.5.txt",
		        "node_list_path": "864702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "864702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrenophoraTriticirepentis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora triticirepentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrenophoraTriticirepentis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45151.protein.sequences.v11.5.fa",
		        "enrichment_path": "45151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45151.protein.info.v11.5.txt",
		        "node_list_path": "45151.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobaculumMassiliae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum massiliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobaculumMassiliae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883066.protein.sequences.v11.5.fa",
		        "enrichment_path": "883066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883066.protein.info.v11.5.txt",
		        "node_list_path": "883066.protein.complete.v11.5.txt"
		    }
		]
    )()

def BizioniaParagorgiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bizionia paragorgiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BizioniaParagorgiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "283786.clusters.info.v11.5.txt",
		        "cluster_tree_path": "283786.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "283786.clusters.proteins.v11.5.txt",
		        "sequence_path": "283786.protein.sequences.v11.5.fa",
		        "enrichment_path": "283786.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283786.protein.info.v11.5.txt",
		        "node_list_path": "283786.cluster.nodes.v11.5.txt",
		        "edge_list_path": "283786.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesF0058Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes F0058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesF0058Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575590.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575590.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575590.clusters.proteins.v11.5.txt",
		        "sequence_path": "575590.protein.sequences.v11.5.fa",
		        "enrichment_path": "575590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575590.protein.info.v11.5.txt",
		        "node_list_path": "575590.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575590.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SuccinivibrioDextrinosolvensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Succinivibrio dextrinosolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuccinivibrioDextrinosolvensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410676.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410676.protein.info.v11.5.txt",
		        "node_list_path": "1410676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwb13910bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_10b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13910bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618573.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618573.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618573.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618573.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618573.protein.info.v11.5.txt",
		        "node_list_path": "1618573.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618573.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylocellaSilvestris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylocella silvestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocellaSilvestris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "395965.protein.sequences.v11.5.fa",
		        "enrichment_path": "395965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395965.protein.info.v11.5.txt",
		        "node_list_path": "395965.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegamonasHypermegaleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megamonas hypermegale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegamonasHypermegaleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122216.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122216.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122216.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122216.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122216.protein.info.v11.5.txt",
		        "node_list_path": "1122216.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122216.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaIsraelensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella israelensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaIsraelensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "454.clusters.proteins.v11.5.txt",
		        "sequence_path": "454.protein.sequences.v11.5.fa",
		        "enrichment_path": "454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454.protein.info.v11.5.txt",
		        "node_list_path": "454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastomycesPercursus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces percursus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomycesPercursus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658174.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658174.protein.info.v11.5.txt",
		        "node_list_path": "1658174.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusMediterraneensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus mediterraneensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusMediterraneensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1870984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870984.protein.info.v11.5.txt",
		        "node_list_path": "1870984.protein.complete.v11.5.txt"
		    }
		]
    )()

def MillerozymaFarinosaCbs7064(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Millerozyma farinosa CBS 7064 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MillerozymaFarinosaCbs7064", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "559304.protein.sequences.v11.5.fa",
		        "enrichment_path": "559304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559304.protein.info.v11.5.txt",
		        "node_list_path": "559304.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRu3701(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. ru370.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRu3701", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761809.protein.info.v11.5.txt",
		        "node_list_path": "1761809.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200240037Sch5390672Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-40037_SCH5390672 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200240037Sch5390672Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834089.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834089.protein.info.v11.5.txt",
		        "node_list_path": "1834089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaGeestianaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella geestiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaGeestianaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45065.clusters.proteins.v11.5.txt",
		        "sequence_path": "45065.protein.sequences.v11.5.fa",
		        "enrichment_path": "45065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45065.protein.info.v11.5.txt",
		        "node_list_path": "45065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumKuroshium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium kuroshium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumKuroshium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2010991.protein.sequences.v11.5.fa",
		        "enrichment_path": "2010991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2010991.protein.info.v11.5.txt",
		        "node_list_path": "2010991.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusPyridinivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus pyridinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusPyridinivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1435356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1435356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1435356.clusters.proteins.v11.5.txt",
		        "sequence_path": "1435356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1435356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1435356.protein.info.v11.5.txt",
		        "node_list_path": "1435356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1435356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OligellaUrethralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oligella urethralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OligellaUrethralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1401065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401065.protein.info.v11.5.txt",
		        "node_list_path": "1401065.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloteneraSp73s(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera sp. 73s graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraSp73s", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1165096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1165096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1165096.protein.info.v11.5.txt",
		        "node_list_path": "1165096.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionKazanBacteriumRifcsplowo201Full4813(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RIFCSPLOWO2_01_FULL_48_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionKazanBacteriumRifcsplowo201Full4813", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798539.protein.info.v11.5.txt",
		        "node_list_path": "1798539.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumNygamaiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium nygamai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumNygamaiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42673.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42673.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42673.clusters.proteins.v11.5.txt",
		        "sequence_path": "42673.protein.sequences.v11.5.fa",
		        "enrichment_path": "42673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42673.protein.info.v11.5.txt",
		        "node_list_path": "42673.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42673.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat18019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-18019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat18019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1705110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705110.protein.info.v11.5.txt",
		        "node_list_path": "1705110.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesVulgatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides vulgatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesVulgatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "435590.clusters.info.v11.5.txt",
		        "cluster_tree_path": "435590.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "435590.clusters.proteins.v11.5.txt",
		        "sequence_path": "435590.protein.sequences.v11.5.fa",
		        "enrichment_path": "435590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435590.protein.info.v11.5.txt",
		        "node_list_path": "435590.cluster.nodes.v11.5.txt",
		        "edge_list_path": "435590.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterCetorumMit007128(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cetorum MIT007128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterCetorumMit007128", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "182217.protein.sequences.v11.5.fa",
		        "enrichment_path": "182217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "182217.protein.info.v11.5.txt",
		        "node_list_path": "182217.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasNasdae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas nasdae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasNasdae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "172043.protein.sequences.v11.5.fa",
		        "enrichment_path": "172043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "172043.protein.info.v11.5.txt",
		        "node_list_path": "172043.protein.complete.v11.5.txt"
		    }
		]
    )()

def NaumovozymaCastelliiCbs4309Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma castellii CBS 4309 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NaumovozymaCastelliiCbs4309Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1064592.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1064592.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1064592.clusters.proteins.v11.5.txt",
		        "sequence_path": "1064592.protein.sequences.v11.5.fa",
		        "enrichment_path": "1064592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1064592.protein.info.v11.5.txt",
		        "node_list_path": "1064592.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1064592.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag545Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:545 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag545Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262742.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262742.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262742.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262742.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262742.protein.info.v11.5.txt",
		        "node_list_path": "1262742.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262742.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KocuriaPalustris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kocuria palustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaPalustris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "71999.protein.sequences.v11.5.fa",
		        "enrichment_path": "71999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "71999.protein.info.v11.5.txt",
		        "node_list_path": "71999.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraJaponicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraJaponicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1325564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1325564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1325564.clusters.proteins.v11.5.txt",
		        "sequence_path": "1325564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325564.protein.info.v11.5.txt",
		        "node_list_path": "1325564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1325564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylibiumSpCf059Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylibium sp. CF059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylibiumSpCf059Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500261.protein.info.v11.5.txt",
		        "node_list_path": "1500261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsplowo201Full3910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_39_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798622.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798622.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798622.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798622.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798622.protein.info.v11.5.txt",
		        "node_list_path": "1798622.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798622.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaThiooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea thiooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaThiooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53254.clusters.proteins.v11.5.txt",
		        "sequence_path": "53254.protein.sequences.v11.5.fa",
		        "enrichment_path": "53254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53254.protein.info.v11.5.txt",
		        "node_list_path": "53254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumHispalense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium hispalense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumHispalense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "491205.protein.sequences.v11.5.fa",
		        "enrichment_path": "491205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "491205.protein.info.v11.5.txt",
		        "node_list_path": "491205.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusMarinonascensNbrc14363(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus marinonascens NBRC 14363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusMarinonascensNbrc14363", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219020.protein.info.v11.5.txt",
		        "node_list_path": "1219020.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSantoriniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter santoriniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSantoriniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288826.protein.info.v11.5.txt",
		        "node_list_path": "1288826.protein.complete.v11.5.txt"
		    }
		]
    )()

def PersephonellaSpKm09lau8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Persephonella sp. KM09Lau8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PersephonellaSpKm09lau8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158345.protein.info.v11.5.txt",
		        "node_list_path": "1158345.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumAlterfunditumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium alterfunditum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumAlterfunditumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449335.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449335.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449335.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449335.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449335.protein.info.v11.5.txt",
		        "node_list_path": "1449335.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449335.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AncylobacterRudongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ancylobacter rudongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AncylobacterRudongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "177413.protein.sequences.v11.5.fa",
		        "enrichment_path": "177413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "177413.protein.info.v11.5.txt",
		        "node_list_path": "177413.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraChibensisNbrc106107Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura chibensis NBRC 106107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraChibensisNbrc106107Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220554.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220554.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220554.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220554.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220554.protein.info.v11.5.txt",
		        "node_list_path": "1220554.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220554.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumRbg19ftCombo3910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RBG_19FT_COMBO_39_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumRbg19ftCombo3910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817748.protein.info.v11.5.txt",
		        "node_list_path": "1817748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumTaibaishanense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium taibaishanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumTaibaishanense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "887144.protein.sequences.v11.5.fa",
		        "enrichment_path": "887144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "887144.protein.info.v11.5.txt",
		        "node_list_path": "887144.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpJah(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. JAH graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpJah", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1742858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742858.protein.info.v11.5.txt",
		        "node_list_path": "1742858.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaSpiralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichinella spiralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaSpiralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6334.protein.sequences.v11.5.fa",
		        "enrichment_path": "6334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6334.protein.info.v11.5.txt",
		        "node_list_path": "6334.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasGinsengisoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasGinsengisoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "336566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "336566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "336566.clusters.proteins.v11.5.txt",
		        "sequence_path": "336566.protein.sequences.v11.5.fa",
		        "enrichment_path": "336566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336566.protein.info.v11.5.txt",
		        "node_list_path": "336566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "336566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConfluentimicrobiumSpEmb200Ns6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Confluentimicrobium sp. EMB200-NS6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConfluentimicrobiumSpEmb200Ns6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1609966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1609966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1609966.clusters.proteins.v11.5.txt",
		        "sequence_path": "1609966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1609966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1609966.protein.info.v11.5.txt",
		        "node_list_path": "1609966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1609966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "917.clusters.proteins.v11.5.txt",
		        "sequence_path": "917.protein.sequences.v11.5.fa",
		        "enrichment_path": "917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "917.protein.info.v11.5.txt",
		        "node_list_path": "917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BranchiibiusSpNy1634622Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Branchiibius sp. NY16-3462-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BranchiibiusSpNy1634622Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807500.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807500.protein.info.v11.5.txt",
		        "node_list_path": "1807500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OryziasLatipes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryzias latipes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryziasLatipes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8090.protein.sequences.v11.5.fa",
		        "enrichment_path": "8090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8090.protein.info.v11.5.txt",
		        "node_list_path": "8090.protein.complete.v11.5.txt"
		    }
		]
    )()

def MariniradiusSaccharolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mariniradius saccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MariniradiusSaccharolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1239962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1239962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1239962.protein.info.v11.5.txt",
		        "node_list_path": "1239962.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumRbg19ftCombo4210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RBG_19FT_COMBO_42_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumRbg19ftCombo4210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797359.protein.info.v11.5.txt",
		        "node_list_path": "1797359.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesOlivaceus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces olivaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesOlivaceus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47716.protein.sequences.v11.5.fa",
		        "enrichment_path": "47716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47716.protein.info.v11.5.txt",
		        "node_list_path": "47716.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylosarcinaLacusLw14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylosarcina lacus LW14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylosarcinaLacusLw14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1114263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114263.protein.info.v11.5.txt",
		        "node_list_path": "1114263.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlautiaHydrogenotrophica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blautia hydrogenotrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaHydrogenotrophica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "476272.protein.sequences.v11.5.fa",
		        "enrichment_path": "476272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "476272.protein.info.v11.5.txt",
		        "node_list_path": "476272.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumAkiainvivens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium akiainvivens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumAkiainvivens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1202724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202724.protein.info.v11.5.txt",
		        "node_list_path": "1202724.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCarboxidivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium carboxidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCarboxidivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "536227.protein.sequences.v11.5.fa",
		        "enrichment_path": "536227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "536227.protein.info.v11.5.txt",
		        "node_list_path": "536227.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumGloeosporioidesCg14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum gloeosporioides Cg-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumGloeosporioidesCg14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1237896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1237896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1237896.protein.info.v11.5.txt",
		        "node_list_path": "1237896.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpStF2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ST-F2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpStF2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1490484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1490484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1490484.protein.info.v11.5.txt",
		        "node_list_path": "1490484.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacteraceaeBacteriumGwc25311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_53_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacteraceaeBacteriumGwc25311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798316.protein.info.v11.5.txt",
		        "node_list_path": "1798316.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChristensenellaTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Christensenella timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChristensenellaTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816678.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816678.protein.info.v11.5.txt",
		        "node_list_path": "1816678.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaGratianaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella gratiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaGratianaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45066.clusters.proteins.v11.5.txt",
		        "sequence_path": "45066.protein.sequences.v11.5.fa",
		        "enrichment_path": "45066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45066.protein.info.v11.5.txt",
		        "node_list_path": "45066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaDenticola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella denticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaDenticola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "767031.protein.sequences.v11.5.fa",
		        "enrichment_path": "767031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767031.protein.info.v11.5.txt",
		        "node_list_path": "767031.protein.complete.v11.5.txt"
		    }
		]
    )()

def RaphidocelisSubcapitataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Raphidocelis subcapitata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RaphidocelisSubcapitataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "307507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "307507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "307507.clusters.proteins.v11.5.txt",
		        "sequence_path": "307507.protein.sequences.v11.5.fa",
		        "enrichment_path": "307507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "307507.protein.info.v11.5.txt",
		        "node_list_path": "307507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "307507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusAsaccharolyticusDsm20463Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus asaccharolyticus DSM 20463 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusAsaccharolyticusDsm20463Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573058.clusters.proteins.v11.5.txt",
		        "sequence_path": "573058.protein.sequences.v11.5.fa",
		        "enrichment_path": "573058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573058.protein.info.v11.5.txt",
		        "node_list_path": "573058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HenriciellaLitoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Henriciella litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HenriciellaLitoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "568102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "568102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "568102.clusters.proteins.v11.5.txt",
		        "sequence_path": "568102.protein.sequences.v11.5.fa",
		        "enrichment_path": "568102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568102.protein.info.v11.5.txt",
		        "node_list_path": "568102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "568102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeosporobacterFerrireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geosporobacter ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeosporobacterFerrireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1424294.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1424294.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1424294.clusters.proteins.v11.5.txt",
		        "sequence_path": "1424294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1424294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1424294.protein.info.v11.5.txt",
		        "node_list_path": "1424294.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1424294.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SediminibacteriumSpC3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium sp. C3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacteriumSpC3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267211.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267211.protein.info.v11.5.txt",
		        "node_list_path": "1267211.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusTerreusNih2624(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus terreus NIH2624 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusTerreusNih2624", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "341663.protein.sequences.v11.5.fa",
		        "enrichment_path": "341663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "341663.protein.info.v11.5.txt",
		        "node_list_path": "341663.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapsicumAnnuumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capsicum annuum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsicumAnnuumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4072.clusters.proteins.v11.5.txt",
		        "sequence_path": "4072.protein.sequences.v11.5.fa",
		        "enrichment_path": "4072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4072.protein.info.v11.5.txt",
		        "node_list_path": "4072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlaciecolaPuniceaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola punicea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaPuniceaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121923.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121923.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121923.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121923.protein.info.v11.5.txt",
		        "node_list_path": "1121923.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121923.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaElongataSubspGlycolyticaAtcc29315Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria elongata subsp. glycolytica ATCC 29315 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaElongataSubspGlycolyticaAtcc29315Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546263.clusters.proteins.v11.5.txt",
		        "sequence_path": "546263.protein.sequences.v11.5.fa",
		        "enrichment_path": "546263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546263.protein.info.v11.5.txt",
		        "node_list_path": "546263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisSk597(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK597 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisSk597", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585204.protein.sequences.v11.5.fa",
		        "enrichment_path": "585204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585204.protein.info.v11.5.txt",
		        "node_list_path": "585204.protein.complete.v11.5.txt"
		    }
		]
    )()

def DaedaleaQuercinaL15889(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Daedalea quercina L-15889 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DaedaleaQuercinaL15889", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314783.protein.info.v11.5.txt",
		        "node_list_path": "1314783.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumSpRoot236(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root236 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumSpRoot236", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736498.protein.info.v11.5.txt",
		        "node_list_path": "1736498.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermovenabulumGondwanense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermovenabulum gondwanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermovenabulumGondwanense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "520767.protein.sequences.v11.5.fa",
		        "enrichment_path": "520767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "520767.protein.info.v11.5.txt",
		        "node_list_path": "520767.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfifellaMarinaDsm2698(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Afifella marina DSM 2698 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfifellaMarinaDsm2698", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120955.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120955.protein.info.v11.5.txt",
		        "node_list_path": "1120955.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpStBin5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. ST-bin5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpStBin5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1978765.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1978765.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1978765.clusters.proteins.v11.5.txt",
		        "sequence_path": "1978765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978765.protein.info.v11.5.txt",
		        "node_list_path": "1978765.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1978765.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacillusBorstelensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus borstelensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusBorstelensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1444309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1444309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1444309.clusters.proteins.v11.5.txt",
		        "sequence_path": "1444309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444309.protein.info.v11.5.txt",
		        "node_list_path": "1444309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1444309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLeaf391Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf391 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLeaf391Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736360.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736360.protein.info.v11.5.txt",
		        "node_list_path": "1736360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermomicrobialesSpKi4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Thermomicrobiales sp. KI4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "ThermomicrobialesSpKi4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1382356.protein.sequences.v11.0.fa",
		        "enrichment_path": "1382356.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1382356.protein.info.v11.0.txt",
		        "node_list_path": "1382356.protein.complete.v11.0.txt"
		    }
		]
    )()

def BacillusVelezensisYauB9601Y2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus velezensis YAU B9601-Y2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusVelezensisYauB9601Y2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1155777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1155777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1155777.protein.info.v11.5.txt",
		        "node_list_path": "1155777.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumCg2306842(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium CG2_30_68_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumCg2306842", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805051.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805051.protein.info.v11.5.txt",
		        "node_list_path": "1805051.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumAlkaliphilum121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium alkaliphilum 12/1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumAlkaliphilum121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "506480.protein.sequences.v11.5.fa",
		        "enrichment_path": "506480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "506480.protein.info.v11.5.txt",
		        "node_list_path": "506480.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "505249.protein.sequences.v11.5.fa",
		        "enrichment_path": "505249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "505249.protein.info.v11.5.txt",
		        "node_list_path": "505249.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLeaf384Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf384 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLeaf384Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736358.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736358.protein.info.v11.5.txt",
		        "node_list_path": "1736358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrechmeriaConiosporaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drechmeria coniospora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrechmeriaConiosporaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "98403.clusters.info.v11.5.txt",
		        "cluster_tree_path": "98403.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "98403.clusters.proteins.v11.5.txt",
		        "sequence_path": "98403.protein.sequences.v11.5.fa",
		        "enrichment_path": "98403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "98403.protein.info.v11.5.txt",
		        "node_list_path": "98403.cluster.nodes.v11.5.txt",
		        "edge_list_path": "98403.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusTorques(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Ruminococcus] torques graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusTorques", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33039.protein.sequences.v11.5.fa",
		        "enrichment_path": "33039.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33039.protein.info.v11.5.txt",
		        "node_list_path": "33039.protein.complete.v11.5.txt"
		    }
		]
    )()

def CeleribacterMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Celeribacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeleribacterMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397108.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397108.protein.info.v11.5.txt",
		        "node_list_path": "1397108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriellaXinjiangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriella xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriellaXinjiangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "684065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "684065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "684065.clusters.proteins.v11.5.txt",
		        "sequence_path": "684065.protein.sequences.v11.5.fa",
		        "enrichment_path": "684065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "684065.protein.info.v11.5.txt",
		        "node_list_path": "684065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "684065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpScn5710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. SCN 57-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpScn5710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660094.protein.info.v11.5.txt",
		        "node_list_path": "1660094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasBoliviensisLc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas boliviensis LC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasBoliviensisLc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1072583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1072583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1072583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1072583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1072583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1072583.protein.info.v11.5.txt",
		        "node_list_path": "1072583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1072583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaSpLc85(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. LC85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpLc85", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502851.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502851.protein.info.v11.5.txt",
		        "node_list_path": "1502851.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusSbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus SB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusSbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59926.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59926.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59926.clusters.proteins.v11.5.txt",
		        "sequence_path": "59926.protein.sequences.v11.5.fa",
		        "enrichment_path": "59926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59926.protein.info.v11.5.txt",
		        "node_list_path": "59926.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59926.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DaucusCarotaSubspSativus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Daucus carota subsp. sativus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DaucusCarotaSubspSativus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "79200.protein.sequences.v11.5.fa",
		        "enrichment_path": "79200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79200.protein.info.v11.5.txt",
		        "node_list_path": "79200.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgreiaBicolorataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agreia bicolorata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgreiaBicolorataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "110935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "110935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "110935.clusters.proteins.v11.5.txt",
		        "sequence_path": "110935.protein.sequences.v11.5.fa",
		        "enrichment_path": "110935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "110935.protein.info.v11.5.txt",
		        "node_list_path": "110935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "110935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalditerrivibrioNitroreducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Calditerrivibrio nitroreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalditerrivibrioNitroreducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "768670.clusters.info.v11.5.txt",
		        "cluster_tree_path": "768670.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "768670.clusters.proteins.v11.5.txt",
		        "sequence_path": "768670.protein.sequences.v11.5.fa",
		        "enrichment_path": "768670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768670.protein.info.v11.5.txt",
		        "node_list_path": "768670.cluster.nodes.v11.5.txt",
		        "edge_list_path": "768670.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpVkmB2647(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. VKM B-2647 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpVkmB2647", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1590651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1590651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1590651.protein.info.v11.5.txt",
		        "node_list_path": "1590651.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumVincentii4113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii 4113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumVincentii4113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469606.protein.sequences.v11.5.fa",
		        "enrichment_path": "469606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469606.protein.info.v11.5.txt",
		        "node_list_path": "469606.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusZeaxanthinifaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus zeaxanthinifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusZeaxanthinifaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1266998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1266998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1266998.clusters.proteins.v11.5.txt",
		        "sequence_path": "1266998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266998.protein.info.v11.5.txt",
		        "node_list_path": "1266998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1266998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag202(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:202 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag202", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262884.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262884.protein.info.v11.5.txt",
		        "node_list_path": "1262884.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusQuebecensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus quebecensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusQuebecensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "903983.protein.sequences.v11.5.fa",
		        "enrichment_path": "903983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903983.protein.info.v11.5.txt",
		        "node_list_path": "903983.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterovibrioCalviensisDsm14347Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio calviensis DSM 14347 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioCalviensisDsm14347Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121867.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121867.protein.info.v11.5.txt",
		        "node_list_path": "1121867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VirgibacillusSiamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus siamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusSiamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "480071.protein.sequences.v11.5.fa",
		        "enrichment_path": "480071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "480071.protein.info.v11.5.txt",
		        "node_list_path": "480071.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlrh(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALRh graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlrh", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1266911.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266911.protein.info.v11.5.txt",
		        "node_list_path": "1266911.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesFulvissimusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces fulvissimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesFulvissimusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1303692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1303692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1303692.clusters.proteins.v11.5.txt",
		        "sequence_path": "1303692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1303692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1303692.protein.info.v11.5.txt",
		        "node_list_path": "1303692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1303692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumThoenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium thoenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumThoenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122998.protein.info.v11.5.txt",
		        "node_list_path": "1122998.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrenophoraTriticiRepentisPt1cBfp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora tritici-repentis Pt-1C-BFP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrenophoraTriticiRepentisPt1cBfp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426418.protein.sequences.v11.5.fa",
		        "enrichment_path": "426418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426418.protein.info.v11.5.txt",
		        "node_list_path": "426418.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeriophthalmusMagnuspinnatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Periophthalmus magnuspinnatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeriophthalmusMagnuspinnatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "409849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "409849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "409849.clusters.proteins.v11.5.txt",
		        "sequence_path": "409849.protein.sequences.v11.5.fa",
		        "enrichment_path": "409849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "409849.protein.info.v11.5.txt",
		        "node_list_path": "409849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "409849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfitibacterSpBrhC19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfitibacter sp. BRH_c19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitibacterSpBrhC19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1734395.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1734395.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1734395.clusters.proteins.v11.5.txt",
		        "sequence_path": "1734395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1734395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1734395.protein.info.v11.5.txt",
		        "node_list_path": "1734395.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1734395.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium9143bfaa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 9143BFAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium9143bfaa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658088.protein.sequences.v11.5.fa",
		        "enrichment_path": "658088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658088.protein.info.v11.5.txt",
		        "node_list_path": "658088.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerolineaThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerolinea thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926569.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926569.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926569.clusters.proteins.v11.5.txt",
		        "sequence_path": "926569.protein.sequences.v11.5.fa",
		        "enrichment_path": "926569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926569.protein.info.v11.5.txt",
		        "node_list_path": "926569.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926569.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FructobacillusDurionis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fructobacillus durionis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FructobacillusDurionis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "283737.protein.sequences.v11.5.fa",
		        "enrichment_path": "283737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283737.protein.info.v11.5.txt",
		        "node_list_path": "283737.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusGauvreauii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus gauvreauii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusGauvreauii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123075.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123075.protein.info.v11.5.txt",
		        "node_list_path": "1123075.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSanguinisSk1057(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK1057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSanguinisSk1057", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888821.protein.sequences.v11.5.fa",
		        "enrichment_path": "888821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888821.protein.info.v11.5.txt",
		        "node_list_path": "888821.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSlbn53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SLBN-53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSlbn53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1570328.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1570328.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1570328.clusters.proteins.v11.5.txt",
		        "sequence_path": "1570328.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570328.protein.info.v11.5.txt",
		        "node_list_path": "1570328.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1570328.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RicheliaIntracellularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Richelia intracellularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RicheliaIntracellularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1165094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1165094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1165094.protein.info.v11.5.txt",
		        "node_list_path": "1165094.protein.complete.v11.5.txt"
		    }
		]
    )()

def BombusImpatiensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bombus impatiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BombusImpatiensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "132113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "132113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "132113.clusters.proteins.v11.5.txt",
		        "sequence_path": "132113.protein.sequences.v11.5.fa",
		        "enrichment_path": "132113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "132113.protein.info.v11.5.txt",
		        "node_list_path": "132113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "132113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpRl(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. RL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpRl", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1452718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1452718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1452718.protein.info.v11.5.txt",
		        "node_list_path": "1452718.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusSpBab2008(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus sp. BAB2008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusSpBab2008", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246484.protein.info.v11.5.txt",
		        "node_list_path": "1246484.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumHassiacumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium hassiacum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumHassiacumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122247.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122247.protein.info.v11.5.txt",
		        "node_list_path": "1122247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpUnc345mftsu51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. UNC345MFTsu5.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpUnc345mftsu51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449070.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449070.protein.info.v11.5.txt",
		        "node_list_path": "1449070.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerosphaeraAminiphilaDsm21120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerosphaera aminiphila DSM 21120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerosphaeraAminiphilaDsm21120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120995.protein.info.v11.5.txt",
		        "node_list_path": "1120995.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807731.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807731.protein.info.v11.5.txt",
		        "node_list_path": "1807731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaladaptatusCibarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haladaptatus cibarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaladaptatusCibarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1455608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1455608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1455608.protein.info.v11.5.txt",
		        "node_list_path": "1455608.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag914(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:914 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag914", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262846.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262846.protein.info.v11.5.txt",
		        "node_list_path": "1262846.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesXylanisolvensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides xylanisolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesXylanisolvensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "657309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "657309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "657309.clusters.proteins.v11.5.txt",
		        "sequence_path": "657309.protein.sequences.v11.5.fa",
		        "enrichment_path": "657309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657309.protein.info.v11.5.txt",
		        "node_list_path": "657309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "657309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlutamicibacterSp0426Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glutamicibacter sp. 0426 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlutamicibacterSp0426Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1913445.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1913445.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1913445.clusters.proteins.v11.5.txt",
		        "sequence_path": "1913445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1913445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1913445.protein.info.v11.5.txt",
		        "node_list_path": "1913445.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1913445.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusFlavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus flavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusFlavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5059.protein.sequences.v11.5.fa",
		        "enrichment_path": "5059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5059.protein.info.v11.5.txt",
		        "node_list_path": "5059.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSelenitireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus selenitireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSelenitireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "439292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "439292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "439292.clusters.proteins.v11.5.txt",
		        "sequence_path": "439292.protein.sequences.v11.5.fa",
		        "enrichment_path": "439292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439292.protein.info.v11.5.txt",
		        "node_list_path": "439292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "439292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumManteniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium mantenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumManteniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "560555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "560555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "560555.clusters.proteins.v11.5.txt",
		        "sequence_path": "560555.protein.sequences.v11.5.fa",
		        "enrichment_path": "560555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "560555.protein.info.v11.5.txt",
		        "node_list_path": "560555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "560555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasEncheleiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas encheleia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasEncheleiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "73010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "73010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "73010.clusters.proteins.v11.5.txt",
		        "sequence_path": "73010.protein.sequences.v11.5.fa",
		        "enrichment_path": "73010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "73010.protein.info.v11.5.txt",
		        "node_list_path": "73010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "73010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrypanosomaBruceiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma brucei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrypanosomaBruceiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5691.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5691.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5691.clusters.proteins.v11.5.txt",
		        "sequence_path": "5691.protein.sequences.v11.5.fa",
		        "enrichment_path": "5691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5691.protein.info.v11.5.txt",
		        "node_list_path": "5691.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5691.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4510c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_02_FULL_45_10c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4510c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798410.protein.info.v11.5.txt",
		        "node_list_path": "1798410.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaParapsilosis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida parapsilosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaParapsilosis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5480.protein.sequences.v11.5.fa",
		        "enrichment_path": "5480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5480.protein.info.v11.5.txt",
		        "node_list_path": "5480.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasSpSn2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. SN2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasSpSn2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "715451.protein.sequences.v11.5.fa",
		        "enrichment_path": "715451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "715451.protein.info.v11.5.txt",
		        "node_list_path": "715451.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisAustraliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis australiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisAustraliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546364.clusters.proteins.v11.5.txt",
		        "sequence_path": "546364.protein.sequences.v11.5.fa",
		        "enrichment_path": "546364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546364.protein.info.v11.5.txt",
		        "node_list_path": "546364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriaceaeBacteriumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacteriaceae bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriaceaeBacteriumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1873462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1873462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1873462.clusters.proteins.v11.5.txt",
		        "sequence_path": "1873462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1873462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1873462.protein.info.v11.5.txt",
		        "node_list_path": "1873462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1873462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PteropusAlecto(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pteropus alecto graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PteropusAlecto", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9402.protein.sequences.v11.5.fa",
		        "enrichment_path": "9402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9402.protein.info.v11.5.txt",
		        "node_list_path": "9402.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAquaticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium aquaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAquaticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1927124.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1927124.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1927124.clusters.proteins.v11.5.txt",
		        "sequence_path": "1927124.protein.sequences.v11.5.fa",
		        "enrichment_path": "1927124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1927124.protein.info.v11.5.txt",
		        "node_list_path": "1927124.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1927124.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122921.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122921.protein.info.v11.5.txt",
		        "node_list_path": "1122921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumM102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium M102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumM102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235796.protein.info.v11.5.txt",
		        "node_list_path": "1235796.protein.complete.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterIshigakiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter ishigakiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterIshigakiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "476157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "476157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "476157.clusters.proteins.v11.5.txt",
		        "sequence_path": "476157.protein.sequences.v11.5.fa",
		        "enrichment_path": "476157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "476157.protein.info.v11.5.txt",
		        "node_list_path": "476157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "476157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumGibsoniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum gibsoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumGibsoniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "767817.protein.sequences.v11.5.fa",
		        "enrichment_path": "767817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767817.protein.info.v11.5.txt",
		        "node_list_path": "767817.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumEtliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumEtliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29449.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29449.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29449.clusters.proteins.v11.5.txt",
		        "sequence_path": "29449.protein.sequences.v11.5.fa",
		        "enrichment_path": "29449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29449.protein.info.v11.5.txt",
		        "node_list_path": "29449.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29449.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxya2Full588(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2_FULL_58_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2Full588", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797962.protein.info.v11.5.txt",
		        "node_list_path": "1797962.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhycicoccusJejuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phycicoccus jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycicoccusJejuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "367299.protein.sequences.v11.5.fa",
		        "enrichment_path": "367299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "367299.protein.info.v11.5.txt",
		        "node_list_path": "367299.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRoot122Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root122 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRoot122Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736431.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736431.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736431.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736431.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736431.protein.info.v11.5.txt",
		        "node_list_path": "1736431.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736431.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CastellaniellaCaeniNbrc101664Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Castellaniella caeni NBRC 101664 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CastellaniellaCaeniNbrc101664Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349760.protein.info.v11.5.txt",
		        "node_list_path": "1349760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusNovalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus novalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusNovalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "220687.clusters.info.v11.5.txt",
		        "cluster_tree_path": "220687.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "220687.clusters.proteins.v11.5.txt",
		        "sequence_path": "220687.protein.sequences.v11.5.fa",
		        "enrichment_path": "220687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220687.protein.info.v11.5.txt",
		        "node_list_path": "220687.cluster.nodes.v11.5.txt",
		        "edge_list_path": "220687.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumScardovii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium scardovii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumScardovii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "158787.protein.sequences.v11.5.fa",
		        "enrichment_path": "158787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158787.protein.info.v11.5.txt",
		        "node_list_path": "158787.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumBrhC4aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRH_c4a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumBrhC4aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629716.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629716.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629716.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629716.protein.info.v11.5.txt",
		        "node_list_path": "1629716.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629716.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchmidhempeliaBombiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schmidhempelia bombi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchmidhempeliaBombiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1387197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1387197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1387197.clusters.proteins.v11.5.txt",
		        "sequence_path": "1387197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387197.protein.info.v11.5.txt",
		        "node_list_path": "1387197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1387197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinicellaSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinicella sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinicellaSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1792834.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1792834.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1792834.clusters.proteins.v11.5.txt",
		        "sequence_path": "1792834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792834.protein.info.v11.5.txt",
		        "node_list_path": "1792834.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1792834.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSpGwe1629Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. GWE1_62_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSpGwe1629Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802374.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802374.protein.info.v11.5.txt",
		        "node_list_path": "1802374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusBasilensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus basilensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusBasilensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68895.protein.sequences.v11.5.fa",
		        "enrichment_path": "68895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68895.protein.info.v11.5.txt",
		        "node_list_path": "68895.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp11649854(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1164985.4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp11649854", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834069.protein.info.v11.5.txt",
		        "node_list_path": "1834069.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho202Full4118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_41_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full4118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801754.protein.info.v11.5.txt",
		        "node_list_path": "1801754.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinarimonadaceaeBacteriumHl109Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinarimonadaceae bacterium HL-109 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinarimonadaceaeBacteriumHl109Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1653334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1653334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1653334.clusters.proteins.v11.5.txt",
		        "sequence_path": "1653334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1653334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1653334.protein.info.v11.5.txt",
		        "node_list_path": "1653334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1653334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinitogaSp1155(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinitoga sp. 1155 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinitogaSp1155", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1428448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1428448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1428448.protein.info.v11.5.txt",
		        "node_list_path": "1428448.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesStercoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides stercoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesStercoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "449673.protein.sequences.v11.5.fa",
		        "enrichment_path": "449673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "449673.protein.info.v11.5.txt",
		        "node_list_path": "449673.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChinchillaLanigeraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chinchilla lanigera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChinchillaLanigeraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34839.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34839.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34839.clusters.proteins.v11.5.txt",
		        "sequence_path": "34839.protein.sequences.v11.5.fa",
		        "enrichment_path": "34839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34839.protein.info.v11.5.txt",
		        "node_list_path": "34839.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34839.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumGw2011Gwf23829Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_38_29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf23829Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619066.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619066.protein.info.v11.5.txt",
		        "node_list_path": "1619066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlaciecolaPunicea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola punicea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaPunicea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121923.protein.info.v11.5.txt",
		        "node_list_path": "1121923.protein.complete.v11.5.txt"
		    }
		]
    )()

def IdiomarinaXiamenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaXiamenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "740709.protein.sequences.v11.5.fa",
		        "enrichment_path": "740709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "740709.protein.info.v11.5.txt",
		        "node_list_path": "740709.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarssoninaCoronariae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marssonina coronariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarssoninaCoronariae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "503106.protein.sequences.v11.5.fa",
		        "enrichment_path": "503106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "503106.protein.info.v11.5.txt",
		        "node_list_path": "503106.protein.complete.v11.5.txt"
		    }
		]
    )()

def PectobacteriumAtrosepticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium atrosepticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumAtrosepticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "218491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "218491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "218491.clusters.proteins.v11.5.txt",
		        "sequence_path": "218491.protein.sequences.v11.5.fa",
		        "enrichment_path": "218491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218491.protein.info.v11.5.txt",
		        "node_list_path": "218491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "218491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpOv118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ov118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpOv118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761747.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761747.protein.info.v11.5.txt",
		        "node_list_path": "1761747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph2100(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH2100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph2100", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217708.protein.info.v11.5.txt",
		        "node_list_path": "1217708.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumLlatzerense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium llatzerense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumLlatzerense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "280871.protein.sequences.v11.5.fa",
		        "enrichment_path": "280871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "280871.protein.info.v11.5.txt",
		        "node_list_path": "280871.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasTranslucens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas translucens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasTranslucens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1205753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1205753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1205753.protein.info.v11.5.txt",
		        "node_list_path": "1205753.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrobacterVulgarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrobacter vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrobacterVulgarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29421.clusters.proteins.v11.5.txt",
		        "sequence_path": "29421.protein.sequences.v11.5.fa",
		        "enrichment_path": "29421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29421.protein.info.v11.5.txt",
		        "node_list_path": "29421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhlebiopsisGigantea110611Cr56(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phlebiopsis gigantea 11061_1 CR5-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhlebiopsisGigantea110611Cr56", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "745531.protein.sequences.v11.5.fa",
		        "enrichment_path": "745531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745531.protein.info.v11.5.txt",
		        "node_list_path": "745531.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumGillisiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium gillisiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumGillisiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "150146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "150146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "150146.clusters.proteins.v11.5.txt",
		        "sequence_path": "150146.protein.sequences.v11.5.fa",
		        "enrichment_path": "150146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150146.protein.info.v11.5.txt",
		        "node_list_path": "150146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "150146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioCoralliilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio coralliilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCoralliilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675814.clusters.proteins.v11.5.txt",
		        "sequence_path": "675814.protein.sequences.v11.5.fa",
		        "enrichment_path": "675814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675814.protein.info.v11.5.txt",
		        "node_list_path": "675814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSinesaloumensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sinesaloumensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSinesaloumensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926280.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926280.protein.info.v11.5.txt",
		        "node_list_path": "1926280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHtcc2148(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHtcc2148", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "247634.protein.sequences.v11.5.fa",
		        "enrichment_path": "247634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247634.protein.info.v11.5.txt",
		        "node_list_path": "247634.protein.complete.v11.5.txt"
		    }
		]
    )()

def SnodgrassellaAlviScgcAb598O02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Snodgrassella alvi SCGC AB-598-O02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SnodgrassellaAlviScgcAb598O02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1443103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1443103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1443103.clusters.proteins.v11.5.txt",
		        "sequence_path": "1443103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443103.protein.info.v11.5.txt",
		        "node_list_path": "1443103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1443103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumPrunaredenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium prunaredense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumPrunaredenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1631249.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1631249.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1631249.clusters.proteins.v11.5.txt",
		        "sequence_path": "1631249.protein.sequences.v11.5.fa",
		        "enrichment_path": "1631249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1631249.protein.info.v11.5.txt",
		        "node_list_path": "1631249.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1631249.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumQingshengiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium qingshengii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumQingshengiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1165689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1165689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1165689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1165689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1165689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1165689.protein.info.v11.5.txt",
		        "node_list_path": "1165689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1165689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobaculumSchaalii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum schaalii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobaculumSchaalii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883067.protein.sequences.v11.5.fa",
		        "enrichment_path": "883067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883067.protein.info.v11.5.txt",
		        "node_list_path": "883067.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucobacterChromiiresistensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter chromiiresistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterChromiiresistensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1079994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1079994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1079994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1079994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1079994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1079994.protein.info.v11.5.txt",
		        "node_list_path": "1079994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1079994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaLeachii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma leachii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaLeachii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "880447.protein.sequences.v11.5.fa",
		        "enrichment_path": "880447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880447.protein.info.v11.5.txt",
		        "node_list_path": "880447.protein.complete.v11.5.txt"
		    }
		]
    )()

def WickerhamomycesAnomalusNrrlY3668(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamomyces anomalus NRRL Y-366-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WickerhamomycesAnomalusNrrlY3668", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "683960.protein.sequences.v11.5.fa",
		        "enrichment_path": "683960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683960.protein.info.v11.5.txt",
		        "node_list_path": "683960.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyadobacterSpLeaf189(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter sp. Leaf189 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterSpLeaf189", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736295.protein.info.v11.5.txt",
		        "node_list_path": "1736295.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioSpYe44(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. YE44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioSpYe44", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520802.protein.info.v11.5.txt",
		        "node_list_path": "1520802.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpOk494(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. OK494 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpOk494", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500306.protein.info.v11.5.txt",
		        "node_list_path": "1500306.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSpFjat14222Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. FJAT-14222 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSpFjat14222Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1932366.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1932366.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1932366.clusters.proteins.v11.5.txt",
		        "sequence_path": "1932366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1932366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1932366.protein.info.v11.5.txt",
		        "node_list_path": "1932366.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1932366.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BelliellaPelovolcaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Belliella pelovolcani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BelliellaPelovolcaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "529505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "529505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "529505.clusters.proteins.v11.5.txt",
		        "sequence_path": "529505.protein.sequences.v11.5.fa",
		        "enrichment_path": "529505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529505.protein.info.v11.5.txt",
		        "node_list_path": "529505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "529505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DuodenibacillusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Duodenibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuodenibacillusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852381.protein.info.v11.5.txt",
		        "node_list_path": "1852381.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtopobiumRimae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium rimae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumRimae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553184.protein.sequences.v11.5.fa",
		        "enrichment_path": "553184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553184.protein.info.v11.5.txt",
		        "node_list_path": "553184.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpYr577Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. YR577 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpYr577Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884373.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884373.protein.info.v11.5.txt",
		        "node_list_path": "1884373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacaedibacterSymbiosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracaedibacter symbiosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacaedibacterSymbiosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "244582.clusters.info.v11.5.txt",
		        "cluster_tree_path": "244582.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "244582.clusters.proteins.v11.5.txt",
		        "sequence_path": "244582.protein.sequences.v11.5.fa",
		        "enrichment_path": "244582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244582.protein.info.v11.5.txt",
		        "node_list_path": "244582.cluster.nodes.v11.5.txt",
		        "edge_list_path": "244582.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg2304411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_44_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805317.protein.info.v11.5.txt",
		        "node_list_path": "1805317.protein.complete.v11.5.txt"
		    }
		]
    )()

def ByssochlamysSpectabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Byssochlamys spectabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ByssochlamysSpectabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264951.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264951.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264951.clusters.proteins.v11.5.txt",
		        "sequence_path": "264951.protein.sequences.v11.5.fa",
		        "enrichment_path": "264951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264951.protein.info.v11.5.txt",
		        "node_list_path": "264951.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264951.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobiumLimicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium limicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumLimicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290315.clusters.proteins.v11.5.txt",
		        "sequence_path": "290315.protein.sequences.v11.5.fa",
		        "enrichment_path": "290315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290315.protein.info.v11.5.txt",
		        "node_list_path": "290315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifcsphigho202Full4916Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_02_FULL_49_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho202Full4916Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801918.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801918.protein.info.v11.5.txt",
		        "node_list_path": "1801918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsplowo202Full5117(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_02_FULL_51_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo202Full5117", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802284.protein.info.v11.5.txt",
		        "node_list_path": "1802284.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrococcusLuteusStrModasaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micrococcus luteus str. modasa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcusLuteusStrModasaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232675.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232675.protein.info.v11.5.txt",
		        "node_list_path": "1232675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWirthbacteriaBacteriumCg2305411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wirthbacteria bacterium CG2_30_54_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWirthbacteriaBacteriumCg2305411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817892.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817892.protein.info.v11.5.txt",
		        "node_list_path": "1817892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColwelliaPolarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia polaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaPolarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326537.clusters.proteins.v11.5.txt",
		        "sequence_path": "326537.protein.sequences.v11.5.fa",
		        "enrichment_path": "326537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326537.protein.info.v11.5.txt",
		        "node_list_path": "326537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZymoseptoriaBrevis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zymoseptoria brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymoseptoriaBrevis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1047168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1047168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1047168.protein.info.v11.5.txt",
		        "node_list_path": "1047168.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaVestfoldensisSka53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella vestfoldensis SKA53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaVestfoldensisSka53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314232.protein.sequences.v11.5.fa",
		        "enrichment_path": "314232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314232.protein.info.v11.5.txt",
		        "node_list_path": "314232.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStoquefichusSpKle1796(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Stoquefichus sp. KLE1796 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStoquefichusSpKle1796", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1574263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1574263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1574263.protein.info.v11.5.txt",
		        "node_list_path": "1574263.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermopetrobacterSpTc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermopetrobacter sp. TC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermopetrobacterSpTc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1495045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495045.protein.info.v11.5.txt",
		        "node_list_path": "1495045.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorBesciiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor bescii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorBesciiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521460.clusters.proteins.v11.5.txt",
		        "sequence_path": "521460.protein.sequences.v11.5.fa",
		        "enrichment_path": "521460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521460.protein.info.v11.5.txt",
		        "node_list_path": "521460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusFaecalis13sdw01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecalis 13SDW01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusFaecalis13sdw01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1260356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1260356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1260356.clusters.proteins.v11.5.txt",
		        "sequence_path": "1260356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1260356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1260356.protein.info.v11.5.txt",
		        "node_list_path": "1260356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1260356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenitaleaLutea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arenitalea lutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenitaleaLutea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1178825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1178825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1178825.protein.info.v11.5.txt",
		        "node_list_path": "1178825.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaLitoraleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma litorale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaLitoraleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216942.clusters.proteins.v11.5.txt",
		        "sequence_path": "216942.protein.sequences.v11.5.fa",
		        "enrichment_path": "216942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216942.protein.info.v11.5.txt",
		        "node_list_path": "216942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DefluviitogaTunisiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Defluviitoga tunisiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DefluviitogaTunisiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1006576.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1006576.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1006576.clusters.proteins.v11.5.txt",
		        "sequence_path": "1006576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1006576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1006576.protein.info.v11.5.txt",
		        "node_list_path": "1006576.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1006576.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpAp50Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. AP50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpAp50Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884369.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884369.protein.info.v11.5.txt",
		        "node_list_path": "1884369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SutterellaWadsworthensis3145b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis 3145B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SutterellaWadsworthensis3145b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742821.protein.sequences.v11.5.fa",
		        "enrichment_path": "742821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742821.protein.info.v11.5.txt",
		        "node_list_path": "742821.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioHepatariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio hepatarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioHepatariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "171383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "171383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "171383.clusters.proteins.v11.5.txt",
		        "sequence_path": "171383.protein.sequences.v11.5.fa",
		        "enrichment_path": "171383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "171383.protein.info.v11.5.txt",
		        "node_list_path": "171383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "171383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GallibacteriumAnatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallibacterium anatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallibacteriumAnatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005058.protein.info.v11.5.txt",
		        "node_list_path": "1005058.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifoxyc2Full4228(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYC2_FULL_42_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyc2Full4228", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798704.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798704.protein.info.v11.5.txt",
		        "node_list_path": "1798704.protein.complete.v11.5.txt"
		    }
		]
    )()

def IsobaculumMelisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Isobaculum melis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IsobaculumMelisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "142588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "142588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "142588.clusters.proteins.v11.5.txt",
		        "sequence_path": "142588.protein.sequences.v11.5.fa",
		        "enrichment_path": "142588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "142588.protein.info.v11.5.txt",
		        "node_list_path": "142588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "142588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentinusTigrinusAlcf2ss16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentinus tigrinus ALCF2SS1-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentinusTigrinusAlcf2ss16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1328759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1328759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1328759.clusters.proteins.v11.5.txt",
		        "sequence_path": "1328759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1328759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1328759.protein.info.v11.5.txt",
		        "node_list_path": "1328759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1328759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TessaracoccusSpT2530Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus sp. T2.5-30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusSpT2530Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1909732.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1909732.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1909732.clusters.proteins.v11.5.txt",
		        "sequence_path": "1909732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1909732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1909732.protein.info.v11.5.txt",
		        "node_list_path": "1909732.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1909732.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchlyaHypogynaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achlya hypogyna Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchlyaHypogynaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1202772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1202772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1202772.clusters.proteins.v11.5.txt",
		        "sequence_path": "1202772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202772.protein.info.v11.5.txt",
		        "node_list_path": "1202772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1202772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusGeothermalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus geothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusGeothermalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "319795.clusters.info.v11.5.txt",
		        "cluster_tree_path": "319795.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "319795.clusters.proteins.v11.5.txt",
		        "sequence_path": "319795.protein.sequences.v11.5.fa",
		        "enrichment_path": "319795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319795.protein.info.v11.5.txt",
		        "node_list_path": "319795.cluster.nodes.v11.5.txt",
		        "edge_list_path": "319795.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfococcusSp4484241(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfococcus sp. 4484_241 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfococcusSp4484241", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1968522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1968522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1968522.protein.info.v11.5.txt",
		        "node_list_path": "1968522.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaribacterIrgensiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter irgensii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterIrgensiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313594.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313594.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313594.clusters.proteins.v11.5.txt",
		        "sequence_path": "313594.protein.sequences.v11.5.fa",
		        "enrichment_path": "313594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313594.protein.info.v11.5.txt",
		        "node_list_path": "313594.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313594.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumGw2011Gwf23917(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_39_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf23917", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619067.protein.info.v11.5.txt",
		        "node_list_path": "1619067.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinocyclocheilusAnshuiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinocyclocheilus anshuiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinocyclocheilusAnshuiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1608454.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608454.protein.info.v11.5.txt",
		        "node_list_path": "1608454.protein.complete.v11.5.txt"
		    }
		]
    )()

def CatalinimonasAlkaloidigena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catalinimonas alkaloidigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatalinimonasAlkaloidigena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1075417.protein.sequences.v11.5.fa",
		        "enrichment_path": "1075417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1075417.protein.info.v11.5.txt",
		        "node_list_path": "1075417.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerobacillusAlkalidiazotrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobacillus alkalidiazotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobacillusAlkalidiazotrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "472963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "472963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "472963.clusters.proteins.v11.5.txt",
		        "sequence_path": "472963.protein.sequences.v11.5.fa",
		        "enrichment_path": "472963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472963.protein.info.v11.5.txt",
		        "node_list_path": "472963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "472963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full5011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_50_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full5011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817828.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817828.protein.info.v11.5.txt",
		        "node_list_path": "1817828.protein.complete.v11.5.txt"
		    }
		]
    )()

def FukomysDamarensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fukomys damarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FukomysDamarensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "885580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "885580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "885580.clusters.proteins.v11.5.txt",
		        "sequence_path": "885580.protein.sequences.v11.5.fa",
		        "enrichment_path": "885580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "885580.protein.info.v11.5.txt",
		        "node_list_path": "885580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "885580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterMalorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter malorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterMalorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "178901.protein.sequences.v11.5.fa",
		        "enrichment_path": "178901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178901.protein.info.v11.5.txt",
		        "node_list_path": "178901.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusEqui(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus equi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusEqui", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "685727.protein.sequences.v11.5.fa",
		        "enrichment_path": "685727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "685727.protein.info.v11.5.txt",
		        "node_list_path": "685727.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpRoot217Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpRoot217Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736492.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736492.protein.info.v11.5.txt",
		        "node_list_path": "1736492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot1220(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1220 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot1220", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736432.protein.info.v11.5.txt",
		        "node_list_path": "1736432.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusGalactosidilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus galactosidilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGalactosidilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "217031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "217031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "217031.clusters.proteins.v11.5.txt",
		        "sequence_path": "217031.protein.sequences.v11.5.fa",
		        "enrichment_path": "217031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "217031.protein.info.v11.5.txt",
		        "node_list_path": "217031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "217031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumAcamd2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium acAMD-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumAcamd2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1504318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504318.protein.info.v11.5.txt",
		        "node_list_path": "1504318.protein.complete.v11.5.txt"
		    }
		]
    )()

def OchrobactrumRhizosphaeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OchrobactrumRhizosphaeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437448.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437448.protein.info.v11.5.txt",
		        "node_list_path": "1437448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusSpS5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. S5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusSpS5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1462527.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462527.protein.info.v11.5.txt",
		        "node_list_path": "1462527.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwa23816(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_38_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa23816", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797802.protein.info.v11.5.txt",
		        "node_list_path": "1797802.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterPullorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pullorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterPullorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "537972.protein.sequences.v11.5.fa",
		        "enrichment_path": "537972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537972.protein.info.v11.5.txt",
		        "node_list_path": "537972.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesRuminicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces ruminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesRuminicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "332524.clusters.info.v11.5.txt",
		        "cluster_tree_path": "332524.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "332524.clusters.proteins.v11.5.txt",
		        "sequence_path": "332524.protein.sequences.v11.5.fa",
		        "enrichment_path": "332524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332524.protein.info.v11.5.txt",
		        "node_list_path": "332524.cluster.nodes.v11.5.txt",
		        "edge_list_path": "332524.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFrigidimarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium frigidimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFrigidimarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "262320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "262320.clusters.proteins.v11.5.txt",
		        "sequence_path": "262320.protein.sequences.v11.5.fa",
		        "enrichment_path": "262320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262320.protein.info.v11.5.txt",
		        "node_list_path": "262320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "262320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxParadoxusS110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax paradoxus S110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxParadoxusS110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "543728.clusters.info.v11.5.txt",
		        "cluster_tree_path": "543728.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "543728.clusters.proteins.v11.5.txt",
		        "sequence_path": "543728.protein.sequences.v11.5.fa",
		        "enrichment_path": "543728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543728.protein.info.v11.5.txt",
		        "node_list_path": "543728.cluster.nodes.v11.5.txt",
		        "edge_list_path": "543728.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpYr485(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR485 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpYr485", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500294.protein.info.v11.5.txt",
		        "node_list_path": "1500294.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacteriumCg1024916Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_49_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024916Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805290.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805290.protein.info.v11.5.txt",
		        "node_list_path": "1805290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyorhinisGdl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis GDL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyorhinisGdl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1129369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1129369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1129369.protein.info.v11.5.txt",
		        "node_list_path": "1129369.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusKaustophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus kaustophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusKaustophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "235909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "235909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "235909.clusters.proteins.v11.5.txt",
		        "sequence_path": "235909.protein.sequences.v11.5.fa",
		        "enrichment_path": "235909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "235909.protein.info.v11.5.txt",
		        "node_list_path": "235909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "235909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSenegalensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSenegalensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033743.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033743.protein.info.v11.5.txt",
		        "node_list_path": "1033743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3810Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_02_FULL_38_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3810Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802074.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802074.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802074.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802074.protein.info.v11.5.txt",
		        "node_list_path": "1802074.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802074.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CucumisMeloCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cucumis melo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CucumisMeloCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3656.clusters.proteins.v11.5.txt",
		        "sequence_path": "3656.protein.sequences.v11.5.fa",
		        "enrichment_path": "3656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3656.protein.info.v11.5.txt",
		        "node_list_path": "3656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EndosymbiontOfRidgeiaPiscesaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Ridgeia piscesae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndosymbiontOfRidgeiaPiscesaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "54398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "54398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "54398.clusters.proteins.v11.5.txt",
		        "sequence_path": "54398.protein.sequences.v11.5.fa",
		        "enrichment_path": "54398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54398.protein.info.v11.5.txt",
		        "node_list_path": "54398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "54398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaLuteaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina lutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaLuteaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "431489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "431489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "431489.clusters.proteins.v11.5.txt",
		        "sequence_path": "431489.protein.sequences.v11.5.fa",
		        "enrichment_path": "431489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431489.protein.info.v11.5.txt",
		        "node_list_path": "431489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "431489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumWce2004Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium WCE2004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumWce2004Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945890.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945890.protein.info.v11.5.txt",
		        "node_list_path": "1945890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoproteusUzoniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoproteus uzoniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoproteusUzoniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999630.protein.sequences.v11.5.fa",
		        "enrichment_path": "999630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999630.protein.info.v11.5.txt",
		        "node_list_path": "999630.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoactinomycesSpDsm45892(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. DSM 45892 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoactinomycesSpDsm45892", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882753.protein.info.v11.5.txt",
		        "node_list_path": "1882753.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusSpBica19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. BICA1-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusSpBica19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1531958.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1531958.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1531958.clusters.proteins.v11.5.txt",
		        "sequence_path": "1531958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1531958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1531958.protein.info.v11.5.txt",
		        "node_list_path": "1531958.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1531958.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSaerimneri30aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus saerimneri 30a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSaerimneri30aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227363.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227363.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227363.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227363.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227363.protein.info.v11.5.txt",
		        "node_list_path": "1227363.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227363.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusWelwitschiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus welwitschiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusWelwitschiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1341132.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341132.protein.info.v11.5.txt",
		        "node_list_path": "1341132.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNc2008(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NC2008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNc2008", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410627.protein.info.v11.5.txt",
		        "node_list_path": "1410627.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTenderiaElectrophaga(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tenderia electrophaga graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTenderiaElectrophaga", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1748243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1748243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1748243.protein.info.v11.5.txt",
		        "node_list_path": "1748243.protein.complete.v11.5.txt"
		    }
		]
    )()

def DiplosphaeraColitermitumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Diplosphaera colitermitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiplosphaeraColitermitumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "278957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "278957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "278957.clusters.proteins.v11.5.txt",
		        "sequence_path": "278957.protein.sequences.v11.5.fa",
		        "enrichment_path": "278957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278957.protein.info.v11.5.txt",
		        "node_list_path": "278957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "278957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KiloniellaSpongiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kiloniella spongiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KiloniellaSpongiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1489064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1489064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1489064.protein.info.v11.5.txt",
		        "node_list_path": "1489064.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusSalinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus salinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusSalinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "192814.protein.sequences.v11.5.fa",
		        "enrichment_path": "192814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192814.protein.info.v11.5.txt",
		        "node_list_path": "192814.protein.complete.v11.5.txt"
		    }
		]
    )()

def OdoribacterSplanchnicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Odoribacter splanchnicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OdoribacterSplanchnicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "709991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "709991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "709991.clusters.proteins.v11.5.txt",
		        "sequence_path": "709991.protein.sequences.v11.5.fa",
		        "enrichment_path": "709991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709991.protein.info.v11.5.txt",
		        "node_list_path": "709991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "709991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsplowo201Full3613(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_36_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3613", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798614.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798614.protein.info.v11.5.txt",
		        "node_list_path": "1798614.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpRoot487d2yCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root487D2Y Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpRoot487d2yCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736547.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736547.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736547.protein.info.v11.5.txt",
		        "node_list_path": "1736547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaOulorumF0390(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oulorum F0390 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOulorumF0390", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "702438.protein.sequences.v11.5.fa",
		        "enrichment_path": "702438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702438.protein.info.v11.5.txt",
		        "node_list_path": "702438.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterSpEp1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. EP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSpEp1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1665555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1665555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1665555.clusters.proteins.v11.5.txt",
		        "sequence_path": "1665555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1665555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1665555.protein.info.v11.5.txt",
		        "node_list_path": "1665555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1665555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaIvanoviiLondoniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria ivanovii londoniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaIvanoviiLondoniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "202752.protein.sequences.v11.5.fa",
		        "enrichment_path": "202752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202752.protein.info.v11.5.txt",
		        "node_list_path": "202752.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumCg2304152Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium CG2_30_41_52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumCg2304152Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805375.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805375.protein.info.v11.5.txt",
		        "node_list_path": "1805375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassospiraSpMccc1a01428(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A01428 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraSpMccc1a01428", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1470575.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470575.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470575.protein.info.v11.5.txt",
		        "node_list_path": "1470575.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensHk44Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens HK44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensHk44Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1042209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1042209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1042209.clusters.proteins.v11.5.txt",
		        "sequence_path": "1042209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042209.protein.info.v11.5.txt",
		        "node_list_path": "1042209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1042209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AegilopsTauschiiSubspStrangulataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aegilops tauschii subsp. strangulata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AegilopsTauschiiSubspStrangulataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "200361.clusters.info.v11.5.txt",
		        "cluster_tree_path": "200361.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "200361.clusters.proteins.v11.5.txt",
		        "sequence_path": "200361.protein.sequences.v11.5.fa",
		        "enrichment_path": "200361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200361.protein.info.v11.5.txt",
		        "node_list_path": "200361.cluster.nodes.v11.5.txt",
		        "edge_list_path": "200361.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermostaphylosporaChromogena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermostaphylospora chromogena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermostaphylosporaChromogena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35622.protein.sequences.v11.5.fa",
		        "enrichment_path": "35622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35622.protein.info.v11.5.txt",
		        "node_list_path": "35622.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoflavimicrobiumDichotomicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoflavimicrobium dichotomicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoflavimicrobiumDichotomicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46223.clusters.proteins.v11.5.txt",
		        "sequence_path": "46223.protein.sequences.v11.5.fa",
		        "enrichment_path": "46223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46223.protein.info.v11.5.txt",
		        "node_list_path": "46223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumChoanae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium choanae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumChoanae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736691.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736691.protein.info.v11.5.txt",
		        "node_list_path": "1736691.protein.complete.v11.5.txt"
		    }
		]
    )()

def RutstroemiaSpNjr2017aBbwCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rutstroemia sp. NJR-2017a BBW Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RutstroemiaSpNjr2017aBbwCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2070414.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2070414.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2070414.clusters.proteins.v11.5.txt",
		        "sequence_path": "2070414.protein.sequences.v11.5.fa",
		        "enrichment_path": "2070414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2070414.protein.info.v11.5.txt",
		        "node_list_path": "2070414.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2070414.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanolobusVulcani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus vulcani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolobusVulcani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "38026.protein.sequences.v11.5.fa",
		        "enrichment_path": "38026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38026.protein.info.v11.5.txt",
		        "node_list_path": "38026.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHlucca12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCA12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHlucca12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1666916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666916.protein.info.v11.5.txt",
		        "node_list_path": "1666916.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumSpRifcsphigho201Full6931(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. RIFCSPHIGHO2_01_FULL_69_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumSpRifcsphigho201Full6931", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801944.protein.info.v11.5.txt",
		        "node_list_path": "1801944.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrotetrasporaGlaucaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microtetraspora glauca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrotetrasporaGlaucaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1996.clusters.proteins.v11.5.txt",
		        "sequence_path": "1996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1996.protein.info.v11.5.txt",
		        "node_list_path": "1996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BasileaPsittacipulmonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Basilea psittacipulmonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BasileaPsittacipulmonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1072685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1072685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1072685.protein.info.v11.5.txt",
		        "node_list_path": "1072685.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisSinuspersici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis sinuspersici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisSinuspersici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "501010.protein.sequences.v11.5.fa",
		        "enrichment_path": "501010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "501010.protein.info.v11.5.txt",
		        "node_list_path": "501010.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4332Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_FULL_43_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4332Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798332.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798332.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798332.protein.info.v11.5.txt",
		        "node_list_path": "1798332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TanticharoeniaSakaeratensisNbrc103193(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tanticharoenia sakaeratensis NBRC 103193 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TanticharoeniaSakaeratensisNbrc103193", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231623.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231623.protein.info.v11.5.txt",
		        "node_list_path": "1231623.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumV9d3004Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium V9D3004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumV9d3004Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410632.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410632.protein.info.v11.5.txt",
		        "node_list_path": "1410632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesRoseochromogenusSubspOscitansDs12976Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces roseochromogenus subsp. oscitans DS 12.976 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRoseochromogenusSubspOscitansDs12976Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1352936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1352936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1352936.clusters.proteins.v11.5.txt",
		        "sequence_path": "1352936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1352936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1352936.protein.info.v11.5.txt",
		        "node_list_path": "1352936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1352936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LepisosteusOculatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lepisosteus oculatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LepisosteusOculatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7918.protein.sequences.v11.5.fa",
		        "enrichment_path": "7918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7918.protein.info.v11.5.txt",
		        "node_list_path": "7918.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSw1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSw1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1920889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920889.protein.info.v11.5.txt",
		        "node_list_path": "1920889.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvencibacteriumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Provencibacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvencibacteriumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841868.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841868.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841868.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841868.protein.info.v11.5.txt",
		        "node_list_path": "1841868.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841868.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumXerosis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium xerosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumXerosis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1725.protein.info.v11.5.txt",
		        "node_list_path": "1725.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptosphaeriaMaculansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptosphaeria maculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptosphaeriaMaculansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5022.clusters.proteins.v11.5.txt",
		        "sequence_path": "5022.protein.sequences.v11.5.fa",
		        "enrichment_path": "5022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5022.protein.info.v11.5.txt",
		        "node_list_path": "5022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DraconibacteriumOrientaleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Draconibacterium orientale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DraconibacteriumOrientaleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1168034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1168034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1168034.clusters.proteins.v11.5.txt",
		        "sequence_path": "1168034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168034.protein.info.v11.5.txt",
		        "node_list_path": "1168034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1168034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfolobusAcidocaldariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusAcidocaldariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "330779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "330779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "330779.clusters.proteins.v11.5.txt",
		        "sequence_path": "330779.protein.sequences.v11.5.fa",
		        "enrichment_path": "330779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "330779.protein.info.v11.5.txt",
		        "node_list_path": "330779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "330779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiO157h7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli O157H7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiO157h7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "155864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "155864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "155864.clusters.proteins.v11.5.txt",
		        "sequence_path": "155864.protein.sequences.v11.5.fa",
		        "enrichment_path": "155864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "155864.protein.info.v11.5.txt",
		        "node_list_path": "155864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "155864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FomitopsisRosea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fomitopsis rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FomitopsisRosea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34475.protein.sequences.v11.5.fa",
		        "enrichment_path": "34475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34475.protein.info.v11.5.txt",
		        "node_list_path": "34475.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoxiellaSpRifcsphigho212Full4215Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coxiella sp. RIFCSPHIGHO2_12_FULL_42_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoxiellaSpRifcsphigho212Full4215Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797696.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797696.protein.info.v11.5.txt",
		        "node_list_path": "1797696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizopogonVinicolorAmOr11026Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizopogon vinicolor AM-OR11-026 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopogonVinicolorAmOr11026Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314800.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314800.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314800.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314800.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314800.protein.info.v11.5.txt",
		        "node_list_path": "1314800.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314800.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpJ39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. J39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpJ39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935848.protein.sequences.v11.5.fa",
		        "enrichment_path": "935848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935848.protein.info.v11.5.txt",
		        "node_list_path": "935848.protein.complete.v11.5.txt"
		    }
		]
    )()

def MastacembelusArmatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mastacembelus armatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MastacembelusArmatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "205130.protein.sequences.v11.5.fa",
		        "enrichment_path": "205130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "205130.protein.info.v11.5.txt",
		        "node_list_path": "205130.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasChangbaiensisNbrc104936(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas changbaiensis NBRC 104936 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasChangbaiensisNbrc104936", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219043.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219043.protein.info.v11.5.txt",
		        "node_list_path": "1219043.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumHwasookii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium hwasookii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumHwasookii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216362.protein.info.v11.5.txt",
		        "node_list_path": "1216362.protein.complete.v11.5.txt"
		    }
		]
    )()

def EctothiorhodosinusMongolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ectothiorhodosinus mongolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctothiorhodosinusMongolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "233100.clusters.info.v11.5.txt",
		        "cluster_tree_path": "233100.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "233100.clusters.proteins.v11.5.txt",
		        "sequence_path": "233100.protein.sequences.v11.5.fa",
		        "enrichment_path": "233100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "233100.protein.info.v11.5.txt",
		        "node_list_path": "233100.cluster.nodes.v11.5.txt",
		        "edge_list_path": "233100.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesIlei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides ilei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesIlei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907658.protein.info.v11.5.txt",
		        "node_list_path": "1907658.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumGw2011Gwf24219Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWF2_42_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwf24219Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618659.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618659.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618659.protein.info.v11.5.txt",
		        "node_list_path": "1618659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaminibacterMediatlanticusTb2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caminibacter mediatlanticus TB-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaminibacterMediatlanticusTb2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391592.protein.sequences.v11.5.fa",
		        "enrichment_path": "391592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391592.protein.info.v11.5.txt",
		        "node_list_path": "391592.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichurisMurisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichuris muris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichurisMurisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "70415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "70415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "70415.clusters.proteins.v11.5.txt",
		        "sequence_path": "70415.protein.sequences.v11.5.fa",
		        "enrichment_path": "70415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "70415.protein.info.v11.5.txt",
		        "node_list_path": "70415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "70415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrobacterAmalonaticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter amalonaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterAmalonaticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35703.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35703.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35703.clusters.proteins.v11.5.txt",
		        "sequence_path": "35703.protein.sequences.v11.5.fa",
		        "enrichment_path": "35703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35703.protein.info.v11.5.txt",
		        "node_list_path": "35703.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35703.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfurellaAcetivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurella acetivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurellaAcetivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "694431.clusters.info.v11.5.txt",
		        "cluster_tree_path": "694431.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "694431.clusters.proteins.v11.5.txt",
		        "sequence_path": "694431.protein.sequences.v11.5.fa",
		        "enrichment_path": "694431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694431.protein.info.v11.5.txt",
		        "node_list_path": "694431.cluster.nodes.v11.5.txt",
		        "edge_list_path": "694431.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SecondaryEndosymbiontOfCtenarytainaEucalypti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Ctenarytaina eucalypti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SecondaryEndosymbiontOfCtenarytainaEucalypti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1199245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1199245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1199245.protein.info.v11.5.txt",
		        "node_list_path": "1199245.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwc14720Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWC1_47_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwc14720Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618529.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618529.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618529.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618529.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618529.protein.info.v11.5.txt",
		        "node_list_path": "1618529.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618529.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumMagnetotacticumMs1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum magnetotacticum MS-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumMagnetotacticumMs1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272627.clusters.proteins.v11.5.txt",
		        "sequence_path": "272627.protein.sequences.v11.5.fa",
		        "enrichment_path": "272627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272627.protein.info.v11.5.txt",
		        "node_list_path": "272627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumLongumNcc2705Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium longum NCC2705 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumLongumNcc2705Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "206672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "206672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "206672.clusters.proteins.v11.5.txt",
		        "sequence_path": "206672.protein.sequences.v11.5.fa",
		        "enrichment_path": "206672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "206672.protein.info.v11.5.txt",
		        "node_list_path": "206672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "206672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinoalloteichusSpGba12924Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoalloteichus sp. GBA129-24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoalloteichusSpGba12924Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1612551.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1612551.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1612551.clusters.proteins.v11.5.txt",
		        "sequence_path": "1612551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1612551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1612551.protein.info.v11.5.txt",
		        "node_list_path": "1612551.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1612551.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "108003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "108003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "108003.clusters.proteins.v11.5.txt",
		        "sequence_path": "108003.protein.sequences.v11.5.fa",
		        "enrichment_path": "108003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "108003.protein.info.v11.5.txt",
		        "node_list_path": "108003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "108003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumRbg135114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_13_51_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumRbg135114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802193.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802193.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802193.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802193.protein.info.v11.5.txt",
		        "node_list_path": "1802193.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802193.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifcsplowo212Full5515(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_12_FULL_55_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo212Full5515", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801931.protein.info.v11.5.txt",
		        "node_list_path": "1801931.protein.complete.v11.5.txt"
		    }
		]
    )()

def TatumellaSpUcdDSuzukiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tatumella sp. UCD-D_suzukii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TatumellaSpUcdDSuzukiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408192.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408192.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408192.protein.info.v11.5.txt",
		        "node_list_path": "1408192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesVarsoviensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces varsoviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesVarsoviensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67373.protein.sequences.v11.5.fa",
		        "enrichment_path": "67373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67373.protein.info.v11.5.txt",
		        "node_list_path": "67373.protein.complete.v11.5.txt"
		    }
		]
    )()

def EntamoebaDisparCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Entamoeba dispar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EntamoebaDisparCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46681.clusters.proteins.v11.5.txt",
		        "sequence_path": "46681.protein.sequences.v11.5.fa",
		        "enrichment_path": "46681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46681.protein.info.v11.5.txt",
		        "node_list_path": "46681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSp5139bfaaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. 5139BFAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSp5139bfaaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "457412.clusters.info.v11.5.txt",
		        "cluster_tree_path": "457412.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "457412.clusters.proteins.v11.5.txt",
		        "sequence_path": "457412.protein.sequences.v11.5.fa",
		        "enrichment_path": "457412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457412.protein.info.v11.5.txt",
		        "node_list_path": "457412.cluster.nodes.v11.5.txt",
		        "edge_list_path": "457412.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanococcusKocurii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planococcus kocurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusKocurii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1374.protein.info.v11.5.txt",
		        "node_list_path": "1374.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumMesophilicumSr166Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium mesophilicum SR1.6/6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumMesophilicumSr166Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "908290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "908290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "908290.clusters.proteins.v11.5.txt",
		        "sequence_path": "908290.protein.sequences.v11.5.fa",
		        "enrichment_path": "908290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908290.protein.info.v11.5.txt",
		        "node_list_path": "908290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "908290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat14578(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-14578 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat14578", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208600.protein.info.v11.5.txt",
		        "node_list_path": "1208600.protein.complete.v11.5.txt"
		    }
		]
    )()

def CnuellaTakakiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cnuella takakiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CnuellaTakakiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1302690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1302690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1302690.clusters.proteins.v11.5.txt",
		        "sequence_path": "1302690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302690.protein.info.v11.5.txt",
		        "node_list_path": "1302690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1302690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillaceaeBacteriumG5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillaceae bacterium G5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillaceaeBacteriumG5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280390.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280390.protein.info.v11.5.txt",
		        "node_list_path": "1280390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LabrenziaAlbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Labrenzia alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrenziaAlbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "311410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "311410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "311410.clusters.proteins.v11.5.txt",
		        "sequence_path": "311410.protein.sequences.v11.5.fa",
		        "enrichment_path": "311410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311410.protein.info.v11.5.txt",
		        "node_list_path": "311410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "311410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporichthyaPolymorpha(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporichthya polymorpha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporichthyaPolymorpha", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1048339.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048339.protein.info.v11.5.txt",
		        "node_list_path": "1048339.protein.complete.v11.5.txt"
		    }
		]
    )()

def EumetaJaponicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eumeta japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EumetaJaponicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "151549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "151549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "151549.clusters.proteins.v11.5.txt",
		        "sequence_path": "151549.protein.sequences.v11.5.fa",
		        "enrichment_path": "151549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "151549.protein.info.v11.5.txt",
		        "node_list_path": "151549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "151549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumRhodesiaeNbb3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rhodesiae NBB3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumRhodesiaeNbb3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "710685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "710685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "710685.clusters.proteins.v11.5.txt",
		        "sequence_path": "710685.protein.sequences.v11.5.fa",
		        "enrichment_path": "710685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710685.protein.info.v11.5.txt",
		        "node_list_path": "710685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "710685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852388.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852388.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852388.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852388.protein.info.v11.5.txt",
		        "node_list_path": "1852388.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852388.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095770.protein.info.v11.5.txt",
		        "node_list_path": "1095770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GambusiaAffinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gambusia affinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GambusiaAffinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33528.clusters.proteins.v11.5.txt",
		        "sequence_path": "33528.protein.sequences.v11.5.fa",
		        "enrichment_path": "33528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33528.protein.info.v11.5.txt",
		        "node_list_path": "33528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasRhizophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas rhizophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasRhizophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216778.protein.sequences.v11.5.fa",
		        "enrichment_path": "216778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216778.protein.info.v11.5.txt",
		        "node_list_path": "216778.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaFormicigenerans4653afaa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dorea formicigenerans 4653AFAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaFormicigenerans4653afaa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742765.protein.sequences.v11.5.fa",
		        "enrichment_path": "742765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742765.protein.info.v11.5.txt",
		        "node_list_path": "742765.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospinaSpLsNobCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospina sp. LS_NOB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospinaSpLsNobCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671875.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671875.protein.info.v11.5.txt",
		        "node_list_path": "1671875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCb03911(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB03911 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCb03911", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1804758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1804758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1804758.protein.info.v11.5.txt",
		        "node_list_path": "1804758.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "252474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "252474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "252474.clusters.proteins.v11.5.txt",
		        "sequence_path": "252474.protein.sequences.v11.5.fa",
		        "enrichment_path": "252474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "252474.protein.info.v11.5.txt",
		        "node_list_path": "252474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "252474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCellulosiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] cellulosi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCellulosiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29343.clusters.proteins.v11.5.txt",
		        "sequence_path": "29343.protein.sequences.v11.5.fa",
		        "enrichment_path": "29343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29343.protein.info.v11.5.txt",
		        "node_list_path": "29343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaHisticolaF0411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella histicola F0411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaHisticolaF0411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "857291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "857291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "857291.clusters.proteins.v11.5.txt",
		        "sequence_path": "857291.protein.sequences.v11.5.fa",
		        "enrichment_path": "857291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857291.protein.info.v11.5.txt",
		        "node_list_path": "857291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "857291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColwelliaMytiliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia mytili Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaMytiliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1888913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1888913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1888913.clusters.proteins.v11.5.txt",
		        "sequence_path": "1888913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1888913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1888913.protein.info.v11.5.txt",
		        "node_list_path": "1888913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1888913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusHeteromorphusCbs11755Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus heteromorphus CBS 117.55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusHeteromorphusCbs11755Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1448321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1448321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1448321.clusters.proteins.v11.5.txt",
		        "sequence_path": "1448321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448321.protein.info.v11.5.txt",
		        "node_list_path": "1448321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1448321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DuganellaSpCf517Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. CF517 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpCf517Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881038.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881038.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881038.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881038.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881038.protein.info.v11.5.txt",
		        "node_list_path": "1881038.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881038.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NiveispirillumIrakenseDsm11586(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Niveispirillum irakense DSM 11586 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiveispirillumIrakenseDsm11586", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121034.protein.info.v11.5.txt",
		        "node_list_path": "1121034.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaAustralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaAustralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094489.protein.info.v11.5.txt",
		        "node_list_path": "1094489.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaPealeanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella pealeana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaPealeanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398579.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398579.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398579.clusters.proteins.v11.5.txt",
		        "sequence_path": "398579.protein.sequences.v11.5.fa",
		        "enrichment_path": "398579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398579.protein.info.v11.5.txt",
		        "node_list_path": "398579.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398579.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RheinheimeraPacificaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraPacificaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "173990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "173990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "173990.clusters.proteins.v11.5.txt",
		        "sequence_path": "173990.protein.sequences.v11.5.fa",
		        "enrichment_path": "173990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "173990.protein.info.v11.5.txt",
		        "node_list_path": "173990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "173990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasSpIs79a3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Is79A3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasSpIs79a3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "261292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "261292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "261292.clusters.proteins.v11.5.txt",
		        "sequence_path": "261292.protein.sequences.v11.5.fa",
		        "enrichment_path": "261292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "261292.protein.info.v11.5.txt",
		        "node_list_path": "261292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "261292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumVentriosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium ventriosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumVentriosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411463.protein.sequences.v11.5.fa",
		        "enrichment_path": "411463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411463.protein.info.v11.5.txt",
		        "node_list_path": "411463.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermosulfidibacterTakaiiAbi70s6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosulfidibacter takaii ABI70S6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosulfidibacterTakaiiAbi70s6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298851.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298851.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298851.protein.info.v11.5.txt",
		        "node_list_path": "1298851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalogranumGelatinilyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halogranum gelatinilyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalogranumGelatinilyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "660521.protein.sequences.v11.5.fa",
		        "enrichment_path": "660521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660521.protein.info.v11.5.txt",
		        "node_list_path": "660521.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcaricomesPhytoseiuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acaricomes phytoseiuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcaricomesPhytoseiuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120917.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120917.protein.info.v11.5.txt",
		        "node_list_path": "1120917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaVermiculataNbrc100427Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia vermiculata NBRC 100427 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaVermiculataNbrc100427Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210096.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210096.protein.info.v11.5.txt",
		        "node_list_path": "1210096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinilabiliaSalmonicolor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinilabilia salmonicolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinilabiliaSalmonicolor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1168289.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168289.protein.info.v11.5.txt",
		        "node_list_path": "1168289.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusMurrayiDsm11303Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus murrayi DSM 11303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusMurrayiDsm11303Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121383.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121383.protein.info.v11.5.txt",
		        "node_list_path": "1121383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfuricurvumSpMlsbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. MLSB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricurvumSpMlsbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1537917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1537917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1537917.clusters.proteins.v11.5.txt",
		        "sequence_path": "1537917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1537917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1537917.protein.info.v11.5.txt",
		        "node_list_path": "1537917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1537917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErysipelatoclostridiumRamosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erysipelatoclostridium ramosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelatoclostridiumRamosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445974.protein.sequences.v11.5.fa",
		        "enrichment_path": "445974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445974.protein.info.v11.5.txt",
		        "node_list_path": "445974.protein.complete.v11.5.txt"
		    }
		]
    )()

def BatrachochytriumDendrobatidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BatrachochytriumDendrobatidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "109871.clusters.info.v11.5.txt",
		        "cluster_tree_path": "109871.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "109871.clusters.proteins.v11.5.txt",
		        "sequence_path": "109871.protein.sequences.v11.5.fa",
		        "enrichment_path": "109871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109871.protein.info.v11.5.txt",
		        "node_list_path": "109871.cluster.nodes.v11.5.txt",
		        "edge_list_path": "109871.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesCoprosuis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides coprosuis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCoprosuis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679937.protein.sequences.v11.5.fa",
		        "enrichment_path": "679937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679937.protein.info.v11.5.txt",
		        "node_list_path": "679937.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasCuatrocienegasensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas cuatrocienegasensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCuatrocienegasensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "543360.protein.sequences.v11.5.fa",
		        "enrichment_path": "543360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543360.protein.info.v11.5.txt",
		        "node_list_path": "543360.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSpechtbacteriaBacteriumRifcsplowo201Full4610(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_01_FULL_46_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo201Full4610", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802163.protein.info.v11.5.txt",
		        "node_list_path": "1802163.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumDamselaeSubspDamselae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium damselae subsp. damselae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumDamselaeSubspDamselae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "85581.protein.sequences.v11.5.fa",
		        "enrichment_path": "85581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85581.protein.info.v11.5.txt",
		        "node_list_path": "85581.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmillariaOstoyaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Armillaria ostoyae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmillariaOstoyaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47428.clusters.proteins.v11.5.txt",
		        "sequence_path": "47428.protein.sequences.v11.5.fa",
		        "enrichment_path": "47428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47428.protein.info.v11.5.txt",
		        "node_list_path": "47428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumBeibuense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium beibuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumBeibuense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1406840.protein.sequences.v11.5.fa",
		        "enrichment_path": "1406840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1406840.protein.info.v11.5.txt",
		        "node_list_path": "1406840.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaBritovi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichinella britovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaBritovi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45882.protein.sequences.v11.5.fa",
		        "enrichment_path": "45882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45882.protein.info.v11.5.txt",
		        "node_list_path": "45882.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusAidingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus aidingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusAidingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "240303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "240303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "240303.clusters.proteins.v11.5.txt",
		        "sequence_path": "240303.protein.sequences.v11.5.fa",
		        "enrichment_path": "240303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240303.protein.info.v11.5.txt",
		        "node_list_path": "240303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "240303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumHalorespiransDsm13726(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum halorespirans DSM 13726 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumHalorespiransDsm13726", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193502.protein.info.v11.5.txt",
		        "node_list_path": "1193502.protein.complete.v11.5.txt"
		    }
		]
    )()

def BursaphelenchusXylophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bursaphelenchus xylophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BursaphelenchusXylophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6326.protein.sequences.v11.5.fa",
		        "enrichment_path": "6326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6326.protein.info.v11.5.txt",
		        "node_list_path": "6326.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusJorgensenbacteriaBacteriumRifcsplowo212Full4211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPLOWO2_12_FULL_42_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsplowo212Full4211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798473.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798473.protein.info.v11.5.txt",
		        "node_list_path": "1798473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumImcc3088Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium IMCC3088 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumImcc3088Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "876044.clusters.info.v11.0.txt",
		        "cluster_tree_path": "876044.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "876044.clusters.proteins.v11.0.txt",
		        "sequence_path": "876044.protein.sequences.v11.0.fa",
		        "enrichment_path": "876044.protein.enrichment.terms.v11.0.txt",
		        "info_path": "876044.protein.info.v11.0.txt",
		        "node_list_path": "876044.cluster.nodes.v11.0.txt",
		        "edge_list_path": "876044.protein.cluster.v11.0.txt"
		    }
		]
    )()

def CandidatusZinderiaInsecticolaCari(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zinderia insecticola CARI graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZinderiaInsecticolaCari", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "871271.protein.sequences.v11.5.fa",
		        "enrichment_path": "871271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871271.protein.info.v11.5.txt",
		        "node_list_path": "871271.protein.complete.v11.5.txt"
		    }
		]
    )()

def HolosporaObtusaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Holospora obtusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HolosporaObtusaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1399147.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1399147.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1399147.clusters.proteins.v11.5.txt",
		        "sequence_path": "1399147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399147.protein.info.v11.5.txt",
		        "node_list_path": "1399147.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1399147.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EmmonsiaCrescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Emmonsia crescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmmonsiaCrescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "73230.protein.sequences.v11.5.fa",
		        "enrichment_path": "73230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "73230.protein.info.v11.5.txt",
		        "node_list_path": "73230.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSp162mfsha11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 162MFSha11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSp162mfsha11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1151119.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151119.protein.info.v11.5.txt",
		        "node_list_path": "1151119.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesoflavibacterZeaxanthinifaciensS86Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanthinifaciens S86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoflavibacterZeaxanthinifaciensS86Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1004149.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1004149.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1004149.clusters.proteins.v11.5.txt",
		        "sequence_path": "1004149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004149.protein.info.v11.5.txt",
		        "node_list_path": "1004149.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1004149.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasKuykendallii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas kuykendallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasKuykendallii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1007099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007099.protein.info.v11.5.txt",
		        "node_list_path": "1007099.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalipigerMucosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salipiger mucosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalipigerMucosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123237.protein.info.v11.5.txt",
		        "node_list_path": "1123237.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedCandidatusPoseidonialesArchaeonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Candidatus Poseidoniales archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedCandidatusPoseidonialesArchaeonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "274854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "274854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "274854.clusters.proteins.v11.5.txt",
		        "sequence_path": "274854.protein.sequences.v11.5.fa",
		        "enrichment_path": "274854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "274854.protein.info.v11.5.txt",
		        "node_list_path": "274854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "274854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTerrybacteriaBacteriumRifcsplowo201Full4424Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPLOWO2_01_FULL_44_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsplowo201Full4424Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802367.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802367.protein.info.v11.5.txt",
		        "node_list_path": "1802367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpJs211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. JS21-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpJs211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855283.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855283.protein.info.v11.5.txt",
		        "node_list_path": "1855283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeodactylumTricornutumCcap10551Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeodactylum tricornutum CCAP 1055/1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeodactylumTricornutumCcap10551Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "556484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "556484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "556484.clusters.proteins.v11.5.txt",
		        "sequence_path": "556484.protein.sequences.v11.5.fa",
		        "enrichment_path": "556484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556484.protein.info.v11.5.txt",
		        "node_list_path": "556484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "556484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MelioribacterRoseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Melioribacter roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MelioribacterRoseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1191523.protein.sequences.v11.5.fa",
		        "enrichment_path": "1191523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1191523.protein.info.v11.5.txt",
		        "node_list_path": "1191523.protein.complete.v11.5.txt"
		    }
		]
    )()

def PectobacteriumCarotovorumPc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum PC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumCarotovorumPc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "561230.protein.sequences.v11.5.fa",
		        "enrichment_path": "561230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561230.protein.info.v11.5.txt",
		        "node_list_path": "561230.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacterium9400853Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9400853 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacterium9400853Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "938278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "938278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "938278.clusters.proteins.v11.5.txt",
		        "sequence_path": "938278.protein.sequences.v11.5.fa",
		        "enrichment_path": "938278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938278.protein.info.v11.5.txt",
		        "node_list_path": "938278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "938278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAzotifigensDsm17556Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas azotifigens DSM 17556 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAzotifigensDsm17556Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1292027.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1292027.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1292027.clusters.proteins.v11.5.txt",
		        "sequence_path": "1292027.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292027.protein.info.v11.5.txt",
		        "node_list_path": "1292027.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1292027.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermothielavioidesTerrestrisNrrl8126Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermothielavioides terrestris NRRL 8126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermothielavioidesTerrestrisNrrl8126Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "578455.clusters.info.v11.5.txt",
		        "cluster_tree_path": "578455.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "578455.clusters.proteins.v11.5.txt",
		        "sequence_path": "578455.protein.sequences.v11.5.fa",
		        "enrichment_path": "578455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578455.protein.info.v11.5.txt",
		        "node_list_path": "578455.cluster.nodes.v11.5.txt",
		        "edge_list_path": "578455.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumGwd23219Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWD2_32_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumGwd23219Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797679.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797679.protein.info.v11.5.txt",
		        "node_list_path": "1797679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasHankookensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas hankookensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasHankookensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "563996.protein.sequences.v11.5.fa",
		        "enrichment_path": "563996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563996.protein.info.v11.5.txt",
		        "node_list_path": "563996.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpH1ai(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. H1ai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpH1ai", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408813.protein.info.v11.5.txt",
		        "node_list_path": "1408813.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpMp1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. MP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpMp1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1458357.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1458357.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1458357.clusters.proteins.v11.5.txt",
		        "sequence_path": "1458357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458357.protein.info.v11.5.txt",
		        "node_list_path": "1458357.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1458357.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpUnc438cl73tsus30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. UNC438CL73TsuS30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpUnc438cl73tsus30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1340434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1340434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1340434.clusters.proteins.v11.5.txt",
		        "sequence_path": "1340434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1340434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1340434.protein.info.v11.5.txt",
		        "node_list_path": "1340434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1340434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PectobacteriumCarotovorumPc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum PC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumCarotovorumPc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "561230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "561230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "561230.clusters.proteins.v11.5.txt",
		        "sequence_path": "561230.protein.sequences.v11.5.fa",
		        "enrichment_path": "561230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561230.protein.info.v11.5.txt",
		        "node_list_path": "561230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "561230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSpCag324(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. CAG:324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSpCag324", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262969.protein.info.v11.5.txt",
		        "node_list_path": "1262969.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMacacae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus macacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMacacae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "764298.protein.sequences.v11.5.fa",
		        "enrichment_path": "764298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "764298.protein.info.v11.5.txt",
		        "node_list_path": "764298.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSpS32Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. S3-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSpS32Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1747903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1747903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1747903.clusters.proteins.v11.5.txt",
		        "sequence_path": "1747903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1747903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1747903.protein.info.v11.5.txt",
		        "node_list_path": "1747903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1747903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DialisterPneumosintesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dialister pneumosintes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterPneumosintesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39950.clusters.proteins.v11.5.txt",
		        "sequence_path": "39950.protein.sequences.v11.5.fa",
		        "enrichment_path": "39950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39950.protein.info.v11.5.txt",
		        "node_list_path": "39950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimihaloglobusSulfuriphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limihaloglobus sulfuriphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimihaloglobusSulfuriphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1851148.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1851148.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1851148.clusters.proteins.v11.5.txt",
		        "sequence_path": "1851148.protein.sequences.v11.5.fa",
		        "enrichment_path": "1851148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1851148.protein.info.v11.5.txt",
		        "node_list_path": "1851148.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1851148.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CycloclasticusSpP1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. P1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CycloclasticusSpP1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "385025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "385025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "385025.clusters.proteins.v11.5.txt",
		        "sequence_path": "385025.protein.sequences.v11.5.fa",
		        "enrichment_path": "385025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "385025.protein.info.v11.5.txt",
		        "node_list_path": "385025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "385025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LarimichthysCrocea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Larimichthys crocea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LarimichthysCrocea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "215358.protein.sequences.v11.5.fa",
		        "enrichment_path": "215358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215358.protein.info.v11.5.txt",
		        "node_list_path": "215358.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidihalobacterProsperusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidihalobacter prosperus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidihalobacterProsperusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "160660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "160660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "160660.clusters.proteins.v11.5.txt",
		        "sequence_path": "160660.protein.sequences.v11.5.fa",
		        "enrichment_path": "160660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "160660.protein.info.v11.5.txt",
		        "node_list_path": "160660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "160660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliivibrioWodanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliivibrio wodanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliivibrioWodanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "80852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "80852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "80852.clusters.proteins.v11.5.txt",
		        "sequence_path": "80852.protein.sequences.v11.5.fa",
		        "enrichment_path": "80852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80852.protein.info.v11.5.txt",
		        "node_list_path": "80852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "80852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifoxya12Full3519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYA12_FULL_35_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxya12Full3519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801646.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801646.protein.info.v11.5.txt",
		        "node_list_path": "1801646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumGwa2478(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_47_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa2478", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801840.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801840.protein.info.v11.5.txt",
		        "node_list_path": "1801840.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSphaericusOt4b31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sphaericus OT4b31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSphaericusOt4b31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1285586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1285586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1285586.clusters.proteins.v11.5.txt",
		        "sequence_path": "1285586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1285586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1285586.protein.info.v11.5.txt",
		        "node_list_path": "1285586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1285586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumChiriqhucha(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium chiriqhucha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumChiriqhucha", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385984.protein.info.v11.5.txt",
		        "node_list_path": "1385984.protein.complete.v11.5.txt"
		    }
		]
    )()

def GranulicellaMallensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Granulicella mallensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicellaMallensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "682795.clusters.info.v11.5.txt",
		        "cluster_tree_path": "682795.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "682795.clusters.proteins.v11.5.txt",
		        "sequence_path": "682795.protein.sequences.v11.5.fa",
		        "enrichment_path": "682795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "682795.protein.info.v11.5.txt",
		        "node_list_path": "682795.cluster.nodes.v11.5.txt",
		        "edge_list_path": "682795.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomicrobiumZhouiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomicrobium zhouii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomicrobiumZhouiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "767519.clusters.info.v11.5.txt",
		        "cluster_tree_path": "767519.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "767519.clusters.proteins.v11.5.txt",
		        "sequence_path": "767519.protein.sequences.v11.5.fa",
		        "enrichment_path": "767519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767519.protein.info.v11.5.txt",
		        "node_list_path": "767519.cluster.nodes.v11.5.txt",
		        "edge_list_path": "767519.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSimulans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus simulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSimulans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1405498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1405498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1405498.protein.info.v11.5.txt",
		        "node_list_path": "1405498.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiocapsaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiocapsa marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiocapsaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "768671.protein.sequences.v11.5.fa",
		        "enrichment_path": "768671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768671.protein.info.v11.5.txt",
		        "node_list_path": "768671.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonasSpCy54118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. CY54118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSpCy54118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280944.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280944.protein.info.v11.5.txt",
		        "node_list_path": "1280944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VirgibacillusProomiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus proomii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusProomiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84407.clusters.proteins.v11.5.txt",
		        "sequence_path": "84407.protein.sequences.v11.5.fa",
		        "enrichment_path": "84407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84407.protein.info.v11.5.txt",
		        "node_list_path": "84407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpRoot60(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpRoot60", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736567.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736567.protein.info.v11.5.txt",
		        "node_list_path": "1736567.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusElongatusPcc6301(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus elongatus PCC6301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusElongatusPcc6301", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "269084.protein.sequences.v11.5.fa",
		        "enrichment_path": "269084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269084.protein.info.v11.5.txt",
		        "node_list_path": "269084.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumTetanomorphumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tetanomorphum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTetanomorphumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230342.protein.info.v11.5.txt",
		        "node_list_path": "1230342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterThereius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter thereius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterThereius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "544718.protein.sequences.v11.5.fa",
		        "enrichment_path": "544718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "544718.protein.info.v11.5.txt",
		        "node_list_path": "544718.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlaviramulusIchthyoenteriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flaviramulus ichthyoenteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlaviramulusIchthyoenteriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380600.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380600.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380600.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380600.protein.info.v11.5.txt",
		        "node_list_path": "1380600.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380600.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpRoot157(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root157 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpRoot157", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736477.protein.info.v11.5.txt",
		        "node_list_path": "1736477.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenericutesBacteriumGwf25713Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWF2_57_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenericutesBacteriumGwf25713Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802354.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802354.protein.info.v11.5.txt",
		        "node_list_path": "1802354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitis2F0392(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis 2 F0392 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitis2F0392", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "768726.protein.sequences.v11.5.fa",
		        "enrichment_path": "768726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768726.protein.info.v11.5.txt",
		        "node_list_path": "768726.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExophialaAquamarinaCbs119918Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exophiala aquamarina CBS 119918 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaAquamarinaCbs119918Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1182545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1182545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1182545.clusters.proteins.v11.5.txt",
		        "sequence_path": "1182545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182545.protein.info.v11.5.txt",
		        "node_list_path": "1182545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1182545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaGrahamiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella grahamii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaGrahamiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634504.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634504.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634504.clusters.proteins.v11.5.txt",
		        "sequence_path": "634504.protein.sequences.v11.5.fa",
		        "enrichment_path": "634504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634504.protein.info.v11.5.txt",
		        "node_list_path": "634504.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634504.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpKbs0721(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KBS0721 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpKbs0721", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1179672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179672.protein.info.v11.5.txt",
		        "node_list_path": "1179672.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrodermaOtae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthroderma otae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrodermaOtae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "63405.protein.sequences.v11.5.fa",
		        "enrichment_path": "63405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63405.protein.info.v11.5.txt",
		        "node_list_path": "63405.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumUc511d2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-1D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumUc511d2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1697780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1697780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1697780.protein.info.v11.5.txt",
		        "node_list_path": "1697780.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenobaculumSpY04aas1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenobaculum sp. Y04AAS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenobaculumSpY04aas1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "380749.protein.sequences.v11.5.fa",
		        "enrichment_path": "380749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380749.protein.info.v11.5.txt",
		        "node_list_path": "380749.protein.complete.v11.5.txt"
		    }
		]
    )()

def KnoelliaSpSoil729Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Knoellia sp. Soil729 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KnoelliaSpSoil729Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736394.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736394.protein.info.v11.5.txt",
		        "node_list_path": "1736394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicroterricolaViridarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microterricola viridarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicroterricolaViridarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "412690.protein.sequences.v11.5.fa",
		        "enrichment_path": "412690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "412690.protein.info.v11.5.txt",
		        "node_list_path": "412690.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaCremeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora cremea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaCremeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "709881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "709881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "709881.clusters.proteins.v11.5.txt",
		        "sequence_path": "709881.protein.sequences.v11.5.fa",
		        "enrichment_path": "709881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709881.protein.info.v11.5.txt",
		        "node_list_path": "709881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "709881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellamassiliaTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotellamassilia timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellamassiliaTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852370.protein.info.v11.5.txt",
		        "node_list_path": "1852370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IntrasporangiumOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Intrasporangium oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntrasporangiumOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1386089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1386089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1386089.protein.info.v11.5.txt",
		        "node_list_path": "1386089.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellalesBacteriumRifcsphigho212Full3511(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionellales bacterium RIFCSPHIGHO2_12_FULL_35_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellalesBacteriumRifcsphigho212Full3511", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798567.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798567.protein.info.v11.5.txt",
		        "node_list_path": "1798567.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236542.protein.info.v11.5.txt",
		        "node_list_path": "1236542.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpVlb120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. VLB120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpVlb120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69328.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69328.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69328.clusters.proteins.v11.5.txt",
		        "sequence_path": "69328.protein.sequences.v11.5.fa",
		        "enrichment_path": "69328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69328.protein.info.v11.5.txt",
		        "node_list_path": "69328.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69328.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSticklandii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sticklandii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSticklandii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1511.protein.sequences.v11.5.fa",
		        "enrichment_path": "1511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1511.protein.info.v11.5.txt",
		        "node_list_path": "1511.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanofollisLiminatansDsm4140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanofollis liminatans DSM 4140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanofollisLiminatansDsm4140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28892.clusters.proteins.v11.5.txt",
		        "sequence_path": "28892.protein.sequences.v11.5.fa",
		        "enrichment_path": "28892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28892.protein.info.v11.5.txt",
		        "node_list_path": "28892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedAcidilobusSpCis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Acidilobus sp. CIS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedAcidilobusSpCis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410574.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410574.protein.info.v11.5.txt",
		        "node_list_path": "1410574.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaStuartii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Providencia stuartii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaStuartii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471874.protein.sequences.v11.5.fa",
		        "enrichment_path": "471874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471874.protein.info.v11.5.txt",
		        "node_list_path": "471874.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioclavaSp13d2w2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. 13D2W2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaSp13d2w2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1317124.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317124.protein.info.v11.5.txt",
		        "node_list_path": "1317124.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslr70273Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70273 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslr70273Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1536772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1536772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1536772.clusters.proteins.v11.5.txt",
		        "sequence_path": "1536772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536772.protein.info.v11.5.txt",
		        "node_list_path": "1536772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1536772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpSk643(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. SK643 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpSk643", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095727.protein.info.v11.5.txt",
		        "node_list_path": "1095727.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusSpRl(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. RL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusSpRl", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1489678.protein.sequences.v11.5.fa",
		        "enrichment_path": "1489678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1489678.protein.info.v11.5.txt",
		        "node_list_path": "1489678.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumUreicelerivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium ureicelerivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumUreicelerivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "401472.protein.sequences.v11.5.fa",
		        "enrichment_path": "401472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "401472.protein.info.v11.5.txt",
		        "node_list_path": "401472.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpHg(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. HG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpHg", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1638643.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638643.protein.info.v11.5.txt",
		        "node_list_path": "1638643.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacterium13140cm46819(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium 13_1_40CM_4_68_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacterium13140cm46819", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805121.protein.info.v11.5.txt",
		        "node_list_path": "1805121.protein.complete.v11.5.txt"
		    }
		]
    )()

def EctocarpusSiliculosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ectocarpus siliculosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctocarpusSiliculosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2880.clusters.proteins.v11.5.txt",
		        "sequence_path": "2880.protein.sequences.v11.5.fa",
		        "enrichment_path": "2880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2880.protein.info.v11.5.txt",
		        "node_list_path": "2880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterBizzozeroniiCcug35545Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii CCUG 35545 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterBizzozeroniiCcug35545Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1002805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1002805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1002805.clusters.proteins.v11.5.txt",
		        "sequence_path": "1002805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002805.protein.info.v11.5.txt",
		        "node_list_path": "1002805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1002805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def Sar324ClusterBacteriumRedseaS27B3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return SAR324 cluster bacterium REDSEA-S27_B3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar324ClusterBacteriumRedseaS27B3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811637.protein.info.v11.5.txt",
		        "node_list_path": "1811637.protein.complete.v11.5.txt"
		    }
		]
    )()

def AestuariimicrobiumKwangyangense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aestuariimicrobium kwangyangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AestuariimicrobiumKwangyangense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120954.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120954.protein.info.v11.5.txt",
		        "node_list_path": "1120954.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumVe20221(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20221 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumVe20221", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232453.protein.info.v11.5.txt",
		        "node_list_path": "1232453.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudorhodoferaxSpLeaf265Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf265 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodoferaxSpLeaf265Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736315.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736315.protein.info.v11.5.txt",
		        "node_list_path": "1736315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag417Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:417 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag417Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262804.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262804.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262804.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262804.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262804.protein.info.v11.5.txt",
		        "node_list_path": "1262804.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262804.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MuscaDomestica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Musca domestica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuscaDomestica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7370.protein.sequences.v11.5.fa",
		        "enrichment_path": "7370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7370.protein.info.v11.5.txt",
		        "node_list_path": "7370.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureimonasSpAu4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpAu4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1638163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638163.protein.info.v11.5.txt",
		        "node_list_path": "1638163.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisSk579Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisSk579Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095737.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095737.protein.info.v11.5.txt",
		        "node_list_path": "1095737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChondrusCrispus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chondrus crispus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChondrusCrispus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2769.protein.sequences.v11.5.fa",
		        "enrichment_path": "2769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2769.protein.info.v11.5.txt",
		        "node_list_path": "2769.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSp20gpm1509m(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. 20GPM1509m graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSp20gpm1509m", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380367.protein.info.v11.5.txt",
		        "node_list_path": "1380367.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraMicroaerophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira microaerophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraMicroaerophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "406020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "406020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "406020.clusters.proteins.v11.5.txt",
		        "sequence_path": "406020.protein.sequences.v11.5.fa",
		        "enrichment_path": "406020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406020.protein.info.v11.5.txt",
		        "node_list_path": "406020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "406020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonadalesBacteriumRifcsplowo212599Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonadales bacterium RIFCSPLOWO2_12_59_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonadalesBacteriumRifcsplowo212599Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802009.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802009.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802009.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802009.protein.info.v11.5.txt",
		        "node_list_path": "1802009.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802009.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgromycesAureus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agromyces aureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesAureus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "453304.protein.sequences.v11.5.fa",
		        "enrichment_path": "453304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "453304.protein.info.v11.5.txt",
		        "node_list_path": "453304.protein.complete.v11.5.txt"
		    }
		]
    )()

def PetromyzonMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Petromyzon marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PetromyzonMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7757.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7757.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7757.clusters.proteins.v11.5.txt",
		        "sequence_path": "7757.protein.sequences.v11.5.fa",
		        "enrichment_path": "7757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7757.protein.info.v11.5.txt",
		        "node_list_path": "7757.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7757.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "405671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "405671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "405671.clusters.proteins.v11.5.txt",
		        "sequence_path": "405671.protein.sequences.v11.5.fa",
		        "enrichment_path": "405671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405671.protein.info.v11.5.txt",
		        "node_list_path": "405671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "405671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaproniaCoronataCbs61796Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capronia coronata CBS 617.96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaproniaCoronataCbs61796Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1182541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1182541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1182541.clusters.proteins.v11.5.txt",
		        "sequence_path": "1182541.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182541.protein.info.v11.5.txt",
		        "node_list_path": "1182541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1182541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaOtitidiscaviarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia otitidiscaviarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaOtitidiscaviarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206732.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206732.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206732.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206732.protein.info.v11.5.txt",
		        "node_list_path": "1206732.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206732.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5413Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5413Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798512.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798512.protein.info.v11.5.txt",
		        "node_list_path": "1798512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumGw2011Gwa14429Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWA1_44_29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwa14429Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618646.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618646.protein.info.v11.5.txt",
		        "node_list_path": "1618646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaFalseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella falsenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaFalseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122983.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122983.protein.info.v11.5.txt",
		        "node_list_path": "1122983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DysgonomonasMacrotermitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas macrotermitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasMacrotermitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1346286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1346286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1346286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1346286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346286.protein.info.v11.5.txt",
		        "node_list_path": "1346286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1346286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinoplanesGlobisporus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes globisporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesGlobisporus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120949.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120949.protein.info.v11.5.txt",
		        "node_list_path": "1120949.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumGw2011Gwf24317(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_43_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf24317", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619068.protein.info.v11.5.txt",
		        "node_list_path": "1619068.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpDmhc10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. DMHC 10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpDmhc10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "747377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "747377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "747377.clusters.proteins.v11.5.txt",
		        "sequence_path": "747377.protein.sequences.v11.5.fa",
		        "enrichment_path": "747377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747377.protein.info.v11.5.txt",
		        "node_list_path": "747377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "747377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoruegeriaLutimaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoruegeria lutimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoruegeriaLutimaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "571298.protein.sequences.v11.5.fa",
		        "enrichment_path": "571298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571298.protein.info.v11.5.txt",
		        "node_list_path": "571298.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full3410(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_34_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full3410", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802205.protein.info.v11.5.txt",
		        "node_list_path": "1802205.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb1438b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_43_8b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb1438b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618875.protein.info.v11.5.txt",
		        "node_list_path": "1618875.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterSpLm6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. LM 6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterSpLm6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896196.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896196.protein.info.v11.5.txt",
		        "node_list_path": "1896196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumGa0077555Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077555 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumGa0077555Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752228.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752228.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752228.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752228.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752228.protein.info.v11.5.txt",
		        "node_list_path": "1752228.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752228.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteitaleaPratensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteitalea pratensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteitaleaPratensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855912.protein.info.v11.5.txt",
		        "node_list_path": "1855912.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag624043Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:62_40_43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag624043Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896990.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896990.protein.info.v11.5.txt",
		        "node_list_path": "1896990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumDisporicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium disporicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumDisporicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84024.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84024.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84024.clusters.proteins.v11.5.txt",
		        "sequence_path": "84024.protein.sequences.v11.5.fa",
		        "enrichment_path": "84024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84024.protein.info.v11.5.txt",
		        "node_list_path": "84024.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84024.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaloramatorSpAld01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caloramator sp. ALD01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloramatorSpAld01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1031288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1031288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1031288.protein.info.v11.5.txt",
		        "node_list_path": "1031288.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpC05(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpC05", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945855.protein.info.v11.5.txt",
		        "node_list_path": "1945855.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShuttleworthiaSatellesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shuttleworthia satelles Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShuttleworthiaSatellesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "626523.clusters.info.v11.5.txt",
		        "cluster_tree_path": "626523.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "626523.clusters.proteins.v11.5.txt",
		        "sequence_path": "626523.protein.sequences.v11.5.fa",
		        "enrichment_path": "626523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626523.protein.info.v11.5.txt",
		        "node_list_path": "626523.cluster.nodes.v11.5.txt",
		        "edge_list_path": "626523.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaSpEui1c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. EuI1c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpEui1c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "298654.protein.sequences.v11.5.fa",
		        "enrichment_path": "298654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "298654.protein.info.v11.5.txt",
		        "node_list_path": "298654.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph973Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH973 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph973Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "520709.clusters.info.v11.5.txt",
		        "cluster_tree_path": "520709.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "520709.clusters.proteins.v11.5.txt",
		        "sequence_path": "520709.protein.sequences.v11.5.fa",
		        "enrichment_path": "520709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "520709.protein.info.v11.5.txt",
		        "node_list_path": "520709.cluster.nodes.v11.5.txt",
		        "edge_list_path": "520709.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpSd21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SD21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpSd21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "161528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "161528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "161528.clusters.proteins.v11.5.txt",
		        "sequence_path": "161528.protein.sequences.v11.5.fa",
		        "enrichment_path": "161528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161528.protein.info.v11.5.txt",
		        "node_list_path": "161528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "161528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4648Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4648 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4648Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977875.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977875.protein.info.v11.5.txt",
		        "node_list_path": "1977875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb245a518o7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_518O7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb245a518o7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1471508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1471508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1471508.clusters.proteins.v11.5.txt",
		        "sequence_path": "1471508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471508.protein.info.v11.5.txt",
		        "node_list_path": "1471508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1471508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSpH5989Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. H5989 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpH5989Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1643450.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1643450.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1643450.clusters.proteins.v11.5.txt",
		        "sequence_path": "1643450.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643450.protein.info.v11.5.txt",
		        "node_list_path": "1643450.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1643450.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfarculusBaarsii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfarculus baarsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfarculusBaarsii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644282.protein.sequences.v11.5.fa",
		        "enrichment_path": "644282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644282.protein.info.v11.5.txt",
		        "node_list_path": "644282.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumAgarivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumAgarivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1908389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908389.protein.info.v11.5.txt",
		        "node_list_path": "1908389.protein.complete.v11.5.txt"
		    }
		]
    )()

def UstilagoMaydis521(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ustilago maydis 521 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UstilagoMaydis521", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "237631.protein.sequences.v11.5.fa",
		        "enrichment_path": "237631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237631.protein.info.v11.5.txt",
		        "node_list_path": "237631.protein.complete.v11.5.txt"
		    }
		]
    )()

def OligotrophaCarboxidovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oligotropha carboxidovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OligotrophaCarboxidovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "504832.protein.sequences.v11.5.fa",
		        "enrichment_path": "504832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504832.protein.info.v11.5.txt",
		        "node_list_path": "504832.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumRifcsphigho212Full5236(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPHIGHO2_12_FULL_52_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumRifcsphigho212Full5236", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801980.protein.info.v11.5.txt",
		        "node_list_path": "1801980.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylacidiphilumInfernorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylacidiphilum infernorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylacidiphilumInfernorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "481448.protein.sequences.v11.5.fa",
		        "enrichment_path": "481448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481448.protein.info.v11.5.txt",
		        "node_list_path": "481448.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpMarseilleP3244(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. Marseille-P3244 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpMarseilleP3244", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871020.protein.info.v11.5.txt",
		        "node_list_path": "1871020.protein.complete.v11.5.txt"
		    }
		]
    )()

def BudviciaAquatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Budvicia aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BudviciaAquatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111728.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111728.protein.info.v11.5.txt",
		        "node_list_path": "1111728.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9215(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9215 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9215", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93060.protein.sequences.v11.5.fa",
		        "enrichment_path": "93060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93060.protein.info.v11.5.txt",
		        "node_list_path": "93060.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinimonasTaiwanensisDsm18899Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinimonas taiwanensis DSM 18899 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinimonasTaiwanensisDsm18899Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121279.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121279.protein.info.v11.5.txt",
		        "node_list_path": "1121279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeofusicoccumParvumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neofusicoccum parvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeofusicoccumParvumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "310453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "310453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "310453.clusters.proteins.v11.5.txt",
		        "sequence_path": "310453.protein.sequences.v11.5.fa",
		        "enrichment_path": "310453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "310453.protein.info.v11.5.txt",
		        "node_list_path": "310453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "310453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KribbellaSpAli6A(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kribbella sp. ALI-6-A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KribbellaSpAli6A", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1933817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933817.protein.info.v11.5.txt",
		        "node_list_path": "1933817.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwb14412(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWB1_44_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwb14412", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618748.protein.info.v11.5.txt",
		        "node_list_path": "1618748.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifcsplowo212Full459Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFCSPLOWO2_12_FULL_45_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifcsplowo212Full459Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802568.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802568.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802568.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802568.protein.info.v11.5.txt",
		        "node_list_path": "1802568.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802568.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemellaHaemolysansAtcc10379Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella haemolysans ATCC10379 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaHaemolysansAtcc10379Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546270.clusters.proteins.v11.5.txt",
		        "sequence_path": "546270.protein.sequences.v11.5.fa",
		        "enrichment_path": "546270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546270.protein.info.v11.5.txt",
		        "node_list_path": "546270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesJaponicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesJaponicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4897.protein.sequences.v11.5.fa",
		        "enrichment_path": "4897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4897.protein.info.v11.5.txt",
		        "node_list_path": "4897.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaOrisDsm18711(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris DSM18711 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOrisDsm18711", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122989.protein.info.v11.5.txt",
		        "node_list_path": "1122989.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasSpRu39b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas sp. RU39B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSpRu39b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907416.protein.info.v11.5.txt",
		        "node_list_path": "1907416.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumGw2011Gwf23829(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_38_29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf23829", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619066.protein.info.v11.5.txt",
		        "node_list_path": "1619066.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinactinosporaThermotoleransDsm45154(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinactinospora thermotolerans DSM 45154 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinactinosporaThermotoleransDsm45154", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122192.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122192.protein.info.v11.5.txt",
		        "node_list_path": "1122192.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacterium6920Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium 69-20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacterium6920Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895696.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895696.protein.info.v11.5.txt",
		        "node_list_path": "1895696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyopneumoniae168Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae 168 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyopneumoniae168Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "907287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "907287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "907287.clusters.proteins.v11.5.txt",
		        "sequence_path": "907287.protein.sequences.v11.5.fa",
		        "enrichment_path": "907287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "907287.protein.info.v11.5.txt",
		        "node_list_path": "907287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "907287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterCancerogenusAtcc35316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cancerogenus ATCC 35316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterCancerogenusAtcc35316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "500639.protein.sequences.v11.5.fa",
		        "enrichment_path": "500639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500639.protein.info.v11.5.txt",
		        "node_list_path": "500639.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag254Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:254 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag254Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262953.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262953.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262953.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262953.protein.info.v11.5.txt",
		        "node_list_path": "1262953.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262953.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusReuteriDsm20016Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri DSM20016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusReuteriDsm20016Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "557436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "557436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "557436.clusters.proteins.v11.5.txt",
		        "sequence_path": "557436.protein.sequences.v11.5.fa",
		        "enrichment_path": "557436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "557436.protein.info.v11.5.txt",
		        "node_list_path": "557436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "557436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterOboediens174bp2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter oboediens 174Bp2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterOboediens174bp2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "940286.protein.sequences.v11.5.fa",
		        "enrichment_path": "940286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "940286.protein.info.v11.5.txt",
		        "node_list_path": "940286.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpizellomycesPunctatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spizellomyces punctatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpizellomycesPunctatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "109760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "109760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "109760.clusters.proteins.v11.5.txt",
		        "sequence_path": "109760.protein.sequences.v11.5.fa",
		        "enrichment_path": "109760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109760.protein.info.v11.5.txt",
		        "node_list_path": "109760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "109760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GrimontiaHollisae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Grimontia hollisae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GrimontiaHollisae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675812.protein.sequences.v11.5.fa",
		        "enrichment_path": "675812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675812.protein.info.v11.5.txt",
		        "node_list_path": "675812.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanolobusSpT824(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus sp. T82-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolobusSpT824", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1794908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1794908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1794908.protein.info.v11.5.txt",
		        "node_list_path": "1794908.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaBarkeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaBarkeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "269797.protein.sequences.v11.5.fa",
		        "enrichment_path": "269797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269797.protein.info.v11.5.txt",
		        "node_list_path": "269797.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaceaeBacteriumRedseaS32B1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxellaceae bacterium REDSEA-S32_B1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaceaeBacteriumRedseaS32B1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811612.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811612.protein.info.v11.5.txt",
		        "node_list_path": "1811612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RamulariaColloCygni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ramularia collo-cygni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RamulariaColloCygni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "112498.protein.sequences.v11.5.fa",
		        "enrichment_path": "112498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112498.protein.info.v11.5.txt",
		        "node_list_path": "112498.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteroidesSaopaulense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacteroides saopaulense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteroidesSaopaulense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1578165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1578165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1578165.protein.info.v11.5.txt",
		        "node_list_path": "1578165.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumBangladeshenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium bangladeshense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumBangladeshenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1138189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1138189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1138189.clusters.proteins.v11.5.txt",
		        "sequence_path": "1138189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1138189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1138189.protein.info.v11.5.txt",
		        "node_list_path": "1138189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1138189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JaapiaArgillaceaMucl33604(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jaapia argillacea MUCL 33604 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JaapiaArgillaceaMucl33604", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "933084.protein.sequences.v11.5.fa",
		        "enrichment_path": "933084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933084.protein.info.v11.5.txt",
		        "node_list_path": "933084.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_01_FULL_40_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797512.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797512.protein.info.v11.5.txt",
		        "node_list_path": "1797512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacaedibacterAcanthamoebaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracaedibacter acanthamoebae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacaedibacterAcanthamoebaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "91604.clusters.info.v11.5.txt",
		        "cluster_tree_path": "91604.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "91604.clusters.proteins.v11.5.txt",
		        "sequence_path": "91604.protein.sequences.v11.5.fa",
		        "enrichment_path": "91604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91604.protein.info.v11.5.txt",
		        "node_list_path": "91604.cluster.nodes.v11.5.txt",
		        "edge_list_path": "91604.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastomycesGilchristiiSlh14081(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces gilchristii SLH14081 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomycesGilchristiiSlh14081", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "559298.protein.sequences.v11.5.fa",
		        "enrichment_path": "559298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559298.protein.info.v11.5.txt",
		        "node_list_path": "559298.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentzeaGuizhouensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentzea guizhouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentzeaGuizhouensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1586287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1586287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1586287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1586287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1586287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1586287.protein.info.v11.5.txt",
		        "node_list_path": "1586287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1586287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumPelagium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium pelagium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumPelagium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426702.protein.sequences.v11.5.fa",
		        "enrichment_path": "426702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426702.protein.info.v11.5.txt",
		        "node_list_path": "426702.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterMinnesotensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter minnesotensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterMinnesotensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118379.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118379.protein.info.v11.5.txt",
		        "node_list_path": "1118379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasHalocynthiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas halocynthiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasHalocynthiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121940.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121940.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121940.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121940.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121940.protein.info.v11.5.txt",
		        "node_list_path": "1121940.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121940.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusParauberisKctc11537(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parauberis KCTC11537 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusParauberisKctc11537", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936154.protein.sequences.v11.5.fa",
		        "enrichment_path": "936154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936154.protein.info.v11.5.txt",
		        "node_list_path": "936154.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumPseudolongumPv82(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum PV8-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumPseudolongumPv82", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1447715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1447715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1447715.protein.info.v11.5.txt",
		        "node_list_path": "1447715.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpDfci1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. DFCI1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpDfci1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230476.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230476.protein.info.v11.5.txt",
		        "node_list_path": "1230476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermosyntrophaLipolyticaDsm11003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosyntropha lipolytica DSM 11003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosyntrophaLipolyticaDsm11003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123382.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123382.protein.info.v11.5.txt",
		        "node_list_path": "1123382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3713bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_37_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3713bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802035.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802035.protein.info.v11.5.txt",
		        "node_list_path": "1802035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerolineaeBacterium4920(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium 49_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaeBacterium4920", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1641376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1641376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1641376.protein.info.v11.5.txt",
		        "node_list_path": "1641376.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalibacterSaccharofermentansDsm14828(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacter saccharofermentans DSM 14828 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacterSaccharofermentansDsm14828", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120975.protein.info.v11.5.txt",
		        "node_list_path": "1120975.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanomethylovoransHollandicaDsm15978(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanomethylovorans hollandica DSM 15978 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomethylovoransHollandicaDsm15978", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "867904.protein.sequences.v11.5.fa",
		        "enrichment_path": "867904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867904.protein.info.v11.5.txt",
		        "node_list_path": "867904.protein.complete.v11.5.txt"
		    }
		]
    )()

def TilletiaWalkeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tilletia walkeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TilletiaWalkeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "117179.protein.sequences.v11.5.fa",
		        "enrichment_path": "117179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "117179.protein.info.v11.5.txt",
		        "node_list_path": "117179.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumSpAf6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumSpAf6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1325737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325737.protein.info.v11.5.txt",
		        "node_list_path": "1325737.protein.complete.v11.5.txt"
		    }
		]
    )()

def EutypaLata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eutypa lata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EutypaLata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "97096.protein.sequences.v11.5.fa",
		        "enrichment_path": "97096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97096.protein.info.v11.5.txt",
		        "node_list_path": "97096.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumLacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium lacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumLacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "169765.clusters.info.v11.5.txt",
		        "cluster_tree_path": "169765.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "169765.clusters.proteins.v11.5.txt",
		        "sequence_path": "169765.protein.sequences.v11.5.fa",
		        "enrichment_path": "169765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "169765.protein.info.v11.5.txt",
		        "node_list_path": "169765.cluster.nodes.v11.5.txt",
		        "edge_list_path": "169765.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumRs24(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium RS24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumRs24", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397666.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397666.protein.info.v11.5.txt",
		        "node_list_path": "1397666.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumDg23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium DG_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumDg23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703414.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703414.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703414.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703414.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703414.protein.info.v11.5.txt",
		        "node_list_path": "1703414.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703414.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichinellaMurrelliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichinella murrelli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaMurrelliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "144512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "144512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "144512.clusters.proteins.v11.5.txt",
		        "sequence_path": "144512.protein.sequences.v11.5.fa",
		        "enrichment_path": "144512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "144512.protein.info.v11.5.txt",
		        "node_list_path": "144512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "144512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LupinusAngustifoliusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lupinus angustifolius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LupinusAngustifoliusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3871.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3871.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3871.clusters.proteins.v11.5.txt",
		        "sequence_path": "3871.protein.sequences.v11.5.fa",
		        "enrichment_path": "3871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3871.protein.info.v11.5.txt",
		        "node_list_path": "3871.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3871.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PectobacteriumBetavasculorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium betavasculorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumBetavasculorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "55207.protein.sequences.v11.5.fa",
		        "enrichment_path": "55207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55207.protein.info.v11.5.txt",
		        "node_list_path": "55207.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasArboricolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas arboricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasArboricolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "454957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "454957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "454957.clusters.proteins.v11.5.txt",
		        "sequence_path": "454957.protein.sequences.v11.5.fa",
		        "enrichment_path": "454957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454957.protein.info.v11.5.txt",
		        "node_list_path": "454957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "454957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaGrimshawi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila grimshawi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaGrimshawi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7222.protein.sequences.v11.5.fa",
		        "enrichment_path": "7222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7222.protein.info.v11.5.txt",
		        "node_list_path": "7222.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaCynosCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma cynos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaCynosCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246955.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246955.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246955.protein.info.v11.5.txt",
		        "node_list_path": "1246955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaMiyamotoiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia miyamotoi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaMiyamotoiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1302858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1302858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1302858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1302858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302858.protein.info.v11.5.txt",
		        "node_list_path": "1302858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1302858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSp9140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. 9140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSp9140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761900.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761900.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761900.protein.info.v11.5.txt",
		        "node_list_path": "1761900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesExalbidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides exalbidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesExalbidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "402596.protein.sequences.v11.5.fa",
		        "enrichment_path": "402596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402596.protein.info.v11.5.txt",
		        "node_list_path": "402596.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpBs2016Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BS-2016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpBs2016Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907766.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907766.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907766.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907766.protein.info.v11.5.txt",
		        "node_list_path": "1907766.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907766.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarmotaMarmotaMarmotaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marmota marmota marmota Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarmotaMarmotaMarmotaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9994.clusters.proteins.v11.5.txt",
		        "sequence_path": "9994.protein.sequences.v11.5.fa",
		        "enrichment_path": "9994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9994.protein.info.v11.5.txt",
		        "node_list_path": "9994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeucobacterSpG161Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter sp. G161 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterSpG161Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "663704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "663704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "663704.clusters.proteins.v11.5.txt",
		        "sequence_path": "663704.protein.sequences.v11.5.fa",
		        "enrichment_path": "663704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663704.protein.info.v11.5.txt",
		        "node_list_path": "663704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "663704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaOneidensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella oneidensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaOneidensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "211586.protein.sequences.v11.5.fa",
		        "enrichment_path": "211586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211586.protein.info.v11.5.txt",
		        "node_list_path": "211586.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaSpAna3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. ANA3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSpAna3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "94122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "94122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "94122.clusters.proteins.v11.5.txt",
		        "sequence_path": "94122.protein.sequences.v11.5.fa",
		        "enrichment_path": "94122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94122.protein.info.v11.5.txt",
		        "node_list_path": "94122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "94122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorBescii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor bescii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorBescii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521460.protein.sequences.v11.5.fa",
		        "enrichment_path": "521460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521460.protein.info.v11.5.txt",
		        "node_list_path": "521460.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3912(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_39_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3912", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797785.protein.info.v11.5.txt",
		        "node_list_path": "1797785.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRifoxyd1Full5311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1_FULL_53_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1Full5311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797403.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797403.protein.info.v11.5.txt",
		        "node_list_path": "1797403.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSp453mf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 453mf graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSp453mf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761874.protein.info.v11.5.txt",
		        "node_list_path": "1761874.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSuis22083(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis 22083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSuis22083", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1214184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214184.protein.info.v11.5.txt",
		        "node_list_path": "1214184.protein.complete.v11.5.txt"
		    }
		]
    )()

def TriboliumCastaneum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tribolium castaneum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TriboliumCastaneum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7070.protein.sequences.v11.5.fa",
		        "enrichment_path": "7070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7070.protein.info.v11.5.txt",
		        "node_list_path": "7070.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaOblongaNbrc102422Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella oblonga NBRC 102422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaOblongaNbrc102422Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349775.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349775.protein.info.v11.5.txt",
		        "node_list_path": "1349775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesMediterraneensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides mediterraneensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesMediterraneensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841856.protein.info.v11.5.txt",
		        "node_list_path": "1841856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumDisporicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium disporicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumDisporicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84024.protein.sequences.v11.5.fa",
		        "enrichment_path": "84024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84024.protein.info.v11.5.txt",
		        "node_list_path": "84024.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesOlivaceusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces olivaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesOlivaceusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47716.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47716.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47716.clusters.proteins.v11.5.txt",
		        "sequence_path": "47716.protein.sequences.v11.5.fa",
		        "enrichment_path": "47716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47716.protein.info.v11.5.txt",
		        "node_list_path": "47716.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47716.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChristensenellaSpAf7305cm02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Christensenella sp. AF73-05CM02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChristensenellaSpAf7305cm02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1851429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1851429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1851429.protein.info.v11.5.txt",
		        "node_list_path": "1851429.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZimmermannellaBifidaNbrc103089(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Zimmermannella] bifida NBRC 103089 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZimmermannellaBifidaNbrc103089", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349787.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349787.protein.info.v11.5.txt",
		        "node_list_path": "1349787.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaMazeiS6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina mazei S-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaMazeiS6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "213585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "213585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "213585.clusters.proteins.v11.5.txt",
		        "sequence_path": "213585.protein.sequences.v11.5.fa",
		        "enrichment_path": "213585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "213585.protein.info.v11.5.txt",
		        "node_list_path": "213585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "213585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NiveispirillumIrakenseDsm11586Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Niveispirillum irakense DSM 11586 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiveispirillumIrakenseDsm11586Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121034.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121034.protein.info.v11.5.txt",
		        "node_list_path": "1121034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusKoppenhoeferiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus koppenhoeferi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusKoppenhoeferiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351659.clusters.proteins.v11.5.txt",
		        "sequence_path": "351659.protein.sequences.v11.5.fa",
		        "enrichment_path": "351659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351659.protein.info.v11.5.txt",
		        "node_list_path": "351659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OblitimonasAlkaliphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oblitimonas alkaliphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OblitimonasAlkaliphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1697053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1697053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1697053.protein.info.v11.5.txt",
		        "node_list_path": "1697053.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmoebophilusSp3638(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amoebophilus sp. 36-38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmoebophilusSp3638", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895716.protein.info.v11.5.txt",
		        "node_list_path": "1895716.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanothermobacterSpCat2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter sp. CaT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermobacterSpCat2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "866790.clusters.info.v11.5.txt",
		        "cluster_tree_path": "866790.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "866790.clusters.proteins.v11.5.txt",
		        "sequence_path": "866790.protein.sequences.v11.5.fa",
		        "enrichment_path": "866790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866790.protein.info.v11.5.txt",
		        "node_list_path": "866790.cluster.nodes.v11.5.txt",
		        "edge_list_path": "866790.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoccidioidesImmitisRs(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis RS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesImmitisRs", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246410.protein.sequences.v11.5.fa",
		        "enrichment_path": "246410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246410.protein.info.v11.5.txt",
		        "node_list_path": "246410.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucobacterMusarumSubspJaponicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter musarum subsp. japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterMusarumSubspJaponicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461259.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461259.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461259.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461259.protein.info.v11.5.txt",
		        "node_list_path": "1461259.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461259.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyellaMarensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyella marensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaMarensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "500610.protein.sequences.v11.5.fa",
		        "enrichment_path": "500610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500610.protein.info.v11.5.txt",
		        "node_list_path": "500610.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgromycesSubbeticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agromyces subbeticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesSubbeticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120960.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120960.protein.info.v11.5.txt",
		        "node_list_path": "1120960.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19035(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19035 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19035", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1460653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460653.protein.info.v11.5.txt",
		        "node_list_path": "1460653.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSpBal39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. BAL39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpBal39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391596.clusters.proteins.v11.5.txt",
		        "sequence_path": "391596.protein.sequences.v11.5.fa",
		        "enrichment_path": "391596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391596.protein.info.v11.5.txt",
		        "node_list_path": "391596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlattellaGermanicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blattella germanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattellaGermanicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6973.clusters.proteins.v11.5.txt",
		        "sequence_path": "6973.protein.sequences.v11.5.fa",
		        "enrichment_path": "6973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6973.protein.info.v11.5.txt",
		        "node_list_path": "6973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAquaticusDsm21051(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus aquaticus DSM 21051 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAquaticusDsm21051", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423725.protein.info.v11.5.txt",
		        "node_list_path": "1423725.protein.complete.v11.5.txt"
		    }
		]
    )()

def KlebsormidiumNitens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klebsormidium nitens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsormidiumNitens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "105231.protein.sequences.v11.5.fa",
		        "enrichment_path": "105231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105231.protein.info.v11.5.txt",
		        "node_list_path": "105231.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasEucrenophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas eucrenophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasEucrenophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649.protein.sequences.v11.5.fa",
		        "enrichment_path": "649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649.protein.info.v11.5.txt",
		        "node_list_path": "649.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumLowiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium lowii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumLowiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1544413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1544413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1544413.clusters.proteins.v11.5.txt",
		        "sequence_path": "1544413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1544413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1544413.protein.info.v11.5.txt",
		        "node_list_path": "1544413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1544413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoccidioidesImmitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesImmitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5501.clusters.proteins.v11.5.txt",
		        "sequence_path": "5501.protein.sequences.v11.5.fa",
		        "enrichment_path": "5501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5501.protein.info.v11.5.txt",
		        "node_list_path": "5501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErysipelotrichaceaeBacteriumMtc7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium MTC7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelotrichaceaeBacteriumMtc7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1768196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1768196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1768196.clusters.proteins.v11.5.txt",
		        "sequence_path": "1768196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768196.protein.info.v11.5.txt",
		        "node_list_path": "1768196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1768196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumChlorophenolicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium chlorophenolicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumChlorophenolicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37916.clusters.proteins.v11.5.txt",
		        "sequence_path": "37916.protein.sequences.v11.5.fa",
		        "enrichment_path": "37916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37916.protein.info.v11.5.txt",
		        "node_list_path": "37916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaHenselae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella henselae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaHenselae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "283166.protein.sequences.v11.5.fa",
		        "enrichment_path": "283166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283166.protein.info.v11.5.txt",
		        "node_list_path": "283166.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophobacterSpDg60(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophobacter sp. DG_60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophobacterSpDg60", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703361.protein.info.v11.5.txt",
		        "node_list_path": "1703361.protein.complete.v11.5.txt"
		    }
		]
    )()

def JannaschiaSpCcs1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia sp. CCS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaSpCcs1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290400.protein.sequences.v11.5.fa",
		        "enrichment_path": "290400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290400.protein.info.v11.5.txt",
		        "node_list_path": "290400.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnq509Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNQ-509 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnq509Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "444103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "444103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "444103.clusters.proteins.v11.5.txt",
		        "sequence_path": "444103.protein.sequences.v11.5.fa",
		        "enrichment_path": "444103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444103.protein.info.v11.5.txt",
		        "node_list_path": "444103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "444103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaTimonensis4401737Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella timonensis 4401737 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaTimonensis4401737Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122992.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122992.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122992.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122992.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122992.protein.info.v11.5.txt",
		        "node_list_path": "1122992.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122992.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BeutenbergiaCavernaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Beutenbergia cavernae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeutenbergiaCavernaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471853.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471853.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471853.clusters.proteins.v11.5.txt",
		        "sequence_path": "471853.protein.sequences.v11.5.fa",
		        "enrichment_path": "471853.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471853.protein.info.v11.5.txt",
		        "node_list_path": "471853.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471853.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpMit0601(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpMit0601", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499498.protein.info.v11.5.txt",
		        "node_list_path": "1499498.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaOdoriferaDsm4582Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia odorifera DSM 4582 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaOdoriferaDsm4582Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "667129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "667129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "667129.clusters.proteins.v11.5.txt",
		        "sequence_path": "667129.protein.sequences.v11.5.fa",
		        "enrichment_path": "667129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667129.protein.info.v11.5.txt",
		        "node_list_path": "667129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "667129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo212Full6728(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_12_FULL_67_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212Full6728", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797503.protein.info.v11.5.txt",
		        "node_list_path": "1797503.protein.complete.v11.5.txt"
		    }
		]
    )()

def RugamonasRubraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rugamonas rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RugamonasRubraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "758825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "758825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "758825.clusters.proteins.v11.5.txt",
		        "sequence_path": "758825.protein.sequences.v11.5.fa",
		        "enrichment_path": "758825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758825.protein.info.v11.5.txt",
		        "node_list_path": "758825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "758825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AfipiaFelis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Afipia felis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaFelis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883080.protein.sequences.v11.5.fa",
		        "enrichment_path": "883080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883080.protein.info.v11.5.txt",
		        "node_list_path": "883080.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaH8234Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida H8234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaH8234Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1331671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1331671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1331671.clusters.proteins.v11.5.txt",
		        "sequence_path": "1331671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1331671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1331671.protein.info.v11.5.txt",
		        "node_list_path": "1331671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1331671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HeliconiusMelpomene(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Heliconius melpomene graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeliconiusMelpomene", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34740.protein.sequences.v11.5.fa",
		        "enrichment_path": "34740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34740.protein.info.v11.5.txt",
		        "node_list_path": "34740.protein.complete.v11.5.txt"
		    }
		]
    )()

def SecondaryEndosymbiontOfCtenarytainaEucalyptiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Ctenarytaina eucalypti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SecondaryEndosymbiontOfCtenarytainaEucalyptiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1199245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1199245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1199245.clusters.proteins.v11.5.txt",
		        "sequence_path": "1199245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1199245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1199245.protein.info.v11.5.txt",
		        "node_list_path": "1199245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1199245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisMacrogoltabidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis macrogoltabida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisMacrogoltabidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33050.clusters.proteins.v11.5.txt",
		        "sequence_path": "33050.protein.sequences.v11.5.fa",
		        "enrichment_path": "33050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33050.protein.info.v11.5.txt",
		        "node_list_path": "33050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpLeaf78Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpLeaf78Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736237.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736237.protein.info.v11.5.txt",
		        "node_list_path": "1736237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpDnf00663Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. DNF00663 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpDnf00663Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1384078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1384078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1384078.clusters.proteins.v11.5.txt",
		        "sequence_path": "1384078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384078.protein.info.v11.5.txt",
		        "node_list_path": "1384078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1384078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpKks102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. KKS102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpKks102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "358220.protein.sequences.v11.5.fa",
		        "enrichment_path": "358220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "358220.protein.info.v11.5.txt",
		        "node_list_path": "358220.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaSpWd121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. WD12.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpWd121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1933903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933903.protein.info.v11.5.txt",
		        "node_list_path": "1933903.protein.complete.v11.5.txt"
		    }
		]
    )()

def SmittiumSimuliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Smittium simulii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmittiumSimuliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "133385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "133385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "133385.clusters.proteins.v11.5.txt",
		        "sequence_path": "133385.protein.sequences.v11.5.fa",
		        "enrichment_path": "133385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133385.protein.info.v11.5.txt",
		        "node_list_path": "133385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "133385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusBouchesdurhonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus bouchesdurhonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusBouchesdurhonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1870990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870990.protein.info.v11.5.txt",
		        "node_list_path": "1870990.protein.complete.v11.5.txt"
		    }
		]
    )()

def DaphniaMagnaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Daphnia magna Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DaphniaMagnaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35525.clusters.proteins.v11.5.txt",
		        "sequence_path": "35525.protein.sequences.v11.5.fa",
		        "enrichment_path": "35525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35525.protein.info.v11.5.txt",
		        "node_list_path": "35525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusColwellbacteriaBacteriumRifcsplowo202Full4511Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_02_FULL_45_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo202Full4511Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797692.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797692.protein.info.v11.5.txt",
		        "node_list_path": "1797692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DietziaMaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dietzia maris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DietziaMaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37915.protein.sequences.v11.5.fa",
		        "enrichment_path": "37915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37915.protein.info.v11.5.txt",
		        "node_list_path": "37915.protein.complete.v11.5.txt"
		    }
		]
    )()

def MitsuariaSpPdc51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mitsuaria sp. PDC51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MitsuariaSpPdc51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881035.protein.info.v11.5.txt",
		        "node_list_path": "1881035.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrateuriaTerreaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frateuria terrea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrateuriaTerreaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "529704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "529704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "529704.clusters.proteins.v11.5.txt",
		        "sequence_path": "529704.protein.sequences.v11.5.fa",
		        "enrichment_path": "529704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529704.protein.info.v11.5.txt",
		        "node_list_path": "529704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "529704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumElkanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumElkanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29448.protein.sequences.v11.5.fa",
		        "enrichment_path": "29448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29448.protein.info.v11.5.txt",
		        "node_list_path": "29448.protein.complete.v11.5.txt"
		    }
		]
    )()

def UrmitellaTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Urmitella timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UrmitellaTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1870994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1870994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1870994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1870994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870994.protein.info.v11.5.txt",
		        "node_list_path": "1870994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1870994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidimangrovimonasIndica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidimangrovimonas indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidimangrovimonasIndica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765699.protein.sequences.v11.5.fa",
		        "enrichment_path": "765699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765699.protein.info.v11.5.txt",
		        "node_list_path": "765699.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumPseudolongumGlobosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum globosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumPseudolongumGlobosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1690.clusters.proteins.v11.5.txt",
		        "sequence_path": "1690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690.protein.info.v11.5.txt",
		        "node_list_path": "1690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusPumilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus pumilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPumilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "315750.protein.sequences.v11.5.fa",
		        "enrichment_path": "315750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "315750.protein.info.v11.5.txt",
		        "node_list_path": "315750.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4135Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_41_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4135Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798677.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798677.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798677.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798677.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798677.protein.info.v11.5.txt",
		        "node_list_path": "1798677.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798677.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTremblayaPrincepsPcval(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tremblaya princeps PCVAL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTremblayaPrincepsPcval", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1053648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1053648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1053648.protein.info.v11.5.txt",
		        "node_list_path": "1053648.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium6417Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 64-17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium6417Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895814.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895814.protein.info.v11.5.txt",
		        "node_list_path": "1895814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenopusTropicalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenopus tropicalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenopusTropicalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8364.clusters.proteins.v11.5.txt",
		        "sequence_path": "8364.protein.sequences.v11.5.fa",
		        "enrichment_path": "8364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8364.protein.info.v11.5.txt",
		        "node_list_path": "8364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTa06BacteriumDg24Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TA06 bacterium DG_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTa06BacteriumDg24Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703770.protein.info.v11.5.txt",
		        "node_list_path": "1703770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaReeseiQm6aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma reesei QM6a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaReeseiQm6aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "431241.clusters.info.v11.5.txt",
		        "cluster_tree_path": "431241.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "431241.clusters.proteins.v11.5.txt",
		        "sequence_path": "431241.protein.sequences.v11.5.fa",
		        "enrichment_path": "431241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431241.protein.info.v11.5.txt",
		        "node_list_path": "431241.cluster.nodes.v11.5.txt",
		        "edge_list_path": "431241.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpM334Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. M334 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpM334Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "563038.clusters.info.v11.5.txt",
		        "cluster_tree_path": "563038.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "563038.clusters.proteins.v11.5.txt",
		        "sequence_path": "563038.protein.sequences.v11.5.fa",
		        "enrichment_path": "563038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563038.protein.info.v11.5.txt",
		        "node_list_path": "563038.cluster.nodes.v11.5.txt",
		        "edge_list_path": "563038.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeiothermusTimidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus timidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusTimidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122223.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122223.protein.info.v11.5.txt",
		        "node_list_path": "1122223.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPacebacteriaBacteriumRifoxyd1Full3927(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFOXYD1_FULL_39_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifoxyd1Full3927", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801892.protein.info.v11.5.txt",
		        "node_list_path": "1801892.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitis2Sk95(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis 2 SK95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitis2Sk95", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1000588.protein.sequences.v11.5.fa",
		        "enrichment_path": "1000588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1000588.protein.info.v11.5.txt",
		        "node_list_path": "1000588.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSuwonensisJ43(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis J43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSuwonensisJ43", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935567.protein.sequences.v11.5.fa",
		        "enrichment_path": "935567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935567.protein.info.v11.5.txt",
		        "node_list_path": "935567.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwa1377Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_37_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa1377Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618545.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618545.protein.info.v11.5.txt",
		        "node_list_path": "1618545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoorellaThermoacetica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moorella thermoacetica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoorellaThermoacetica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264732.protein.sequences.v11.5.fa",
		        "enrichment_path": "264732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264732.protein.info.v11.5.txt",
		        "node_list_path": "264732.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf339(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf339 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf339", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736343.protein.info.v11.5.txt",
		        "node_list_path": "1736343.protein.complete.v11.5.txt"
		    }
		]
    )()

def VolvoxCarteriFNagariensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Volvox carteri f. nagariensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VolvoxCarteriFNagariensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3068.protein.sequences.v11.5.fa",
		        "enrichment_path": "3068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3068.protein.info.v11.5.txt",
		        "node_list_path": "3068.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrocystisAeruginosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microcystis aeruginosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrocystisAeruginosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "449447.clusters.info.v11.5.txt",
		        "cluster_tree_path": "449447.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "449447.clusters.proteins.v11.5.txt",
		        "sequence_path": "449447.protein.sequences.v11.5.fa",
		        "enrichment_path": "449447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "449447.protein.info.v11.5.txt",
		        "node_list_path": "449447.cluster.nodes.v11.5.txt",
		        "edge_list_path": "449447.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusIctaluri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus ictaluri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusIctaluri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "764299.protein.sequences.v11.5.fa",
		        "enrichment_path": "764299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "764299.protein.info.v11.5.txt",
		        "node_list_path": "764299.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesViolensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces violens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesViolensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66377.clusters.proteins.v11.5.txt",
		        "sequence_path": "66377.protein.sequences.v11.5.fa",
		        "enrichment_path": "66377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66377.protein.info.v11.5.txt",
		        "node_list_path": "66377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NothoproctaPerdicaria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nothoprocta perdicaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NothoproctaPerdicaria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "30464.protein.sequences.v11.5.fa",
		        "enrichment_path": "30464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30464.protein.info.v11.5.txt",
		        "node_list_path": "30464.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterAceti1023Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter aceti 1023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterAceti1023Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1457393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1457393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1457393.clusters.proteins.v11.5.txt",
		        "sequence_path": "1457393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1457393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1457393.protein.info.v11.5.txt",
		        "node_list_path": "1457393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1457393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LutibacterProfundiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lutibacter profundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutibacterProfundiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1622118.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1622118.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1622118.clusters.proteins.v11.5.txt",
		        "sequence_path": "1622118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622118.protein.info.v11.5.txt",
		        "node_list_path": "1622118.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1622118.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerribacillusAidingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terribacillus aidingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerribacillusAidingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "586416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "586416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "586416.clusters.proteins.v11.5.txt",
		        "sequence_path": "586416.protein.sequences.v11.5.fa",
		        "enrichment_path": "586416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "586416.protein.info.v11.5.txt",
		        "node_list_path": "586416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "586416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSp35w(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 35W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSp35w", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1132441.protein.sequences.v11.5.fa",
		        "enrichment_path": "1132441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1132441.protein.info.v11.5.txt",
		        "node_list_path": "1132441.protein.complete.v11.5.txt"
		    }
		]
    )()

def JeotgalicoccusPsychrophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalicoccus psychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalicoccusPsychrophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122129.protein.info.v11.5.txt",
		        "node_list_path": "1122129.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpBcu110501(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. BCU110501 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpBcu110501", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "365528.protein.sequences.v11.5.fa",
		        "enrichment_path": "365528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "365528.protein.info.v11.5.txt",
		        "node_list_path": "365528.protein.complete.v11.5.txt"
		    }
		]
    )()

def NoviherbaspirillumSpRoot189(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Noviherbaspirillum sp. Root189 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NoviherbaspirillumSpRoot189", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736487.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736487.protein.info.v11.5.txt",
		        "node_list_path": "1736487.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaGallinaceumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallinaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaGallinaceumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29556.clusters.proteins.v11.5.txt",
		        "sequence_path": "29556.protein.sequences.v11.5.fa",
		        "enrichment_path": "29556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29556.protein.info.v11.5.txt",
		        "node_list_path": "29556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpMitS9509Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. MIT S9509 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpMitS9509Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801630.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801630.protein.info.v11.5.txt",
		        "node_list_path": "1801630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaDisiensJcm6334(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella disiens JCM6334 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaDisiensJcm6334", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235811.protein.info.v11.5.txt",
		        "node_list_path": "1235811.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRiesiaPediculischaeffiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia pediculischaeffi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRiesiaPediculischaeffiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "428411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "428411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "428411.clusters.proteins.v11.5.txt",
		        "sequence_path": "428411.protein.sequences.v11.5.fa",
		        "enrichment_path": "428411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428411.protein.info.v11.5.txt",
		        "node_list_path": "428411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "428411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerotruncusSpG3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. G3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotruncusSpG3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235835.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235835.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235835.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235835.protein.info.v11.5.txt",
		        "node_list_path": "1235835.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235835.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735676.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735676.protein.info.v11.5.txt",
		        "node_list_path": "1735676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumViridifuturi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium viridifuturi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumViridifuturi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1654716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1654716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1654716.protein.info.v11.5.txt",
		        "node_list_path": "1654716.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSp37maCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 37MA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp37maCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1132442.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1132442.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1132442.clusters.proteins.v11.5.txt",
		        "sequence_path": "1132442.protein.sequences.v11.5.fa",
		        "enrichment_path": "1132442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1132442.protein.info.v11.5.txt",
		        "node_list_path": "1132442.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1132442.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_42_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618820.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618820.protein.info.v11.5.txt",
		        "node_list_path": "1618820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsplowo201Full4421Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPLOWO2_01_FULL_44_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsplowo201Full4421Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817841.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817841.protein.info.v11.5.txt",
		        "node_list_path": "1817841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc24817Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC2_48_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc24817Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618933.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618933.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618933.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618933.protein.info.v11.5.txt",
		        "node_list_path": "1618933.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618933.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PatagioenasFasciataMonilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Patagioenas fasciata monilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PatagioenasFasciataMonilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "372326.protein.sequences.v11.5.fa",
		        "enrichment_path": "372326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "372326.protein.info.v11.5.txt",
		        "node_list_path": "372326.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaSpP37(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina sp. P37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaSpP37", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930546.protein.info.v11.5.txt",
		        "node_list_path": "1930546.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpLeaf151(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf151 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpLeaf151", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736276.protein.info.v11.5.txt",
		        "node_list_path": "1736276.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumCavolei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum cavolei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumCavolei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "366522.protein.sequences.v11.5.fa",
		        "enrichment_path": "366522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366522.protein.info.v11.5.txt",
		        "node_list_path": "366522.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicycliphilusDenitrificansBc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans BC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicycliphilusDenitrificansBc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596153.protein.sequences.v11.5.fa",
		        "enrichment_path": "596153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596153.protein.info.v11.5.txt",
		        "node_list_path": "596153.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucobacterMusarumSubspJaponicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter musarum subsp. japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterMusarumSubspJaponicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461259.protein.info.v11.5.txt",
		        "node_list_path": "1461259.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacillusPsychrotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacillus psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacillusPsychrotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "126156.protein.sequences.v11.5.fa",
		        "enrichment_path": "126156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "126156.protein.info.v11.5.txt",
		        "node_list_path": "126156.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpS7Ms2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. S7 MS 2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpS7Ms2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1287488.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1287488.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1287488.clusters.proteins.v11.5.txt",
		        "sequence_path": "1287488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287488.protein.info.v11.5.txt",
		        "node_list_path": "1287488.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1287488.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GottschalkiaPurinilytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gottschalkia purinilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GottschalkiaPurinilytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1503.protein.info.v11.5.txt",
		        "node_list_path": "1503.protein.complete.v11.5.txt"
		    }
		]
    )()

def DokdonellaImmobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dokdonella immobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DokdonellaImmobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "578942.protein.sequences.v11.5.fa",
		        "enrichment_path": "578942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578942.protein.info.v11.5.txt",
		        "node_list_path": "578942.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusHaemolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus haemolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusHaemolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "279808.protein.sequences.v11.5.fa",
		        "enrichment_path": "279808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279808.protein.info.v11.5.txt",
		        "node_list_path": "279808.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldimicrobiumThiodismutans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldimicrobium thiodismutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldimicrobiumThiodismutans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1653476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1653476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1653476.protein.info.v11.5.txt",
		        "node_list_path": "1653476.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAquimaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus aquimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAquimaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "189382.protein.sequences.v11.5.fa",
		        "enrichment_path": "189382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189382.protein.info.v11.5.txt",
		        "node_list_path": "189382.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytophthoraInfestansT304(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora infestans T30-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraInfestansT304", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "403677.protein.sequences.v11.5.fa",
		        "enrichment_path": "403677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "403677.protein.info.v11.5.txt",
		        "node_list_path": "403677.protein.complete.v11.5.txt"
		    }
		]
    )()

def TeredinibacterTurneraeT7901(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Teredinibacter turnerae T7901 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TeredinibacterTurneraeT7901", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "377629.protein.sequences.v11.5.fa",
		        "enrichment_path": "377629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "377629.protein.info.v11.5.txt",
		        "node_list_path": "377629.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSaliperosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium saliperosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSaliperosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1341155.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341155.protein.info.v11.5.txt",
		        "node_list_path": "1341155.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumHimb59(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB59 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumHimb59", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "744985.protein.sequences.v11.5.fa",
		        "enrichment_path": "744985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "744985.protein.info.v11.5.txt",
		        "node_list_path": "744985.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpBal3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. BAL3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpBal3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391600.protein.sequences.v11.5.fa",
		        "enrichment_path": "391600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391600.protein.info.v11.5.txt",
		        "node_list_path": "391600.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusMarincolaHl49Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus marincola HL49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusMarincolaHl49Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1305737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1305737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1305737.clusters.proteins.v11.5.txt",
		        "sequence_path": "1305737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305737.protein.info.v11.5.txt",
		        "node_list_path": "1305737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1305737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfopilaAestuariiDsm18488(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfopila aestuarii DSM 18488 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfopilaAestuariiDsm18488", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121416.protein.info.v11.5.txt",
		        "node_list_path": "1121416.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrobacterYoungae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter youngae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterYoungae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "500640.protein.sequences.v11.5.fa",
		        "enrichment_path": "500640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500640.protein.info.v11.5.txt",
		        "node_list_path": "500640.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioFibrisolvensDsm3071(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens DSM 3071 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioFibrisolvensDsm3071", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121131.protein.info.v11.5.txt",
		        "node_list_path": "1121131.protein.complete.v11.5.txt"
		    }
		]
    )()

def AngiostrongylusCostaricensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Angiostrongylus costaricensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AngiostrongylusCostaricensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "334426.protein.sequences.v11.5.fa",
		        "enrichment_path": "334426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334426.protein.info.v11.5.txt",
		        "node_list_path": "334426.protein.complete.v11.5.txt"
		    }
		]
    )()

def DictyoglomusThermophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dictyoglomus thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DictyoglomusThermophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "309799.clusters.info.v11.5.txt",
		        "cluster_tree_path": "309799.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "309799.clusters.proteins.v11.5.txt",
		        "sequence_path": "309799.protein.sequences.v11.5.fa",
		        "enrichment_path": "309799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "309799.protein.info.v11.5.txt",
		        "node_list_path": "309799.cluster.nodes.v11.5.txt",
		        "edge_list_path": "309799.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumHimb114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumHimb114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "684719.protein.sequences.v11.5.fa",
		        "enrichment_path": "684719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "684719.protein.info.v11.5.txt",
		        "node_list_path": "684719.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGwa1418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GWA1_41_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGwa1418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802471.protein.info.v11.5.txt",
		        "node_list_path": "1802471.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpNo7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. No. 7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpNo7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1714373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714373.protein.info.v11.5.txt",
		        "node_list_path": "1714373.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClunioMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clunio marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClunioMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "568069.protein.sequences.v11.5.fa",
		        "enrichment_path": "568069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568069.protein.info.v11.5.txt",
		        "node_list_path": "568069.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanospirillumHungatei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanospirillum hungatei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanospirillumHungatei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "323259.protein.sequences.v11.5.fa",
		        "enrichment_path": "323259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323259.protein.info.v11.5.txt",
		        "node_list_path": "323259.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrusClementina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrus clementina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrusClementina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "85681.protein.sequences.v11.5.fa",
		        "enrichment_path": "85681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85681.protein.info.v11.5.txt",
		        "node_list_path": "85681.protein.complete.v11.5.txt"
		    }
		]
    )()

def AngustibacterSpRoot456(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Angustibacter sp. Root456 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AngustibacterSpRoot456", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736539.protein.info.v11.5.txt",
		        "node_list_path": "1736539.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumHaemolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium haemolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumHaemolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "394935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "394935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "394935.clusters.proteins.v11.5.txt",
		        "sequence_path": "394935.protein.sequences.v11.5.fa",
		        "enrichment_path": "394935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394935.protein.info.v11.5.txt",
		        "node_list_path": "394935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "394935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrobacterSp6223(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrobacter sp. 62-23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrobacterSp6223", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895798.protein.info.v11.5.txt",
		        "node_list_path": "1895798.protein.complete.v11.5.txt"
		    }
		]
    )()

def StylophoraPistillata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stylophora pistillata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StylophoraPistillata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "50429.protein.sequences.v11.5.fa",
		        "enrichment_path": "50429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50429.protein.info.v11.5.txt",
		        "node_list_path": "50429.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumChungbukense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium chungbukense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumChungbukense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56193.protein.sequences.v11.5.fa",
		        "enrichment_path": "56193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56193.protein.info.v11.5.txt",
		        "node_list_path": "56193.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSubvibrioides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas subvibrioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSubvibrioides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "633149.protein.sequences.v11.5.fa",
		        "enrichment_path": "633149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633149.protein.info.v11.5.txt",
		        "node_list_path": "633149.protein.complete.v11.5.txt"
		    }
		]
    )()

def TessaracoccusFlavescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusFlavescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "399497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "399497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "399497.clusters.proteins.v11.5.txt",
		        "sequence_path": "399497.protein.sequences.v11.5.fa",
		        "enrichment_path": "399497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399497.protein.info.v11.5.txt",
		        "node_list_path": "399497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "399497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnoclostridiumPhocaeense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnoclostridium phocaeense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoclostridiumPhocaeense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871021.protein.info.v11.5.txt",
		        "node_list_path": "1871021.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnicellularCyanobacteriumSu2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return unicellular cyanobacterium SU2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnicellularCyanobacteriumSu2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1981054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1981054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1981054.protein.info.v11.5.txt",
		        "node_list_path": "1981054.protein.complete.v11.5.txt"
		    }
		]
    )()

def GaetbulibacterSaemankumensisDsm17032(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gaetbulibacter saemankumensis DSM 17032 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GaetbulibacterSaemankumensisDsm17032", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121909.protein.info.v11.5.txt",
		        "node_list_path": "1121909.protein.complete.v11.5.txt"
		    }
		]
    )()

def KineosphaeraLimosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kineosphaera limosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KineosphaeraLimosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1184609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1184609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1184609.protein.info.v11.5.txt",
		        "node_list_path": "1184609.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpAt4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. AT4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpAt4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720194.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720194.protein.info.v11.5.txt",
		        "node_list_path": "1720194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTsri0281(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TSRI0281 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTsri0281", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1718998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1718998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1718998.protein.info.v11.5.txt",
		        "node_list_path": "1718998.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumOxysporumFSpLycopersici4287Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. lycopersici 4287 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumOxysporumFSpLycopersici4287Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426428.clusters.proteins.v11.5.txt",
		        "sequence_path": "426428.protein.sequences.v11.5.fa",
		        "enrichment_path": "426428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426428.protein.info.v11.5.txt",
		        "node_list_path": "426428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusVulcanius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus vulcanius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusVulcanius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "579137.protein.sequences.v11.5.fa",
		        "enrichment_path": "579137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579137.protein.info.v11.5.txt",
		        "node_list_path": "579137.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioNeptuniusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio neptunius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioNeptuniusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "170651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "170651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "170651.clusters.proteins.v11.5.txt",
		        "sequence_path": "170651.protein.sequences.v11.5.fa",
		        "enrichment_path": "170651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "170651.protein.info.v11.5.txt",
		        "node_list_path": "170651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "170651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaAbscessusNbrc100374(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia abscessus NBRC 100374 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAbscessusNbrc100374", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206723.protein.info.v11.5.txt",
		        "node_list_path": "1206723.protein.complete.v11.5.txt"
		    }
		]
    )()

def DothistromaSeptosporumNze10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dothistroma septosporum NZE10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DothistromaSeptosporumNze10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675120.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675120.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675120.clusters.proteins.v11.5.txt",
		        "sequence_path": "675120.protein.sequences.v11.5.fa",
		        "enrichment_path": "675120.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675120.protein.info.v11.5.txt",
		        "node_list_path": "675120.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675120.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpLeaf7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. Leaf7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpLeaf7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736210.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736210.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736210.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736210.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736210.protein.info.v11.5.txt",
		        "node_list_path": "1736210.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736210.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrateuriaTerrea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frateuria terrea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrateuriaTerrea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "529704.protein.sequences.v11.5.fa",
		        "enrichment_path": "529704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529704.protein.info.v11.5.txt",
		        "node_list_path": "529704.protein.complete.v11.5.txt"
		    }
		]
    )()

def RahnellaAquatilisCip7865Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rahnella aquatilis CIP78.65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RahnellaAquatilisCip7865Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "745277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "745277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "745277.clusters.proteins.v11.5.txt",
		        "sequence_path": "745277.protein.sequences.v11.5.fa",
		        "enrichment_path": "745277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745277.protein.info.v11.5.txt",
		        "node_list_path": "745277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "745277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlaviramulusBasaltis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flaviramulus basaltis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlaviramulusBasaltis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "369401.protein.sequences.v11.5.fa",
		        "enrichment_path": "369401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "369401.protein.info.v11.5.txt",
		        "node_list_path": "369401.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumImmobileAtcc35973Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium immobile (ATCC 35973) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumImmobileAtcc35973Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "31967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "31967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "31967.clusters.proteins.v11.5.txt",
		        "sequence_path": "31967.protein.sequences.v11.5.fa",
		        "enrichment_path": "31967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31967.protein.info.v11.5.txt",
		        "node_list_path": "31967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "31967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSaniviriJcm17471Dsm24301Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus saniviri JCM 17471 DSM 24301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSaniviriJcm17471Dsm24301Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293598.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293598.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293598.protein.info.v11.5.txt",
		        "node_list_path": "1293598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAtroolivaceus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces atroolivaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAtroolivaceus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66869.protein.sequences.v11.5.fa",
		        "enrichment_path": "66869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66869.protein.info.v11.5.txt",
		        "node_list_path": "66869.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctopirusHydrillae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctopirus hydrillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctopirusHydrillae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841610.protein.info.v11.5.txt",
		        "node_list_path": "1841610.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophothermusLipocalidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophothermus lipocalidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophothermusLipocalidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "643648.protein.sequences.v11.5.fa",
		        "enrichment_path": "643648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "643648.protein.info.v11.5.txt",
		        "node_list_path": "643648.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelosinusFermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelosinusFermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122947.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122947.protein.info.v11.5.txt",
		        "node_list_path": "1122947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRbg13469Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RBG_13_46_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRbg13469Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801818.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801818.protein.info.v11.5.txt",
		        "node_list_path": "1801818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpLeaf264(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf264 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpLeaf264", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736314.protein.info.v11.5.txt",
		        "node_list_path": "1736314.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumButyricumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium butyricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumButyricumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "632245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "632245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "632245.clusters.proteins.v11.5.txt",
		        "sequence_path": "632245.protein.sequences.v11.5.fa",
		        "enrichment_path": "632245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632245.protein.info.v11.5.txt",
		        "node_list_path": "632245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "632245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho202Full4243(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_02_FULL_42_43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho202Full4243", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798272.protein.info.v11.5.txt",
		        "node_list_path": "1798272.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaPallensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella pallens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaPallensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "997353.clusters.info.v11.5.txt",
		        "cluster_tree_path": "997353.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "997353.clusters.proteins.v11.5.txt",
		        "sequence_path": "997353.protein.sequences.v11.5.fa",
		        "enrichment_path": "997353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997353.protein.info.v11.5.txt",
		        "node_list_path": "997353.cluster.nodes.v11.5.txt",
		        "edge_list_path": "997353.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusIslandicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus islandicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusIslandicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123389.protein.info.v11.5.txt",
		        "node_list_path": "1123389.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusSp8g7Msg3316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sp. 8G7_MSG3316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSp8g7Msg3316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834191.protein.info.v11.5.txt",
		        "node_list_path": "1834191.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumGw2011Gwb1471Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWB1_47_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwb1471Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619007.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619007.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619007.protein.info.v11.5.txt",
		        "node_list_path": "1619007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumJdfr86(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumJdfr86", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935147.protein.info.v11.5.txt",
		        "node_list_path": "1935147.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpOsyse(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. OSYSE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpOsyse", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196323.protein.info.v11.5.txt",
		        "node_list_path": "1196323.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechocystisSpPcc6803Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC6803 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechocystisSpPcc6803Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1148.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1148.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1148.clusters.proteins.v11.5.txt",
		        "sequence_path": "1148.protein.sequences.v11.5.fa",
		        "enrichment_path": "1148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1148.protein.info.v11.5.txt",
		        "node_list_path": "1148.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1148.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollimonasSpOk412(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collimonas sp. OK412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollimonasSpOk412", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801619.protein.info.v11.5.txt",
		        "node_list_path": "1801619.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxJadensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax jadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxJadensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1177181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1177181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1177181.clusters.proteins.v11.5.txt",
		        "sequence_path": "1177181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177181.protein.info.v11.5.txt",
		        "node_list_path": "1177181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1177181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu033Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU033 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu033Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1676153.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1676153.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1676153.clusters.proteins.v11.5.txt",
		        "sequence_path": "1676153.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676153.protein.info.v11.5.txt",
		        "node_list_path": "1676153.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1676153.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumCelatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium celatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumCelatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28045.clusters.proteins.v11.5.txt",
		        "sequence_path": "28045.protein.sequences.v11.5.fa",
		        "enrichment_path": "28045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28045.protein.info.v11.5.txt",
		        "node_list_path": "28045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FungalSpNo14919(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return fungal sp. No.14919 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FungalSpNo14919", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1813822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1813822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1813822.protein.info.v11.5.txt",
		        "node_list_path": "1813822.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterPinnipediorumSubspPinnipediorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter pinnipediorum subsp. pinnipediorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterPinnipediorumSubspPinnipediorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660067.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660067.protein.info.v11.5.txt",
		        "node_list_path": "1660067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusRubeinfantis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus rubeinfantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusRubeinfantis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720199.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720199.protein.info.v11.5.txt",
		        "node_list_path": "1720199.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusRuminisAtcc27782Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ruminis ATCC27782 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusRuminisAtcc27782Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1069534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1069534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1069534.clusters.proteins.v11.5.txt",
		        "sequence_path": "1069534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069534.protein.info.v11.5.txt",
		        "node_list_path": "1069534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1069534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaLutea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina lutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaLutea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "431489.protein.sequences.v11.5.fa",
		        "enrichment_path": "431489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431489.protein.info.v11.5.txt",
		        "node_list_path": "431489.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchistosomaCurassoni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma curassoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaCurassoni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6186.protein.sequences.v11.5.fa",
		        "enrichment_path": "6186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6186.protein.info.v11.5.txt",
		        "node_list_path": "6186.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaBovis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaBovis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "289397.protein.sequences.v11.5.fa",
		        "enrichment_path": "289397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "289397.protein.info.v11.5.txt",
		        "node_list_path": "289397.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAfricanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio africanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAfricanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "690850.protein.sequences.v11.5.fa",
		        "enrichment_path": "690850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690850.protein.info.v11.5.txt",
		        "node_list_path": "690850.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSpPamc26640(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. PAMC 26640 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSpPamc26640", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1300914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300914.protein.info.v11.5.txt",
		        "node_list_path": "1300914.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterRodentium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter rodentium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterRodentium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449345.protein.info.v11.5.txt",
		        "node_list_path": "1449345.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinicolaSocius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinicola socius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicolaSocius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "404433.protein.sequences.v11.5.fa",
		        "enrichment_path": "404433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "404433.protein.info.v11.5.txt",
		        "node_list_path": "404433.protein.complete.v11.5.txt"
		    }
		]
    )()

def PediculusHumanusCorporis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pediculus humanus corporis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediculusHumanusCorporis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "121224.protein.sequences.v11.5.fa",
		        "enrichment_path": "121224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121224.protein.info.v11.5.txt",
		        "node_list_path": "121224.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusTorquesAtcc27756(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus torques ATCC27756 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusTorquesAtcc27756", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411460.protein.sequences.v11.5.fa",
		        "enrichment_path": "411460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411460.protein.info.v11.5.txt",
		        "node_list_path": "411460.protein.complete.v11.5.txt"
		    }
		]
    )()

def BhargavaeaBeijingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bhargavaea beijingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BhargavaeaBeijingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426756.clusters.proteins.v11.5.txt",
		        "sequence_path": "426756.protein.sequences.v11.5.fa",
		        "enrichment_path": "426756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426756.protein.info.v11.5.txt",
		        "node_list_path": "426756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShimazuellaKribbensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shimazuella kribbensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShimazuellaKribbensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123252.protein.info.v11.5.txt",
		        "node_list_path": "1123252.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylohalobiusCrimeensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylohalobius crimeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylohalobiusCrimeensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1283300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283300.protein.info.v11.5.txt",
		        "node_list_path": "1283300.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpF0091Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0091 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpF0091Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227276.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227276.protein.info.v11.5.txt",
		        "node_list_path": "1227276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumOlb15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumOlb15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617416.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617416.protein.info.v11.5.txt",
		        "node_list_path": "1617416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProlemurSimusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prolemur simus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProlemurSimusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1328070.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1328070.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1328070.clusters.proteins.v11.5.txt",
		        "sequence_path": "1328070.protein.sequences.v11.5.fa",
		        "enrichment_path": "1328070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1328070.protein.info.v11.5.txt",
		        "node_list_path": "1328070.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1328070.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium284(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 284 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium284", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "397287.protein.sequences.v11.5.fa",
		        "enrichment_path": "397287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397287.protein.info.v11.5.txt",
		        "node_list_path": "397287.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioThiocyanoxidansArhCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArhCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "713587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "713587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "713587.clusters.proteins.v11.5.txt",
		        "sequence_path": "713587.protein.sequences.v11.5.fa",
		        "enrichment_path": "713587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713587.protein.info.v11.5.txt",
		        "node_list_path": "713587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "713587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinivibrioAlkaliphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinivibrio alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinivibrioAlkaliphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1313304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1313304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1313304.clusters.proteins.v11.5.txt",
		        "sequence_path": "1313304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313304.protein.info.v11.5.txt",
		        "node_list_path": "1313304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1313304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavihumibacterSpCaciam22h1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavihumibacter sp. CACIAM 22H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavihumibacterSpCaciam22h1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1812911.protein.sequences.v11.5.fa",
		        "enrichment_path": "1812911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1812911.protein.info.v11.5.txt",
		        "node_list_path": "1812911.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterSenuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter senuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterSenuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "386913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "386913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "386913.clusters.proteins.v11.5.txt",
		        "sequence_path": "386913.protein.sequences.v11.5.fa",
		        "enrichment_path": "386913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "386913.protein.info.v11.5.txt",
		        "node_list_path": "386913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "386913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaNeofelifaecisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia neofelifaecis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaNeofelifaecisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644548.clusters.proteins.v11.5.txt",
		        "sequence_path": "644548.protein.sequences.v11.5.fa",
		        "enrichment_path": "644548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644548.protein.info.v11.5.txt",
		        "node_list_path": "644548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SeonamhaeicolaSpS23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Seonamhaeicola sp. S2-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SeonamhaeicolaSpS23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1936081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1936081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1936081.clusters.proteins.v11.5.txt",
		        "sequence_path": "1936081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1936081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1936081.protein.info.v11.5.txt",
		        "node_list_path": "1936081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1936081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusKimchii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus kimchii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusKimchii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1238184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238184.protein.info.v11.5.txt",
		        "node_list_path": "1238184.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3814(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_38_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3814", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798279.protein.info.v11.5.txt",
		        "node_list_path": "1798279.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaCarbonacea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora carbonacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaCarbonacea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47853.protein.sequences.v11.5.fa",
		        "enrichment_path": "47853.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47853.protein.info.v11.5.txt",
		        "node_list_path": "47853.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumExtorquensPa1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium extorquens PA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumExtorquensPa1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "419610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "419610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "419610.clusters.proteins.v11.5.txt",
		        "sequence_path": "419610.protein.sequences.v11.5.fa",
		        "enrichment_path": "419610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419610.protein.info.v11.5.txt",
		        "node_list_path": "419610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "419610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermomonasHydrothermalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermomonas hydrothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermomonasHydrothermalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "213588.protein.sequences.v11.5.fa",
		        "enrichment_path": "213588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "213588.protein.info.v11.5.txt",
		        "node_list_path": "213588.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpF0418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpF0418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "904294.protein.sequences.v11.5.fa",
		        "enrichment_path": "904294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904294.protein.info.v11.5.txt",
		        "node_list_path": "904294.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterVulgarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterVulgarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "291985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "291985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "291985.clusters.proteins.v11.5.txt",
		        "sequence_path": "291985.protein.sequences.v11.5.fa",
		        "enrichment_path": "291985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "291985.protein.info.v11.5.txt",
		        "node_list_path": "291985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "291985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryobacteriumArcticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryobacterium arcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryobacteriumArcticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "670052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "670052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "670052.clusters.proteins.v11.5.txt",
		        "sequence_path": "670052.protein.sequences.v11.5.fa",
		        "enrichment_path": "670052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670052.protein.info.v11.5.txt",
		        "node_list_path": "670052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "670052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4332(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_FULL_43_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4332", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798332.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798332.protein.info.v11.5.txt",
		        "node_list_path": "1798332.protein.complete.v11.5.txt"
		    }
		]
    )()

def WilliamsiaSp1138Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Williamsia sp. 1138 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WilliamsiaSp1138Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1903117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1903117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1903117.clusters.proteins.v11.5.txt",
		        "sequence_path": "1903117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903117.protein.info.v11.5.txt",
		        "node_list_path": "1903117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1903117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumMedpeSwcelCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium MedPE-SWcel Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumMedpeSwcelCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1860092.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1860092.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1860092.clusters.proteins.v11.5.txt",
		        "sequence_path": "1860092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860092.protein.info.v11.5.txt",
		        "node_list_path": "1860092.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1860092.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FinegoldiaMagnaAtcc29328(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Finegoldia magna ATCC29328 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FinegoldiaMagnaAtcc29328", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "334413.protein.sequences.v11.5.fa",
		        "enrichment_path": "334413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334413.protein.info.v11.5.txt",
		        "node_list_path": "334413.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaWheatBlue(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma wheat blue graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaWheatBlue", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321961.protein.sequences.v11.0.fa",
		        "enrichment_path": "321961.protein.enrichment.terms.v11.0.txt",
		        "info_path": "321961.protein.info.v11.0.txt",
		        "node_list_path": "321961.protein.complete.v11.0.txt"
		    }
		]
    )()

def ClostridiumSpMaddingley(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. Maddingley graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpMaddingley", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196322.protein.info.v11.5.txt",
		        "node_list_path": "1196322.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaDonostiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia donostiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaDonostiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1538463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1538463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1538463.clusters.proteins.v11.5.txt",
		        "sequence_path": "1538463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1538463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1538463.protein.info.v11.5.txt",
		        "node_list_path": "1538463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1538463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaPolyisoprenivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia polyisoprenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaPolyisoprenivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1112204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1112204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1112204.clusters.proteins.v11.5.txt",
		        "sequence_path": "1112204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112204.protein.info.v11.5.txt",
		        "node_list_path": "1112204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1112204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanosphaerulaPalustris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosphaerula palustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosphaerulaPalustris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521011.protein.sequences.v11.5.fa",
		        "enrichment_path": "521011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521011.protein.info.v11.5.txt",
		        "node_list_path": "521011.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesCoprosuisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides coprosuis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCoprosuisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679937.clusters.proteins.v11.5.txt",
		        "sequence_path": "679937.protein.sequences.v11.5.fa",
		        "enrichment_path": "679937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679937.protein.info.v11.5.txt",
		        "node_list_path": "679937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EdwardsiellaHoshinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Edwardsiella hoshinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EdwardsiellaHoshinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216966.protein.info.v11.5.txt",
		        "node_list_path": "1216966.protein.complete.v11.5.txt"
		    }
		]
    )()

def FormosaSpHel131208(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Formosa sp. Hel1_31_208 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaSpHel131208", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798225.protein.info.v11.5.txt",
		        "node_list_path": "1798225.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusPanaciterraeDsm19096Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus panaciterrae DSM 19096 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPanaciterraeDsm19096Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121093.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121093.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121093.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121093.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121093.protein.info.v11.5.txt",
		        "node_list_path": "1121093.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121093.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSpRoot635Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. Root635 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpRoot635Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736575.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736575.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736575.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736575.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736575.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736575.protein.info.v11.5.txt",
		        "node_list_path": "1736575.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736575.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumSg839(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium SG8_39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumSg839", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703390.protein.info.v11.5.txt",
		        "node_list_path": "1703390.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynergistesJonesiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synergistes jonesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynergistesJonesiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2754.clusters.proteins.v11.5.txt",
		        "sequence_path": "2754.protein.sequences.v11.5.fa",
		        "enrichment_path": "2754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2754.protein.info.v11.5.txt",
		        "node_list_path": "2754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusSp29Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus sp. 2.9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusSp29Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577051.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577051.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577051.protein.info.v11.5.txt",
		        "node_list_path": "1577051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophobacterFumaroxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophobacter fumaroxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophobacterFumaroxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "335543.clusters.info.v11.5.txt",
		        "cluster_tree_path": "335543.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "335543.clusters.proteins.v11.5.txt",
		        "sequence_path": "335543.protein.sequences.v11.5.fa",
		        "enrichment_path": "335543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335543.protein.info.v11.5.txt",
		        "node_list_path": "335543.cluster.nodes.v11.5.txt",
		        "edge_list_path": "335543.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterPsychrophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter psychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterPsychrophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "330734.protein.sequences.v11.5.fa",
		        "enrichment_path": "330734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "330734.protein.info.v11.5.txt",
		        "node_list_path": "330734.protein.complete.v11.5.txt"
		    }
		]
    )()

def SediminibacterSpHeli10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacter sp. HelI10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacterSpHeli10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392490.protein.info.v11.5.txt",
		        "node_list_path": "1392490.protein.complete.v11.5.txt"
		    }
		]
    )()

def PararhodobacterSpCcbMm2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pararhodobacter sp. CCB-MM2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PararhodobacterSpCcbMm2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1786003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1786003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1786003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1786003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1786003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1786003.protein.info.v11.5.txt",
		        "node_list_path": "1786003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1786003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PochoniaChlamydosporia170Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pochonia chlamydosporia 170 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PochoniaChlamydosporia170Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380566.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380566.protein.info.v11.5.txt",
		        "node_list_path": "1380566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpOlb3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. OLB3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpOlb3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617410.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617410.protein.info.v11.5.txt",
		        "node_list_path": "1617410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CucumisMeloVarMakuwaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cucumis melo var. makuwa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CucumisMeloVarMakuwaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1194695.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1194695.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1194695.clusters.proteins.v11.5.txt",
		        "sequence_path": "1194695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194695.protein.info.v11.5.txt",
		        "node_list_path": "1194695.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1194695.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PanPaniscus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pan paniscus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PanPaniscus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9597.protein.sequences.v11.5.fa",
		        "enrichment_path": "9597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9597.protein.info.v11.5.txt",
		        "node_list_path": "9597.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSpRim11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSpRim11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1100719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1100719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1100719.clusters.proteins.v11.5.txt",
		        "sequence_path": "1100719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1100719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1100719.protein.info.v11.5.txt",
		        "node_list_path": "1100719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1100719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasZhanjiangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas zhanjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasZhanjiangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "574966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "574966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "574966.clusters.proteins.v11.5.txt",
		        "sequence_path": "574966.protein.sequences.v11.5.fa",
		        "enrichment_path": "574966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574966.protein.info.v11.5.txt",
		        "node_list_path": "574966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "574966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaHaemolyticaBovine(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica BOVINE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaHaemolyticaBovine", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "669262.protein.sequences.v11.0.fa",
		        "enrichment_path": "669262.protein.enrichment.terms.v11.0.txt",
		        "info_path": "669262.protein.info.v11.0.txt",
		        "node_list_path": "669262.protein.complete.v11.0.txt"
		    }
		]
    )()

def BacteroidesReticulotermitisJcm10512Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides reticulotermitis JCM 10512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesReticulotermitisJcm10512Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1445607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1445607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1445607.clusters.proteins.v11.5.txt",
		        "sequence_path": "1445607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1445607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1445607.protein.info.v11.5.txt",
		        "node_list_path": "1445607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1445607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseomonasAerilata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas aerilata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseomonasAerilata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123060.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123060.protein.info.v11.5.txt",
		        "node_list_path": "1123060.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110056Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110056 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110056Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1570345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1570345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1570345.clusters.proteins.v11.5.txt",
		        "sequence_path": "1570345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570345.protein.info.v11.5.txt",
		        "node_list_path": "1570345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1570345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AggregatibacterActinomycetemcomitansRhaa1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans RhAA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterActinomycetemcomitansRhaa1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089447.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089447.protein.info.v11.5.txt",
		        "node_list_path": "1089447.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumGa0074137(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium Ga0074137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumGa0074137", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752195.protein.info.v11.5.txt",
		        "node_list_path": "1752195.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcticibacterSvalbardensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcticibacter svalbardensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcticibacterSvalbardensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150600.protein.info.v11.5.txt",
		        "node_list_path": "1150600.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanocorpusculumBavaricumDsm4179Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocorpusculum bavaricum DSM 4179 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocorpusculumBavaricumDsm4179Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122230.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122230.protein.info.v11.5.txt",
		        "node_list_path": "1122230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23623Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_36_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23623Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618480.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618480.protein.info.v11.5.txt",
		        "node_list_path": "1618480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacterium9403326(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9403326 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacterium9403326", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "938289.protein.sequences.v11.5.fa",
		        "enrichment_path": "938289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938289.protein.info.v11.5.txt",
		        "node_list_path": "938289.protein.complete.v11.5.txt"
		    }
		]
    )()

def RodentibacterRarus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter rarus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterRarus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1908260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908260.protein.info.v11.5.txt",
		        "node_list_path": "1908260.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusHominisC80(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus hominis C80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusHominisC80", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "435837.protein.sequences.v11.5.fa",
		        "enrichment_path": "435837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435837.protein.info.v11.5.txt",
		        "node_list_path": "435837.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaPerflavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria perflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaPerflavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33053.clusters.proteins.v11.5.txt",
		        "sequence_path": "33053.protein.sequences.v11.5.fa",
		        "enrichment_path": "33053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33053.protein.info.v11.5.txt",
		        "node_list_path": "33053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacterSpSw2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter sp. SW2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterSpSw2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "371731.protein.sequences.v11.5.fa",
		        "enrichment_path": "371731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "371731.protein.info.v11.5.txt",
		        "node_list_path": "371731.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaprolegniaDiclinaVs20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saprolegnia diclina VS20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaprolegniaDiclinaVs20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1156394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1156394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1156394.clusters.proteins.v11.5.txt",
		        "sequence_path": "1156394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156394.protein.info.v11.5.txt",
		        "node_list_path": "1156394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1156394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223545.protein.info.v11.5.txt",
		        "node_list_path": "1223545.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusMellifer(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mellifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMellifer", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218492.protein.info.v11.5.txt",
		        "node_list_path": "1218492.protein.complete.v11.5.txt"
		    }
		]
    )()

def EpibacteriumMobileF1926(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epibacterium mobile F1926 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpibacteriumMobileF1926", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265309.protein.info.v11.5.txt",
		        "node_list_path": "1265309.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229783.protein.info.v11.5.txt",
		        "node_list_path": "1229783.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumBrachy(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium brachy graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumBrachy", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321814.protein.info.v11.5.txt",
		        "node_list_path": "1321814.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeorhizobiumGalegaeBvOrientalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae bv. orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorhizobiumGalegaeBvOrientalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "323655.protein.sequences.v11.5.fa",
		        "enrichment_path": "323655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323655.protein.info.v11.5.txt",
		        "node_list_path": "323655.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpBtai1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. BTAi1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpBtai1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "288000.clusters.info.v11.5.txt",
		        "cluster_tree_path": "288000.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "288000.clusters.proteins.v11.5.txt",
		        "sequence_path": "288000.protein.sequences.v11.5.fa",
		        "enrichment_path": "288000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "288000.protein.info.v11.5.txt",
		        "node_list_path": "288000.cluster.nodes.v11.5.txt",
		        "edge_list_path": "288000.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumVulpinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium vulpinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumVulpinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29845.clusters.proteins.v11.5.txt",
		        "sequence_path": "29845.protein.sequences.v11.5.fa",
		        "enrichment_path": "29845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29845.protein.info.v11.5.txt",
		        "node_list_path": "29845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacterKorlensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter korlensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterKorlensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "400092.clusters.info.v11.5.txt",
		        "cluster_tree_path": "400092.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "400092.clusters.proteins.v11.5.txt",
		        "sequence_path": "400092.protein.sequences.v11.5.fa",
		        "enrichment_path": "400092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400092.protein.info.v11.5.txt",
		        "node_list_path": "400092.cluster.nodes.v11.5.txt",
		        "edge_list_path": "400092.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumAmorphae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium amorphae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumAmorphae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1082933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1082933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1082933.protein.info.v11.5.txt",
		        "node_list_path": "1082933.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpP22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpP22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "483908.protein.sequences.v11.5.fa",
		        "enrichment_path": "483908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483908.protein.info.v11.5.txt",
		        "node_list_path": "483908.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillochlorisTrichoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillochloris trichoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillochlorisTrichoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765420.protein.sequences.v11.5.fa",
		        "enrichment_path": "765420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765420.protein.info.v11.5.txt",
		        "node_list_path": "765420.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumRoquefortiFm164Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium roqueforti FM164 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumRoquefortiFm164Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1365484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1365484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1365484.clusters.proteins.v11.5.txt",
		        "sequence_path": "1365484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1365484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1365484.protein.info.v11.5.txt",
		        "node_list_path": "1365484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1365484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumFalciparum3d7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium falciparum 3D7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumFalciparum3d7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36329.protein.sequences.v11.5.fa",
		        "enrichment_path": "36329.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36329.protein.info.v11.5.txt",
		        "node_list_path": "36329.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraWolffiiSerovarKhoratStrKhoratH2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira wolffii serovar Khorat str. Khorat-H2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraWolffiiSerovarKhoratStrKhoratH2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193069.protein.info.v11.5.txt",
		        "node_list_path": "1193069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusHerbariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus herbarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusHerbariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120972.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120972.protein.info.v11.5.txt",
		        "node_list_path": "1120972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontStrainCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont strain Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontStrainCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "292805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "292805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "292805.clusters.proteins.v11.5.txt",
		        "sequence_path": "292805.protein.sequences.v11.5.fa",
		        "enrichment_path": "292805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292805.protein.info.v11.5.txt",
		        "node_list_path": "292805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "292805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasOleovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas oleovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasOleovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "301.clusters.proteins.v11.5.txt",
		        "sequence_path": "301.protein.sequences.v11.5.fa",
		        "enrichment_path": "301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "301.protein.info.v11.5.txt",
		        "node_list_path": "301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OpitutusSpGas368Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Opitutus sp. GAS368 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpitutusSpGas368Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882749.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882749.protein.info.v11.5.txt",
		        "node_list_path": "1882749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumGw2011Gwf24332Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium GW2011_GWF2_43_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumGw2011Gwf24332Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618643.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618643.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618643.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618643.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618643.protein.info.v11.5.txt",
		        "node_list_path": "1618643.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618643.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphaeroformaArcticaJp610(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphaeroforma arctica JP610 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaeroformaArcticaJp610", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "667725.protein.sequences.v11.5.fa",
		        "enrichment_path": "667725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667725.protein.info.v11.5.txt",
		        "node_list_path": "667725.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusLarvaeSubspLarvaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus larvae subsp. larvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusLarvaeSubspLarvaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "147375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "147375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "147375.clusters.proteins.v11.5.txt",
		        "sequence_path": "147375.protein.sequences.v11.5.fa",
		        "enrichment_path": "147375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "147375.protein.info.v11.5.txt",
		        "node_list_path": "147375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "147375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlesiocystisPacifica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plesiocystis pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlesiocystisPacifica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391625.protein.sequences.v11.5.fa",
		        "enrichment_path": "391625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391625.protein.info.v11.5.txt",
		        "node_list_path": "391625.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCf332Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. cf332 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCf332Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761804.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761804.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761804.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761804.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761804.protein.info.v11.5.txt",
		        "node_list_path": "1761804.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761804.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NothoproctaPerdicariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nothoprocta perdicaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NothoproctaPerdicariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "30464.clusters.info.v11.5.txt",
		        "cluster_tree_path": "30464.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "30464.clusters.proteins.v11.5.txt",
		        "sequence_path": "30464.protein.sequences.v11.5.fa",
		        "enrichment_path": "30464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30464.protein.info.v11.5.txt",
		        "node_list_path": "30464.cluster.nodes.v11.5.txt",
		        "edge_list_path": "30464.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpRifcsphigho212Full6519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. RIFCSPHIGHO2_12_FULL_65_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpRifcsphigho212Full6519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802172.protein.info.v11.5.txt",
		        "node_list_path": "1802172.protein.complete.v11.5.txt"
		    }
		]
    )()

def HumibacterAlbus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Humibacter albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HumibacterAlbus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121952.protein.info.v11.5.txt",
		        "node_list_path": "1121952.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParoeduraPictaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paroedura picta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParoeduraPictaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "143630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "143630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "143630.clusters.proteins.v11.5.txt",
		        "sequence_path": "143630.protein.sequences.v11.5.fa",
		        "enrichment_path": "143630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "143630.protein.info.v11.5.txt",
		        "node_list_path": "143630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "143630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OnionYellows(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Onion yellows graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OnionYellows", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262768.protein.sequences.v11.5.fa",
		        "enrichment_path": "262768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262768.protein.info.v11.5.txt",
		        "node_list_path": "262768.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatranaerobiusThermophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natranaerobius thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatranaerobiusThermophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "457570.protein.sequences.v11.5.fa",
		        "enrichment_path": "457570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457570.protein.info.v11.5.txt",
		        "node_list_path": "457570.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumSm2361Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium SM23_61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumSm2361Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703399.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703399.protein.info.v11.5.txt",
		        "node_list_path": "1703399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3918(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_39_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3918", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801771.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801771.protein.info.v11.5.txt",
		        "node_list_path": "1801771.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasCassavaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas cassavae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCassavaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219375.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219375.protein.info.v11.5.txt",
		        "node_list_path": "1219375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaprolegniaDiclinaVs20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saprolegnia diclina VS20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaprolegniaDiclinaVs20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1156394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156394.protein.info.v11.5.txt",
		        "node_list_path": "1156394.protein.complete.v11.5.txt"
		    }
		]
    )()

def TheileriaOrientalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Theileria orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheileriaOrientalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68886.protein.sequences.v11.5.fa",
		        "enrichment_path": "68886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68886.protein.info.v11.5.txt",
		        "node_list_path": "68886.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaBryophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia bryophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaBryophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1169143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169143.protein.info.v11.5.txt",
		        "node_list_path": "1169143.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasLeviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas levii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasLeviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122973.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122973.protein.info.v11.5.txt",
		        "node_list_path": "1122973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterorhabdusCaecimurisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterorhabdus caecimuris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterorhabdusCaecimurisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235794.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235794.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235794.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235794.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235794.protein.info.v11.5.txt",
		        "node_list_path": "1235794.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235794.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolibacillusSilvestrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solibacillus silvestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolibacillusSilvestrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1002809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1002809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1002809.clusters.proteins.v11.5.txt",
		        "sequence_path": "1002809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002809.protein.info.v11.5.txt",
		        "node_list_path": "1002809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1002809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpOralTaxon136(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpOralTaxon136", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "713030.protein.sequences.v11.5.fa",
		        "enrichment_path": "713030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713030.protein.info.v11.5.txt",
		        "node_list_path": "713030.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumAcnesHl037pa2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes HL037PA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumAcnesHl037pa2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765123.clusters.proteins.v11.5.txt",
		        "sequence_path": "765123.protein.sequences.v11.5.fa",
		        "enrichment_path": "765123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765123.protein.info.v11.5.txt",
		        "node_list_path": "765123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusNamurensisDsm19117Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus namurensis DSM 19117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusNamurensisDsm19117Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423773.protein.info.v11.5.txt",
		        "node_list_path": "1423773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterSpRm16704(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM16704 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSpRm16704", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500960.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500960.protein.info.v11.5.txt",
		        "node_list_path": "1500960.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpLeaf2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Leaf2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpLeaf2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735670.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735670.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735670.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735670.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735670.protein.info.v11.5.txt",
		        "node_list_path": "1735670.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735670.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSpg23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SPG23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSpg23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1610703.protein.sequences.v11.5.fa",
		        "enrichment_path": "1610703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1610703.protein.info.v11.5.txt",
		        "node_list_path": "1610703.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusWeihenstephanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus weihenstephanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusWeihenstephanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "315730.protein.sequences.v11.5.fa",
		        "enrichment_path": "315730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "315730.protein.info.v11.5.txt",
		        "node_list_path": "315730.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrametesPubescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trametes pubescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrametesPubescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "154538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "154538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "154538.clusters.proteins.v11.5.txt",
		        "sequence_path": "154538.protein.sequences.v11.5.fa",
		        "enrichment_path": "154538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "154538.protein.info.v11.5.txt",
		        "node_list_path": "154538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "154538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OxobacterPfennigii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oxobacter pfennigii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OxobacterPfennigii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36849.protein.sequences.v11.5.fa",
		        "enrichment_path": "36849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36849.protein.info.v11.5.txt",
		        "node_list_path": "36849.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumSpDsm25559Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. DSM 25559 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumSpDsm25559Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907666.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907666.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907666.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907666.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907666.protein.info.v11.5.txt",
		        "node_list_path": "1907666.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907666.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSaccharobutylicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium saccharobutylicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSaccharobutylicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1345695.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1345695.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1345695.clusters.proteins.v11.5.txt",
		        "sequence_path": "1345695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1345695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1345695.protein.info.v11.5.txt",
		        "node_list_path": "1345695.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1345695.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpM313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. m313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpM313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "406124.protein.sequences.v11.5.fa",
		        "enrichment_path": "406124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406124.protein.info.v11.5.txt",
		        "node_list_path": "406124.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumFabrum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium fabrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumFabrum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "176299.protein.sequences.v11.5.fa",
		        "enrichment_path": "176299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "176299.protein.info.v11.5.txt",
		        "node_list_path": "176299.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusEndobugulaSertula(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Endobugula sertula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusEndobugulaSertula", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "62101.protein.sequences.v11.5.fa",
		        "enrichment_path": "62101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62101.protein.info.v11.5.txt",
		        "node_list_path": "62101.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotogaLettingaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga lettingae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaLettingaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "416591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "416591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "416591.clusters.proteins.v11.5.txt",
		        "sequence_path": "416591.protein.sequences.v11.5.fa",
		        "enrichment_path": "416591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416591.protein.info.v11.5.txt",
		        "node_list_path": "416591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "416591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusSpTm1035Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius sp. TM1035 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusSpTm1035Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391613.clusters.proteins.v11.5.txt",
		        "sequence_path": "391613.protein.sequences.v11.5.fa",
		        "enrichment_path": "391613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391613.protein.info.v11.5.txt",
		        "node_list_path": "391613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaBelliiRml369cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia bellii RML369C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaBelliiRml369cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "336407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "336407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "336407.clusters.proteins.v11.5.txt",
		        "sequence_path": "336407.protein.sequences.v11.5.fa",
		        "enrichment_path": "336407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336407.protein.info.v11.5.txt",
		        "node_list_path": "336407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "336407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full5011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_50_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full5011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817828.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817828.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817828.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817828.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817828.protein.info.v11.5.txt",
		        "node_list_path": "1817828.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817828.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusContaminansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus contaminans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusContaminansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120971.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120971.protein.info.v11.5.txt",
		        "node_list_path": "1120971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusHaemoglobinophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemoglobinophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusHaemoglobinophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "733.protein.sequences.v11.5.fa",
		        "enrichment_path": "733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "733.protein.info.v11.5.txt",
		        "node_list_path": "733.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpOk665(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. OK665 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpOk665", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500305.protein.info.v11.5.txt",
		        "node_list_path": "1500305.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermocrispumAgresteDsm44070(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermocrispum agreste DSM 44070 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocrispumAgresteDsm44070", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111738.protein.info.v11.5.txt",
		        "node_list_path": "1111738.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionivibrioDicarboxylicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionivibrio dicarboxylicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionivibrioDicarboxylicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83767.clusters.proteins.v11.5.txt",
		        "sequence_path": "83767.protein.sequences.v11.5.fa",
		        "enrichment_path": "83767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83767.protein.info.v11.5.txt",
		        "node_list_path": "83767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChrysemysPicta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chrysemys picta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChrysemysPicta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8479.protein.sequences.v11.5.fa",
		        "enrichment_path": "8479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8479.protein.info.v11.5.txt",
		        "node_list_path": "8479.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacillusPsychrotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacillus psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacillusPsychrotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "126156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "126156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "126156.clusters.proteins.v11.5.txt",
		        "sequence_path": "126156.protein.sequences.v11.5.fa",
		        "enrichment_path": "126156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "126156.protein.info.v11.5.txt",
		        "node_list_path": "126156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "126156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumGordonaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium gordonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumGordonaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1778.clusters.proteins.v11.5.txt",
		        "sequence_path": "1778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1778.protein.info.v11.5.txt",
		        "node_list_path": "1778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFlavescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFlavescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29435.protein.sequences.v11.5.fa",
		        "enrichment_path": "29435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29435.protein.info.v11.5.txt",
		        "node_list_path": "29435.protein.complete.v11.5.txt"
		    }
		]
    )()

def SlackiaPiriformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Slackia piriformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SlackiaPiriformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742818.protein.sequences.v11.5.fa",
		        "enrichment_path": "742818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742818.protein.info.v11.5.txt",
		        "node_list_path": "742818.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusOryzaeRib40(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus oryzae RIB40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusOryzaeRib40", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "510516.protein.sequences.v11.5.fa",
		        "enrichment_path": "510516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "510516.protein.info.v11.5.txt",
		        "node_list_path": "510516.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaviaApereaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cavia aperea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaviaApereaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37548.clusters.proteins.v11.5.txt",
		        "sequence_path": "37548.protein.sequences.v11.5.fa",
		        "enrichment_path": "37548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37548.protein.info.v11.5.txt",
		        "node_list_path": "37548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp11000297(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1100029.7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp11000297", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834067.protein.info.v11.5.txt",
		        "node_list_path": "1834067.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusRapiDsm19907Jcm15042Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rapi DSM 19907 JCM 15042 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusRapiDsm19907Jcm15042Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423795.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423795.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423795.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423795.protein.info.v11.5.txt",
		        "node_list_path": "1423795.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423795.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesRubidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces rubidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRubidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "310780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "310780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "310780.clusters.proteins.v11.5.txt",
		        "sequence_path": "310780.protein.sequences.v11.5.fa",
		        "enrichment_path": "310780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "310780.protein.info.v11.5.txt",
		        "node_list_path": "310780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "310780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpOralTaxon126(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpOralTaxon126", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "712528.protein.sequences.v11.5.fa",
		        "enrichment_path": "712528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712528.protein.info.v11.5.txt",
		        "node_list_path": "712528.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWs6BacteriumRifoxyb1Full3315Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium RIFOXYB1_FULL_33_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWs6BacteriumRifoxyb1Full3315Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817897.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817897.protein.info.v11.5.txt",
		        "node_list_path": "1817897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFermentibacterDaniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fermentibacter daniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFermentibacterDaniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729713.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729713.protein.info.v11.5.txt",
		        "node_list_path": "1729713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaSimulansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila simulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaSimulansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7240.clusters.proteins.v11.5.txt",
		        "sequence_path": "7240.protein.sequences.v11.5.fa",
		        "enrichment_path": "7240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7240.protein.info.v11.5.txt",
		        "node_list_path": "7240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocorpusculumLabreanum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanocorpusculum labreanum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocorpusculumLabreanum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "410358.protein.sequences.v11.5.fa",
		        "enrichment_path": "410358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "410358.protein.info.v11.5.txt",
		        "node_list_path": "410358.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaeniclostridiumSordelliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paeniclostridium sordellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaeniclostridiumSordelliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1505.clusters.proteins.v11.5.txt",
		        "sequence_path": "1505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505.protein.info.v11.5.txt",
		        "node_list_path": "1505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrobacterPenzbergensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrobacter penzbergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrobacterPenzbergensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235997.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235997.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235997.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235997.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235997.protein.info.v11.5.txt",
		        "node_list_path": "1235997.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235997.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodomicrobiumUdaipurenseJa643(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodomicrobium udaipurense JA643 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodomicrobiumUdaipurenseJa643", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "858455.protein.sequences.v11.5.fa",
		        "enrichment_path": "858455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "858455.protein.info.v11.5.txt",
		        "node_list_path": "858455.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4516Fw969(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4516 (FW-969) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4516Fw969", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420910.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420910.protein.info.v11.5.txt",
		        "node_list_path": "1420910.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidomycesRichmondensisBfw(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidomyces richmondensis BFW graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidomycesRichmondensisBfw", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "766039.protein.sequences.v11.5.fa",
		        "enrichment_path": "766039.protein.enrichment.terms.v11.5.txt",
		        "info_path": "766039.protein.info.v11.5.txt",
		        "node_list_path": "766039.protein.complete.v11.5.txt"
		    }
		]
    )()

def DietziaSp111n121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dietzia sp. 111N12-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DietziaSp111n121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1785156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1785156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1785156.clusters.proteins.v11.5.txt",
		        "sequence_path": "1785156.protein.sequences.v11.5.fa",
		        "enrichment_path": "1785156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1785156.protein.info.v11.5.txt",
		        "node_list_path": "1785156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1785156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterMuridarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter muridarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterMuridarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216.clusters.proteins.v11.5.txt",
		        "sequence_path": "216.protein.sequences.v11.5.fa",
		        "enrichment_path": "216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216.protein.info.v11.5.txt",
		        "node_list_path": "216.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MillisiaBrevisNbrc105863Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Millisia brevis NBRC 105863 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MillisiaBrevisNbrc105863Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219361.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219361.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219361.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219361.protein.info.v11.5.txt",
		        "node_list_path": "1219361.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219361.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TenericutesBacteriumGwd23827(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWD2_38_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenericutesBacteriumGwd23827", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802348.protein.info.v11.5.txt",
		        "node_list_path": "1802348.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusFumarioliNbrc102428Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus fumarioli NBRC 102428 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusFumarioliNbrc102428Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314754.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314754.protein.info.v11.5.txt",
		        "node_list_path": "1314754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumLacusprofundiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum lacusprofundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumLacusprofundiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "416348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "416348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "416348.clusters.proteins.v11.5.txt",
		        "sequence_path": "416348.protein.sequences.v11.5.fa",
		        "enrichment_path": "416348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416348.protein.info.v11.5.txt",
		        "node_list_path": "416348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "416348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfomicrobiumOraleDsm12838(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium orale DSM 12838 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfomicrobiumOraleDsm12838", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888061.protein.sequences.v11.5.fa",
		        "enrichment_path": "888061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888061.protein.info.v11.5.txt",
		        "node_list_path": "888061.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag520Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:520 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag520Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262929.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262929.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262929.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262929.protein.info.v11.5.txt",
		        "node_list_path": "1262929.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262929.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrobacterSpNb311aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrobacter sp. Nb-311A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrobacterSpNb311aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314253.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314253.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314253.clusters.proteins.v11.5.txt",
		        "sequence_path": "314253.protein.sequences.v11.5.fa",
		        "enrichment_path": "314253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314253.protein.info.v11.5.txt",
		        "node_list_path": "314253.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314253.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassilioclostridiumColi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilioclostridium coli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassilioclostridiumColi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1870991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870991.protein.info.v11.5.txt",
		        "node_list_path": "1870991.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoemansiaReversaNrrl1564Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coemansia reversa NRRL 1564 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoemansiaReversaNrrl1564Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "763665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "763665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "763665.clusters.proteins.v11.5.txt",
		        "sequence_path": "763665.protein.sequences.v11.5.fa",
		        "enrichment_path": "763665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "763665.protein.info.v11.5.txt",
		        "node_list_path": "763665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "763665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphibacillusSediminisNbrc103570Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amphibacillus sediminis NBRC 103570 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphibacillusSediminisNbrc103570Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220586.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220586.protein.info.v11.5.txt",
		        "node_list_path": "1220586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AptenodytesForsteriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aptenodytes forsteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AptenodytesForsteriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9233.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9233.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9233.clusters.proteins.v11.5.txt",
		        "sequence_path": "9233.protein.sequences.v11.5.fa",
		        "enrichment_path": "9233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9233.protein.info.v11.5.txt",
		        "node_list_path": "9233.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9233.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterVulgaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterVulgaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "291985.protein.sequences.v11.5.fa",
		        "enrichment_path": "291985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "291985.protein.info.v11.5.txt",
		        "node_list_path": "291985.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumGas113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium GAS113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumGas113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884352.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884352.protein.info.v11.5.txt",
		        "node_list_path": "1884352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FructobacillusFiculneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fructobacillus ficulneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FructobacillusFiculneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "157463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "157463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "157463.clusters.proteins.v11.5.txt",
		        "sequence_path": "157463.protein.sequences.v11.5.fa",
		        "enrichment_path": "157463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157463.protein.info.v11.5.txt",
		        "node_list_path": "157463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "157463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacinutrixSp5h374(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix sp. 5H374 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixSp5h374", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983544.protein.sequences.v11.5.fa",
		        "enrichment_path": "983544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983544.protein.info.v11.5.txt",
		        "node_list_path": "983544.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumAntarcticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumAntarcticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1087448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1087448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1087448.protein.info.v11.5.txt",
		        "node_list_path": "1087448.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4217Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_42_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4217Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801780.protein.info.v11.5.txt",
		        "node_list_path": "1801780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag3212622Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:321_26_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag3212622Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897034.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897034.protein.info.v11.5.txt",
		        "node_list_path": "1897034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesTimonensisJc136Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes timonensis JC136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesTimonensisJc136Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033731.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033731.protein.info.v11.5.txt",
		        "node_list_path": "1033731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmatimonadetesBacterium13120cm46611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium 13_1_20CM_4_66_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonadetesBacterium13120cm46611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805172.protein.info.v11.5.txt",
		        "node_list_path": "1805172.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag1000Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag1000Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262768.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262768.protein.info.v11.5.txt",
		        "node_list_path": "1262768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpNkbg15041cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. NKBG15041c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpNkbg15041cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1407650.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1407650.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1407650.clusters.proteins.v11.5.txt",
		        "sequence_path": "1407650.protein.sequences.v11.5.fa",
		        "enrichment_path": "1407650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1407650.protein.info.v11.5.txt",
		        "node_list_path": "1407650.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1407650.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag449(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:449 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag449", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263023.protein.info.v11.5.txt",
		        "node_list_path": "1263023.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLeaf371Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf371 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLeaf371Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736355.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736355.protein.info.v11.5.txt",
		        "node_list_path": "1736355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeokomagataeaThailandicaNbrc106555(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neokomagataea thailandica NBRC 106555 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeokomagataeaThailandicaNbrc106555", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223520.protein.info.v11.5.txt",
		        "node_list_path": "1223520.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf23066Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_30_66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf23066Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619078.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619078.protein.info.v11.5.txt",
		        "node_list_path": "1619078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrypanosomaCruziStrainClBrenerCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma cruzi strain CL Brener Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrypanosomaCruziStrainClBrenerCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "353153.clusters.info.v11.5.txt",
		        "cluster_tree_path": "353153.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "353153.clusters.proteins.v11.5.txt",
		        "sequence_path": "353153.protein.sequences.v11.5.fa",
		        "enrichment_path": "353153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "353153.protein.info.v11.5.txt",
		        "node_list_path": "353153.cluster.nodes.v11.5.txt",
		        "edge_list_path": "353153.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MusMusculusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mus musculus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusMusculusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10090.clusters.proteins.v11.5.txt",
		        "sequence_path": "10090.protein.sequences.v11.5.fa",
		        "enrichment_path": "10090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10090.protein.info.v11.5.txt",
		        "node_list_path": "10090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporomusaSphaeroidesDsm2875Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporomusa sphaeroides DSM 2875 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporomusaSphaeroidesDsm2875Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1337886.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1337886.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1337886.clusters.proteins.v11.5.txt",
		        "sequence_path": "1337886.protein.sequences.v11.5.fa",
		        "enrichment_path": "1337886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1337886.protein.info.v11.5.txt",
		        "node_list_path": "1337886.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1337886.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaPersicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia persica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaPersicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1417230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1417230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1417230.clusters.proteins.v11.5.txt",
		        "sequence_path": "1417230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1417230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1417230.protein.info.v11.5.txt",
		        "node_list_path": "1417230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1417230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenopusLaevisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenopus laevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenopusLaevisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8355.clusters.proteins.v11.5.txt",
		        "sequence_path": "8355.protein.sequences.v11.5.fa",
		        "enrichment_path": "8355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8355.protein.info.v11.5.txt",
		        "node_list_path": "8355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseatelesDepolymerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseateles depolymerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseatelesDepolymerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "76731.protein.sequences.v11.5.fa",
		        "enrichment_path": "76731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76731.protein.info.v11.5.txt",
		        "node_list_path": "76731.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674851.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674851.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674851.protein.info.v11.5.txt",
		        "node_list_path": "1674851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerinusCanaria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serinus canaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerinusCanaria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9135.protein.sequences.v11.5.fa",
		        "enrichment_path": "9135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9135.protein.info.v11.5.txt",
		        "node_list_path": "9135.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag230Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:230 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag230Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262782.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262782.protein.info.v11.5.txt",
		        "node_list_path": "1262782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillaceaeBacteriumGas479Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillaceae bacterium GAS479 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillaceaeBacteriumGas479Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882832.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882832.protein.info.v11.5.txt",
		        "node_list_path": "1882832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusAlbusAd2013(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus albus AD2013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusAlbusAd2013", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1384065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384065.protein.info.v11.5.txt",
		        "node_list_path": "1384065.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusKribbensisDsm17871Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus kribbensis DSM 17871 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusKribbensisDsm17871Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121092.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121092.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121092.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121092.protein.info.v11.5.txt",
		        "node_list_path": "1121092.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121092.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FenollariaTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fenollaria timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FenollariaTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1723384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1723384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1723384.protein.info.v11.5.txt",
		        "node_list_path": "1723384.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGa0074134(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0074134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGa0074134", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752213.protein.info.v11.5.txt",
		        "node_list_path": "1752213.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumRifcsphigho202Full4613(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO2_02_FULL_46_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho202Full4613", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797220.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797220.protein.info.v11.5.txt",
		        "node_list_path": "1797220.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhormidiumAmbiguumIamM71Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phormidium ambiguum IAM M-71 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhormidiumAmbiguumIamM71Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "454136.clusters.info.v11.5.txt",
		        "cluster_tree_path": "454136.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "454136.clusters.proteins.v11.5.txt",
		        "sequence_path": "454136.protein.sequences.v11.5.fa",
		        "enrichment_path": "454136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454136.protein.info.v11.5.txt",
		        "node_list_path": "454136.cluster.nodes.v11.5.txt",
		        "edge_list_path": "454136.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaFaecisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseburia faecis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaFaecisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "301302.clusters.info.v11.5.txt",
		        "cluster_tree_path": "301302.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "301302.clusters.proteins.v11.5.txt",
		        "sequence_path": "301302.protein.sequences.v11.5.fa",
		        "enrichment_path": "301302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "301302.protein.info.v11.5.txt",
		        "node_list_path": "301302.cluster.nodes.v11.5.txt",
		        "edge_list_path": "301302.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhormidiumTenueNies30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phormidium tenue NIES-30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhormidiumTenueNies30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "549789.clusters.info.v11.5.txt",
		        "cluster_tree_path": "549789.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "549789.clusters.proteins.v11.5.txt",
		        "sequence_path": "549789.protein.sequences.v11.5.fa",
		        "enrichment_path": "549789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "549789.protein.info.v11.5.txt",
		        "node_list_path": "549789.cluster.nodes.v11.5.txt",
		        "edge_list_path": "549789.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaAustralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaAustralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1105110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1105110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1105110.clusters.proteins.v11.5.txt",
		        "sequence_path": "1105110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1105110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1105110.protein.info.v11.5.txt",
		        "node_list_path": "1105110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1105110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpP838Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. P838 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpP838Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1029823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1029823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1029823.clusters.proteins.v11.5.txt",
		        "sequence_path": "1029823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1029823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1029823.protein.info.v11.5.txt",
		        "node_list_path": "1029823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1029823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosospiraSpNl5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nl5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraSpNl5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "200120.clusters.info.v11.5.txt",
		        "cluster_tree_path": "200120.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "200120.clusters.proteins.v11.5.txt",
		        "sequence_path": "200120.protein.sequences.v11.5.fa",
		        "enrichment_path": "200120.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200120.protein.info.v11.5.txt",
		        "node_list_path": "200120.cluster.nodes.v11.5.txt",
		        "edge_list_path": "200120.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaBrasiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaBrasiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1133849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1133849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1133849.clusters.proteins.v11.5.txt",
		        "sequence_path": "1133849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1133849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1133849.protein.info.v11.5.txt",
		        "node_list_path": "1133849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1133849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IchthyophthiriusMultifiliisStrainG5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ichthyophthirius multifiliis strain G5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IchthyophthiriusMultifiliisStrainG5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "857967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "857967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "857967.clusters.proteins.v11.5.txt",
		        "sequence_path": "857967.protein.sequences.v11.5.fa",
		        "enrichment_path": "857967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857967.protein.info.v11.5.txt",
		        "node_list_path": "857967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "857967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaSpPsnih1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. PSNIH1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpPsnih1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1484158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484158.protein.info.v11.5.txt",
		        "node_list_path": "1484158.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpH103Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. H103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpH103Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761893.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761893.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761893.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761893.protein.info.v11.5.txt",
		        "node_list_path": "1761893.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761893.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaTobetsuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella tobetsuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaTobetsuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1110546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1110546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1110546.clusters.proteins.v11.5.txt",
		        "sequence_path": "1110546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1110546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1110546.protein.info.v11.5.txt",
		        "node_list_path": "1110546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1110546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24716Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_47_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24716Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618842.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618842.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618842.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618842.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618842.protein.info.v11.5.txt",
		        "node_list_path": "1618842.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618842.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonRbg136020Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_60_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg136020Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797380.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797380.protein.info.v11.5.txt",
		        "node_list_path": "1797380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumScindens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium scindens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumScindens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411468.protein.sequences.v11.5.fa",
		        "enrichment_path": "411468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411468.protein.info.v11.5.txt",
		        "node_list_path": "411468.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSalegensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas salegens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSalegensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434072.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434072.protein.info.v11.5.txt",
		        "node_list_path": "1434072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNd2006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium ND2006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNd2006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410628.protein.info.v11.5.txt",
		        "node_list_path": "1410628.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsphigho202Full4114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_02_FULL_41_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho202Full4114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797775.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797775.protein.info.v11.5.txt",
		        "node_list_path": "1797775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaQuinlivaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella quinlivanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaQuinlivaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45073.clusters.proteins.v11.5.txt",
		        "sequence_path": "45073.protein.sequences.v11.5.fa",
		        "enrichment_path": "45073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45073.protein.info.v11.5.txt",
		        "node_list_path": "45073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag533(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:533 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag533", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262818.protein.info.v11.5.txt",
		        "node_list_path": "1262818.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraMayottensis200901116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira mayottensis 200901116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraMayottensis200901116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1192864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1192864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1192864.clusters.proteins.v11.5.txt",
		        "sequence_path": "1192864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192864.protein.info.v11.5.txt",
		        "node_list_path": "1192864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1192864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTokpelaiaHoelldoblerii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tokpelaia hoelldoblerii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTokpelaiaHoelldoblerii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1902579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1902579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1902579.protein.info.v11.5.txt",
		        "node_list_path": "1902579.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaYamanashiensisNbrc100130(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia yamanashiensis NBRC 100130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaYamanashiensisNbrc100130", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210099.protein.info.v11.5.txt",
		        "node_list_path": "1210099.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerobutyricumHallii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobutyricum hallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobutyricumHallii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39488.protein.sequences.v11.5.fa",
		        "enrichment_path": "39488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39488.protein.info.v11.5.txt",
		        "node_list_path": "39488.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeeiaOryzaeDsm17879(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leeia oryzae DSM 17879 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeeiaOryzaeDsm17879", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122158.protein.info.v11.5.txt",
		        "node_list_path": "1122158.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusEdwardsbacteriaBacteriumGwe25412Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Edwardsbacteria bacterium GWE2_54_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusEdwardsbacteriaBacteriumGwe25412Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817850.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817850.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817850.protein.info.v11.5.txt",
		        "node_list_path": "1817850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesJenseniiJcm1364Nbrc14755(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides jensenii JCM 1364 NBRC 14755 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesJenseniiJcm1364Nbrc14755", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1303683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1303683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1303683.protein.info.v11.5.txt",
		        "node_list_path": "1303683.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusEquinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus equinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusEquinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525379.protein.sequences.v11.5.fa",
		        "enrichment_path": "525379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525379.protein.info.v11.5.txt",
		        "node_list_path": "525379.protein.complete.v11.5.txt"
		    }
		]
    )()

def OleiagrimonasSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oleiagrimonas soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OleiagrimonasSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1543381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1543381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1543381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1543381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1543381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1543381.protein.info.v11.5.txt",
		        "node_list_path": "1543381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1543381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusVersmoldensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus versmoldensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusVersmoldensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423815.protein.info.v11.5.txt",
		        "node_list_path": "1423815.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiothrixLacustrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix lacustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiothrixLacustrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123401.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123401.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123401.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123401.protein.info.v11.5.txt",
		        "node_list_path": "1123401.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123401.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AfipiaSp1nls2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. 1NLS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaSp1nls2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "666684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "666684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "666684.clusters.proteins.v11.5.txt",
		        "sequence_path": "666684.protein.sequences.v11.5.fa",
		        "enrichment_path": "666684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "666684.protein.info.v11.5.txt",
		        "node_list_path": "666684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "666684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterMustelae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter mustelae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterMustelae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679897.protein.sequences.v11.5.fa",
		        "enrichment_path": "679897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679897.protein.info.v11.5.txt",
		        "node_list_path": "679897.protein.complete.v11.5.txt"
		    }
		]
    )()

def CloacimonetesBacteriumScgcAaa252N14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium SCGC AAA252-N14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CloacimonetesBacteriumScgcAaa252N14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1046965.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046965.protein.info.v11.5.txt",
		        "node_list_path": "1046965.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasResinovoransNbrc106553(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas resinovorans NBRC106553 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasResinovoransNbrc106553", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1245471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245471.protein.info.v11.5.txt",
		        "node_list_path": "1245471.protein.complete.v11.5.txt"
		    }
		]
    )()

def KitasatosporaSpRoot187Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora sp. Root187 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaSpRoot187Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736486.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736486.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736486.protein.info.v11.5.txt",
		        "node_list_path": "1736486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerinusCanariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serinus canaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerinusCanariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9135.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9135.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9135.clusters.proteins.v11.5.txt",
		        "sequence_path": "9135.protein.sequences.v11.5.fa",
		        "enrichment_path": "9135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9135.protein.info.v11.5.txt",
		        "node_list_path": "9135.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9135.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgromycesFlavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agromyces flavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesFlavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "589382.protein.sequences.v11.5.fa",
		        "enrichment_path": "589382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "589382.protein.info.v11.5.txt",
		        "node_list_path": "589382.protein.complete.v11.5.txt"
		    }
		]
    )()

def HabropodaLaboriosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Habropoda laboriosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HabropodaLaboriosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "597456.clusters.info.v11.5.txt",
		        "cluster_tree_path": "597456.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "597456.clusters.proteins.v11.5.txt",
		        "sequence_path": "597456.protein.sequences.v11.5.fa",
		        "enrichment_path": "597456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "597456.protein.info.v11.5.txt",
		        "node_list_path": "597456.cluster.nodes.v11.5.txt",
		        "edge_list_path": "597456.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AvibacteriumParagallinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AvibacteriumParagallinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "728.protein.sequences.v11.5.fa",
		        "enrichment_path": "728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "728.protein.info.v11.5.txt",
		        "node_list_path": "728.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterBizzozeronii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterBizzozeronii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1002804.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002804.protein.info.v11.5.txt",
		        "node_list_path": "1002804.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaritimibacterSpRedseaS28B5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maritimibacter sp. REDSEA-S28_B5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaritimibacterSpRedseaS28B5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811547.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811547.protein.info.v11.5.txt",
		        "node_list_path": "1811547.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusFlavusNrrl3357Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus flavus NRRL3357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusFlavusNrrl3357Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "332952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "332952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "332952.clusters.proteins.v11.5.txt",
		        "sequence_path": "332952.protein.sequences.v11.5.fa",
		        "enrichment_path": "332952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332952.protein.info.v11.5.txt",
		        "node_list_path": "332952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "332952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBombi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bombi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBombi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1341695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341695.protein.info.v11.5.txt",
		        "node_list_path": "1341695.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumAvidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium avidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumAvidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1170318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1170318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1170318.protein.info.v11.5.txt",
		        "node_list_path": "1170318.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaSpHmsc072f04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC072F04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSpHmsc072f04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739348.protein.info.v11.5.txt",
		        "node_list_path": "1739348.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwc24211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_42_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc24211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797816.protein.info.v11.5.txt",
		        "node_list_path": "1797816.protein.complete.v11.5.txt"
		    }
		]
    )()

def TepidanaerobacterSpEbm38Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tepidanaerobacter sp. EBM-38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidanaerobacterSpEbm38Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1918496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1918496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1918496.clusters.proteins.v11.5.txt",
		        "sequence_path": "1918496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918496.protein.info.v11.5.txt",
		        "node_list_path": "1918496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1918496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzospirillumSp5120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum sp. 51_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumSp5120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896972.protein.info.v11.5.txt",
		        "node_list_path": "1896972.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpJa23ba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. JA23Ba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpJa23ba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321332.protein.sequences.v11.5.fa",
		        "enrichment_path": "321332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321332.protein.info.v11.5.txt",
		        "node_list_path": "321332.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterVariabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter variabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterVariabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "70346.protein.sequences.v11.5.fa",
		        "enrichment_path": "70346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "70346.protein.info.v11.5.txt",
		        "node_list_path": "70346.protein.complete.v11.5.txt"
		    }
		]
    )()

def FervidobacteriumGondwanenseDsm13020Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium gondwanense DSM 13020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidobacteriumGondwanenseDsm13020Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121883.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121883.protein.info.v11.5.txt",
		        "node_list_path": "1121883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSynechococcusSpongiarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Synechococcus spongiarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSynechococcusSpongiarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "431041.protein.sequences.v11.5.fa",
		        "enrichment_path": "431041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431041.protein.info.v11.5.txt",
		        "node_list_path": "431041.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaMeningitidisMc58(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria meningitidis MC58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaMeningitidisMc58", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "122586.protein.sequences.v11.5.fa",
		        "enrichment_path": "122586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "122586.protein.info.v11.5.txt",
		        "node_list_path": "122586.protein.complete.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsSpCamponotiLeonardi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps sp. camponoti-leonardi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsSpCamponotiLeonardi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2039875.protein.sequences.v11.5.fa",
		        "enrichment_path": "2039875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2039875.protein.info.v11.5.txt",
		        "node_list_path": "2039875.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndolissoclinumFaulkneriL5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Endolissoclinum faulkneri L5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndolissoclinumFaulkneriL5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1401328.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1401328.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1401328.clusters.proteins.v11.5.txt",
		        "sequence_path": "1401328.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401328.protein.info.v11.5.txt",
		        "node_list_path": "1401328.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1401328.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinocatenisporaSeraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinocatenispora sera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinocatenisporaSeraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "390989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "390989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "390989.clusters.proteins.v11.5.txt",
		        "sequence_path": "390989.protein.sequences.v11.5.fa",
		        "enrichment_path": "390989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390989.protein.info.v11.5.txt",
		        "node_list_path": "390989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "390989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumEtliCiat652Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli CIAT652 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumEtliCiat652Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "491916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "491916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "491916.clusters.proteins.v11.5.txt",
		        "sequence_path": "491916.protein.sequences.v11.5.fa",
		        "enrichment_path": "491916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "491916.protein.info.v11.5.txt",
		        "node_list_path": "491916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "491916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DermabacterSpHfh0086(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dermabacter sp. HFH0086 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DermabacterSpHfh0086", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203568.protein.info.v11.5.txt",
		        "node_list_path": "1203568.protein.complete.v11.5.txt"
		    }
		]
    )()

def RosaChinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rosa chinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RosaChinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "74649.clusters.info.v11.5.txt",
		        "cluster_tree_path": "74649.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "74649.clusters.proteins.v11.5.txt",
		        "sequence_path": "74649.protein.sequences.v11.5.fa",
		        "enrichment_path": "74649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74649.protein.info.v11.5.txt",
		        "node_list_path": "74649.cluster.nodes.v11.5.txt",
		        "edge_list_path": "74649.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaYuzhufengensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia yuzhufengensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaYuzhufengensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1164594.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1164594.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1164594.clusters.proteins.v11.5.txt",
		        "sequence_path": "1164594.protein.sequences.v11.5.fa",
		        "enrichment_path": "1164594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1164594.protein.info.v11.5.txt",
		        "node_list_path": "1164594.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1164594.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumPiscicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium piscicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumPiscicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "551459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "551459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "551459.clusters.proteins.v11.5.txt",
		        "sequence_path": "551459.protein.sequences.v11.5.fa",
		        "enrichment_path": "551459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551459.protein.info.v11.5.txt",
		        "node_list_path": "551459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "551459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OpisthorchisViverriniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Opisthorchis viverrini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpisthorchisViverriniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6198.clusters.proteins.v11.5.txt",
		        "sequence_path": "6198.protein.sequences.v11.5.fa",
		        "enrichment_path": "6198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6198.protein.info.v11.5.txt",
		        "node_list_path": "6198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusMaliNbrc102425Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus mali NBRC 102425 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusMaliNbrc102425Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314748.protein.info.v11.5.txt",
		        "node_list_path": "1314748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioGracilisDsm16080(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio gracilis DSM 16080 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioGracilisDsm16080", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121449.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121449.protein.info.v11.5.txt",
		        "node_list_path": "1121449.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpUrhe0023(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. URHE0023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpUrhe0023", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380354.protein.info.v11.5.txt",
		        "node_list_path": "1380354.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwf13410Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWF1_34_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwf13410Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618715.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618715.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618715.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618715.protein.info.v11.5.txt",
		        "node_list_path": "1618715.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618715.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHtcc2083Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HTCC2083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHtcc2083Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314270.clusters.proteins.v11.5.txt",
		        "sequence_path": "314270.protein.sequences.v11.5.fa",
		        "enrichment_path": "314270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314270.protein.info.v11.5.txt",
		        "node_list_path": "314270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusBarengoltziiG22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus barengoltzii G22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusBarengoltziiG22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235795.protein.info.v11.5.txt",
		        "node_list_path": "1235795.protein.complete.v11.5.txt"
		    }
		]
    )()

def OxalobacteraceaeBacteriumAb14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacteraceae bacterium AB_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OxalobacteraceaeBacteriumAb14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158293.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158293.protein.info.v11.5.txt",
		        "node_list_path": "1158293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EremococcusColeocolaAcs139vcol8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eremococcus coleocola ACS139VCol8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremococcusColeocolaAcs139vcol8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "908337.protein.sequences.v11.5.fa",
		        "enrichment_path": "908337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908337.protein.info.v11.5.txt",
		        "node_list_path": "908337.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE3198(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E3198 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE3198", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834143.protein.info.v11.5.txt",
		        "node_list_path": "1834143.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusFirmus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus firmus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusFirmus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1307436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307436.protein.info.v11.5.txt",
		        "node_list_path": "1307436.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasNaejangsanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas naejangsanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasNaejangsanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "588932.protein.sequences.v11.5.fa",
		        "enrichment_path": "588932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588932.protein.info.v11.5.txt",
		        "node_list_path": "588932.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag624Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:624 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag624Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262965.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262965.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262965.protein.info.v11.5.txt",
		        "node_list_path": "1262965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureispiraSpCcbqb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureispira sp. CCBQB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureispiraSpCcbqb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1313421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313421.protein.info.v11.5.txt",
		        "node_list_path": "1313421.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpJ33Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. J33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJ33Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935836.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935836.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935836.clusters.proteins.v11.5.txt",
		        "sequence_path": "935836.protein.sequences.v11.5.fa",
		        "enrichment_path": "935836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935836.protein.info.v11.5.txt",
		        "node_list_path": "935836.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935836.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaHoronobensisHb1Jcm15518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina horonobensis HB-1 JCM 15518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaHoronobensisHb1Jcm15518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434110.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434110.protein.info.v11.5.txt",
		        "node_list_path": "1434110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCurieaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus curieae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCurieaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1138822.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1138822.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1138822.clusters.proteins.v11.5.txt",
		        "sequence_path": "1138822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1138822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1138822.protein.info.v11.5.txt",
		        "node_list_path": "1138822.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1138822.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LinumUsitatissimumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Linum usitatissimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LinumUsitatissimumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4006.clusters.proteins.v11.5.txt",
		        "sequence_path": "4006.protein.sequences.v11.5.fa",
		        "enrichment_path": "4006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4006.protein.info.v11.5.txt",
		        "node_list_path": "4006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaProteobacteriumScgcAaa027K21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return beta proteobacterium SCGC AAA027-K21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaProteobacteriumScgcAaa027K21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "938785.protein.sequences.v11.5.fa",
		        "enrichment_path": "938785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938785.protein.info.v11.5.txt",
		        "node_list_path": "938785.protein.complete.v11.5.txt"
		    }
		]
    )()

def KribbellaCatacumbae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kribbella catacumbae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KribbellaCatacumbae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122138.protein.info.v11.5.txt",
		        "node_list_path": "1122138.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusBrevisNbrc100599(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus brevis NBRC100599 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusBrevisNbrc100599", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "358681.protein.sequences.v11.5.fa",
		        "enrichment_path": "358681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "358681.protein.info.v11.5.txt",
		        "node_list_path": "358681.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpS62Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. S-6-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpS62Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1931241.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1931241.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1931241.clusters.proteins.v11.5.txt",
		        "sequence_path": "1931241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1931241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1931241.protein.info.v11.5.txt",
		        "node_list_path": "1931241.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1931241.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyxococcusXanthusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus xanthus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcusXanthusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246197.clusters.proteins.v11.5.txt",
		        "sequence_path": "246197.protein.sequences.v11.5.fa",
		        "enrichment_path": "246197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246197.protein.info.v11.5.txt",
		        "node_list_path": "246197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpUnc496mf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNC496MF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpUnc496mf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502753.protein.info.v11.5.txt",
		        "node_list_path": "1502753.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusAureus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus aureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusAureus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280.protein.info.v11.5.txt",
		        "node_list_path": "1280.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterUrsingiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter ursingii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterUrsingiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "981336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "981336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "981336.clusters.proteins.v11.5.txt",
		        "sequence_path": "981336.protein.sequences.v11.5.fa",
		        "enrichment_path": "981336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981336.protein.info.v11.5.txt",
		        "node_list_path": "981336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "981336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_35_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618478.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618478.protein.info.v11.5.txt",
		        "node_list_path": "1618478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoturnixJaponica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coturnix japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoturnixJaponica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93934.protein.sequences.v11.5.fa",
		        "enrichment_path": "93934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93934.protein.info.v11.5.txt",
		        "node_list_path": "93934.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusFischeriNrrl181(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus fischeri NRRL 181 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusFischeriNrrl181", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "331117.protein.sequences.v11.5.fa",
		        "enrichment_path": "331117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331117.protein.info.v11.5.txt",
		        "node_list_path": "331117.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraAtramentaria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura atramentaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraAtramentaria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120936.protein.info.v11.5.txt",
		        "node_list_path": "1120936.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumHiranonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium hiranonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumHiranonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "500633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "500633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "500633.clusters.proteins.v11.5.txt",
		        "sequence_path": "500633.protein.sequences.v11.5.fa",
		        "enrichment_path": "500633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500633.protein.info.v11.5.txt",
		        "node_list_path": "500633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "500633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumSpBv1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum sp. BV1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumSpBv1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1498500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1498500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1498500.clusters.proteins.v11.5.txt",
		        "sequence_path": "1498500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1498500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1498500.protein.info.v11.5.txt",
		        "node_list_path": "1498500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1498500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorellaSorokiniana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorella sorokiniana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorellaSorokiniana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3076.protein.sequences.v11.5.fa",
		        "enrichment_path": "3076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3076.protein.info.v11.5.txt",
		        "node_list_path": "3076.protein.complete.v11.5.txt"
		    }
		]
    )()

def TheileriaOrientalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Theileria orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheileriaOrientalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68886.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68886.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68886.clusters.proteins.v11.5.txt",
		        "sequence_path": "68886.protein.sequences.v11.5.fa",
		        "enrichment_path": "68886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68886.protein.info.v11.5.txt",
		        "node_list_path": "68886.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68886.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PomaceaCanaliculataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pomacea canaliculata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PomaceaCanaliculataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "400727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "400727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "400727.clusters.proteins.v11.5.txt",
		        "sequence_path": "400727.protein.sequences.v11.5.fa",
		        "enrichment_path": "400727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400727.protein.info.v11.5.txt",
		        "node_list_path": "400727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "400727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VenturiaNashicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Venturia nashicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VenturiaNashicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86259.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86259.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86259.clusters.proteins.v11.5.txt",
		        "sequence_path": "86259.protein.sequences.v11.5.fa",
		        "enrichment_path": "86259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86259.protein.info.v11.5.txt",
		        "node_list_path": "86259.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86259.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumGwf24151Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_41_51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumGwf24151Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801957.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801957.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801957.protein.info.v11.5.txt",
		        "node_list_path": "1801957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasSpMwyl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. MWYL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasSpMwyl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "400668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "400668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "400668.clusters.proteins.v11.5.txt",
		        "sequence_path": "400668.protein.sequences.v11.5.fa",
		        "enrichment_path": "400668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400668.protein.info.v11.5.txt",
		        "node_list_path": "400668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "400668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpathiphylliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter spathiphylli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpathiphylliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1163407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1163407.clusters.proteins.v11.5.txt",
		        "sequence_path": "1163407.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163407.protein.info.v11.5.txt",
		        "node_list_path": "1163407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1163407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonomuraeaCoxensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea coxensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaCoxensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122611.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122611.protein.info.v11.5.txt",
		        "node_list_path": "1122611.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumLeptum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium leptum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumLeptum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "428125.protein.sequences.v11.5.fa",
		        "enrichment_path": "428125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428125.protein.info.v11.5.txt",
		        "node_list_path": "428125.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifoxyd2Full4114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD2_FULL_41_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd2Full4114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798709.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798709.protein.info.v11.5.txt",
		        "node_list_path": "1798709.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpCch5F6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. CCH5-F6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpCch5F6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1768753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768753.protein.info.v11.5.txt",
		        "node_list_path": "1768753.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloprofundusSedimenti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloprofundus sedimenti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloprofundusSedimenti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420851.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420851.protein.info.v11.5.txt",
		        "node_list_path": "1420851.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScalinduaBrodae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scalindua brodae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScalinduaBrodae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "237368.protein.sequences.v11.5.fa",
		        "enrichment_path": "237368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237368.protein.info.v11.5.txt",
		        "node_list_path": "237368.protein.complete.v11.5.txt"
		    }
		]
    )()

def WigglesworthiaGlossinidiaEndosymbiontOfGlossinaBrevipalpis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia endosymbiont of Glossina brevipalpis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WigglesworthiaGlossinidiaEndosymbiontOfGlossinaBrevipalpis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36870.protein.sequences.v11.5.fa",
		        "enrichment_path": "36870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36870.protein.info.v11.5.txt",
		        "node_list_path": "36870.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumRbg136212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_13_62_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg136212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797269.protein.info.v11.5.txt",
		        "node_list_path": "1797269.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollinsellaAerofaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collinsella aerofaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaAerofaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "74426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "74426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "74426.clusters.proteins.v11.5.txt",
		        "sequence_path": "74426.protein.sequences.v11.5.fa",
		        "enrichment_path": "74426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74426.protein.info.v11.5.txt",
		        "node_list_path": "74426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "74426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpHel185Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel185 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpHel185Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1250005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1250005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1250005.clusters.proteins.v11.5.txt",
		        "sequence_path": "1250005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250005.protein.info.v11.5.txt",
		        "node_list_path": "1250005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1250005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudozobelliaThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudozobellia thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudozobelliaThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "192903.protein.sequences.v11.5.fa",
		        "enrichment_path": "192903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192903.protein.info.v11.5.txt",
		        "node_list_path": "192903.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnhygromyxaSalinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enhygromyxa salina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnhygromyxaSalinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "215803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "215803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "215803.clusters.proteins.v11.5.txt",
		        "sequence_path": "215803.protein.sequences.v11.5.fa",
		        "enrichment_path": "215803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215803.protein.info.v11.5.txt",
		        "node_list_path": "215803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "215803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonadaceaeBacteriumUrha0028(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium URHA0028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonadaceaeBacteriumUrha0028", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298913.protein.info.v11.5.txt",
		        "node_list_path": "1298913.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryptobacteriumSpCag338Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptobacterium sp. CAG:338 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptobacteriumSpCag338Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262868.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262868.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262868.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262868.protein.info.v11.5.txt",
		        "node_list_path": "1262868.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262868.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumAestuarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumAestuarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1638982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638982.protein.info.v11.5.txt",
		        "node_list_path": "1638982.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosphaeraStadtmanae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosphaera stadtmanae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosphaeraStadtmanae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "339860.protein.sequences.v11.5.fa",
		        "enrichment_path": "339860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "339860.protein.info.v11.5.txt",
		        "node_list_path": "339860.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrabulsiellaOdontotermitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trabulsiella odontotermitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrabulsiellaOdontotermitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "379893.clusters.info.v11.5.txt",
		        "cluster_tree_path": "379893.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "379893.clusters.proteins.v11.5.txt",
		        "sequence_path": "379893.protein.sequences.v11.5.fa",
		        "enrichment_path": "379893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "379893.protein.info.v11.5.txt",
		        "node_list_path": "379893.cluster.nodes.v11.5.txt",
		        "edge_list_path": "379893.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterBizzozeroniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterBizzozeroniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1002804.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1002804.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1002804.clusters.proteins.v11.5.txt",
		        "sequence_path": "1002804.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002804.protein.info.v11.5.txt",
		        "node_list_path": "1002804.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1002804.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SclerotiniaBorealisF4128Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sclerotinia borealis F-4128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SclerotiniaBorealisF4128Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1432307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1432307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1432307.clusters.proteins.v11.5.txt",
		        "sequence_path": "1432307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432307.protein.info.v11.5.txt",
		        "node_list_path": "1432307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1432307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasSpMed121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. MED121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasSpMed121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314277.clusters.proteins.v11.5.txt",
		        "sequence_path": "314277.protein.sequences.v11.5.fa",
		        "enrichment_path": "314277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314277.protein.info.v11.5.txt",
		        "node_list_path": "314277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusHomomorphusCbs101889(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus homomorphus CBS 101889 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusHomomorphusCbs101889", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1450537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450537.protein.info.v11.5.txt",
		        "node_list_path": "1450537.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumRifoxyb1Full4423Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFOXYB1_FULL_44_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifoxyb1Full4423Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797263.protein.info.v11.5.txt",
		        "node_list_path": "1797263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrenarchaeotaArchaeon13140cm35210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_52_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenarchaeotaArchaeon13140cm35210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805095.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805095.protein.info.v11.5.txt",
		        "node_list_path": "1805095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArmatimonadetesBacterium13140cm6414(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium 13_1_40CM_64_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmatimonadetesBacterium13140cm6414", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805026.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805026.protein.info.v11.5.txt",
		        "node_list_path": "1805026.protein.complete.v11.5.txt"
		    }
		]
    )()

def MobilibacteriumTimonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobilibacterium timonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobilibacteriumTimonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871012.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871012.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871012.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871012.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871012.protein.info.v11.5.txt",
		        "node_list_path": "1871012.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871012.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloplanusVescusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloplanus vescus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloplanusVescusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "555874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "555874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "555874.clusters.proteins.v11.5.txt",
		        "sequence_path": "555874.protein.sequences.v11.5.fa",
		        "enrichment_path": "555874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555874.protein.info.v11.5.txt",
		        "node_list_path": "555874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "555874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSclerotialusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sclerotialus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSclerotialusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1957.clusters.proteins.v11.5.txt",
		        "sequence_path": "1957.protein.sequences.v11.5.fa",
		        "enrichment_path": "1957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1957.protein.info.v11.5.txt",
		        "node_list_path": "1957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaSpCag380(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:380 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSpCag380", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262946.protein.info.v11.5.txt",
		        "node_list_path": "1262946.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterAntibioticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter antibioticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterAntibioticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84531.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84531.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84531.clusters.proteins.v11.5.txt",
		        "sequence_path": "84531.protein.sequences.v11.5.fa",
		        "enrichment_path": "84531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84531.protein.info.v11.5.txt",
		        "node_list_path": "84531.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84531.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrombidiumDeliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrombidium deliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrombidiumDeliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "299467.protein.sequences.v11.5.fa",
		        "enrichment_path": "299467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299467.protein.info.v11.5.txt",
		        "node_list_path": "299467.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenovibrioSpMa26(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenovibrio sp. MA2-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenovibrioSpMa26", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449087.protein.info.v11.5.txt",
		        "node_list_path": "1449087.protein.complete.v11.5.txt"
		    }
		]
    )()

def JannaschiaFaecimarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia faecimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaFaecimarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1244108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1244108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1244108.clusters.proteins.v11.5.txt",
		        "sequence_path": "1244108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1244108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1244108.protein.info.v11.5.txt",
		        "node_list_path": "1244108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1244108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesIndistinctusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes indistinctus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesIndistinctusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742725.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742725.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742725.clusters.proteins.v11.5.txt",
		        "sequence_path": "742725.protein.sequences.v11.5.fa",
		        "enrichment_path": "742725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742725.protein.info.v11.5.txt",
		        "node_list_path": "742725.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742725.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSuis865192Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis 865192 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSuis865192Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1214166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1214166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1214166.clusters.proteins.v11.5.txt",
		        "sequence_path": "1214166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214166.protein.info.v11.5.txt",
		        "node_list_path": "1214166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1214166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlossinaPalpalisGambiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glossina palpalis gambiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlossinaPalpalisGambiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67801.protein.sequences.v11.5.fa",
		        "enrichment_path": "67801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67801.protein.info.v11.5.txt",
		        "node_list_path": "67801.protein.complete.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterEpoxidivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter epoxidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterEpoxidivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "361183.clusters.info.v11.5.txt",
		        "cluster_tree_path": "361183.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "361183.clusters.proteins.v11.5.txt",
		        "sequence_path": "361183.protein.sequences.v11.5.fa",
		        "enrichment_path": "361183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "361183.protein.info.v11.5.txt",
		        "node_list_path": "361183.cluster.nodes.v11.5.txt",
		        "edge_list_path": "361183.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioCarbinoliphilusSubspOakridgensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio carbinoliphilus subsp. oakridgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioCarbinoliphilusSubspOakridgensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "694327.protein.sequences.v11.5.fa",
		        "enrichment_path": "694327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694327.protein.info.v11.5.txt",
		        "node_list_path": "694327.protein.complete.v11.5.txt"
		    }
		]
    )()

def NaumovozymaCastelliiCbs4309(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma castellii CBS 4309 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NaumovozymaCastelliiCbs4309", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1064592.protein.sequences.v11.5.fa",
		        "enrichment_path": "1064592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1064592.protein.info.v11.5.txt",
		        "node_list_path": "1064592.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumRifoxyd12Full368Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYD12_FULL_36_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyd12Full368Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798454.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798454.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798454.protein.info.v11.5.txt",
		        "node_list_path": "1798454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RaphidiopsisBrookiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Raphidiopsis brookii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RaphidiopsisBrookiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "533247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "533247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "533247.clusters.proteins.v11.5.txt",
		        "sequence_path": "533247.protein.sequences.v11.5.fa",
		        "enrichment_path": "533247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "533247.protein.info.v11.5.txt",
		        "node_list_path": "533247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "533247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium filum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121889.protein.info.v11.5.txt",
		        "node_list_path": "1121889.protein.complete.v11.5.txt"
		    }
		]
    )()

def OdoribacterLaneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Odoribacter laneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OdoribacterLaneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742817.protein.sequences.v11.5.fa",
		        "enrichment_path": "742817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742817.protein.info.v11.5.txt",
		        "node_list_path": "742817.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSpLeaf41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpLeaf41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736218.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736218.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736218.protein.info.v11.5.txt",
		        "node_list_path": "1736218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKalixensisDsm16043Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kalixensis DSM 16043 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKalixensisDsm16043Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423763.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423763.protein.info.v11.5.txt",
		        "node_list_path": "1423763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumAap38Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium AAP38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumAap38Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523418.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523418.protein.info.v11.5.txt",
		        "node_list_path": "1523418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpAgr2160(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. AGR2160 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpAgr2160", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280674.protein.info.v11.5.txt",
		        "node_list_path": "1280674.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanobacteriumStanieri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanobacterium stanieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobacteriumStanieri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "292563.protein.sequences.v11.5.fa",
		        "enrichment_path": "292563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292563.protein.info.v11.5.txt",
		        "node_list_path": "292563.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiocapsaRoseopersicinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiocapsa roseopersicina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiocapsaRoseopersicinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1058.clusters.proteins.v11.5.txt",
		        "sequence_path": "1058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1058.protein.info.v11.5.txt",
		        "node_list_path": "1058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JeotgalibacaSpPts2502(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalibaca sp. PTS2502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalibacaSpPts2502", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1903686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903686.protein.info.v11.5.txt",
		        "node_list_path": "1903686.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaMonacensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia monacensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaMonacensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "109232.protein.sequences.v11.5.fa",
		        "enrichment_path": "109232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109232.protein.info.v11.5.txt",
		        "node_list_path": "109232.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoalloteichusSpGba12924(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoalloteichus sp. GBA129-24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoalloteichusSpGba12924", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1612551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1612551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1612551.protein.info.v11.5.txt",
		        "node_list_path": "1612551.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolanumLycopersicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solanum lycopersicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolanumLycopersicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4081.protein.sequences.v11.5.fa",
		        "enrichment_path": "4081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4081.protein.info.v11.5.txt",
		        "node_list_path": "4081.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpCag988Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. CAG:988 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpCag988Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262708.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262708.protein.info.v11.5.txt",
		        "node_list_path": "1262708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GluconobacterFrateurii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter frateurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterFrateurii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1307834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307834.protein.info.v11.5.txt",
		        "node_list_path": "1307834.protein.complete.v11.5.txt"
		    }
		]
    )()

def KlebsiellaOxytocaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella oxytoca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaOxytocaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "571.clusters.proteins.v11.5.txt",
		        "sequence_path": "571.protein.sequences.v11.5.fa",
		        "enrichment_path": "571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571.protein.info.v11.5.txt",
		        "node_list_path": "571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospinaSpScgcAaa288L16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospina sp. SCGC AAA288-L16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospinaSpScgcAaa288L16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "913337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "913337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "913337.clusters.proteins.v11.5.txt",
		        "sequence_path": "913337.protein.sequences.v11.5.fa",
		        "enrichment_path": "913337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913337.protein.info.v11.5.txt",
		        "node_list_path": "913337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "913337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusOrisrattiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus orisratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOrisrattiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123311.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123311.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123311.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123311.protein.info.v11.5.txt",
		        "node_list_path": "1123311.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123311.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacterium13140cm2607Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_1_40CM_2_60_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacterium13140cm2607Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803443.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803443.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803443.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803443.protein.info.v11.5.txt",
		        "node_list_path": "1803443.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803443.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumGrahamiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium grahamii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumGrahamiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "990285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "990285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "990285.clusters.proteins.v11.5.txt",
		        "sequence_path": "990285.protein.sequences.v11.5.fa",
		        "enrichment_path": "990285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990285.protein.info.v11.5.txt",
		        "node_list_path": "990285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "990285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubrivivaxSpScn71131Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubrivivax sp. SCN 71-131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrivivaxSpScn71131Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660138.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660138.protein.info.v11.5.txt",
		        "node_list_path": "1660138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PasteurellaBettyae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella bettyae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaBettyae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095749.protein.info.v11.5.txt",
		        "node_list_path": "1095749.protein.complete.v11.5.txt"
		    }
		]
    )()

def SimkaniaNegevensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Simkania negevensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SimkaniaNegevensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "331113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "331113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "331113.clusters.proteins.v11.5.txt",
		        "sequence_path": "331113.protein.sequences.v11.5.fa",
		        "enrichment_path": "331113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331113.protein.info.v11.5.txt",
		        "node_list_path": "331113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "331113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalarsenatibacterSilvermaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halarsenatibacter silvermanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalarsenatibacterSilvermaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "321763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "321763.clusters.proteins.v11.5.txt",
		        "sequence_path": "321763.protein.sequences.v11.5.fa",
		        "enrichment_path": "321763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321763.protein.info.v11.5.txt",
		        "node_list_path": "321763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "321763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HeterobasidionIrregulareTc321(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Heterobasidion irregulare TC 32-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeterobasidionIrregulareTc321", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "747525.protein.sequences.v11.5.fa",
		        "enrichment_path": "747525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747525.protein.info.v11.5.txt",
		        "node_list_path": "747525.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarininemaMesophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marininema mesophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarininemaMesophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1048340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1048340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1048340.clusters.proteins.v11.5.txt",
		        "sequence_path": "1048340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048340.protein.info.v11.5.txt",
		        "node_list_path": "1048340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1048340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaPsittaci10139811(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia psittaci 10139811 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaPsittaci10139811", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1238237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238237.protein.info.v11.5.txt",
		        "node_list_path": "1238237.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4717Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_47_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4717Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802143.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802143.protein.info.v11.5.txt",
		        "node_list_path": "1802143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_40_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618814.protein.info.v11.5.txt",
		        "node_list_path": "1618814.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf236131(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_36_131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf236131", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619081.protein.info.v11.5.txt",
		        "node_list_path": "1619081.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpAb215Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB215 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpAb215Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841861.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841861.protein.info.v11.5.txt",
		        "node_list_path": "1841861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AphanomycesAstaci(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aphanomyces astaci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AphanomycesAstaci", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "112090.protein.sequences.v11.5.fa",
		        "enrichment_path": "112090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112090.protein.info.v11.5.txt",
		        "node_list_path": "112090.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidaminococcusSpCag917Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidaminococcus sp. CAG:917 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminococcusSpCag917Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262688.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262688.protein.info.v11.5.txt",
		        "node_list_path": "1262688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumNuruki(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium nuruki graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumNuruki", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "863239.protein.sequences.v11.5.fa",
		        "enrichment_path": "863239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "863239.protein.info.v11.5.txt",
		        "node_list_path": "863239.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumOlb16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium OLB16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumOlb16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617433.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617433.protein.info.v11.5.txt",
		        "node_list_path": "1617433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubellimicrobiumThermophilumDsm16684Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubellimicrobium thermophilum DSM 16684 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubellimicrobiumThermophilumDsm16684Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123069.protein.info.v11.5.txt",
		        "node_list_path": "1123069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShinellaSpGws1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shinella sp. GWS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShinellaSpGws1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1692240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1692240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1692240.protein.info.v11.5.txt",
		        "node_list_path": "1692240.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumUkl132Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium UKL13-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumUkl132Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1690485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1690485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1690485.clusters.proteins.v11.5.txt",
		        "sequence_path": "1690485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690485.protein.info.v11.5.txt",
		        "node_list_path": "1690485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1690485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OreniaMetallireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Orenia metallireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OreniaMetallireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1413210.protein.sequences.v11.5.fa",
		        "enrichment_path": "1413210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1413210.protein.info.v11.5.txt",
		        "node_list_path": "1413210.protein.complete.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaSgCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Sg Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaSgCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "198804.clusters.info.v11.5.txt",
		        "cluster_tree_path": "198804.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "198804.clusters.proteins.v11.5.txt",
		        "sequence_path": "198804.protein.sequences.v11.5.fa",
		        "enrichment_path": "198804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198804.protein.info.v11.5.txt",
		        "node_list_path": "198804.cluster.nodes.v11.5.txt",
		        "edge_list_path": "198804.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpLeaf191Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf191 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpLeaf191Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736296.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736296.protein.info.v11.5.txt",
		        "node_list_path": "1736296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaWadsworthii9715(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria wadsworthii 9715 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaWadsworthii9715", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1030841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1030841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1030841.protein.info.v11.5.txt",
		        "node_list_path": "1030841.protein.complete.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "261317.protein.sequences.v11.5.fa",
		        "enrichment_path": "261317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "261317.protein.info.v11.5.txt",
		        "node_list_path": "261317.protein.complete.v11.5.txt"
		    }
		]
    )()

def RasamsoniaEmersoniiCbs39364(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rasamsonia emersonii CBS 393.64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RasamsoniaEmersoniiCbs39364", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408163.protein.info.v11.5.txt",
		        "node_list_path": "1408163.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslh7689(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH7689 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslh7689", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227349.protein.info.v11.5.txt",
		        "node_list_path": "1227349.protein.complete.v11.5.txt"
		    }
		]
    )()

def LodderomycesElongisporus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lodderomyces elongisporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LodderomycesElongisporus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36914.protein.sequences.v11.5.fa",
		        "enrichment_path": "36914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36914.protein.info.v11.5.txt",
		        "node_list_path": "36914.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichodermaReeseiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma reesei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaReeseiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "51453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "51453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "51453.clusters.proteins.v11.5.txt",
		        "sequence_path": "51453.protein.sequences.v11.5.fa",
		        "enrichment_path": "51453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51453.protein.info.v11.5.txt",
		        "node_list_path": "51453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "51453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaHumi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaHumi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "745366.protein.sequences.v11.5.fa",
		        "enrichment_path": "745366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745366.protein.info.v11.5.txt",
		        "node_list_path": "745366.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinicoccusCarnicancri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus carnicancri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusCarnicancri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235755.protein.info.v11.5.txt",
		        "node_list_path": "1235755.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteibacterRhizovicinusDsm16549Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter rhizovicinus DSM 16549 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterRhizovicinusDsm16549Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1440763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1440763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1440763.clusters.proteins.v11.5.txt",
		        "sequence_path": "1440763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1440763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1440763.protein.info.v11.5.txt",
		        "node_list_path": "1440763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1440763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumA2Kyoto(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum A2 Kyoto graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumA2Kyoto", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "536232.protein.sequences.v11.5.fa",
		        "enrichment_path": "536232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "536232.protein.info.v11.5.txt",
		        "node_list_path": "536232.protein.complete.v11.5.txt"
		    }
		]
    )()

def CytosporaLeucostomaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cytospora leucostoma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CytosporaLeucostomaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230097.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230097.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230097.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230097.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230097.protein.info.v11.5.txt",
		        "node_list_path": "1230097.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230097.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasEndophyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas endophytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasEndophyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1563157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1563157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1563157.clusters.proteins.v11.5.txt",
		        "sequence_path": "1563157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1563157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1563157.protein.info.v11.5.txt",
		        "node_list_path": "1563157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1563157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaSp513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sp. 5.13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaSp513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1929465.protein.sequences.v11.5.fa",
		        "enrichment_path": "1929465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1929465.protein.info.v11.5.txt",
		        "node_list_path": "1929465.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrucellaAbortus2308(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brucella abortus 2308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrucellaAbortus2308", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "359391.protein.sequences.v11.5.fa",
		        "enrichment_path": "359391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "359391.protein.info.v11.5.txt",
		        "node_list_path": "359391.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusBuchneriAtcc11577Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri ATCC11577 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBuchneriAtcc11577Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525318.clusters.proteins.v11.5.txt",
		        "sequence_path": "525318.protein.sequences.v11.5.fa",
		        "enrichment_path": "525318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525318.protein.info.v11.5.txt",
		        "node_list_path": "525318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1659199.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659199.protein.info.v11.5.txt",
		        "node_list_path": "1659199.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumChlorophenolicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium chlorophenolicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumChlorophenolicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37916.protein.sequences.v11.5.fa",
		        "enrichment_path": "37916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37916.protein.info.v11.5.txt",
		        "node_list_path": "37916.protein.complete.v11.5.txt"
		    }
		]
    )()

def XylanimonasCellulosilyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylanimonas cellulosilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylanimonasCellulosilyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "446471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "446471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "446471.clusters.proteins.v11.5.txt",
		        "sequence_path": "446471.protein.sequences.v11.5.fa",
		        "enrichment_path": "446471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446471.protein.info.v11.5.txt",
		        "node_list_path": "446471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "446471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaminibacterMediatlanticusTb2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caminibacter mediatlanticus TB-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaminibacterMediatlanticusTb2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391592.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391592.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391592.clusters.proteins.v11.5.txt",
		        "sequence_path": "391592.protein.sequences.v11.5.fa",
		        "enrichment_path": "391592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391592.protein.info.v11.5.txt",
		        "node_list_path": "391592.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391592.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrococcusBaldri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrococcus baldri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrococcusBaldri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "153730.protein.sequences.v11.5.fa",
		        "enrichment_path": "153730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "153730.protein.info.v11.5.txt",
		        "node_list_path": "153730.protein.complete.v11.5.txt"
		    }
		]
    )()

def CronobacterDublinensisSubspLausannensisLmg23824Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. lausannensis LMG 23824 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CronobacterDublinensisSubspLausannensisLmg23824Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1159560.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1159560.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1159560.clusters.proteins.v11.5.txt",
		        "sequence_path": "1159560.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159560.protein.info.v11.5.txt",
		        "node_list_path": "1159560.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1159560.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudacidovoraxIntermedius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudacidovorax intermedius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudacidovoraxIntermedius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "433924.protein.sequences.v11.5.fa",
		        "enrichment_path": "433924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "433924.protein.info.v11.5.txt",
		        "node_list_path": "433924.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacteriumSalinarumNrc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium salinarum NRC-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacteriumSalinarumNrc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "64091.protein.sequences.v11.5.fa",
		        "enrichment_path": "64091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64091.protein.info.v11.5.txt",
		        "node_list_path": "64091.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5620(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_56_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5620", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798652.protein.info.v11.5.txt",
		        "node_list_path": "1798652.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalococcoidesMccartyi195Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi 195 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalococcoidesMccartyi195Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243164.clusters.proteins.v11.5.txt",
		        "sequence_path": "243164.protein.sequences.v11.5.fa",
		        "enrichment_path": "243164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243164.protein.info.v11.5.txt",
		        "node_list_path": "243164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinivirgaCyanobacteriivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinivirga cyanobacteriivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivirgaCyanobacteriivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1307839.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307839.protein.info.v11.5.txt",
		        "node_list_path": "1307839.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgromycesSpNdb4y10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agromyces sp. NDB4Y10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesSpNdb4y10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1775951.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1775951.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1775951.clusters.proteins.v11.5.txt",
		        "sequence_path": "1775951.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775951.protein.info.v11.5.txt",
		        "node_list_path": "1775951.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1775951.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PopulusAlba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Populus alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PopulusAlba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43335.protein.sequences.v11.5.fa",
		        "enrichment_path": "43335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43335.protein.info.v11.5.txt",
		        "node_list_path": "43335.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporolactobacillusNakayamae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus nakayamae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolactobacillusNakayamae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "269670.protein.sequences.v11.5.fa",
		        "enrichment_path": "269670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269670.protein.info.v11.5.txt",
		        "node_list_path": "269670.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpIP16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. I-P16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpIP16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1156433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156433.protein.info.v11.5.txt",
		        "node_list_path": "1156433.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumSpGw103(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. GW103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumSpGw103", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1175306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1175306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1175306.protein.info.v11.5.txt",
		        "node_list_path": "1175306.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimihaloglobusSulfuriphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limihaloglobus sulfuriphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimihaloglobusSulfuriphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1851148.protein.sequences.v11.5.fa",
		        "enrichment_path": "1851148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1851148.protein.info.v11.5.txt",
		        "node_list_path": "1851148.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalobacterSpFth1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dehalobacter sp. FTH1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalobacterSpFth1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035308.protein.info.v11.5.txt",
		        "node_list_path": "1035308.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaPiezotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella piezotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaPiezotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "225849.protein.sequences.v11.5.fa",
		        "enrichment_path": "225849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225849.protein.info.v11.5.txt",
		        "node_list_path": "225849.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAgglomeratusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces agglomeratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAgglomeratusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "285458.clusters.info.v11.5.txt",
		        "cluster_tree_path": "285458.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "285458.clusters.proteins.v11.5.txt",
		        "sequence_path": "285458.protein.sequences.v11.5.fa",
		        "enrichment_path": "285458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285458.protein.info.v11.5.txt",
		        "node_list_path": "285458.cluster.nodes.v11.5.txt",
		        "edge_list_path": "285458.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrenotaleaThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crenotalea thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenotaleaThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1393122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1393122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1393122.clusters.proteins.v11.5.txt",
		        "sequence_path": "1393122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1393122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1393122.protein.info.v11.5.txt",
		        "node_list_path": "1393122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1393122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasLipolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas lipolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasLipolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "570156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "570156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "570156.clusters.proteins.v11.5.txt",
		        "sequence_path": "570156.protein.sequences.v11.5.fa",
		        "enrichment_path": "570156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570156.protein.info.v11.5.txt",
		        "node_list_path": "570156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "570156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoorellaGlycerini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moorella glycerini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoorellaGlycerini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "55779.protein.sequences.v11.5.fa",
		        "enrichment_path": "55779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55779.protein.info.v11.5.txt",
		        "node_list_path": "55779.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaClarridgeiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella clarridgeiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaClarridgeiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "696125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "696125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "696125.clusters.proteins.v11.5.txt",
		        "sequence_path": "696125.protein.sequences.v11.5.fa",
		        "enrichment_path": "696125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696125.protein.info.v11.5.txt",
		        "node_list_path": "696125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "696125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaStewartiiSubspStewartiiDc283(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea stewartii subsp. stewartii DC283 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaStewartiiSubspStewartiiDc283", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "660596.protein.sequences.v11.5.fa",
		        "enrichment_path": "660596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660596.protein.info.v11.5.txt",
		        "node_list_path": "660596.protein.complete.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpScgB11wgaEpuloa1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. SCG-B11WGA-EpuloA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpScgB11wgaEpuloa1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1710701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1710701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1710701.protein.info.v11.5.txt",
		        "node_list_path": "1710701.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumMoscoviense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum moscoviense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumMoscoviense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437059.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437059.protein.info.v11.5.txt",
		        "node_list_path": "1437059.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf32(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf32", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736214.protein.info.v11.5.txt",
		        "node_list_path": "1736214.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrothrixParvicella(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microthrix parvicella graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrothrixParvicella", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229780.protein.info.v11.5.txt",
		        "node_list_path": "1229780.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCaenarcanumBioreactoricolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Caenarcanum bioreactoricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCaenarcanumBioreactoricolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906166.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906166.protein.info.v11.5.txt",
		        "node_list_path": "1906166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioRenipiscarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio renipiscarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioRenipiscarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461322.protein.info.v11.5.txt",
		        "node_list_path": "1461322.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIs836(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-836 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIs836", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834160.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834160.protein.info.v11.5.txt",
		        "node_list_path": "1834160.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliellaChilensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borreliella chilensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliellaChilensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1245910.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1245910.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1245910.clusters.proteins.v11.5.txt",
		        "sequence_path": "1245910.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245910.protein.info.v11.5.txt",
		        "node_list_path": "1245910.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1245910.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumZavarziniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium zavarzinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumZavarziniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267005.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267005.protein.info.v11.5.txt",
		        "node_list_path": "1267005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumOrbiculareMaff240422(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum orbiculare MAFF 240422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumOrbiculareMaff240422", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1213857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1213857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1213857.protein.info.v11.5.txt",
		        "node_list_path": "1213857.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnolisCarolinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anolis carolinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnolisCarolinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28377.protein.sequences.v11.5.fa",
		        "enrichment_path": "28377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28377.protein.info.v11.5.txt",
		        "node_list_path": "28377.protein.complete.v11.5.txt"
		    }
		]
    )()

def TheileriaEquiStrainWaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Theileria equi strain WA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheileriaEquiStrainWaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1537102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1537102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1537102.clusters.proteins.v11.5.txt",
		        "sequence_path": "1537102.protein.sequences.v11.5.fa",
		        "enrichment_path": "1537102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1537102.protein.info.v11.5.txt",
		        "node_list_path": "1537102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1537102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomonasLenta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas lenta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasLenta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "980561.protein.sequences.v11.5.fa",
		        "enrichment_path": "980561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "980561.protein.info.v11.5.txt",
		        "node_list_path": "980561.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_49_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798396.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798396.protein.info.v11.5.txt",
		        "node_list_path": "1798396.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucobacterKomagatae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter komagatae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterKomagatae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "55969.protein.sequences.v11.5.fa",
		        "enrichment_path": "55969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55969.protein.info.v11.5.txt",
		        "node_list_path": "55969.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophorhabdusAromaticivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophorhabdus aromaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophorhabdusAromaticivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "909663.protein.sequences.v11.5.fa",
		        "enrichment_path": "909663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "909663.protein.info.v11.5.txt",
		        "node_list_path": "909663.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag590Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:590 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag590Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262825.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262825.protein.info.v11.5.txt",
		        "node_list_path": "1262825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumRbg166422Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RBG_16_64_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumRbg166422Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801708.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801708.protein.info.v11.5.txt",
		        "node_list_path": "1801708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TogniniaMinima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Togninia minima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TogniniaMinima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "223192.protein.sequences.v11.5.fa",
		        "enrichment_path": "223192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223192.protein.info.v11.5.txt",
		        "node_list_path": "223192.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpYr583Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. YR583 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpYr583Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881047.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881047.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881047.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881047.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881047.protein.info.v11.5.txt",
		        "node_list_path": "1881047.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881047.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharopolysporaFlavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharopolyspora flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharopolysporaFlavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "95161.clusters.info.v11.5.txt",
		        "cluster_tree_path": "95161.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "95161.clusters.proteins.v11.5.txt",
		        "sequence_path": "95161.protein.sequences.v11.5.fa",
		        "enrichment_path": "95161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "95161.protein.info.v11.5.txt",
		        "node_list_path": "95161.cluster.nodes.v11.5.txt",
		        "edge_list_path": "95161.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusBingmayongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus bingmayongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusBingmayongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150157.protein.info.v11.5.txt",
		        "node_list_path": "1150157.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumPeregrinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium peregrinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumPeregrinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43304.protein.sequences.v11.5.fa",
		        "enrichment_path": "43304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43304.protein.info.v11.5.txt",
		        "node_list_path": "43304.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaNorrlandica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella norrlandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaNorrlandica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1498499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1498499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1498499.protein.info.v11.5.txt",
		        "node_list_path": "1498499.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaWaksmaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella waksmanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaWaksmaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336233.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336233.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336233.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336233.protein.info.v11.5.txt",
		        "node_list_path": "1336233.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336233.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermotogaSp2812b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga sp. 2812B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaSp2812b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157948.protein.info.v11.5.txt",
		        "node_list_path": "1157948.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeisingeraAquaemixtaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leisingera aquaemixtae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraAquaemixtaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1396826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1396826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1396826.clusters.proteins.v11.5.txt",
		        "sequence_path": "1396826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1396826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1396826.protein.info.v11.5.txt",
		        "node_list_path": "1396826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1396826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelaginellaMoellendorffii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selaginella moellendorffii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelaginellaMoellendorffii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "88036.protein.sequences.v11.5.fa",
		        "enrichment_path": "88036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "88036.protein.info.v11.5.txt",
		        "node_list_path": "88036.protein.complete.v11.5.txt"
		    }
		]
    )()

def OstreococcusLucimarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ostreococcus lucimarinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OstreococcusLucimarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "242159.protein.sequences.v11.5.fa",
		        "enrichment_path": "242159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "242159.protein.info.v11.5.txt",
		        "node_list_path": "242159.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterJejuniNctc11168(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter jejuni NCTC11168 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterJejuniNctc11168", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "192222.protein.sequences.v11.5.fa",
		        "enrichment_path": "192222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192222.protein.info.v11.5.txt",
		        "node_list_path": "192222.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpL2c084a000Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. L2C084A000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpL2c084a000Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1287116.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1287116.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1287116.clusters.proteins.v11.5.txt",
		        "sequence_path": "1287116.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287116.protein.info.v11.5.txt",
		        "node_list_path": "1287116.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1287116.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicolaLitoreusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola litoreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaLitoreusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217970.protein.info.v11.5.txt",
		        "node_list_path": "1217970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LelliottiaAmnigena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lelliottia amnigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LelliottiaAmnigena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61646.protein.sequences.v11.5.fa",
		        "enrichment_path": "61646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61646.protein.info.v11.5.txt",
		        "node_list_path": "61646.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastococcusSpDsm44268(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 44268 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusSpDsm44268", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1550231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550231.protein.info.v11.5.txt",
		        "node_list_path": "1550231.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterJejuniNctc11168Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter jejuni NCTC11168 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterJejuniNctc11168Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "192222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "192222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "192222.clusters.proteins.v11.5.txt",
		        "sequence_path": "192222.protein.sequences.v11.5.fa",
		        "enrichment_path": "192222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192222.protein.info.v11.5.txt",
		        "node_list_path": "192222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "192222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidiaBacterium4341Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidia bacterium 43-41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidiaBacterium4341Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895720.protein.info.v11.5.txt",
		        "node_list_path": "1895720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusInfantisX(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis X graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusInfantisX", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "997830.protein.sequences.v11.5.fa",
		        "enrichment_path": "997830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997830.protein.info.v11.5.txt",
		        "node_list_path": "997830.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteusMirabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteus mirabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteusMirabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "529507.protein.sequences.v11.5.fa",
		        "enrichment_path": "529507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529507.protein.info.v11.5.txt",
		        "node_list_path": "529507.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterorhabdusMucosicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterorhabdus mucosicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterorhabdusMucosicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121866.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121866.protein.info.v11.5.txt",
		        "node_list_path": "1121866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporolactobacillusTerraeHkm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus terrae HKM-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolactobacillusTerraeHkm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449983.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449983.protein.info.v11.5.txt",
		        "node_list_path": "1449983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPutrefaciensKs1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens KS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPutrefaciensKs1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743965.protein.sequences.v11.5.fa",
		        "enrichment_path": "743965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743965.protein.info.v11.5.txt",
		        "node_list_path": "743965.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseburiaSpCag1004157(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:10041_57 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSpCag1004157", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897016.protein.info.v11.5.txt",
		        "node_list_path": "1897016.protein.complete.v11.5.txt"
		    }
		]
    )()

def UlvibacterSpLpb0005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ulvibacter sp. LPB0005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UlvibacterSpLpb0005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1763537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1763537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1763537.clusters.proteins.v11.5.txt",
		        "sequence_path": "1763537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1763537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1763537.protein.info.v11.5.txt",
		        "node_list_path": "1763537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1763537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StruthioCamelusAustralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Struthio camelus australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StruthioCamelusAustralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "441894.clusters.info.v11.5.txt",
		        "cluster_tree_path": "441894.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "441894.clusters.proteins.v11.5.txt",
		        "sequence_path": "441894.protein.sequences.v11.5.fa",
		        "enrichment_path": "441894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441894.protein.info.v11.5.txt",
		        "node_list_path": "441894.cluster.nodes.v11.5.txt",
		        "edge_list_path": "441894.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasGingivalisW83(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis W83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasGingivalisW83", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "242619.protein.sequences.v11.5.fa",
		        "enrichment_path": "242619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "242619.protein.info.v11.5.txt",
		        "node_list_path": "242619.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpCb0101Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. CB0101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpCb0101Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "232348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "232348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "232348.clusters.proteins.v11.5.txt",
		        "sequence_path": "232348.protein.sequences.v11.5.fa",
		        "enrichment_path": "232348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "232348.protein.info.v11.5.txt",
		        "node_list_path": "232348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "232348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusSibiricusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sibiricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSibiricusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "604354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "604354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "604354.clusters.proteins.v11.5.txt",
		        "sequence_path": "604354.protein.sequences.v11.5.fa",
		        "enrichment_path": "604354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "604354.protein.info.v11.5.txt",
		        "node_list_path": "604354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "604354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpRs9917Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. RS9917 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpRs9917Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "221360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "221360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "221360.clusters.proteins.v11.5.txt",
		        "sequence_path": "221360.protein.sequences.v11.5.fa",
		        "enrichment_path": "221360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221360.protein.info.v11.5.txt",
		        "node_list_path": "221360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "221360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh5701Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 5701 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh5701Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69042.clusters.proteins.v11.5.txt",
		        "sequence_path": "69042.protein.sequences.v11.5.fa",
		        "enrichment_path": "69042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69042.protein.info.v11.5.txt",
		        "node_list_path": "69042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemellaMorbillorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemella morbillorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaMorbillorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "562982.protein.sequences.v11.5.fa",
		        "enrichment_path": "562982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562982.protein.info.v11.5.txt",
		        "node_list_path": "562982.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacteriumCg10243210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_43_210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg10243210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805286.protein.info.v11.5.txt",
		        "node_list_path": "1805286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacterium13220cm2628Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium 13_2_20CM_2_62_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacterium13220cm2628Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805272.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805272.protein.info.v11.5.txt",
		        "node_list_path": "1805272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumCaspAlpha2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium casp-alpha2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumCaspAlpha2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1655503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655503.protein.info.v11.5.txt",
		        "node_list_path": "1655503.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpNc3005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. NC3005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpNc3005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280685.protein.info.v11.5.txt",
		        "node_list_path": "1280685.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterCryaerophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter cryaerophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterCryaerophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28198.clusters.proteins.v11.5.txt",
		        "sequence_path": "28198.protein.sequences.v11.5.fa",
		        "enrichment_path": "28198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28198.protein.info.v11.5.txt",
		        "node_list_path": "28198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpBnl1100Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. BNL1100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpBnl1100Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "755731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "755731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "755731.clusters.proteins.v11.5.txt",
		        "sequence_path": "755731.protein.sequences.v11.5.fa",
		        "enrichment_path": "755731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "755731.protein.info.v11.5.txt",
		        "node_list_path": "755731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "755731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoorellaSp6041Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moorella sp. 60_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoorellaSp6041Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635264.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635264.protein.info.v11.5.txt",
		        "node_list_path": "1635264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumSpHmsc063g07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium sp. HMSC063G07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumSpHmsc063g07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739261.protein.info.v11.5.txt",
		        "node_list_path": "1739261.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlycomycesArizonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glycomyces arizonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlycomycesArizonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121926.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121926.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121926.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121926.protein.info.v11.5.txt",
		        "node_list_path": "1121926.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121926.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumGwe25113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium GWE2_51_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumGwe25113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798010.protein.info.v11.5.txt",
		        "node_list_path": "1798010.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaSpSgdV85(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sp. SGD-V-85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSpSgdV85", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1414651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414651.protein.info.v11.5.txt",
		        "node_list_path": "1414651.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloteneraSpL2l1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera sp. L2L1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraSpL2l1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502770.protein.info.v11.5.txt",
		        "node_list_path": "1502770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpAe3005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. AE3005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpAe3005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1485543.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1485543.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1485543.clusters.proteins.v11.5.txt",
		        "sequence_path": "1485543.protein.sequences.v11.5.fa",
		        "enrichment_path": "1485543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1485543.protein.info.v11.5.txt",
		        "node_list_path": "1485543.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1485543.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedMegasphaeraSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Megasphaera sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedMegasphaeraSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "165188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "165188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "165188.clusters.proteins.v11.5.txt",
		        "sequence_path": "165188.protein.sequences.v11.5.fa",
		        "enrichment_path": "165188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "165188.protein.info.v11.5.txt",
		        "node_list_path": "165188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "165188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermomicrobialesBacteriumKi4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermomicrobiales bacterium KI4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermomicrobialesBacteriumKi4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1382356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382356.protein.info.v11.5.txt",
		        "node_list_path": "1382356.protein.complete.v11.5.txt"
		    }
		]
    )()

def RikenellaMicrofusus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rikenella microfusus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RikenellaMicrofusus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "880526.protein.sequences.v11.5.fa",
		        "enrichment_path": "880526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880526.protein.info.v11.5.txt",
		        "node_list_path": "880526.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumNordicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium nordicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumNordicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "229535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "229535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "229535.clusters.proteins.v11.5.txt",
		        "sequence_path": "229535.protein.sequences.v11.5.fa",
		        "enrichment_path": "229535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229535.protein.info.v11.5.txt",
		        "node_list_path": "229535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "229535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetalesBacteriumSpiro07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetalesBacteriumSpiro07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674863.protein.info.v11.5.txt",
		        "node_list_path": "1674863.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAureocirculatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aureocirculatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAureocirculatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67275.protein.sequences.v11.5.fa",
		        "enrichment_path": "67275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67275.protein.info.v11.5.txt",
		        "node_list_path": "67275.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb1416(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_41_6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb1416", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618869.protein.info.v11.5.txt",
		        "node_list_path": "1618869.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpHel13349(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel13349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpHel13349", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336803.protein.info.v11.5.txt",
		        "node_list_path": "1336803.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichechusManatusLatirostrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichechus manatus latirostris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichechusManatusLatirostrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "127582.clusters.info.v11.5.txt",
		        "cluster_tree_path": "127582.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "127582.clusters.proteins.v11.5.txt",
		        "sequence_path": "127582.protein.sequences.v11.5.fa",
		        "enrichment_path": "127582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "127582.protein.info.v11.5.txt",
		        "node_list_path": "127582.cluster.nodes.v11.5.txt",
		        "edge_list_path": "127582.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumRm5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium RM5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumRm5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1200721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1200721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1200721.clusters.proteins.v11.5.txt",
		        "sequence_path": "1200721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200721.protein.info.v11.5.txt",
		        "node_list_path": "1200721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1200721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "361041.clusters.info.v11.5.txt",
		        "cluster_tree_path": "361041.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "361041.clusters.proteins.v11.5.txt",
		        "sequence_path": "361041.protein.sequences.v11.5.fa",
		        "enrichment_path": "361041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "361041.protein.info.v11.5.txt",
		        "node_list_path": "361041.cluster.nodes.v11.5.txt",
		        "edge_list_path": "361041.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnsiferSpWsm1721(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. WSM1721 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferSpWsm1721", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041159.protein.info.v11.5.txt",
		        "node_list_path": "1041159.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp303mfcol52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 303MFCol52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp303mfcol52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1172181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172181.protein.info.v11.5.txt",
		        "node_list_path": "1172181.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioDesulfuricansAtcc27774Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans ATCC27774 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioDesulfuricansAtcc27774Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525146.clusters.proteins.v11.5.txt",
		        "sequence_path": "525146.protein.sequences.v11.5.fa",
		        "enrichment_path": "525146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525146.protein.info.v11.5.txt",
		        "node_list_path": "525146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivivaxMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379903.protein.info.v11.5.txt",
		        "node_list_path": "1379903.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpWb2n11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Wb2n-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpWb2n11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1030533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1030533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1030533.clusters.proteins.v11.5.txt",
		        "sequence_path": "1030533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1030533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1030533.protein.info.v11.5.txt",
		        "node_list_path": "1030533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1030533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasSp22ii122f38(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. 22II122F38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSp22ii122f38", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280948.protein.info.v11.5.txt",
		        "node_list_path": "1280948.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaStercoreaCag629(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella stercorea CAG:629 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaStercoreaCag629", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263103.protein.info.v11.5.txt",
		        "node_list_path": "1263103.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSp2a57ct2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 2A57CT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp2a57ct2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665959.clusters.proteins.v11.5.txt",
		        "sequence_path": "665959.protein.sequences.v11.5.fa",
		        "enrichment_path": "665959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665959.protein.info.v11.5.txt",
		        "node_list_path": "665959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaBuccalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia buccalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaBuccalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "523794.protein.sequences.v11.5.fa",
		        "enrichment_path": "523794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523794.protein.info.v11.5.txt",
		        "node_list_path": "523794.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "198620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "198620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "198620.clusters.proteins.v11.5.txt",
		        "sequence_path": "198620.protein.sequences.v11.5.fa",
		        "enrichment_path": "198620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198620.protein.info.v11.5.txt",
		        "node_list_path": "198620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "198620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpAg1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ag1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpAg1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1642949.protein.sequences.v11.5.fa",
		        "enrichment_path": "1642949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1642949.protein.info.v11.5.txt",
		        "node_list_path": "1642949.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumElkaniiUsda76Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii USDA76 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumElkaniiUsda76Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398525.clusters.proteins.v11.5.txt",
		        "sequence_path": "398525.protein.sequences.v11.5.fa",
		        "enrichment_path": "398525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398525.protein.info.v11.5.txt",
		        "node_list_path": "398525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfosarcinaSpBus5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosarcina sp. BuS5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosarcinaSpBus5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "933262.protein.sequences.v11.5.fa",
		        "enrichment_path": "933262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933262.protein.info.v11.5.txt",
		        "node_list_path": "933262.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumDesmolansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium desmolans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumDesmolansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408437.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408437.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408437.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408437.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408437.protein.info.v11.5.txt",
		        "node_list_path": "1408437.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408437.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatenariaAnguillulaePl171Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catenaria anguillulae PL171 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenariaAnguillulaePl171Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765915.clusters.proteins.v11.5.txt",
		        "sequence_path": "765915.protein.sequences.v11.5.fa",
		        "enrichment_path": "765915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765915.protein.info.v11.5.txt",
		        "node_list_path": "765915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RothiaNasimuriumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rothia nasimurium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RothiaNasimuriumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "85336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "85336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "85336.clusters.proteins.v11.5.txt",
		        "sequence_path": "85336.protein.sequences.v11.5.fa",
		        "enrichment_path": "85336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85336.protein.info.v11.5.txt",
		        "node_list_path": "85336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "85336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4135(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_41_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4135", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798677.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798677.protein.info.v11.5.txt",
		        "node_list_path": "1798677.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpRedseaS34B3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. REDSEA-S34_B3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpRedseaS34B3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811533.protein.info.v11.5.txt",
		        "node_list_path": "1811533.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusIslandicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus islandicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusIslandicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123389.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123389.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123389.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123389.protein.info.v11.5.txt",
		        "node_list_path": "1123389.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123389.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GracilibacterSpBrhC7aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacter sp. BRH_c7a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacterSpBrhC7aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1734398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1734398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1734398.clusters.proteins.v11.5.txt",
		        "sequence_path": "1734398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1734398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1734398.protein.info.v11.5.txt",
		        "node_list_path": "1734398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1734398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CallipeplaSquamata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Callipepla squamata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CallipeplaSquamata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9009.protein.sequences.v11.5.fa",
		        "enrichment_path": "9009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9009.protein.info.v11.5.txt",
		        "node_list_path": "9009.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidocellaSpMxAz02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidocella sp. MX-AZ02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidocellaSpMxAz02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1214225.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1214225.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1214225.clusters.proteins.v11.5.txt",
		        "sequence_path": "1214225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214225.protein.info.v11.5.txt",
		        "node_list_path": "1214225.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1214225.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaSaliphilaYim90502Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora saliphila YIM 90502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaSaliphilaYim90502Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "882085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "882085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "882085.clusters.proteins.v11.5.txt",
		        "sequence_path": "882085.protein.sequences.v11.5.fa",
		        "enrichment_path": "882085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882085.protein.info.v11.5.txt",
		        "node_list_path": "882085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "882085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudooceanicolaNitratireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudooceanicola nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudooceanicolaNitratireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "517719.protein.sequences.v11.5.fa",
		        "enrichment_path": "517719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "517719.protein.info.v11.5.txt",
		        "node_list_path": "517719.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumEstertheticumSubspEstertheticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium estertheticum subsp. estertheticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumEstertheticumSubspEstertheticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1552.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1552.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1552.clusters.proteins.v11.5.txt",
		        "sequence_path": "1552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1552.protein.info.v11.5.txt",
		        "node_list_path": "1552.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1552.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DomibacillusEnclensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus enclensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusEnclensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1017273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1017273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1017273.clusters.proteins.v11.5.txt",
		        "sequence_path": "1017273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1017273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1017273.protein.info.v11.5.txt",
		        "node_list_path": "1017273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1017273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusSpSb3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. SB3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusSpSb3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1673719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673719.protein.info.v11.5.txt",
		        "node_list_path": "1673719.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusColwellbacteriaBacteriumRifcsphigho212Full4417(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPHIGHO2_12_FULL_44_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsphigho212Full4417", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797689.protein.info.v11.5.txt",
		        "node_list_path": "1797689.protein.complete.v11.5.txt"
		    }
		]
    )()

def DichantheliumOligosanthesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dichanthelium oligosanthes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DichantheliumOligosanthesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888268.clusters.proteins.v11.5.txt",
		        "sequence_path": "888268.protein.sequences.v11.5.fa",
		        "enrichment_path": "888268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888268.protein.info.v11.5.txt",
		        "node_list_path": "888268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpA23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. A23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpA23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1944133.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1944133.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1944133.clusters.proteins.v11.5.txt",
		        "sequence_path": "1944133.protein.sequences.v11.5.fa",
		        "enrichment_path": "1944133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1944133.protein.info.v11.5.txt",
		        "node_list_path": "1944133.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1944133.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumOxalicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium oxalicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumOxalicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69781.protein.sequences.v11.5.fa",
		        "enrichment_path": "69781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69781.protein.info.v11.5.txt",
		        "node_list_path": "69781.protein.complete.v11.5.txt"
		    }
		]
    )()

def VitreoscillaStercorariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vitreoscilla stercoraria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VitreoscillaStercorariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123499.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123499.protein.info.v11.5.txt",
		        "node_list_path": "1123499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpLeaf394(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf394 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpLeaf394", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736361.protein.info.v11.5.txt",
		        "node_list_path": "1736361.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorchorusCapsularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corchorus capsularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorchorusCapsularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "210143.protein.sequences.v11.5.fa",
		        "enrichment_path": "210143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "210143.protein.info.v11.5.txt",
		        "node_list_path": "210143.protein.complete.v11.5.txt"
		    }
		]
    )()

def SeinonellaPeptonophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Seinonella peptonophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SeinonellaPeptonophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "112248.protein.sequences.v11.5.fa",
		        "enrichment_path": "112248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112248.protein.info.v11.5.txt",
		        "node_list_path": "112248.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacterium13140cm6517Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 13_1_40CM_65_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacterium13140cm6517Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805080.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805080.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805080.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805080.protein.info.v11.5.txt",
		        "node_list_path": "1805080.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805080.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LutibacterProfundi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lutibacter profundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutibacterProfundi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1622118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622118.protein.info.v11.5.txt",
		        "node_list_path": "1622118.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFlectensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas flectens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFlectensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336237.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336237.protein.info.v11.5.txt",
		        "node_list_path": "1336237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LabrenziaAlba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Labrenzia alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrenziaAlba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "311410.protein.sequences.v11.5.fa",
		        "enrichment_path": "311410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311410.protein.info.v11.5.txt",
		        "node_list_path": "311410.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf23066(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_30_66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf23066", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619078.protein.info.v11.5.txt",
		        "node_list_path": "1619078.protein.complete.v11.5.txt"
		    }
		]
    )()

def FilomicrobiumInsigneCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Filomicrobium insigne Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FilomicrobiumInsigneCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "418854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "418854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "418854.clusters.proteins.v11.5.txt",
		        "sequence_path": "418854.protein.sequences.v11.5.fa",
		        "enrichment_path": "418854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "418854.protein.info.v11.5.txt",
		        "node_list_path": "418854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "418854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaceaeBacteriumHl53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarinaceae bacterium HL-53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaceaeBacteriumHl53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298881.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298881.protein.info.v11.5.txt",
		        "node_list_path": "1298881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGa0077554Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0077554 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGa0077554Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752215.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752215.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752215.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752215.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752215.protein.info.v11.5.txt",
		        "node_list_path": "1752215.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752215.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumCg1026336(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_63_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumCg1026336", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805133.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805133.protein.info.v11.5.txt",
		        "node_list_path": "1805133.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumHalliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium hallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumHalliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411469.clusters.proteins.v11.5.txt",
		        "sequence_path": "411469.protein.sequences.v11.5.fa",
		        "enrichment_path": "411469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411469.protein.info.v11.5.txt",
		        "node_list_path": "411469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesFaecisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides faecis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFaecisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1077285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1077285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1077285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1077285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077285.protein.info.v11.5.txt",
		        "node_list_path": "1077285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1077285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesCardiffensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces cardiffensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesCardiffensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888050.protein.sequences.v11.5.fa",
		        "enrichment_path": "888050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888050.protein.info.v11.5.txt",
		        "node_list_path": "888050.protein.complete.v11.5.txt"
		    }
		]
    )()

def UncinocarpusReesii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Uncinocarpus reesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UncinocarpusReesii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33188.protein.sequences.v11.5.fa",
		        "enrichment_path": "33188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33188.protein.info.v11.5.txt",
		        "node_list_path": "33188.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpMl96Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ML96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpMl96Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523503.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523503.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523503.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523503.protein.info.v11.5.txt",
		        "node_list_path": "1523503.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523503.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaAlni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia alni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaAlni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326424.protein.sequences.v11.5.fa",
		        "enrichment_path": "326424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326424.protein.info.v11.5.txt",
		        "node_list_path": "326424.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacteriumDehalogenansDsm11527Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacterium dehalogenans DSM 11527 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacteriumDehalogenansDsm11527Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1068975.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1068975.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1068975.clusters.proteins.v11.5.txt",
		        "sequence_path": "1068975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1068975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1068975.protein.info.v11.5.txt",
		        "node_list_path": "1068975.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1068975.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NostocSpNies3756(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nostoc sp. NIES-3756 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocSpNies3756", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1751286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1751286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1751286.protein.info.v11.5.txt",
		        "node_list_path": "1751286.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinopolymorphaSingaporensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinopolymorpha singaporensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolymorphaSingaporensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "117157.protein.sequences.v11.5.fa",
		        "enrichment_path": "117157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "117157.protein.info.v11.5.txt",
		        "node_list_path": "117157.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyunsoonleellaJejuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyunsoonleella jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyunsoonleellaJejuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "419940.protein.sequences.v11.5.fa",
		        "enrichment_path": "419940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419940.protein.info.v11.5.txt",
		        "node_list_path": "419940.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusSputorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus sputorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusSputorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035839.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035839.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035839.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035839.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035839.protein.info.v11.5.txt",
		        "node_list_path": "1035839.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035839.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaMatsumotoense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora matsumotoense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaMatsumotoense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "121616.protein.sequences.v11.5.fa",
		        "enrichment_path": "121616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121616.protein.info.v11.5.txt",
		        "node_list_path": "121616.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4315Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_43_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4315Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797790.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797790.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797790.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797790.protein.info.v11.5.txt",
		        "node_list_path": "1797790.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797790.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusParabrevis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus parabrevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParabrevis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267003.protein.info.v11.5.txt",
		        "node_list_path": "1267003.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusIniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus iniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusIniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346.protein.info.v11.5.txt",
		        "node_list_path": "1346.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychromonasSpCnpt3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas sp. CNPT3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychromonasSpCnpt3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314282.clusters.proteins.v11.5.txt",
		        "sequence_path": "314282.protein.sequences.v11.5.fa",
		        "enrichment_path": "314282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314282.protein.info.v11.5.txt",
		        "node_list_path": "314282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpFsw0699(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. FSW06-99 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpFsw0699", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739113.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739113.protein.info.v11.5.txt",
		        "node_list_path": "1739113.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumIncanum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum incanum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumIncanum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1573173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1573173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1573173.protein.info.v11.5.txt",
		        "node_list_path": "1573173.protein.complete.v11.5.txt"
		    }
		]
    )()

def TepidanaerobacterAcetatoxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tepidanaerobacter acetatoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidanaerobacterAcetatoxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1209989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1209989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1209989.protein.info.v11.5.txt",
		        "node_list_path": "1209989.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAtrophaeus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus atrophaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAtrophaeus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "720555.protein.sequences.v11.5.fa",
		        "enrichment_path": "720555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "720555.protein.info.v11.5.txt",
		        "node_list_path": "720555.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynergistalesBacterium5424Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synergistales bacterium 54_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynergistalesBacterium5424Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635272.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635272.protein.info.v11.5.txt",
		        "node_list_path": "1635272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KluyveraIntermedia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kluyvera intermedia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KluyveraIntermedia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61648.protein.sequences.v11.5.fa",
		        "enrichment_path": "61648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61648.protein.info.v11.5.txt",
		        "node_list_path": "61648.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumJeikeium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium jeikeium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumJeikeium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "306537.protein.sequences.v11.5.fa",
		        "enrichment_path": "306537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306537.protein.info.v11.5.txt",
		        "node_list_path": "306537.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCylindrosporumDsm605Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cylindrosporum DSM 605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCylindrosporumDsm605Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121307.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121307.protein.info.v11.5.txt",
		        "node_list_path": "1121307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumKishitanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium kishitanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumKishitanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "318456.protein.sequences.v11.5.fa",
		        "enrichment_path": "318456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318456.protein.info.v11.5.txt",
		        "node_list_path": "318456.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalococcusSalifodinaeDsm8989Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halococcus salifodinae DSM 8989 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusSalifodinaeDsm8989Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227456.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227456.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227456.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227456.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227456.protein.info.v11.5.txt",
		        "node_list_path": "1227456.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227456.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4513Fw928(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4513 (FW-928) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4513Fw928", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420907.protein.info.v11.5.txt",
		        "node_list_path": "1420907.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumAmmoniigenesNbrc101786Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium ammoniigenes NBRC 101786 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumAmmoniigenesNbrc101786Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223517.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223517.protein.info.v11.5.txt",
		        "node_list_path": "1223517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UreibacillusThermosphaericus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ureibacillus thermosphaericus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UreibacillusThermosphaericus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1160707.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160707.protein.info.v11.5.txt",
		        "node_list_path": "1160707.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpPamc28756(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. PAMC 28756 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpPamc28756", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1795053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795053.protein.info.v11.5.txt",
		        "node_list_path": "1795053.protein.complete.v11.5.txt"
		    }
		]
    )()

def SorangiumCellulosumSo01572(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sorangium cellulosum So01572 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SorangiumCellulosumSo01572", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1254432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1254432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1254432.protein.info.v11.5.txt",
		        "node_list_path": "1254432.protein.complete.v11.5.txt"
		    }
		]
    )()

def ByssochlamysSpectabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Byssochlamys spectabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ByssochlamysSpectabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264951.protein.sequences.v11.5.fa",
		        "enrichment_path": "264951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264951.protein.info.v11.5.txt",
		        "node_list_path": "264951.protein.complete.v11.5.txt"
		    }
		]
    )()

def HabropodaLaboriosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Habropoda laboriosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HabropodaLaboriosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "597456.protein.sequences.v11.5.fa",
		        "enrichment_path": "597456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "597456.protein.info.v11.5.txt",
		        "node_list_path": "597456.protein.complete.v11.5.txt"
		    }
		]
    )()

def GranulicatellaElegansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Granulicatella elegans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicatellaElegansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "626369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "626369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "626369.clusters.proteins.v11.5.txt",
		        "sequence_path": "626369.protein.sequences.v11.5.fa",
		        "enrichment_path": "626369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626369.protein.info.v11.5.txt",
		        "node_list_path": "626369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "626369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelomonasSpRoot1444(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1444 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelomonasSpRoot1444", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736464.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736464.protein.info.v11.5.txt",
		        "node_list_path": "1736464.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGastranaerophilalesBacteriumHum9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium HUM_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumHum9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1916320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1916320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1916320.clusters.proteins.v11.5.txt",
		        "sequence_path": "1916320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1916320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1916320.protein.info.v11.5.txt",
		        "node_list_path": "1916320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1916320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaSp348mftsu51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia sp. 348MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSp348mftsu51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1172185.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1172185.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1172185.clusters.proteins.v11.5.txt",
		        "sequence_path": "1172185.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172185.protein.info.v11.5.txt",
		        "node_list_path": "1172185.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1172185.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HeliobacteriumModesticaldum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Heliobacterium modesticaldum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeliobacteriumModesticaldum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "498761.protein.sequences.v11.5.fa",
		        "enrichment_path": "498761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498761.protein.info.v11.5.txt",
		        "node_list_path": "498761.protein.complete.v11.5.txt"
		    }
		]
    )()

def DonghicolaEburneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Donghicola eburneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DonghicolaEburneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "393278.protein.sequences.v11.5.fa",
		        "enrichment_path": "393278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393278.protein.info.v11.5.txt",
		        "node_list_path": "393278.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumCorienseDsm10284(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum coriense DSM 10284 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumCorienseDsm10284", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227466.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227466.protein.info.v11.5.txt",
		        "node_list_path": "1227466.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCelluloflavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces celluloflavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCelluloflavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "58344.protein.sequences.v11.5.fa",
		        "enrichment_path": "58344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58344.protein.info.v11.5.txt",
		        "node_list_path": "58344.protein.complete.v11.5.txt"
		    }
		]
    )()

def NostocPunctiformeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nostoc punctiforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocPunctiformeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "63737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "63737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "63737.clusters.proteins.v11.5.txt",
		        "sequence_path": "63737.protein.sequences.v11.5.fa",
		        "enrichment_path": "63737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63737.protein.info.v11.5.txt",
		        "node_list_path": "63737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "63737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPyruviciproducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pyruviciproducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPyruviciproducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125779.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125779.protein.info.v11.5.txt",
		        "node_list_path": "1125779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCt34Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CT34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCt34Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1553907.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1553907.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1553907.clusters.proteins.v11.5.txt",
		        "sequence_path": "1553907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1553907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1553907.protein.info.v11.5.txt",
		        "node_list_path": "1553907.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1553907.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpLshc420b00(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LSHC420B00 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpLshc420b00", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1287292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287292.protein.info.v11.5.txt",
		        "node_list_path": "1287292.protein.complete.v11.5.txt"
		    }
		]
    )()

def DiaportheAmpelinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Diaporthe ampelina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiaportheAmpelinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1214573.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1214573.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1214573.clusters.proteins.v11.5.txt",
		        "sequence_path": "1214573.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214573.protein.info.v11.5.txt",
		        "node_list_path": "1214573.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1214573.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlaciecolaArcticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaArcticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "493475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "493475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "493475.clusters.proteins.v11.5.txt",
		        "sequence_path": "493475.protein.sequences.v11.5.fa",
		        "enrichment_path": "493475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "493475.protein.info.v11.5.txt",
		        "node_list_path": "493475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "493475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusDownei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus downei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDownei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "904293.protein.sequences.v11.5.fa",
		        "enrichment_path": "904293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904293.protein.info.v11.5.txt",
		        "node_list_path": "904293.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumL41aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium L41A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumL41aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229204.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229204.protein.info.v11.5.txt",
		        "node_list_path": "1229204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteocatellaSphenisci(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteocatella sphenisci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteocatellaSphenisci", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123009.protein.info.v11.5.txt",
		        "node_list_path": "1123009.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusJidaibacterAcanthamoeba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jidaibacter acanthamoeba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJidaibacterAcanthamoeba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86105.protein.sequences.v11.5.fa",
		        "enrichment_path": "86105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86105.protein.info.v11.5.txt",
		        "node_list_path": "86105.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacterMetallireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter metallireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterMetallireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "269799.clusters.info.v11.5.txt",
		        "cluster_tree_path": "269799.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "269799.clusters.proteins.v11.5.txt",
		        "sequence_path": "269799.protein.sequences.v11.5.fa",
		        "enrichment_path": "269799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269799.protein.info.v11.5.txt",
		        "node_list_path": "269799.cluster.nodes.v11.5.txt",
		        "edge_list_path": "269799.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioPaciniiDsm19139(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio pacinii DSM 19139 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioPaciniiDsm19139", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123494.protein.info.v11.5.txt",
		        "node_list_path": "1123494.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacterium4461(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 44-61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacterium4461", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895838.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895838.protein.info.v11.5.txt",
		        "node_list_path": "1895838.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp142mfcol31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 142MFCol31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp142mfcol31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1172179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172179.protein.info.v11.5.txt",
		        "node_list_path": "1172179.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacillusSpOk028Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacillus sp. OK028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacillusSpOk028Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884359.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884359.protein.info.v11.5.txt",
		        "node_list_path": "1884359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSpicheriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus spicheri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSpicheriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216463.clusters.proteins.v11.5.txt",
		        "sequence_path": "216463.protein.sequences.v11.5.fa",
		        "enrichment_path": "216463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216463.protein.info.v11.5.txt",
		        "node_list_path": "216463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwb15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWB15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwb15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1938898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1938898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1938898.clusters.proteins.v11.5.txt",
		        "sequence_path": "1938898.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938898.protein.info.v11.5.txt",
		        "node_list_path": "1938898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1938898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinophagaEiseniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga eiseniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaEiseniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634771.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634771.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634771.clusters.proteins.v11.5.txt",
		        "sequence_path": "634771.protein.sequences.v11.5.fa",
		        "enrichment_path": "634771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634771.protein.info.v11.5.txt",
		        "node_list_path": "634771.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634771.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterLappiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter lappiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterLappiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "354630.protein.sequences.v11.5.fa",
		        "enrichment_path": "354630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "354630.protein.info.v11.5.txt",
		        "node_list_path": "354630.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedButyricicoccusSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Butyricicoccus sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedButyricicoccusSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193532.protein.info.v11.5.txt",
		        "node_list_path": "1193532.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHtcc9022Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC9022 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHtcc9022Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265756.protein.info.v11.5.txt",
		        "node_list_path": "1265756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YaniellaHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yaniella halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YaniellaHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123507.protein.info.v11.5.txt",
		        "node_list_path": "1123507.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpAm1D1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. AM1-D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpAm1D1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1917485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917485.protein.info.v11.5.txt",
		        "node_list_path": "1917485.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpHk1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. HK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpHk1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1469245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469245.protein.info.v11.5.txt",
		        "node_list_path": "1469245.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacteriumWieringae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacterium wieringae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacteriumWieringae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52694.protein.sequences.v11.5.fa",
		        "enrichment_path": "52694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52694.protein.info.v11.5.txt",
		        "node_list_path": "52694.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhycisphaeraMikurensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phycisphaera mikurensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycisphaeraMikurensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1142394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1142394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1142394.clusters.proteins.v11.5.txt",
		        "sequence_path": "1142394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1142394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1142394.protein.info.v11.5.txt",
		        "node_list_path": "1142394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1142394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalibacteriumHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salibacterium halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalibacteriumHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884432.protein.info.v11.5.txt",
		        "node_list_path": "1884432.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsplowo201Full3334Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_01_FULL_33_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo201Full3334Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798685.protein.info.v11.5.txt",
		        "node_list_path": "1798685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesCoprophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides coprophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCoprophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "547042.protein.sequences.v11.5.fa",
		        "enrichment_path": "547042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547042.protein.info.v11.5.txt",
		        "node_list_path": "547042.protein.complete.v11.5.txt"
		    }
		]
    )()

def DaphniaPulexCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Daphnia pulex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DaphniaPulexCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6669.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6669.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6669.clusters.proteins.v11.5.txt",
		        "sequence_path": "6669.protein.sequences.v11.5.fa",
		        "enrichment_path": "6669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6669.protein.info.v11.5.txt",
		        "node_list_path": "6669.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6669.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwb26322Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWB2_63_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwb26322Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797929.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797929.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797929.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797929.protein.info.v11.5.txt",
		        "node_list_path": "1797929.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797929.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPyridomyceticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces pyridomyceticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPyridomyceticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68260.clusters.proteins.v11.5.txt",
		        "sequence_path": "68260.protein.sequences.v11.5.fa",
		        "enrichment_path": "68260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68260.protein.info.v11.5.txt",
		        "node_list_path": "68260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBeckwithbacteriaBacteriumCg1024737(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium CG1_02_47_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumCg1024737", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805034.protein.info.v11.5.txt",
		        "node_list_path": "1805034.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprococcusSpCag782Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus sp. CAG:782 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprococcusSpCag782Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262863.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262863.protein.info.v11.5.txt",
		        "node_list_path": "1262863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloteneraSpG11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera sp. G11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraSpG11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1506585.protein.sequences.v11.5.fa",
		        "enrichment_path": "1506585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1506585.protein.info.v11.5.txt",
		        "node_list_path": "1506585.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSp12014mblMicdiv(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. 1_2014MBL_MicDiv graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSp12014mblMicdiv", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1644131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1644131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1644131.protein.info.v11.5.txt",
		        "node_list_path": "1644131.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGa0074134Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0074134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGa0074134Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752213.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752213.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752213.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752213.protein.info.v11.5.txt",
		        "node_list_path": "1752213.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752213.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioclavaSpDt234(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. DT234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaSpDt234", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1353528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353528.protein.info.v11.5.txt",
		        "node_list_path": "1353528.protein.complete.v11.5.txt"
		    }
		]
    )()

def KoribacterVersatilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Koribacter versatilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KoribacterVersatilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "204669.protein.sequences.v11.5.fa",
		        "enrichment_path": "204669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "204669.protein.info.v11.5.txt",
		        "node_list_path": "204669.protein.complete.v11.5.txt"
		    }
		]
    )()

def NannospalaxGaliliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nannospalax galili Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NannospalaxGaliliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1026970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1026970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1026970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1026970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1026970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1026970.protein.info.v11.5.txt",
		        "node_list_path": "1026970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1026970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiO157h7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli O157H7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiO157h7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "155864.protein.sequences.v11.5.fa",
		        "enrichment_path": "155864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "155864.protein.info.v11.5.txt",
		        "node_list_path": "155864.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerotruncusColihominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerotruncus colihominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotruncusColihominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445972.protein.sequences.v11.5.fa",
		        "enrichment_path": "445972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445972.protein.info.v11.5.txt",
		        "node_list_path": "445972.protein.complete.v11.5.txt"
		    }
		]
    )()

def PicrophilusTorridusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Picrophilus torridus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PicrophilusTorridusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "263820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "263820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "263820.clusters.proteins.v11.5.txt",
		        "sequence_path": "263820.protein.sequences.v11.5.fa",
		        "enrichment_path": "263820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263820.protein.info.v11.5.txt",
		        "node_list_path": "263820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "263820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GranulicatellaAdiacens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Granulicatella adiacens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicatellaAdiacens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "638301.protein.sequences.v11.5.fa",
		        "enrichment_path": "638301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "638301.protein.info.v11.5.txt",
		        "node_list_path": "638301.protein.complete.v11.5.txt"
		    }
		]
    )()

def StomatobaculumLongumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stomatobaculum longum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StomatobaculumLongumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "796942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "796942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "796942.clusters.proteins.v11.5.txt",
		        "sequence_path": "796942.protein.sequences.v11.5.fa",
		        "enrichment_path": "796942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796942.protein.info.v11.5.txt",
		        "node_list_path": "796942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "796942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BipolarisMaydis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris maydis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisMaydis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5016.protein.sequences.v11.5.fa",
		        "enrichment_path": "5016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5016.protein.info.v11.5.txt",
		        "node_list_path": "5016.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusSpTolM(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. Tol-M graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusSpTolM", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1536651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536651.protein.info.v11.5.txt",
		        "node_list_path": "1536651.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpLnjc398b00Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LNJC398B00 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpLnjc398b00Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1287276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1287276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1287276.clusters.proteins.v11.5.txt",
		        "sequence_path": "1287276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287276.protein.info.v11.5.txt",
		        "node_list_path": "1287276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1287276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAcetothermiaBacteriumJdfr48Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acetothermia bacterium JdFR-48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAcetothermiaBacteriumJdfr48Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935102.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935102.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935102.protein.info.v11.5.txt",
		        "node_list_path": "1935102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMacacaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus macacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMacacaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "764298.clusters.info.v11.5.txt",
		        "cluster_tree_path": "764298.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "764298.clusters.proteins.v11.5.txt",
		        "sequence_path": "764298.protein.sequences.v11.5.fa",
		        "enrichment_path": "764298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "764298.protein.info.v11.5.txt",
		        "node_list_path": "764298.cluster.nodes.v11.5.txt",
		        "edge_list_path": "764298.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfDrosophilaMelanogasterCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila melanogaster Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophilaMelanogasterCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "163164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "163164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "163164.clusters.proteins.v11.5.txt",
		        "sequence_path": "163164.protein.sequences.v11.5.fa",
		        "enrichment_path": "163164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "163164.protein.info.v11.5.txt",
		        "node_list_path": "163164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "163164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LechevalieriaXinjiangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lechevalieria xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LechevalieriaXinjiangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "402600.protein.sequences.v11.5.fa",
		        "enrichment_path": "402600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402600.protein.info.v11.5.txt",
		        "node_list_path": "402600.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusLactarisCc59002dCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus lactaris CC59_002D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusLactarisCc59002dCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1073376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1073376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1073376.clusters.proteins.v11.5.txt",
		        "sequence_path": "1073376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073376.protein.info.v11.5.txt",
		        "node_list_path": "1073376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1073376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeoalkalibacterFerrihydriticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geoalkalibacter ferrihydriticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeoalkalibacterFerrihydriticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "392333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "392333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "392333.clusters.proteins.v11.5.txt",
		        "sequence_path": "392333.protein.sequences.v11.5.fa",
		        "enrichment_path": "392333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392333.protein.info.v11.5.txt",
		        "node_list_path": "392333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "392333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpMc2021Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MC2021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpMc2021Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408306.protein.info.v11.5.txt",
		        "node_list_path": "1408306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KocuriaPalustrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kocuria palustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaPalustrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "71999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "71999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "71999.clusters.proteins.v11.5.txt",
		        "sequence_path": "71999.protein.sequences.v11.5.fa",
		        "enrichment_path": "71999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "71999.protein.info.v11.5.txt",
		        "node_list_path": "71999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "71999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CanisLupusDingoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Canis lupus dingo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CanisLupusDingoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "286419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "286419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "286419.clusters.proteins.v11.5.txt",
		        "sequence_path": "286419.protein.sequences.v11.5.fa",
		        "enrichment_path": "286419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "286419.protein.info.v11.5.txt",
		        "node_list_path": "286419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "286419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19034Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19034Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1481928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1481928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1481928.clusters.proteins.v11.5.txt",
		        "sequence_path": "1481928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1481928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1481928.protein.info.v11.5.txt",
		        "node_list_path": "1481928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1481928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumZeae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium zeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumZeae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1416779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416779.protein.info.v11.5.txt",
		        "node_list_path": "1416779.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalioglobusPacificus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halioglobus pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalioglobusPacificus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930806.protein.sequences.v11.5.fa",
		        "enrichment_path": "930806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930806.protein.info.v11.5.txt",
		        "node_list_path": "930806.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaTropicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia tropica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaTropicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "92647.clusters.info.v11.5.txt",
		        "cluster_tree_path": "92647.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "92647.clusters.proteins.v11.5.txt",
		        "sequence_path": "92647.protein.sequences.v11.5.fa",
		        "enrichment_path": "92647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92647.protein.info.v11.5.txt",
		        "node_list_path": "92647.cluster.nodes.v11.5.txt",
		        "edge_list_path": "92647.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UrsusAmericanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ursus americanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UrsusAmericanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9643.protein.sequences.v11.5.fa",
		        "enrichment_path": "9643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9643.protein.info.v11.5.txt",
		        "node_list_path": "9643.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChthoniobacterFlavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chthoniobacter flavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChthoniobacterFlavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "497964.clusters.info.v11.5.txt",
		        "cluster_tree_path": "497964.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "497964.clusters.proteins.v11.5.txt",
		        "sequence_path": "497964.protein.sequences.v11.5.fa",
		        "enrichment_path": "497964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "497964.protein.info.v11.5.txt",
		        "node_list_path": "497964.cluster.nodes.v11.5.txt",
		        "edge_list_path": "497964.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKomeilibacteriaBacteriumRifcsplowo201Full4510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_01_FULL_45_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo201Full4510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798550.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798550.protein.info.v11.5.txt",
		        "node_list_path": "1798550.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrobaculumIslandicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum islandicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumIslandicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "384616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "384616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "384616.clusters.proteins.v11.5.txt",
		        "sequence_path": "384616.protein.sequences.v11.5.fa",
		        "enrichment_path": "384616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "384616.protein.info.v11.5.txt",
		        "node_list_path": "384616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "384616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodotorulaDiobovataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula diobovata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodotorulaDiobovataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5288.clusters.proteins.v11.5.txt",
		        "sequence_path": "5288.protein.sequences.v11.5.fa",
		        "enrichment_path": "5288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5288.protein.info.v11.5.txt",
		        "node_list_path": "5288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastococcusEndophyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus endophyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusEndophyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "673521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "673521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "673521.clusters.proteins.v11.5.txt",
		        "sequence_path": "673521.protein.sequences.v11.5.fa",
		        "enrichment_path": "673521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "673521.protein.info.v11.5.txt",
		        "node_list_path": "673521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "673521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpSoil805(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil805 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpSoil805", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736416.protein.info.v11.5.txt",
		        "node_list_path": "1736416.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumCg2303166Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG2_30_31_66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumCg2303166Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805159.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805159.protein.info.v11.5.txt",
		        "node_list_path": "1805159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaLascolaii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella lascolaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaLascolaii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776379.protein.info.v11.5.txt",
		        "node_list_path": "1776379.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollinsellaPhocaeensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collinsella phocaeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaPhocaeensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871016.protein.info.v11.5.txt",
		        "node_list_path": "1871016.protein.complete.v11.5.txt"
		    }
		]
    )()

def PiscibacillusSalipiscariusJcm13188(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Piscibacillus salipiscarius JCM 13188 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiscibacillusSalipiscariusJcm13188", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1294022.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294022.protein.info.v11.5.txt",
		        "node_list_path": "1294022.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfurobacteriumIndicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurobacterium indicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurobacteriumIndicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1914305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1914305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1914305.protein.info.v11.5.txt",
		        "node_list_path": "1914305.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalolaminaSpCba1230(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halolamina sp. CBA1230 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolaminaSpCba1230", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1853690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1853690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1853690.protein.info.v11.5.txt",
		        "node_list_path": "1853690.protein.complete.v11.5.txt"
		    }
		]
    )()

def BipolarisOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "101162.protein.sequences.v11.5.fa",
		        "enrichment_path": "101162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101162.protein.info.v11.5.txt",
		        "node_list_path": "101162.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSpSk12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSpSk12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1454001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1454001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1454001.clusters.proteins.v11.5.txt",
		        "sequence_path": "1454001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454001.protein.info.v11.5.txt",
		        "node_list_path": "1454001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1454001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpGd7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. GD7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpGd7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232427.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232427.protein.info.v11.5.txt",
		        "node_list_path": "1232427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaXiamenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaXiamenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "332186.protein.sequences.v11.5.fa",
		        "enrichment_path": "332186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332186.protein.info.v11.5.txt",
		        "node_list_path": "332186.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpP6w(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. P6W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpP6w", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1609758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1609758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1609758.protein.info.v11.5.txt",
		        "node_list_path": "1609758.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpHun102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. HUN102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpHun102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392486.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392486.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392486.protein.info.v11.5.txt",
		        "node_list_path": "1392486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudovibrioStylochi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio stylochi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioStylochi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807766.protein.info.v11.5.txt",
		        "node_list_path": "1807766.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrioBacteriovorusWCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrioBacteriovorusWCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765869.clusters.proteins.v11.5.txt",
		        "sequence_path": "765869.protein.sequences.v11.5.fa",
		        "enrichment_path": "765869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765869.protein.info.v11.5.txt",
		        "node_list_path": "765869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaYeatsiiGm274bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma yeatsii GM274B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaYeatsiiGm274bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743967.clusters.proteins.v11.5.txt",
		        "sequence_path": "743967.protein.sequences.v11.5.fa",
		        "enrichment_path": "743967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743967.protein.info.v11.5.txt",
		        "node_list_path": "743967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EikenellaCorrodensAtcc23834(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eikenella corrodens ATCC23834 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EikenellaCorrodensAtcc23834", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546274.protein.sequences.v11.5.fa",
		        "enrichment_path": "546274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546274.protein.info.v11.5.txt",
		        "node_list_path": "546274.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpF0429Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0429 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpF0429Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1127695.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1127695.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1127695.clusters.proteins.v11.5.txt",
		        "sequence_path": "1127695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127695.protein.info.v11.5.txt",
		        "node_list_path": "1127695.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1127695.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMmg1533(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MMG1533 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMmg1533", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415546.protein.info.v11.5.txt",
		        "node_list_path": "1415546.protein.complete.v11.5.txt"
		    }
		]
    )()

def MariprofundusMicoguttaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mariprofundus micogutta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MariprofundusMicoguttaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1921010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1921010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1921010.clusters.proteins.v11.5.txt",
		        "sequence_path": "1921010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921010.protein.info.v11.5.txt",
		        "node_list_path": "1921010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1921010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDoolittleaEndobia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doolittlea endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoolittleaEndobia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1778262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1778262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1778262.protein.info.v11.5.txt",
		        "node_list_path": "1778262.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusCaballiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus caballi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusCaballiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123298.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123298.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123298.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123298.protein.info.v11.5.txt",
		        "node_list_path": "1123298.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123298.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlantibacterFlavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plantibacter flavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlantibacterFlavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "150123.protein.sequences.v11.5.fa",
		        "enrichment_path": "150123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150123.protein.info.v11.5.txt",
		        "node_list_path": "150123.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesPhaeoluteigriseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces phaeoluteigriseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPhaeoluteigriseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "114686.protein.sequences.v11.5.fa",
		        "enrichment_path": "114686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "114686.protein.info.v11.5.txt",
		        "node_list_path": "114686.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoraliomargaritaSpCag312(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coraliomargarita sp. CAG:312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoraliomargaritaSpCag312", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262865.protein.info.v11.5.txt",
		        "node_list_path": "1262865.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumDefluviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium defluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumDefluviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "370979.clusters.info.v11.5.txt",
		        "cluster_tree_path": "370979.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "370979.clusters.proteins.v11.5.txt",
		        "sequence_path": "370979.protein.sequences.v11.5.fa",
		        "enrichment_path": "370979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "370979.protein.info.v11.5.txt",
		        "node_list_path": "370979.cluster.nodes.v11.5.txt",
		        "edge_list_path": "370979.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasEnteropelogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas enteropelogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasEnteropelogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29489.protein.sequences.v11.5.fa",
		        "enrichment_path": "29489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29489.protein.info.v11.5.txt",
		        "node_list_path": "29489.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusOryziterrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus oryziterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusOryziterrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1191699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1191699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1191699.protein.info.v11.5.txt",
		        "node_list_path": "1191699.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpAap43(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. AAP43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpAap43", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523420.protein.info.v11.5.txt",
		        "node_list_path": "1523420.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchizophyllumCommuneH48Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizophyllum commune H4-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizophyllumCommuneH48Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "578458.clusters.info.v11.5.txt",
		        "cluster_tree_path": "578458.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "578458.clusters.proteins.v11.5.txt",
		        "sequence_path": "578458.protein.sequences.v11.5.fa",
		        "enrichment_path": "578458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578458.protein.info.v11.5.txt",
		        "node_list_path": "578458.cluster.nodes.v11.5.txt",
		        "edge_list_path": "578458.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaIowaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma iowae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaIowaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1048830.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1048830.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1048830.clusters.proteins.v11.5.txt",
		        "sequence_path": "1048830.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048830.protein.info.v11.5.txt",
		        "node_list_path": "1048830.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1048830.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusFasciansD188Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus fascians D188 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusFasciansD188Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1051973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1051973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1051973.clusters.proteins.v11.5.txt",
		        "sequence_path": "1051973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051973.protein.info.v11.5.txt",
		        "node_list_path": "1051973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1051973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "390242.clusters.info.v11.5.txt",
		        "cluster_tree_path": "390242.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "390242.clusters.proteins.v11.5.txt",
		        "sequence_path": "390242.protein.sequences.v11.5.fa",
		        "enrichment_path": "390242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390242.protein.info.v11.5.txt",
		        "node_list_path": "390242.cluster.nodes.v11.5.txt",
		        "edge_list_path": "390242.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmatimonasAurantiaca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonas aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonasAurantiaca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "379066.protein.sequences.v11.5.fa",
		        "enrichment_path": "379066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "379066.protein.info.v11.5.txt",
		        "node_list_path": "379066.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaOulorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oulorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOulorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28136.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28136.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28136.clusters.proteins.v11.5.txt",
		        "sequence_path": "28136.protein.sequences.v11.5.fa",
		        "enrichment_path": "28136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28136.protein.info.v11.5.txt",
		        "node_list_path": "28136.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28136.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RunellaLimosaDsm17973Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Runella limosa DSM 17973 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RunellaLimosaDsm17973Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123077.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123077.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123077.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123077.protein.info.v11.5.txt",
		        "node_list_path": "1123077.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123077.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLeaf155Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf155 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLeaf155Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736278.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736278.protein.info.v11.5.txt",
		        "node_list_path": "1736278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JejuiaPallidilutea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jejuia pallidilutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JejuiaPallidilutea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "504487.protein.sequences.v11.5.fa",
		        "enrichment_path": "504487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504487.protein.info.v11.5.txt",
		        "node_list_path": "504487.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumAcidisoliDsm12555Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acidisoli DSM 12555 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAcidisoliDsm12555Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121291.protein.info.v11.5.txt",
		        "node_list_path": "1121291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophusFodinaeScgcAaa011A17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophus fodinae SCGC AAA011-A17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophusFodinaeScgcAaa011A17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "699264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "699264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "699264.clusters.proteins.v11.5.txt",
		        "sequence_path": "699264.protein.sequences.v11.5.fa",
		        "enrichment_path": "699264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "699264.protein.info.v11.5.txt",
		        "node_list_path": "699264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "699264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlleyaNamhaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olleya namhaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlleyaNamhaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144750.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144750.protein.info.v11.5.txt",
		        "node_list_path": "1144750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KinetoplastibacteriumGalatiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium galatii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KinetoplastibacteriumGalatiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208921.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208921.protein.info.v11.5.txt",
		        "node_list_path": "1208921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag253(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:253 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag253", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262785.protein.info.v11.5.txt",
		        "node_list_path": "1262785.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParasaccharibacterApiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parasaccharibacter apium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParasaccharibacterApiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1510841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1510841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1510841.clusters.proteins.v11.5.txt",
		        "sequence_path": "1510841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1510841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1510841.protein.info.v11.5.txt",
		        "node_list_path": "1510841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1510841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumAurantiacumDsm6208(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium aurantiacum DSM 6208 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumAurantiacumDsm6208", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397694.protein.info.v11.5.txt",
		        "node_list_path": "1397694.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSpIng2D1g(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. ING2-D1G graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSpIng2D1g", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1912856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912856.protein.info.v11.5.txt",
		        "node_list_path": "1912856.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCoatesbacteriaBacteriumRbg136614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Coatesbacteria bacterium RBG_13_66_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCoatesbacteriaBacteriumRbg136614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817816.protein.info.v11.5.txt",
		        "node_list_path": "1817816.protein.complete.v11.5.txt"
		    }
		]
    )()

def BilophilaWadsworthiaAtcc49260Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia ATCC49260 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BilophilaWadsworthiaAtcc49260Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408428.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408428.protein.info.v11.5.txt",
		        "node_list_path": "1408428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumAquaticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium aquaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumAquaticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "270351.clusters.info.v11.5.txt",
		        "cluster_tree_path": "270351.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "270351.clusters.proteins.v11.5.txt",
		        "sequence_path": "270351.protein.sequences.v11.5.fa",
		        "enrichment_path": "270351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "270351.protein.info.v11.5.txt",
		        "node_list_path": "270351.cluster.nodes.v11.5.txt",
		        "edge_list_path": "270351.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPollutisoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pollutisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPollutisoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1610489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1610489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1610489.protein.info.v11.5.txt",
		        "node_list_path": "1610489.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProfftellaArmaturaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Profftella armatura Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProfftellaArmaturaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "669502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "669502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "669502.clusters.proteins.v11.5.txt",
		        "sequence_path": "669502.protein.sequences.v11.5.fa",
		        "enrichment_path": "669502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "669502.protein.info.v11.5.txt",
		        "node_list_path": "669502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "669502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanktomarinaTemperataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planktomarina temperata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktomarinaTemperataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "666509.clusters.info.v11.5.txt",
		        "cluster_tree_path": "666509.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "666509.clusters.proteins.v11.5.txt",
		        "sequence_path": "666509.protein.sequences.v11.5.fa",
		        "enrichment_path": "666509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "666509.protein.info.v11.5.txt",
		        "node_list_path": "666509.cluster.nodes.v11.5.txt",
		        "edge_list_path": "666509.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnormaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enorma massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnormaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118060.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118060.protein.info.v11.5.txt",
		        "node_list_path": "1118060.protein.complete.v11.5.txt"
		    }
		]
    )()

def CrocodylusPorosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crocodylus porosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrocodylusPorosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8502.protein.sequences.v11.5.fa",
		        "enrichment_path": "8502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8502.protein.info.v11.5.txt",
		        "node_list_path": "8502.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpAmel2xe9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Amel2xE9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpAmel2xe9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157634.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157634.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157634.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157634.protein.info.v11.5.txt",
		        "node_list_path": "1157634.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157634.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaToletanaDappPg735Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia toletana DAPP-PG 735 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaToletanaDappPg735Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1274722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1274722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1274722.clusters.proteins.v11.5.txt",
		        "sequence_path": "1274722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274722.protein.info.v11.5.txt",
		        "node_list_path": "1274722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1274722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGa0077527(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077527 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077527", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752200.protein.info.v11.5.txt",
		        "node_list_path": "1752200.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag617(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:617 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag617", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262933.protein.info.v11.5.txt",
		        "node_list_path": "1262933.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoorellaThermoaceticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moorella thermoacetica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoorellaThermoaceticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264732.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264732.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264732.clusters.proteins.v11.5.txt",
		        "sequence_path": "264732.protein.sequences.v11.5.fa",
		        "enrichment_path": "264732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264732.protein.info.v11.5.txt",
		        "node_list_path": "264732.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264732.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSparsogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sparsogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSparsogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67365.clusters.proteins.v11.5.txt",
		        "sequence_path": "67365.protein.sequences.v11.5.fa",
		        "enrichment_path": "67365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67365.protein.info.v11.5.txt",
		        "node_list_path": "67365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaToletanaDappPg735(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia toletana DAPP-PG 735 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaToletanaDappPg735", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1274722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274722.protein.info.v11.5.txt",
		        "node_list_path": "1274722.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlleyaSpVcsm12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olleya sp. VCSM12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlleyaSpVcsm12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "745718.protein.sequences.v11.5.fa",
		        "enrichment_path": "745718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745718.protein.info.v11.5.txt",
		        "node_list_path": "745718.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSpEjy3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. EJY3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpEjy3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1116375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1116375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1116375.clusters.proteins.v11.5.txt",
		        "sequence_path": "1116375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116375.protein.info.v11.5.txt",
		        "node_list_path": "1116375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1116375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumOceanosedimentum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium oceanosedimentum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumOceanosedimentum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "465820.protein.sequences.v11.5.fa",
		        "enrichment_path": "465820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "465820.protein.info.v11.5.txt",
		        "node_list_path": "465820.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinococcusHalotoleransDsm16375Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinococcus halotolerans DSM 16375 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinococcusHalotoleransDsm16375Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122203.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122203.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122203.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122203.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122203.protein.info.v11.5.txt",
		        "node_list_path": "1122203.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122203.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifoxyc12Full3613Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYC12_FULL_36_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxyc12Full3613Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801654.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801654.protein.info.v11.5.txt",
		        "node_list_path": "1801654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BalneolaVulgaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Balneola vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BalneolaVulgaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121104.protein.info.v11.5.txt",
		        "node_list_path": "1121104.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesFlavidovirens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavidovirens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesFlavidovirens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123319.protein.info.v11.5.txt",
		        "node_list_path": "1123319.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasCoronafaciensPvPorriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas coronafaciens pv. porri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCoronafaciensPvPorriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83964.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83964.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83964.clusters.proteins.v11.5.txt",
		        "sequence_path": "83964.protein.sequences.v11.5.fa",
		        "enrichment_path": "83964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83964.protein.info.v11.5.txt",
		        "node_list_path": "83964.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83964.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumAurumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium aurum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumAurumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36805.clusters.proteins.v11.5.txt",
		        "sequence_path": "36805.protein.sequences.v11.5.fa",
		        "enrichment_path": "36805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36805.protein.info.v11.5.txt",
		        "node_list_path": "36805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpR1ns10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. R1NS10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpR1ns10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1306990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1306990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1306990.clusters.proteins.v11.5.txt",
		        "sequence_path": "1306990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306990.protein.info.v11.5.txt",
		        "node_list_path": "1306990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1306990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TepidibacillusDecaturensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tepidibacillus decaturensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidibacillusDecaturensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1413211.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1413211.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1413211.clusters.proteins.v11.5.txt",
		        "sequence_path": "1413211.protein.sequences.v11.5.fa",
		        "enrichment_path": "1413211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1413211.protein.info.v11.5.txt",
		        "node_list_path": "1413211.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1413211.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMediterraneensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mediterraneensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMediterraneensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805474.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805474.protein.info.v11.5.txt",
		        "node_list_path": "1805474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpEhn04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. EhN04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpEhn04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849167.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849167.protein.info.v11.5.txt",
		        "node_list_path": "1849167.protein.complete.v11.5.txt"
		    }
		]
    )()

def FonsecaeaMultimorphosaCbs102226(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fonsecaea multimorphosa CBS 102226 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FonsecaeaMultimorphosaCbs102226", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1442371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1442371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1442371.protein.info.v11.5.txt",
		        "node_list_path": "1442371.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumClostridioforme2149faa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium clostridioforme 2149FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumClostridioforme2149faa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742735.protein.sequences.v11.5.fa",
		        "enrichment_path": "742735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742735.protein.info.v11.5.txt",
		        "node_list_path": "742735.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriovoraxMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriovoraxMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "862908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "862908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "862908.clusters.proteins.v11.5.txt",
		        "sequence_path": "862908.protein.sequences.v11.5.fa",
		        "enrichment_path": "862908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862908.protein.info.v11.5.txt",
		        "node_list_path": "862908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "862908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCasei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus casei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCasei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1582.protein.info.v11.5.txt",
		        "node_list_path": "1582.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAmycolatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium amycolatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAmycolatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553204.clusters.proteins.v11.5.txt",
		        "sequence_path": "553204.protein.sequences.v11.5.fa",
		        "enrichment_path": "553204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553204.protein.info.v11.5.txt",
		        "node_list_path": "553204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumArgentinense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium argentinense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumArgentinense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29341.protein.sequences.v11.5.fa",
		        "enrichment_path": "29341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29341.protein.info.v11.5.txt",
		        "node_list_path": "29341.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisNigrescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis nigrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisNigrescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1068980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1068980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1068980.protein.info.v11.5.txt",
		        "node_list_path": "1068980.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusThermoamylovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus thermoamylovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusThermoamylovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35841.clusters.proteins.v11.5.txt",
		        "sequence_path": "35841.protein.sequences.v11.5.fa",
		        "enrichment_path": "35841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35841.protein.info.v11.5.txt",
		        "node_list_path": "35841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeleribacterBaekdonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Celeribacter baekdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeleribacterBaekdonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208323.protein.info.v11.5.txt",
		        "node_list_path": "1208323.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasAnticariensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas anticariensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasAnticariensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121939.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121939.protein.info.v11.5.txt",
		        "node_list_path": "1121939.protein.complete.v11.5.txt"
		    }
		]
    )()

def AestuariibacterSalexigens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aestuariibacter salexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AestuariibacterSalexigens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120953.protein.info.v11.5.txt",
		        "node_list_path": "1120953.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumRifcsphigho212Full4012Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_12_FULL_40_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho212Full4012Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802457.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802457.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802457.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802457.protein.info.v11.5.txt",
		        "node_list_path": "1802457.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802457.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaGuanche(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila guanche graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaGuanche", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7266.protein.sequences.v11.5.fa",
		        "enrichment_path": "7266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7266.protein.info.v11.5.txt",
		        "node_list_path": "7266.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGastranaerophilalesBacteriumHum1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium HUM_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumHum1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1916322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1916322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1916322.clusters.proteins.v11.5.txt",
		        "sequence_path": "1916322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1916322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1916322.protein.info.v11.5.txt",
		        "node_list_path": "1916322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1916322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomonasArsenitoxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas arsenitoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomonasArsenitoxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426114.clusters.proteins.v11.5.txt",
		        "sequence_path": "426114.protein.sequences.v11.5.fa",
		        "enrichment_path": "426114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426114.protein.info.v11.5.txt",
		        "node_list_path": "426114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulosimicrobiumFunkeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulosimicrobium funkei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulosimicrobiumFunkeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264251.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264251.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264251.clusters.proteins.v11.5.txt",
		        "sequence_path": "264251.protein.sequences.v11.5.fa",
		        "enrichment_path": "264251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264251.protein.info.v11.5.txt",
		        "node_list_path": "264251.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264251.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachanceaLanzarotensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachancea lanzarotensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachanceaLanzarotensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1245769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245769.protein.info.v11.5.txt",
		        "node_list_path": "1245769.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaUreae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina ureae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaUreae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123290.protein.info.v11.5.txt",
		        "node_list_path": "1123290.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudorhodoferaxSpLeaf267Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf267 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodoferaxSpLeaf267Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736316.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736316.protein.info.v11.5.txt",
		        "node_list_path": "1736316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeersiaPerrieriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leersia perrieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeersiaPerrieriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "77586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "77586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "77586.clusters.proteins.v11.5.txt",
		        "sequence_path": "77586.protein.sequences.v11.5.fa",
		        "enrichment_path": "77586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77586.protein.info.v11.5.txt",
		        "node_list_path": "77586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "77586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LinderinaPennisporaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Linderina pennispora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LinderinaPennisporaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61395.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61395.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61395.clusters.proteins.v11.5.txt",
		        "sequence_path": "61395.protein.sequences.v11.5.fa",
		        "enrichment_path": "61395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61395.protein.info.v11.5.txt",
		        "node_list_path": "61395.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61395.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumS85Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium S85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumS85Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1042376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1042376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1042376.clusters.proteins.v11.5.txt",
		        "sequence_path": "1042376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042376.protein.info.v11.5.txt",
		        "node_list_path": "1042376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1042376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParvularculaOceaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parvularcula oceani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvularculaOceaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1247963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1247963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1247963.clusters.proteins.v11.5.txt",
		        "sequence_path": "1247963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1247963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1247963.protein.info.v11.5.txt",
		        "node_list_path": "1247963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1247963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpAt1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. AT1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpAt1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "574934.protein.sequences.v11.5.fa",
		        "enrichment_path": "574934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574934.protein.info.v11.5.txt",
		        "node_list_path": "574934.protein.complete.v11.5.txt"
		    }
		]
    )()

def FangiaHongkongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fangia hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FangiaHongkongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089439.protein.info.v11.5.txt",
		        "node_list_path": "1089439.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusFumigatusAf293Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus fumigatus Af293 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusFumigatusAf293Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "330879.clusters.info.v11.5.txt",
		        "cluster_tree_path": "330879.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "330879.clusters.proteins.v11.5.txt",
		        "sequence_path": "330879.protein.sequences.v11.5.fa",
		        "enrichment_path": "330879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "330879.protein.info.v11.5.txt",
		        "node_list_path": "330879.cluster.nodes.v11.5.txt",
		        "edge_list_path": "330879.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFrederiksbergensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas frederiksbergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFrederiksbergensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "104087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "104087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "104087.clusters.proteins.v11.5.txt",
		        "sequence_path": "104087.protein.sequences.v11.5.fa",
		        "enrichment_path": "104087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104087.protein.info.v11.5.txt",
		        "node_list_path": "104087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "104087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumMarinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumMarinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397696.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397696.protein.info.v11.5.txt",
		        "node_list_path": "1397696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylocaldumSzegedienseO12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylocaldum szegediense O-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocaldumSzegedienseO12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675524.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675524.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675524.clusters.proteins.v11.5.txt",
		        "sequence_path": "675524.protein.sequences.v11.5.fa",
		        "enrichment_path": "675524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675524.protein.info.v11.5.txt",
		        "node_list_path": "675524.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675524.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumAcmicro4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium acMicro-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumAcmicro4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1504317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504317.protein.info.v11.5.txt",
		        "node_list_path": "1504317.protein.complete.v11.5.txt"
		    }
		]
    )()

def DracunculusMedinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dracunculus medinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DracunculusMedinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "318479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "318479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "318479.clusters.proteins.v11.5.txt",
		        "sequence_path": "318479.protein.sequences.v11.5.fa",
		        "enrichment_path": "318479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318479.protein.info.v11.5.txt",
		        "node_list_path": "318479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "318479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPacebacteriaBacteriumRifcsphigho201Full4610Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFCSPHIGHO2_01_FULL_46_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifcsphigho201Full4610Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801884.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801884.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801884.protein.info.v11.5.txt",
		        "node_list_path": "1801884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumXpb1003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XPB1003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumXpb1003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520825.protein.info.v11.5.txt",
		        "node_list_path": "1520825.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFirestonebacteriaBacteriumRifoxyc2Full3967Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Firestonebacteria bacterium RIFOXYC2_FULL_39_67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFirestonebacteriaBacteriumRifoxyc2Full3967Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817861.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817861.protein.info.v11.5.txt",
		        "node_list_path": "1817861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSpAl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. AL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSpAl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "861530.protein.sequences.v11.5.fa",
		        "enrichment_path": "861530.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861530.protein.info.v11.5.txt",
		        "node_list_path": "861530.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaMuridarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia muridarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaMuridarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243161.protein.sequences.v11.5.fa",
		        "enrichment_path": "243161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243161.protein.info.v11.5.txt",
		        "node_list_path": "243161.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumFoliorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium foliorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumFoliorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "104336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "104336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "104336.clusters.proteins.v11.5.txt",
		        "sequence_path": "104336.protein.sequences.v11.5.fa",
		        "enrichment_path": "104336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104336.protein.info.v11.5.txt",
		        "node_list_path": "104336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "104336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLc145Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. LC145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLc145Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120688.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120688.protein.info.v11.5.txt",
		        "node_list_path": "1120688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpKjjCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KJJ Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpKjjCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1270193.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1270193.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1270193.clusters.proteins.v11.5.txt",
		        "sequence_path": "1270193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1270193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1270193.protein.info.v11.5.txt",
		        "node_list_path": "1270193.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1270193.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3610b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_36_10b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3610b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801766.protein.info.v11.5.txt",
		        "node_list_path": "1801766.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpUcdGkaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UCD-GKA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpUcdGkaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1913576.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1913576.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1913576.clusters.proteins.v11.5.txt",
		        "sequence_path": "1913576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1913576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1913576.protein.info.v11.5.txt",
		        "node_list_path": "1913576.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1913576.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalioglobusJaponicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halioglobus japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalioglobusJaponicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930805.clusters.proteins.v11.5.txt",
		        "sequence_path": "930805.protein.sequences.v11.5.fa",
		        "enrichment_path": "930805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930805.protein.info.v11.5.txt",
		        "node_list_path": "930805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpUnc345mftsu51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. UNC345MFTsu5.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpUnc345mftsu51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449070.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449070.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449070.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449070.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449070.protein.info.v11.5.txt",
		        "node_list_path": "1449070.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449070.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasAestuariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasAestuariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52441.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52441.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52441.clusters.proteins.v11.5.txt",
		        "sequence_path": "52441.protein.sequences.v11.5.fa",
		        "enrichment_path": "52441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52441.protein.info.v11.5.txt",
		        "node_list_path": "52441.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52441.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesEggerthiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides eggerthii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesEggerthiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "483216.clusters.info.v11.5.txt",
		        "cluster_tree_path": "483216.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "483216.clusters.proteins.v11.5.txt",
		        "sequence_path": "483216.protein.sequences.v11.5.fa",
		        "enrichment_path": "483216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483216.protein.info.v11.5.txt",
		        "node_list_path": "483216.cluster.nodes.v11.5.txt",
		        "edge_list_path": "483216.protein.cluster.v11.5.txt"
		    }
		]
    )()

def Bacterium2013arg42i(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium 2013Arg42i graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Bacterium2013arg42i", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1561003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561003.protein.info.v11.5.txt",
		        "node_list_path": "1561003.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwb13322(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_33_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13322", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618566.protein.info.v11.5.txt",
		        "node_list_path": "1618566.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalegentibacterSpT436Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter sp. T436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterSpT436Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729720.protein.info.v11.5.txt",
		        "node_list_path": "1729720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesIhuae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides ihuae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesIhuae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852362.protein.info.v11.5.txt",
		        "node_list_path": "1852362.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaBuccalisAtcc35310Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccalis ATCC35310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBuccalisAtcc35310Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679190.clusters.proteins.v11.5.txt",
		        "sequence_path": "679190.protein.sequences.v11.5.fa",
		        "enrichment_path": "679190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679190.protein.info.v11.5.txt",
		        "node_list_path": "679190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp155(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 155 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp155", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157943.protein.info.v11.5.txt",
		        "node_list_path": "1157943.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarivirgaSpAntB6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marivirga sp. ANT-B6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivirgaSpAntB6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1844760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1844760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1844760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1844760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1844760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1844760.protein.info.v11.5.txt",
		        "node_list_path": "1844760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1844760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTaa486(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA486 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTaa486", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298880.protein.info.v11.5.txt",
		        "node_list_path": "1298880.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpRoot1497(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. Root1497 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpRoot1497", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736474.protein.info.v11.5.txt",
		        "node_list_path": "1736474.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollimonasPratensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collimonas pratensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollimonasPratensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "279113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "279113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "279113.clusters.proteins.v11.5.txt",
		        "sequence_path": "279113.protein.sequences.v11.5.fa",
		        "enrichment_path": "279113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279113.protein.info.v11.5.txt",
		        "node_list_path": "279113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "279113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusUrinalisFb127cna2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus urinalis FB127CNA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusUrinalisFb127cna2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883168.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883168.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883168.clusters.proteins.v11.5.txt",
		        "sequence_path": "883168.protein.sequences.v11.5.fa",
		        "enrichment_path": "883168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883168.protein.info.v11.5.txt",
		        "node_list_path": "883168.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883168.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumSaccharovorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum saccharovorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumSaccharovorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227484.protein.info.v11.5.txt",
		        "node_list_path": "1227484.protein.complete.v11.5.txt"
		    }
		]
    )()

def HirschiaMaritimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hirschia maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HirschiaMaritimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "551275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "551275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "551275.clusters.proteins.v11.5.txt",
		        "sequence_path": "551275.protein.sequences.v11.5.fa",
		        "enrichment_path": "551275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551275.protein.info.v11.5.txt",
		        "node_list_path": "551275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "551275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpNdb2meth1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. NDB2Meth1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpNdb2meth1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1892847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1892847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1892847.clusters.proteins.v11.5.txt",
		        "sequence_path": "1892847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892847.protein.info.v11.5.txt",
		        "node_list_path": "1892847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1892847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanotorrisIgneusKol5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanotorris igneus Kol 5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanotorrisIgneusKol5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "880724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "880724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "880724.clusters.proteins.v11.5.txt",
		        "sequence_path": "880724.protein.sequences.v11.5.fa",
		        "enrichment_path": "880724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880724.protein.info.v11.5.txt",
		        "node_list_path": "880724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "880724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumKnowlesiStrainH(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium knowlesi strain H graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumKnowlesiStrainH", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5851.protein.sequences.v11.5.fa",
		        "enrichment_path": "5851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5851.protein.info.v11.5.txt",
		        "node_list_path": "5851.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxSp19m6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. 19m6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxSp19m6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1177154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177154.protein.info.v11.5.txt",
		        "node_list_path": "1177154.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShinellaSpDd12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shinella sp. DD12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShinellaSpDd12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410620.protein.info.v11.5.txt",
		        "node_list_path": "1410620.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaFungorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia fungorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaFungorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "134537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "134537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "134537.clusters.proteins.v11.5.txt",
		        "sequence_path": "134537.protein.sequences.v11.5.fa",
		        "enrichment_path": "134537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134537.protein.info.v11.5.txt",
		        "node_list_path": "134537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "134537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharothrixSpNrrlB16348(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharothrix sp. NRRL B-16348 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharothrixSpNrrlB16348", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415542.protein.info.v11.5.txt",
		        "node_list_path": "1415542.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMycoplasmaHaemolamaeStrPurdueCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemolamae str. Purdue Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMycoplasmaHaemolamaeStrPurdueCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1212765.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1212765.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1212765.clusters.proteins.v11.5.txt",
		        "sequence_path": "1212765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1212765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1212765.protein.info.v11.5.txt",
		        "node_list_path": "1212765.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1212765.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaCitreaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora citrea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaCitreaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47855.clusters.proteins.v11.5.txt",
		        "sequence_path": "47855.protein.sequences.v11.5.fa",
		        "enrichment_path": "47855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47855.protein.info.v11.5.txt",
		        "node_list_path": "47855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlloscardoviaMacacae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alloscardovia macacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloscardoviaMacacae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1160091.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160091.protein.info.v11.5.txt",
		        "node_list_path": "1160091.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprococcusPhoceensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus phoceensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprococcusPhoceensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1870993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1870993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1870993.clusters.proteins.v11.5.txt",
		        "sequence_path": "1870993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870993.protein.info.v11.5.txt",
		        "node_list_path": "1870993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1870993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpCc6Yy74Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CC6-YY-74 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpCc6Yy74Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930532.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930532.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930532.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930532.protein.info.v11.5.txt",
		        "node_list_path": "1930532.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930532.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110053(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110053 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110053", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1570342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570342.protein.info.v11.5.txt",
		        "node_list_path": "1570342.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumHaemophilumDsm44634Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium haemophilum DSM 44634 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumHaemophilumDsm44634Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1202450.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1202450.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1202450.clusters.proteins.v11.5.txt",
		        "sequence_path": "1202450.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202450.protein.info.v11.5.txt",
		        "node_list_path": "1202450.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1202450.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSpNbs1129Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora sp. NBS 11-29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSpNbs1129Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1960879.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1960879.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1960879.clusters.proteins.v11.5.txt",
		        "sequence_path": "1960879.protein.sequences.v11.5.fa",
		        "enrichment_path": "1960879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1960879.protein.info.v11.5.txt",
		        "node_list_path": "1960879.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1960879.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSp17376(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 17376 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp17376", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "977905.protein.sequences.v11.5.fa",
		        "enrichment_path": "977905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "977905.protein.info.v11.5.txt",
		        "node_list_path": "977905.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasRhizophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas rhizophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasRhizophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216778.clusters.proteins.v11.5.txt",
		        "sequence_path": "216778.protein.sequences.v11.5.fa",
		        "enrichment_path": "216778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216778.protein.info.v11.5.txt",
		        "node_list_path": "216778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AciduliprofundumBooneiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aciduliprofundum boonei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AciduliprofundumBooneiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "439481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "439481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "439481.clusters.proteins.v11.5.txt",
		        "sequence_path": "439481.protein.sequences.v11.5.fa",
		        "enrichment_path": "439481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439481.protein.info.v11.5.txt",
		        "node_list_path": "439481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "439481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaAurantiaca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaAurantiaca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "676200.protein.sequences.v11.5.fa",
		        "enrichment_path": "676200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "676200.protein.info.v11.5.txt",
		        "node_list_path": "676200.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumElephantis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium elephantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumElephantis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "81858.protein.sequences.v11.5.fa",
		        "enrichment_path": "81858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81858.protein.info.v11.5.txt",
		        "node_list_path": "81858.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumSubspPolymorphum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum subsp. polymorphum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumSubspPolymorphum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "76857.protein.sequences.v11.5.fa",
		        "enrichment_path": "76857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76857.protein.info.v11.5.txt",
		        "node_list_path": "76857.protein.complete.v11.5.txt"
		    }
		]
    )()

def BelnapiaRoseaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Belnapia rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BelnapiaRoseaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "938405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "938405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "938405.clusters.proteins.v11.5.txt",
		        "sequence_path": "938405.protein.sequences.v11.5.fa",
		        "enrichment_path": "938405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938405.protein.info.v11.5.txt",
		        "node_list_path": "938405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "938405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf238335(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_38_335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf238335", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797344.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797344.protein.info.v11.5.txt",
		        "node_list_path": "1797344.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiumSpBvorr034(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. BvORR034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiumSpBvorr034", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1396418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1396418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1396418.protein.info.v11.5.txt",
		        "node_list_path": "1396418.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusCacaonumDsm21116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus cacaonum DSM 21116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCacaonumDsm21116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423729.protein.info.v11.5.txt",
		        "node_list_path": "1423729.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalopigerSpIih3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halopiger sp. IIH3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalopigerSpIih3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293048.protein.info.v11.5.txt",
		        "node_list_path": "1293048.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarboxydothermusHydrogenoformans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carboxydothermus hydrogenoformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarboxydothermusHydrogenoformans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246194.protein.sequences.v11.5.fa",
		        "enrichment_path": "246194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246194.protein.info.v11.5.txt",
		        "node_list_path": "246194.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumMd2004Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MD2004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumMd2004Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410625.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410625.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410625.protein.info.v11.5.txt",
		        "node_list_path": "1410625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicoccusSpYb142(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus sp. YB14-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusSpYb142", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1572701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1572701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1572701.protein.info.v11.5.txt",
		        "node_list_path": "1572701.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterIcosiumassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter icosiumassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterIcosiumassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1792835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792835.protein.info.v11.5.txt",
		        "node_list_path": "1792835.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemmatimonasAurantiacaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonas aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonasAurantiacaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "379066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "379066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "379066.clusters.proteins.v11.5.txt",
		        "sequence_path": "379066.protein.sequences.v11.5.fa",
		        "enrichment_path": "379066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "379066.protein.info.v11.5.txt",
		        "node_list_path": "379066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "379066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusParainfluenzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus parainfluenzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusParainfluenzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "862965.protein.sequences.v11.5.fa",
		        "enrichment_path": "862965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862965.protein.info.v11.5.txt",
		        "node_list_path": "862965.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumTimonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium timonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumTimonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203190.protein.info.v11.5.txt",
		        "node_list_path": "1203190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesCryophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces cryophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesCryophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "866546.protein.sequences.v11.5.fa",
		        "enrichment_path": "866546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866546.protein.info.v11.5.txt",
		        "node_list_path": "866546.protein.complete.v11.5.txt"
		    }
		]
    )()

def SciscionellaMarinaDsm45152Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sciscionella marina DSM 45152 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SciscionellaMarinaDsm45152Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123244.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123244.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123244.protein.info.v11.5.txt",
		        "node_list_path": "1123244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpUrhd0057Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. URHD0057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpUrhd0057Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380389.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380389.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380389.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380389.protein.info.v11.5.txt",
		        "node_list_path": "1380389.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380389.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeratocystisFimbriataCbs114723(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ceratocystis fimbriata CBS 114723 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeratocystisFimbriataCbs114723", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035309.protein.info.v11.5.txt",
		        "node_list_path": "1035309.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpB04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. B04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpB04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945860.protein.info.v11.5.txt",
		        "node_list_path": "1945860.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusChampanellensis18p13Jcm17042(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus champanellensis 18P13 JCM 17042 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusChampanellensis18p13Jcm17042", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "213810.protein.sequences.v11.5.fa",
		        "enrichment_path": "213810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "213810.protein.info.v11.5.txt",
		        "node_list_path": "213810.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureobasidiumNamibiaeCbs14797(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium namibiae CBS 147.97 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureobasidiumNamibiaeCbs14797", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1043004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1043004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1043004.protein.info.v11.5.txt",
		        "node_list_path": "1043004.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRifcsplowo202Full6128(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO2_02_FULL_61_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202Full6128", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797180.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797180.protein.info.v11.5.txt",
		        "node_list_path": "1797180.protein.complete.v11.5.txt"
		    }
		]
    )()

def LihuaxuellaThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lihuaxuella thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LihuaxuellaThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173111.protein.info.v11.5.txt",
		        "node_list_path": "1173111.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesQuadriannulatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles quadriannulatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesQuadriannulatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34691.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34691.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34691.clusters.proteins.v11.5.txt",
		        "sequence_path": "34691.protein.sequences.v11.5.fa",
		        "enrichment_path": "34691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34691.protein.info.v11.5.txt",
		        "node_list_path": "34691.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34691.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylocystisSpAtcc49242(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylocystis sp. ATCC49242 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocystisSpAtcc49242", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "622637.protein.sequences.v11.5.fa",
		        "enrichment_path": "622637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "622637.protein.info.v11.5.txt",
		        "node_list_path": "622637.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusDaliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus daliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusDaliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "745820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "745820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "745820.clusters.proteins.v11.5.txt",
		        "sequence_path": "745820.protein.sequences.v11.5.fa",
		        "enrichment_path": "745820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745820.protein.info.v11.5.txt",
		        "node_list_path": "745820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "745820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanococcusMaritimusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planococcus maritimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusMaritimusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "192421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "192421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "192421.clusters.proteins.v11.5.txt",
		        "sequence_path": "192421.protein.sequences.v11.5.fa",
		        "enrichment_path": "192421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192421.protein.info.v11.5.txt",
		        "node_list_path": "192421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "192421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodoferaxFerrireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodoferax ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodoferaxFerrireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "338969.protein.sequences.v11.5.fa",
		        "enrichment_path": "338969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "338969.protein.info.v11.5.txt",
		        "node_list_path": "338969.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumMs0242aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium MS0242A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumMs0242aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "487796.clusters.info.v11.5.txt",
		        "cluster_tree_path": "487796.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "487796.clusters.proteins.v11.5.txt",
		        "sequence_path": "487796.protein.sequences.v11.5.fa",
		        "enrichment_path": "487796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487796.protein.info.v11.5.txt",
		        "node_list_path": "487796.cluster.nodes.v11.5.txt",
		        "edge_list_path": "487796.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeitlerinemaSpPcc7105Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC 7105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeitlerinemaSpPcc7105Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "102127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "102127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "102127.clusters.proteins.v11.5.txt",
		        "sequence_path": "102127.protein.sequences.v11.5.fa",
		        "enrichment_path": "102127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102127.protein.info.v11.5.txt",
		        "node_list_path": "102127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "102127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSpNdb2meth4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. NDB2Meth4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSpNdb2meth4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1892846.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892846.protein.info.v11.5.txt",
		        "node_list_path": "1892846.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotogaThermarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga thermarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaThermarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "688269.protein.sequences.v11.5.fa",
		        "enrichment_path": "688269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688269.protein.info.v11.5.txt",
		        "node_list_path": "688269.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrospiraNitrosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira nitrosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrospiraNitrosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1742972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742972.protein.info.v11.5.txt",
		        "node_list_path": "1742972.protein.complete.v11.5.txt"
		    }
		]
    )()

def NostocSpPcc7107(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocSpPcc7107", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "317936.protein.sequences.v11.5.fa",
		        "enrichment_path": "317936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317936.protein.info.v11.5.txt",
		        "node_list_path": "317936.protein.complete.v11.5.txt"
		    }
		]
    )()

def CrocodylusPorosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crocodylus porosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrocodylusPorosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8502.clusters.proteins.v11.5.txt",
		        "sequence_path": "8502.protein.sequences.v11.5.fa",
		        "enrichment_path": "8502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8502.protein.info.v11.5.txt",
		        "node_list_path": "8502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodospirillalesBacteriumUrhd0017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium URHD0017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillalesBacteriumUrhd0017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380357.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380357.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380357.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380357.protein.info.v11.5.txt",
		        "node_list_path": "1380357.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380357.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfuromonasSpDdh964Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromonas sp. DDH964 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromonasSpDdh964Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1823759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1823759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1823759.clusters.proteins.v11.5.txt",
		        "sequence_path": "1823759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1823759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1823759.protein.info.v11.5.txt",
		        "node_list_path": "1823759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1823759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaAurantiacaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaAurantiacaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644283.clusters.proteins.v11.5.txt",
		        "sequence_path": "644283.protein.sequences.v11.5.fa",
		        "enrichment_path": "644283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644283.protein.info.v11.5.txt",
		        "node_list_path": "644283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumSpP610X1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium sp. P6-10-X1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumSpP610X1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1903186.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1903186.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1903186.clusters.proteins.v11.5.txt",
		        "sequence_path": "1903186.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903186.protein.info.v11.5.txt",
		        "node_list_path": "1903186.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1903186.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GracilimonasTropica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gracilimonas tropica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilimonasTropica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121930.protein.info.v11.5.txt",
		        "node_list_path": "1121930.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium101Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium101Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235800.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235800.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235800.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235800.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235800.protein.info.v11.5.txt",
		        "node_list_path": "1235800.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235800.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonlabensSpYik11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens sp. YIK11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensSpYik11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1453349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453349.protein.info.v11.5.txt",
		        "node_list_path": "1453349.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumHalophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum halophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumHalophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "413816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "413816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "413816.clusters.proteins.v11.5.txt",
		        "sequence_path": "413816.protein.sequences.v11.5.fa",
		        "enrichment_path": "413816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "413816.protein.info.v11.5.txt",
		        "node_list_path": "413816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "413816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevrieseaAgamarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devriesea agamarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevrieseaAgamarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "472569.clusters.info.v11.5.txt",
		        "cluster_tree_path": "472569.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "472569.clusters.proteins.v11.5.txt",
		        "sequence_path": "472569.protein.sequences.v11.5.fa",
		        "enrichment_path": "472569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472569.protein.info.v11.5.txt",
		        "node_list_path": "472569.cluster.nodes.v11.5.txt",
		        "edge_list_path": "472569.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycetalesBacteriumActino02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomycetales bacterium Actino_02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycetalesBacteriumActino02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674809.protein.info.v11.5.txt",
		        "node_list_path": "1674809.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanospirillumMultiglobuliferumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum multiglobuliferum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanospirillumMultiglobuliferumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "64969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "64969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "64969.clusters.proteins.v11.5.txt",
		        "sequence_path": "64969.protein.sequences.v11.5.fa",
		        "enrichment_path": "64969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64969.protein.info.v11.5.txt",
		        "node_list_path": "64969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "64969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HypsizygusMarmoreus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hypsizygus marmoreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HypsizygusMarmoreus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39966.protein.sequences.v11.5.fa",
		        "enrichment_path": "39966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39966.protein.info.v11.5.txt",
		        "node_list_path": "39966.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaSpLeaf51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. Leaf51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpLeaf51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736224.protein.info.v11.5.txt",
		        "node_list_path": "1736224.protein.complete.v11.5.txt"
		    }
		]
    )()

def DiplocarponRosae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Diplocarpon rosae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiplocarponRosae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "946125.protein.sequences.v11.5.fa",
		        "enrichment_path": "946125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946125.protein.info.v11.5.txt",
		        "node_list_path": "946125.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarivitaGeojedonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marivita geojedonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivitaGeojedonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123756.protein.info.v11.5.txt",
		        "node_list_path": "1123756.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag145(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag145", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263005.protein.info.v11.5.txt",
		        "node_list_path": "1263005.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzobacteroidesPseudotrichonymphae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azobacteroides pseudotrichonymphae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzobacteroidesPseudotrichonymphae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "511995.protein.sequences.v11.5.fa",
		        "enrichment_path": "511995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511995.protein.info.v11.5.txt",
		        "node_list_path": "511995.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSaccharoperbutylacetonicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium saccharoperbutylacetonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSaccharoperbutylacetonicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "931276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "931276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "931276.clusters.proteins.v11.5.txt",
		        "sequence_path": "931276.protein.sequences.v11.5.fa",
		        "enrichment_path": "931276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "931276.protein.info.v11.5.txt",
		        "node_list_path": "931276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "931276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KordiaZhangzhouensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kordia zhangzhouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KordiaZhangzhouensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1620405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1620405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1620405.protein.info.v11.5.txt",
		        "node_list_path": "1620405.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermofilumSp1910b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum sp. 1910b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermofilumSp1910b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1365176.protein.sequences.v11.5.fa",
		        "enrichment_path": "1365176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1365176.protein.info.v11.5.txt",
		        "node_list_path": "1365176.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaAlniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia alni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaAlniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326424.clusters.proteins.v11.5.txt",
		        "sequence_path": "326424.protein.sequences.v11.5.fa",
		        "enrichment_path": "326424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326424.protein.info.v11.5.txt",
		        "node_list_path": "326424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KalmanozymaBrasiliensisGhg001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kalmanozyma brasiliensis GHG001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KalmanozymaBrasiliensisGhg001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1365824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1365824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1365824.protein.info.v11.5.txt",
		        "node_list_path": "1365824.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesoplasmaSeiffertiiAtcc49495(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesoplasma seiffertii ATCC 49495 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoplasmaSeiffertiiAtcc49495", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336238.protein.info.v11.5.txt",
		        "node_list_path": "1336238.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusThermophilusLmg18311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus LMG18311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusThermophilusLmg18311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264199.protein.sequences.v11.5.fa",
		        "enrichment_path": "264199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264199.protein.info.v11.5.txt",
		        "node_list_path": "264199.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudozymaBrasiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudozymaBrasiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392244.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392244.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392244.protein.info.v11.5.txt",
		        "node_list_path": "1392244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxSp19m6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. 19m6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxSp19m6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1177154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1177154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1177154.clusters.proteins.v11.5.txt",
		        "sequence_path": "1177154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177154.protein.info.v11.5.txt",
		        "node_list_path": "1177154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1177154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacteriumSp457220Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterium sp. 4572_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteriumSp457220Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1971621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1971621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1971621.clusters.proteins.v11.5.txt",
		        "sequence_path": "1971621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971621.protein.info.v11.5.txt",
		        "node_list_path": "1971621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1971621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcusAeolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus aeolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusAeolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "419665.protein.sequences.v11.5.fa",
		        "enrichment_path": "419665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419665.protein.info.v11.5.txt",
		        "node_list_path": "419665.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674851.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674851.protein.info.v11.5.txt",
		        "node_list_path": "1674851.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo212Full6258Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_12_FULL_62_58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212Full6258Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797497.protein.info.v11.5.txt",
		        "node_list_path": "1797497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlloactinosynnemaAlbum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alloactinosynnema album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloactinosynnemaAlbum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "504798.protein.sequences.v11.5.fa",
		        "enrichment_path": "504798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504798.protein.info.v11.5.txt",
		        "node_list_path": "504798.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpUrhc0008(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. URHC0008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpUrhc0008", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380350.protein.info.v11.5.txt",
		        "node_list_path": "1380350.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusThioglobusSpRedseaS12B1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus sp. REDSEA-S12_B1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThioglobusSpRedseaS12B1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811594.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811594.protein.info.v11.5.txt",
		        "node_list_path": "1811594.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraOligosporaAtcc43269Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura oligospora ATCC 43269 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraOligosporaAtcc43269Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1399798.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1399798.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1399798.clusters.proteins.v11.5.txt",
		        "sequence_path": "1399798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399798.protein.info.v11.5.txt",
		        "node_list_path": "1399798.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1399798.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhocaeicolaAbscessusCcug55929(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phocaeicola abscessus CCUG 55929 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhocaeicolaAbscessusCcug55929", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1204719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1204719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1204719.protein.info.v11.5.txt",
		        "node_list_path": "1204719.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNeoehrlichiaLotorisStrRac413(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Neoehrlichia lotoris str. RAC413 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNeoehrlichiaLotorisStrRac413", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1359163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1359163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1359163.protein.info.v11.5.txt",
		        "node_list_path": "1359163.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSuebicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus suebicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSuebicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423807.protein.info.v11.5.txt",
		        "node_list_path": "1423807.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaAvium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella avium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaAvium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "360910.protein.sequences.v11.5.fa",
		        "enrichment_path": "360910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360910.protein.info.v11.5.txt",
		        "node_list_path": "360910.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionispiraArboris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionispira arboris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionispiraArboris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84035.protein.sequences.v11.5.fa",
		        "enrichment_path": "84035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84035.protein.info.v11.5.txt",
		        "node_list_path": "84035.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwa23217Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_32_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwa23217Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797316.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797316.protein.info.v11.5.txt",
		        "node_list_path": "1797316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpP22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpP22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "483908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "483908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "483908.clusters.proteins.v11.5.txt",
		        "sequence_path": "483908.protein.sequences.v11.5.fa",
		        "enrichment_path": "483908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483908.protein.info.v11.5.txt",
		        "node_list_path": "483908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "483908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HypoxylonSpCo275(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hypoxylon sp. CO27-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HypoxylonSpCo275", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1001938.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001938.protein.info.v11.5.txt",
		        "node_list_path": "1001938.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinitogaPiezophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinitoga piezophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinitogaPiezophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "443254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "443254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "443254.clusters.proteins.v11.5.txt",
		        "sequence_path": "443254.protein.sequences.v11.5.fa",
		        "enrichment_path": "443254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443254.protein.info.v11.5.txt",
		        "node_list_path": "443254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "443254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsphigho2024316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_43_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho2024316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798331.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798331.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798331.protein.info.v11.5.txt",
		        "node_list_path": "1798331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumExBugulaNeritinaAb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium (ex Bugula neritina AB1) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumExBugulaNeritinaAb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1868286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1868286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1868286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1868286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1868286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1868286.protein.info.v11.5.txt",
		        "node_list_path": "1868286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1868286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LynxCanadensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lynx canadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LynxCanadensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61383.clusters.proteins.v11.5.txt",
		        "sequence_path": "61383.protein.sequences.v11.5.fa",
		        "enrichment_path": "61383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61383.protein.info.v11.5.txt",
		        "node_list_path": "61383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KluyveraCryocrescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kluyvera cryocrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KluyveraCryocrescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "580.protein.sequences.v11.5.fa",
		        "enrichment_path": "580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "580.protein.info.v11.5.txt",
		        "node_list_path": "580.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumVignae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium vignae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumVignae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "690585.protein.sequences.v11.5.fa",
		        "enrichment_path": "690585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690585.protein.info.v11.5.txt",
		        "node_list_path": "690585.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinalesArchaeonMethan01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcinales archaeon Methan_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinalesArchaeonMethan01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674798.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674798.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674798.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674798.protein.info.v11.5.txt",
		        "node_list_path": "1674798.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674798.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedArchaeonA07hr67Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HR67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedArchaeonA07hr67Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1412871.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1412871.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1412871.clusters.proteins.v11.5.txt",
		        "sequence_path": "1412871.protein.sequences.v11.5.fa",
		        "enrichment_path": "1412871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1412871.protein.info.v11.5.txt",
		        "node_list_path": "1412871.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1412871.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FischerellaSpPcc9605(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FischerellaSpPcc9605", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173024.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173024.protein.info.v11.5.txt",
		        "node_list_path": "1173024.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpUnc358mftsu51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. UNC358MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpUnc358mftsu51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449049.protein.info.v11.5.txt",
		        "node_list_path": "1449049.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudozymaHubeiensisSy62(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma hubeiensis SY62 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudozymaHubeiensisSy62", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1305764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305764.protein.info.v11.5.txt",
		        "node_list_path": "1305764.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpF0472Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0472 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpF0472Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095752.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095752.protein.info.v11.5.txt",
		        "node_list_path": "1095752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumGallicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium gallicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumGallicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041138.protein.info.v11.5.txt",
		        "node_list_path": "1041138.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesYokosukanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces yokosukanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesYokosukanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67386.protein.sequences.v11.5.fa",
		        "enrichment_path": "67386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67386.protein.info.v11.5.txt",
		        "node_list_path": "67386.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermosediminibacterOceani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermosediminibacter oceani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosediminibacterOceani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "555079.protein.sequences.v11.5.fa",
		        "enrichment_path": "555079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555079.protein.info.v11.5.txt",
		        "node_list_path": "555079.protein.complete.v11.5.txt"
		    }
		]
    )()

def RudaeaCellulosilytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rudaea cellulosilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RudaeaCellulosilytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123073.protein.info.v11.5.txt",
		        "node_list_path": "1123073.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpEhn04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. EhN04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpEhn04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849167.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849167.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849167.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849167.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849167.protein.info.v11.5.txt",
		        "node_list_path": "1849167.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849167.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumGwa26437Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GWA2_64_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumGwa26437Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797549.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797549.protein.info.v11.5.txt",
		        "node_list_path": "1797549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfatatorAtlanticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfatator atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfatatorAtlanticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123371.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123371.protein.info.v11.5.txt",
		        "node_list_path": "1123371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogulbenkianiaSpMai1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania sp. MAI-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogulbenkianiaSpMai1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "990370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "990370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "990370.clusters.proteins.v11.5.txt",
		        "sequence_path": "990370.protein.sequences.v11.5.fa",
		        "enrichment_path": "990370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990370.protein.info.v11.5.txt",
		        "node_list_path": "990370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "990370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full4210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_42_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full4210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798285.protein.info.v11.5.txt",
		        "node_list_path": "1798285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPacebacteriaBacteriumRifoxyd1Full3927Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFOXYD1_FULL_39_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifoxyd1Full3927Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801892.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801892.protein.info.v11.5.txt",
		        "node_list_path": "1801892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg166312(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_63_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg166312", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797657.protein.info.v11.5.txt",
		        "node_list_path": "1797657.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpBv3p1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. BV3P1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpBv3p1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111130.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111130.protein.info.v11.5.txt",
		        "node_list_path": "1111130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LewinellaAgarilytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lewinella agarilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LewinellaAgarilytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "478744.protein.sequences.v11.5.fa",
		        "enrichment_path": "478744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "478744.protein.info.v11.5.txt",
		        "node_list_path": "478744.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaNbrc14164(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida NBRC14164 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaNbrc14164", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211579.protein.info.v11.5.txt",
		        "node_list_path": "1211579.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterNectaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter nectaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterNectaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392540.protein.info.v11.5.txt",
		        "node_list_path": "1392540.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpBcu110501Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. BCU110501 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpBcu110501Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "365528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "365528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "365528.clusters.proteins.v11.5.txt",
		        "sequence_path": "365528.protein.sequences.v11.5.fa",
		        "enrichment_path": "365528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "365528.protein.info.v11.5.txt",
		        "node_list_path": "365528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "365528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnabaenaSp90Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anabaena sp. 90 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabaenaSp90Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46234.clusters.proteins.v11.5.txt",
		        "sequence_path": "46234.protein.sequences.v11.5.fa",
		        "enrichment_path": "46234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46234.protein.info.v11.5.txt",
		        "node_list_path": "46234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFulvaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fulva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFulvaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743720.clusters.proteins.v11.5.txt",
		        "sequence_path": "743720.protein.sequences.v11.5.fa",
		        "enrichment_path": "743720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743720.protein.info.v11.5.txt",
		        "node_list_path": "743720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpPrwf1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. PRwf1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpPrwf1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349106.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349106.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349106.clusters.proteins.v11.5.txt",
		        "sequence_path": "349106.protein.sequences.v11.5.fa",
		        "enrichment_path": "349106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349106.protein.info.v11.5.txt",
		        "node_list_path": "349106.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349106.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GramellaForsetiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gramella forsetii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaForsetiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411154.clusters.proteins.v11.5.txt",
		        "sequence_path": "411154.protein.sequences.v11.5.fa",
		        "enrichment_path": "411154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411154.protein.info.v11.5.txt",
		        "node_list_path": "411154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoritellaSpJt01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moritella sp. JT01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoritellaSpJt01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "756698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "756698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "756698.clusters.proteins.v11.5.txt",
		        "sequence_path": "756698.protein.sequences.v11.5.fa",
		        "enrichment_path": "756698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "756698.protein.info.v11.5.txt",
		        "node_list_path": "756698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "756698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiumSpBvorr034Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. BvORR034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiumSpBvorr034Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1396418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1396418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1396418.clusters.proteins.v11.5.txt",
		        "sequence_path": "1396418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1396418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1396418.protein.info.v11.5.txt",
		        "node_list_path": "1396418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1396418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwel(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWEL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwel", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896209.protein.info.v11.5.txt",
		        "node_list_path": "1896209.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanomassiliicoccusIntestinalisIssoireMx1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomassiliicoccus intestinalis Issoire-Mx1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanomassiliicoccusIntestinalisIssoireMx1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1295009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1295009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1295009.protein.info.v11.5.txt",
		        "node_list_path": "1295009.protein.complete.v11.5.txt"
		    }
		]
    )()

def TerracoccusSp273mftsu31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terracoccus sp. 273MFTsu31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerracoccusSp273mftsu31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1172188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172188.protein.info.v11.5.txt",
		        "node_list_path": "1172188.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterPasteurianusIfo328301Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus IFO328301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterPasteurianusIfo328301Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634452.clusters.proteins.v11.5.txt",
		        "sequence_path": "634452.protein.sequences.v11.5.fa",
		        "enrichment_path": "634452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634452.protein.info.v11.5.txt",
		        "node_list_path": "634452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaDentalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella dentalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaDentalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "908937.protein.sequences.v11.5.fa",
		        "enrichment_path": "908937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908937.protein.info.v11.5.txt",
		        "node_list_path": "908937.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarum3841Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum 3841 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarum3841Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216596.clusters.info.v11.0.txt",
		        "cluster_tree_path": "216596.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "216596.clusters.proteins.v11.0.txt",
		        "sequence_path": "216596.protein.sequences.v11.0.fa",
		        "enrichment_path": "216596.protein.enrichment.terms.v11.0.txt",
		        "info_path": "216596.protein.info.v11.0.txt",
		        "node_list_path": "216596.cluster.nodes.v11.0.txt",
		        "edge_list_path": "216596.protein.cluster.v11.0.txt"
		    }
		]
    )()

def LibanicoccusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Libanicoccus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LibanicoccusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871022.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871022.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871022.protein.info.v11.5.txt",
		        "node_list_path": "1871022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumRenale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium renale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumRenale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1724.protein.info.v11.5.txt",
		        "node_list_path": "1724.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumAbikonenseNbrc16140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium abikonense NBRC 16140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumAbikonenseNbrc16140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219036.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219036.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219036.protein.info.v11.5.txt",
		        "node_list_path": "1219036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusLactarisCc59002d(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus lactaris CC59_002D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusLactarisCc59002d", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1073376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073376.protein.info.v11.5.txt",
		        "node_list_path": "1073376.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaRocourtiaeFslF6920(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria rocourtiae FSL F6-920 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaRocourtiaeFslF6920", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265846.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265846.protein.info.v11.5.txt",
		        "node_list_path": "1265846.protein.complete.v11.5.txt"
		    }
		]
    )()

def KinetoplastibacteriumOncopeltiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium oncopeltii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KinetoplastibacteriumOncopeltiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208920.protein.info.v11.5.txt",
		        "node_list_path": "1208920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusDowneiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus downei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDowneiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "904293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "904293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "904293.clusters.proteins.v11.5.txt",
		        "sequence_path": "904293.protein.sequences.v11.5.fa",
		        "enrichment_path": "904293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904293.protein.info.v11.5.txt",
		        "node_list_path": "904293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "904293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumCg1023251(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium CG1_02_32_51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumCg1023251", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805238.protein.info.v11.5.txt",
		        "node_list_path": "1805238.protein.complete.v11.5.txt"
		    }
		]
    )()

def CongregibacterLitoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Congregibacter litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CongregibacterLitoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314285.protein.sequences.v11.5.fa",
		        "enrichment_path": "314285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314285.protein.info.v11.5.txt",
		        "node_list_path": "314285.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumDicentrarchi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum dicentrarchi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumDicentrarchi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "669041.protein.sequences.v11.5.fa",
		        "enrichment_path": "669041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "669041.protein.info.v11.5.txt",
		        "node_list_path": "669041.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAnginosusF0211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus F0211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAnginosusF0211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "706437.clusters.info.v11.5.txt",
		        "cluster_tree_path": "706437.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "706437.clusters.proteins.v11.5.txt",
		        "sequence_path": "706437.protein.sequences.v11.5.fa",
		        "enrichment_path": "706437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706437.protein.info.v11.5.txt",
		        "node_list_path": "706437.cluster.nodes.v11.5.txt",
		        "edge_list_path": "706437.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag145Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag145Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263005.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263005.protein.info.v11.5.txt",
		        "node_list_path": "1263005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterPinetiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter pineti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterPinetiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1391627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1391627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1391627.clusters.proteins.v11.5.txt",
		        "sequence_path": "1391627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391627.protein.info.v11.5.txt",
		        "node_list_path": "1391627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1391627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaTyphiStrB9991cwppCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia typhi str. B9991CWPP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaTyphiStrB9991cwppCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1003202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1003202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1003202.clusters.proteins.v11.5.txt",
		        "sequence_path": "1003202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1003202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1003202.protein.info.v11.5.txt",
		        "node_list_path": "1003202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1003202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpKim(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. KIM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpKim", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1955422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1955422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1955422.protein.info.v11.5.txt",
		        "node_list_path": "1955422.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExophialaOligosperma(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exophiala oligosperma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaOligosperma", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "215243.protein.sequences.v11.5.fa",
		        "enrichment_path": "215243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215243.protein.info.v11.5.txt",
		        "node_list_path": "215243.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaBovigenitaliumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma bovigenitalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaBovigenitaliumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1188235.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1188235.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1188235.clusters.proteins.v11.5.txt",
		        "sequence_path": "1188235.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188235.protein.info.v11.5.txt",
		        "node_list_path": "1188235.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1188235.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumPullorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pullorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumPullorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437600.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437600.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437600.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437600.protein.info.v11.5.txt",
		        "node_list_path": "1437600.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437600.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxSp43bgom46mCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. 43BGOM46m Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxSp43bgom46mCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380387.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380387.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380387.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380387.protein.info.v11.5.txt",
		        "node_list_path": "1380387.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380387.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseorubiginosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseorubiginosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseorubiginosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67304.protein.sequences.v11.5.fa",
		        "enrichment_path": "67304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67304.protein.info.v11.5.txt",
		        "node_list_path": "67304.protein.complete.v11.5.txt"
		    }
		]
    )()

def RodentibacterHeylii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter heylii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterHeylii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906744.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906744.protein.info.v11.5.txt",
		        "node_list_path": "1906744.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpCzUam(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. CZ-UAM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpCzUam", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1933868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933868.protein.info.v11.5.txt",
		        "node_list_path": "1933868.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermogemmatisporaOnikobensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermogemmatispora onikobensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermogemmatisporaOnikobensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "732234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "732234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "732234.clusters.proteins.v11.5.txt",
		        "sequence_path": "732234.protein.sequences.v11.5.fa",
		        "enrichment_path": "732234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "732234.protein.info.v11.5.txt",
		        "node_list_path": "732234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "732234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacillusSpJf8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. JF8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusSpJf8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1345697.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1345697.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1345697.clusters.proteins.v11.5.txt",
		        "sequence_path": "1345697.protein.sequences.v11.5.fa",
		        "enrichment_path": "1345697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1345697.protein.info.v11.5.txt",
		        "node_list_path": "1345697.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1345697.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumCg2304152(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium CG2_30_41_52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumCg2304152", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805375.protein.info.v11.5.txt",
		        "node_list_path": "1805375.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwa25646Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_56_46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwa25646Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797922.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797922.protein.info.v11.5.txt",
		        "node_list_path": "1797922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumGranulosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium granulosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumGranulosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1292373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1292373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1292373.clusters.proteins.v11.5.txt",
		        "sequence_path": "1292373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292373.protein.info.v11.5.txt",
		        "node_list_path": "1292373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1292373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAlcaligenesNbrc14159(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alcaligenes NBRC14159 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAlcaligenesNbrc14159", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1215092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215092.protein.info.v11.5.txt",
		        "node_list_path": "1215092.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioBizertensisDsm18034Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio bizertensis DSM 18034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioBizertensisDsm18034Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121442.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121442.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121442.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121442.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121442.protein.info.v11.5.txt",
		        "node_list_path": "1121442.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121442.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaDenticola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema denticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaDenticola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243275.protein.sequences.v11.5.fa",
		        "enrichment_path": "243275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243275.protein.info.v11.5.txt",
		        "node_list_path": "243275.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriiaBacteriumRifoxyc2Full3518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriia bacterium RIFOXYC2_FULL_35_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriiaBacteriumRifoxyc2Full3518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802166.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802166.protein.info.v11.5.txt",
		        "node_list_path": "1802166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasMariniglutinosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas mariniglutinosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasMariniglutinosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "206042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "206042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "206042.clusters.proteins.v11.5.txt",
		        "sequence_path": "206042.protein.sequences.v11.5.fa",
		        "enrichment_path": "206042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "206042.protein.info.v11.5.txt",
		        "node_list_path": "206042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "206042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaOtitidisNbrc100426Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia otitidis NBRC 100426 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaOtitidisNbrc100426Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1108044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1108044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1108044.clusters.proteins.v11.5.txt",
		        "sequence_path": "1108044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1108044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1108044.protein.info.v11.5.txt",
		        "node_list_path": "1108044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1108044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSucicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sucicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSucicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423806.protein.info.v11.5.txt",
		        "node_list_path": "1423806.protein.complete.v11.5.txt"
		    }
		]
    )()

def KibdelosporangiumSpMj126Nf4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kibdelosporangium sp. MJ126-NF4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KibdelosporangiumSpMj126Nf4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "703222.protein.sequences.v11.5.fa",
		        "enrichment_path": "703222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "703222.protein.info.v11.5.txt",
		        "node_list_path": "703222.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanolineaTardaNobi1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanolinea tarda NOBI-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolineaTardaNobi1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "882090.protein.sequences.v11.5.fa",
		        "enrichment_path": "882090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882090.protein.info.v11.5.txt",
		        "node_list_path": "882090.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumAmylolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium amylolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAmylolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121298.protein.info.v11.5.txt",
		        "node_list_path": "1121298.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusIgniterraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus igniterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusIgniterraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123388.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123388.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123388.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123388.protein.info.v11.5.txt",
		        "node_list_path": "1123388.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123388.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomarinumVadi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomarinum vadi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomarinumVadi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "438855.protein.sequences.v11.5.fa",
		        "enrichment_path": "438855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "438855.protein.info.v11.5.txt",
		        "node_list_path": "438855.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSalinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas salina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSalinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42565.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42565.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42565.clusters.proteins.v11.5.txt",
		        "sequence_path": "42565.protein.sequences.v11.5.fa",
		        "enrichment_path": "42565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42565.protein.info.v11.5.txt",
		        "node_list_path": "42565.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42565.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloquadratumWalsbyiJ07hqw1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi J07HQW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloquadratumWalsbyiJ07hqw1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1238424.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238424.protein.info.v11.5.txt",
		        "node_list_path": "1238424.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylopilaSp73b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylopila sp. 73B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylopilaSp73b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120792.protein.info.v11.5.txt",
		        "node_list_path": "1120792.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusJorgensenbacteriaBacteriumRifcsplowo201Full4525bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPLOWO2_01_FULL_45_25b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsplowo201Full4525bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798471.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798471.protein.info.v11.5.txt",
		        "node_list_path": "1798471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasSimiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas simiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSimiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "218936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "218936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "218936.clusters.proteins.v11.5.txt",
		        "sequence_path": "218936.protein.sequences.v11.5.fa",
		        "enrichment_path": "218936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218936.protein.info.v11.5.txt",
		        "node_list_path": "218936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "218936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag563(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:563 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag563", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262961.protein.info.v11.5.txt",
		        "node_list_path": "1262961.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumDecumbensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium decumbens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumDecumbensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69771.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69771.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69771.clusters.proteins.v11.5.txt",
		        "sequence_path": "69771.protein.sequences.v11.5.fa",
		        "enrichment_path": "69771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69771.protein.info.v11.5.txt",
		        "node_list_path": "69771.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69771.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_46_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817824.protein.info.v11.5.txt",
		        "node_list_path": "1817824.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpJha26Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. JHA26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpJha26Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1917143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1917143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1917143.clusters.proteins.v11.5.txt",
		        "sequence_path": "1917143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917143.protein.info.v11.5.txt",
		        "node_list_path": "1917143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1917143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonCaspThauma4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon casp-thauma4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonCaspThauma4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1661714.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1661714.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1661714.clusters.proteins.v11.5.txt",
		        "sequence_path": "1661714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661714.protein.info.v11.5.txt",
		        "node_list_path": "1661714.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1661714.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaribacterIrgensii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter irgensii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterIrgensii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313594.protein.sequences.v11.5.fa",
		        "enrichment_path": "313594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313594.protein.info.v11.5.txt",
		        "node_list_path": "313594.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanococcusPlakortidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planococcus plakortidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusPlakortidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1038856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038856.protein.info.v11.5.txt",
		        "node_list_path": "1038856.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123500.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123500.protein.info.v11.5.txt",
		        "node_list_path": "1123500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "347256.clusters.info.v11.5.txt",
		        "cluster_tree_path": "347256.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "347256.clusters.proteins.v11.5.txt",
		        "sequence_path": "347256.protein.sequences.v11.5.fa",
		        "enrichment_path": "347256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "347256.protein.info.v11.5.txt",
		        "node_list_path": "347256.cluster.nodes.v11.5.txt",
		        "edge_list_path": "347256.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitratireductorBasaltisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitratireductor basaltis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratireductorBasaltisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "472175.clusters.info.v11.5.txt",
		        "cluster_tree_path": "472175.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "472175.clusters.proteins.v11.5.txt",
		        "sequence_path": "472175.protein.sequences.v11.5.fa",
		        "enrichment_path": "472175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472175.protein.info.v11.5.txt",
		        "node_list_path": "472175.cluster.nodes.v11.5.txt",
		        "edge_list_path": "472175.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfuribacillusAlkaliarsenatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfuribacillus alkaliarsenatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuribacillusAlkaliarsenatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "766136.clusters.info.v11.5.txt",
		        "cluster_tree_path": "766136.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "766136.clusters.proteins.v11.5.txt",
		        "sequence_path": "766136.protein.sequences.v11.5.fa",
		        "enrichment_path": "766136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "766136.protein.info.v11.5.txt",
		        "node_list_path": "766136.cluster.nodes.v11.5.txt",
		        "edge_list_path": "766136.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerasakiispiraPapahanaumokuakeensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terasakiispira papahanaumokuakeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerasakiispiraPapahanaumokuakeensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "197479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "197479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "197479.clusters.proteins.v11.5.txt",
		        "sequence_path": "197479.protein.sequences.v11.5.fa",
		        "enrichment_path": "197479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "197479.protein.info.v11.5.txt",
		        "node_list_path": "197479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "197479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NostocSpNies3756Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nostoc sp. NIES-3756 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocSpNies3756Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1751286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1751286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1751286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1751286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1751286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1751286.protein.info.v11.5.txt",
		        "node_list_path": "1751286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1751286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpH115Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H115 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpH115Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1759073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1759073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1759073.clusters.proteins.v11.5.txt",
		        "sequence_path": "1759073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759073.protein.info.v11.5.txt",
		        "node_list_path": "1759073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1759073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5411b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_54_11b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5411b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798494.protein.info.v11.5.txt",
		        "node_list_path": "1798494.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaSpJb15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. JB15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpJb15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1933906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933906.protein.info.v11.5.txt",
		        "node_list_path": "1933906.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavisolibacterTropicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavisolibacter tropicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavisolibacterTropicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1492898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1492898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1492898.clusters.proteins.v11.5.txt",
		        "sequence_path": "1492898.protein.sequences.v11.5.fa",
		        "enrichment_path": "1492898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1492898.protein.info.v11.5.txt",
		        "node_list_path": "1492898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1492898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaElizabethaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella elizabethae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaElizabethaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408427.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408427.protein.info.v11.5.txt",
		        "node_list_path": "1408427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaLimiDsm17137Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia limi DSM 17137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaLimiDsm17137Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121477.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121477.protein.info.v11.5.txt",
		        "node_list_path": "1121477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacterium4632(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 46-32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacterium4632", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895839.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895839.protein.info.v11.5.txt",
		        "node_list_path": "1895839.protein.complete.v11.5.txt"
		    }
		]
    )()

def BaudoiniaPanamericanaUamh10762Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Baudoinia panamericana UAMH 10762 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BaudoiniaPanamericanaUamh10762Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717646.clusters.proteins.v11.5.txt",
		        "sequence_path": "717646.protein.sequences.v11.5.fa",
		        "enrichment_path": "717646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717646.protein.info.v11.5.txt",
		        "node_list_path": "717646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PararhodobacterSpCcbMm2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pararhodobacter sp. CCB-MM2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PararhodobacterSpCcbMm2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1786003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1786003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1786003.protein.info.v11.5.txt",
		        "node_list_path": "1786003.protein.complete.v11.5.txt"
		    }
		]
    )()

def DysgonomonasSpBgc7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas sp. BGC7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasSpBgc7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658008.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658008.protein.info.v11.5.txt",
		        "node_list_path": "1658008.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnsiferSpTw10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. TW10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferSpTw10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1353531.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1353531.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1353531.clusters.proteins.v11.5.txt",
		        "sequence_path": "1353531.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353531.protein.info.v11.5.txt",
		        "node_list_path": "1353531.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1353531.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumAlcoholivorax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum alcoholivorax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumAlcoholivorax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121422.protein.info.v11.5.txt",
		        "node_list_path": "1121422.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpFa1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. FA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpFa1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1346710.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346710.protein.info.v11.5.txt",
		        "node_list_path": "1346710.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807729.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807729.protein.info.v11.5.txt",
		        "node_list_path": "1807729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactococcusGarvieaeI113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae I113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusGarvieaeI113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229517.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229517.protein.info.v11.5.txt",
		        "node_list_path": "1229517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinocyclocheilusGrahamiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinocyclocheilus grahami Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinocyclocheilusGrahamiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "75366.clusters.info.v11.5.txt",
		        "cluster_tree_path": "75366.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "75366.clusters.proteins.v11.5.txt",
		        "sequence_path": "75366.protein.sequences.v11.5.fa",
		        "enrichment_path": "75366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75366.protein.info.v11.5.txt",
		        "node_list_path": "75366.cluster.nodes.v11.5.txt",
		        "edge_list_path": "75366.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SymbiobacteriumThermophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Symbiobacterium thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SymbiobacteriumThermophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "292459.protein.sequences.v11.5.fa",
		        "enrichment_path": "292459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292459.protein.info.v11.5.txt",
		        "node_list_path": "292459.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaclostridiumBifermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraclostridium bifermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaclostridiumBifermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1490.clusters.proteins.v11.5.txt",
		        "sequence_path": "1490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1490.protein.info.v11.5.txt",
		        "node_list_path": "1490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaPedi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia pedi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaPedi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777141.protein.info.v11.5.txt",
		        "node_list_path": "1777141.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzotobacterBeijerinckii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azotobacter beijerinckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzotobacterBeijerinckii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "170623.protein.sequences.v11.5.fa",
		        "enrichment_path": "170623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "170623.protein.info.v11.5.txt",
		        "node_list_path": "170623.protein.complete.v11.5.txt"
		    }
		]
    )()

def GaboniaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gabonia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GaboniaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1686296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686296.protein.info.v11.5.txt",
		        "node_list_path": "1686296.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShimazuellaKribbensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shimazuella kribbensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShimazuellaKribbensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123252.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123252.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123252.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123252.protein.info.v11.5.txt",
		        "node_list_path": "1123252.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123252.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptobacteriumSpCag338(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptobacterium sp. CAG:338 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptobacteriumSpCag338", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262868.protein.info.v11.5.txt",
		        "node_list_path": "1262868.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaPneumophilaParis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila Paris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaPneumophilaParis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "297246.protein.sequences.v11.5.fa",
		        "enrichment_path": "297246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "297246.protein.info.v11.5.txt",
		        "node_list_path": "297246.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTuberculosisVariantAfricanumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant africanum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTuberculosisVariantAfricanumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33894.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33894.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33894.clusters.proteins.v11.5.txt",
		        "sequence_path": "33894.protein.sequences.v11.5.fa",
		        "enrichment_path": "33894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33894.protein.info.v11.5.txt",
		        "node_list_path": "33894.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33894.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacteriumCsp16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium CSP1-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacteriumCsp16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1640509.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1640509.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1640509.clusters.proteins.v11.5.txt",
		        "sequence_path": "1640509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640509.protein.info.v11.5.txt",
		        "node_list_path": "1640509.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1640509.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumAquatile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium aquatile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumAquatile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1453498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453498.protein.info.v11.5.txt",
		        "node_list_path": "1453498.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnobacteriumBovisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnobacterium bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnobacteriumBovisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "140626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "140626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "140626.clusters.proteins.v11.5.txt",
		        "sequence_path": "140626.protein.sequences.v11.5.fa",
		        "enrichment_path": "140626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "140626.protein.info.v11.5.txt",
		        "node_list_path": "140626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "140626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GonapodyaProliferaJel478Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gonapodya prolifera JEL478 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GonapodyaProliferaJel478Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1344416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1344416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1344416.clusters.proteins.v11.5.txt",
		        "sequence_path": "1344416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1344416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1344416.protein.info.v11.5.txt",
		        "node_list_path": "1344416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1344416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpWsm3224(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. WSM3224 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpWsm3224", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1040986.protein.sequences.v11.5.fa",
		        "enrichment_path": "1040986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1040986.protein.info.v11.5.txt",
		        "node_list_path": "1040986.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexusIslandicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexus islandicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexusIslandicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1707952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1707952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1707952.protein.info.v11.5.txt",
		        "node_list_path": "1707952.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesExfoliatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces exfoliatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesExfoliatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1905.protein.info.v11.5.txt",
		        "node_list_path": "1905.protein.complete.v11.5.txt"
		    }
		]
    )()

def BalneatrixAlpicaDsm16621(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Balneatrix alpica DSM 16621 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BalneatrixAlpicaDsm16621", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121103.protein.info.v11.5.txt",
		        "node_list_path": "1121103.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc13822(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_38_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc13822", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618897.protein.info.v11.5.txt",
		        "node_list_path": "1618897.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusJohnsoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus johnsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusJohnsoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "257314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "257314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "257314.clusters.proteins.v11.5.txt",
		        "sequence_path": "257314.protein.sequences.v11.5.fa",
		        "enrichment_path": "257314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "257314.protein.info.v11.5.txt",
		        "node_list_path": "257314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "257314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosotenuisChungbukensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis chungbukensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosotenuisChungbukensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1353246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353246.protein.info.v11.5.txt",
		        "node_list_path": "1353246.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumIntermediumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium intermedium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumIntermediumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28445.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28445.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28445.clusters.proteins.v11.5.txt",
		        "sequence_path": "28445.protein.sequences.v11.5.fa",
		        "enrichment_path": "28445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28445.protein.info.v11.5.txt",
		        "node_list_path": "28445.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28445.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeitlerinemaSpPcc7407Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC7407 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeitlerinemaSpPcc7407Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173025.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173025.protein.info.v11.5.txt",
		        "node_list_path": "1173025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSpL294Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. L294 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSpL294Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1643920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1643920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1643920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1643920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643920.protein.info.v11.5.txt",
		        "node_list_path": "1643920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1643920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanktothrixAgardhiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planktothrix agardhii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktothrixAgardhiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "388467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "388467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "388467.clusters.proteins.v11.5.txt",
		        "sequence_path": "388467.protein.sequences.v11.5.fa",
		        "enrichment_path": "388467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388467.protein.info.v11.5.txt",
		        "node_list_path": "388467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "388467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WallemiaIchthyophagaExf994(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wallemia ichthyophaga EXF-994 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WallemiaIchthyophagaExf994", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1299270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1299270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1299270.protein.info.v11.5.txt",
		        "node_list_path": "1299270.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumGriseofulvum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium griseofulvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumGriseofulvum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5078.protein.sequences.v11.5.fa",
		        "enrichment_path": "5078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5078.protein.info.v11.5.txt",
		        "node_list_path": "5078.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasDenitrificansDsm6059Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas denitrificans DSM 6059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasDenitrificansDsm6059Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123010.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123010.protein.info.v11.5.txt",
		        "node_list_path": "1123010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumDamselaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium damselae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumDamselaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675817.clusters.proteins.v11.5.txt",
		        "sequence_path": "675817.protein.sequences.v11.5.fa",
		        "enrichment_path": "675817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675817.protein.info.v11.5.txt",
		        "node_list_path": "675817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterAtlanticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterAtlanticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1648404.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1648404.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1648404.clusters.proteins.v11.5.txt",
		        "sequence_path": "1648404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1648404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1648404.protein.info.v11.5.txt",
		        "node_list_path": "1648404.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1648404.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarivitaHallyeonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marivita hallyeonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivitaHallyeonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "996342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "996342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "996342.clusters.proteins.v11.5.txt",
		        "sequence_path": "996342.protein.sequences.v11.5.fa",
		        "enrichment_path": "996342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "996342.protein.info.v11.5.txt",
		        "node_list_path": "996342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "996342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteralesBacterium6551(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium 65-51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteralesBacterium6551", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895824.protein.info.v11.5.txt",
		        "node_list_path": "1895824.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacteriumWoodiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacterium woodii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacteriumWoodiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "931626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "931626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "931626.clusters.proteins.v11.5.txt",
		        "sequence_path": "931626.protein.sequences.v11.5.fa",
		        "enrichment_path": "931626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "931626.protein.info.v11.5.txt",
		        "node_list_path": "931626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "931626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyphomyrmexCostatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyphomyrmex costatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyphomyrmexCostatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "456900.protein.sequences.v11.5.fa",
		        "enrichment_path": "456900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "456900.protein.info.v11.5.txt",
		        "node_list_path": "456900.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp131216(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 13-12-16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp131216", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1570823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570823.protein.info.v11.5.txt",
		        "node_list_path": "1570823.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpBg2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. Bg2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpBg2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1784823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1784823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1784823.protein.info.v11.5.txt",
		        "node_list_path": "1784823.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnoanaerobaculumSpObrc55Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum sp. OBRC5-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoanaerobaculumSpObrc55Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936595.clusters.proteins.v11.5.txt",
		        "sequence_path": "936595.protein.sequences.v11.5.fa",
		        "enrichment_path": "936595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936595.protein.info.v11.5.txt",
		        "node_list_path": "936595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaSibiricaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia sibirica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaSibiricaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272951.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272951.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272951.clusters.proteins.v11.5.txt",
		        "sequence_path": "272951.protein.sequences.v11.5.fa",
		        "enrichment_path": "272951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272951.protein.info.v11.5.txt",
		        "node_list_path": "272951.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272951.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaXishanensisNbrc101358Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia xishanensis NBRC 101358 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaXishanensisNbrc101358Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210101.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210101.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210101.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210101.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210101.protein.info.v11.5.txt",
		        "node_list_path": "1210101.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210101.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc074e01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC074E01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc074e01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1715017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1715017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1715017.clusters.proteins.v11.5.txt",
		        "sequence_path": "1715017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715017.protein.info.v11.5.txt",
		        "node_list_path": "1715017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1715017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnobacteriumBovisDsm14045(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnobacterium bovis DSM 14045 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnobacteriumBovisDsm14045", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122142.protein.info.v11.5.txt",
		        "node_list_path": "1122142.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSynoviae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma synoviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSynoviae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262723.protein.sequences.v11.5.fa",
		        "enrichment_path": "262723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262723.protein.info.v11.5.txt",
		        "node_list_path": "262723.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaBovis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaBovis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "476.protein.sequences.v11.5.fa",
		        "enrichment_path": "476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "476.protein.info.v11.5.txt",
		        "node_list_path": "476.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribiusSpMola401Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribius sp. MOLA401 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribiusSpMola401Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1530186.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1530186.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1530186.clusters.proteins.v11.5.txt",
		        "sequence_path": "1530186.protein.sequences.v11.5.fa",
		        "enrichment_path": "1530186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1530186.protein.info.v11.5.txt",
		        "node_list_path": "1530186.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1530186.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubrobacterAplysinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubrobacter aplysinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrobacterAplysinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "909625.protein.sequences.v11.5.fa",
		        "enrichment_path": "909625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "909625.protein.info.v11.5.txt",
		        "node_list_path": "909625.protein.complete.v11.5.txt"
		    }
		]
    )()

def CordycepsFumosoroseaArsef2679Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps fumosorosea ARSEF 2679 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CordycepsFumosoroseaArsef2679Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1081104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1081104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1081104.clusters.proteins.v11.5.txt",
		        "sequence_path": "1081104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081104.protein.info.v11.5.txt",
		        "node_list_path": "1081104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1081104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubrobacterRadiotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubrobacter radiotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrobacterRadiotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42256.protein.sequences.v11.5.fa",
		        "enrichment_path": "42256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42256.protein.info.v11.5.txt",
		        "node_list_path": "42256.protein.complete.v11.5.txt"
		    }
		]
    )()

def PteropusVampyrus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pteropus vampyrus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PteropusVampyrus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "132908.protein.sequences.v11.5.fa",
		        "enrichment_path": "132908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "132908.protein.info.v11.5.txt",
		        "node_list_path": "132908.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusGallinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusGallinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293.protein.info.v11.5.txt",
		        "node_list_path": "1293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSp6622(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. 66-22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSp6622", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895753.protein.info.v11.5.txt",
		        "node_list_path": "1895753.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZonotrichiaAlbicollisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zonotrichia albicollis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZonotrichiaAlbicollisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44394.clusters.proteins.v11.5.txt",
		        "sequence_path": "44394.protein.sequences.v11.5.fa",
		        "enrichment_path": "44394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44394.protein.info.v11.5.txt",
		        "node_list_path": "44394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiaBacteriumTcs56Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiaBacteriumTcs56Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1781247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1781247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1781247.clusters.proteins.v11.5.txt",
		        "sequence_path": "1781247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1781247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1781247.protein.info.v11.5.txt",
		        "node_list_path": "1781247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1781247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioCincinnatiensisDsm19608Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cincinnatiensis DSM 19608 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCincinnatiensisDsm19608Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123491.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123491.protein.info.v11.5.txt",
		        "node_list_path": "1123491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpNcr5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. NCR5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpNcr5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1978342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1978342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1978342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1978342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978342.protein.info.v11.5.txt",
		        "node_list_path": "1978342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1978342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyphellophoraEuropaeaCbs101466(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyphellophora europaea CBS 101466 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyphellophoraEuropaeaCbs101466", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220924.protein.info.v11.5.txt",
		        "node_list_path": "1220924.protein.complete.v11.5.txt"
		    }
		]
    )()

def CatenovulumAgarivoransYm01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catenovulum agarivorans YM01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenovulumAgarivoransYm01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "659495.protein.sequences.v11.5.fa",
		        "enrichment_path": "659495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "659495.protein.info.v11.5.txt",
		        "node_list_path": "659495.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumArizonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium arizonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumArizonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1835702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1835702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1835702.clusters.proteins.v11.5.txt",
		        "sequence_path": "1835702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1835702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1835702.protein.info.v11.5.txt",
		        "node_list_path": "1835702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1835702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseoruberCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseoruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseoruberCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1943.clusters.proteins.v11.5.txt",
		        "sequence_path": "1943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1943.protein.info.v11.5.txt",
		        "node_list_path": "1943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosopelagicusSpRedseaS31B2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopelagicus sp. REDSEA-S31_B2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopelagicusSpRedseaS31B2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811586.protein.info.v11.5.txt",
		        "node_list_path": "1811586.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonasTestosteroniCnb2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas testosteroni CNB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasTestosteroniCnb2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "688245.protein.sequences.v11.5.fa",
		        "enrichment_path": "688245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688245.protein.info.v11.5.txt",
		        "node_list_path": "688245.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcaligenesFaecalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcaligenes faecalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcaligenesFaecalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "511.protein.sequences.v11.5.fa",
		        "enrichment_path": "511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511.protein.info.v11.5.txt",
		        "node_list_path": "511.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag83(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag83", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262992.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262992.protein.info.v11.5.txt",
		        "node_list_path": "1262992.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanobacillusSpCastelsardo(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. Castelsardo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusSpCastelsardo", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1851204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1851204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1851204.protein.info.v11.5.txt",
		        "node_list_path": "1851204.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocKimchii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc kimchii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocKimchii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762051.protein.sequences.v11.5.fa",
		        "enrichment_path": "762051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762051.protein.info.v11.5.txt",
		        "node_list_path": "762051.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioThiocyanodenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanodenitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioThiocyanodenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "713586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "713586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "713586.clusters.proteins.v11.5.txt",
		        "sequence_path": "713586.protein.sequences.v11.5.fa",
		        "enrichment_path": "713586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713586.protein.info.v11.5.txt",
		        "node_list_path": "713586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "713586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaPnomenusa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea pnomenusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaPnomenusa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93220.protein.sequences.v11.5.fa",
		        "enrichment_path": "93220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93220.protein.info.v11.5.txt",
		        "node_list_path": "93220.protein.complete.v11.5.txt"
		    }
		]
    )()

def RamazzottiusVarieornatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ramazzottius varieornatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RamazzottiusVarieornatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "947166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "947166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "947166.clusters.proteins.v11.5.txt",
		        "sequence_path": "947166.protein.sequences.v11.5.fa",
		        "enrichment_path": "947166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "947166.protein.info.v11.5.txt",
		        "node_list_path": "947166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "947166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DefluviimonasSp20v17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Defluviimonas sp. 20V17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DefluviimonasSp20v17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1417296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1417296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1417296.protein.info.v11.5.txt",
		        "node_list_path": "1417296.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpKpl2004Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL2004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpKpl2004Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203632.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203632.protein.info.v11.5.txt",
		        "node_list_path": "1203632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumLotiCj3sym(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti CJ3sym graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumLotiCj3sym", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1040982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1040982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1040982.protein.info.v11.5.txt",
		        "node_list_path": "1040982.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpMf4836(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. MF4836 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpMf4836", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1960827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1960827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1960827.protein.info.v11.5.txt",
		        "node_list_path": "1960827.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacterialesBacteriumAlc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriales bacterium ALC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacterialesBacteriumAlc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391603.protein.sequences.v11.5.fa",
		        "enrichment_path": "391603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391603.protein.info.v11.5.txt",
		        "node_list_path": "391603.protein.complete.v11.5.txt"
		    }
		]
    )()

def OligoflexusTunisiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oligoflexus tunisiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OligoflexusTunisiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "708132.clusters.info.v11.5.txt",
		        "cluster_tree_path": "708132.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "708132.clusters.proteins.v11.5.txt",
		        "sequence_path": "708132.protein.sequences.v11.5.fa",
		        "enrichment_path": "708132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "708132.protein.info.v11.5.txt",
		        "node_list_path": "708132.cluster.nodes.v11.5.txt",
		        "edge_list_path": "708132.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumMc2017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MC2017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumMc2017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408324.protein.info.v11.5.txt",
		        "node_list_path": "1408324.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumPopuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium populi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumPopuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "441620.protein.sequences.v11.5.fa",
		        "enrichment_path": "441620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441620.protein.info.v11.5.txt",
		        "node_list_path": "441620.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaFlabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella flabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaFlabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "463014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "463014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "463014.clusters.proteins.v11.5.txt",
		        "sequence_path": "463014.protein.sequences.v11.5.fa",
		        "enrichment_path": "463014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "463014.protein.info.v11.5.txt",
		        "node_list_path": "463014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "463014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusKorlensisNbrc107688Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus korlensis NBRC 107688 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusKorlensisNbrc107688Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348629.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348629.protein.info.v11.5.txt",
		        "node_list_path": "1348629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JiangellaAlbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jiangella alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JiangellaAlbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "561176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "561176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "561176.clusters.proteins.v11.5.txt",
		        "sequence_path": "561176.protein.sequences.v11.5.fa",
		        "enrichment_path": "561176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561176.protein.info.v11.5.txt",
		        "node_list_path": "561176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "561176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_37_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797783.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797783.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797783.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797783.protein.info.v11.5.txt",
		        "node_list_path": "1797783.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797783.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaRubrilucens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella rubrilucens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaRubrilucens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "458.protein.sequences.v11.5.fa",
		        "enrichment_path": "458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "458.protein.info.v11.5.txt",
		        "node_list_path": "458.protein.complete.v11.5.txt"
		    }
		]
    )()

def AkkermansiaSpKle1797Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Akkermansia sp. KLE1797 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AkkermansiaSpKle1797Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1574264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1574264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1574264.clusters.proteins.v11.5.txt",
		        "sequence_path": "1574264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1574264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1574264.protein.info.v11.5.txt",
		        "node_list_path": "1574264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1574264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5331(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_53_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5331", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798481.protein.info.v11.5.txt",
		        "node_list_path": "1798481.protein.complete.v11.5.txt"
		    }
		]
    )()

def ViridibacillusArvi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Viridibacillus arvi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ViridibacillusArvi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "263475.protein.sequences.v11.5.fa",
		        "enrichment_path": "263475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263475.protein.info.v11.5.txt",
		        "node_list_path": "263475.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusSp2009(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. 2009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusSp2009", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "684949.protein.sequences.v11.5.fa",
		        "enrichment_path": "684949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "684949.protein.info.v11.5.txt",
		        "node_list_path": "684949.protein.complete.v11.5.txt"
		    }
		]
    )()

def RicheliaIntracellularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Richelia intracellularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RicheliaIntracellularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1165094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1165094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1165094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1165094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1165094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1165094.protein.info.v11.5.txt",
		        "node_list_path": "1165094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1165094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusXylanilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus xylanilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusXylanilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582475.protein.sequences.v11.5.fa",
		        "enrichment_path": "582475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582475.protein.info.v11.5.txt",
		        "node_list_path": "582475.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaCt18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Salmonella enterica CT18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaCt18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "220341.protein.sequences.v11.0.fa",
		        "enrichment_path": "220341.protein.enrichment.terms.v11.0.txt",
		        "info_path": "220341.protein.info.v11.0.txt",
		        "node_list_path": "220341.protein.complete.v11.0.txt"
		    }
		]
    )()

def FlavobacteriumSinopsychrotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sinopsychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSinopsychrotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "604089.protein.sequences.v11.5.fa",
		        "enrichment_path": "604089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "604089.protein.info.v11.5.txt",
		        "node_list_path": "604089.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaAnserina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia anserina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaAnserina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1313293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313293.protein.info.v11.5.txt",
		        "node_list_path": "1313293.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusParahaemolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus parahaemolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusParahaemolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "735.protein.sequences.v11.5.fa",
		        "enrichment_path": "735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "735.protein.info.v11.5.txt",
		        "node_list_path": "735.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807754.protein.info.v11.5.txt",
		        "node_list_path": "1807754.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusVaginalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusVaginalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423814.protein.info.v11.5.txt",
		        "node_list_path": "1423814.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesertifilumSpIppasB1220(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desertifilum sp. IPPAS B-1220 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesertifilumSpIppasB1220", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1781255.protein.sequences.v11.5.fa",
		        "enrichment_path": "1781255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1781255.protein.info.v11.5.txt",
		        "node_list_path": "1781255.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlaciecolaNitratireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaNitratireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1085623.protein.sequences.v11.5.fa",
		        "enrichment_path": "1085623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1085623.protein.info.v11.5.txt",
		        "node_list_path": "1085623.protein.complete.v11.5.txt"
		    }
		]
    )()

def SilanimonasLenta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Silanimonas lenta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SilanimonasLenta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123253.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123253.protein.info.v11.5.txt",
		        "node_list_path": "1123253.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSpBmaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. BMA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpBmaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1663685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1663685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1663685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1663685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1663685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1663685.protein.info.v11.5.txt",
		        "node_list_path": "1663685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1663685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollinsellaSp609(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collinsella sp. 60_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaSp609", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896993.protein.info.v11.5.txt",
		        "node_list_path": "1896993.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIs1590Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1590 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIs1590Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1772286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1772286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1772286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1772286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772286.protein.info.v11.5.txt",
		        "node_list_path": "1772286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1772286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusHomomorphusCbs101889Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus homomorphus CBS 101889 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusHomomorphusCbs101889Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1450537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1450537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1450537.clusters.proteins.v11.5.txt",
		        "sequence_path": "1450537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450537.protein.info.v11.5.txt",
		        "node_list_path": "1450537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1450537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaSteeleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella steelei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaSteeleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "947033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "947033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "947033.clusters.proteins.v11.5.txt",
		        "sequence_path": "947033.protein.sequences.v11.5.fa",
		        "enrichment_path": "947033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "947033.protein.info.v11.5.txt",
		        "node_list_path": "947033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "947033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YooniaRosea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yoonia rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YooniaRosea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "287098.protein.sequences.v11.5.fa",
		        "enrichment_path": "287098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "287098.protein.info.v11.5.txt",
		        "node_list_path": "287098.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaBovisM02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bovis m02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaBovisM02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094492.protein.info.v11.5.txt",
		        "node_list_path": "1094492.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpC8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. C8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpC8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1667357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1667357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1667357.protein.info.v11.5.txt",
		        "node_list_path": "1667357.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpFw1012b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. FW1012B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpFw1012b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644968.protein.sequences.v11.5.fa",
		        "enrichment_path": "644968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644968.protein.info.v11.5.txt",
		        "node_list_path": "644968.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerpetosiphonGeysericola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herpetosiphon geysericola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerpetosiphonGeysericola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "70996.protein.sequences.v11.5.fa",
		        "enrichment_path": "70996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "70996.protein.info.v11.5.txt",
		        "node_list_path": "70996.protein.complete.v11.5.txt"
		    }
		]
    )()

def DenticepsClupeoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Denticeps clupeoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DenticepsClupeoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "299321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "299321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "299321.clusters.proteins.v11.5.txt",
		        "sequence_path": "299321.protein.sequences.v11.5.fa",
		        "enrichment_path": "299321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299321.protein.info.v11.5.txt",
		        "node_list_path": "299321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "299321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumInsubricum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium insubricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumInsubricum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "444597.protein.sequences.v11.5.fa",
		        "enrichment_path": "444597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444597.protein.info.v11.5.txt",
		        "node_list_path": "444597.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichormusSpNmc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichormus sp. NMC-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichormusSpNmc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1853259.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1853259.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1853259.clusters.proteins.v11.5.txt",
		        "sequence_path": "1853259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1853259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1853259.protein.info.v11.5.txt",
		        "node_list_path": "1853259.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1853259.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisGranuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis granuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisGranuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "267128.protein.sequences.v11.5.fa",
		        "enrichment_path": "267128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267128.protein.info.v11.5.txt",
		        "node_list_path": "267128.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquiflexumBalticumDsm16537(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquiflexum balticum DSM 16537 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquiflexumBalticumDsm16537", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "758820.protein.sequences.v11.5.fa",
		        "enrichment_path": "758820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758820.protein.info.v11.5.txt",
		        "node_list_path": "758820.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSpUcdFrssp1630(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. UCD-FRSSP16_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpUcdFrssp1630", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1853258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1853258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1853258.protein.info.v11.5.txt",
		        "node_list_path": "1853258.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaBiviaDnf00188(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bivia DNF00188 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBiviaDnf00188", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1287476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287476.protein.info.v11.5.txt",
		        "node_list_path": "1287476.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoculleusChikugoensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus chikugoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusChikugoensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118126.clusters.proteins.v11.5.txt",
		        "sequence_path": "118126.protein.sequences.v11.5.fa",
		        "enrichment_path": "118126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118126.protein.info.v11.5.txt",
		        "node_list_path": "118126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobotryumSaponariae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbotryum saponariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobotryumSaponariae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "289078.protein.sequences.v11.5.fa",
		        "enrichment_path": "289078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "289078.protein.info.v11.5.txt",
		        "node_list_path": "289078.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSpBa94(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. BA-94 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSpBa94", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1454005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454005.protein.info.v11.5.txt",
		        "node_list_path": "1454005.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumKomaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium komanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumKomaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566885.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566885.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566885.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566885.protein.info.v11.5.txt",
		        "node_list_path": "1566885.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566885.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TersicoccusSpBi70(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tersicoccus sp. Bi-70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TersicoccusSpBi70", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897634.protein.info.v11.5.txt",
		        "node_list_path": "1897634.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHimb058(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HIMB058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHimb058", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144932.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144932.protein.info.v11.5.txt",
		        "node_list_path": "1144932.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4515Fw2607Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4515 (FW-2607) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4515Fw2607Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420909.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420909.protein.info.v11.5.txt",
		        "node_list_path": "1420909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaHispanica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena hispanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaHispanica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "392421.protein.sequences.v11.5.fa",
		        "enrichment_path": "392421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392421.protein.info.v11.5.txt",
		        "node_list_path": "392421.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusErwiniaHaradaeae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Erwinia haradaeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusErwiniaHaradaeae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1922217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1922217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1922217.protein.info.v11.5.txt",
		        "node_list_path": "1922217.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSp4081(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 40-81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSp4081", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896169.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896169.protein.info.v11.5.txt",
		        "node_list_path": "1896169.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumJaponicum22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum 22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumJaponicum22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304877.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304877.protein.info.v11.5.txt",
		        "node_list_path": "1304877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonadalesBacteriumBs08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonadales bacterium BS08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonadalesBacteriumBs08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895005.protein.info.v11.5.txt",
		        "node_list_path": "1895005.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaSuccinifaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema succinifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSuccinifaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "869209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "869209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "869209.clusters.proteins.v11.5.txt",
		        "sequence_path": "869209.protein.sequences.v11.5.fa",
		        "enrichment_path": "869209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869209.protein.info.v11.5.txt",
		        "node_list_path": "869209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "869209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FranconibacterHelveticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Franconibacter helveticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FranconibacterHelveticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "357240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "357240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "357240.clusters.proteins.v11.5.txt",
		        "sequence_path": "357240.protein.sequences.v11.5.fa",
		        "enrichment_path": "357240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357240.protein.info.v11.5.txt",
		        "node_list_path": "357240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "357240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonadalesBacterium6313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 63-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonadalesBacterium6313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895867.protein.info.v11.5.txt",
		        "node_list_path": "1895867.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlectobacillusMajor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flectobacillus major graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlectobacillusMajor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "929703.protein.sequences.v11.5.fa",
		        "enrichment_path": "929703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929703.protein.info.v11.5.txt",
		        "node_list_path": "929703.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocGelidumKctc3527Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum KCTC3527 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocGelidumKctc3527Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "927691.clusters.info.v11.5.txt",
		        "cluster_tree_path": "927691.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "927691.clusters.proteins.v11.5.txt",
		        "sequence_path": "927691.protein.sequences.v11.5.fa",
		        "enrichment_path": "927691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927691.protein.info.v11.5.txt",
		        "node_list_path": "927691.cluster.nodes.v11.5.txt",
		        "edge_list_path": "927691.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTriplex(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium triplex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTriplex", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47839.protein.sequences.v11.5.fa",
		        "enrichment_path": "47839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47839.protein.info.v11.5.txt",
		        "node_list_path": "47839.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpRu33c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. RU33C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpRu33c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907398.protein.info.v11.5.txt",
		        "node_list_path": "1907398.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolytolypaHystricisUamh7299(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polytolypa hystricis UAMH7299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolytolypaHystricisUamh7299", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1447883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1447883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1447883.protein.info.v11.5.txt",
		        "node_list_path": "1447883.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioFibrisolvensNd3005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens ND3005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioFibrisolvensNd3005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280696.protein.info.v11.5.txt",
		        "node_list_path": "1280696.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpRoot227Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root227 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpRoot227Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736496.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736496.protein.info.v11.5.txt",
		        "node_list_path": "1736496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodothermusMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodothermus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodothermusMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "518766.clusters.info.v11.5.txt",
		        "cluster_tree_path": "518766.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "518766.clusters.proteins.v11.5.txt",
		        "sequence_path": "518766.protein.sequences.v11.5.fa",
		        "enrichment_path": "518766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "518766.protein.info.v11.5.txt",
		        "node_list_path": "518766.cluster.nodes.v11.5.txt",
		        "edge_list_path": "518766.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulophagaBalticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga baltica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaBalticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348583.protein.info.v11.5.txt",
		        "node_list_path": "1348583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19058Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19058Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1460652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1460652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1460652.clusters.proteins.v11.5.txt",
		        "sequence_path": "1460652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460652.protein.info.v11.5.txt",
		        "node_list_path": "1460652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1460652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyadobacterFermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterFermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471854.protein.sequences.v11.5.fa",
		        "enrichment_path": "471854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471854.protein.info.v11.5.txt",
		        "node_list_path": "471854.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeotomaLepidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neotoma lepida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeotomaLepidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56216.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56216.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56216.clusters.proteins.v11.5.txt",
		        "sequence_path": "56216.protein.sequences.v11.5.fa",
		        "enrichment_path": "56216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56216.protein.info.v11.5.txt",
		        "node_list_path": "56216.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56216.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumSpRv1423Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. RV1423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumSpRv1423Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1443993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1443993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1443993.clusters.proteins.v11.5.txt",
		        "sequence_path": "1443993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443993.protein.info.v11.5.txt",
		        "node_list_path": "1443993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1443993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PalaeococcusPacificusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Palaeococcus pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PalaeococcusPacificusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1343739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1343739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1343739.clusters.proteins.v11.5.txt",
		        "sequence_path": "1343739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1343739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1343739.protein.info.v11.5.txt",
		        "node_list_path": "1343739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1343739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumCg2304417Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium CG2_30_44_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumCg2304417Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805324.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805324.protein.info.v11.5.txt",
		        "node_list_path": "1805324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCereusRock344Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cereus Rock3-44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCereusRock344Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "526986.clusters.info.v11.5.txt",
		        "cluster_tree_path": "526986.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "526986.clusters.proteins.v11.5.txt",
		        "sequence_path": "526986.protein.sequences.v11.5.fa",
		        "enrichment_path": "526986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526986.protein.info.v11.5.txt",
		        "node_list_path": "526986.cluster.nodes.v11.5.txt",
		        "edge_list_path": "526986.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorallococcusCoralloidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corallococcus coralloides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorallococcusCoralloidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144275.protein.info.v11.5.txt",
		        "node_list_path": "1144275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsphigho201Full3637Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_01_FULL_36_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho201Full3637Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797758.protein.info.v11.5.txt",
		        "node_list_path": "1797758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsplowo212Full4426(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_12_FULL_44_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo212Full4426", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802130.protein.info.v11.5.txt",
		        "node_list_path": "1802130.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSp2mfcol31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. 2MFCol31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSp2mfcol31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246459.protein.info.v11.5.txt",
		        "node_list_path": "1246459.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpA45(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. A45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpA45", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945862.protein.info.v11.5.txt",
		        "node_list_path": "1945862.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumEnclense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium enclense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumEnclense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "993073.protein.sequences.v11.5.fa",
		        "enrichment_path": "993073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "993073.protein.info.v11.5.txt",
		        "node_list_path": "993073.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptonemaIlliniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptonema illini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptonemaIlliniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "183.clusters.info.v11.5.txt",
		        "cluster_tree_path": "183.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "183.clusters.proteins.v11.5.txt",
		        "sequence_path": "183.protein.sequences.v11.5.fa",
		        "enrichment_path": "183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "183.protein.info.v11.5.txt",
		        "node_list_path": "183.cluster.nodes.v11.5.txt",
		        "edge_list_path": "183.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DendrobiumCatenatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dendrobium catenatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DendrobiumCatenatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "906689.protein.sequences.v11.5.fa",
		        "enrichment_path": "906689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "906689.protein.info.v11.5.txt",
		        "node_list_path": "906689.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioclavaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioclava marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1915077.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1915077.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1915077.clusters.proteins.v11.5.txt",
		        "sequence_path": "1915077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915077.protein.info.v11.5.txt",
		        "node_list_path": "1915077.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1915077.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiK12SubstrMg1655(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli K12 substr. MG1655 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiK12SubstrMg1655", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "511145.protein.sequences.v11.5.fa",
		        "enrichment_path": "511145.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511145.protein.info.v11.5.txt",
		        "node_list_path": "511145.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerrimonasMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrimonasMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "299255.clusters.info.v11.5.txt",
		        "cluster_tree_path": "299255.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "299255.clusters.proteins.v11.5.txt",
		        "sequence_path": "299255.protein.sequences.v11.5.fa",
		        "enrichment_path": "299255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299255.protein.info.v11.5.txt",
		        "node_list_path": "299255.cluster.nodes.v11.5.txt",
		        "edge_list_path": "299255.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSaliperosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium saliperosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSaliperosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1341155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1341155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1341155.clusters.proteins.v11.5.txt",
		        "sequence_path": "1341155.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341155.protein.info.v11.5.txt",
		        "node_list_path": "1341155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1341155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesFluxus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fluxus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFluxus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "763034.protein.sequences.v11.5.fa",
		        "enrichment_path": "763034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "763034.protein.info.v11.5.txt",
		        "node_list_path": "763034.protein.complete.v11.5.txt"
		    }
		]
    )()

def GaeumannomycesTriticiR3111a1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gaeumannomyces tritici R3-111a-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GaeumannomycesTriticiR3111a1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644352.protein.sequences.v11.5.fa",
		        "enrichment_path": "644352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644352.protein.info.v11.5.txt",
		        "node_list_path": "644352.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifoxyb1Full3816(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYB1_FULL_38_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyb1Full3816", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802538.protein.info.v11.5.txt",
		        "node_list_path": "1802538.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterTolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter tolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterTolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1604334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1604334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1604334.protein.info.v11.5.txt",
		        "node_list_path": "1604334.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaRibeironis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia ribeironis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaRibeironis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1247936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1247936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1247936.protein.info.v11.5.txt",
		        "node_list_path": "1247936.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelodictyonPhaeoclathratiforme(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelodictyon phaeoclathratiforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelodictyonPhaeoclathratiforme", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "324925.protein.sequences.v11.5.fa",
		        "enrichment_path": "324925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "324925.protein.info.v11.5.txt",
		        "node_list_path": "324925.protein.complete.v11.5.txt"
		    }
		]
    )()

def TimonellaSenegalensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Timonella senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TimonellaSenegalensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095772.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095772.protein.info.v11.5.txt",
		        "node_list_path": "1095772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurovumSpNbc371(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum sp. NBC371 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurovumSpNbc371", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "387093.protein.sequences.v11.5.fa",
		        "enrichment_path": "387093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "387093.protein.info.v11.5.txt",
		        "node_list_path": "387093.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriaceaeBacteriumDw12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriaceae bacterium DW12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriaceaeBacteriumDw12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1550091.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550091.protein.info.v11.5.txt",
		        "node_list_path": "1550091.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusSpG1w1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. G1w1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusSpG1w1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1430331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1430331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1430331.clusters.proteins.v11.5.txt",
		        "sequence_path": "1430331.protein.sequences.v11.5.fa",
		        "enrichment_path": "1430331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1430331.protein.info.v11.5.txt",
		        "node_list_path": "1430331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1430331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPlatensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces platensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPlatensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "58346.protein.sequences.v11.5.fa",
		        "enrichment_path": "58346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58346.protein.info.v11.5.txt",
		        "node_list_path": "58346.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCasei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium casei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCasei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1285583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1285583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1285583.protein.info.v11.5.txt",
		        "node_list_path": "1285583.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusPettenkoferiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus pettenkoferi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusPettenkoferiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "904314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "904314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "904314.clusters.proteins.v11.5.txt",
		        "sequence_path": "904314.protein.sequences.v11.5.fa",
		        "enrichment_path": "904314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904314.protein.info.v11.5.txt",
		        "node_list_path": "904314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "904314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHtcc2207Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2207 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHtcc2207Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314287.clusters.proteins.v11.5.txt",
		        "sequence_path": "314287.protein.sequences.v11.5.fa",
		        "enrichment_path": "314287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314287.protein.info.v11.5.txt",
		        "node_list_path": "314287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCamelliaeDsm22697Jcm13995Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus camelliae DSM 22697 JCM 13995 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCamelliaeDsm22697Jcm13995Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423730.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423730.protein.info.v11.5.txt",
		        "node_list_path": "1423730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSpOk268Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK268 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSpOk268Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881048.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881048.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881048.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881048.protein.info.v11.5.txt",
		        "node_list_path": "1881048.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881048.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterRhizosphaerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterRhizosphaerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "390241.protein.sequences.v11.5.fa",
		        "enrichment_path": "390241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390241.protein.info.v11.5.txt",
		        "node_list_path": "390241.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeyerozymaGuilliermondii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meyerozyma guilliermondii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeyerozymaGuilliermondii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4929.protein.sequences.v11.5.fa",
		        "enrichment_path": "4929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4929.protein.info.v11.5.txt",
		        "node_list_path": "4929.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag462(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:462 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag462", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262740.protein.info.v11.5.txt",
		        "node_list_path": "1262740.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4222Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_42_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4222Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798391.protein.info.v11.5.txt",
		        "node_list_path": "1798391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumAap81bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium AAP81b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumAap81bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523432.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523432.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523432.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523432.protein.info.v11.5.txt",
		        "node_list_path": "1523432.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523432.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAcidophilus30sc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus 30SC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAcidophilus30sc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "891391.protein.sequences.v11.5.fa",
		        "enrichment_path": "891391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "891391.protein.info.v11.5.txt",
		        "node_list_path": "891391.protein.complete.v11.5.txt"
		    }
		]
    )()

def FurculomycesBoomerangus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Furculomyces boomerangus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FurculomycesBoomerangus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61424.protein.sequences.v11.5.fa",
		        "enrichment_path": "61424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61424.protein.info.v11.5.txt",
		        "node_list_path": "61424.protein.complete.v11.5.txt"
		    }
		]
    )()

def TorulasporaDelbrueckii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Torulaspora delbrueckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TorulasporaDelbrueckii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4950.protein.sequences.v11.5.fa",
		        "enrichment_path": "4950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4950.protein.info.v11.5.txt",
		        "node_list_path": "4950.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaSepticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea septica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSepticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "472695.clusters.info.v11.5.txt",
		        "cluster_tree_path": "472695.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "472695.clusters.proteins.v11.5.txt",
		        "sequence_path": "472695.protein.sequences.v11.5.fa",
		        "enrichment_path": "472695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472695.protein.info.v11.5.txt",
		        "node_list_path": "472695.cluster.nodes.v11.5.txt",
		        "edge_list_path": "472695.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanolobusVulcaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus vulcani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolobusVulcaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "38026.clusters.info.v11.5.txt",
		        "cluster_tree_path": "38026.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "38026.clusters.proteins.v11.5.txt",
		        "sequence_path": "38026.protein.sequences.v11.5.fa",
		        "enrichment_path": "38026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38026.protein.info.v11.5.txt",
		        "node_list_path": "38026.cluster.nodes.v11.5.txt",
		        "edge_list_path": "38026.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GrifolaFrondosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Grifola frondosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GrifolaFrondosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5627.clusters.proteins.v11.5.txt",
		        "sequence_path": "5627.protein.sequences.v11.5.fa",
		        "enrichment_path": "5627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5627.protein.info.v11.5.txt",
		        "node_list_path": "5627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalibacteriumHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salibacterium halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalibacteriumHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884432.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884432.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884432.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884432.protein.info.v11.5.txt",
		        "node_list_path": "1884432.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884432.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesCatenulaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces catenulae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCatenulaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66875.clusters.proteins.v11.5.txt",
		        "sequence_path": "66875.protein.sequences.v11.5.fa",
		        "enrichment_path": "66875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66875.protein.info.v11.5.txt",
		        "node_list_path": "66875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusUdagawaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus udagawae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusUdagawaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "91492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "91492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "91492.clusters.proteins.v11.5.txt",
		        "sequence_path": "91492.protein.sequences.v11.5.fa",
		        "enrichment_path": "91492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91492.protein.info.v11.5.txt",
		        "node_list_path": "91492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "91492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterSpNctc13003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. NCTC 13003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSpNctc13003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660064.protein.info.v11.5.txt",
		        "node_list_path": "1660064.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProtomycesLactucaedebilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Protomyces lactucaedebilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProtomycesLactucaedebilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56484.protein.sequences.v11.5.fa",
		        "enrichment_path": "56484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56484.protein.info.v11.5.txt",
		        "node_list_path": "56484.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgromycesSpCf514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agromyces sp. CF514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesSpCf514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881031.protein.info.v11.5.txt",
		        "node_list_path": "1881031.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaceaeBacteriumDtu079Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU079 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaceaeBacteriumDtu079Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671645.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671645.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671645.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671645.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671645.protein.info.v11.5.txt",
		        "node_list_path": "1671645.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671645.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfonauticusSubmarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonauticus submarinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonauticusSubmarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "206665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "206665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "206665.clusters.proteins.v11.5.txt",
		        "sequence_path": "206665.protein.sequences.v11.5.fa",
		        "enrichment_path": "206665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "206665.protein.info.v11.5.txt",
		        "node_list_path": "206665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "206665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacillusSpOk042(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus sp. OK042 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusSpOk042", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884381.protein.info.v11.5.txt",
		        "node_list_path": "1884381.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydatigeraTaeniaeformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydatigera taeniaeformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydatigeraTaeniaeformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6205.clusters.proteins.v11.5.txt",
		        "sequence_path": "6205.protein.sequences.v11.5.fa",
		        "enrichment_path": "6205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6205.protein.info.v11.5.txt",
		        "node_list_path": "6205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesJohnsoniiDsm18315Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides johnsonii DSM 18315 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesJohnsoniiDsm18315Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "537006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "537006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "537006.clusters.proteins.v11.5.txt",
		        "sequence_path": "537006.protein.sequences.v11.5.fa",
		        "enrichment_path": "537006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537006.protein.info.v11.5.txt",
		        "node_list_path": "537006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "537006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa1478Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA1_47_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa1478Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618793.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618793.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618793.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618793.protein.info.v11.5.txt",
		        "node_list_path": "1618793.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618793.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesPectinophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides pectinophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesPectinophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "483218.protein.sequences.v11.5.fa",
		        "enrichment_path": "483218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483218.protein.info.v11.5.txt",
		        "node_list_path": "483218.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxCitrulli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax citrulli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxCitrulli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "397945.protein.sequences.v11.5.fa",
		        "enrichment_path": "397945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397945.protein.info.v11.5.txt",
		        "node_list_path": "397945.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusThioreducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus thioreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusThioreducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "277988.clusters.info.v11.5.txt",
		        "cluster_tree_path": "277988.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "277988.clusters.proteins.v11.5.txt",
		        "sequence_path": "277988.protein.sequences.v11.5.fa",
		        "enrichment_path": "277988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "277988.protein.info.v11.5.txt",
		        "node_list_path": "277988.cluster.nodes.v11.5.txt",
		        "edge_list_path": "277988.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlebsiellaQuasipneumoniaeSubspSimilipneumoniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella quasipneumoniae subsp. similipneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaQuasipneumoniaeSubspSimilipneumoniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463164.protein.info.v11.5.txt",
		        "node_list_path": "1463164.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesGlycerinitolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces glycerinitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesGlycerinitolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1892869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892869.protein.info.v11.5.txt",
		        "node_list_path": "1892869.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiameybacterMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Niameybacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiameybacterMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658108.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658108.protein.info.v11.5.txt",
		        "node_list_path": "1658108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KribbellaSpAli6ACluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kribbella sp. ALI-6-A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KribbellaSpAli6ACluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1933817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1933817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1933817.clusters.proteins.v11.5.txt",
		        "sequence_path": "1933817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933817.protein.info.v11.5.txt",
		        "node_list_path": "1933817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1933817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumGraminicolaM1001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum graminicola M1.001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumGraminicolaM1001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "645133.protein.sequences.v11.5.fa",
		        "enrichment_path": "645133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645133.protein.info.v11.5.txt",
		        "node_list_path": "645133.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaeB728aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae B728a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaeB728aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "205918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "205918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "205918.clusters.proteins.v11.5.txt",
		        "sequence_path": "205918.protein.sequences.v11.5.fa",
		        "enrichment_path": "205918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "205918.protein.info.v11.5.txt",
		        "node_list_path": "205918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "205918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhialophoraAmericana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phialophora americana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhialophoraAmericana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5601.protein.sequences.v11.5.fa",
		        "enrichment_path": "5601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5601.protein.info.v11.5.txt",
		        "node_list_path": "5601.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium6137faaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 6_1_37FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium6137faaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658656.clusters.proteins.v11.5.txt",
		        "sequence_path": "658656.protein.sequences.v11.5.fa",
		        "enrichment_path": "658656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658656.protein.info.v11.5.txt",
		        "node_list_path": "658656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BotrytisCinereaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Botrytis cinerea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotrytisCinereaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40559.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40559.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40559.clusters.proteins.v11.5.txt",
		        "sequence_path": "40559.protein.sequences.v11.5.fa",
		        "enrichment_path": "40559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40559.protein.info.v11.5.txt",
		        "node_list_path": "40559.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40559.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KocuriaTurfanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kocuria turfanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaTurfanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "388357.protein.sequences.v11.5.fa",
		        "enrichment_path": "388357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388357.protein.info.v11.5.txt",
		        "node_list_path": "388357.protein.complete.v11.5.txt"
		    }
		]
    )()

def AllisonellaHistaminiformans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Allisonella histaminiformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllisonellaHistaminiformans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "209880.protein.sequences.v11.5.fa",
		        "enrichment_path": "209880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "209880.protein.info.v11.5.txt",
		        "node_list_path": "209880.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcremoniumChrysogenumAtcc11550(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acremonium chrysogenum ATCC 11550 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcremoniumChrysogenumAtcc11550", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "857340.protein.sequences.v11.5.fa",
		        "enrichment_path": "857340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857340.protein.info.v11.5.txt",
		        "node_list_path": "857340.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusAlkaliphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusAlkaliphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "279824.protein.sequences.v11.5.fa",
		        "enrichment_path": "279824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279824.protein.info.v11.5.txt",
		        "node_list_path": "279824.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3812(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_38_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3812", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802061.protein.info.v11.5.txt",
		        "node_list_path": "1802061.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychroserpensMesophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens mesophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroserpensMesophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "325473.protein.sequences.v11.5.fa",
		        "enrichment_path": "325473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "325473.protein.info.v11.5.txt",
		        "node_list_path": "325473.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifoxyd12Full5323(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12_FULL_53_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12Full5323", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797903.protein.info.v11.5.txt",
		        "node_list_path": "1797903.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArsukibacteriumIkkenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arsukibacterium ikkense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArsukibacteriumIkkenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "336831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "336831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "336831.clusters.proteins.v11.5.txt",
		        "sequence_path": "336831.protein.sequences.v11.5.fa",
		        "enrichment_path": "336831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336831.protein.info.v11.5.txt",
		        "node_list_path": "336831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "336831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaHanseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia hansenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaHanseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "537007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "537007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "537007.clusters.proteins.v11.5.txt",
		        "sequence_path": "537007.protein.sequences.v11.5.fa",
		        "enrichment_path": "537007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537007.protein.info.v11.5.txt",
		        "node_list_path": "537007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "537007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanidioschyzonMerolaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanidioschyzon merolae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanidioschyzonMerolaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45157.clusters.proteins.v11.5.txt",
		        "sequence_path": "45157.protein.sequences.v11.5.fa",
		        "enrichment_path": "45157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45157.protein.info.v11.5.txt",
		        "node_list_path": "45157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NodosilineaNodulosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nodosilinea nodulosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NodosilineaNodulosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118166.clusters.proteins.v11.5.txt",
		        "sequence_path": "118166.protein.sequences.v11.5.fa",
		        "enrichment_path": "118166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118166.protein.info.v11.5.txt",
		        "node_list_path": "118166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag288(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:288 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag288", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262791.protein.info.v11.5.txt",
		        "node_list_path": "1262791.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeitlerinemaSpPcc7105(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC 7105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeitlerinemaSpPcc7105", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "102127.protein.sequences.v11.5.fa",
		        "enrichment_path": "102127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102127.protein.info.v11.5.txt",
		        "node_list_path": "102127.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrobacterSuccinogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter succinogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSuccinogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59374.protein.sequences.v11.5.fa",
		        "enrichment_path": "59374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59374.protein.info.v11.5.txt",
		        "node_list_path": "59374.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxHongdengensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax hongdengensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxHongdengensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1177179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1177179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1177179.clusters.proteins.v11.5.txt",
		        "sequence_path": "1177179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177179.protein.info.v11.5.txt",
		        "node_list_path": "1177179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1177179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AequorivitaSublithincola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aequorivita sublithincola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AequorivitaSublithincola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "746697.protein.sequences.v11.5.fa",
		        "enrichment_path": "746697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "746697.protein.info.v11.5.txt",
		        "node_list_path": "746697.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldalkalibacillusThermarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldalkalibacillus thermarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldalkalibacillusThermarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "986075.clusters.info.v11.5.txt",
		        "cluster_tree_path": "986075.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "986075.clusters.proteins.v11.5.txt",
		        "sequence_path": "986075.protein.sequences.v11.5.fa",
		        "enrichment_path": "986075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "986075.protein.info.v11.5.txt",
		        "node_list_path": "986075.cluster.nodes.v11.5.txt",
		        "edge_list_path": "986075.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorallococcusSpCag1435Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corallococcus sp. CAG:1435 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorallococcusSpCag1435Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262867.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262867.protein.info.v11.5.txt",
		        "node_list_path": "1262867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelomonasSpRoot662(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root662 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelomonasSpRoot662", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736580.protein.info.v11.5.txt",
		        "node_list_path": "1736580.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusRivorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus rivorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusRivorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762845.protein.sequences.v11.5.fa",
		        "enrichment_path": "762845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762845.protein.info.v11.5.txt",
		        "node_list_path": "762845.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwc14518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWC1_45_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwc14518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618696.protein.info.v11.5.txt",
		        "node_list_path": "1618696.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnormaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enorma massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnormaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118060.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118060.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118060.protein.info.v11.5.txt",
		        "node_list_path": "1118060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConexibacterWoeseiDsm14684Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Conexibacter woesei DSM14684 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConexibacterWoeseiDsm14684Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469383.clusters.proteins.v11.5.txt",
		        "sequence_path": "469383.protein.sequences.v11.5.fa",
		        "enrichment_path": "469383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469383.protein.info.v11.5.txt",
		        "node_list_path": "469383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusVogelbacteriaBacteriumRifoxyd1Full4619Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_46_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full4619Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802439.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802439.protein.info.v11.5.txt",
		        "node_list_path": "1802439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasPituitosaNbrc102491(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas pituitosa NBRC 102491 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasPituitosaNbrc102491", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219051.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219051.protein.info.v11.5.txt",
		        "node_list_path": "1219051.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumPseudocatenulatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudocatenulatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumPseudocatenulatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "547043.clusters.info.v11.5.txt",
		        "cluster_tree_path": "547043.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "547043.clusters.proteins.v11.5.txt",
		        "sequence_path": "547043.protein.sequences.v11.5.fa",
		        "enrichment_path": "547043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547043.protein.info.v11.5.txt",
		        "node_list_path": "547043.cluster.nodes.v11.5.txt",
		        "edge_list_path": "547043.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaSpA4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. A4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpA4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1225184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1225184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1225184.clusters.proteins.v11.5.txt",
		        "sequence_path": "1225184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225184.protein.info.v11.5.txt",
		        "node_list_path": "1225184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1225184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusAuricularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus auricularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusAuricularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29379.clusters.proteins.v11.5.txt",
		        "sequence_path": "29379.protein.sequences.v11.5.fa",
		        "enrichment_path": "29379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29379.protein.info.v11.5.txt",
		        "node_list_path": "29379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCb03234(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB03234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCb03234", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703937.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703937.protein.info.v11.5.txt",
		        "node_list_path": "1703937.protein.complete.v11.5.txt"
		    }
		]
    )()

def IchthyophthiriusMultifiliis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ichthyophthirius multifiliis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IchthyophthiriusMultifiliis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5932.protein.sequences.v11.5.fa",
		        "enrichment_path": "5932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5932.protein.info.v11.5.txt",
		        "node_list_path": "5932.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidiplasmaSpMba1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidiplasma sp. MBA-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidiplasmaSpMba1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293648.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293648.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293648.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293648.protein.info.v11.5.txt",
		        "node_list_path": "1293648.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293648.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSp63713(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. 63-713 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSp63713", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895900.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895900.protein.info.v11.5.txt",
		        "node_list_path": "1895900.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumZeaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium zeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumZeaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1416779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1416779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1416779.clusters.proteins.v11.5.txt",
		        "sequence_path": "1416779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416779.protein.info.v11.5.txt",
		        "node_list_path": "1416779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1416779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DactylellinaHaptotylaCbs20050(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dactylellina haptotyla CBS 200.50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DactylellinaHaptotylaCbs20050", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1284197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284197.protein.info.v11.5.txt",
		        "node_list_path": "1284197.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpBr18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Br18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpBr18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1312954.protein.sequences.v11.5.fa",
		        "enrichment_path": "1312954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1312954.protein.info.v11.5.txt",
		        "node_list_path": "1312954.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusFervensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus fervens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusFervensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573064.clusters.proteins.v11.5.txt",
		        "sequence_path": "573064.protein.sequences.v11.5.fa",
		        "enrichment_path": "573064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573064.protein.info.v11.5.txt",
		        "node_list_path": "573064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium4316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 43-16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium4316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895923.protein.info.v11.5.txt",
		        "node_list_path": "1895923.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyramidobacterPiscolens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyramidobacter piscolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyramidobacterPiscolens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "352165.protein.sequences.v11.5.fa",
		        "enrichment_path": "352165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "352165.protein.info.v11.5.txt",
		        "node_list_path": "352165.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusHelveticusDpc4571Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus DPC4571 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHelveticusDpc4571Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "405566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "405566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "405566.clusters.proteins.v11.5.txt",
		        "sequence_path": "405566.protein.sequences.v11.5.fa",
		        "enrichment_path": "405566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405566.protein.info.v11.5.txt",
		        "node_list_path": "405566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "405566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpRd272Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Rd 27.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpRd272Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926479.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926479.protein.info.v11.5.txt",
		        "node_list_path": "1926479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MooreaProducensPal815081Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moorea producens PAL-8-15-08-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MooreaProducensPal815081Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1458985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1458985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1458985.clusters.proteins.v11.5.txt",
		        "sequence_path": "1458985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458985.protein.info.v11.5.txt",
		        "node_list_path": "1458985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1458985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConexibacterWoeseiDsm14684(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Conexibacter woesei DSM14684 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConexibacterWoeseiDsm14684", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469383.protein.sequences.v11.5.fa",
		        "enrichment_path": "469383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469383.protein.info.v11.5.txt",
		        "node_list_path": "469383.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumLf3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium LF3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumLf3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1504823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504823.protein.info.v11.5.txt",
		        "node_list_path": "1504823.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeminocystisHerdmanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geminocystis herdmanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeminocystisHerdmanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "113355.protein.sequences.v11.5.fa",
		        "enrichment_path": "113355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113355.protein.info.v11.5.txt",
		        "node_list_path": "113355.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4152bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_52b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4152bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801779.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801779.protein.info.v11.5.txt",
		        "node_list_path": "1801779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterPeloridisLmg23910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter peloridis LMG 23910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterPeloridisLmg23910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1388753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1388753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1388753.protein.info.v11.5.txt",
		        "node_list_path": "1388753.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpUnc402clcolCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. UNC402CLCol Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpUnc402clcolCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1510531.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1510531.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1510531.clusters.proteins.v11.5.txt",
		        "sequence_path": "1510531.protein.sequences.v11.5.fa",
		        "enrichment_path": "1510531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1510531.protein.info.v11.5.txt",
		        "node_list_path": "1510531.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1510531.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FerrimonasSenticiiDsm18821(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas senticii DSM 18821 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrimonasSenticiiDsm18821", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121880.protein.info.v11.5.txt",
		        "node_list_path": "1121880.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaUbonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia ubonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaUbonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "101571.protein.sequences.v11.5.fa",
		        "enrichment_path": "101571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101571.protein.info.v11.5.txt",
		        "node_list_path": "101571.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpKk1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. KK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpKk1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855726.protein.info.v11.5.txt",
		        "node_list_path": "1855726.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumCg2303729(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium CG2_30_37_29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumCg2303729", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805237.protein.info.v11.5.txt",
		        "node_list_path": "1805237.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioParahaemolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio parahaemolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioParahaemolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "223926.clusters.info.v11.5.txt",
		        "cluster_tree_path": "223926.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "223926.clusters.proteins.v11.5.txt",
		        "sequence_path": "223926.protein.sequences.v11.5.fa",
		        "enrichment_path": "223926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223926.protein.info.v11.5.txt",
		        "node_list_path": "223926.cluster.nodes.v11.5.txt",
		        "edge_list_path": "223926.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DactylellinaHaptotylaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dactylellina haptotyla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DactylellinaHaptotylaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "430498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "430498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "430498.clusters.proteins.v11.5.txt",
		        "sequence_path": "430498.protein.sequences.v11.5.fa",
		        "enrichment_path": "430498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "430498.protein.info.v11.5.txt",
		        "node_list_path": "430498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "430498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PluralibacterGergoviaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pluralibacter gergoviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PluralibacterGergoviaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61647.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61647.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61647.clusters.proteins.v11.5.txt",
		        "sequence_path": "61647.protein.sequences.v11.5.fa",
		        "enrichment_path": "61647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61647.protein.info.v11.5.txt",
		        "node_list_path": "61647.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61647.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteroidesChelonae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacteroides chelonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteroidesChelonae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1774.protein.info.v11.5.txt",
		        "node_list_path": "1774.protein.complete.v11.5.txt"
		    }
		]
    )()

def SclerotiniaSclerotiorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sclerotinia sclerotiorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SclerotiniaSclerotiorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5180.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5180.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5180.clusters.proteins.v11.5.txt",
		        "sequence_path": "5180.protein.sequences.v11.5.fa",
		        "enrichment_path": "5180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5180.protein.info.v11.5.txt",
		        "node_list_path": "5180.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5180.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium6579(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 65-79 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium6579", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895815.protein.info.v11.5.txt",
		        "node_list_path": "1895815.protein.complete.v11.5.txt"
		    }
		]
    )()

def MastigocladopsisRepensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mastigocladopsis repens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MastigocladopsisRepensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "221288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "221288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "221288.clusters.proteins.v11.5.txt",
		        "sequence_path": "221288.protein.sequences.v11.5.fa",
		        "enrichment_path": "221288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221288.protein.info.v11.5.txt",
		        "node_list_path": "221288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "221288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchistosomaBovisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaBovisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6184.clusters.proteins.v11.5.txt",
		        "sequence_path": "6184.protein.sequences.v11.5.fa",
		        "enrichment_path": "6184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6184.protein.info.v11.5.txt",
		        "node_list_path": "6184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaEffusa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia effusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaEffusa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1077974.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077974.protein.info.v11.5.txt",
		        "node_list_path": "1077974.protein.complete.v11.5.txt"
		    }
		]
    )()

def VaranusKomodoensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Varanus komodoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaranusKomodoensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61221.clusters.proteins.v11.5.txt",
		        "sequence_path": "61221.protein.sequences.v11.5.fa",
		        "enrichment_path": "61221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61221.protein.info.v11.5.txt",
		        "node_list_path": "61221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusFonticolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus fonticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusFonticolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122918.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122918.protein.info.v11.5.txt",
		        "node_list_path": "1122918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumLentiflavumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium lentiflavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumLentiflavumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "141349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "141349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "141349.clusters.proteins.v11.5.txt",
		        "sequence_path": "141349.protein.sequences.v11.5.fa",
		        "enrichment_path": "141349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "141349.protein.info.v11.5.txt",
		        "node_list_path": "141349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "141349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliopsisZonataCbs50665(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicilliopsis zonata CBS 506.65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliopsisZonataCbs50665", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1073090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073090.protein.info.v11.5.txt",
		        "node_list_path": "1073090.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHtcc2143(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHtcc2143", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "247633.protein.sequences.v11.5.fa",
		        "enrichment_path": "247633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247633.protein.info.v11.5.txt",
		        "node_list_path": "247633.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusFructivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fructivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFructivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "941770.protein.sequences.v11.5.fa",
		        "enrichment_path": "941770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "941770.protein.info.v11.5.txt",
		        "node_list_path": "941770.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChaetomiumThermophilumVarThermophilumDsm1495(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium thermophilum var. thermophilum DSM 1495 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChaetomiumThermophilumVarThermophilumDsm1495", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "759272.protein.sequences.v11.5.fa",
		        "enrichment_path": "759272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759272.protein.info.v11.5.txt",
		        "node_list_path": "759272.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobotrysFlagrans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobotrys flagrans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobotrysFlagrans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "97331.protein.sequences.v11.5.fa",
		        "enrichment_path": "97331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97331.protein.info.v11.5.txt",
		        "node_list_path": "97331.protein.complete.v11.5.txt"
		    }
		]
    )()

def FonsecaeaMultimorphosaCbs102226Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fonsecaea multimorphosa CBS 102226 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FonsecaeaMultimorphosaCbs102226Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1442371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1442371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1442371.clusters.proteins.v11.5.txt",
		        "sequence_path": "1442371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1442371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1442371.protein.info.v11.5.txt",
		        "node_list_path": "1442371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1442371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelotomaculumSpDtu098Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelotomaculum sp. DTU098 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelotomaculumSpDtu098Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671628.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671628.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671628.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671628.protein.info.v11.5.txt",
		        "node_list_path": "1671628.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671628.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4470(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4470 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4470", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977881.protein.info.v11.5.txt",
		        "node_list_path": "1977881.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifoxyd12Full5712Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12_FULL_57_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12Full5712Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797906.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797906.protein.info.v11.5.txt",
		        "node_list_path": "1797906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AkkermansiaMuciniphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Akkermansia muciniphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AkkermansiaMuciniphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349741.clusters.proteins.v11.5.txt",
		        "sequence_path": "349741.protein.sequences.v11.5.fa",
		        "enrichment_path": "349741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349741.protein.info.v11.5.txt",
		        "node_list_path": "349741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpKms(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. KMS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpKms", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "189918.protein.sequences.v11.5.fa",
		        "enrichment_path": "189918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189918.protein.info.v11.5.txt",
		        "node_list_path": "189918.protein.complete.v11.5.txt"
		    }
		]
    )()

def BosMutusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bos mutus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BosMutusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "72004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "72004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "72004.clusters.proteins.v11.5.txt",
		        "sequence_path": "72004.protein.sequences.v11.5.fa",
		        "enrichment_path": "72004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72004.protein.info.v11.5.txt",
		        "node_list_path": "72004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "72004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloquadratumWalsbyiJ07hqw2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi J07HQW2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloquadratumWalsbyiJ07hqw2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1238425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1238425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1238425.clusters.proteins.v11.5.txt",
		        "sequence_path": "1238425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238425.protein.info.v11.5.txt",
		        "node_list_path": "1238425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1238425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesocricetusAuratus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesocricetus auratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesocricetusAuratus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10036.protein.sequences.v11.5.fa",
		        "enrichment_path": "10036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10036.protein.info.v11.5.txt",
		        "node_list_path": "10036.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumMinimumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium minimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumMinimumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1693.clusters.proteins.v11.5.txt",
		        "sequence_path": "1693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1693.protein.info.v11.5.txt",
		        "node_list_path": "1693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpVt162(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. VT 162 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpVt162", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1419814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1419814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1419814.protein.info.v11.5.txt",
		        "node_list_path": "1419814.protein.complete.v11.5.txt"
		    }
		]
    )()

def DenitrovibrioAcetiphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Denitrovibrio acetiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DenitrovibrioAcetiphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "522772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "522772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "522772.clusters.proteins.v11.5.txt",
		        "sequence_path": "522772.protein.sequences.v11.5.fa",
		        "enrichment_path": "522772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "522772.protein.info.v11.5.txt",
		        "node_list_path": "522772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "522772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AncylostomaCaninum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ancylostoma caninum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AncylostomaCaninum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29170.protein.sequences.v11.5.fa",
		        "enrichment_path": "29170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29170.protein.info.v11.5.txt",
		        "node_list_path": "29170.protein.complete.v11.5.txt"
		    }
		]
    )()

def SedimentitaleaNanhaiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sedimentitalea nanhaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SedimentitaleaNanhaiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999627.clusters.proteins.v11.5.txt",
		        "sequence_path": "999627.protein.sequences.v11.5.fa",
		        "enrichment_path": "999627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999627.protein.info.v11.5.txt",
		        "node_list_path": "999627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitis2Sk95Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis 2 SK95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitis2Sk95Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1000588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1000588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1000588.clusters.proteins.v11.5.txt",
		        "sequence_path": "1000588.protein.sequences.v11.5.fa",
		        "enrichment_path": "1000588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1000588.protein.info.v11.5.txt",
		        "node_list_path": "1000588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1000588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChelativoransSpBnc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chelativorans sp. BNC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelativoransSpBnc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266779.clusters.proteins.v11.5.txt",
		        "sequence_path": "266779.protein.sequences.v11.5.fa",
		        "enrichment_path": "266779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266779.protein.info.v11.5.txt",
		        "node_list_path": "266779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumGwa24518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_45_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa24518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801839.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801839.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801839.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801839.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801839.protein.info.v11.5.txt",
		        "node_list_path": "1801839.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801839.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DiaphorinaCitri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Diaphorina citri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiaphorinaCitri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "121845.protein.sequences.v11.5.fa",
		        "enrichment_path": "121845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121845.protein.info.v11.5.txt",
		        "node_list_path": "121845.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachyspiraMurdochii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira murdochii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraMurdochii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "526224.protein.sequences.v11.5.fa",
		        "enrichment_path": "526224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526224.protein.info.v11.5.txt",
		        "node_list_path": "526224.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPenetrans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma penetrans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPenetrans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272633.protein.sequences.v11.5.fa",
		        "enrichment_path": "272633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272633.protein.info.v11.5.txt",
		        "node_list_path": "272633.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloteneraVersatilis7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera versatilis 7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraVersatilis7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1101193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101193.protein.info.v11.5.txt",
		        "node_list_path": "1101193.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasAquaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasAquaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "558964.clusters.info.v11.5.txt",
		        "cluster_tree_path": "558964.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "558964.clusters.proteins.v11.5.txt",
		        "sequence_path": "558964.protein.sequences.v11.5.fa",
		        "enrichment_path": "558964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558964.protein.info.v11.5.txt",
		        "node_list_path": "558964.cluster.nodes.v11.5.txt",
		        "edge_list_path": "558964.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudovibrioSpFobeg1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. FOBEG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioSpFobeg1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "911045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "911045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "911045.clusters.proteins.v11.5.txt",
		        "sequence_path": "911045.protein.sequences.v11.5.fa",
		        "enrichment_path": "911045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "911045.protein.info.v11.5.txt",
		        "node_list_path": "911045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "911045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VitellibacterAquimarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vitellibacter aquimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VitellibacterAquimarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1548749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1548749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1548749.clusters.proteins.v11.5.txt",
		        "sequence_path": "1548749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548749.protein.info.v11.5.txt",
		        "node_list_path": "1548749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1548749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfuromonadaceaeBacteriumGwc25813Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromonadaceae bacterium GWC2_58_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromonadaceaeBacteriumGwc25813Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801896.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801896.protein.info.v11.5.txt",
		        "node_list_path": "1801896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpS9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. S9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpS9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "686578.clusters.info.v11.5.txt",
		        "cluster_tree_path": "686578.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "686578.clusters.proteins.v11.5.txt",
		        "sequence_path": "686578.protein.sequences.v11.5.fa",
		        "enrichment_path": "686578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686578.protein.info.v11.5.txt",
		        "node_list_path": "686578.cluster.nodes.v11.5.txt",
		        "edge_list_path": "686578.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LabeoRohita(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Labeo rohita graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabeoRohita", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84645.protein.sequences.v11.5.fa",
		        "enrichment_path": "84645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84645.protein.info.v11.5.txt",
		        "node_list_path": "84645.protein.complete.v11.5.txt"
		    }
		]
    )()

def SideroxydansLithotrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sideroxydans lithotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SideroxydansLithotrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "580332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "580332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "580332.clusters.proteins.v11.5.txt",
		        "sequence_path": "580332.protein.sequences.v11.5.fa",
		        "enrichment_path": "580332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "580332.protein.info.v11.5.txt",
		        "node_list_path": "580332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "580332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpDjl10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. djl-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpDjl10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1879023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1879023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1879023.protein.info.v11.5.txt",
		        "node_list_path": "1879023.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumAcnesSk182bjcvi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes SK182BJCVI graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumAcnesSk182bjcvi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1051006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051006.protein.info.v11.5.txt",
		        "node_list_path": "1051006.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpKpl1986(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1986 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpKpl1986", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203619.protein.info.v11.5.txt",
		        "node_list_path": "1203619.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasSpAap120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas sp. AAP120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasSpAap120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523430.protein.info.v11.5.txt",
		        "node_list_path": "1523430.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeovisonVisonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neovison vison Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeovisonVisonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "452646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "452646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "452646.clusters.proteins.v11.5.txt",
		        "sequence_path": "452646.protein.sequences.v11.5.fa",
		        "enrichment_path": "452646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452646.protein.info.v11.5.txt",
		        "node_list_path": "452646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "452646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmoparaHalstediiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmopara halstedii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmoparaHalstediiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4781.clusters.proteins.v11.5.txt",
		        "sequence_path": "4781.protein.sequences.v11.5.fa",
		        "enrichment_path": "4781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4781.protein.info.v11.5.txt",
		        "node_list_path": "4781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycesSpShPl14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces sp. SH-PL14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycesSpShPl14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1632864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1632864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1632864.clusters.proteins.v11.5.txt",
		        "sequence_path": "1632864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1632864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1632864.protein.info.v11.5.txt",
		        "node_list_path": "1632864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1632864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChristensenellaceaeBacteriumPhil7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Christensenellaceae bacterium Phil7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChristensenellaceaeBacteriumPhil7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930013.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930013.protein.info.v11.5.txt",
		        "node_list_path": "1930013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumConfluentis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium confluentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumConfluentis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28047.protein.sequences.v11.5.fa",
		        "enrichment_path": "28047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28047.protein.info.v11.5.txt",
		        "node_list_path": "28047.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumCag495(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium CAG:495 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumCag495", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262987.protein.info.v11.5.txt",
		        "node_list_path": "1262987.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaSpRubisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia sp. Rubis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaSpRubisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1444712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1444712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1444712.clusters.proteins.v11.5.txt",
		        "sequence_path": "1444712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444712.protein.info.v11.5.txt",
		        "node_list_path": "1444712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1444712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAlniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces alni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAlniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "380248.clusters.info.v11.5.txt",
		        "cluster_tree_path": "380248.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "380248.clusters.proteins.v11.5.txt",
		        "sequence_path": "380248.protein.sequences.v11.5.fa",
		        "enrichment_path": "380248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380248.protein.info.v11.5.txt",
		        "node_list_path": "380248.cluster.nodes.v11.5.txt",
		        "edge_list_path": "380248.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumDeltae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium deltae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumDeltae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1393034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1393034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1393034.protein.info.v11.5.txt",
		        "node_list_path": "1393034.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122609.protein.info.v11.5.txt",
		        "node_list_path": "1122609.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumBkt015925(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum BKT015925 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumBkt015925", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "929506.protein.sequences.v11.5.fa",
		        "enrichment_path": "929506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929506.protein.info.v11.5.txt",
		        "node_list_path": "929506.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaludibacterJiangxiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paludibacter jiangxiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaludibacterJiangxiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "681398.protein.sequences.v11.5.fa",
		        "enrichment_path": "681398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "681398.protein.info.v11.5.txt",
		        "node_list_path": "681398.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaConcava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia concava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaConcava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206741.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206741.protein.info.v11.5.txt",
		        "node_list_path": "1206741.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWs6BacteriumOlb20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium OLB20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWs6BacteriumOlb20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617426.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617426.protein.info.v11.5.txt",
		        "node_list_path": "1617426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrosporumCanisCbs113480Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microsporum canis CBS 113480 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrosporumCanisCbs113480Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "554155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "554155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "554155.clusters.proteins.v11.5.txt",
		        "sequence_path": "554155.protein.sequences.v11.5.fa",
		        "enrichment_path": "554155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "554155.protein.info.v11.5.txt",
		        "node_list_path": "554155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "554155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseobacterLitoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterLitoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391595.protein.sequences.v11.5.fa",
		        "enrichment_path": "391595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391595.protein.info.v11.5.txt",
		        "node_list_path": "391595.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaJejuensisNbrc103114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia jejuensis NBRC 103114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaJejuensisNbrc103114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210088.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210088.protein.info.v11.5.txt",
		        "node_list_path": "1210088.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumJdfr81Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumJdfr81Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935142.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935142.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935142.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935142.protein.info.v11.5.txt",
		        "node_list_path": "1935142.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935142.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSyntrophoarchaeumButanivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Syntrophoarchaeum butanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSyntrophoarchaeumButanivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1839936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1839936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1839936.clusters.proteins.v11.5.txt",
		        "sequence_path": "1839936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1839936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1839936.protein.info.v11.5.txt",
		        "node_list_path": "1839936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1839936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfonatronospiraThiodismutans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronospira thiodismutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronospiraThiodismutans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "555779.protein.sequences.v11.5.fa",
		        "enrichment_path": "555779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555779.protein.info.v11.5.txt",
		        "node_list_path": "555779.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycetocolaMiduiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycetocola miduiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycetocolaMiduiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "995034.protein.sequences.v11.5.fa",
		        "enrichment_path": "995034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "995034.protein.info.v11.5.txt",
		        "node_list_path": "995034.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusHominickiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus hominickii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusHominickiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351679.clusters.proteins.v11.5.txt",
		        "sequence_path": "351679.protein.sequences.v11.5.fa",
		        "enrichment_path": "351679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351679.protein.info.v11.5.txt",
		        "node_list_path": "351679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomonasIntermedia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas intermedia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomonasIntermedia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "75379.protein.sequences.v11.5.fa",
		        "enrichment_path": "75379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75379.protein.info.v11.5.txt",
		        "node_list_path": "75379.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBaumanniiBjab07104(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii BJAB07104 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBaumanniiBjab07104", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1096995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1096995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1096995.protein.info.v11.5.txt",
		        "node_list_path": "1096995.protein.complete.v11.5.txt"
		    }
		]
    )()

def PonticaulisKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ponticaulis koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PonticaulisKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "551789.protein.sequences.v11.5.fa",
		        "enrichment_path": "551789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551789.protein.info.v11.5.txt",
		        "node_list_path": "551789.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasCampestrisPvCampestrisStrAtcc33913(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris pv. campestris str. ATCC 33913 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCampestrisPvCampestrisStrAtcc33913", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "190485.protein.sequences.v11.5.fa",
		        "enrichment_path": "190485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190485.protein.info.v11.5.txt",
		        "node_list_path": "190485.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpLeaf72Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Leaf72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpLeaf72Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736234.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736234.protein.info.v11.5.txt",
		        "node_list_path": "1736234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusFlavithermusWk1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus WK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusFlavithermusWk1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "491915.protein.sequences.v11.5.fa",
		        "enrichment_path": "491915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "491915.protein.info.v11.5.txt",
		        "node_list_path": "491915.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobiumPhaeovibrioides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium phaeovibrioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumPhaeovibrioides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290318.protein.sequences.v11.5.fa",
		        "enrichment_path": "290318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290318.protein.info.v11.5.txt",
		        "node_list_path": "290318.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlycomycesTenuis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glycomyces tenuis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlycomycesTenuis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "58116.protein.sequences.v11.5.fa",
		        "enrichment_path": "58116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58116.protein.info.v11.5.txt",
		        "node_list_path": "58116.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxXenomutansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax xenomutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxXenomutansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094342.protein.info.v11.5.txt",
		        "node_list_path": "1094342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSpHh01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. HH01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSpHh01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1198452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1198452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1198452.clusters.proteins.v11.5.txt",
		        "sequence_path": "1198452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198452.protein.info.v11.5.txt",
		        "node_list_path": "1198452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1198452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SedimentisphaeraSalicampiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sedimentisphaera salicampi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SedimentisphaeraSalicampiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1941349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1941349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1941349.clusters.proteins.v11.5.txt",
		        "sequence_path": "1941349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1941349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1941349.protein.info.v11.5.txt",
		        "node_list_path": "1941349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1941349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAtratus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces atratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAtratus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1893.protein.info.v11.5.txt",
		        "node_list_path": "1893.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1755099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1755099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1755099.clusters.proteins.v11.5.txt",
		        "sequence_path": "1755099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1755099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1755099.protein.info.v11.5.txt",
		        "node_list_path": "1755099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1755099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbiconiuxSpYr403Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbiconiux sp. YR403 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbiconiuxSpYr403Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500280.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500280.protein.info.v11.5.txt",
		        "node_list_path": "1500280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumViciae248(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae 248 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumViciae248", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936136.protein.sequences.v11.5.fa",
		        "enrichment_path": "936136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936136.protein.info.v11.5.txt",
		        "node_list_path": "936136.protein.complete.v11.5.txt"
		    }
		]
    )()

def DickeyaSpDw0440(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya sp. DW 0440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaSpDw0440", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1225785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225785.protein.info.v11.5.txt",
		        "node_list_path": "1225785.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaSabaudienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma sabaudiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaSabaudienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1276257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1276257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1276257.clusters.proteins.v11.5.txt",
		        "sequence_path": "1276257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276257.protein.info.v11.5.txt",
		        "node_list_path": "1276257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1276257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TulasnellaCalosporaMut4182Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tulasnella calospora MUT 4182 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TulasnellaCalosporaMut4182Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1051891.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1051891.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1051891.clusters.proteins.v11.5.txt",
		        "sequence_path": "1051891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051891.protein.info.v11.5.txt",
		        "node_list_path": "1051891.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1051891.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusSclerotionigerCbs115572(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sclerotioniger CBS 115572 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusSclerotionigerCbs115572", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1450535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450535.protein.info.v11.5.txt",
		        "node_list_path": "1450535.protein.complete.v11.5.txt"
		    }
		]
    )()

def SmaragdicoccusNiigatensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Smaragdicoccus niigatensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmaragdicoccusNiigatensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123258.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123258.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123258.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123258.protein.info.v11.5.txt",
		        "node_list_path": "1123258.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123258.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioInopinatusDsm10711Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio inopinatus DSM 10711 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioInopinatusDsm10711Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121453.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121453.protein.info.v11.5.txt",
		        "node_list_path": "1121453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusSp4557(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sp. 4557 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSp4557", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1042877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042877.protein.info.v11.5.txt",
		        "node_list_path": "1042877.protein.complete.v11.5.txt"
		    }
		]
    )()

def SunxiuqiniaDokdonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sunxiuqinia dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SunxiuqiniaDokdonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1409788.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1409788.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1409788.clusters.proteins.v11.5.txt",
		        "sequence_path": "1409788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1409788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1409788.protein.info.v11.5.txt",
		        "node_list_path": "1409788.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1409788.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TepidibacillusDecaturensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tepidibacillus decaturensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidibacillusDecaturensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1413211.protein.sequences.v11.5.fa",
		        "enrichment_path": "1413211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1413211.protein.info.v11.5.txt",
		        "node_list_path": "1413211.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonScgcAaa007O23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon SCGC AAA007-O23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonScgcAaa007O23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "913333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "913333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "913333.clusters.proteins.v11.5.txt",
		        "sequence_path": "913333.protein.sequences.v11.5.fa",
		        "enrichment_path": "913333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913333.protein.info.v11.5.txt",
		        "node_list_path": "913333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "913333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionKazanBacteriumRifcsphigho201Full4414(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RIFCSPHIGHO2_01_FULL_44_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionKazanBacteriumRifcsphigho201Full4414", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798536.protein.info.v11.5.txt",
		        "node_list_path": "1798536.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChishuiellaChangwenlii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chishuiella changwenlii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChishuiellaChangwenlii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434701.protein.info.v11.5.txt",
		        "node_list_path": "1434701.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpHeli88Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. HelI88 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpHeli88Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1250006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1250006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1250006.clusters.proteins.v11.5.txt",
		        "sequence_path": "1250006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250006.protein.info.v11.5.txt",
		        "node_list_path": "1250006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1250006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurovumRiftiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum riftiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurovumRiftiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1630136.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1630136.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1630136.clusters.proteins.v11.5.txt",
		        "sequence_path": "1630136.protein.sequences.v11.5.fa",
		        "enrichment_path": "1630136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1630136.protein.info.v11.5.txt",
		        "node_list_path": "1630136.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1630136.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho202Full4243Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_02_FULL_42_43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho202Full4243Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798272.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798272.protein.info.v11.5.txt",
		        "node_list_path": "1798272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalvatorMerianae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salvator merianae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalvatorMerianae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "96440.protein.sequences.v11.5.fa",
		        "enrichment_path": "96440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "96440.protein.info.v11.5.txt",
		        "node_list_path": "96440.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAc2014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAc2014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408320.protein.info.v11.5.txt",
		        "node_list_path": "1408320.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRbg13469(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RBG_13_46_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRbg13469", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801818.protein.info.v11.5.txt",
		        "node_list_path": "1801818.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodovulumSulfidophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sulfidophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovulumSulfidophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1188256.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188256.protein.info.v11.5.txt",
		        "node_list_path": "1188256.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosococcusOceaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosococcus oceani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosococcusOceaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "323261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "323261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "323261.clusters.proteins.v11.5.txt",
		        "sequence_path": "323261.protein.sequences.v11.5.fa",
		        "enrichment_path": "323261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323261.protein.info.v11.5.txt",
		        "node_list_path": "323261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "323261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PestalotiopsisFiciW1061(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pestalotiopsis fici W106-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PestalotiopsisFiciW1061", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229662.protein.info.v11.5.txt",
		        "node_list_path": "1229662.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfOnchocercaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Onchocerca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfOnchocercaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "100901.clusters.info.v11.5.txt",
		        "cluster_tree_path": "100901.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "100901.clusters.proteins.v11.5.txt",
		        "sequence_path": "100901.protein.sequences.v11.5.fa",
		        "enrichment_path": "100901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "100901.protein.info.v11.5.txt",
		        "node_list_path": "100901.cluster.nodes.v11.5.txt",
		        "edge_list_path": "100901.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KocuriaAtrinaeC38(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kocuria atrinae C3-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaAtrinaeC38", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1179225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179225.protein.info.v11.5.txt",
		        "node_list_path": "1179225.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloceanibacterCaenitepidi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloceanibacter caenitepidi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloceanibacterCaenitepidi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1384459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384459.protein.info.v11.5.txt",
		        "node_list_path": "1384459.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpGm2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GM2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpGm2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1622070.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1622070.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1622070.clusters.proteins.v11.5.txt",
		        "sequence_path": "1622070.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622070.protein.info.v11.5.txt",
		        "node_list_path": "1622070.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1622070.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KluyveromycesLactisNrrlY1140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kluyveromyces lactis NRRL Y-1140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KluyveromycesLactisNrrlY1140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "284590.protein.sequences.v11.5.fa",
		        "enrichment_path": "284590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284590.protein.info.v11.5.txt",
		        "node_list_path": "284590.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacterium13220cm2648Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_2_20CM_2_64_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacterium13220cm2648Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805369.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805369.protein.info.v11.5.txt",
		        "node_list_path": "1805369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DiplocarponRosaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Diplocarpon rosae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiplocarponRosaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "946125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "946125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "946125.clusters.proteins.v11.5.txt",
		        "sequence_path": "946125.protein.sequences.v11.5.fa",
		        "enrichment_path": "946125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946125.protein.info.v11.5.txt",
		        "node_list_path": "946125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "946125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSp05ny08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 05NY08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSp05ny08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1622149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622149.protein.info.v11.5.txt",
		        "node_list_path": "1622149.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumDegerlachei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium degerlachei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumDegerlachei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "229203.protein.sequences.v11.5.fa",
		        "enrichment_path": "229203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229203.protein.info.v11.5.txt",
		        "node_list_path": "229203.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonasPolymorphaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas polymorpha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasPolymorphaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280954.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280954.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280954.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280954.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280954.protein.info.v11.5.txt",
		        "node_list_path": "1280954.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280954.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RutstroemiaSpNjr2017aBbw(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rutstroemia sp. NJR-2017a BBW graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RutstroemiaSpNjr2017aBbw", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2070414.protein.sequences.v11.5.fa",
		        "enrichment_path": "2070414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2070414.protein.info.v11.5.txt",
		        "node_list_path": "2070414.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonasNeptunium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas neptunium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasNeptunium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "228405.protein.sequences.v11.5.fa",
		        "enrichment_path": "228405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228405.protein.info.v11.5.txt",
		        "node_list_path": "228405.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisCga009Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris CGA009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisCga009Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "258594.clusters.info.v11.5.txt",
		        "cluster_tree_path": "258594.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "258594.clusters.proteins.v11.5.txt",
		        "sequence_path": "258594.protein.sequences.v11.5.fa",
		        "enrichment_path": "258594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "258594.protein.info.v11.5.txt",
		        "node_list_path": "258594.cluster.nodes.v11.5.txt",
		        "edge_list_path": "258594.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GaleopterusVariegatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Galeopterus variegatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GaleopterusVariegatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "482537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "482537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "482537.clusters.proteins.v11.5.txt",
		        "sequence_path": "482537.protein.sequences.v11.5.fa",
		        "enrichment_path": "482537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "482537.protein.info.v11.5.txt",
		        "node_list_path": "482537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "482537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumPolonicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium polonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumPolonicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "60169.clusters.info.v11.5.txt",
		        "cluster_tree_path": "60169.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "60169.clusters.proteins.v11.5.txt",
		        "sequence_path": "60169.protein.sequences.v11.5.fa",
		        "enrichment_path": "60169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60169.protein.info.v11.5.txt",
		        "node_list_path": "60169.cluster.nodes.v11.5.txt",
		        "edge_list_path": "60169.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalanaerobiumSaccharolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halanaerobium saccharolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaerobiumSaccharolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293054.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293054.protein.info.v11.5.txt",
		        "node_list_path": "1293054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterFetusVenerealis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus venerealis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterFetusVenerealis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983328.protein.sequences.v11.5.fa",
		        "enrichment_path": "983328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983328.protein.info.v11.5.txt",
		        "node_list_path": "983328.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChelatococcusSpCo6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chelatococcus sp. CO-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelatococcusSpCo6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1702325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1702325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1702325.protein.info.v11.5.txt",
		        "node_list_path": "1702325.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusTuccetiDsm20183(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus tucceti DSM 20183 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusTuccetiDsm20183", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423811.protein.info.v11.5.txt",
		        "node_list_path": "1423811.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterJeongneungensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter jeongneungensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterJeongneungensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "947309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "947309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "947309.clusters.proteins.v11.5.txt",
		        "sequence_path": "947309.protein.sequences.v11.5.fa",
		        "enrichment_path": "947309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "947309.protein.info.v11.5.txt",
		        "node_list_path": "947309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "947309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlaciecolaArctica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaArctica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "493475.protein.sequences.v11.5.fa",
		        "enrichment_path": "493475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "493475.protein.info.v11.5.txt",
		        "node_list_path": "493475.protein.complete.v11.5.txt"
		    }
		]
    )()

def OpisthocomusHoazinCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Opisthocomus hoazin Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpisthocomusHoazinCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "30419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "30419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "30419.clusters.proteins.v11.5.txt",
		        "sequence_path": "30419.protein.sequences.v11.5.fa",
		        "enrichment_path": "30419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30419.protein.info.v11.5.txt",
		        "node_list_path": "30419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "30419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumLotiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumLotiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "381.clusters.proteins.v11.5.txt",
		        "sequence_path": "381.protein.sequences.v11.5.fa",
		        "enrichment_path": "381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381.protein.info.v11.5.txt",
		        "node_list_path": "381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumEhc02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium EhC02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumEhc02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849170.protein.info.v11.5.txt",
		        "node_list_path": "1849170.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFluviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium fluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFluviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "468056.clusters.info.v11.5.txt",
		        "cluster_tree_path": "468056.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "468056.clusters.proteins.v11.5.txt",
		        "sequence_path": "468056.protein.sequences.v11.5.fa",
		        "enrichment_path": "468056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "468056.protein.info.v11.5.txt",
		        "node_list_path": "468056.cluster.nodes.v11.5.txt",
		        "edge_list_path": "468056.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingorhabdusSpM41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingorhabdus sp. M41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingorhabdusSpM41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1806885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806885.protein.info.v11.5.txt",
		        "node_list_path": "1806885.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterLutaoensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter lutaoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterLutaoensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "135739.protein.sequences.v11.5.fa",
		        "enrichment_path": "135739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "135739.protein.info.v11.5.txt",
		        "node_list_path": "135739.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpUrhb0044(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. URHB0044 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpUrhb0044", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380386.protein.info.v11.5.txt",
		        "node_list_path": "1380386.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaSativa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaSativa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4530.protein.sequences.v11.5.fa",
		        "enrichment_path": "4530.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4530.protein.info.v11.5.txt",
		        "node_list_path": "4530.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndomicrobiumProavitumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Endomicrobium proavitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndomicrobiumProavitumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408281.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408281.protein.info.v11.5.txt",
		        "node_list_path": "1408281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumVitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium vitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumVitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "311402.protein.sequences.v11.5.fa",
		        "enrichment_path": "311402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311402.protein.info.v11.5.txt",
		        "node_list_path": "311402.protein.complete.v11.5.txt"
		    }
		]
    )()

def DactylococcopsisSalina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dactylococcopsis salina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DactylococcopsisSalina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13035.protein.sequences.v11.5.fa",
		        "enrichment_path": "13035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13035.protein.info.v11.5.txt",
		        "node_list_path": "13035.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaPrimitiaZas1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema primitia ZAS-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPrimitiaZas1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717227.protein.sequences.v11.5.fa",
		        "enrichment_path": "717227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717227.protein.info.v11.5.txt",
		        "node_list_path": "717227.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaceaeBacterium16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiaceae bacterium 16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaceaeBacterium16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619952.protein.info.v11.5.txt",
		        "node_list_path": "1619952.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpSoil522Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil522 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpSoil522Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736388.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736388.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736388.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736388.protein.info.v11.5.txt",
		        "node_list_path": "1736388.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736388.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusMauleoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus mauleonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusMauleoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351675.clusters.proteins.v11.5.txt",
		        "sequence_path": "351675.protein.sequences.v11.5.fa",
		        "enrichment_path": "351675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351675.protein.info.v11.5.txt",
		        "node_list_path": "351675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSpHk10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora sp. HK10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSpHk10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1538294.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1538294.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1538294.clusters.proteins.v11.5.txt",
		        "sequence_path": "1538294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1538294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1538294.protein.info.v11.5.txt",
		        "node_list_path": "1538294.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1538294.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSp6610Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 66-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSp6610Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895848.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895848.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895848.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895848.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895848.protein.info.v11.5.txt",
		        "node_list_path": "1895848.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895848.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudovibrioSpJcm19062(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. JCM 19062 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioSpJcm19062", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1481932.protein.sequences.v11.5.fa",
		        "enrichment_path": "1481932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1481932.protein.info.v11.5.txt",
		        "node_list_path": "1481932.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesNeuiiDsm8576Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces neuii DSM8576 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesNeuiiDsm8576Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120945.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120945.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120945.protein.info.v11.5.txt",
		        "node_list_path": "1120945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrialbaceaeArchaeonTcBr11E2g14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon Tc-Br11_E2g14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaceaeArchaeonTcBr11E2g14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729462.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729462.protein.info.v11.5.txt",
		        "node_list_path": "1729462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag567Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:567 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag567Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262820.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262820.protein.info.v11.5.txt",
		        "node_list_path": "1262820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronobacteriumTexcoconenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronobacterium texcoconense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronobacteriumTexcoconenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095778.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095778.protein.info.v11.5.txt",
		        "node_list_path": "1095778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColwelliaSpUcdKl20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia sp. UCD-KL20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaSpUcdKl20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1917165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917165.protein.info.v11.5.txt",
		        "node_list_path": "1917165.protein.complete.v11.5.txt"
		    }
		]
    )()

def TalaromycesMarneffeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces marneffei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesMarneffeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37727.clusters.proteins.v11.5.txt",
		        "sequence_path": "37727.protein.sequences.v11.5.fa",
		        "enrichment_path": "37727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37727.protein.info.v11.5.txt",
		        "node_list_path": "37727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlatysternonMegacephalumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Platysternon megacephalum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlatysternonMegacephalumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "55544.clusters.info.v11.5.txt",
		        "cluster_tree_path": "55544.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "55544.clusters.proteins.v11.5.txt",
		        "sequence_path": "55544.protein.sequences.v11.5.fa",
		        "enrichment_path": "55544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55544.protein.info.v11.5.txt",
		        "node_list_path": "55544.cluster.nodes.v11.5.txt",
		        "edge_list_path": "55544.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidiphiliumSpCag727Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidiphilium sp. CAG:727 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidiphiliumSpCag727Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262689.protein.info.v11.5.txt",
		        "node_list_path": "1262689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlr1721Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALR1721 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlr1721Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1269813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1269813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1269813.clusters.proteins.v11.5.txt",
		        "sequence_path": "1269813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1269813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1269813.protein.info.v11.5.txt",
		        "node_list_path": "1269813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1269813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusGallinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGallinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423748.protein.info.v11.5.txt",
		        "node_list_path": "1423748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGracilibacteriaBacteriumCg10238174Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gracilibacteria bacterium CG1_02_38_174 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGracilibacteriaBacteriumCg10238174Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805210.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805210.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805210.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805210.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805210.protein.info.v11.5.txt",
		        "node_list_path": "1805210.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805210.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpScn6821Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. SCN 68-21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpScn6821Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660154.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660154.protein.info.v11.5.txt",
		        "node_list_path": "1660154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PuniceibacteriumSpImcc21224(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Puniceibacterium sp. IMCC21224 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PuniceibacteriumSpImcc21224", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618204.protein.info.v11.5.txt",
		        "node_list_path": "1618204.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag884Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:884 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag884Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262990.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262990.protein.info.v11.5.txt",
		        "node_list_path": "1262990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaSpRoot136Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia sp. Root136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSpRoot136Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736458.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736458.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736458.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736458.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736458.protein.info.v11.5.txt",
		        "node_list_path": "1736458.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736458.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4027Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_40_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4027Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797788.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797788.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797788.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797788.protein.info.v11.5.txt",
		        "node_list_path": "1797788.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797788.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KitasatosporaMediocidicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora mediocidica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaMediocidicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449347.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449347.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449347.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449347.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449347.protein.info.v11.5.txt",
		        "node_list_path": "1449347.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449347.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonomuraeaJiangxiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea jiangxiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaJiangxiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "633440.protein.sequences.v11.5.fa",
		        "enrichment_path": "633440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633440.protein.info.v11.5.txt",
		        "node_list_path": "633440.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterPseudethanolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter pseudethanolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterPseudethanolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "340099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "340099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "340099.clusters.proteins.v11.5.txt",
		        "sequence_path": "340099.protein.sequences.v11.5.fa",
		        "enrichment_path": "340099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340099.protein.info.v11.5.txt",
		        "node_list_path": "340099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "340099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24716(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_47_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24716", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618842.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618842.protein.info.v11.5.txt",
		        "node_list_path": "1618842.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaNivaraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza nivara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaNivaraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4536.clusters.proteins.v11.5.txt",
		        "sequence_path": "4536.protein.sequences.v11.5.fa",
		        "enrichment_path": "4536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4536.protein.info.v11.5.txt",
		        "node_list_path": "4536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LaribacterHongkongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Laribacter hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LaribacterHongkongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "557598.protein.sequences.v11.5.fa",
		        "enrichment_path": "557598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "557598.protein.info.v11.5.txt",
		        "node_list_path": "557598.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseibiumSpTrichskd4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseibium sp. TrichSKD4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseibiumSpTrichskd4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "744980.clusters.info.v11.5.txt",
		        "cluster_tree_path": "744980.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "744980.clusters.proteins.v11.5.txt",
		        "sequence_path": "744980.protein.sequences.v11.5.fa",
		        "enrichment_path": "744980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "744980.protein.info.v11.5.txt",
		        "node_list_path": "744980.cluster.nodes.v11.5.txt",
		        "edge_list_path": "744980.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpL2c084a000(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. L2C084A000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpL2c084a000", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1287116.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287116.protein.info.v11.5.txt",
		        "node_list_path": "1287116.protein.complete.v11.5.txt"
		    }
		]
    )()

def AndreprevotiaChitinilytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Andreprevotia chitinilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AndreprevotiaChitinilytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120999.protein.info.v11.5.txt",
		        "node_list_path": "1120999.protein.complete.v11.5.txt"
		    }
		]
    )()

def StomatobaculumLongum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stomatobaculum longum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StomatobaculumLongum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "796942.protein.sequences.v11.5.fa",
		        "enrichment_path": "796942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796942.protein.info.v11.5.txt",
		        "node_list_path": "796942.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasProsekiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas prosekii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasProsekiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1148509.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1148509.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1148509.clusters.proteins.v11.5.txt",
		        "sequence_path": "1148509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1148509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1148509.protein.info.v11.5.txt",
		        "node_list_path": "1148509.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1148509.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumSpOralTaxon193Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium sp. oral taxon 193 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumSpOralTaxon193Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "671223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "671223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "671223.clusters.proteins.v11.5.txt",
		        "sequence_path": "671223.protein.sequences.v11.5.fa",
		        "enrichment_path": "671223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "671223.protein.info.v11.5.txt",
		        "node_list_path": "671223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "671223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalsuginibacillusKocuriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salsuginibacillus kocurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalsuginibacillusKocuriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123239.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123239.protein.info.v11.5.txt",
		        "node_list_path": "1123239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeraceosorusGuamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ceraceosorus guamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeraceosorusGuamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1522189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1522189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1522189.clusters.proteins.v11.5.txt",
		        "sequence_path": "1522189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522189.protein.info.v11.5.txt",
		        "node_list_path": "1522189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1522189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacimicrobiumAlkaliphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lacimicrobium alkaliphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacimicrobiumAlkaliphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1526571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1526571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1526571.clusters.proteins.v11.5.txt",
		        "sequence_path": "1526571.protein.sequences.v11.5.fa",
		        "enrichment_path": "1526571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1526571.protein.info.v11.5.txt",
		        "node_list_path": "1526571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1526571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasBauzanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas bauzanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBauzanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "653930.clusters.info.v11.5.txt",
		        "cluster_tree_path": "653930.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "653930.clusters.proteins.v11.5.txt",
		        "sequence_path": "653930.protein.sequences.v11.5.fa",
		        "enrichment_path": "653930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "653930.protein.info.v11.5.txt",
		        "node_list_path": "653930.cluster.nodes.v11.5.txt",
		        "edge_list_path": "653930.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MollicutesBacteriumHr2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mollicutes bacterium HR2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MollicutesBacteriumHr2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1541960.protein.sequences.v11.5.fa",
		        "enrichment_path": "1541960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1541960.protein.info.v11.5.txt",
		        "node_list_path": "1541960.protein.complete.v11.5.txt"
		    }
		]
    )()

def FaecalibacteriumPrausnitziiL26Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii L26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibacteriumPrausnitziiL26Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "718252.clusters.info.v11.5.txt",
		        "cluster_tree_path": "718252.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "718252.clusters.proteins.v11.5.txt",
		        "sequence_path": "718252.protein.sequences.v11.5.fa",
		        "enrichment_path": "718252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "718252.protein.info.v11.5.txt",
		        "node_list_path": "718252.cluster.nodes.v11.5.txt",
		        "edge_list_path": "718252.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaMagnaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella magna Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaMagnaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123489.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123489.protein.info.v11.5.txt",
		        "node_list_path": "1123489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwd23614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWD2_36_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwd23614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618758.protein.info.v11.5.txt",
		        "node_list_path": "1618758.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonadalesBacteriumRifcsplowo212599(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonadales bacterium RIFCSPLOWO2_12_59_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonadalesBacteriumRifcsplowo212599", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802009.protein.info.v11.5.txt",
		        "node_list_path": "1802009.protein.complete.v11.5.txt"
		    }
		]
    )()

def BryobacterAggregatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bryobacter aggregatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BryobacterAggregatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1340493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1340493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1340493.protein.info.v11.5.txt",
		        "node_list_path": "1340493.protein.complete.v11.5.txt"
		    }
		]
    )()

def CruoricaptorIgnavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cruoricaptor ignavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CruoricaptorIgnavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118202.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118202.protein.info.v11.5.txt",
		        "node_list_path": "1118202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumScgcAaa536G10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA536-G10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumScgcAaa536G10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1009708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1009708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1009708.clusters.proteins.v11.5.txt",
		        "sequence_path": "1009708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009708.protein.info.v11.5.txt",
		        "node_list_path": "1009708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1009708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCb02923(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB02923 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCb02923", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1718985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1718985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1718985.protein.info.v11.5.txt",
		        "node_list_path": "1718985.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisLatensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis latens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisLatensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1503980.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1503980.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1503980.clusters.proteins.v11.5.txt",
		        "sequence_path": "1503980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1503980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1503980.protein.info.v11.5.txt",
		        "node_list_path": "1503980.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1503980.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumDeleyianumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum deleyianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumDeleyianumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525898.clusters.proteins.v11.5.txt",
		        "sequence_path": "525898.protein.sequences.v11.5.fa",
		        "enrichment_path": "525898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525898.protein.info.v11.5.txt",
		        "node_list_path": "525898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisMediterraneiS699Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis mediterranei S699 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisMediterraneiS699Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "713604.clusters.info.v11.5.txt",
		        "cluster_tree_path": "713604.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "713604.clusters.proteins.v11.5.txt",
		        "sequence_path": "713604.protein.sequences.v11.5.fa",
		        "enrichment_path": "713604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713604.protein.info.v11.5.txt",
		        "node_list_path": "713604.cluster.nodes.v11.5.txt",
		        "edge_list_path": "713604.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusZinderiaInsecticolaCariCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zinderia insecticola CARI Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZinderiaInsecticolaCariCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "871271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "871271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "871271.clusters.proteins.v11.5.txt",
		        "sequence_path": "871271.protein.sequences.v11.5.fa",
		        "enrichment_path": "871271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871271.protein.info.v11.5.txt",
		        "node_list_path": "871271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "871271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterJohnsonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter johnsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterJohnsonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575586.protein.sequences.v11.5.fa",
		        "enrichment_path": "575586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575586.protein.info.v11.5.txt",
		        "node_list_path": "575586.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaSpLeaf53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia sp. Leaf53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaSpLeaf53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736225.protein.info.v11.5.txt",
		        "node_list_path": "1736225.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMuproteobacteriaBacteriumRbg166213Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_62_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166213Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817756.protein.info.v11.5.txt",
		        "node_list_path": "1817756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxya2Full3919(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2_FULL_39_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2Full3919", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797957.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797957.protein.info.v11.5.txt",
		        "node_list_path": "1797957.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusStomatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus stomatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusStomatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596315.protein.sequences.v11.5.fa",
		        "enrichment_path": "596315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596315.protein.info.v11.5.txt",
		        "node_list_path": "596315.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAsteroidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium asteroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAsteroidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1147128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1147128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1147128.clusters.proteins.v11.5.txt",
		        "sequence_path": "1147128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1147128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1147128.protein.info.v11.5.txt",
		        "node_list_path": "1147128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1147128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrunusYedoensisVarNudiflora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prunus yedoensis var. nudiflora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrunusYedoensisVarNudiflora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2094558.protein.sequences.v11.5.fa",
		        "enrichment_path": "2094558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2094558.protein.info.v11.5.txt",
		        "node_list_path": "2094558.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetallosphaeraYellowstonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metallosphaera yellowstonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetallosphaeraYellowstonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "671065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "671065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "671065.clusters.proteins.v11.5.txt",
		        "sequence_path": "671065.protein.sequences.v11.5.fa",
		        "enrichment_path": "671065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "671065.protein.info.v11.5.txt",
		        "node_list_path": "671065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "671065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLiberibacterAfricanusPtsapsy(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liberibacter africanus PTSAPSY graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiberibacterAfricanusPtsapsy", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1277257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1277257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1277257.protein.info.v11.5.txt",
		        "node_list_path": "1277257.protein.complete.v11.5.txt"
		    }
		]
    )()

def GloeomargaritaLithophoraAlchichicaD10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gloeomargarita lithophora Alchichica-D10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeomargaritaLithophoraAlchichicaD10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1188229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188229.protein.info.v11.5.txt",
		        "node_list_path": "1188229.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoranellaEndobia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moranella endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoranellaEndobia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "903503.protein.sequences.v11.5.fa",
		        "enrichment_path": "903503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903503.protein.info.v11.5.txt",
		        "node_list_path": "903503.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrodochiumBolleyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microdochium bolleyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrodochiumBolleyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "196109.protein.sequences.v11.5.fa",
		        "enrichment_path": "196109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "196109.protein.info.v11.5.txt",
		        "node_list_path": "196109.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthobacterSoliDsm19599Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthobacter soli DSM 19599 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthobacterSoliDsm19599Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123029.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123029.protein.info.v11.5.txt",
		        "node_list_path": "1123029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaMaritimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaMaritimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "519453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "519453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "519453.clusters.proteins.v11.5.txt",
		        "sequence_path": "519453.protein.sequences.v11.5.fa",
		        "enrichment_path": "519453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519453.protein.info.v11.5.txt",
		        "node_list_path": "519453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "519453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhyllobacteriumSpUnc302mfcol52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. UNC302MFCol52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhyllobacteriumSpUnc302mfcol52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449065.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449065.protein.info.v11.5.txt",
		        "node_list_path": "1449065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKomeilibacteriaBacteriumRifoxyd1Full3729Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFOXYD1_FULL_37_29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifoxyd1Full3729Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798557.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798557.protein.info.v11.5.txt",
		        "node_list_path": "1798557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaceaeBacterium16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiaceae bacterium 16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaceaeBacterium16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619952.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619952.protein.info.v11.5.txt",
		        "node_list_path": "1619952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellalesBacteriumRifcsphigho212Full3714(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionellales bacterium RIFCSPHIGHO2_12_FULL_37_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellalesBacteriumRifcsphigho212Full3714", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798568.protein.info.v11.5.txt",
		        "node_list_path": "1798568.protein.complete.v11.5.txt"
		    }
		]
    )()

def TessaracoccusBendigoensisDsm12906Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus bendigoensis DSM 12906 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusBendigoensisDsm12906Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123357.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123357.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123357.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123357.protein.info.v11.5.txt",
		        "node_list_path": "1123357.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123357.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PararhizobiumPolonicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pararhizobium polonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PararhizobiumPolonicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1612624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1612624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1612624.protein.info.v11.5.txt",
		        "node_list_path": "1612624.protein.complete.v11.5.txt"
		    }
		]
    )()

def AllokutzneriaAlbata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Allokutzneria albata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllokutzneriaAlbata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "211114.protein.sequences.v11.5.fa",
		        "enrichment_path": "211114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211114.protein.info.v11.5.txt",
		        "node_list_path": "211114.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpYr295(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR295 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpYr295", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500257.protein.info.v11.5.txt",
		        "node_list_path": "1500257.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasPiscicidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas piscicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasPiscicidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43662.clusters.proteins.v11.5.txt",
		        "sequence_path": "43662.protein.sequences.v11.5.fa",
		        "enrichment_path": "43662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43662.protein.info.v11.5.txt",
		        "node_list_path": "43662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanktotaleaFrisiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planktotalea frisia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktotaleaFrisiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "696762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "696762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "696762.clusters.proteins.v11.5.txt",
		        "sequence_path": "696762.protein.sequences.v11.5.fa",
		        "enrichment_path": "696762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696762.protein.info.v11.5.txt",
		        "node_list_path": "696762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "696762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumDivergens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium divergens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumDivergens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449336.protein.info.v11.5.txt",
		        "node_list_path": "1449336.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfatatorAtlanticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfatator atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfatatorAtlanticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123371.protein.info.v11.5.txt",
		        "node_list_path": "1123371.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisMediterranei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis mediterranei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisMediterranei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "749927.protein.sequences.v11.5.fa",
		        "enrichment_path": "749927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "749927.protein.info.v11.5.txt",
		        "node_list_path": "749927.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifoxyc12Full3613(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYC12_FULL_36_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxyc12Full3613", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801654.protein.info.v11.5.txt",
		        "node_list_path": "1801654.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaExalbidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia exalbida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaExalbidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206729.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206729.protein.info.v11.5.txt",
		        "node_list_path": "1206729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacterAkesuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter akesuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterAkesuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "388950.protein.sequences.v11.5.fa",
		        "enrichment_path": "388950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388950.protein.info.v11.5.txt",
		        "node_list_path": "388950.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusAcetotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acetotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAcetotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1600.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1600.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1600.clusters.proteins.v11.5.txt",
		        "sequence_path": "1600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1600.protein.info.v11.5.txt",
		        "node_list_path": "1600.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1600.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesUniformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides uniformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesUniformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411479.clusters.proteins.v11.5.txt",
		        "sequence_path": "411479.protein.sequences.v11.5.fa",
		        "enrichment_path": "411479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411479.protein.info.v11.5.txt",
		        "node_list_path": "411479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioQuintilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio quintilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioQuintilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117707.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1117707.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1117707.clusters.proteins.v11.5.txt",
		        "sequence_path": "1117707.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117707.protein.info.v11.5.txt",
		        "node_list_path": "1117707.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1117707.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpR1ns10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. R1NS10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpR1ns10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1306990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306990.protein.info.v11.5.txt",
		        "node_list_path": "1306990.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaRodasii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea rodasii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaRodasii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1076549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076549.protein.info.v11.5.txt",
		        "node_list_path": "1076549.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumGwf23610(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWF2_36_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumGwf23610", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797682.protein.info.v11.5.txt",
		        "node_list_path": "1797682.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaIntermediaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Candida] intermedia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaIntermediaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45354.clusters.proteins.v11.5.txt",
		        "sequence_path": "45354.protein.sequences.v11.5.fa",
		        "enrichment_path": "45354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45354.protein.info.v11.5.txt",
		        "node_list_path": "45354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusThiodiazotrophaEndolucinidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thiodiazotropha endolucinida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThiodiazotrophaEndolucinidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1655433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1655433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1655433.clusters.proteins.v11.5.txt",
		        "sequence_path": "1655433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655433.protein.info.v11.5.txt",
		        "node_list_path": "1655433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1655433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumThalassium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium thalassium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumThalassium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426701.protein.sequences.v11.5.fa",
		        "enrichment_path": "426701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426701.protein.info.v11.5.txt",
		        "node_list_path": "426701.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaSpQh12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sp. QH-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSpQh12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437876.protein.info.v11.5.txt",
		        "node_list_path": "1437876.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSaelicesensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora saelicesensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSaelicesensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "285676.protein.sequences.v11.5.fa",
		        "enrichment_path": "285676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285676.protein.info.v11.5.txt",
		        "node_list_path": "285676.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerinicoccusMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serinicoccus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerinicoccusMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123251.protein.info.v11.5.txt",
		        "node_list_path": "1123251.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpGw1013h11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. GW101-3H11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpGw1013h11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1813946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1813946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1813946.protein.info.v11.5.txt",
		        "node_list_path": "1813946.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClupeaHarengusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clupea harengus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClupeaHarengusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7950.clusters.proteins.v11.5.txt",
		        "sequence_path": "7950.protein.sequences.v11.5.fa",
		        "enrichment_path": "7950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7950.protein.info.v11.5.txt",
		        "node_list_path": "7950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusEhimensisA2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ehimensis A2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusEhimensisA2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1444314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444314.protein.info.v11.5.txt",
		        "node_list_path": "1444314.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpLpb0140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LPB0140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpLpb0140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1913578.protein.sequences.v11.5.fa",
		        "enrichment_path": "1913578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1913578.protein.info.v11.5.txt",
		        "node_list_path": "1913578.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmadillidiumVulgare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Armadillidium vulgare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmadillidiumVulgare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13347.protein.sequences.v11.5.fa",
		        "enrichment_path": "13347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13347.protein.info.v11.5.txt",
		        "node_list_path": "13347.protein.complete.v11.5.txt"
		    }
		]
    )()

def KlebsiellaSpRitPiDCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella sp. RIT-PI-d Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaSpRitPiDCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1681196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1681196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1681196.clusters.proteins.v11.5.txt",
		        "sequence_path": "1681196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1681196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1681196.protein.info.v11.5.txt",
		        "node_list_path": "1681196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1681196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenimonasSpScn70307(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas sp. SCN 70-307 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenimonasSpScn70307", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660089.protein.info.v11.5.txt",
		        "node_list_path": "1660089.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpQa3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. QA3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpQa3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "710111.protein.sequences.v11.5.fa",
		        "enrichment_path": "710111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710111.protein.info.v11.5.txt",
		        "node_list_path": "710111.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpOk281Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. OK281 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpOk281Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881067.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881067.protein.info.v11.5.txt",
		        "node_list_path": "1881067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrettanomycesBruxellensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brettanomyces bruxellensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrettanomycesBruxellensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5007.clusters.proteins.v11.5.txt",
		        "sequence_path": "5007.protein.sequences.v11.5.fa",
		        "enrichment_path": "5007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5007.protein.info.v11.5.txt",
		        "node_list_path": "5007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusConstellatusPharyngisSk1060(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus constellatus pharyngis SK1060 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusConstellatusPharyngisSk1060", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035184.protein.info.v11.5.txt",
		        "node_list_path": "1035184.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusFaecalisV583Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecalis V583 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusFaecalisV583Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "226185.clusters.info.v11.5.txt",
		        "cluster_tree_path": "226185.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "226185.clusters.proteins.v11.5.txt",
		        "sequence_path": "226185.protein.sequences.v11.5.fa",
		        "enrichment_path": "226185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226185.protein.info.v11.5.txt",
		        "node_list_path": "226185.cluster.nodes.v11.5.txt",
		        "edge_list_path": "226185.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivivaxRoseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxRoseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641238.protein.sequences.v11.5.fa",
		        "enrichment_path": "641238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641238.protein.info.v11.5.txt",
		        "node_list_path": "641238.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHimb083(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HIMB083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHimb083", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1096769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1096769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1096769.protein.info.v11.5.txt",
		        "node_list_path": "1096769.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaCyriacigeorgica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia cyriacigeorgica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaCyriacigeorgica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1127134.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127134.protein.info.v11.5.txt",
		        "node_list_path": "1127134.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1659195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1659195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1659195.clusters.proteins.v11.5.txt",
		        "sequence_path": "1659195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659195.protein.info.v11.5.txt",
		        "node_list_path": "1659195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1659195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasAxonopodisPhaseoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis phaseoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasAxonopodisPhaseoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "317013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "317013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "317013.clusters.proteins.v11.5.txt",
		        "sequence_path": "317013.protein.sequences.v11.5.fa",
		        "enrichment_path": "317013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317013.protein.info.v11.5.txt",
		        "node_list_path": "317013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "317013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StackebrandtiaNassauensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stackebrandtia nassauensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StackebrandtiaNassauensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "446470.protein.sequences.v11.5.fa",
		        "enrichment_path": "446470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446470.protein.info.v11.5.txt",
		        "node_list_path": "446470.protein.complete.v11.5.txt"
		    }
		]
    )()

def NematocidaDisplodereCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nematocida displodere Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NematocidaDisplodereCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805483.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805483.protein.info.v11.5.txt",
		        "node_list_path": "1805483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoflavonifractorCapillosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoflavonifractor capillosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoflavonifractorCapillosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411467.protein.sequences.v11.5.fa",
		        "enrichment_path": "411467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411467.protein.info.v11.5.txt",
		        "node_list_path": "411467.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaVulnerisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia vulneris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaVulnerisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1115515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1115515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1115515.clusters.proteins.v11.5.txt",
		        "sequence_path": "1115515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1115515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1115515.protein.info.v11.5.txt",
		        "node_list_path": "1115515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1115515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaRhizospheraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia rhizosphera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaRhizospheraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1108045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1108045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1108045.clusters.proteins.v11.5.txt",
		        "sequence_path": "1108045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1108045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1108045.protein.info.v11.5.txt",
		        "node_list_path": "1108045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1108045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeosporobacterSubterraneusDsm17957Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geosporobacter subterraneus DSM 17957 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeosporobacterSubterraneusDsm17957Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121919.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121919.protein.info.v11.5.txt",
		        "node_list_path": "1121919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumLsSob(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium LS_SOB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumLsSob", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671877.protein.info.v11.5.txt",
		        "node_list_path": "1671877.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumSpA49Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. A49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumSpA49Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945861.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945861.protein.info.v11.5.txt",
		        "node_list_path": "1945861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalanaerobiumHydrogeniformansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halanaerobium hydrogeniformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaerobiumHydrogeniformansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "656519.clusters.info.v11.5.txt",
		        "cluster_tree_path": "656519.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "656519.clusters.proteins.v11.5.txt",
		        "sequence_path": "656519.protein.sequences.v11.5.fa",
		        "enrichment_path": "656519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656519.protein.info.v11.5.txt",
		        "node_list_path": "656519.cluster.nodes.v11.5.txt",
		        "edge_list_path": "656519.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslR70337(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSL R7-0337 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslR70337", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926588.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926588.protein.info.v11.5.txt",
		        "node_list_path": "1926588.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4655Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4655 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4655Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977878.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977878.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977878.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977878.protein.info.v11.5.txt",
		        "node_list_path": "1977878.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977878.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusSp4681Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. 4681 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSp4681Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1525715.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1525715.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1525715.clusters.proteins.v11.5.txt",
		        "sequence_path": "1525715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1525715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1525715.protein.info.v11.5.txt",
		        "node_list_path": "1525715.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1525715.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxParadoxus110b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax paradoxus 110B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxParadoxus110b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157708.protein.info.v11.5.txt",
		        "node_list_path": "1157708.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFloridensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas floridensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFloridensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1958950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1958950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1958950.protein.info.v11.5.txt",
		        "node_list_path": "1958950.protein.complete.v11.5.txt"
		    }
		]
    )()

def RodentibacterGenomosp2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter genomosp. 2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterGenomosp2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1908266.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908266.protein.info.v11.5.txt",
		        "node_list_path": "1908266.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_34_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618477.protein.info.v11.5.txt",
		        "node_list_path": "1618477.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpD16r12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. D16R12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpD16r12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855662.protein.info.v11.5.txt",
		        "node_list_path": "1855662.protein.complete.v11.5.txt"
		    }
		]
    )()

def OreochromisAureus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oreochromis aureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OreochromisAureus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47969.protein.sequences.v11.5.fa",
		        "enrichment_path": "47969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47969.protein.info.v11.5.txt",
		        "node_list_path": "47969.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusBrockianusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus brockianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusBrockianusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56956.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56956.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56956.clusters.proteins.v11.5.txt",
		        "sequence_path": "56956.protein.sequences.v11.5.fa",
		        "enrichment_path": "56956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56956.protein.info.v11.5.txt",
		        "node_list_path": "56956.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56956.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacteriumAutotrophicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterium autotrophicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteriumAutotrophicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "177437.clusters.info.v11.5.txt",
		        "cluster_tree_path": "177437.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "177437.clusters.proteins.v11.5.txt",
		        "sequence_path": "177437.protein.sequences.v11.5.fa",
		        "enrichment_path": "177437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "177437.protein.info.v11.5.txt",
		        "node_list_path": "177437.cluster.nodes.v11.5.txt",
		        "edge_list_path": "177437.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusMannitolivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus mannitolivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusMannitolivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120965.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120965.protein.info.v11.5.txt",
		        "node_list_path": "1120965.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacteraceaeBacteriumOtszA272(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacteraceae bacterium OTSz_A_272 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacteraceaeBacteriumOtszA272", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1759059.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759059.protein.info.v11.5.txt",
		        "node_list_path": "1759059.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraArcticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraArcticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123514.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123514.protein.info.v11.5.txt",
		        "node_list_path": "1123514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasArcis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas arcis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasArcis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "416873.protein.sequences.v11.5.fa",
		        "enrichment_path": "416873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416873.protein.info.v11.5.txt",
		        "node_list_path": "416873.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSmegmatisMc2155Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium smegmatis MC2155 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSmegmatisMc2155Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246196.clusters.proteins.v11.5.txt",
		        "sequence_path": "246196.protein.sequences.v11.5.fa",
		        "enrichment_path": "246196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246196.protein.info.v11.5.txt",
		        "node_list_path": "246196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusFelisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Haemophilus] felis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusFelisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "123822.clusters.info.v11.5.txt",
		        "cluster_tree_path": "123822.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "123822.clusters.proteins.v11.5.txt",
		        "sequence_path": "123822.protein.sequences.v11.5.fa",
		        "enrichment_path": "123822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "123822.protein.info.v11.5.txt",
		        "node_list_path": "123822.cluster.nodes.v11.5.txt",
		        "edge_list_path": "123822.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterDonghicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter donghicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterDonghicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1300350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300350.protein.info.v11.5.txt",
		        "node_list_path": "1300350.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaChokoriensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora chokoriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaChokoriensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "356851.protein.sequences.v11.5.fa",
		        "enrichment_path": "356851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "356851.protein.info.v11.5.txt",
		        "node_list_path": "356851.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanohalophilusMahiiDsm5219Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus mahii DSM 5219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanohalophilusMahiiDsm5219Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "547558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "547558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "547558.clusters.proteins.v11.5.txt",
		        "sequence_path": "547558.protein.sequences.v11.5.fa",
		        "enrichment_path": "547558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547558.protein.info.v11.5.txt",
		        "node_list_path": "547558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "547558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiaBacteriumTcs52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiaBacteriumTcs52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1781243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1781243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1781243.protein.info.v11.5.txt",
		        "node_list_path": "1781243.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5123(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5123", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463856.protein.info.v11.5.txt",
		        "node_list_path": "1463856.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChishuiellaChangwenliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chishuiella changwenlii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChishuiellaChangwenliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434701.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434701.protein.info.v11.5.txt",
		        "node_list_path": "1434701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAminophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio aminophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAminophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121440.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121440.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121440.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121440.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121440.protein.info.v11.5.txt",
		        "node_list_path": "1121440.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121440.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudarcicellaHirudinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudarcicella hirudinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudarcicellaHirudinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1079859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1079859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1079859.protein.info.v11.5.txt",
		        "node_list_path": "1079859.protein.complete.v11.5.txt"
		    }
		]
    )()

def LagierellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lagierella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LagierellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1689303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1689303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1689303.clusters.proteins.v11.5.txt",
		        "sequence_path": "1689303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1689303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1689303.protein.info.v11.5.txt",
		        "node_list_path": "1689303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1689303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKryptoniumThompsoniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kryptonium thompsoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKryptoniumThompsoniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1633631.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1633631.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1633631.clusters.proteins.v11.5.txt",
		        "sequence_path": "1633631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1633631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1633631.protein.info.v11.5.txt",
		        "node_list_path": "1633631.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1633631.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalibacteriumQingdaonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salibacterium qingdaonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalibacteriumQingdaonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266892.clusters.proteins.v11.5.txt",
		        "sequence_path": "266892.protein.sequences.v11.5.fa",
		        "enrichment_path": "266892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266892.protein.info.v11.5.txt",
		        "node_list_path": "266892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterJohnsoniiXbb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter johnsonii XBB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterJohnsoniiXbb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1242245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1242245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1242245.clusters.proteins.v11.5.txt",
		        "sequence_path": "1242245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1242245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1242245.protein.info.v11.5.txt",
		        "node_list_path": "1242245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1242245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpKw12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. KW12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpKw12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499685.protein.info.v11.5.txt",
		        "node_list_path": "1499685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaliobacillusSpPm2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraliobacillus sp. PM-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaliobacillusSpPm2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1462524.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462524.protein.info.v11.5.txt",
		        "node_list_path": "1462524.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuberMelanosporumMel28Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tuber melanosporum Mel28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuberMelanosporumMel28Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "656061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "656061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "656061.clusters.proteins.v11.5.txt",
		        "sequence_path": "656061.protein.sequences.v11.5.fa",
		        "enrichment_path": "656061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656061.protein.info.v11.5.txt",
		        "node_list_path": "656061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "656061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiaBacteriumScgcAaa298D23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium SCGC AAA298-D23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiaBacteriumScgcAaa298D23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "939857.protein.sequences.v11.5.fa",
		        "enrichment_path": "939857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939857.protein.info.v11.5.txt",
		        "node_list_path": "939857.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSimiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas simiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSimiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321846.protein.sequences.v11.5.fa",
		        "enrichment_path": "321846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321846.protein.info.v11.5.txt",
		        "node_list_path": "321846.protein.complete.v11.5.txt"
		    }
		]
    )()

def AliagarivoransMarinusDsm23064(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aliagarivorans marinus DSM 23064 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliagarivoransMarinusDsm23064", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120969.protein.info.v11.5.txt",
		        "node_list_path": "1120969.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag349(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag349", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262797.protein.info.v11.5.txt",
		        "node_list_path": "1262797.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloteneraSpG11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera sp. G11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraSpG11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1506585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1506585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1506585.clusters.proteins.v11.5.txt",
		        "sequence_path": "1506585.protein.sequences.v11.5.fa",
		        "enrichment_path": "1506585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1506585.protein.info.v11.5.txt",
		        "node_list_path": "1506585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1506585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeotogaPetraea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geotoga petraea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeotogaPetraea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28234.protein.sequences.v11.5.fa",
		        "enrichment_path": "28234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28234.protein.info.v11.5.txt",
		        "node_list_path": "28234.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwc14311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWC1_43_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwc14311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618520.protein.info.v11.5.txt",
		        "node_list_path": "1618520.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesGoldsteiniiDsm19448Wal12034(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides goldsteinii DSM 19448 WAL 12034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesGoldsteiniiDsm19448Wal12034", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "927665.protein.sequences.v11.5.fa",
		        "enrichment_path": "927665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927665.protein.info.v11.5.txt",
		        "node_list_path": "927665.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfonatronumLacustreDsm10312(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronum lacustre DSM 10312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronumLacustreDsm10312", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935942.protein.sequences.v11.5.fa",
		        "enrichment_path": "935942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935942.protein.info.v11.5.txt",
		        "node_list_path": "935942.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirosomaSpitsbergense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma spitsbergense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaSpitsbergense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123278.protein.info.v11.5.txt",
		        "node_list_path": "1123278.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenobaculumSpHoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenobaculum sp. HO Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenobaculumSpHoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "547144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "547144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "547144.clusters.proteins.v11.5.txt",
		        "sequence_path": "547144.protein.sequences.v11.5.fa",
		        "enrichment_path": "547144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547144.protein.info.v11.5.txt",
		        "node_list_path": "547144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "547144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ImmundisolibacterCernigliae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Immundisolibacter cernigliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ImmundisolibacterCernigliae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1810504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1810504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1810504.protein.info.v11.5.txt",
		        "node_list_path": "1810504.protein.complete.v11.5.txt"
		    }
		]
    )()

def SordariaMacrosporaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sordaria macrospora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SordariaMacrosporaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5147.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5147.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5147.clusters.proteins.v11.5.txt",
		        "sequence_path": "5147.protein.sequences.v11.5.fa",
		        "enrichment_path": "5147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5147.protein.info.v11.5.txt",
		        "node_list_path": "5147.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5147.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BeauveriaBassianaArsef2860(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Beauveria bassiana ARSEF 2860 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeauveriaBassianaArsef2860", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655819.protein.sequences.v11.5.fa",
		        "enrichment_path": "655819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655819.protein.info.v11.5.txt",
		        "node_list_path": "655819.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpOrs3428(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3428 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpOrs3428", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "540997.protein.sequences.v11.5.fa",
		        "enrichment_path": "540997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "540997.protein.info.v11.5.txt",
		        "node_list_path": "540997.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusSpB2m1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. B2M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusSpB2m1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1490052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1490052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1490052.protein.info.v11.5.txt",
		        "node_list_path": "1490052.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenopusTropicalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenopus tropicalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenopusTropicalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8364.protein.sequences.v11.5.fa",
		        "enrichment_path": "8364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8364.protein.info.v11.5.txt",
		        "node_list_path": "8364.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesNodosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces nodosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesNodosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40318.clusters.proteins.v11.5.txt",
		        "sequence_path": "40318.protein.sequences.v11.5.fa",
		        "enrichment_path": "40318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40318.protein.info.v11.5.txt",
		        "node_list_path": "40318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaBaroniaeDsm16972Jcm13447Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella baroniae DSM 16972 JCM 13447 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBaroniaeDsm16972Jcm13447Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122980.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122980.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122980.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122980.protein.info.v11.5.txt",
		        "node_list_path": "1122980.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122980.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusBvHnlc2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus bv. HNLC2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusBvHnlc2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041939.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041939.protein.info.v11.5.txt",
		        "node_list_path": "1041939.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpTb23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. TB23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpTb23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "494419.protein.sequences.v11.5.fa",
		        "enrichment_path": "494419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "494419.protein.info.v11.5.txt",
		        "node_list_path": "494419.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfurivibrioAlkaliphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurivibrio alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurivibrioAlkaliphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "589865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "589865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "589865.clusters.proteins.v11.5.txt",
		        "sequence_path": "589865.protein.sequences.v11.5.fa",
		        "enrichment_path": "589865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "589865.protein.info.v11.5.txt",
		        "node_list_path": "589865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "589865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsphigho201Full4110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_01_FULL_41_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho201Full4110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802500.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802500.protein.info.v11.5.txt",
		        "node_list_path": "1802500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MonosporascusSpMc138bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. MC13-8B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSpMc138bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2211646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2211646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2211646.clusters.proteins.v11.5.txt",
		        "sequence_path": "2211646.protein.sequences.v11.5.fa",
		        "enrichment_path": "2211646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2211646.protein.info.v11.5.txt",
		        "node_list_path": "2211646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2211646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SusScrofa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sus scrofa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SusScrofa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9823.protein.sequences.v11.5.fa",
		        "enrichment_path": "9823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9823.protein.info.v11.5.txt",
		        "node_list_path": "9823.protein.complete.v11.5.txt"
		    }
		]
    )()

def TaylorellaAsinigenitalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Taylorella asinigenitalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TaylorellaAsinigenitalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1008459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1008459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1008459.protein.info.v11.5.txt",
		        "node_list_path": "1008459.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytophthoraSojae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora sojae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraSojae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67593.protein.sequences.v11.5.fa",
		        "enrichment_path": "67593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67593.protein.info.v11.5.txt",
		        "node_list_path": "67593.protein.complete.v11.5.txt"
		    }
		]
    )()

def TardiphagaRobiniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tardiphaga robiniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TardiphagaRobiniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "943830.clusters.info.v11.5.txt",
		        "cluster_tree_path": "943830.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "943830.clusters.proteins.v11.5.txt",
		        "sequence_path": "943830.protein.sequences.v11.5.fa",
		        "enrichment_path": "943830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "943830.protein.info.v11.5.txt",
		        "node_list_path": "943830.cluster.nodes.v11.5.txt",
		        "edge_list_path": "943830.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarivitaGeojedonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marivita geojedonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivitaGeojedonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123756.protein.info.v11.5.txt",
		        "node_list_path": "1123756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumChauvoeiJf4335(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium chauvoei JF4335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumChauvoeiJf4335", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1351755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1351755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1351755.protein.info.v11.5.txt",
		        "node_list_path": "1351755.protein.complete.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterAtlanticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterAtlanticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267766.protein.info.v11.5.txt",
		        "node_list_path": "1267766.protein.complete.v11.5.txt"
		    }
		]
    )()

def PontibacterRoseusDsm17521Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter roseus DSM 17521 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterRoseusDsm17521Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122967.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122967.protein.info.v11.5.txt",
		        "node_list_path": "1122967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UrsusArctosHorribilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ursus arctos horribilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UrsusArctosHorribilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "116960.protein.sequences.v11.5.fa",
		        "enrichment_path": "116960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "116960.protein.info.v11.5.txt",
		        "node_list_path": "116960.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrotetrasporaGlauca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microtetraspora glauca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrotetrasporaGlauca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1996.protein.info.v11.5.txt",
		        "node_list_path": "1996.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpCf122(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF122 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpCf122", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144312.protein.info.v11.5.txt",
		        "node_list_path": "1144312.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full4317b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_43_17b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full4317b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802216.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802216.protein.info.v11.5.txt",
		        "node_list_path": "1802216.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumFructicolaNaraGc5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum fructicola Nara gc5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumFructicolaNaraGc5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1213859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1213859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1213859.protein.info.v11.5.txt",
		        "node_list_path": "1213859.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpH2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. H2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpH2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658612.protein.sequences.v11.5.fa",
		        "enrichment_path": "658612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658612.protein.info.v11.5.txt",
		        "node_list_path": "658612.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpSynace01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. SynAce01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpSynace01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1916956.protein.sequences.v11.5.fa",
		        "enrichment_path": "1916956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1916956.protein.info.v11.5.txt",
		        "node_list_path": "1916956.protein.complete.v11.5.txt"
		    }
		]
    )()

def AllomycesMacrogynusAtcc38327Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Allomyces macrogynus ATCC 38327 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllomycesMacrogynusAtcc38327Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "578462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "578462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "578462.clusters.proteins.v11.5.txt",
		        "sequence_path": "578462.protein.sequences.v11.5.fa",
		        "enrichment_path": "578462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578462.protein.info.v11.5.txt",
		        "node_list_path": "578462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "578462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumMarseilleP2935Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium Marseille-P2935 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumMarseilleP2935Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852383.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852383.protein.info.v11.5.txt",
		        "node_list_path": "1852383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrobacterSedlakiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sedlakii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterSedlakiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218086.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218086.protein.info.v11.5.txt",
		        "node_list_path": "1218086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BotrytisCinerea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Botrytis cinerea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotrytisCinerea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40559.protein.sequences.v11.5.fa",
		        "enrichment_path": "40559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40559.protein.info.v11.5.txt",
		        "node_list_path": "40559.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuberibacillusSpMarseilleP3662Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tuberibacillus sp. Marseille-P3662 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuberibacillusSpMarseilleP3662Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1965358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1965358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1965358.clusters.proteins.v11.5.txt",
		        "sequence_path": "1965358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1965358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1965358.protein.info.v11.5.txt",
		        "node_list_path": "1965358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1965358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMicrarchaeotaArchaeonCg1026051Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_60_51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1026051Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805252.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805252.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805252.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805252.protein.info.v11.5.txt",
		        "node_list_path": "1805252.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805252.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumPseudosasicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium pseudosasicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumPseudosasicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582667.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582667.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582667.clusters.proteins.v11.5.txt",
		        "sequence_path": "582667.protein.sequences.v11.5.fa",
		        "enrichment_path": "582667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582667.protein.info.v11.5.txt",
		        "node_list_path": "582667.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582667.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag452(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:452 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag452", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262810.protein.info.v11.5.txt",
		        "node_list_path": "1262810.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674852.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674852.protein.info.v11.5.txt",
		        "node_list_path": "1674852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnothrixSpP13c2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnothrix sp. P13C2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnothrixSpP13c2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1880902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1880902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1880902.clusters.proteins.v11.5.txt",
		        "sequence_path": "1880902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1880902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1880902.protein.info.v11.5.txt",
		        "node_list_path": "1880902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1880902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AedesAegyptiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aedes aegypti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AedesAegyptiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7159.clusters.proteins.v11.5.txt",
		        "sequence_path": "7159.protein.sequences.v11.5.fa",
		        "enrichment_path": "7159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7159.protein.info.v11.5.txt",
		        "node_list_path": "7159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerolineaceaeBacterium457278(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium 4572_78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaceaeBacterium457278", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1972460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1972460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1972460.protein.info.v11.5.txt",
		        "node_list_path": "1972460.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesCulicifacies(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles culicifacies graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesCulicifacies", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "139723.protein.sequences.v11.5.fa",
		        "enrichment_path": "139723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "139723.protein.info.v11.5.txt",
		        "node_list_path": "139723.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCaatingaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces caatingaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCaatingaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1678637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1678637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1678637.clusters.proteins.v11.5.txt",
		        "sequence_path": "1678637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678637.protein.info.v11.5.txt",
		        "node_list_path": "1678637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1678637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusOzensisDsm23829Jcm17196(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ozensis DSM 23829 JCM 17196 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOzensisDsm23829Jcm17196", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423781.protein.info.v11.5.txt",
		        "node_list_path": "1423781.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusChromogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus chromogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusChromogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220551.protein.info.v11.5.txt",
		        "node_list_path": "1220551.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyroidesOdoratusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myroides odoratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyroidesOdoratusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "929704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "929704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "929704.clusters.proteins.v11.5.txt",
		        "sequence_path": "929704.protein.sequences.v11.5.fa",
		        "enrichment_path": "929704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929704.protein.info.v11.5.txt",
		        "node_list_path": "929704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "929704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusAsiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus asini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusAsiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158606.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158606.protein.info.v11.5.txt",
		        "node_list_path": "1158606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasTaeanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas taeanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasTaeanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1395571.protein.sequences.v11.5.fa",
		        "enrichment_path": "1395571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1395571.protein.info.v11.5.txt",
		        "node_list_path": "1395571.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacillusKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacillus koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacillusKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1069220.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1069220.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1069220.clusters.proteins.v11.5.txt",
		        "sequence_path": "1069220.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069220.protein.info.v11.5.txt",
		        "node_list_path": "1069220.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1069220.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusFlavefaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusFlavefaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265.protein.info.v11.5.txt",
		        "node_list_path": "1265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanohalobiumEvestigatumZ7303(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanohalobium evestigatum Z-7303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanohalobiumEvestigatumZ7303", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644295.protein.sequences.v11.5.fa",
		        "enrichment_path": "644295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644295.protein.info.v11.5.txt",
		        "node_list_path": "644295.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumGraminearumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium graminearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumGraminearumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5518.clusters.proteins.v11.5.txt",
		        "sequence_path": "5518.protein.sequences.v11.5.fa",
		        "enrichment_path": "5518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5518.protein.info.v11.5.txt",
		        "node_list_path": "5518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpEpa45(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. EPa45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpEpa45", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1545728.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545728.protein.info.v11.5.txt",
		        "node_list_path": "1545728.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarivitaCryptomonadisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marivita cryptomonadis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivitaCryptomonadisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "505252.clusters.info.v11.5.txt",
		        "cluster_tree_path": "505252.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "505252.clusters.proteins.v11.5.txt",
		        "sequence_path": "505252.protein.sequences.v11.5.fa",
		        "enrichment_path": "505252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "505252.protein.info.v11.5.txt",
		        "node_list_path": "505252.cluster.nodes.v11.5.txt",
		        "edge_list_path": "505252.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpLfm046Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. LFM046 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpLfm046Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1608357.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1608357.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1608357.clusters.proteins.v11.5.txt",
		        "sequence_path": "1608357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608357.protein.info.v11.5.txt",
		        "node_list_path": "1608357.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1608357.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HoldemanellaBiformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Holdemanella biformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoldemanellaBiformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "518637.protein.sequences.v11.5.fa",
		        "enrichment_path": "518637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "518637.protein.info.v11.5.txt",
		        "node_list_path": "518637.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusAs9601(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus AS9601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusAs9601", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "146891.protein.sequences.v11.5.fa",
		        "enrichment_path": "146891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146891.protein.info.v11.5.txt",
		        "node_list_path": "146891.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumAestuarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumAestuarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1821621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1821621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1821621.protein.info.v11.5.txt",
		        "node_list_path": "1821621.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonJgiOtu1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon JGI OTU-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonJgiOtu1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1378080.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1378080.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1378080.clusters.proteins.v11.5.txt",
		        "sequence_path": "1378080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1378080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1378080.protein.info.v11.5.txt",
		        "node_list_path": "1378080.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1378080.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat22090Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-22090 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat22090Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1581038.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1581038.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1581038.clusters.proteins.v11.5.txt",
		        "sequence_path": "1581038.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581038.protein.info.v11.5.txt",
		        "node_list_path": "1581038.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1581038.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EggerthellaSpCag298Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eggerthella sp. CAG:298 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthellaSpCag298Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262876.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262876.protein.info.v11.5.txt",
		        "node_list_path": "1262876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CriblamydiaSequanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Criblamydia sequanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CriblamydiaSequanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437425.protein.info.v11.5.txt",
		        "node_list_path": "1437425.protein.complete.v11.5.txt"
		    }
		]
    )()

def InquilinusLimosusDsm16000(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Inquilinus limosus DSM 16000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "InquilinusLimosusDsm16000", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122125.protein.info.v11.5.txt",
		        "node_list_path": "1122125.protein.complete.v11.5.txt"
		    }
		]
    )()

def SetosphaeriaTurcicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Setosphaeria turcica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SetosphaeriaTurcicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93612.clusters.proteins.v11.5.txt",
		        "sequence_path": "93612.protein.sequences.v11.5.fa",
		        "enrichment_path": "93612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93612.protein.info.v11.5.txt",
		        "node_list_path": "93612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumPeriodonticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium periodonticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumPeriodonticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546275.clusters.proteins.v11.5.txt",
		        "sequence_path": "546275.protein.sequences.v11.5.fa",
		        "enrichment_path": "546275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546275.protein.info.v11.5.txt",
		        "node_list_path": "546275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AstatotilapiaCalliptera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Astatotilapia calliptera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AstatotilapiaCalliptera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8154.protein.sequences.v11.5.fa",
		        "enrichment_path": "8154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8154.protein.info.v11.5.txt",
		        "node_list_path": "8154.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaBongoriN26808(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella bongori N26808 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaBongoriN26808", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1197719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197719.protein.info.v11.5.txt",
		        "node_list_path": "1197719.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlautiaStaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plautia stali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlautiaStaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "891974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "891974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "891974.clusters.proteins.v11.5.txt",
		        "sequence_path": "891974.protein.sequences.v11.5.fa",
		        "enrichment_path": "891974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "891974.protein.info.v11.5.txt",
		        "node_list_path": "891974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "891974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraMultiparaAtcc19207Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospira multipara ATCC19207 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraMultiparaAtcc19207Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1282887.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1282887.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1282887.clusters.proteins.v11.5.txt",
		        "sequence_path": "1282887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282887.protein.info.v11.5.txt",
		        "node_list_path": "1282887.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1282887.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KushneriaSpYcwa18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kushneria sp. YCWA18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KushneriaSpYcwa18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "657387.protein.sequences.v11.5.fa",
		        "enrichment_path": "657387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657387.protein.info.v11.5.txt",
		        "node_list_path": "657387.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp12747566Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1274756.6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp12747566Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834076.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834076.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834076.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834076.protein.info.v11.5.txt",
		        "node_list_path": "1834076.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834076.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusBoritoleransDsm17298Jcm18970Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus boritolerans DSM 17298 JCM 18970 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusBoritoleransDsm17298Jcm18970Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120964.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120964.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120964.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120964.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120964.protein.info.v11.5.txt",
		        "node_list_path": "1120964.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120964.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full349Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_34_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full349Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802206.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802206.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802206.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802206.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802206.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802206.protein.info.v11.5.txt",
		        "node_list_path": "1802206.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802206.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasIndica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasIndica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "941907.protein.sequences.v11.5.fa",
		        "enrichment_path": "941907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "941907.protein.info.v11.5.txt",
		        "node_list_path": "941907.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoaLoaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loa loa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoaLoaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7209.clusters.proteins.v11.5.txt",
		        "sequence_path": "7209.protein.sequences.v11.5.fa",
		        "enrichment_path": "7209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7209.protein.info.v11.5.txt",
		        "node_list_path": "7209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3913Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_39_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3913Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797796.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797796.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797796.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797796.protein.info.v11.5.txt",
		        "node_list_path": "1797796.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797796.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgaricusBisporusVarBurnettiiJb137S8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agaricus bisporus var. burnettii JB137-S8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgaricusBisporusVarBurnettiiJb137S8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "597362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "597362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "597362.clusters.proteins.v11.5.txt",
		        "sequence_path": "597362.protein.sequences.v11.5.fa",
		        "enrichment_path": "597362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "597362.protein.info.v11.5.txt",
		        "node_list_path": "597362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "597362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EutypaLataUcrel1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eutypa lata UCREL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EutypaLataUcrel1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1287681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1287681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1287681.clusters.proteins.v11.5.txt",
		        "sequence_path": "1287681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287681.protein.info.v11.5.txt",
		        "node_list_path": "1287681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1287681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlcaligenesFaecalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcaligenes faecalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcaligenesFaecalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "511.clusters.info.v11.5.txt",
		        "cluster_tree_path": "511.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "511.clusters.proteins.v11.5.txt",
		        "sequence_path": "511.protein.sequences.v11.5.fa",
		        "enrichment_path": "511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511.protein.info.v11.5.txt",
		        "node_list_path": "511.cluster.nodes.v11.5.txt",
		        "edge_list_path": "511.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalothiobacillusSpXi15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halothiobacillus sp. XI15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalothiobacillusSpXi15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1766620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1766620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1766620.clusters.proteins.v11.5.txt",
		        "sequence_path": "1766620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1766620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1766620.protein.info.v11.5.txt",
		        "node_list_path": "1766620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1766620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GramellaEchinicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gramella echinicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaEchinicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121931.protein.info.v11.5.txt",
		        "node_list_path": "1121931.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioFructosivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio fructosivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioFructosivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596151.protein.sequences.v11.5.fa",
		        "enrichment_path": "596151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596151.protein.info.v11.5.txt",
		        "node_list_path": "596151.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioTasmaniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio tasmaniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioTasmaniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575788.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575788.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575788.clusters.proteins.v11.5.txt",
		        "sequence_path": "575788.protein.sequences.v11.5.fa",
		        "enrichment_path": "575788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575788.protein.info.v11.5.txt",
		        "node_list_path": "575788.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575788.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifoxyc2Full3612(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYC2_FULL_36_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyc2Full3612", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798002.protein.info.v11.5.txt",
		        "node_list_path": "1798002.protein.complete.v11.5.txt"
		    }
		]
    )()

def BabesiaBigeminaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Babesia bigemina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BabesiaBigeminaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5866.clusters.proteins.v11.5.txt",
		        "sequence_path": "5866.protein.sequences.v11.5.fa",
		        "enrichment_path": "5866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5866.protein.info.v11.5.txt",
		        "node_list_path": "5866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ApteryxRowiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Apteryx rowi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApteryxRowiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "308060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "308060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "308060.clusters.proteins.v11.5.txt",
		        "sequence_path": "308060.protein.sequences.v11.5.fa",
		        "enrichment_path": "308060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "308060.protein.info.v11.5.txt",
		        "node_list_path": "308060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "308060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYonathbacteriaBacteriumRifcsplowo201Full4733b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPLOWO2_01_FULL_47_33b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsplowo201Full4733b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802727.protein.info.v11.5.txt",
		        "node_list_path": "1802727.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSalanitronis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides salanitronis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSalanitronis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "667015.protein.sequences.v11.5.fa",
		        "enrichment_path": "667015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667015.protein.info.v11.5.txt",
		        "node_list_path": "667015.protein.complete.v11.5.txt"
		    }
		]
    )()

def ModestobacterMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Modestobacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ModestobacterMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "477641.clusters.info.v11.5.txt",
		        "cluster_tree_path": "477641.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "477641.clusters.proteins.v11.5.txt",
		        "sequence_path": "477641.protein.sequences.v11.5.fa",
		        "enrichment_path": "477641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477641.protein.info.v11.5.txt",
		        "node_list_path": "477641.cluster.nodes.v11.5.txt",
		        "edge_list_path": "477641.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfitobacteriumChlororespiransDsm11544Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium chlororespirans DSM 11544 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitobacteriumChlororespiransDsm11544Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121395.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121395.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121395.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121395.protein.info.v11.5.txt",
		        "node_list_path": "1121395.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121395.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollinsellaSpMs5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collinsella sp. MS5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaSpMs5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499681.protein.info.v11.5.txt",
		        "node_list_path": "1499681.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCollinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces collinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCollinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1214242.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214242.protein.info.v11.5.txt",
		        "node_list_path": "1214242.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusAcidipiscis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidipiscis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAcidipiscis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "89059.protein.sequences.v11.5.fa",
		        "enrichment_path": "89059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89059.protein.info.v11.5.txt",
		        "node_list_path": "89059.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusInfluenzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus influenzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusInfluenzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "71421.protein.sequences.v11.5.fa",
		        "enrichment_path": "71421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "71421.protein.info.v11.5.txt",
		        "node_list_path": "71421.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag217(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag217", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262779.protein.info.v11.5.txt",
		        "node_list_path": "1262779.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag1000(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag1000", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262768.protein.info.v11.5.txt",
		        "node_list_path": "1262768.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraRubrobruneaNbrc15275(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura rubrobrunea NBRC 15275 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraRubrobruneaNbrc15275", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220567.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220567.protein.info.v11.5.txt",
		        "node_list_path": "1220567.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaSpWriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia sp. wRi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaSpWriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66084.clusters.proteins.v11.5.txt",
		        "sequence_path": "66084.protein.sequences.v11.5.fa",
		        "enrichment_path": "66084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66084.protein.info.v11.5.txt",
		        "node_list_path": "66084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterHeparinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter heparinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterHeparinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "485917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "485917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "485917.clusters.proteins.v11.5.txt",
		        "sequence_path": "485917.protein.sequences.v11.5.fa",
		        "enrichment_path": "485917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485917.protein.info.v11.5.txt",
		        "node_list_path": "485917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "485917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronorubrumTexcoconense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronorubrum texcoconense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronorubrumTexcoconense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095776.protein.info.v11.5.txt",
		        "node_list_path": "1095776.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumRifoxyd1Full3611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFOXYD1_FULL_36_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifoxyd1Full3611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798656.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798656.protein.info.v11.5.txt",
		        "node_list_path": "1798656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRiesiaPthiripubisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia pthiripubis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRiesiaPthiripubisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "428412.clusters.info.v11.5.txt",
		        "cluster_tree_path": "428412.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "428412.clusters.proteins.v11.5.txt",
		        "sequence_path": "428412.protein.sequences.v11.5.fa",
		        "enrichment_path": "428412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428412.protein.info.v11.5.txt",
		        "node_list_path": "428412.cluster.nodes.v11.5.txt",
		        "edge_list_path": "428412.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full5121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_51_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full5121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802773.protein.info.v11.5.txt",
		        "node_list_path": "1802773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpYe71Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. YE71 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpYe71Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "244362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "244362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "244362.clusters.proteins.v11.5.txt",
		        "sequence_path": "244362.protein.sequences.v11.5.fa",
		        "enrichment_path": "244362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244362.protein.info.v11.5.txt",
		        "node_list_path": "244362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "244362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCf335Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CF335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCf335Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500279.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500279.protein.info.v11.5.txt",
		        "node_list_path": "1500279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphaerobacterThermophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphaerobacter thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerobacterThermophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "479434.protein.sequences.v11.5.fa",
		        "enrichment_path": "479434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479434.protein.info.v11.5.txt",
		        "node_list_path": "479434.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonadaceaeBacteriumUkl131(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonadaceae bacterium UKL13-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonadaceaeBacteriumUkl131", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1690484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690484.protein.info.v11.5.txt",
		        "node_list_path": "1690484.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusLentulus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus lentulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusLentulus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "293939.protein.sequences.v11.5.fa",
		        "enrichment_path": "293939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "293939.protein.info.v11.5.txt",
		        "node_list_path": "293939.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrilusPlanipennis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrilus planipennis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrilusPlanipennis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "224129.protein.sequences.v11.5.fa",
		        "enrichment_path": "224129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224129.protein.info.v11.5.txt",
		        "node_list_path": "224129.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpMilost2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. MilosT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpMilost2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "90814.protein.sequences.v11.5.fa",
		        "enrichment_path": "90814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90814.protein.info.v11.5.txt",
		        "node_list_path": "90814.protein.complete.v11.5.txt"
		    }
		]
    )()

def CupriavidusOxalaticusNbrc13593(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus oxalaticus NBRC 13593 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusOxalaticusNbrc13593", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349762.protein.info.v11.5.txt",
		        "node_list_path": "1349762.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobacterSpRoot1221Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root1221 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobacterSpRoot1221Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736433.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736433.protein.info.v11.5.txt",
		        "node_list_path": "1736433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DiplosphaeraColitermitum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Diplosphaera colitermitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiplosphaeraColitermitum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "278957.protein.sequences.v11.5.fa",
		        "enrichment_path": "278957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278957.protein.info.v11.5.txt",
		        "node_list_path": "278957.protein.complete.v11.5.txt"
		    }
		]
    )()

def CrocinitomixCatalasitica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crocinitomix catalasitica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrocinitomixCatalasitica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408433.protein.info.v11.5.txt",
		        "node_list_path": "1408433.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSpScn65179(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. SCN 65-179 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSpScn65179", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660144.protein.info.v11.5.txt",
		        "node_list_path": "1660144.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinicellaSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinicella sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinicellaSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1792834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792834.protein.info.v11.5.txt",
		        "node_list_path": "1792834.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusPittmaniaeHk85(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus pittmaniae HK 85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusPittmaniaeHk85", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035188.protein.info.v11.5.txt",
		        "node_list_path": "1035188.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterGangjinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter gangjinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterGangjinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "502682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "502682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "502682.clusters.proteins.v11.5.txt",
		        "sequence_path": "502682.protein.sequences.v11.5.fa",
		        "enrichment_path": "502682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502682.protein.info.v11.5.txt",
		        "node_list_path": "502682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "502682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaEquifetaleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma equifetale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaEquifetaleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408415.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408415.protein.info.v11.5.txt",
		        "node_list_path": "1408415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraLicerasiaeStrMmd4847(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira licerasiae str. MMD4847 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraLicerasiaeStrMmd4847", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1049971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1049971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1049971.protein.info.v11.5.txt",
		        "node_list_path": "1049971.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaMegateriumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina megaterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaMegateriumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1443666.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1443666.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1443666.clusters.proteins.v11.5.txt",
		        "sequence_path": "1443666.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443666.protein.info.v11.5.txt",
		        "node_list_path": "1443666.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1443666.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LevilineaSaccharolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Levilinea saccharolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LevilineaSaccharolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "229921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "229921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "229921.clusters.proteins.v11.5.txt",
		        "sequence_path": "229921.protein.sequences.v11.5.fa",
		        "enrichment_path": "229921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229921.protein.info.v11.5.txt",
		        "node_list_path": "229921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "229921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumCiceriCa181Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium ciceri ca181 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumCiceriCa181Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "682633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "682633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "682633.clusters.proteins.v11.5.txt",
		        "sequence_path": "682633.protein.sequences.v11.5.fa",
		        "enrichment_path": "682633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "682633.protein.info.v11.5.txt",
		        "node_list_path": "682633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "682633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalostagnicolaLarseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halostagnicola larsenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalostagnicolaLarseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "797299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "797299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "797299.clusters.proteins.v11.5.txt",
		        "sequence_path": "797299.protein.sequences.v11.5.fa",
		        "enrichment_path": "797299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797299.protein.info.v11.5.txt",
		        "node_list_path": "797299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "797299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumKlh11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium KLH11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumKlh11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "467661.protein.sequences.v11.5.fa",
		        "enrichment_path": "467661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "467661.protein.info.v11.5.txt",
		        "node_list_path": "467661.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusPontisDsm8475Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pontis DSM 8475 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPontisDsm8475Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423794.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423794.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423794.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423794.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423794.protein.info.v11.5.txt",
		        "node_list_path": "1423794.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423794.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwc24211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_42_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc24211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797816.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797816.protein.info.v11.5.txt",
		        "node_list_path": "1797816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeiothermusChliarophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus chliarophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusChliarophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926560.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926560.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926560.clusters.proteins.v11.5.txt",
		        "sequence_path": "926560.protein.sequences.v11.5.fa",
		        "enrichment_path": "926560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926560.protein.info.v11.5.txt",
		        "node_list_path": "926560.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926560.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumHomopropionicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium homopropionicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumHomopropionicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36844.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36844.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36844.clusters.proteins.v11.5.txt",
		        "sequence_path": "36844.protein.sequences.v11.5.fa",
		        "enrichment_path": "36844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36844.protein.info.v11.5.txt",
		        "node_list_path": "36844.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36844.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulosimicrobiumCellulansJ1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulosimicrobium cellulans J1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulosimicrobiumCellulansJ1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "903523.protein.sequences.v11.5.fa",
		        "enrichment_path": "903523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903523.protein.info.v11.5.txt",
		        "node_list_path": "903523.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumPutridalgicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium putridalgicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumPutridalgicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426703.protein.sequences.v11.5.fa",
		        "enrichment_path": "426703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426703.protein.info.v11.5.txt",
		        "node_list_path": "426703.protein.complete.v11.5.txt"
		    }
		]
    )()

def SusScrofaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sus scrofa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SusScrofaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9823.clusters.proteins.v11.5.txt",
		        "sequence_path": "9823.protein.sequences.v11.5.fa",
		        "enrichment_path": "9823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9823.protein.info.v11.5.txt",
		        "node_list_path": "9823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4105Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC4105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4105Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217703.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217703.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217703.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217703.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217703.protein.info.v11.5.txt",
		        "node_list_path": "1217703.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217703.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumCg2303346(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium CG2_30_33_46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumCg2303346", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805400.protein.info.v11.5.txt",
		        "node_list_path": "1805400.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizopusDelemar(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus delemar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopusDelemar", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936053.protein.sequences.v11.5.fa",
		        "enrichment_path": "936053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936053.protein.info.v11.5.txt",
		        "node_list_path": "936053.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaSpPdc64(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. PDC64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpPdc64", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881046.protein.info.v11.5.txt",
		        "node_list_path": "1881046.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusXiamenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusXiamenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1178537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1178537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1178537.protein.info.v11.5.txt",
		        "node_list_path": "1178537.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetaSmaragdinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta smaragdinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaSmaragdinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573413.clusters.proteins.v11.5.txt",
		        "sequence_path": "573413.protein.sequences.v11.5.fa",
		        "enrichment_path": "573413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573413.protein.info.v11.5.txt",
		        "node_list_path": "573413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumLividum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium lividum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumLividum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29581.protein.sequences.v11.5.fa",
		        "enrichment_path": "29581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29581.protein.info.v11.5.txt",
		        "node_list_path": "29581.protein.complete.v11.5.txt"
		    }
		]
    )()

def MorganellaMorganiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Morganella morganii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MorganellaMorganiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1124991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1124991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1124991.clusters.proteins.v11.5.txt",
		        "sequence_path": "1124991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1124991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1124991.protein.info.v11.5.txt",
		        "node_list_path": "1124991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1124991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusHyovaginalisDsm12219Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus hyovaginalis DSM 12219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusHyovaginalisDsm12219Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123305.protein.info.v11.5.txt",
		        "node_list_path": "1123305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSpCag831(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:831 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpCag831", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262698.protein.info.v11.5.txt",
		        "node_list_path": "1262698.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterAcinonychisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter acinonychis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterAcinonychisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "382638.clusters.info.v11.5.txt",
		        "cluster_tree_path": "382638.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "382638.clusters.proteins.v11.5.txt",
		        "sequence_path": "382638.protein.sequences.v11.5.fa",
		        "enrichment_path": "382638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "382638.protein.info.v11.5.txt",
		        "node_list_path": "382638.cluster.nodes.v11.5.txt",
		        "edge_list_path": "382638.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110051Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110051 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110051Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1570340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1570340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1570340.clusters.proteins.v11.5.txt",
		        "sequence_path": "1570340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570340.protein.info.v11.5.txt",
		        "node_list_path": "1570340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1570340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpOlga172(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. OLGA172 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpOlga172", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1804984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1804984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1804984.protein.info.v11.5.txt",
		        "node_list_path": "1804984.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaryophanonTenueCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caryophanon tenue Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaryophanonTenueCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33978.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33978.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33978.clusters.proteins.v11.5.txt",
		        "sequence_path": "33978.protein.sequences.v11.5.fa",
		        "enrichment_path": "33978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33978.protein.info.v11.5.txt",
		        "node_list_path": "33978.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33978.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpRac03(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. RAC03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpRac03", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1843368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1843368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1843368.protein.info.v11.5.txt",
		        "node_list_path": "1843368.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumUasb124Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium UASB124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumUasb124Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1655308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1655308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1655308.clusters.proteins.v11.5.txt",
		        "sequence_path": "1655308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655308.protein.info.v11.5.txt",
		        "node_list_path": "1655308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1655308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaplochromisBurtoniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haplochromis burtoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaplochromisBurtoniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8153.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8153.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8153.clusters.proteins.v11.5.txt",
		        "sequence_path": "8153.protein.sequences.v11.5.fa",
		        "enrichment_path": "8153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8153.protein.info.v11.5.txt",
		        "node_list_path": "8153.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8153.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpUnc380mfsha31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. unc380mfsha3.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpUnc380mfsha31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1793723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1793723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1793723.protein.info.v11.5.txt",
		        "node_list_path": "1793723.protein.complete.v11.5.txt"
		    }
		]
    )()

def FinegoldiaMagnaAtcc29328Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Finegoldia magna ATCC29328 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FinegoldiaMagnaAtcc29328Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "334413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "334413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "334413.clusters.proteins.v11.5.txt",
		        "sequence_path": "334413.protein.sequences.v11.5.fa",
		        "enrichment_path": "334413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334413.protein.info.v11.5.txt",
		        "node_list_path": "334413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "334413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcyrthosiphonPisumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acyrthosiphon pisum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcyrthosiphonPisumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7029.clusters.proteins.v11.5.txt",
		        "sequence_path": "7029.protein.sequences.v11.5.fa",
		        "enrichment_path": "7029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7029.protein.info.v11.5.txt",
		        "node_list_path": "7029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiohalorhabdusDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiohalorhabdus denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiohalorhabdusDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "381306.protein.sequences.v11.5.fa",
		        "enrichment_path": "381306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381306.protein.info.v11.5.txt",
		        "node_list_path": "381306.protein.complete.v11.5.txt"
		    }
		]
    )()

def OwenweeksiaHongkongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Owenweeksia hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OwenweeksiaHongkongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926562.protein.sequences.v11.5.fa",
		        "enrichment_path": "926562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926562.protein.info.v11.5.txt",
		        "node_list_path": "926562.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfobacteriumHydrogeniphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium hydrogeniphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfobacteriumHydrogeniphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "161156.protein.sequences.v11.5.fa",
		        "enrichment_path": "161156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161156.protein.info.v11.5.txt",
		        "node_list_path": "161156.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollimonasFungivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collimonas fungivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollimonasFungivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005048.protein.info.v11.5.txt",
		        "node_list_path": "1005048.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumMoscovienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum moscoviense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumMoscovienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437059.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437059.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437059.protein.info.v11.5.txt",
		        "node_list_path": "1437059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSporothermoduransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sporothermodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSporothermoduransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46224.clusters.proteins.v11.5.txt",
		        "sequence_path": "46224.protein.sequences.v11.5.fa",
		        "enrichment_path": "46224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46224.protein.info.v11.5.txt",
		        "node_list_path": "46224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HirundoRusticaRustica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hirundo rustica rustica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HirundoRusticaRustica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "333673.protein.sequences.v11.5.fa",
		        "enrichment_path": "333673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "333673.protein.info.v11.5.txt",
		        "node_list_path": "333673.protein.complete.v11.5.txt"
		    }
		]
    )()

def JaapiaArgillaceaMucl33604Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jaapia argillacea MUCL 33604 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JaapiaArgillaceaMucl33604Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "933084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "933084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "933084.clusters.proteins.v11.5.txt",
		        "sequence_path": "933084.protein.sequences.v11.5.fa",
		        "enrichment_path": "933084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933084.protein.info.v11.5.txt",
		        "node_list_path": "933084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "933084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HylemonellaGracilisNiagara(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hylemonella gracilis Niagara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HylemonellaGracilisNiagara", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1458275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458275.protein.info.v11.5.txt",
		        "node_list_path": "1458275.protein.complete.v11.5.txt"
		    }
		]
    )()

def RachicladosporiumSpCcfee5018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rachicladosporium sp. CCFEE 5018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RachicladosporiumSpCcfee5018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1974281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1974281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1974281.protein.info.v11.5.txt",
		        "node_list_path": "1974281.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpOralTaxon299StrF0039Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. oral taxon 299 str. F0039 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpOralTaxon299StrF0039Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575614.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575614.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575614.clusters.proteins.v11.5.txt",
		        "sequence_path": "575614.protein.sequences.v11.5.fa",
		        "enrichment_path": "575614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575614.protein.info.v11.5.txt",
		        "node_list_path": "575614.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575614.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHtcc7217(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC7217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHtcc7217", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1400525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400525.protein.info.v11.5.txt",
		        "node_list_path": "1400525.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusStrMit9303(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus str. MIT 9303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusStrMit9303", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59922.protein.sequences.v11.5.fa",
		        "enrichment_path": "59922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59922.protein.info.v11.5.txt",
		        "node_list_path": "59922.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNeoehrlichiaLotorisStrRac413Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Neoehrlichia lotoris str. RAC413 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNeoehrlichiaLotorisStrRac413Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1359163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1359163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1359163.clusters.proteins.v11.5.txt",
		        "sequence_path": "1359163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1359163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1359163.protein.info.v11.5.txt",
		        "node_list_path": "1359163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1359163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpBl8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. BL8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpBl8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354301.protein.info.v11.5.txt",
		        "node_list_path": "1354301.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaeromassilibacillusSpMarseilleP3371Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaeromassilibacillus sp. Marseille-P3371 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeromassilibacillusSpMarseilleP3371Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1944639.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1944639.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1944639.clusters.proteins.v11.5.txt",
		        "sequence_path": "1944639.protein.sequences.v11.5.fa",
		        "enrichment_path": "1944639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1944639.protein.info.v11.5.txt",
		        "node_list_path": "1944639.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1944639.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraParasiticaInra310Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora parasitica INRA-310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraParasiticaInra310Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "761204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "761204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "761204.clusters.proteins.v11.5.txt",
		        "sequence_path": "761204.protein.sequences.v11.5.fa",
		        "enrichment_path": "761204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "761204.protein.info.v11.5.txt",
		        "node_list_path": "761204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "761204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GaldieriaSulphuraria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Galdieria sulphuraria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GaldieriaSulphuraria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "130081.protein.sequences.v11.5.fa",
		        "enrichment_path": "130081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "130081.protein.info.v11.5.txt",
		        "node_list_path": "130081.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusArthromitusSpSfbTurkey(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arthromitus sp. SFB-turkey graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusArthromitusSpSfbTurkey", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1840217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1840217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1840217.protein.info.v11.5.txt",
		        "node_list_path": "1840217.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusColwellbacteriaBacteriumRifcsphigho212Full4417Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPHIGHO2_12_FULL_44_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsphigho212Full4417Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797689.protein.info.v11.5.txt",
		        "node_list_path": "1797689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesPlebeius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides plebeius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesPlebeius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "484018.protein.sequences.v11.5.fa",
		        "enrichment_path": "484018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484018.protein.info.v11.5.txt",
		        "node_list_path": "484018.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMmg1533Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MMG1533 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMmg1533Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415546.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415546.protein.info.v11.5.txt",
		        "node_list_path": "1415546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MariprofundusFerrooxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mariprofundus ferrooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MariprofundusFerrooxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314345.protein.sequences.v11.5.fa",
		        "enrichment_path": "314345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314345.protein.info.v11.5.txt",
		        "node_list_path": "314345.protein.complete.v11.5.txt"
		    }
		]
    )()

def IndibacterAlkaliphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Indibacter alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IndibacterAlkaliphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1189612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1189612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1189612.clusters.proteins.v11.5.txt",
		        "sequence_path": "1189612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1189612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1189612.protein.info.v11.5.txt",
		        "node_list_path": "1189612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1189612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterSpAtcc31444Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter sp. ATCC31444 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterSpAtcc31444Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1806484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1806484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1806484.clusters.proteins.v11.5.txt",
		        "sequence_path": "1806484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806484.protein.info.v11.5.txt",
		        "node_list_path": "1806484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1806484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSp37zxxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 37zxx Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSp37zxxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1550073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1550073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1550073.clusters.proteins.v11.5.txt",
		        "sequence_path": "1550073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550073.protein.info.v11.5.txt",
		        "node_list_path": "1550073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1550073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumLentumNbrc107847Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium lentum NBRC 107847 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumLentumNbrc107847Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219033.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219033.protein.info.v11.5.txt",
		        "node_list_path": "1219033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanobiumSpPcc7001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanobium sp. PCC7001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobiumSpPcc7001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "180281.protein.sequences.v11.5.fa",
		        "enrichment_path": "180281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180281.protein.info.v11.5.txt",
		        "node_list_path": "180281.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrugiaPahangiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brugia pahangi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrugiaPahangiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6280.clusters.proteins.v11.5.txt",
		        "sequence_path": "6280.protein.sequences.v11.5.fa",
		        "enrichment_path": "6280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6280.protein.info.v11.5.txt",
		        "node_list_path": "6280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterAsburiaeLf7a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter asburiae LF7a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterAsburiaeLf7a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "640513.protein.sequences.v11.5.fa",
		        "enrichment_path": "640513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640513.protein.info.v11.5.txt",
		        "node_list_path": "640513.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumCoryneformeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium coryneforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumCoryneformeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1687.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1687.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1687.clusters.proteins.v11.5.txt",
		        "sequence_path": "1687.protein.sequences.v11.5.fa",
		        "enrichment_path": "1687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1687.protein.info.v11.5.txt",
		        "node_list_path": "1687.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1687.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesLuteus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesLuteus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1915400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915400.protein.info.v11.5.txt",
		        "node_list_path": "1915400.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumSpCag439Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium sp. CAG:439 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumSpCag439Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262899.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262899.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262899.protein.info.v11.5.txt",
		        "node_list_path": "1262899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StackebrandtiaNassauensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stackebrandtia nassauensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StackebrandtiaNassauensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "446470.clusters.info.v11.5.txt",
		        "cluster_tree_path": "446470.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "446470.clusters.proteins.v11.5.txt",
		        "sequence_path": "446470.protein.sequences.v11.5.fa",
		        "enrichment_path": "446470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446470.protein.info.v11.5.txt",
		        "node_list_path": "446470.cluster.nodes.v11.5.txt",
		        "edge_list_path": "446470.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3744Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYB1_FULL_37_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3744Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802223.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802223.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802223.protein.info.v11.5.txt",
		        "node_list_path": "1802223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaAphisGlycinesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Aphis glycines) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaAphisGlycinesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265350.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265350.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265350.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265350.protein.info.v11.5.txt",
		        "node_list_path": "1265350.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265350.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanolobusTindariusDsm2278Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus tindarius DSM 2278 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolobusTindariusDsm2278Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1090322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1090322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1090322.clusters.proteins.v11.5.txt",
		        "sequence_path": "1090322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1090322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1090322.protein.info.v11.5.txt",
		        "node_list_path": "1090322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1090322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUzinuraDiaspidicolaStrAsnerCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uzinura diaspidicola str. ASNER Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUzinuraDiaspidicolaStrAsnerCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1133592.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1133592.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1133592.clusters.proteins.v11.5.txt",
		        "sequence_path": "1133592.protein.sequences.v11.5.fa",
		        "enrichment_path": "1133592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1133592.protein.info.v11.5.txt",
		        "node_list_path": "1133592.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1133592.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterUraniireducensRf4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter uraniireducens Rf4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterUraniireducensRf4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351605.clusters.proteins.v11.5.txt",
		        "sequence_path": "351605.protein.sequences.v11.5.fa",
		        "enrichment_path": "351605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351605.protein.info.v11.5.txt",
		        "node_list_path": "351605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumScgcAaa288N07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA288-N07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumScgcAaa288N07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "939346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "939346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "939346.clusters.proteins.v11.5.txt",
		        "sequence_path": "939346.protein.sequences.v11.5.fa",
		        "enrichment_path": "939346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939346.protein.info.v11.5.txt",
		        "node_list_path": "939346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "939346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterCetorumMit007128Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cetorum MIT007128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterCetorumMit007128Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "182217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "182217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "182217.clusters.proteins.v11.5.txt",
		        "sequence_path": "182217.protein.sequences.v11.5.fa",
		        "enrichment_path": "182217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "182217.protein.info.v11.5.txt",
		        "node_list_path": "182217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "182217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElaeophoraElaphiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elaeophora elaphi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElaeophoraElaphiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1147741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1147741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1147741.clusters.proteins.v11.5.txt",
		        "sequence_path": "1147741.protein.sequences.v11.5.fa",
		        "enrichment_path": "1147741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1147741.protein.info.v11.5.txt",
		        "node_list_path": "1147741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1147741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaNorrlandicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella norrlandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaNorrlandicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1498499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1498499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1498499.clusters.proteins.v11.5.txt",
		        "sequence_path": "1498499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1498499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1498499.protein.info.v11.5.txt",
		        "node_list_path": "1498499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1498499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGr1643(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium GR16-43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGr1643", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1904640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904640.protein.info.v11.5.txt",
		        "node_list_path": "1904640.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseburiaFaecis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseburia faecis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaFaecis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "301302.protein.sequences.v11.5.fa",
		        "enrichment_path": "301302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "301302.protein.info.v11.5.txt",
		        "node_list_path": "301302.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinicoccusRoseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusRoseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45670.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45670.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45670.clusters.proteins.v11.5.txt",
		        "sequence_path": "45670.protein.sequences.v11.5.fa",
		        "enrichment_path": "45670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45670.protein.info.v11.5.txt",
		        "node_list_path": "45670.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45670.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PuniceicoccalesBacteriumVerruco02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Puniceicoccales bacterium Verruco_02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PuniceicoccalesBacteriumVerruco02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674913.protein.info.v11.5.txt",
		        "node_list_path": "1674913.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermosynechococcusSpNk55a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermosynechococcus sp. NK55a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosynechococcusSpNk55a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1394889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394889.protein.info.v11.5.txt",
		        "node_list_path": "1394889.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpYcRl4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. YC-RL4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpYcRl4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1682113.protein.sequences.v11.5.fa",
		        "enrichment_path": "1682113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1682113.protein.info.v11.5.txt",
		        "node_list_path": "1682113.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpP11g5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. P11G5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpP11g5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1699624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1699624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1699624.clusters.proteins.v11.5.txt",
		        "sequence_path": "1699624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1699624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1699624.protein.info.v11.5.txt",
		        "node_list_path": "1699624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1699624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaNiastensisDsm21313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia niastensis DSM 21313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaNiastensisDsm21313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122215.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122215.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122215.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122215.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122215.protein.info.v11.5.txt",
		        "node_list_path": "1122215.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122215.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesLincolnensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces lincolnensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesLincolnensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915.protein.info.v11.5.txt",
		        "node_list_path": "1915.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg164411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_44_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg164411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797837.protein.info.v11.5.txt",
		        "node_list_path": "1797837.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChaetomiumGlobosumCbs14851(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium globosum CBS 148.51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChaetomiumGlobosumCbs14851", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "306901.protein.sequences.v11.5.fa",
		        "enrichment_path": "306901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306901.protein.info.v11.5.txt",
		        "node_list_path": "306901.protein.complete.v11.5.txt"
		    }
		]
    )()

def TepidanaerobacterSyntrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tepidanaerobacter syntrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidanaerobacterSyntrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "224999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "224999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "224999.clusters.proteins.v11.5.txt",
		        "sequence_path": "224999.protein.sequences.v11.5.fa",
		        "enrichment_path": "224999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224999.protein.info.v11.5.txt",
		        "node_list_path": "224999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "224999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioSpRc586Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. RC586 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpRc586Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675815.clusters.proteins.v11.5.txt",
		        "sequence_path": "675815.protein.sequences.v11.5.fa",
		        "enrichment_path": "675815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675815.protein.info.v11.5.txt",
		        "node_list_path": "675815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrococcusLahaulensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrococcus lahaulensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrococcusLahaulensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120958.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120958.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120958.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120958.protein.info.v11.5.txt",
		        "node_list_path": "1120958.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120958.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusJeotgali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusJeotgali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "129985.protein.sequences.v11.5.fa",
		        "enrichment_path": "129985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "129985.protein.info.v11.5.txt",
		        "node_list_path": "129985.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudorhodobacterFerrugineusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodobacter ferrugineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodobacterFerrugineusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "77008.clusters.info.v11.5.txt",
		        "cluster_tree_path": "77008.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "77008.clusters.proteins.v11.5.txt",
		        "sequence_path": "77008.protein.sequences.v11.5.fa",
		        "enrichment_path": "77008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77008.protein.info.v11.5.txt",
		        "node_list_path": "77008.cluster.nodes.v11.5.txt",
		        "edge_list_path": "77008.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRoot61(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRoot61", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736570.protein.info.v11.5.txt",
		        "node_list_path": "1736570.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaceaeBacteriumDnf00626(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonellaceae bacterium DNF00626 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaceaeBacteriumDnf00626", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1588754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588754.protein.info.v11.5.txt",
		        "node_list_path": "1588754.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusLactolyticusS7113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus S7113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusLactolyticusS7113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1284686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1284686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1284686.clusters.proteins.v11.5.txt",
		        "sequence_path": "1284686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284686.protein.info.v11.5.txt",
		        "node_list_path": "1284686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1284686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusBeijingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus beijingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusBeijingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1126833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1126833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1126833.clusters.proteins.v11.5.txt",
		        "sequence_path": "1126833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1126833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1126833.protein.info.v11.5.txt",
		        "node_list_path": "1126833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1126833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumD1873Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum D 1873 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumD1873Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "592027.clusters.info.v11.5.txt",
		        "cluster_tree_path": "592027.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "592027.clusters.proteins.v11.5.txt",
		        "sequence_path": "592027.protein.sequences.v11.5.fa",
		        "enrichment_path": "592027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592027.protein.info.v11.5.txt",
		        "node_list_path": "592027.cluster.nodes.v11.5.txt",
		        "edge_list_path": "592027.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArabiaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arabia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArabiaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1870985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1870985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1870985.clusters.proteins.v11.5.txt",
		        "sequence_path": "1870985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870985.protein.info.v11.5.txt",
		        "node_list_path": "1870985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1870985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlcaligenaceaeBacteriumDtu041(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcaligenaceae bacterium DTU041 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcaligenaceaeBacteriumDtu041", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671635.protein.info.v11.5.txt",
		        "node_list_path": "1671635.protein.complete.v11.5.txt"
		    }
		]
    )()

def LacinutrixSpHelI90Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix sp. Hel_I_90 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixSpHelI90Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1249999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1249999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1249999.clusters.proteins.v11.5.txt",
		        "sequence_path": "1249999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249999.protein.info.v11.5.txt",
		        "node_list_path": "1249999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1249999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlysiellaCrassaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alysiella crassa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlysiellaCrassaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120980.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120980.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120980.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120980.protein.info.v11.5.txt",
		        "node_list_path": "1120980.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120980.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WallemiaMellicolaCbs63366(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wallemia mellicola CBS 633.66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WallemiaMellicolaCbs63366", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "671144.protein.sequences.v11.5.fa",
		        "enrichment_path": "671144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "671144.protein.info.v11.5.txt",
		        "node_list_path": "671144.protein.complete.v11.5.txt"
		    }
		]
    )()

def EremococcusColeocolaDsm15696Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eremococcus coleocola DSM15696 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremococcusColeocolaDsm15696Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121871.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121871.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121871.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121871.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121871.protein.info.v11.5.txt",
		        "node_list_path": "1121871.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121871.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioThiocyanoxidansArh2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArh2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1279019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1279019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1279019.clusters.proteins.v11.5.txt",
		        "sequence_path": "1279019.protein.sequences.v11.5.fa",
		        "enrichment_path": "1279019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1279019.protein.info.v11.5.txt",
		        "node_list_path": "1279019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1279019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphaerotilusNatans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphaerotilus natans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerotilusNatans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1286631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286631.protein.info.v11.5.txt",
		        "node_list_path": "1286631.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizoctoniaSolani123eCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizoctonia solani 123E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizoctoniaSolani123eCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423351.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423351.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423351.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423351.protein.info.v11.5.txt",
		        "node_list_path": "1423351.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423351.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpTomcCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. TomC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpTomcCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1562888.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1562888.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1562888.clusters.proteins.v11.5.txt",
		        "sequence_path": "1562888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1562888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1562888.protein.info.v11.5.txt",
		        "node_list_path": "1562888.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1562888.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KnoelliaSubterranea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Knoellia subterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KnoelliaSubterranea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385521.protein.info.v11.5.txt",
		        "node_list_path": "1385521.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusAmylolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus amylolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAmylolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585524.protein.sequences.v11.5.fa",
		        "enrichment_path": "585524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585524.protein.info.v11.5.txt",
		        "node_list_path": "585524.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusSpRitPiFCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sp. RIT-PI-f Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSpRitPiFCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1690244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1690244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1690244.clusters.proteins.v11.5.txt",
		        "sequence_path": "1690244.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690244.protein.info.v11.5.txt",
		        "node_list_path": "1690244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1690244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FermentimonasCaenicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fermentimonas caenicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FermentimonasCaenicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1562970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1562970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1562970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1562970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1562970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1562970.protein.info.v11.5.txt",
		        "node_list_path": "1562970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1562970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParasponiaAndersoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parasponia andersonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParasponiaAndersoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3476.clusters.proteins.v11.5.txt",
		        "sequence_path": "3476.protein.sequences.v11.5.fa",
		        "enrichment_path": "3476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3476.protein.info.v11.5.txt",
		        "node_list_path": "3476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerobaculumHydrogeniformansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobaculum hydrogeniformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobaculumHydrogeniformansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "592015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "592015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "592015.clusters.proteins.v11.5.txt",
		        "sequence_path": "592015.protein.sequences.v11.5.fa",
		        "enrichment_path": "592015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592015.protein.info.v11.5.txt",
		        "node_list_path": "592015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "592015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumRifcsplowo201Full4816(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPLOWO2_01_FULL_48_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsplowo201Full4816", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802461.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802461.protein.info.v11.5.txt",
		        "node_list_path": "1802461.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaGoodfellowii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia goodfellowii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaGoodfellowii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596323.protein.sequences.v11.5.fa",
		        "enrichment_path": "596323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596323.protein.info.v11.5.txt",
		        "node_list_path": "596323.protein.complete.v11.5.txt"
		    }
		]
    )()

def WigglesworthiaGlossinidiaSpGbr(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia sp. Gbr graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WigglesworthiaGlossinidiaSpGbr", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36870.protein.sequences.v11.0.fa",
		        "enrichment_path": "36870.protein.enrichment.terms.v11.0.txt",
		        "info_path": "36870.protein.info.v11.0.txt",
		        "node_list_path": "36870.protein.complete.v11.0.txt"
		    }
		]
    )()

def BacteroidalesBacteriumCf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium CF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumCf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1400053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400053.protein.info.v11.5.txt",
		        "node_list_path": "1400053.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalipaludibacillusAgaradhaerens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salipaludibacillus agaradhaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalipaludibacillusAgaradhaerens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "76935.protein.sequences.v11.5.fa",
		        "enrichment_path": "76935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76935.protein.info.v11.5.txt",
		        "node_list_path": "76935.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4322(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_43_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4322", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798688.protein.info.v11.5.txt",
		        "node_list_path": "1798688.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerophagaThermohalophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerophaga thermohalophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerophagaThermohalophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "886379.protein.sequences.v11.5.fa",
		        "enrichment_path": "886379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "886379.protein.info.v11.5.txt",
		        "node_list_path": "886379.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillospiraceaeBacteriumZagget6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillospiraceae bacterium Zagget6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillospiraceaeBacteriumZagget6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930019.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930019.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930019.protein.info.v11.5.txt",
		        "node_list_path": "1930019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NesterenkoniaJeotgaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesterenkoniaJeotgaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "317018.clusters.info.v11.5.txt",
		        "cluster_tree_path": "317018.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "317018.clusters.proteins.v11.5.txt",
		        "sequence_path": "317018.protein.sequences.v11.5.fa",
		        "enrichment_path": "317018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317018.protein.info.v11.5.txt",
		        "node_list_path": "317018.cluster.nodes.v11.5.txt",
		        "edge_list_path": "317018.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumReuteri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium reuteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumReuteri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437610.protein.info.v11.5.txt",
		        "node_list_path": "1437610.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaePhaseolicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae phaseolicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaePhaseolicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264730.clusters.proteins.v11.5.txt",
		        "sequence_path": "264730.protein.sequences.v11.5.fa",
		        "enrichment_path": "264730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264730.protein.info.v11.5.txt",
		        "node_list_path": "264730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseomonasSpB5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas sp. B5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseomonasSpB5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217720.protein.info.v11.5.txt",
		        "node_list_path": "1217720.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporanaerobacterAcetigenesDsm13106Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporanaerobacter acetigenes DSM 13106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporanaerobacterAcetigenesDsm13106Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123281.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123281.protein.info.v11.5.txt",
		        "node_list_path": "1123281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85201350091Sch5140682Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852013-50091_SCH5140682 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85201350091Sch5140682Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834109.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834109.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834109.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834109.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834109.protein.info.v11.5.txt",
		        "node_list_path": "1834109.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834109.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioSpMd2005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. MD2005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioSpMd2005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410616.protein.info.v11.5.txt",
		        "node_list_path": "1410616.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaAustralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaAustralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1105110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1105110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1105110.protein.info.v11.5.txt",
		        "node_list_path": "1105110.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovirgulaThermocuniculi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovirgula thermocuniculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovirgulaThermocuniculi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121468.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121468.protein.info.v11.5.txt",
		        "node_list_path": "1121468.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermobaculumTerrenum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermobaculum terrenum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobaculumTerrenum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525904.protein.sequences.v11.5.fa",
		        "enrichment_path": "525904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525904.protein.info.v11.5.txt",
		        "node_list_path": "525904.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumBrhC25Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium BRH_c25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumBrhC25Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1734399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1734399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1734399.clusters.proteins.v11.5.txt",
		        "sequence_path": "1734399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1734399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1734399.protein.info.v11.5.txt",
		        "node_list_path": "1734399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1734399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CuculusCanorusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cuculus canorus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CuculusCanorusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "55661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "55661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "55661.clusters.proteins.v11.5.txt",
		        "sequence_path": "55661.protein.sequences.v11.5.fa",
		        "enrichment_path": "55661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55661.protein.info.v11.5.txt",
		        "node_list_path": "55661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "55661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaCoriaceaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia coriaceae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaCoriaceaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1313292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1313292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1313292.clusters.proteins.v11.5.txt",
		        "sequence_path": "1313292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313292.protein.info.v11.5.txt",
		        "node_list_path": "1313292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1313292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubritepidaFlocculans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubritepida flocculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubritepidaFlocculans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123072.protein.info.v11.5.txt",
		        "node_list_path": "1123072.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaIntermediaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella intermedia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaIntermediaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28131.clusters.proteins.v11.5.txt",
		        "sequence_path": "28131.protein.sequences.v11.5.fa",
		        "enrichment_path": "28131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28131.protein.info.v11.5.txt",
		        "node_list_path": "28131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHtcc2143Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHtcc2143Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "247633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "247633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "247633.clusters.proteins.v11.5.txt",
		        "sequence_path": "247633.protein.sequences.v11.5.fa",
		        "enrichment_path": "247633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247633.protein.info.v11.5.txt",
		        "node_list_path": "247633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "247633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27251Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27251Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1684142.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1684142.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1684142.clusters.proteins.v11.5.txt",
		        "sequence_path": "1684142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1684142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1684142.protein.info.v11.5.txt",
		        "node_list_path": "1684142.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1684142.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAviumAviumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Mycobacterium avium avium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAviumAviumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44454.clusters.info.v11.0.txt",
		        "cluster_tree_path": "44454.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "44454.clusters.proteins.v11.0.txt",
		        "sequence_path": "44454.protein.sequences.v11.0.fa",
		        "enrichment_path": "44454.protein.enrichment.terms.v11.0.txt",
		        "info_path": "44454.protein.info.v11.0.txt",
		        "node_list_path": "44454.cluster.nodes.v11.0.txt",
		        "edge_list_path": "44454.protein.cluster.v11.0.txt"
		    }
		]
    )()

def MethanogenicArchaeonMixedCultureIso4G1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return methanogenic archaeon mixed culture ISO4-G1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanogenicArchaeonMixedCultureIso4G1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1452364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1452364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1452364.clusters.proteins.v11.5.txt",
		        "sequence_path": "1452364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1452364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1452364.protein.info.v11.5.txt",
		        "node_list_path": "1452364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1452364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonomuraeaWenchangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea wenchangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaWenchangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "568860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "568860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "568860.clusters.proteins.v11.5.txt",
		        "sequence_path": "568860.protein.sequences.v11.5.fa",
		        "enrichment_path": "568860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568860.protein.info.v11.5.txt",
		        "node_list_path": "568860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "568860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AvibacteriumParagallinarum221Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum 221 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AvibacteriumParagallinarum221Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278971.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278971.protein.info.v11.5.txt",
		        "node_list_path": "1278971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaceaeBacteriumKbs83Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs83Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267533.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267533.protein.info.v11.5.txt",
		        "node_list_path": "1267533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaNiwaeNbrc108934Dsm45340Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia niwae NBRC 108934 DSM 45340 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaNiwaeNbrc108934Dsm45340Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223489.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223489.protein.info.v11.5.txt",
		        "node_list_path": "1223489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasAquamarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas aquamarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasAquamarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "77097.protein.sequences.v11.5.fa",
		        "enrichment_path": "77097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77097.protein.info.v11.5.txt",
		        "node_list_path": "77097.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterGummosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter gummosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterGummosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "262324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "262324.clusters.proteins.v11.5.txt",
		        "sequence_path": "262324.protein.sequences.v11.5.fa",
		        "enrichment_path": "262324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262324.protein.info.v11.5.txt",
		        "node_list_path": "262324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "262324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaceaeBacteriumKbs96Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs96Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267535.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267535.protein.info.v11.5.txt",
		        "node_list_path": "1267535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraKuenenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira kuenenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraKuenenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1168067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168067.protein.info.v11.5.txt",
		        "node_list_path": "1168067.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterCibinongensis4h1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter cibinongensis 4H-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterCibinongensis4h1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231339.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231339.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231339.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231339.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231339.protein.info.v11.5.txt",
		        "node_list_path": "1231339.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231339.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifoxyd1Full4224Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYD1_FULL_42_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyd1Full4224Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802651.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802651.protein.info.v11.5.txt",
		        "node_list_path": "1802651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumLuticocti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium luticocti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumLuticocti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122239.protein.info.v11.5.txt",
		        "node_list_path": "1122239.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa23813(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_38_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa23813", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618811.protein.info.v11.5.txt",
		        "node_list_path": "1618811.protein.complete.v11.5.txt"
		    }
		]
    )()

def DechloromonasAgitataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dechloromonas agitata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DechloromonasAgitataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304883.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304883.protein.info.v11.5.txt",
		        "node_list_path": "1304883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpLtsp849(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LTSP849 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpLtsp849", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1615890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1615890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1615890.protein.info.v11.5.txt",
		        "node_list_path": "1615890.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag169Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:169 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag169Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262778.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262778.protein.info.v11.5.txt",
		        "node_list_path": "1262778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ItalianCloverPhyllodyPhytoplasmaStrMa1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Italian clover phyllody phytoplasma str. MA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ItalianCloverPhyllodyPhytoplasmaStrMa1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196421.protein.info.v11.5.txt",
		        "node_list_path": "1196421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpN5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. N5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpN5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1101189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101189.protein.info.v11.5.txt",
		        "node_list_path": "1101189.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumStBin11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium ST_bin11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumStBin11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1978759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1978759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1978759.clusters.proteins.v11.5.txt",
		        "sequence_path": "1978759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978759.protein.info.v11.5.txt",
		        "node_list_path": "1978759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1978759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg165711(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_57_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg165711", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797651.protein.info.v11.5.txt",
		        "node_list_path": "1797651.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuberBorchiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tuber borchii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuberBorchiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42251.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42251.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42251.clusters.proteins.v11.5.txt",
		        "sequence_path": "42251.protein.sequences.v11.5.fa",
		        "enrichment_path": "42251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42251.protein.info.v11.5.txt",
		        "node_list_path": "42251.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42251.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferThermotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer thermotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferThermotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "252514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "252514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "252514.clusters.proteins.v11.5.txt",
		        "sequence_path": "252514.protein.sequences.v11.5.fa",
		        "enrichment_path": "252514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "252514.protein.info.v11.5.txt",
		        "node_list_path": "252514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "252514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpiritivorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium spiritivorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpiritivorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525373.protein.sequences.v11.5.fa",
		        "enrichment_path": "525373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525373.protein.info.v11.5.txt",
		        "node_list_path": "525373.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwf236839Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWF2_36_839 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwf236839Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618723.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618723.protein.info.v11.5.txt",
		        "node_list_path": "1618723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacterium351910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium 351910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacterium351910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "531844.clusters.info.v11.5.txt",
		        "cluster_tree_path": "531844.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "531844.clusters.proteins.v11.5.txt",
		        "sequence_path": "531844.protein.sequences.v11.5.fa",
		        "enrichment_path": "531844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "531844.protein.info.v11.5.txt",
		        "node_list_path": "531844.cluster.nodes.v11.5.txt",
		        "edge_list_path": "531844.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpCag1963641Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CAG:196_36_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpCag1963641Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896966.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896966.protein.info.v11.5.txt",
		        "node_list_path": "1896966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZhongshaniaAliphaticivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zhongshania aliphaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZhongshaniaAliphaticivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1470434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1470434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1470434.clusters.proteins.v11.5.txt",
		        "sequence_path": "1470434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470434.protein.info.v11.5.txt",
		        "node_list_path": "1470434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1470434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735683.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735683.protein.info.v11.5.txt",
		        "node_list_path": "1735683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LautropiaMirabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lautropia mirabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LautropiaMirabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "887898.protein.sequences.v11.5.fa",
		        "enrichment_path": "887898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "887898.protein.info.v11.5.txt",
		        "node_list_path": "887898.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusDysgalactiaeAtcc27957Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae ATCC27957 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDysgalactiaeAtcc27957Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "663952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "663952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "663952.clusters.proteins.v11.5.txt",
		        "sequence_path": "663952.protein.sequences.v11.5.fa",
		        "enrichment_path": "663952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663952.protein.info.v11.5.txt",
		        "node_list_path": "663952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "663952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusPseudintermedius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus pseudintermedius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusPseudintermedius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "984892.protein.sequences.v11.5.fa",
		        "enrichment_path": "984892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "984892.protein.info.v11.5.txt",
		        "node_list_path": "984892.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumParaconglomeratumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium paraconglomeratum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumParaconglomeratumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1064537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1064537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1064537.clusters.proteins.v11.5.txt",
		        "sequence_path": "1064537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1064537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1064537.protein.info.v11.5.txt",
		        "node_list_path": "1064537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1064537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizophagusClarus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus clarus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizophagusClarus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "94130.protein.sequences.v11.5.fa",
		        "enrichment_path": "94130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94130.protein.info.v11.5.txt",
		        "node_list_path": "94130.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumUj101Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium UJ101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumUj101Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150389.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150389.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150389.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150389.protein.info.v11.5.txt",
		        "node_list_path": "1150389.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150389.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9107Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9107Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59921.clusters.proteins.v11.5.txt",
		        "sequence_path": "59921.protein.sequences.v11.5.fa",
		        "enrichment_path": "59921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59921.protein.info.v11.5.txt",
		        "node_list_path": "59921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachanceaLanzarotensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachancea lanzarotensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachanceaLanzarotensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1245769.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1245769.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1245769.clusters.proteins.v11.5.txt",
		        "sequence_path": "1245769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245769.protein.info.v11.5.txt",
		        "node_list_path": "1245769.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1245769.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospinaSpAb629b18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospina sp. AB629B18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospinaSpAb629b18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131269.protein.info.v11.5.txt",
		        "node_list_path": "1131269.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpKh1p2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. kh1p2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpKh1p2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761883.protein.info.v11.5.txt",
		        "node_list_path": "1761883.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpDg25b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. DG25B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpDg25b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385664.protein.info.v11.5.txt",
		        "node_list_path": "1385664.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTpA0356(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TP-A0356 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTpA0356", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1359208.protein.sequences.v11.5.fa",
		        "enrichment_path": "1359208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1359208.protein.info.v11.5.txt",
		        "node_list_path": "1359208.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807739.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807739.protein.info.v11.5.txt",
		        "node_list_path": "1807739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumGwf24514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_45_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumGwf24514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798572.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798572.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798572.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798572.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798572.protein.info.v11.5.txt",
		        "node_list_path": "1798572.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798572.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpWcc10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. WCC10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpWcc10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855343.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855343.protein.info.v11.5.txt",
		        "node_list_path": "1855343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TistrellaMobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tistrella mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TistrellaMobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1110502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1110502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1110502.clusters.proteins.v11.5.txt",
		        "sequence_path": "1110502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1110502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1110502.protein.info.v11.5.txt",
		        "node_list_path": "1110502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1110502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumRoseum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium roseum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumRoseum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84029.protein.sequences.v11.5.fa",
		        "enrichment_path": "84029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84029.protein.info.v11.5.txt",
		        "node_list_path": "84029.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumZor0006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium ZOR0006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumZor0006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1339252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1339252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1339252.protein.info.v11.5.txt",
		        "node_list_path": "1339252.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumGw2011Gwa24413bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWA2_44_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwa24413bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618647.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618647.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618647.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618647.protein.info.v11.5.txt",
		        "node_list_path": "1618647.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618647.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomaduraOligosporaAtcc43269(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura oligospora ATCC 43269 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraOligosporaAtcc43269", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1399798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399798.protein.info.v11.5.txt",
		        "node_list_path": "1399798.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusSpMv1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus sp. MV1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusSpMv1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219626.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219626.protein.info.v11.5.txt",
		        "node_list_path": "1219626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaEburneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora eburnea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaEburneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "227316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "227316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "227316.clusters.proteins.v11.5.txt",
		        "sequence_path": "227316.protein.sequences.v11.5.fa",
		        "enrichment_path": "227316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227316.protein.info.v11.5.txt",
		        "node_list_path": "227316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "227316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporolactobacillusTerraeHkm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus terrae HKM-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolactobacillusTerraeHkm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449983.protein.info.v11.5.txt",
		        "node_list_path": "1449983.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpSfdCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. SFD Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpSfdCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805635.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805635.protein.info.v11.5.txt",
		        "node_list_path": "1805635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkelbacteriaBacteriumRifoxya2Full4310(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFOXYA2_FULL_43_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifoxya2Full4310", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797472.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797472.protein.info.v11.5.txt",
		        "node_list_path": "1797472.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSpOk626Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. ok626 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpOk626Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761882.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761882.protein.info.v11.5.txt",
		        "node_list_path": "1761882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErysipelothrixTonsillarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erysipelothrix tonsillarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelothrixTonsillarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121874.protein.info.v11.5.txt",
		        "node_list_path": "1121874.protein.complete.v11.5.txt"
		    }
		]
    )()

def PneumocystisJiroveciiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PneumocystisJiroveciiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42068.clusters.proteins.v11.5.txt",
		        "sequence_path": "42068.protein.sequences.v11.5.fa",
		        "enrichment_path": "42068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42068.protein.info.v11.5.txt",
		        "node_list_path": "42068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesFlavochromogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavochromogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesFlavochromogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68199.clusters.proteins.v11.5.txt",
		        "sequence_path": "68199.protein.sequences.v11.5.fa",
		        "enrichment_path": "68199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68199.protein.info.v11.5.txt",
		        "node_list_path": "68199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrondihabitansSpLeaf304Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frondihabitans sp. Leaf304 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrondihabitansSpLeaf304Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736329.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736329.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736329.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736329.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736329.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736329.protein.info.v11.5.txt",
		        "node_list_path": "1736329.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736329.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumTakakiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium takakiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumTakakiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1302685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302685.protein.info.v11.5.txt",
		        "node_list_path": "1302685.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaloranaerobacterSpTr13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caloranaerobacter sp. TR13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloranaerobacterSpTr13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1302151.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302151.protein.info.v11.5.txt",
		        "node_list_path": "1302151.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusGeothermalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus geothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusGeothermalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "319795.protein.sequences.v11.5.fa",
		        "enrichment_path": "319795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319795.protein.info.v11.5.txt",
		        "node_list_path": "319795.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacillusSpMm3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacillus sp. MM3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacillusSpMm3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1848039.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1848039.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1848039.clusters.proteins.v11.5.txt",
		        "sequence_path": "1848039.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848039.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848039.protein.info.v11.5.txt",
		        "node_list_path": "1848039.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1848039.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloactinobacteriumAlbum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloactinobacterium album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloactinobacteriumAlbum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "648782.protein.sequences.v11.5.fa",
		        "enrichment_path": "648782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "648782.protein.info.v11.5.txt",
		        "node_list_path": "648782.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusLactisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus lactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusLactisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743719.clusters.proteins.v11.5.txt",
		        "sequence_path": "743719.protein.sequences.v11.5.fa",
		        "enrichment_path": "743719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743719.protein.info.v11.5.txt",
		        "node_list_path": "743719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphiprionPercula(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amphiprion percula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphiprionPercula", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "161767.protein.sequences.v11.5.fa",
		        "enrichment_path": "161767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161767.protein.info.v11.5.txt",
		        "node_list_path": "161767.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionCpr3BacteriumGw2011Gwf23518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR3 bacterium GW2011_GWF2_35_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionCpr3BacteriumGw2011Gwf23518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618350.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618350.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618350.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618350.protein.info.v11.5.txt",
		        "node_list_path": "1618350.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618350.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesUrinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesUrinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1689268.protein.sequences.v11.5.fa",
		        "enrichment_path": "1689268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1689268.protein.info.v11.5.txt",
		        "node_list_path": "1689268.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGwe24236(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWE2_42_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGwe24236", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798262.protein.info.v11.5.txt",
		        "node_list_path": "1798262.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpNsp21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. NSP2.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpNsp21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071072.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071072.protein.info.v11.5.txt",
		        "node_list_path": "1071072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiCft073(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli CFT073 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiCft073", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "199310.protein.sequences.v11.5.fa",
		        "enrichment_path": "199310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "199310.protein.info.v11.5.txt",
		        "node_list_path": "199310.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumCg2305367(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_53_67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumCg2305367", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805278.protein.info.v11.5.txt",
		        "node_list_path": "1805278.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParvimonasSpF0440Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parvimonas sp. F0440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvimonasSpF0440Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "944565.clusters.info.v11.5.txt",
		        "cluster_tree_path": "944565.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "944565.clusters.proteins.v11.5.txt",
		        "sequence_path": "944565.protein.sequences.v11.5.fa",
		        "enrichment_path": "944565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944565.protein.info.v11.5.txt",
		        "node_list_path": "944565.cluster.nodes.v11.5.txt",
		        "edge_list_path": "944565.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag568Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:568 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag568Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262821.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262821.protein.info.v11.5.txt",
		        "node_list_path": "1262821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAchromatiumPalustreCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Achromatium palustre Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAchromatiumPalustreCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1662188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1662188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1662188.clusters.proteins.v11.5.txt",
		        "sequence_path": "1662188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662188.protein.info.v11.5.txt",
		        "node_list_path": "1662188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1662188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyopneumoniae232(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae 232 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyopneumoniae232", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "295358.protein.sequences.v11.5.fa",
		        "enrichment_path": "295358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "295358.protein.info.v11.5.txt",
		        "node_list_path": "295358.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpScn6214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SCN 62-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpScn6214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660099.protein.info.v11.5.txt",
		        "node_list_path": "1660099.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaritimibacterSpRedseaS28B5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maritimibacter sp. REDSEA-S28_B5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaritimibacterSpRedseaS28B5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811547.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811547.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811547.protein.info.v11.5.txt",
		        "node_list_path": "1811547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterGuttiformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter guttiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterGuttiformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1443111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443111.protein.info.v11.5.txt",
		        "node_list_path": "1443111.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterNitrogenifigensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter nitrogenifigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterNitrogenifigensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120919.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120919.protein.info.v11.5.txt",
		        "node_list_path": "1120919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CroceibacteriumMercuriale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Croceibacterium mercuriale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CroceibacteriumMercuriale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1572751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1572751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1572751.protein.info.v11.5.txt",
		        "node_list_path": "1572751.protein.complete.v11.5.txt"
		    }
		]
    )()

def RubrobacterRadiotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubrobacter radiotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrobacterRadiotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42256.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42256.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42256.clusters.proteins.v11.5.txt",
		        "sequence_path": "42256.protein.sequences.v11.5.fa",
		        "enrichment_path": "42256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42256.protein.info.v11.5.txt",
		        "node_list_path": "42256.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42256.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FaecalicatenaContorta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Faecalicatena contorta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalicatenaContorta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39482.protein.sequences.v11.5.fa",
		        "enrichment_path": "39482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39482.protein.info.v11.5.txt",
		        "node_list_path": "39482.protein.complete.v11.5.txt"
		    }
		]
    )()

def FaecalibacteriumPrausnitziiSl33(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii SL33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibacteriumPrausnitziiSl33", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "657322.protein.sequences.v11.5.fa",
		        "enrichment_path": "657322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657322.protein.info.v11.5.txt",
		        "node_list_path": "657322.protein.complete.v11.5.txt"
		    }
		]
    )()

def VirgibacillusSpSk37Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus sp. SK37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusSpSk37Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "403957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "403957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "403957.clusters.proteins.v11.5.txt",
		        "sequence_path": "403957.protein.sequences.v11.5.fa",
		        "enrichment_path": "403957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "403957.protein.info.v11.5.txt",
		        "node_list_path": "403957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "403957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraBorgpeterseniiSerovarHardjoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii serovar Hardjo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraBorgpeterseniiSerovarHardjoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "328971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "328971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "328971.clusters.proteins.v11.5.txt",
		        "sequence_path": "328971.protein.sequences.v11.5.fa",
		        "enrichment_path": "328971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "328971.protein.info.v11.5.txt",
		        "node_list_path": "328971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "328971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesEuropaeus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces europaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesEuropaeus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883069.protein.sequences.v11.5.fa",
		        "enrichment_path": "883069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883069.protein.info.v11.5.txt",
		        "node_list_path": "883069.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaGinsengisegetisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga ginsengisegetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaGinsengisegetisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "393003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "393003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "393003.clusters.proteins.v11.5.txt",
		        "sequence_path": "393003.protein.sequences.v11.5.fa",
		        "enrichment_path": "393003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393003.protein.info.v11.5.txt",
		        "node_list_path": "393003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "393003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumBergheiAnkaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium berghei ANKA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumBergheiAnkaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5823.clusters.proteins.v11.5.txt",
		        "sequence_path": "5823.protein.sequences.v11.5.fa",
		        "enrichment_path": "5823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5823.protein.info.v11.5.txt",
		        "node_list_path": "5823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807730.protein.info.v11.5.txt",
		        "node_list_path": "1807730.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpLeaf405Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf405 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpLeaf405Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736367.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736367.protein.info.v11.5.txt",
		        "node_list_path": "1736367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaVarigenaUsdaarsusmarc1296Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia varigena USDAARSUSMARC1296 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaVarigenaUsdaarsusmarc1296Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1433287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1433287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1433287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1433287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1433287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1433287.protein.info.v11.5.txt",
		        "node_list_path": "1433287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1433287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifcsphigho201Full63240Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPHIGHO2_01_FULL_63_240 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifcsphigho201Full63240Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797552.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797552.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797552.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797552.protein.info.v11.5.txt",
		        "node_list_path": "1797552.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797552.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EntamoebaDispar(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Entamoeba dispar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EntamoebaDispar", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46681.protein.sequences.v11.5.fa",
		        "enrichment_path": "46681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46681.protein.info.v11.5.txt",
		        "node_list_path": "46681.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquamicrobiumAerolatumDsm21857Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquamicrobium aerolatum DSM 21857 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquamicrobiumAerolatumDsm21857Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121003.protein.info.v11.5.txt",
		        "node_list_path": "1121003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasNeptuniumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas neptunium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasNeptuniumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "228405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "228405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "228405.clusters.proteins.v11.5.txt",
		        "sequence_path": "228405.protein.sequences.v11.5.fa",
		        "enrichment_path": "228405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228405.protein.info.v11.5.txt",
		        "node_list_path": "228405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "228405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumChubuense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium chubuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumChubuense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "710421.protein.sequences.v11.5.fa",
		        "enrichment_path": "710421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710421.protein.info.v11.5.txt",
		        "node_list_path": "710421.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumSoleaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum soleae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumSoleaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "447689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "447689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "447689.clusters.proteins.v11.5.txt",
		        "sequence_path": "447689.protein.sequences.v11.5.fa",
		        "enrichment_path": "447689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "447689.protein.info.v11.5.txt",
		        "node_list_path": "447689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "447689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacterium5419Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 54-19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacterium5419Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895928.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895928.protein.info.v11.5.txt",
		        "node_list_path": "1895928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaPneumophilaSubspPascullei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila subsp. pascullei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaPneumophilaSubspPascullei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "91890.protein.sequences.v11.5.fa",
		        "enrichment_path": "91890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91890.protein.info.v11.5.txt",
		        "node_list_path": "91890.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpNfr01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. NFR01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpNfr01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566279.protein.info.v11.5.txt",
		        "node_list_path": "1566279.protein.complete.v11.5.txt"
		    }
		]
    )()

def DiaportheHelianthiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Diaporthe helianthi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiaportheHelianthiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "158607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "158607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "158607.clusters.proteins.v11.5.txt",
		        "sequence_path": "158607.protein.sequences.v11.5.fa",
		        "enrichment_path": "158607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158607.protein.info.v11.5.txt",
		        "node_list_path": "158607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "158607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumA4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium A4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumA4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "397291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "397291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "397291.clusters.proteins.v11.5.txt",
		        "sequence_path": "397291.protein.sequences.v11.5.fa",
		        "enrichment_path": "397291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397291.protein.info.v11.5.txt",
		        "node_list_path": "397291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "397291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MizugakiibacterSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mizugakiibacter sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MizugakiibacterSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1475481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1475481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1475481.clusters.proteins.v11.5.txt",
		        "sequence_path": "1475481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1475481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1475481.protein.info.v11.5.txt",
		        "node_list_path": "1475481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1475481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoriobacteriumGlomerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coriobacterium glomerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacteriumGlomerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "700015.protein.sequences.v11.5.fa",
		        "enrichment_path": "700015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "700015.protein.info.v11.5.txt",
		        "node_list_path": "700015.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumTumefaciensCcnwgs0286Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens CCNWGS0286 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumTumefaciensCcnwgs0286Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1082932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1082932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1082932.clusters.proteins.v11.5.txt",
		        "sequence_path": "1082932.protein.sequences.v11.5.fa",
		        "enrichment_path": "1082932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1082932.protein.info.v11.5.txt",
		        "node_list_path": "1082932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1082932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp7243faa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 7243FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp7243faa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "457396.protein.sequences.v11.5.fa",
		        "enrichment_path": "457396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457396.protein.info.v11.5.txt",
		        "node_list_path": "457396.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusIsoporaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus isoporae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusIsoporaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "591205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "591205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "591205.clusters.proteins.v11.5.txt",
		        "sequence_path": "591205.protein.sequences.v11.5.fa",
		        "enrichment_path": "591205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591205.protein.info.v11.5.txt",
		        "node_list_path": "591205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "591205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumOxalicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium oxalicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumOxalicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69781.clusters.proteins.v11.5.txt",
		        "sequence_path": "69781.protein.sequences.v11.5.fa",
		        "enrichment_path": "69781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69781.protein.info.v11.5.txt",
		        "node_list_path": "69781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusBuchneriCd034Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri CD034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBuchneriCd034Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071400.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071400.protein.info.v11.5.txt",
		        "node_list_path": "1071400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusAntranikianii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus antranikianii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusAntranikianii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123386.protein.info.v11.5.txt",
		        "node_list_path": "1123386.protein.complete.v11.5.txt"
		    }
		]
    )()

def TolypocladiumCapitatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tolypocladium capitatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolypocladiumCapitatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45235.protein.sequences.v11.5.fa",
		        "enrichment_path": "45235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45235.protein.info.v11.5.txt",
		        "node_list_path": "45235.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillatorialesCyanobacteriumCg2304061(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium CG2_30_40_61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillatorialesCyanobacteriumCg2304061", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805291.protein.info.v11.5.txt",
		        "node_list_path": "1805291.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusGottheiliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus gottheilii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGottheiliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "859144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "859144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "859144.clusters.proteins.v11.5.txt",
		        "sequence_path": "859144.protein.sequences.v11.5.fa",
		        "enrichment_path": "859144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "859144.protein.info.v11.5.txt",
		        "node_list_path": "859144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "859144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumCg1024617Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium CG1_02_46_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumCg1024617Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803508.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803508.protein.info.v11.5.txt",
		        "node_list_path": "1803508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HoefleaPhototrophicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hoeflea phototrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoefleaPhototrophicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411684.clusters.proteins.v11.5.txt",
		        "sequence_path": "411684.protein.sequences.v11.5.fa",
		        "enrichment_path": "411684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411684.protein.info.v11.5.txt",
		        "node_list_path": "411684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrococcusTerreus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micrococcus terreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcusTerreus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "574650.protein.sequences.v11.5.fa",
		        "enrichment_path": "574650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574650.protein.info.v11.5.txt",
		        "node_list_path": "574650.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParageobacillusThermantarcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parageobacillus thermantarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParageobacillusThermantarcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "186116.clusters.info.v11.5.txt",
		        "cluster_tree_path": "186116.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "186116.clusters.proteins.v11.5.txt",
		        "sequence_path": "186116.protein.sequences.v11.5.fa",
		        "enrichment_path": "186116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "186116.protein.info.v11.5.txt",
		        "node_list_path": "186116.cluster.nodes.v11.5.txt",
		        "edge_list_path": "186116.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeminorellaGrimontiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leminorella grimontii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeminorellaGrimontiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005999.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005999.protein.info.v11.5.txt",
		        "node_list_path": "1005999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumHigginsianumImi349063Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum higginsianum IMI 349063 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumHigginsianumImi349063Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "759273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "759273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "759273.clusters.proteins.v11.5.txt",
		        "sequence_path": "759273.protein.sequences.v11.5.fa",
		        "enrichment_path": "759273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759273.protein.info.v11.5.txt",
		        "node_list_path": "759273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "759273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaViridescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella viridescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaViridescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629.protein.info.v11.5.txt",
		        "node_list_path": "1629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpJce(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJce", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461580.protein.info.v11.5.txt",
		        "node_list_path": "1461580.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrobaculumSp1860Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum sp. 1860 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumSp1860Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1104324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1104324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1104324.clusters.proteins.v11.5.txt",
		        "sequence_path": "1104324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104324.protein.info.v11.5.txt",
		        "node_list_path": "1104324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1104324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumTyrobutyricumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tyrobutyricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTyrobutyricumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121342.protein.info.v11.5.txt",
		        "node_list_path": "1121342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusTuaregiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus tuaregi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusTuaregiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816681.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816681.protein.info.v11.5.txt",
		        "node_list_path": "1816681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisNigoniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis nigoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisNigoniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1611254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1611254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1611254.clusters.proteins.v11.5.txt",
		        "sequence_path": "1611254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1611254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1611254.protein.info.v11.5.txt",
		        "node_list_path": "1611254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1611254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaMontpellierensisDsm17217(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella montpellierensis DSM 17217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaMontpellierensisDsm17217", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123490.protein.info.v11.5.txt",
		        "node_list_path": "1123490.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteroidesSalmoniphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacteroides salmoniphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteroidesSalmoniphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "404941.protein.sequences.v11.5.fa",
		        "enrichment_path": "404941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "404941.protein.info.v11.5.txt",
		        "node_list_path": "404941.protein.complete.v11.5.txt"
		    }
		]
    )()

def VirgibacillusSpSk37(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus sp. SK37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusSpSk37", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "403957.protein.sequences.v11.5.fa",
		        "enrichment_path": "403957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "403957.protein.info.v11.5.txt",
		        "node_list_path": "403957.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3712Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_37_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3712Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802056.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802056.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802056.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802056.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802056.protein.info.v11.5.txt",
		        "node_list_path": "1802056.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802056.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaStercorea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella stercorea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaStercorea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1002367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002367.protein.info.v11.5.txt",
		        "node_list_path": "1002367.protein.complete.v11.5.txt"
		    }
		]
    )()

def EucalyptusGrandisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eucalyptus grandis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EucalyptusGrandisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "71139.clusters.info.v11.5.txt",
		        "cluster_tree_path": "71139.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "71139.clusters.proteins.v11.5.txt",
		        "sequence_path": "71139.protein.sequences.v11.5.fa",
		        "enrichment_path": "71139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "71139.protein.info.v11.5.txt",
		        "node_list_path": "71139.cluster.nodes.v11.5.txt",
		        "edge_list_path": "71139.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HericiumAlpestreCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hericium alpestre Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HericiumAlpestreCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "135208.clusters.info.v11.5.txt",
		        "cluster_tree_path": "135208.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "135208.clusters.proteins.v11.5.txt",
		        "sequence_path": "135208.protein.sequences.v11.5.fa",
		        "enrichment_path": "135208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "135208.protein.info.v11.5.txt",
		        "node_list_path": "135208.cluster.nodes.v11.5.txt",
		        "edge_list_path": "135208.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaSpF0087Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0087 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaSpF0087Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "706436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "706436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "706436.clusters.proteins.v11.5.txt",
		        "sequence_path": "706436.protein.sequences.v11.5.fa",
		        "enrichment_path": "706436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706436.protein.info.v11.5.txt",
		        "node_list_path": "706436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "706436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureimonasJatrophaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas jatrophae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasJatrophaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1166073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1166073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1166073.clusters.proteins.v11.5.txt",
		        "sequence_path": "1166073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166073.protein.info.v11.5.txt",
		        "node_list_path": "1166073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1166073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaPaucivoransNbrc100373Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia paucivorans NBRC 100373 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaPaucivoransNbrc100373Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206734.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206734.protein.info.v11.5.txt",
		        "node_list_path": "1206734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpSm22m07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. SM22M-07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpSm22m07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520813.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520813.protein.info.v11.5.txt",
		        "node_list_path": "1520813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumFlavescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumFlavescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28028.clusters.proteins.v11.5.txt",
		        "sequence_path": "28028.protein.sequences.v11.5.fa",
		        "enrichment_path": "28028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28028.protein.info.v11.5.txt",
		        "node_list_path": "28028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopirellulaEuropaeaSh398Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopirellula europaea SH398 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopirellulaEuropaeaSh398Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263868.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263868.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263868.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263868.protein.info.v11.5.txt",
		        "node_list_path": "1263868.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263868.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaHolmesiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella holmesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaHolmesiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1247649.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1247649.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1247649.clusters.proteins.v11.5.txt",
		        "sequence_path": "1247649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1247649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1247649.protein.info.v11.5.txt",
		        "node_list_path": "1247649.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1247649.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhlebiaCentrifuga(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phlebia centrifuga graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhlebiaCentrifuga", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "98765.protein.sequences.v11.5.fa",
		        "enrichment_path": "98765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "98765.protein.info.v11.5.txt",
		        "node_list_path": "98765.protein.complete.v11.5.txt"
		    }
		]
    )()

def YuhushiellaDeserti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yuhushiella deserti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YuhushiellaDeserti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "587909.protein.sequences.v11.5.fa",
		        "enrichment_path": "587909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "587909.protein.info.v11.5.txt",
		        "node_list_path": "587909.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasSpAe122Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas sp. AE122 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSpAe122Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "558884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "558884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "558884.clusters.proteins.v11.5.txt",
		        "sequence_path": "558884.protein.sequences.v11.5.fa",
		        "enrichment_path": "558884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558884.protein.info.v11.5.txt",
		        "node_list_path": "558884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "558884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PichiaKudriavzevii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pichia kudriavzevii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PichiaKudriavzevii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4909.protein.sequences.v11.5.fa",
		        "enrichment_path": "4909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4909.protein.info.v11.5.txt",
		        "node_list_path": "4909.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaMonocytogenesScott(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria monocytogenes Scott graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaMonocytogenesScott", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1027396.protein.sequences.v11.5.fa",
		        "enrichment_path": "1027396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1027396.protein.info.v11.5.txt",
		        "node_list_path": "1027396.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaSp2HT1a6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina sp. 2.H.T.1A.6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaSp2HT1a6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1483599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1483599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1483599.clusters.proteins.v11.5.txt",
		        "sequence_path": "1483599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1483599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1483599.protein.info.v11.5.txt",
		        "node_list_path": "1483599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1483599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnohabitansPlanktonicusIiD5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans planktonicus II-D5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansPlanktonicusIiD5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293045.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293045.protein.info.v11.5.txt",
		        "node_list_path": "1293045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4648(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4648 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4648", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977875.protein.info.v11.5.txt",
		        "node_list_path": "1977875.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylopilaSpM107Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylopila sp. M107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylopilaSpM107Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1101190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1101190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1101190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1101190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101190.protein.info.v11.5.txt",
		        "node_list_path": "1101190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1101190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumGenospCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium genosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumGenospCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936455.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936455.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936455.clusters.proteins.v11.5.txt",
		        "sequence_path": "936455.protein.sequences.v11.5.fa",
		        "enrichment_path": "936455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936455.protein.info.v11.5.txt",
		        "node_list_path": "936455.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936455.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp3211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp3211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1964449.protein.sequences.v11.5.fa",
		        "enrichment_path": "1964449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1964449.protein.info.v11.5.txt",
		        "node_list_path": "1964449.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSordellii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sordellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSordellii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1292035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292035.protein.info.v11.5.txt",
		        "node_list_path": "1292035.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpLeaf359(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Leaf359 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpLeaf359", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736351.protein.info.v11.5.txt",
		        "node_list_path": "1736351.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterCetorumMit995656(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cetorum MIT995656 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterCetorumMit995656", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163745.protein.info.v11.5.txt",
		        "node_list_path": "1163745.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumImcc26207Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium IMCC26207 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumImcc26207Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1641811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1641811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1641811.clusters.proteins.v11.5.txt",
		        "sequence_path": "1641811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1641811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1641811.protein.info.v11.5.txt",
		        "node_list_path": "1641811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1641811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifoxyd1Full4714(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFOXYD1_FULL_47_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifoxyd1Full4714", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798533.protein.info.v11.5.txt",
		        "node_list_path": "1798533.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumVacciniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium vaccinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumVacciniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1108595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1108595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1108595.clusters.proteins.v11.5.txt",
		        "sequence_path": "1108595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1108595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1108595.protein.info.v11.5.txt",
		        "node_list_path": "1108595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1108595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeronosporaEffusa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peronospora effusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeronosporaEffusa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "542832.protein.sequences.v11.5.fa",
		        "enrichment_path": "542832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "542832.protein.info.v11.5.txt",
		        "node_list_path": "542832.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalinemaSpCaciam70d(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalinema sp. CACIAM 70d graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalinemaSpCaciam70d", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1934309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934309.protein.info.v11.5.txt",
		        "node_list_path": "1934309.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumMt11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium mt11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumMt11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1686289.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686289.protein.info.v11.5.txt",
		        "node_list_path": "1686289.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBeckwithbacteriaBacteriumRifcsphigho212Full4717(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium RIFCSPHIGHO2_12_FULL_47_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumRifcsphigho212Full4717", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797460.protein.info.v11.5.txt",
		        "node_list_path": "1797460.protein.complete.v11.5.txt"
		    }
		]
    )()

def SuccinivibrionaceaeBacteriumWg1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Succinivibrionaceae bacterium WG-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuccinivibrionaceaeBacteriumWg1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "758828.clusters.info.v11.5.txt",
		        "cluster_tree_path": "758828.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "758828.clusters.proteins.v11.5.txt",
		        "sequence_path": "758828.protein.sequences.v11.5.fa",
		        "enrichment_path": "758828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758828.protein.info.v11.5.txt",
		        "node_list_path": "758828.cluster.nodes.v11.5.txt",
		        "edge_list_path": "758828.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusKwashiorkori(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus kwashiorkori graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusKwashiorkori", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1522318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522318.protein.info.v11.5.txt",
		        "node_list_path": "1522318.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumNitrogenifigensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium nitrogenifigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumNitrogenifigensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983920.clusters.proteins.v11.5.txt",
		        "sequence_path": "983920.protein.sequences.v11.5.fa",
		        "enrichment_path": "983920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983920.protein.info.v11.5.txt",
		        "node_list_path": "983920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ScleropagesFormosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scleropages formosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScleropagesFormosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "113540.protein.sequences.v11.5.fa",
		        "enrichment_path": "113540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113540.protein.info.v11.5.txt",
		        "node_list_path": "113540.protein.complete.v11.5.txt"
		    }
		]
    )()

def BeduiniMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Beduini massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeduiniMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1585974.protein.sequences.v11.5.fa",
		        "enrichment_path": "1585974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1585974.protein.info.v11.5.txt",
		        "node_list_path": "1585974.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpJa23baCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. JA23Ba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpJa23baCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "321332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "321332.clusters.proteins.v11.5.txt",
		        "sequence_path": "321332.protein.sequences.v11.5.fa",
		        "enrichment_path": "321332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321332.protein.info.v11.5.txt",
		        "node_list_path": "321332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "321332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpSoil777Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil777 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpSoil777Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736409.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736409.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736409.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736409.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736409.protein.info.v11.5.txt",
		        "node_list_path": "1736409.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736409.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfatatorIndicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfatator indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfatatorIndicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "667014.protein.sequences.v11.5.fa",
		        "enrichment_path": "667014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667014.protein.info.v11.5.txt",
		        "node_list_path": "667014.protein.complete.v11.5.txt"
		    }
		]
    )()

def RheinheimeraSpA13lCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera sp. A13L Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraSpA13lCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "506534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "506534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "506534.clusters.proteins.v11.5.txt",
		        "sequence_path": "506534.protein.sequences.v11.5.fa",
		        "enrichment_path": "506534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "506534.protein.info.v11.5.txt",
		        "node_list_path": "506534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "506534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusMurrayiDsm11303(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus murrayi DSM 11303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusMurrayiDsm11303", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121383.protein.info.v11.5.txt",
		        "node_list_path": "1121383.protein.complete.v11.5.txt"
		    }
		]
    )()

def HeterosteliumAlbumPn500Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Heterostelium album PN500 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeterosteliumAlbumPn500Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "670386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "670386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "670386.clusters.proteins.v11.5.txt",
		        "sequence_path": "670386.protein.sequences.v11.5.fa",
		        "enrichment_path": "670386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670386.protein.info.v11.5.txt",
		        "node_list_path": "670386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "670386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichosporonAsahiiVarAsahiiCbs8904(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichosporon asahii var. asahii CBS 8904 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichosporonAsahiiVarAsahiiCbs8904", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220162.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220162.protein.info.v11.5.txt",
		        "node_list_path": "1220162.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastomonasSpCacia14h2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastomonas sp. CACIA14H2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomonasSpCacia14h2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1419876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1419876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1419876.clusters.proteins.v11.5.txt",
		        "sequence_path": "1419876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1419876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1419876.protein.info.v11.5.txt",
		        "node_list_path": "1419876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1419876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaRodasiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea rodasii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaRodasiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1076549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1076549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1076549.clusters.proteins.v11.5.txt",
		        "sequence_path": "1076549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076549.protein.info.v11.5.txt",
		        "node_list_path": "1076549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1076549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeropyrumCaminiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeropyrum camini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeropyrumCaminiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1198449.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1198449.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1198449.clusters.proteins.v11.5.txt",
		        "sequence_path": "1198449.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198449.protein.info.v11.5.txt",
		        "node_list_path": "1198449.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1198449.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseobacterSpCcs2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. CCS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterSpCcs2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391593.clusters.proteins.v11.5.txt",
		        "sequence_path": "391593.protein.sequences.v11.5.fa",
		        "enrichment_path": "391593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391593.protein.info.v11.5.txt",
		        "node_list_path": "391593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaGlebaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia glebae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaGlebaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777143.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777143.protein.info.v11.5.txt",
		        "node_list_path": "1777143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumYanoikuyaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium yanoikuyae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumYanoikuyaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13690.clusters.proteins.v11.5.txt",
		        "sequence_path": "13690.protein.sequences.v11.5.fa",
		        "enrichment_path": "13690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13690.protein.info.v11.5.txt",
		        "node_list_path": "13690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRaac2Wwe31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RAAC2_WWE3_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRaac2Wwe31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1394710.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394710.protein.info.v11.5.txt",
		        "node_list_path": "1394710.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesRoseoverticillatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces roseoverticillatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRoseoverticillatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66429.clusters.proteins.v11.5.txt",
		        "sequence_path": "66429.protein.sequences.v11.5.fa",
		        "enrichment_path": "66429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66429.protein.info.v11.5.txt",
		        "node_list_path": "66429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfonatronumThiodismutansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronum thiodismutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronumThiodismutansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "159290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "159290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "159290.clusters.proteins.v11.5.txt",
		        "sequence_path": "159290.protein.sequences.v11.5.fa",
		        "enrichment_path": "159290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "159290.protein.info.v11.5.txt",
		        "node_list_path": "159290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "159290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumGb30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum GB30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumGb30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041142.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1041142.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1041142.clusters.proteins.v11.0.txt",
		        "sequence_path": "1041142.protein.sequences.v11.0.fa",
		        "enrichment_path": "1041142.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1041142.protein.info.v11.0.txt",
		        "node_list_path": "1041142.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1041142.protein.cluster.v11.0.txt"
		    }
		]
    )()

def AureimonasSpAu20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpAu20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349819.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349819.protein.info.v11.5.txt",
		        "node_list_path": "1349819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsbolusVerrucosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asbolus verrucosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsbolusVerrucosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1661398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661398.protein.info.v11.5.txt",
		        "node_list_path": "1661398.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSp6614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. 66-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSp6614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895752.protein.info.v11.5.txt",
		        "node_list_path": "1895752.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumDaejeonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium daejeonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumDaejeonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121887.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121887.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121887.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121887.protein.info.v11.5.txt",
		        "node_list_path": "1121887.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121887.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillatorialesCyanobacteriumCg2304421Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium CG2_30_44_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillatorialesCyanobacteriumCg2304421Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805292.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805292.protein.info.v11.5.txt",
		        "node_list_path": "1805292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HesseltinellaVesiculosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hesseltinella vesiculosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HesseltinellaVesiculosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "101127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "101127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "101127.clusters.proteins.v11.5.txt",
		        "sequence_path": "101127.protein.sequences.v11.5.fa",
		        "enrichment_path": "101127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101127.protein.info.v11.5.txt",
		        "node_list_path": "101127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "101127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlebsiellaAerogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella aerogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaAerogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "548.protein.sequences.v11.5.fa",
		        "enrichment_path": "548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "548.protein.info.v11.5.txt",
		        "node_list_path": "548.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasHaloplanktisAtcc14393(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis ATCC14393 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasHaloplanktisAtcc14393", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117315.protein.info.v11.5.txt",
		        "node_list_path": "1117315.protein.complete.v11.5.txt"
		    }
		]
    )()

def DermacoccusSpPe3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dermacoccus sp. PE3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DermacoccusSpPe3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1641401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1641401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1641401.protein.info.v11.5.txt",
		        "node_list_path": "1641401.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumNeoaurum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium neoaurum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumNeoaurum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795.protein.info.v11.5.txt",
		        "node_list_path": "1795.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiaceaeBacteriumSg6c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobiaceae bacterium SG6C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiaceaeBacteriumSg6c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "709797.protein.sequences.v11.5.fa",
		        "enrichment_path": "709797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709797.protein.info.v11.5.txt",
		        "node_list_path": "709797.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosopumilusSpNsubCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. Nsub Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopumilusSpNsubCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776294.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776294.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776294.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776294.protein.info.v11.5.txt",
		        "node_list_path": "1776294.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776294.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterAfricanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter africanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterAfricanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "151894.protein.sequences.v11.5.fa",
		        "enrichment_path": "151894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "151894.protein.info.v11.5.txt",
		        "node_list_path": "151894.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPhoceenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium phoceense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPhoceenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1686286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1686286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1686286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1686286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686286.protein.info.v11.5.txt",
		        "node_list_path": "1686286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1686286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaLeachiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma leachii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaLeachiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "880447.clusters.info.v11.5.txt",
		        "cluster_tree_path": "880447.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "880447.clusters.proteins.v11.5.txt",
		        "sequence_path": "880447.protein.sequences.v11.5.fa",
		        "enrichment_path": "880447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880447.protein.info.v11.5.txt",
		        "node_list_path": "880447.cluster.nodes.v11.5.txt",
		        "edge_list_path": "880447.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpF0426Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0426 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpF0426Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321786.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321786.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321786.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321786.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321786.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321786.protein.info.v11.5.txt",
		        "node_list_path": "1321786.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321786.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCitroniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium citroniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCitroniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742733.clusters.proteins.v11.5.txt",
		        "sequence_path": "742733.protein.sequences.v11.5.fa",
		        "enrichment_path": "742733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742733.protein.info.v11.5.txt",
		        "node_list_path": "742733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4518Fw2643(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4518 (FW-2643) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4518Fw2643", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420913.protein.info.v11.5.txt",
		        "node_list_path": "1420913.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpUrhd0025(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. URHD0025 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpUrhd0025", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298864.protein.info.v11.5.txt",
		        "node_list_path": "1298864.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpJm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. JM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpJm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1233950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1233950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1233950.protein.info.v11.5.txt",
		        "node_list_path": "1233950.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwf23876Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWF2_38_76 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwf23876Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618960.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618960.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618960.protein.info.v11.5.txt",
		        "node_list_path": "1618960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp22311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2231.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp22311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855347.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855347.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855347.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855347.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855347.protein.info.v11.5.txt",
		        "node_list_path": "1855347.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855347.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1205683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1205683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1205683.clusters.proteins.v11.5.txt",
		        "sequence_path": "1205683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1205683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1205683.protein.info.v11.5.txt",
		        "node_list_path": "1205683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1205683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAceticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium aceticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAceticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84022.protein.sequences.v11.5.fa",
		        "enrichment_path": "84022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84022.protein.info.v11.5.txt",
		        "node_list_path": "84022.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesGallinarumDsm18171Jcm13658Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides gallinarum DSM 18171 JCM 13658 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesGallinarumDsm18171Jcm13658Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121096.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121096.protein.info.v11.5.txt",
		        "node_list_path": "1121096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerriglobusRoseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terriglobus roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerriglobusRoseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926566.protein.sequences.v11.5.fa",
		        "enrichment_path": "926566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926566.protein.info.v11.5.txt",
		        "node_list_path": "926566.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpTdk1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. TDK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpTdk1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "453247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "453247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "453247.clusters.proteins.v11.5.txt",
		        "sequence_path": "453247.protein.sequences.v11.5.fa",
		        "enrichment_path": "453247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "453247.protein.info.v11.5.txt",
		        "node_list_path": "453247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "453247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasTaxiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas taxi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasTaxiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1549858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1549858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1549858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1549858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1549858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1549858.protein.info.v11.5.txt",
		        "node_list_path": "1549858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1549858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag253Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:253 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag253Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262785.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262785.protein.info.v11.5.txt",
		        "node_list_path": "1262785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonasSpAlt199Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. ALT199 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasSpAlt199Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298865.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298865.protein.info.v11.5.txt",
		        "node_list_path": "1298865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnabaenaCylindricaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anabaena cylindrica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabaenaCylindricaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272123.clusters.proteins.v11.5.txt",
		        "sequence_path": "272123.protein.sequences.v11.5.fa",
		        "enrichment_path": "272123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272123.protein.info.v11.5.txt",
		        "node_list_path": "272123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaJaponicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaJaponicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93973.clusters.proteins.v11.5.txt",
		        "sequence_path": "93973.protein.sequences.v11.5.fa",
		        "enrichment_path": "93973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93973.protein.info.v11.5.txt",
		        "node_list_path": "93973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPolymyxaM1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPolymyxaM1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1052684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1052684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1052684.clusters.proteins.v11.5.txt",
		        "sequence_path": "1052684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1052684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1052684.protein.info.v11.5.txt",
		        "node_list_path": "1052684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1052684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhascolarctobacteriumSpCag207Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phascolarctobacterium sp. CAG207 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhascolarctobacteriumSpCag207Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262914.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262914.protein.info.v11.5.txt",
		        "node_list_path": "1262914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAlcaligenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alcaligenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAlcaligenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43263.protein.sequences.v11.5.fa",
		        "enrichment_path": "43263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43263.protein.info.v11.5.txt",
		        "node_list_path": "43263.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusAnaerobius653lCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius 653L Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusAnaerobius653lCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596329.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596329.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596329.clusters.proteins.v11.5.txt",
		        "sequence_path": "596329.protein.sequences.v11.5.fa",
		        "enrichment_path": "596329.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596329.protein.info.v11.5.txt",
		        "node_list_path": "596329.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596329.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloprofundusSedimentiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloprofundus sedimenti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloprofundusSedimentiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420851.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420851.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420851.protein.info.v11.5.txt",
		        "node_list_path": "1420851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpMc2021(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MC2021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpMc2021", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408306.protein.info.v11.5.txt",
		        "node_list_path": "1408306.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSegetisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium segetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSegetisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "271157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "271157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "271157.clusters.proteins.v11.5.txt",
		        "sequence_path": "271157.protein.sequences.v11.5.fa",
		        "enrichment_path": "271157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "271157.protein.info.v11.5.txt",
		        "node_list_path": "271157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "271157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAle31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAle31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158182.protein.info.v11.5.txt",
		        "node_list_path": "1158182.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumOxalicum1142(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium oxalicum 114-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumOxalicum1142", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "933388.protein.sequences.v11.5.fa",
		        "enrichment_path": "933388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933388.protein.info.v11.5.txt",
		        "node_list_path": "933388.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosphaeraSpWgk6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosphaera sp. WGK6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosphaeraSpWgk6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1561964.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561964.protein.info.v11.5.txt",
		        "node_list_path": "1561964.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaFlavaNbrc102514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga flava NBRC 102514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaFlavaNbrc102514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349752.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349752.protein.info.v11.5.txt",
		        "node_list_path": "1349752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusParaphrohaemolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus paraphrohaemolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusParaphrohaemolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095743.protein.info.v11.5.txt",
		        "node_list_path": "1095743.protein.complete.v11.5.txt"
		    }
		]
    )()

def TilletiaWalkeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tilletia walkeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TilletiaWalkeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "117179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "117179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "117179.clusters.proteins.v11.5.txt",
		        "sequence_path": "117179.protein.sequences.v11.5.fa",
		        "enrichment_path": "117179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "117179.protein.info.v11.5.txt",
		        "node_list_path": "117179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "117179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrypanosomaCruzi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma cruzi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrypanosomaCruzi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5693.protein.sequences.v11.5.fa",
		        "enrichment_path": "5693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5693.protein.info.v11.5.txt",
		        "node_list_path": "5693.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesFinegoldiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes finegoldii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesFinegoldiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679935.clusters.proteins.v11.5.txt",
		        "sequence_path": "679935.protein.sequences.v11.5.fa",
		        "enrichment_path": "679935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679935.protein.info.v11.5.txt",
		        "node_list_path": "679935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaSpMd27(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. MD27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSpMd27", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1676617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676617.protein.info.v11.5.txt",
		        "node_list_path": "1676617.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumLipolyticumDsm21995(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum lipolyticum DSM 21995 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumLipolyticumDsm21995", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227482.protein.info.v11.5.txt",
		        "node_list_path": "1227482.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusRhizosphaerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusRhizosphaerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "297318.protein.sequences.v11.5.fa",
		        "enrichment_path": "297318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "297318.protein.info.v11.5.txt",
		        "node_list_path": "297318.protein.complete.v11.5.txt"
		    }
		]
    )()

def EchinopsTelfairiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Echinops telfairi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EchinopsTelfairiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9371.clusters.proteins.v11.5.txt",
		        "sequence_path": "9371.protein.sequences.v11.5.fa",
		        "enrichment_path": "9371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9371.protein.info.v11.5.txt",
		        "node_list_path": "9371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsplowo201Full5916(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_59_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full5916", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802280.protein.info.v11.5.txt",
		        "node_list_path": "1802280.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeisingeraSpJc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leisingera sp. JC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraSpJc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855282.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855282.protein.info.v11.5.txt",
		        "node_list_path": "1855282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasDiversa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas diversa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasDiversa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1268237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268237.protein.info.v11.5.txt",
		        "node_list_path": "1268237.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanobacillusOncorhynchi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus oncorhynchi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusOncorhynchi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "545501.protein.sequences.v11.5.fa",
		        "enrichment_path": "545501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545501.protein.info.v11.5.txt",
		        "node_list_path": "545501.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpQa3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. QA3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpQa3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "710111.clusters.info.v11.5.txt",
		        "cluster_tree_path": "710111.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "710111.clusters.proteins.v11.5.txt",
		        "sequence_path": "710111.protein.sequences.v11.5.fa",
		        "enrichment_path": "710111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710111.protein.info.v11.5.txt",
		        "node_list_path": "710111.cluster.nodes.v11.5.txt",
		        "edge_list_path": "710111.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumCucumis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium cucumis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumCucumis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "416016.protein.sequences.v11.5.fa",
		        "enrichment_path": "416016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416016.protein.info.v11.5.txt",
		        "node_list_path": "416016.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTuberculosisH37ra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis H37Ra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTuberculosisH37ra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "419947.protein.sequences.v11.5.fa",
		        "enrichment_path": "419947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419947.protein.info.v11.5.txt",
		        "node_list_path": "419947.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacterium13140cm6927(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_1_40CM_69_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacterium13140cm6927", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805367.protein.info.v11.5.txt",
		        "node_list_path": "1805367.protein.complete.v11.5.txt"
		    }
		]
    )()

def AngiostrongylusCostaricensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Angiostrongylus costaricensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AngiostrongylusCostaricensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "334426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "334426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "334426.clusters.proteins.v11.5.txt",
		        "sequence_path": "334426.protein.sequences.v11.5.fa",
		        "enrichment_path": "334426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334426.protein.info.v11.5.txt",
		        "node_list_path": "334426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "334426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumCg2303729Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium CG2_30_37_29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumCg2303729Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805237.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805237.protein.info.v11.5.txt",
		        "node_list_path": "1805237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpEdens01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Edens01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpEdens01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1732020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1732020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1732020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1732020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1732020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1732020.protein.info.v11.5.txt",
		        "node_list_path": "1732020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1732020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4311bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_43_11b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4311bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798392.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798392.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798392.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798392.protein.info.v11.5.txt",
		        "node_list_path": "1798392.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798392.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusZeaxanthinifaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus zeaxanthinifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusZeaxanthinifaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1266998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266998.protein.info.v11.5.txt",
		        "node_list_path": "1266998.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterAcetiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter aceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterAcetiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "435.clusters.info.v11.5.txt",
		        "cluster_tree_path": "435.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "435.clusters.proteins.v11.5.txt",
		        "sequence_path": "435.protein.sequences.v11.5.fa",
		        "enrichment_path": "435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435.protein.info.v11.5.txt",
		        "node_list_path": "435.cluster.nodes.v11.5.txt",
		        "edge_list_path": "435.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HistoplasmaCapsulatumH143Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum H143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HistoplasmaCapsulatumH143Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "544712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "544712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "544712.clusters.proteins.v11.5.txt",
		        "sequence_path": "544712.protein.sequences.v11.5.fa",
		        "enrichment_path": "544712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "544712.protein.info.v11.5.txt",
		        "node_list_path": "544712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "544712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSimplexCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus simplex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSimplexCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1403313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1403313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1403313.clusters.proteins.v11.5.txt",
		        "sequence_path": "1403313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403313.protein.info.v11.5.txt",
		        "node_list_path": "1403313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1403313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GluconacetobacterDiazotrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gluconacetobacter diazotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconacetobacterDiazotrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272568.protein.sequences.v11.5.fa",
		        "enrichment_path": "272568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272568.protein.info.v11.5.txt",
		        "node_list_path": "272568.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterNitratireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterNitratireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1137280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137280.protein.info.v11.5.txt",
		        "node_list_path": "1137280.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpH5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpH5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267973.protein.info.v11.5.txt",
		        "node_list_path": "1267973.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioRumoiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio rumoiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioRumoiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1188252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188252.protein.info.v11.5.txt",
		        "node_list_path": "1188252.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgromycesSpRoot81Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agromyces sp. Root81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesSpRoot81Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736601.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736601.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736601.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736601.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736601.protein.info.v11.5.txt",
		        "node_list_path": "1736601.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736601.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusActinosclerusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus actinosclerus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusActinosclerusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1768108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1768108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1768108.clusters.proteins.v11.5.txt",
		        "sequence_path": "1768108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768108.protein.info.v11.5.txt",
		        "node_list_path": "1768108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1768108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumMultihospitiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium multihospitium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumMultihospitiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "410764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "410764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "410764.clusters.proteins.v11.5.txt",
		        "sequence_path": "410764.protein.sequences.v11.5.fa",
		        "enrichment_path": "410764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "410764.protein.info.v11.5.txt",
		        "node_list_path": "410764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "410764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterDefluvii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter defluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterDefluvii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871111.protein.info.v11.5.txt",
		        "node_list_path": "1871111.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSp2136faa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. 2136FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSp2136faa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469609.protein.sequences.v11.5.fa",
		        "enrichment_path": "469609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469609.protein.info.v11.5.txt",
		        "node_list_path": "469609.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSpFjat14222(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. FJAT-14222 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSpFjat14222", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1932366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1932366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1932366.protein.info.v11.5.txt",
		        "node_list_path": "1932366.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronomonasMoolapensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronomonas moolapensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronomonasMoolapensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "268739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "268739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "268739.clusters.proteins.v11.5.txt",
		        "sequence_path": "268739.protein.sequences.v11.5.fa",
		        "enrichment_path": "268739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "268739.protein.info.v11.5.txt",
		        "node_list_path": "268739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "268739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlossinaFuscipesFuscipes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glossina fuscipes fuscipes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlossinaFuscipesFuscipes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "201502.protein.sequences.v11.5.fa",
		        "enrichment_path": "201502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "201502.protein.info.v11.5.txt",
		        "node_list_path": "201502.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaCarnea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia carnea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaCarnea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206726.protein.info.v11.5.txt",
		        "node_list_path": "1206726.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusParaplantarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paraplantarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParaplantarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "60520.clusters.info.v11.5.txt",
		        "cluster_tree_path": "60520.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "60520.clusters.proteins.v11.5.txt",
		        "sequence_path": "60520.protein.sequences.v11.5.fa",
		        "enrichment_path": "60520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60520.protein.info.v11.5.txt",
		        "node_list_path": "60520.cluster.nodes.v11.5.txt",
		        "edge_list_path": "60520.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaloramatorQuimbayensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caloramator quimbayensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloramatorQuimbayensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1147123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1147123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1147123.clusters.proteins.v11.5.txt",
		        "sequence_path": "1147123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1147123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1147123.protein.info.v11.5.txt",
		        "node_list_path": "1147123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1147123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonB24Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB24Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1779368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1779368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1779368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1779368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1779368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1779368.protein.info.v11.5.txt",
		        "node_list_path": "1779368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1779368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivivaxLentus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax lentus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxLentus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "633194.protein.sequences.v11.5.fa",
		        "enrichment_path": "633194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633194.protein.info.v11.5.txt",
		        "node_list_path": "633194.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemetriaTerragenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demetria terragena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemetriaTerragenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121385.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121385.protein.info.v11.5.txt",
		        "node_list_path": "1121385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IntestinibacterBartlettii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Intestinibacter bartlettii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntestinibacterBartlettii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445973.protein.sequences.v11.5.fa",
		        "enrichment_path": "445973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445973.protein.info.v11.5.txt",
		        "node_list_path": "445973.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterNitrogenifigens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter nitrogenifigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterNitrogenifigens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120919.protein.info.v11.5.txt",
		        "node_list_path": "1120919.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrinemaSalaciae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrinema salaciae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrinemaSalaciae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1186196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1186196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1186196.protein.info.v11.5.txt",
		        "node_list_path": "1186196.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraMoscoviensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira moscoviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraMoscoviensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42253.protein.sequences.v11.5.fa",
		        "enrichment_path": "42253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42253.protein.info.v11.5.txt",
		        "node_list_path": "42253.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229783.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229783.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229783.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229783.protein.info.v11.5.txt",
		        "node_list_path": "1229783.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229783.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeonGw2011Ar15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return archaeon GW2011_AR15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeonGw2011Ar15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1579373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579373.protein.info.v11.5.txt",
		        "node_list_path": "1579373.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonadaceaeBacteriumH1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonadaceaeBacteriumH1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658779.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658779.protein.info.v11.5.txt",
		        "node_list_path": "1658779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpQhl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. QHL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpQhl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123773.protein.info.v11.5.txt",
		        "node_list_path": "1123773.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisTropicalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis tropicalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisTropicalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1561998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1561998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1561998.clusters.proteins.v11.5.txt",
		        "sequence_path": "1561998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561998.protein.info.v11.5.txt",
		        "node_list_path": "1561998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1561998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhycicoccusSpSoil803Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Soil803 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycicoccusSpSoil803Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736415.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736415.protein.info.v11.5.txt",
		        "node_list_path": "1736415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermosulfurimonasDismutansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosulfurimonas dismutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosulfurimonasDismutansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999894.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999894.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999894.clusters.proteins.v11.5.txt",
		        "sequence_path": "999894.protein.sequences.v11.5.fa",
		        "enrichment_path": "999894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999894.protein.info.v11.5.txt",
		        "node_list_path": "999894.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999894.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanolobusPsychrophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus psychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolobusPsychrophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094980.protein.info.v11.5.txt",
		        "node_list_path": "1094980.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusVestibularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus vestibularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusVestibularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "904306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "904306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "904306.clusters.proteins.v11.5.txt",
		        "sequence_path": "904306.protein.sequences.v11.5.fa",
		        "enrichment_path": "904306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904306.protein.info.v11.5.txt",
		        "node_list_path": "904306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "904306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaHisticolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella histicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaHisticolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236504.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236504.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236504.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236504.protein.info.v11.5.txt",
		        "node_list_path": "1236504.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236504.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaSpF0422(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. F0422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaSpF0422", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "944564.protein.sequences.v11.5.fa",
		        "enrichment_path": "944564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944564.protein.info.v11.5.txt",
		        "node_list_path": "944564.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFulva(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fulva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFulva", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743720.protein.sequences.v11.5.fa",
		        "enrichment_path": "743720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743720.protein.info.v11.5.txt",
		        "node_list_path": "743720.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraKmetyiSerovarMalaysiaStrBejoIso9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira kmetyi serovar Malaysia str. Bejo-Iso9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraKmetyiSerovarMalaysiaStrBejoIso9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1049970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1049970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1049970.protein.info.v11.5.txt",
		        "node_list_path": "1049970.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumEuropaeum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium europaeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumEuropaeum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "761804.protein.sequences.v11.5.fa",
		        "enrichment_path": "761804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "761804.protein.info.v11.5.txt",
		        "node_list_path": "761804.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnsiferSpBr816Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. BR816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferSpBr816Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1057002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1057002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1057002.clusters.proteins.v11.5.txt",
		        "sequence_path": "1057002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1057002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1057002.protein.info.v11.5.txt",
		        "node_list_path": "1057002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1057002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasAxonopodisPhaseoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis phaseoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasAxonopodisPhaseoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "317013.protein.sequences.v11.5.fa",
		        "enrichment_path": "317013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317013.protein.info.v11.5.txt",
		        "node_list_path": "317013.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpBm10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. BM10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpBm10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1529069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1529069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1529069.protein.info.v11.5.txt",
		        "node_list_path": "1529069.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetaSpEbm43Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta sp. EBM-43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaSpEbm43Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1918502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1918502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1918502.clusters.proteins.v11.5.txt",
		        "sequence_path": "1918502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918502.protein.info.v11.5.txt",
		        "node_list_path": "1918502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1918502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusStelliferCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus stellifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusStelliferCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "169760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "169760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "169760.clusters.proteins.v11.5.txt",
		        "sequence_path": "169760.protein.sequences.v11.5.fa",
		        "enrichment_path": "169760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "169760.protein.info.v11.5.txt",
		        "node_list_path": "169760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "169760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfurobacteriumIndicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurobacterium indicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurobacteriumIndicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1914305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1914305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1914305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1914305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1914305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1914305.protein.info.v11.5.txt",
		        "node_list_path": "1914305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1914305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinibacterTainanensisDsm15459Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinibacter tainanensis DSM 15459 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinibacterTainanensisDsm15459Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121274.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121274.protein.info.v11.5.txt",
		        "node_list_path": "1121274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NosocomiicoccusSpNp2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nosocomiicoccus sp. NP2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NosocomiicoccusSpNp2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232430.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232430.protein.info.v11.5.txt",
		        "node_list_path": "1232430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0332Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0332 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0332Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649743.clusters.proteins.v11.5.txt",
		        "sequence_path": "649743.protein.sequences.v11.5.fa",
		        "enrichment_path": "649743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649743.protein.info.v11.5.txt",
		        "node_list_path": "649743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBaratii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium baratii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBaratii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415775.protein.info.v11.5.txt",
		        "node_list_path": "1415775.protein.complete.v11.5.txt"
		    }
		]
    )()

def AngiostrongylusCantonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Angiostrongylus cantonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AngiostrongylusCantonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6313.protein.sequences.v11.5.fa",
		        "enrichment_path": "6313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6313.protein.info.v11.5.txt",
		        "node_list_path": "6313.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifcsphigho201Full5513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_01_FULL_55_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho201Full5513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801917.protein.info.v11.5.txt",
		        "node_list_path": "1801917.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumNordicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium nordicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumNordicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "229535.protein.sequences.v11.5.fa",
		        "enrichment_path": "229535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229535.protein.info.v11.5.txt",
		        "node_list_path": "229535.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotogaThermarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga thermarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaThermarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "688269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "688269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "688269.clusters.proteins.v11.5.txt",
		        "sequence_path": "688269.protein.sequences.v11.5.fa",
		        "enrichment_path": "688269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688269.protein.info.v11.5.txt",
		        "node_list_path": "688269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "688269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpSlbn35Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. SLBN-35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpSlbn35Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "512030.clusters.info.v11.5.txt",
		        "cluster_tree_path": "512030.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "512030.clusters.proteins.v11.5.txt",
		        "sequence_path": "512030.protein.sequences.v11.5.fa",
		        "enrichment_path": "512030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512030.protein.info.v11.5.txt",
		        "node_list_path": "512030.cluster.nodes.v11.5.txt",
		        "edge_list_path": "512030.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSimilisDsm23365Jcm2765(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus similis DSM 23365 JCM 2765 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSimilisDsm23365Jcm2765", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423804.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423804.protein.info.v11.5.txt",
		        "node_list_path": "1423804.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumCrassostreae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium crassostreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumCrassostreae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1763534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1763534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1763534.protein.info.v11.5.txt",
		        "node_list_path": "1763534.protein.complete.v11.5.txt"
		    }
		]
    )()

def DerxiaGummosaDsm723Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Derxia gummosa DSM 723 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DerxiaGummosaDsm723Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121388.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121388.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121388.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121388.protein.info.v11.5.txt",
		        "node_list_path": "1121388.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121388.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumFreudenreichii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium freudenreichii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumFreudenreichii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "754252.protein.sequences.v11.5.fa",
		        "enrichment_path": "754252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754252.protein.info.v11.5.txt",
		        "node_list_path": "754252.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrothrixParvicellaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microthrix parvicella Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrothrixParvicellaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229780.protein.info.v11.5.txt",
		        "node_list_path": "1229780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaSpAb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. aB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpAb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "517433.protein.sequences.v11.5.fa",
		        "enrichment_path": "517433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "517433.protein.info.v11.5.txt",
		        "node_list_path": "517433.protein.complete.v11.5.txt"
		    }
		]
    )()

def BranchiibiusSpNy1634622(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Branchiibius sp. NY16-3462-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BranchiibiusSpNy1634622", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807500.protein.info.v11.5.txt",
		        "node_list_path": "1807500.protein.complete.v11.5.txt"
		    }
		]
    )()

def StrongyloidesPapillosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Strongyloides papillosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrongyloidesPapillosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "174720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "174720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "174720.clusters.proteins.v11.5.txt",
		        "sequence_path": "174720.protein.sequences.v11.5.fa",
		        "enrichment_path": "174720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "174720.protein.info.v11.5.txt",
		        "node_list_path": "174720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "174720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaRattaustralianiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella rattaustraliani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaRattaustralianiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1205681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1205681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1205681.clusters.proteins.v11.5.txt",
		        "sequence_path": "1205681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1205681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1205681.protein.info.v11.5.txt",
		        "node_list_path": "1205681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1205681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AllochromatiumVinosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Allochromatium vinosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllochromatiumVinosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "572477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "572477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "572477.clusters.proteins.v11.5.txt",
		        "sequence_path": "572477.protein.sequences.v11.5.fa",
		        "enrichment_path": "572477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572477.protein.info.v11.5.txt",
		        "node_list_path": "572477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "572477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpLeaf141Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf141 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpLeaf141Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736273.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736273.protein.info.v11.5.txt",
		        "node_list_path": "1736273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumXueshanense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium xueshanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumXueshanense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935223.protein.sequences.v11.5.fa",
		        "enrichment_path": "935223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935223.protein.info.v11.5.txt",
		        "node_list_path": "935223.protein.complete.v11.5.txt"
		    }
		]
    )()

def AminobacteriumMobile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aminobacterium mobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminobacteriumMobile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304875.protein.info.v11.5.txt",
		        "node_list_path": "1304875.protein.complete.v11.5.txt"
		    }
		]
    )()

def PapioAnubis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Papio anubis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PapioAnubis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9555.protein.sequences.v11.5.fa",
		        "enrichment_path": "9555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9555.protein.info.v11.5.txt",
		        "node_list_path": "9555.protein.complete.v11.5.txt"
		    }
		]
    )()

def FilamentousCyanobacteriumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return filamentous cyanobacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FilamentousCyanobacteriumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1128427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1128427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1128427.clusters.proteins.v11.5.txt",
		        "sequence_path": "1128427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128427.protein.info.v11.5.txt",
		        "node_list_path": "1128427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1128427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpYr558(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. YR558 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpYr558", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881044.protein.info.v11.5.txt",
		        "node_list_path": "1881044.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpYr375Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. yr375 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpYr375Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761906.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761906.protein.info.v11.5.txt",
		        "node_list_path": "1761906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionicicellaSuperfundiaDsm22317Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionicicella superfundia DSM 22317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionicicellaSuperfundiaDsm22317Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122999.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122999.protein.info.v11.5.txt",
		        "node_list_path": "1122999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynchytriumEndobioticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synchytrium endobioticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynchytriumEndobioticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "286115.clusters.info.v11.5.txt",
		        "cluster_tree_path": "286115.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "286115.clusters.proteins.v11.5.txt",
		        "sequence_path": "286115.protein.sequences.v11.5.fa",
		        "enrichment_path": "286115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "286115.protein.info.v11.5.txt",
		        "node_list_path": "286115.cluster.nodes.v11.5.txt",
		        "edge_list_path": "286115.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumFrankenforstenseDsm45800Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium frankenforstense DSM 45800 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumFrankenforstenseDsm45800Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437875.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437875.protein.info.v11.5.txt",
		        "node_list_path": "1437875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalodesulfurarchaeumFormicicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halodesulfurarchaeum formicicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalodesulfurarchaeumFormicicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1873524.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1873524.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1873524.clusters.proteins.v11.5.txt",
		        "sequence_path": "1873524.protein.sequences.v11.5.fa",
		        "enrichment_path": "1873524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1873524.protein.info.v11.5.txt",
		        "node_list_path": "1873524.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1873524.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaPetrii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella petrii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaPetrii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "94624.protein.sequences.v11.5.fa",
		        "enrichment_path": "94624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94624.protein.info.v11.5.txt",
		        "node_list_path": "94624.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinum202fCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum 202F Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinum202fCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415774.protein.info.v11.5.txt",
		        "node_list_path": "1415774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnochordaPilosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnochorda pilosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnochordaPilosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1555112.protein.sequences.v11.5.fa",
		        "enrichment_path": "1555112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1555112.protein.info.v11.5.txt",
		        "node_list_path": "1555112.protein.complete.v11.5.txt"
		    }
		]
    )()

def HypholomaSublateritiumFd334Ss4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hypholoma sublateritium FD-334 SS-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HypholomaSublateritiumFd334Ss4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "945553.protein.sequences.v11.5.fa",
		        "enrichment_path": "945553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "945553.protein.info.v11.5.txt",
		        "node_list_path": "945553.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaHongkongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaHongkongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122180.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122180.protein.info.v11.5.txt",
		        "node_list_path": "1122180.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumTrifoliiCb782(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum trifolii CB782 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumTrifoliiCb782", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033991.protein.info.v11.5.txt",
		        "node_list_path": "1033991.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpIbvhs1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. IBVHS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpIbvhs1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1985169.protein.sequences.v11.5.fa",
		        "enrichment_path": "1985169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1985169.protein.info.v11.5.txt",
		        "node_list_path": "1985169.protein.complete.v11.5.txt"
		    }
		]
    )()

def SnodgrassellaAlviWkb2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Snodgrassella alvi wkB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SnodgrassellaAlviWkb2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196094.protein.info.v11.5.txt",
		        "node_list_path": "1196094.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhyscomitrellaPatens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Physcomitrella patens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhyscomitrellaPatens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3218.protein.sequences.v11.5.fa",
		        "enrichment_path": "3218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3218.protein.info.v11.5.txt",
		        "node_list_path": "3218.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSimplex(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus simplex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSimplex", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1403313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403313.protein.info.v11.5.txt",
		        "node_list_path": "1403313.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumCavoleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum cavolei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumCavoleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "366522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "366522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "366522.clusters.proteins.v11.5.txt",
		        "sequence_path": "366522.protein.sequences.v11.5.fa",
		        "enrichment_path": "366522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366522.protein.info.v11.5.txt",
		        "node_list_path": "366522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "366522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RheinheimeraNanhaiensisE4078(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera nanhaiensis E407-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraNanhaiensisE4078", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "562729.protein.sequences.v11.5.fa",
		        "enrichment_path": "562729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562729.protein.info.v11.5.txt",
		        "node_list_path": "562729.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumRbg19ftCombo3910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RBG_19FT_COMBO_39_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumRbg19ftCombo3910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817748.protein.info.v11.5.txt",
		        "node_list_path": "1817748.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesQinglanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces qinglanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesQinglanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "943816.protein.sequences.v11.5.fa",
		        "enrichment_path": "943816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "943816.protein.info.v11.5.txt",
		        "node_list_path": "943816.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusJorgensenbacteriaBacteriumRifcsplowo212Full4211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPLOWO2_12_FULL_42_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsplowo212Full4211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798473.protein.info.v11.5.txt",
		        "node_list_path": "1798473.protein.complete.v11.5.txt"
		    }
		]
    )()

def PapaverSomniferum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Papaver somniferum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PapaverSomniferum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3469.protein.sequences.v11.5.fa",
		        "enrichment_path": "3469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3469.protein.info.v11.5.txt",
		        "node_list_path": "3469.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacillusPleuropneumoniae5bL20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae 5b L20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusPleuropneumoniae5bL20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "416269.protein.sequences.v11.5.fa",
		        "enrichment_path": "416269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416269.protein.info.v11.5.txt",
		        "node_list_path": "416269.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpNml140438Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML140438 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpNml140438Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906334.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906334.protein.info.v11.5.txt",
		        "node_list_path": "1906334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LitorimicrobiumTaeanenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Litorimicrobium taeanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LitorimicrobiumTaeanenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "657014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "657014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "657014.clusters.proteins.v11.5.txt",
		        "sequence_path": "657014.protein.sequences.v11.5.fa",
		        "enrichment_path": "657014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657014.protein.info.v11.5.txt",
		        "node_list_path": "657014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "657014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfolobusIslandicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus islandicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusIslandicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930945.clusters.proteins.v11.5.txt",
		        "sequence_path": "930945.protein.sequences.v11.5.fa",
		        "enrichment_path": "930945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930945.protein.info.v11.5.txt",
		        "node_list_path": "930945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasCrevioricanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas crevioricanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasCrevioricanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "393921.protein.sequences.v11.5.fa",
		        "enrichment_path": "393921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393921.protein.info.v11.5.txt",
		        "node_list_path": "393921.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpWp9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. WP9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpWp9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500263.protein.info.v11.5.txt",
		        "node_list_path": "1500263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumFlaccumfaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium flaccumfaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumFlaccumfaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2035.protein.sequences.v11.5.fa",
		        "enrichment_path": "2035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2035.protein.info.v11.5.txt",
		        "node_list_path": "2035.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsplowo201Full5314Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO2_01_FULL_53_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201Full5314Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802628.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802628.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802628.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802628.protein.info.v11.5.txt",
		        "node_list_path": "1802628.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802628.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAzotifigensDsm17556(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas azotifigens DSM 17556 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAzotifigensDsm17556", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1292027.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292027.protein.info.v11.5.txt",
		        "node_list_path": "1292027.protein.complete.v11.5.txt"
		    }
		]
    )()

def DermacoccusSpEllin185(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dermacoccus sp. Ellin185 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DermacoccusSpEllin185", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "188626.protein.sequences.v11.5.fa",
		        "enrichment_path": "188626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188626.protein.info.v11.5.txt",
		        "node_list_path": "188626.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasGingeriNcppb3146Lmg5327(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas gingeri NCPPB 3146 LMG 5327 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasGingeriNcppb3146Lmg5327", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "707248.protein.sequences.v11.5.fa",
		        "enrichment_path": "707248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "707248.protein.info.v11.5.txt",
		        "node_list_path": "707248.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalobacterSpCf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dehalobacter sp. CF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalobacterSpCf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131462.protein.info.v11.5.txt",
		        "node_list_path": "1131462.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoplanesGlobisporusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes globisporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesGlobisporusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120949.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120949.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120949.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120949.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120949.protein.info.v11.5.txt",
		        "node_list_path": "1120949.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120949.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavisolibacterGinsengisoliDsm18119Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavisolibacter ginsengisoli DSM 18119 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavisolibacterGinsengisoliDsm18119Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121884.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121884.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121884.protein.info.v11.5.txt",
		        "node_list_path": "1121884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PythiumIrregulareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pythium irregulare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PythiumIrregulareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36331.clusters.proteins.v11.5.txt",
		        "sequence_path": "36331.protein.sequences.v11.5.fa",
		        "enrichment_path": "36331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36331.protein.info.v11.5.txt",
		        "node_list_path": "36331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuegeriaSp6palisep08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. 6PALISEP08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaSp6palisep08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1225660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1225660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1225660.clusters.proteins.v11.5.txt",
		        "sequence_path": "1225660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225660.protein.info.v11.5.txt",
		        "node_list_path": "1225660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1225660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalolaminaPelagica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halolamina pelagica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolaminaPelagica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "699431.protein.sequences.v11.5.fa",
		        "enrichment_path": "699431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "699431.protein.info.v11.5.txt",
		        "node_list_path": "699431.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonBa1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon BA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonBa1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1700835.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1700835.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1700835.clusters.proteins.v11.5.txt",
		        "sequence_path": "1700835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1700835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1700835.protein.info.v11.5.txt",
		        "node_list_path": "1700835.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1700835.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStoquefichusSpKle1796Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Stoquefichus sp. KLE1796 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStoquefichusSpKle1796Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1574263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1574263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1574263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1574263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1574263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1574263.protein.info.v11.5.txt",
		        "node_list_path": "1574263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1574263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpMst1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. MSt1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpMst1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1501230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1501230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1501230.clusters.proteins.v11.5.txt",
		        "sequence_path": "1501230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1501230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1501230.protein.info.v11.5.txt",
		        "node_list_path": "1501230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1501230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAcetobutylicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acetobutylicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAcetobutylicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272562.clusters.proteins.v11.5.txt",
		        "sequence_path": "272562.protein.sequences.v11.5.fa",
		        "enrichment_path": "272562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272562.protein.info.v11.5.txt",
		        "node_list_path": "272562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSuis865192(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis 865192 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSuis865192", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1214166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214166.protein.info.v11.5.txt",
		        "node_list_path": "1214166.protein.complete.v11.5.txt"
		    }
		]
    )()

def YooniaTamlensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yoonia tamlensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YooniaTamlensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "390270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "390270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "390270.clusters.proteins.v11.5.txt",
		        "sequence_path": "390270.protein.sequences.v11.5.fa",
		        "enrichment_path": "390270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390270.protein.info.v11.5.txt",
		        "node_list_path": "390270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "390270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterPickeringiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter pickeringii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterPickeringiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "345632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "345632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "345632.clusters.proteins.v11.5.txt",
		        "sequence_path": "345632.protein.sequences.v11.5.fa",
		        "enrichment_path": "345632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "345632.protein.info.v11.5.txt",
		        "node_list_path": "345632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "345632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantholopsHodgsonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantholops hodgsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantholopsHodgsonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59538.protein.sequences.v11.5.fa",
		        "enrichment_path": "59538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59538.protein.info.v11.5.txt",
		        "node_list_path": "59538.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParageobacillusThermoglucosidasius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parageobacillus thermoglucosidasius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParageobacillusThermoglucosidasius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1426.protein.info.v11.5.txt",
		        "node_list_path": "1426.protein.complete.v11.5.txt"
		    }
		]
    )()

def PannonibacterPhragmitetus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pannonibacter phragmitetus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PannonibacterPhragmitetus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122929.protein.info.v11.5.txt",
		        "node_list_path": "1122929.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpP838(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. P838 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpP838", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1029823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1029823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1029823.protein.info.v11.5.txt",
		        "node_list_path": "1029823.protein.complete.v11.5.txt"
		    }
		]
    )()

def MitsuariaSp7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mitsuaria sp. 7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MitsuariaSp7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658665.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658665.protein.info.v11.5.txt",
		        "node_list_path": "1658665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FischerellaThermalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fischerella thermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FischerellaThermalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "98439.protein.sequences.v11.5.fa",
		        "enrichment_path": "98439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "98439.protein.info.v11.5.txt",
		        "node_list_path": "98439.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnsiferAridiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer aridi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferAridiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1708715.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1708715.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1708715.clusters.proteins.v11.5.txt",
		        "sequence_path": "1708715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1708715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1708715.protein.info.v11.5.txt",
		        "node_list_path": "1708715.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1708715.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LiberibacterSolanacearum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter solanacearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LiberibacterSolanacearum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658172.protein.sequences.v11.5.fa",
		        "enrichment_path": "658172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658172.protein.info.v11.5.txt",
		        "node_list_path": "658172.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosaetaHarundinacea6acCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosaeta harundinacea 6Ac Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosaetaHarundinacea6acCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1110509.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1110509.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1110509.clusters.proteins.v11.5.txt",
		        "sequence_path": "1110509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1110509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1110509.protein.info.v11.5.txt",
		        "node_list_path": "1110509.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1110509.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobaculaSpRifoxya12Full4616(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacula sp. RIFOXYA12_FULL_46_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobaculaSpRifoxya12Full4616", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797911.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797911.protein.info.v11.5.txt",
		        "node_list_path": "1797911.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpJ31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. J31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpJ31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935851.protein.sequences.v11.5.fa",
		        "enrichment_path": "935851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935851.protein.info.v11.5.txt",
		        "node_list_path": "935851.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacterSpBrhC7a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacter sp. BRH_c7a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacterSpBrhC7a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1734398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1734398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1734398.protein.info.v11.5.txt",
		        "node_list_path": "1734398.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumWsm2304(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum WSM2304 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumWsm2304", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "395492.protein.sequences.v11.0.fa",
		        "enrichment_path": "395492.protein.enrichment.terms.v11.0.txt",
		        "info_path": "395492.protein.info.v11.0.txt",
		        "node_list_path": "395492.protein.complete.v11.0.txt"
		    }
		]
    )()

def BrevibacteriumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1176165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1176165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1176165.protein.info.v11.5.txt",
		        "node_list_path": "1176165.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122609.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122609.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122609.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122609.protein.info.v11.5.txt",
		        "node_list_path": "1122609.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122609.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaPutrefaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella putrefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaPutrefaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "319224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "319224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "319224.clusters.proteins.v11.5.txt",
		        "sequence_path": "319224.protein.sequences.v11.5.fa",
		        "enrichment_path": "319224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319224.protein.info.v11.5.txt",
		        "node_list_path": "319224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "319224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpLeaf261Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. Leaf261 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpLeaf261Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736311.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736311.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736311.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736311.protein.info.v11.5.txt",
		        "node_list_path": "1736311.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736311.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaseolusVulgarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaseolus vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaseolusVulgarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3885.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3885.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3885.clusters.proteins.v11.5.txt",
		        "sequence_path": "3885.protein.sequences.v11.5.fa",
		        "enrichment_path": "3885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3885.protein.info.v11.5.txt",
		        "node_list_path": "3885.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3885.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeoalkalibacterFerrihydriticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geoalkalibacter ferrihydriticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeoalkalibacterFerrihydriticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "392333.protein.sequences.v11.5.fa",
		        "enrichment_path": "392333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392333.protein.info.v11.5.txt",
		        "node_list_path": "392333.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpS718(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. S718 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpS718", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1284775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284775.protein.info.v11.5.txt",
		        "node_list_path": "1284775.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1024082(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_40_82 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024082", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805306.protein.info.v11.5.txt",
		        "node_list_path": "1805306.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4413(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_44_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4413", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802069.protein.info.v11.5.txt",
		        "node_list_path": "1802069.protein.complete.v11.5.txt"
		    }
		]
    )()

def CalothrixSp3363Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Calothrix sp. 3363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalothrixSp3363Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1337936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1337936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1337936.clusters.proteins.v11.5.txt",
		        "sequence_path": "1337936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1337936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1337936.protein.info.v11.5.txt",
		        "node_list_path": "1337936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1337936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsphigho212Full4311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_12_FULL_43_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho212Full4311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797780.protein.info.v11.5.txt",
		        "node_list_path": "1797780.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpFc2018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. FC2018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpFc2018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410617.protein.info.v11.5.txt",
		        "node_list_path": "1410617.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaBacilliformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria bacilliformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaBacilliformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "267212.protein.sequences.v11.5.fa",
		        "enrichment_path": "267212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267212.protein.info.v11.5.txt",
		        "node_list_path": "267212.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExophialaDermatitidisNihUt8656(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exophiala dermatitidis NIH/UT8656 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaDermatitidisNihUt8656", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "858893.protein.sequences.v11.5.fa",
		        "enrichment_path": "858893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "858893.protein.info.v11.5.txt",
		        "node_list_path": "858893.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterLanienae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter lanienae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterLanienae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "75658.protein.sequences.v11.5.fa",
		        "enrichment_path": "75658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75658.protein.info.v11.5.txt",
		        "node_list_path": "75658.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumArgentinenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium argentinense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumArgentinenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29341.clusters.proteins.v11.5.txt",
		        "sequence_path": "29341.protein.sequences.v11.5.fa",
		        "enrichment_path": "29341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29341.protein.info.v11.5.txt",
		        "node_list_path": "29341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaPeucetia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora peucetia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaPeucetia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47871.protein.sequences.v11.5.fa",
		        "enrichment_path": "47871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47871.protein.info.v11.5.txt",
		        "node_list_path": "47871.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaMarshiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella marshii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMarshiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "862515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "862515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "862515.clusters.proteins.v11.5.txt",
		        "sequence_path": "862515.protein.sequences.v11.5.fa",
		        "enrichment_path": "862515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862515.protein.info.v11.5.txt",
		        "node_list_path": "862515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "862515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudohongiellaNitratireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudohongiella nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudohongiellaNitratireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1768907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768907.protein.info.v11.5.txt",
		        "node_list_path": "1768907.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSaniviriJcm17471Dsm24301(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus saniviri JCM 17471 DSM 24301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSaniviriJcm17471Dsm24301", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293598.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293598.protein.info.v11.5.txt",
		        "node_list_path": "1293598.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentzeaJiangxiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentzea jiangxiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentzeaJiangxiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641025.protein.sequences.v11.5.fa",
		        "enrichment_path": "641025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641025.protein.info.v11.5.txt",
		        "node_list_path": "641025.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterSpKpr6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter sp. kpr-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterSpKpr6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761782.protein.info.v11.5.txt",
		        "node_list_path": "1761782.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrovirgaVignaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microvirga vignae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaVignaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1225564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1225564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1225564.clusters.proteins.v11.5.txt",
		        "sequence_path": "1225564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225564.protein.info.v11.5.txt",
		        "node_list_path": "1225564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1225564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EchinicolaVietnamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Echinicola vietnamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EchinicolaVietnamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926556.protein.sequences.v11.5.fa",
		        "enrichment_path": "926556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926556.protein.info.v11.5.txt",
		        "node_list_path": "926556.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumPectinovorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium pectinovorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumPectinovorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29533.clusters.proteins.v11.5.txt",
		        "sequence_path": "29533.protein.sequences.v11.5.fa",
		        "enrichment_path": "29533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29533.protein.info.v11.5.txt",
		        "node_list_path": "29533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumMelilotiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium meliloti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumMelilotiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266834.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266834.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266834.clusters.proteins.v11.5.txt",
		        "sequence_path": "266834.protein.sequences.v11.5.fa",
		        "enrichment_path": "266834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266834.protein.info.v11.5.txt",
		        "node_list_path": "266834.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266834.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumVivax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium vivax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumVivax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5855.protein.sequences.v11.5.fa",
		        "enrichment_path": "5855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5855.protein.info.v11.5.txt",
		        "node_list_path": "5855.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumMarseilleP2986Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Marseille-P2986 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumMarseilleP2986Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852391.protein.info.v11.5.txt",
		        "node_list_path": "1852391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SideroxydansLithotrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sideroxydans lithotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SideroxydansLithotrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "580332.protein.sequences.v11.5.fa",
		        "enrichment_path": "580332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "580332.protein.info.v11.5.txt",
		        "node_list_path": "580332.protein.complete.v11.5.txt"
		    }
		]
    )()

def SkermanellaAerolataKacc11604(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Skermanella aerolata KACC 11604 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SkermanellaAerolataKacc11604", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385368.protein.info.v11.5.txt",
		        "node_list_path": "1385368.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpB13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. b13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpB13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761774.protein.info.v11.5.txt",
		        "node_list_path": "1761774.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumNeworleansenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium neworleansense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumNeworleansenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "146018.clusters.info.v11.5.txt",
		        "cluster_tree_path": "146018.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "146018.clusters.proteins.v11.5.txt",
		        "sequence_path": "146018.protein.sequences.v11.5.fa",
		        "enrichment_path": "146018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146018.protein.info.v11.5.txt",
		        "node_list_path": "146018.cluster.nodes.v11.5.txt",
		        "edge_list_path": "146018.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaSpCny236(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia sp. CNY236 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSpCny236", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1169152.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169152.protein.info.v11.5.txt",
		        "node_list_path": "1169152.protein.complete.v11.5.txt"
		    }
		]
    )()

def PochoniaChlamydosporia123(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pochonia chlamydosporia 123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PochoniaChlamydosporia123", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1052797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1052797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1052797.protein.info.v11.5.txt",
		        "node_list_path": "1052797.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesTurgidiscabies(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces turgidiscabies graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesTurgidiscabies", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "85558.protein.sequences.v11.5.fa",
		        "enrichment_path": "85558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85558.protein.info.v11.5.txt",
		        "node_list_path": "85558.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalimicrobiumCyclicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalimicrobium cyclicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalimicrobiumCyclicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717773.clusters.proteins.v11.5.txt",
		        "sequence_path": "717773.protein.sequences.v11.5.fa",
		        "enrichment_path": "717773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717773.protein.info.v11.5.txt",
		        "node_list_path": "717773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsplowo201Full4732(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_47_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full4732", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802277.protein.info.v11.5.txt",
		        "node_list_path": "1802277.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaMahiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena mahii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaMahiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1416969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1416969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1416969.clusters.proteins.v11.5.txt",
		        "sequence_path": "1416969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416969.protein.info.v11.5.txt",
		        "node_list_path": "1416969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1416969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusEqui(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus equi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusEqui", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40041.protein.sequences.v11.5.fa",
		        "enrichment_path": "40041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40041.protein.info.v11.5.txt",
		        "node_list_path": "40041.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZymophilusRaffinosivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymophilus raffinosivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymophilusRaffinosivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123511.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123511.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123511.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123511.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123511.protein.info.v11.5.txt",
		        "node_list_path": "1123511.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123511.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SilanimonasLentaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Silanimonas lenta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SilanimonasLentaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123253.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123253.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123253.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123253.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123253.protein.info.v11.5.txt",
		        "node_list_path": "1123253.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123253.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasUtahensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas utahensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasUtahensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86177.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86177.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86177.clusters.proteins.v11.5.txt",
		        "sequence_path": "86177.protein.sequences.v11.5.fa",
		        "enrichment_path": "86177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86177.protein.info.v11.5.txt",
		        "node_list_path": "86177.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86177.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DickeyaSolani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya solani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaSolani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089444.protein.info.v11.5.txt",
		        "node_list_path": "1089444.protein.complete.v11.5.txt"
		    }
		]
    )()

def VirgibacillusSp6r(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus sp. 6R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusSp6r", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1911587.protein.sequences.v11.5.fa",
		        "enrichment_path": "1911587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1911587.protein.info.v11.5.txt",
		        "node_list_path": "1911587.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpBiomig1nCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BIOMIG1N Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpBiomig1nCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1763882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1763882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1763882.clusters.proteins.v11.5.txt",
		        "sequence_path": "1763882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1763882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1763882.protein.info.v11.5.txt",
		        "node_list_path": "1763882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1763882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodospiraTrueperi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospira trueperi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospiraTrueperi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69960.protein.sequences.v11.5.fa",
		        "enrichment_path": "69960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69960.protein.info.v11.5.txt",
		        "node_list_path": "69960.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpZagget11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. Zagget11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpZagget11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930004.protein.info.v11.5.txt",
		        "node_list_path": "1930004.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumIndologenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium indologenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumIndologenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218103.protein.info.v11.5.txt",
		        "node_list_path": "1218103.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaTrachomatisDUw3CxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia trachomatis D/UW-3/CX Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaTrachomatisDUw3CxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272561.clusters.proteins.v11.5.txt",
		        "sequence_path": "272561.protein.sequences.v11.5.fa",
		        "enrichment_path": "272561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272561.protein.info.v11.5.txt",
		        "node_list_path": "272561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumCiceriBiovarCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium ciceri biovar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumCiceriBiovarCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765698.clusters.proteins.v11.5.txt",
		        "sequence_path": "765698.protein.sequences.v11.5.fa",
		        "enrichment_path": "765698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765698.protein.info.v11.5.txt",
		        "node_list_path": "765698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetragenococcusSolitariusNbrc100494(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetragenococcus solitarius NBRC 100494 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetragenococcusSolitariusNbrc100494", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223494.protein.info.v11.5.txt",
		        "node_list_path": "1223494.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusClavatusNrrl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus clavatus NRRL 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusClavatusNrrl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "344612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "344612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "344612.clusters.proteins.v11.5.txt",
		        "sequence_path": "344612.protein.sequences.v11.5.fa",
		        "enrichment_path": "344612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "344612.protein.info.v11.5.txt",
		        "node_list_path": "344612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "344612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpE14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. e14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpE14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "645465.clusters.info.v11.5.txt",
		        "cluster_tree_path": "645465.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "645465.clusters.proteins.v11.5.txt",
		        "sequence_path": "645465.protein.sequences.v11.5.fa",
		        "enrichment_path": "645465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645465.protein.info.v11.5.txt",
		        "node_list_path": "645465.cluster.nodes.v11.5.txt",
		        "edge_list_path": "645465.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElioraeaTepidiphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elioraea tepidiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElioraeaTepidiphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121861.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121861.protein.info.v11.5.txt",
		        "node_list_path": "1121861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaFonticola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia fonticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaFonticola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47917.protein.sequences.v11.5.fa",
		        "enrichment_path": "47917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47917.protein.info.v11.5.txt",
		        "node_list_path": "47917.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumNalgiovense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium nalgiovense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumNalgiovense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "60175.protein.sequences.v11.5.fa",
		        "enrichment_path": "60175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60175.protein.info.v11.5.txt",
		        "node_list_path": "60175.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumMa2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium MA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumMa2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1333998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1333998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1333998.clusters.proteins.v11.5.txt",
		        "sequence_path": "1333998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333998.protein.info.v11.5.txt",
		        "node_list_path": "1333998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1333998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumHylemonaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium hylemonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumHylemonaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553973.clusters.proteins.v11.5.txt",
		        "sequence_path": "553973.protein.sequences.v11.5.fa",
		        "enrichment_path": "553973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553973.protein.info.v11.5.txt",
		        "node_list_path": "553973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloversatilisDiscipulorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloversatilis discipulorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloversatilisDiscipulorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1119528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1119528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1119528.clusters.proteins.v11.5.txt",
		        "sequence_path": "1119528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1119528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1119528.protein.info.v11.5.txt",
		        "node_list_path": "1119528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1119528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquilegiaCoeruleaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquilegia coerulea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquilegiaCoeruleaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "218851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "218851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "218851.clusters.proteins.v11.5.txt",
		        "sequence_path": "218851.protein.sequences.v11.5.fa",
		        "enrichment_path": "218851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218851.protein.info.v11.5.txt",
		        "node_list_path": "218851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "218851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FimbriimonasGinsengisoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fimbriimonas ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FimbriimonasGinsengisoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "661478.protein.sequences.v11.5.fa",
		        "enrichment_path": "661478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "661478.protein.info.v11.5.txt",
		        "node_list_path": "661478.protein.complete.v11.5.txt"
		    }
		]
    )()

def BeijerinckiaSp28Yea48(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Beijerinckia sp. 28-YEA-48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeijerinckiaSp28Yea48", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882748.protein.info.v11.5.txt",
		        "node_list_path": "1882748.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConiochaetaLigniariaNrrl30616(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coniochaeta ligniaria NRRL 30616 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConiochaetaLigniariaNrrl30616", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408157.protein.info.v11.5.txt",
		        "node_list_path": "1408157.protein.complete.v11.5.txt"
		    }
		]
    )()

def DermabacterVaginalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dermabacter vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DermabacterVaginalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1630135.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1630135.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1630135.clusters.proteins.v11.5.txt",
		        "sequence_path": "1630135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1630135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1630135.protein.info.v11.5.txt",
		        "node_list_path": "1630135.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1630135.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeptuniibacterCaesariensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neptuniibacter caesariensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptuniibacterCaesariensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "207954.clusters.info.v11.5.txt",
		        "cluster_tree_path": "207954.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "207954.clusters.proteins.v11.5.txt",
		        "sequence_path": "207954.protein.sequences.v11.5.fa",
		        "enrichment_path": "207954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "207954.protein.info.v11.5.txt",
		        "node_list_path": "207954.cluster.nodes.v11.5.txt",
		        "edge_list_path": "207954.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VulcanisaetaDistributaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vulcanisaeta distributa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulcanisaetaDistributaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "572478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "572478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "572478.clusters.proteins.v11.5.txt",
		        "sequence_path": "572478.protein.sequences.v11.5.fa",
		        "enrichment_path": "572478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572478.protein.info.v11.5.txt",
		        "node_list_path": "572478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "572478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpH14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpH14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1312959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1312959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1312959.protein.info.v11.5.txt",
		        "node_list_path": "1312959.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSp369(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 36-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSp369", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895905.protein.info.v11.5.txt",
		        "node_list_path": "1895905.protein.complete.v11.5.txt"
		    }
		]
    )()

def OphiostomaPiceaeUamh11346Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ophiostoma piceae UAMH 11346 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiostomaPiceaeUamh11346Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262450.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262450.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262450.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262450.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262450.protein.info.v11.5.txt",
		        "node_list_path": "1262450.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262450.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensQ287(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Q287 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensQ287", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1038922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038922.protein.info.v11.5.txt",
		        "node_list_path": "1038922.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacterMetallireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter metallireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterMetallireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "269799.protein.sequences.v11.5.fa",
		        "enrichment_path": "269799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269799.protein.info.v11.5.txt",
		        "node_list_path": "269799.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumSpRoot495(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root495 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumSpRoot495", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736550.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736550.protein.info.v11.5.txt",
		        "node_list_path": "1736550.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCl2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CL2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCl2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499684.protein.info.v11.5.txt",
		        "node_list_path": "1499684.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudohongiellaNitratireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudohongiella nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudohongiellaNitratireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1768907.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1768907.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1768907.clusters.proteins.v11.5.txt",
		        "sequence_path": "1768907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768907.protein.info.v11.5.txt",
		        "node_list_path": "1768907.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1768907.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxBoronicumulans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax boronicumulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxBoronicumulans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "436515.protein.sequences.v11.5.fa",
		        "enrichment_path": "436515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436515.protein.info.v11.5.txt",
		        "node_list_path": "436515.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaQuintanaRm11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella quintana RM-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaQuintanaRm11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1225179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1225179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1225179.clusters.proteins.v11.5.txt",
		        "sequence_path": "1225179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225179.protein.info.v11.5.txt",
		        "node_list_path": "1225179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1225179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusIntermediusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus intermedius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusIntermediusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1141106.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1141106.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1141106.clusters.proteins.v11.5.txt",
		        "sequence_path": "1141106.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141106.protein.info.v11.5.txt",
		        "node_list_path": "1141106.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1141106.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaAmbifariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia ambifaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaAmbifariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "339670.clusters.info.v11.5.txt",
		        "cluster_tree_path": "339670.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "339670.clusters.proteins.v11.5.txt",
		        "sequence_path": "339670.protein.sequences.v11.5.fa",
		        "enrichment_path": "339670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "339670.protein.info.v11.5.txt",
		        "node_list_path": "339670.cluster.nodes.v11.5.txt",
		        "edge_list_path": "339670.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinoalloteichusCyanogriseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoalloteichus cyanogriseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoalloteichusCyanogriseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "65497.protein.sequences.v11.5.fa",
		        "enrichment_path": "65497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65497.protein.info.v11.5.txt",
		        "node_list_path": "65497.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumCg2303210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium CG2_30_32_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumCg2303210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805032.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805032.protein.info.v11.5.txt",
		        "node_list_path": "1805032.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndosymbiontOfUnidentifiedScalySnailIsolateMonjuCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of unidentified scaly snail isolate Monju Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndosymbiontOfUnidentifiedScalySnailIsolateMonjuCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1248727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1248727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1248727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1248727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1248727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1248727.protein.info.v11.5.txt",
		        "node_list_path": "1248727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1248727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ApostichopusJaponicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Apostichopus japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApostichopusJaponicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "307972.protein.sequences.v11.5.fa",
		        "enrichment_path": "307972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "307972.protein.info.v11.5.txt",
		        "node_list_path": "307972.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaceaeBacteriumKbs83(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs83", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267533.protein.info.v11.5.txt",
		        "node_list_path": "1267533.protein.complete.v11.5.txt"
		    }
		]
    )()

def CeleribacterNeptunius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Celeribacter neptunius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeleribacterNeptunius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "588602.protein.sequences.v11.5.fa",
		        "enrichment_path": "588602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588602.protein.info.v11.5.txt",
		        "node_list_path": "588602.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrococcusBaldriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrococcus baldri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrococcusBaldriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "153730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "153730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "153730.clusters.proteins.v11.5.txt",
		        "sequence_path": "153730.protein.sequences.v11.5.fa",
		        "enrichment_path": "153730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "153730.protein.info.v11.5.txt",
		        "node_list_path": "153730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "153730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodosporidiumToruloidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodosporidium toruloides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodosporidiumToruloidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5286.clusters.proteins.v11.5.txt",
		        "sequence_path": "5286.protein.sequences.v11.5.fa",
		        "enrichment_path": "5286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5286.protein.info.v11.5.txt",
		        "node_list_path": "5286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumDurumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium durum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumDurumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035195.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035195.protein.info.v11.5.txt",
		        "node_list_path": "1035195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusParviboronicapiensJcm18861(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus parviboronicapiens JCM 18861 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusParviboronicapiensJcm18861", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293591.protein.info.v11.5.txt",
		        "node_list_path": "1293591.protein.complete.v11.5.txt"
		    }
		]
    )()

def CladophialophoraPsammophilaCbs110553Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora psammophila CBS 110553 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CladophialophoraPsammophilaCbs110553Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1182543.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1182543.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1182543.clusters.proteins.v11.5.txt",
		        "sequence_path": "1182543.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182543.protein.info.v11.5.txt",
		        "node_list_path": "1182543.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1182543.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc24417(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC2_44_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc24417", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618929.protein.info.v11.5.txt",
		        "node_list_path": "1618929.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrnatilineaApprima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ornatilinea apprima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnatilineaApprima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1134406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134406.protein.info.v11.5.txt",
		        "node_list_path": "1134406.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacterSp24Yea8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter sp. 24-YEA-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterSp24Yea8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884310.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884310.protein.info.v11.5.txt",
		        "node_list_path": "1884310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NelumboNuciferaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nelumbo nucifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NelumboNuciferaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4432.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4432.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4432.clusters.proteins.v11.5.txt",
		        "sequence_path": "4432.protein.sequences.v11.5.fa",
		        "enrichment_path": "4432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4432.protein.info.v11.5.txt",
		        "node_list_path": "4432.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4432.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusNasuensisJcm17158(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nasuensis JCM 17158 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusNasuensisJcm17158", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1291734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291734.protein.info.v11.5.txt",
		        "node_list_path": "1291734.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhyllobacteriumSpOv277(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. OV277 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhyllobacteriumSpOv277", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882772.protein.info.v11.5.txt",
		        "node_list_path": "1882772.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full3811b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_38_11b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full3811b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797725.protein.info.v11.5.txt",
		        "node_list_path": "1797725.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacterSphaeroides241Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter sphaeroides 241 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterSphaeroides241Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272943.clusters.proteins.v11.5.txt",
		        "sequence_path": "272943.protein.sequences.v11.5.fa",
		        "enrichment_path": "272943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272943.protein.info.v11.5.txt",
		        "node_list_path": "272943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwa26618(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_66_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwa26618", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797926.protein.info.v11.5.txt",
		        "node_list_path": "1797926.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpLeaf7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. Leaf7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpLeaf7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736210.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736210.protein.info.v11.5.txt",
		        "node_list_path": "1736210.protein.complete.v11.5.txt"
		    }
		]
    )()

def FaecalibaculumRodentium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Faecalibaculum rodentium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibaculumRodentium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1702221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1702221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1702221.protein.info.v11.5.txt",
		        "node_list_path": "1702221.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumNeonataleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium neonatale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumNeonataleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "137838.clusters.info.v11.5.txt",
		        "cluster_tree_path": "137838.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "137838.clusters.proteins.v11.5.txt",
		        "sequence_path": "137838.protein.sequences.v11.5.fa",
		        "enrichment_path": "137838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137838.protein.info.v11.5.txt",
		        "node_list_path": "137838.cluster.nodes.v11.5.txt",
		        "edge_list_path": "137838.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpCaviae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. caviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpCaviae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1915004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915004.protein.info.v11.5.txt",
		        "node_list_path": "1915004.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifoxyc1Full3818(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYC1_FULL_38_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyc1Full3818", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802229.protein.info.v11.5.txt",
		        "node_list_path": "1802229.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaMucosaAtcc25996Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria mucosa ATCC25996 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaMucosaAtcc25996Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546266.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546266.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546266.clusters.proteins.v11.5.txt",
		        "sequence_path": "546266.protein.sequences.v11.5.fa",
		        "enrichment_path": "546266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546266.protein.info.v11.5.txt",
		        "node_list_path": "546266.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546266.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrabulsiellaGuamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trabulsiella guamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrabulsiellaGuamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005994.protein.info.v11.5.txt",
		        "node_list_path": "1005994.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusUrinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus urinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusUrinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "866775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "866775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "866775.clusters.proteins.v11.5.txt",
		        "sequence_path": "866775.protein.sequences.v11.5.fa",
		        "enrichment_path": "866775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866775.protein.info.v11.5.txt",
		        "node_list_path": "866775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "866775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RaineyellaAntarcticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Raineyella antarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RaineyellaAntarcticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577474.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577474.protein.info.v11.5.txt",
		        "node_list_path": "1577474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AiluropodaMelanoleuca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ailuropoda melanoleuca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AiluropodaMelanoleuca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9646.protein.sequences.v11.5.fa",
		        "enrichment_path": "9646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9646.protein.info.v11.5.txt",
		        "node_list_path": "9646.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumGw2011Gwa25212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium GW2011_GWA2_52_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumGw2011Gwa25212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618671.protein.info.v11.5.txt",
		        "node_list_path": "1618671.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpDi166(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. DI166 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpDi166", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1839783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1839783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1839783.protein.info.v11.5.txt",
		        "node_list_path": "1839783.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwc25213(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWC2_52_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwc25213", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802181.protein.info.v11.5.txt",
		        "node_list_path": "1802181.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusCalidoustusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus calidoustus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusCalidoustusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "454130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "454130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "454130.clusters.proteins.v11.5.txt",
		        "sequence_path": "454130.protein.sequences.v11.5.fa",
		        "enrichment_path": "454130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454130.protein.info.v11.5.txt",
		        "node_list_path": "454130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "454130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacillusYanchengensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacillus yanchengensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacillusYanchengensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385514.protein.info.v11.5.txt",
		        "node_list_path": "1385514.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaLijiangensisNbrc108240Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia lijiangensis NBRC 108240 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaLijiangensisNbrc108240Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210083.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210083.protein.info.v11.5.txt",
		        "node_list_path": "1210083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZobelliaGalactanivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zobellia galactanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZobelliaGalactanivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "63186.protein.sequences.v11.5.fa",
		        "enrichment_path": "63186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63186.protein.info.v11.5.txt",
		        "node_list_path": "63186.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaTrachomatisDUw3Cx(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia trachomatis D/UW-3/CX graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaTrachomatisDUw3Cx", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272561.protein.sequences.v11.5.fa",
		        "enrichment_path": "272561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272561.protein.info.v11.5.txt",
		        "node_list_path": "272561.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarineGroupIiEuryarchaeoteRedseaS11B3n4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marine group II euryarchaeote REDSEA-S11_B3N4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineGroupIiEuryarchaeoteRedseaS11B3n4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811651.protein.info.v11.5.txt",
		        "node_list_path": "1811651.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaPsychrophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaPsychrophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "225848.clusters.info.v11.5.txt",
		        "cluster_tree_path": "225848.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "225848.clusters.proteins.v11.5.txt",
		        "sequence_path": "225848.protein.sequences.v11.5.fa",
		        "enrichment_path": "225848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225848.protein.info.v11.5.txt",
		        "node_list_path": "225848.cluster.nodes.v11.5.txt",
		        "edge_list_path": "225848.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrenarchaeotaArchaeon13140cm35217Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_52_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenarchaeotaArchaeon13140cm35217Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805096.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805096.protein.info.v11.5.txt",
		        "node_list_path": "1805096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCavendishiiDsm21758Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cavendishii DSM 21758 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCavendishiiDsm21758Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121302.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121302.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121302.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121302.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121302.protein.info.v11.5.txt",
		        "node_list_path": "1121302.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121302.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaFidelisAtccBaa318Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella fidelis ATCC BAA-318 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaFidelisAtccBaa318Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336247.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336247.protein.info.v11.5.txt",
		        "node_list_path": "1336247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteiniclasticumRuminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteiniclasticum ruminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteiniclasticumRuminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410668.protein.info.v11.5.txt",
		        "node_list_path": "1410668.protein.complete.v11.5.txt"
		    }
		]
    )()

def FaecalitaleaCylindroidesT287(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Faecalitalea cylindroides T2-87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalitaleaCylindroidesT287", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717960.protein.sequences.v11.5.fa",
		        "enrichment_path": "717960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717960.protein.info.v11.5.txt",
		        "node_list_path": "717960.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfofarcimenIntricatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfofarcimen intricatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfofarcimenIntricatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1285191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1285191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1285191.protein.info.v11.5.txt",
		        "node_list_path": "1285191.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeeksellaSpFf8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weeksella sp. FF8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeeksellaSpFf8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461577.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461577.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461577.protein.info.v11.5.txt",
		        "node_list_path": "1461577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNiyogibacteriaBacteriumRifcsplowo202Full4513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Niyogibacteria bacterium RIFCSPLOWO2_02_FULL_45_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNiyogibacteriaBacteriumRifcsplowo202Full4513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801725.protein.info.v11.5.txt",
		        "node_list_path": "1801725.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumPiscicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium piscicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumPiscicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "551459.protein.sequences.v11.5.fa",
		        "enrichment_path": "551459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551459.protein.info.v11.5.txt",
		        "node_list_path": "551459.protein.complete.v11.5.txt"
		    }
		]
    )()

def KaistiaGranuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kaistia granuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KaistiaGranuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122132.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122132.protein.info.v11.5.txt",
		        "node_list_path": "1122132.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhialocephalaScopiformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phialocephala scopiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhialocephalaScopiformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "149040.protein.sequences.v11.5.fa",
		        "enrichment_path": "149040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "149040.protein.info.v11.5.txt",
		        "node_list_path": "149040.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusGarvieaeLg2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae Lg2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusGarvieaeLg2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "420890.protein.sequences.v11.5.fa",
		        "enrichment_path": "420890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420890.protein.info.v11.5.txt",
		        "node_list_path": "420890.protein.complete.v11.5.txt"
		    }
		]
    )()

def TheobromaCacaoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Theobroma cacao Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheobromaCacaoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3641.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3641.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3641.clusters.proteins.v11.5.txt",
		        "sequence_path": "3641.protein.sequences.v11.5.fa",
		        "enrichment_path": "3641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3641.protein.info.v11.5.txt",
		        "node_list_path": "3641.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3641.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFermentum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fermentum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFermentum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1613.protein.info.v11.5.txt",
		        "node_list_path": "1613.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterSpFy07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter sp. FY-07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterSpFy07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1692238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1692238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1692238.protein.info.v11.5.txt",
		        "node_list_path": "1692238.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumCaeni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumCaeni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121285.protein.info.v11.5.txt",
		        "node_list_path": "1121285.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaErythra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella erythra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaErythra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "448.protein.sequences.v11.5.fa",
		        "enrichment_path": "448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "448.protein.info.v11.5.txt",
		        "node_list_path": "448.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpShues1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. SHUES1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpShues1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849383.protein.info.v11.5.txt",
		        "node_list_path": "1849383.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterGossypiicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter gossypiicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterGossypiicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "551995.clusters.info.v11.5.txt",
		        "cluster_tree_path": "551995.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "551995.clusters.proteins.v11.5.txt",
		        "sequence_path": "551995.protein.sequences.v11.5.fa",
		        "enrichment_path": "551995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551995.protein.info.v11.5.txt",
		        "node_list_path": "551995.cluster.nodes.v11.5.txt",
		        "edge_list_path": "551995.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisSpAc460Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC460 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisSpAc460Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1282360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1282360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1282360.clusters.proteins.v11.5.txt",
		        "sequence_path": "1282360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282360.protein.info.v11.5.txt",
		        "node_list_path": "1282360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1282360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetarhiziumRobertsiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium robertsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetarhiziumRobertsiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "568076.clusters.info.v11.5.txt",
		        "cluster_tree_path": "568076.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "568076.clusters.proteins.v11.5.txt",
		        "sequence_path": "568076.protein.sequences.v11.5.fa",
		        "enrichment_path": "568076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568076.protein.info.v11.5.txt",
		        "node_list_path": "568076.cluster.nodes.v11.5.txt",
		        "edge_list_path": "568076.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusPlurextorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus plurextorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPlurextorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123314.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123314.protein.info.v11.5.txt",
		        "node_list_path": "1123314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SingulisphaeraAcidiphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Singulisphaera acidiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SingulisphaeraAcidiphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "886293.protein.sequences.v11.5.fa",
		        "enrichment_path": "886293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "886293.protein.info.v11.5.txt",
		        "node_list_path": "886293.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusLacisalsi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus lacisalsi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusLacisalsi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121929.protein.info.v11.5.txt",
		        "node_list_path": "1121929.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophilaceaeBacterium11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophilaceae bacterium 11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilaceaeBacterium11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1101195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1101195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1101195.clusters.proteins.v11.5.txt",
		        "sequence_path": "1101195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101195.protein.info.v11.5.txt",
		        "node_list_path": "1101195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1101195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnsiferGlycinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer glycinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferGlycinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1472378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1472378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1472378.clusters.proteins.v11.5.txt",
		        "sequence_path": "1472378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1472378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1472378.protein.info.v11.5.txt",
		        "node_list_path": "1472378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1472378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MobiluncusMulieris281Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris 281 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobiluncusMulieris281Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596328.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596328.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596328.clusters.proteins.v11.5.txt",
		        "sequence_path": "596328.protein.sequences.v11.5.fa",
		        "enrichment_path": "596328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596328.protein.info.v11.5.txt",
		        "node_list_path": "596328.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596328.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EmpedobacterFalseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Empedobacter falsenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmpedobacterFalseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "343874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "343874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "343874.clusters.proteins.v11.5.txt",
		        "sequence_path": "343874.protein.sequences.v11.5.fa",
		        "enrichment_path": "343874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "343874.protein.info.v11.5.txt",
		        "node_list_path": "343874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "343874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpStm4661Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. STM4661 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpStm4661Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1297570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1297570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1297570.clusters.proteins.v11.5.txt",
		        "sequence_path": "1297570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297570.protein.info.v11.5.txt",
		        "node_list_path": "1297570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1297570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusYeeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus yeei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusYeeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1446473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1446473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1446473.clusters.proteins.v11.5.txt",
		        "sequence_path": "1446473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1446473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1446473.protein.info.v11.5.txt",
		        "node_list_path": "1446473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1446473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomirabilisOxyferaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomirabilis oxyfera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomirabilisOxyferaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "671143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "671143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "671143.clusters.proteins.v11.5.txt",
		        "sequence_path": "671143.protein.sequences.v11.5.fa",
		        "enrichment_path": "671143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "671143.protein.info.v11.5.txt",
		        "node_list_path": "671143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "671143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidiphiliumRubrum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidiphilium rubrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidiphiliumRubrum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "526.protein.sequences.v11.5.fa",
		        "enrichment_path": "526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526.protein.info.v11.5.txt",
		        "node_list_path": "526.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusTengchongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus tengchongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusTengchongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449357.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449357.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449357.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449357.protein.info.v11.5.txt",
		        "node_list_path": "1449357.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449357.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodonellumIkkaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodonellum ikkaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodonellumIkkaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "336829.clusters.info.v11.5.txt",
		        "cluster_tree_path": "336829.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "336829.clusters.proteins.v11.5.txt",
		        "sequence_path": "336829.protein.sequences.v11.5.fa",
		        "enrichment_path": "336829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336829.protein.info.v11.5.txt",
		        "node_list_path": "336829.cluster.nodes.v11.5.txt",
		        "edge_list_path": "336829.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpNfr16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. NFR16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpNfr16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566248.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566248.protein.info.v11.5.txt",
		        "node_list_path": "1566248.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpUnc362mftsu51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UNC362MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpUnc362mftsu51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449044.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449044.protein.info.v11.5.txt",
		        "node_list_path": "1449044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarssoninaBrunneaFSpMultigermtubiMbM1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marssonina brunnea f. sp. multigermtubi MB_m1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarssoninaBrunneaFSpMultigermtubiMbM1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1072389.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1072389.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1072389.clusters.proteins.v11.5.txt",
		        "sequence_path": "1072389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1072389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1072389.protein.info.v11.5.txt",
		        "node_list_path": "1072389.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1072389.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PararhizobiumAntarcticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pararhizobium antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PararhizobiumAntarcticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798805.protein.info.v11.5.txt",
		        "node_list_path": "1798805.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumBal199Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium BAL199 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumBal199Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "331869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "331869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "331869.clusters.proteins.v11.5.txt",
		        "sequence_path": "331869.protein.sequences.v11.5.fa",
		        "enrichment_path": "331869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331869.protein.info.v11.5.txt",
		        "node_list_path": "331869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "331869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls337(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS337 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls337", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463900.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463900.protein.info.v11.5.txt",
		        "node_list_path": "1463900.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaSpHh13063007Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. HH130630-07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaSpHh13063007Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1690815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1690815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1690815.clusters.proteins.v11.5.txt",
		        "sequence_path": "1690815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690815.protein.info.v11.5.txt",
		        "node_list_path": "1690815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1690815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharopolysporaFlava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharopolyspora flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharopolysporaFlava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "95161.protein.sequences.v11.5.fa",
		        "enrichment_path": "95161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "95161.protein.info.v11.5.txt",
		        "node_list_path": "95161.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoculleusThermophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusThermophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2200.clusters.proteins.v11.5.txt",
		        "sequence_path": "2200.protein.sequences.v11.5.fa",
		        "enrichment_path": "2200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2200.protein.info.v11.5.txt",
		        "node_list_path": "2200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusOryzisoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus oryzisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusOryzisoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1850517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850517.protein.info.v11.5.txt",
		        "node_list_path": "1850517.protein.complete.v11.5.txt"
		    }
		]
    )()

def EptatretusBurgeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eptatretus burgeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EptatretusBurgeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7764.clusters.proteins.v11.5.txt",
		        "sequence_path": "7764.protein.sequences.v11.5.fa",
		        "enrichment_path": "7764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7764.protein.info.v11.5.txt",
		        "node_list_path": "7764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophagaMuralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga muralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaMuralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "291169.clusters.info.v11.5.txt",
		        "cluster_tree_path": "291169.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "291169.clusters.proteins.v11.5.txt",
		        "sequence_path": "291169.protein.sequences.v11.5.fa",
		        "enrichment_path": "291169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "291169.protein.info.v11.5.txt",
		        "node_list_path": "291169.cluster.nodes.v11.5.txt",
		        "edge_list_path": "291169.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EndolissoclinumFaulkneriL2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Endolissoclinum faulkneri L2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndolissoclinumFaulkneriL2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193729.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193729.protein.info.v11.5.txt",
		        "node_list_path": "1193729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaCaballeronis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia caballeronis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaCaballeronis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "416943.protein.sequences.v11.5.fa",
		        "enrichment_path": "416943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416943.protein.info.v11.5.txt",
		        "node_list_path": "416943.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasElongataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas elongata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasElongataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "768066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "768066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "768066.clusters.proteins.v11.5.txt",
		        "sequence_path": "768066.protein.sequences.v11.5.fa",
		        "enrichment_path": "768066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768066.protein.info.v11.5.txt",
		        "node_list_path": "768066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "768066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHdn1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HdN1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHdn1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83406.protein.sequences.v11.5.fa",
		        "enrichment_path": "83406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83406.protein.info.v11.5.txt",
		        "node_list_path": "83406.protein.complete.v11.5.txt"
		    }
		]
    )()

def AkkermansiaSpCag344Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Akkermansia sp. CAG:344 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AkkermansiaSpCag344Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262691.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262691.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262691.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262691.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262691.protein.info.v11.5.txt",
		        "node_list_path": "1262691.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262691.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RiemerellaColumbinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Riemerella columbina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RiemerellaColumbinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123058.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123058.protein.info.v11.5.txt",
		        "node_list_path": "1123058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSubglaciescola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas subglaciescola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSubglaciescola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29571.protein.sequences.v11.5.fa",
		        "enrichment_path": "29571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29571.protein.info.v11.5.txt",
		        "node_list_path": "29571.protein.complete.v11.5.txt"
		    }
		]
    )()

def SneathiaAmniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sneathia amnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SneathiaAmniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "187101.clusters.info.v11.5.txt",
		        "cluster_tree_path": "187101.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "187101.clusters.proteins.v11.5.txt",
		        "sequence_path": "187101.protein.sequences.v11.5.fa",
		        "enrichment_path": "187101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "187101.protein.info.v11.5.txt",
		        "node_list_path": "187101.cluster.nodes.v11.5.txt",
		        "edge_list_path": "187101.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGa0077532Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077532 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077532Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752201.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752201.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752201.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752201.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752201.protein.info.v11.5.txt",
		        "node_list_path": "1752201.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752201.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XylonaHeveaeTc161Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylona heveae TC161 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylonaHeveaeTc161Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1328760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1328760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1328760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1328760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1328760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1328760.protein.info.v11.5.txt",
		        "node_list_path": "1328760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1328760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGa0077527Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077527 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077527Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752200.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752200.protein.info.v11.5.txt",
		        "node_list_path": "1752200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumRs24Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium RS24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumRs24Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397666.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397666.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397666.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397666.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397666.protein.info.v11.5.txt",
		        "node_list_path": "1397666.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397666.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsphigho201Full4815Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO2_01_FULL_48_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201Full4815Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802619.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802619.protein.info.v11.5.txt",
		        "node_list_path": "1802619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CricetulusGriseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cricetulus griseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CricetulusGriseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10029.clusters.proteins.v11.5.txt",
		        "sequence_path": "10029.protein.sequences.v11.5.fa",
		        "enrichment_path": "10029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10029.protein.info.v11.5.txt",
		        "node_list_path": "10029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophusGentianae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophus gentianae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophusGentianae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43775.protein.sequences.v11.5.fa",
		        "enrichment_path": "43775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43775.protein.info.v11.5.txt",
		        "node_list_path": "43775.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarichromatiumPurpuratum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marichromatium purpuratum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarichromatiumPurpuratum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765910.protein.sequences.v11.5.fa",
		        "enrichment_path": "765910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765910.protein.info.v11.5.txt",
		        "node_list_path": "765910.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu013(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu013", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671648.protein.info.v11.5.txt",
		        "node_list_path": "1671648.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrusSinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrus sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrusSinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2711.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2711.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2711.clusters.proteins.v11.5.txt",
		        "sequence_path": "2711.protein.sequences.v11.5.fa",
		        "enrichment_path": "2711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2711.protein.info.v11.5.txt",
		        "node_list_path": "2711.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2711.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpQxt31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. QXT-31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpQxt31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1357916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357916.protein.info.v11.5.txt",
		        "node_list_path": "1357916.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumRifcsphigho201Full4526Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPHIGHO2_01_FULL_45_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsphigho201Full4526Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817737.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817737.protein.info.v11.5.txt",
		        "node_list_path": "1817737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCurieae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus curieae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCurieae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1138822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1138822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1138822.protein.info.v11.5.txt",
		        "node_list_path": "1138822.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhaeobacterSp11andimar09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter sp. 11ANDIMAR09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterSp11andimar09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1225647.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1225647.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1225647.clusters.proteins.v11.5.txt",
		        "sequence_path": "1225647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225647.protein.info.v11.5.txt",
		        "node_list_path": "1225647.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1225647.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpPcc7002Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpPcc7002Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32049.clusters.proteins.v11.5.txt",
		        "sequence_path": "32049.protein.sequences.v11.5.fa",
		        "enrichment_path": "32049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32049.protein.info.v11.5.txt",
		        "node_list_path": "32049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbiconiuxGinsengiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbiconiux ginsengi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbiconiuxGinsengiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "381665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "381665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "381665.clusters.proteins.v11.5.txt",
		        "sequence_path": "381665.protein.sequences.v11.5.fa",
		        "enrichment_path": "381665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381665.protein.info.v11.5.txt",
		        "node_list_path": "381665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "381665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpOk605Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. OK605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpOk605Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855317.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855317.protein.info.v11.5.txt",
		        "node_list_path": "1855317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RicinusCommunis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ricinus communis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RicinusCommunis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3988.protein.sequences.v11.5.fa",
		        "enrichment_path": "3988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3988.protein.info.v11.5.txt",
		        "node_list_path": "3988.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpS4c9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. S4C9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpS4c9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219581.protein.info.v11.5.txt",
		        "node_list_path": "1219581.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisFlavescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisFlavescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "758803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "758803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "758803.clusters.proteins.v11.5.txt",
		        "sequence_path": "758803.protein.sequences.v11.5.fa",
		        "enrichment_path": "758803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758803.protein.info.v11.5.txt",
		        "node_list_path": "758803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "758803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZymomonasMobilisPomaceaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymomonas mobilis pomaceae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymomonasMobilisPomaceaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "579138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "579138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "579138.clusters.proteins.v11.5.txt",
		        "sequence_path": "579138.protein.sequences.v11.5.fa",
		        "enrichment_path": "579138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579138.protein.info.v11.5.txt",
		        "node_list_path": "579138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "579138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkanindigesSpH1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkanindiges sp. H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkanindigesSpH1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907941.protein.info.v11.5.txt",
		        "node_list_path": "1907941.protein.complete.v11.5.txt"
		    }
		]
    )()

def GymnopilusDilepis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gymnopilus dilepis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GymnopilusDilepis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "231916.protein.sequences.v11.5.fa",
		        "enrichment_path": "231916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "231916.protein.info.v11.5.txt",
		        "node_list_path": "231916.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesmosporaSp8437Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desmospora sp. 8437 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesmosporaSp8437Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "997346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "997346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "997346.clusters.proteins.v11.5.txt",
		        "sequence_path": "997346.protein.sequences.v11.5.fa",
		        "enrichment_path": "997346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997346.protein.info.v11.5.txt",
		        "node_list_path": "997346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "997346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorOwensensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor owensensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorOwensensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "632518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "632518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "632518.clusters.proteins.v11.5.txt",
		        "sequence_path": "632518.protein.sequences.v11.5.fa",
		        "enrichment_path": "632518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632518.protein.info.v11.5.txt",
		        "node_list_path": "632518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "632518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumFreiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium freii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumFreiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "48697.clusters.info.v11.5.txt",
		        "cluster_tree_path": "48697.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "48697.clusters.proteins.v11.5.txt",
		        "sequence_path": "48697.protein.sequences.v11.5.fa",
		        "enrichment_path": "48697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48697.protein.info.v11.5.txt",
		        "node_list_path": "48697.cluster.nodes.v11.5.txt",
		        "edge_list_path": "48697.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaribacterSp12014mblMicdiv(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter sp. 1_2014MBL_MicDiv graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterSp12014mblMicdiv", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1644130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1644130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1644130.protein.info.v11.5.txt",
		        "node_list_path": "1644130.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidithiobacillusCaldusSm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus caldus SM-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithiobacillusCaldusSm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "990288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "990288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "990288.clusters.proteins.v11.5.txt",
		        "sequence_path": "990288.protein.sequences.v11.5.fa",
		        "enrichment_path": "990288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990288.protein.info.v11.5.txt",
		        "node_list_path": "990288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "990288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisNigrescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis nigrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisNigrescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1068980.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1068980.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1068980.clusters.proteins.v11.5.txt",
		        "sequence_path": "1068980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1068980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1068980.protein.info.v11.5.txt",
		        "node_list_path": "1068980.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1068980.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpBgarf1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. BGARF1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpBgarf1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1664319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1664319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1664319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1664319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1664319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1664319.protein.info.v11.5.txt",
		        "node_list_path": "1664319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1664319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpCp53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Cp53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpCp53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "443598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "443598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "443598.clusters.proteins.v11.5.txt",
		        "sequence_path": "443598.protein.sequences.v11.5.fa",
		        "enrichment_path": "443598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443598.protein.info.v11.5.txt",
		        "node_list_path": "443598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "443598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeleribacterIndicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Celeribacter indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeleribacterIndicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208324.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208324.protein.info.v11.5.txt",
		        "node_list_path": "1208324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusPakistanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus pakistanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusPakistanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "759811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "759811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "759811.clusters.proteins.v11.5.txt",
		        "sequence_path": "759811.protein.sequences.v11.5.fa",
		        "enrichment_path": "759811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759811.protein.info.v11.5.txt",
		        "node_list_path": "759811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "759811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IsosphaeraPallida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Isosphaera pallida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IsosphaeraPallida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575540.protein.sequences.v11.5.fa",
		        "enrichment_path": "575540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575540.protein.info.v11.5.txt",
		        "node_list_path": "575540.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusHesperidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus hesperidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusHesperidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "89784.protein.sequences.v11.5.fa",
		        "enrichment_path": "89784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89784.protein.info.v11.5.txt",
		        "node_list_path": "89784.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHomeothermusArabinoxylanisolvensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Homeothermus arabinoxylanisolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHomeothermusArabinoxylanisolvensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2005518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2005518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2005518.clusters.proteins.v11.5.txt",
		        "sequence_path": "2005518.protein.sequences.v11.5.fa",
		        "enrichment_path": "2005518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2005518.protein.info.v11.5.txt",
		        "node_list_path": "2005518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2005518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumLjungdahliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium ljungdahlii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumLjungdahliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "748727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "748727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "748727.clusters.proteins.v11.5.txt",
		        "sequence_path": "748727.protein.sequences.v11.5.fa",
		        "enrichment_path": "748727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748727.protein.info.v11.5.txt",
		        "node_list_path": "748727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "748727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusTorquesAtcc27756Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus torques ATCC27756 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusTorquesAtcc27756Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411460.clusters.proteins.v11.5.txt",
		        "sequence_path": "411460.protein.sequences.v11.5.fa",
		        "enrichment_path": "411460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411460.protein.info.v11.5.txt",
		        "node_list_path": "411460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TsukamurellaSp1534Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tsukamurella sp. 1534 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TsukamurellaSp1534Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1151061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1151061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1151061.clusters.proteins.v11.5.txt",
		        "sequence_path": "1151061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151061.protein.info.v11.5.txt",
		        "node_list_path": "1151061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1151061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPelagia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pelagia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPelagia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1323663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1323663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1323663.protein.info.v11.5.txt",
		        "node_list_path": "1323663.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag192(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:192 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag192", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262883.protein.info.v11.5.txt",
		        "node_list_path": "1262883.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaHippikon(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma hippikon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaHippikon", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408416.protein.info.v11.5.txt",
		        "node_list_path": "1408416.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobaculumSuis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum suis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobaculumSuis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1657.protein.info.v11.5.txt",
		        "node_list_path": "1657.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarssoninaBrunnea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marssonina brunnea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarssoninaBrunnea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "698440.protein.sequences.v11.5.fa",
		        "enrichment_path": "698440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698440.protein.info.v11.5.txt",
		        "node_list_path": "698440.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaSediminilitorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia sediminilitoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaSediminilitorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1820336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1820336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1820336.clusters.proteins.v11.5.txt",
		        "sequence_path": "1820336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1820336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1820336.protein.info.v11.5.txt",
		        "node_list_path": "1820336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1820336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DonghicolaEburneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Donghicola eburneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DonghicolaEburneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "393278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "393278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "393278.clusters.proteins.v11.5.txt",
		        "sequence_path": "393278.protein.sequences.v11.5.fa",
		        "enrichment_path": "393278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393278.protein.info.v11.5.txt",
		        "node_list_path": "393278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "393278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeorhizobiumGalegaeOfficinalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae officinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorhizobiumGalegaeOfficinalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1028801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1028801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1028801.clusters.proteins.v11.5.txt",
		        "sequence_path": "1028801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028801.protein.info.v11.5.txt",
		        "node_list_path": "1028801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1028801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VirgibacillusSenegalensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusSenegalensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499679.protein.info.v11.5.txt",
		        "node_list_path": "1499679.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpDd11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpDd11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777879.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777879.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777879.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777879.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777879.protein.info.v11.5.txt",
		        "node_list_path": "1777879.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777879.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorientalisRegularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorientalis regularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorientalisRegularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "660518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "660518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "660518.clusters.proteins.v11.5.txt",
		        "sequence_path": "660518.protein.sequences.v11.5.fa",
		        "enrichment_path": "660518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660518.protein.info.v11.5.txt",
		        "node_list_path": "660518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "660518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StrongyloidesVenezuelensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Strongyloides venezuelensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrongyloidesVenezuelensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "75913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "75913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "75913.clusters.proteins.v11.5.txt",
		        "sequence_path": "75913.protein.sequences.v11.5.fa",
		        "enrichment_path": "75913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75913.protein.info.v11.5.txt",
		        "node_list_path": "75913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "75913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSpV48Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. V48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpV48Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "509635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "509635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "509635.clusters.proteins.v11.5.txt",
		        "sequence_path": "509635.protein.sequences.v11.5.fa",
		        "enrichment_path": "509635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "509635.protein.info.v11.5.txt",
		        "node_list_path": "509635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "509635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumYuriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium yurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumYuriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "864565.clusters.info.v11.5.txt",
		        "cluster_tree_path": "864565.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "864565.clusters.proteins.v11.5.txt",
		        "sequence_path": "864565.protein.sequences.v11.5.fa",
		        "enrichment_path": "864565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864565.protein.info.v11.5.txt",
		        "node_list_path": "864565.cluster.nodes.v11.5.txt",
		        "edge_list_path": "864565.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaFortuita(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia fortuita graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaFortuita", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777138.protein.info.v11.5.txt",
		        "node_list_path": "1777138.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhaeospirillumMolischianum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeospirillum molischianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeospirillumMolischianum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150626.protein.info.v11.5.txt",
		        "node_list_path": "1150626.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumLongumNcc2705(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium longum NCC2705 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumLongumNcc2705", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "206672.protein.sequences.v11.5.fa",
		        "enrichment_path": "206672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "206672.protein.info.v11.5.txt",
		        "node_list_path": "206672.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpGw460121014Lb2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. GW460-12-10-14-LB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpGw460121014Lb2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1827469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827469.protein.info.v11.5.txt",
		        "node_list_path": "1827469.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusJensenii1153chn(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii 1153CHN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusJensenii1153chn", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575605.protein.sequences.v11.5.fa",
		        "enrichment_path": "575605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575605.protein.info.v11.5.txt",
		        "node_list_path": "575605.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrobacterKoseriAtccBaa895Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter koseri ATCC BAA-895 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterKoseriAtccBaa895Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290338.clusters.proteins.v11.5.txt",
		        "sequence_path": "290338.protein.sequences.v11.5.fa",
		        "enrichment_path": "290338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290338.protein.info.v11.5.txt",
		        "node_list_path": "290338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392877.protein.info.v11.5.txt",
		        "node_list_path": "1392877.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobotrysOligosporaAtcc24927Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobotrys oligospora ATCC 24927 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobotrysOligosporaAtcc24927Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "756982.clusters.info.v11.5.txt",
		        "cluster_tree_path": "756982.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "756982.clusters.proteins.v11.5.txt",
		        "sequence_path": "756982.protein.sequences.v11.5.fa",
		        "enrichment_path": "756982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "756982.protein.info.v11.5.txt",
		        "node_list_path": "756982.cluster.nodes.v11.5.txt",
		        "edge_list_path": "756982.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterSpCit045Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. CIT045 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSpCit045Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1448857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1448857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1448857.clusters.proteins.v11.5.txt",
		        "sequence_path": "1448857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448857.protein.info.v11.5.txt",
		        "node_list_path": "1448857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1448857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4417Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_44_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4417Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802668.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802668.protein.info.v11.5.txt",
		        "node_list_path": "1802668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAgalactiaePg2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae PG2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAgalactiaePg2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "347257.protein.sequences.v11.5.fa",
		        "enrichment_path": "347257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "347257.protein.info.v11.5.txt",
		        "node_list_path": "347257.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudovibrioHongkongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioHongkongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1647556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1647556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1647556.clusters.proteins.v11.5.txt",
		        "sequence_path": "1647556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1647556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1647556.protein.info.v11.5.txt",
		        "node_list_path": "1647556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1647556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterPelagius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter pelagius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterPelagius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "379482.protein.sequences.v11.5.fa",
		        "enrichment_path": "379482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "379482.protein.info.v11.5.txt",
		        "node_list_path": "379482.protein.complete.v11.5.txt"
		    }
		]
    )()

def MartelellaSpAd3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Martelella sp. AD-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MartelellaSpAd3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "686597.protein.sequences.v11.5.fa",
		        "enrichment_path": "686597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686597.protein.info.v11.5.txt",
		        "node_list_path": "686597.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusTriatomaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus triatomae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusTriatomaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278078.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278078.protein.info.v11.5.txt",
		        "node_list_path": "1278078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SedimenticolaThiotauriniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sedimenticola thiotaurini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SedimenticolaThiotauriniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1543721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1543721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1543721.clusters.proteins.v11.5.txt",
		        "sequence_path": "1543721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1543721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1543721.protein.info.v11.5.txt",
		        "node_list_path": "1543721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1543721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1024126Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_41_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024126Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805308.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805308.protein.info.v11.5.txt",
		        "node_list_path": "1805308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasSpLm091Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas sp. LM091 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasSpLm091Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1904944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1904944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1904944.clusters.proteins.v11.5.txt",
		        "sequence_path": "1904944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904944.protein.info.v11.5.txt",
		        "node_list_path": "1904944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1904944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaNavojoa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila navojoa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaNavojoa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7232.protein.sequences.v11.5.fa",
		        "enrichment_path": "7232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7232.protein.info.v11.5.txt",
		        "node_list_path": "7232.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteimonasAbyssiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas abyssi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteimonasAbyssiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1247514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1247514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1247514.clusters.proteins.v11.5.txt",
		        "sequence_path": "1247514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1247514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1247514.protein.info.v11.5.txt",
		        "node_list_path": "1247514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1247514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeorickettsiaSennetsuCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neorickettsia sennetsu Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorickettsiaSennetsuCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "222891.clusters.info.v11.5.txt",
		        "cluster_tree_path": "222891.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "222891.clusters.proteins.v11.5.txt",
		        "sequence_path": "222891.protein.sequences.v11.5.fa",
		        "enrichment_path": "222891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "222891.protein.info.v11.5.txt",
		        "node_list_path": "222891.cluster.nodes.v11.5.txt",
		        "edge_list_path": "222891.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFormosensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas formosensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFormosensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1002526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002526.protein.info.v11.5.txt",
		        "node_list_path": "1002526.protein.complete.v11.5.txt"
		    }
		]
    )()

def ViridibacillusArenosiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Viridibacillus arenosi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ViridibacillusArenosiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227360.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227360.protein.info.v11.5.txt",
		        "node_list_path": "1227360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaSmaragdinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta smaragdinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaSmaragdinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573413.protein.sequences.v11.5.fa",
		        "enrichment_path": "573413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573413.protein.info.v11.5.txt",
		        "node_list_path": "573413.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallionellalesBacteriumRifcsplowo212Full5922Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallionellales bacterium RIFCSPLOWO2_12_FULL_59_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallionellalesBacteriumRifcsplowo212Full5922Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798257.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798257.protein.info.v11.5.txt",
		        "node_list_path": "1798257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpLb2008Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. LB2008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpLb2008Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408305.protein.info.v11.5.txt",
		        "node_list_path": "1408305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusColwellbacteriaBacteriumRifcsplowo212Full4311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_12_FULL_43_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo212Full4311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797693.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797693.protein.info.v11.5.txt",
		        "node_list_path": "1797693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusIshikawaellaCapsulataMpkobe(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ishikawaella capsulata Mpkobe graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusIshikawaellaCapsulataMpkobe", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "476281.protein.sequences.v11.5.fa",
		        "enrichment_path": "476281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "476281.protein.info.v11.5.txt",
		        "node_list_path": "476281.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSplendidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio splendidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSplendidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "617140.clusters.info.v11.5.txt",
		        "cluster_tree_path": "617140.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "617140.clusters.proteins.v11.5.txt",
		        "sequence_path": "617140.protein.sequences.v11.5.fa",
		        "enrichment_path": "617140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "617140.protein.info.v11.5.txt",
		        "node_list_path": "617140.cluster.nodes.v11.5.txt",
		        "edge_list_path": "617140.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphaerotilusNatansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaerotilus natans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerotilusNatansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1286631.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1286631.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1286631.clusters.proteins.v11.5.txt",
		        "sequence_path": "1286631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286631.protein.info.v11.5.txt",
		        "node_list_path": "1286631.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1286631.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusEvansiaMuelleriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Evansia muelleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusEvansiaMuelleriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1495769.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1495769.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1495769.clusters.proteins.v11.5.txt",
		        "sequence_path": "1495769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495769.protein.info.v11.5.txt",
		        "node_list_path": "1495769.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1495769.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollinsellaTanakaeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collinsella tanakaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaTanakaeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742742.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742742.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742742.clusters.proteins.v11.5.txt",
		        "sequence_path": "742742.protein.sequences.v11.5.fa",
		        "enrichment_path": "742742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742742.protein.info.v11.5.txt",
		        "node_list_path": "742742.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742742.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AhrensiaSp13gom1096m(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ahrensia sp. 13GOM1096m graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AhrensiaSp13gom1096m", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380380.protein.info.v11.5.txt",
		        "node_list_path": "1380380.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCaldiarchaeumSubterraneum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Caldiarchaeum subterraneum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCaldiarchaeumSubterraneum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "311458.protein.sequences.v11.5.fa",
		        "enrichment_path": "311458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311458.protein.info.v11.5.txt",
		        "node_list_path": "311458.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasCellaseaDsm20118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas cellasea DSM 20118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasCellaseaDsm20118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408250.protein.info.v11.5.txt",
		        "node_list_path": "1408250.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaRhizosphaerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaRhizosphaerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "568872.protein.sequences.v11.5.fa",
		        "enrichment_path": "568872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568872.protein.info.v11.5.txt",
		        "node_list_path": "568872.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpFp211J200(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FP211-J200 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpFp211J200", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1792309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792309.protein.info.v11.5.txt",
		        "node_list_path": "1792309.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpLkl04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. LKL04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpLkl04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "912630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "912630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "912630.clusters.proteins.v11.5.txt",
		        "sequence_path": "912630.protein.sequences.v11.5.fa",
		        "enrichment_path": "912630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "912630.protein.info.v11.5.txt",
		        "node_list_path": "912630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "912630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobiumSpGbchlbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium sp. GBChlB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumSpGbchlbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1519464.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1519464.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1519464.clusters.proteins.v11.5.txt",
		        "sequence_path": "1519464.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519464.protein.info.v11.5.txt",
		        "node_list_path": "1519464.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1519464.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumSpLk1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium sp. LK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumSpLk1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1628193.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1628193.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1628193.clusters.proteins.v11.5.txt",
		        "sequence_path": "1628193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628193.protein.info.v11.5.txt",
		        "node_list_path": "1628193.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1628193.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiumSp3c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. 3C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiumSp3c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1134055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134055.protein.info.v11.5.txt",
		        "node_list_path": "1134055.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpLc3010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. LC3010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpLc3010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280680.protein.info.v11.5.txt",
		        "node_list_path": "1280680.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsphigho202Full5017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPHIGHO2_02_FULL_50_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202Full5017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801857.protein.info.v11.5.txt",
		        "node_list_path": "1801857.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaPhenoliruptrixCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phenoliruptrix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaPhenoliruptrixCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229205.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229205.protein.info.v11.5.txt",
		        "node_list_path": "1229205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSp233421I1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 23342-1-I1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSp233421I1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1524831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1524831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1524831.clusters.proteins.v11.5.txt",
		        "sequence_path": "1524831.protein.sequences.v11.5.fa",
		        "enrichment_path": "1524831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1524831.protein.info.v11.5.txt",
		        "node_list_path": "1524831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1524831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptosporangiumAurantiacum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporangium aurantiacum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptosporangiumAurantiacum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "134849.protein.sequences.v11.5.fa",
		        "enrichment_path": "134849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134849.protein.info.v11.5.txt",
		        "node_list_path": "134849.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumMinimum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium minimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumMinimum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1693.protein.info.v11.5.txt",
		        "node_list_path": "1693.protein.complete.v11.5.txt"
		    }
		]
    )()

def IzhakiellaCapsodisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Izhakiella capsodis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IzhakiellaCapsodisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1367852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1367852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1367852.clusters.proteins.v11.5.txt",
		        "sequence_path": "1367852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1367852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1367852.protein.info.v11.5.txt",
		        "node_list_path": "1367852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1367852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SodalisLikeEndosymbiontOfProechinophthirusFluctusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sodalis-like endosymbiont of Proechinophthirus fluctus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SodalisLikeEndosymbiontOfProechinophthirusFluctusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1462730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1462730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1462730.clusters.proteins.v11.5.txt",
		        "sequence_path": "1462730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462730.protein.info.v11.5.txt",
		        "node_list_path": "1462730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1462730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DiversisporaEpigaea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Diversispora epigaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiversisporaEpigaea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348612.protein.info.v11.5.txt",
		        "node_list_path": "1348612.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaCrocina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia crocina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaCrocina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "429728.protein.sequences.v11.5.fa",
		        "enrichment_path": "429728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "429728.protein.info.v11.5.txt",
		        "node_list_path": "429728.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureobasidiumPullulansExf150(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium pullulans EXF-150 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureobasidiumPullulansExf150", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1043002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1043002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1043002.protein.info.v11.5.txt",
		        "node_list_path": "1043002.protein.complete.v11.5.txt"
		    }
		]
    )()

def AggregatibacterActinomycetemcomitansD7s1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans D7S1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterActinomycetemcomitansD7s1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "694569.protein.sequences.v11.5.fa",
		        "enrichment_path": "694569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694569.protein.info.v11.5.txt",
		        "node_list_path": "694569.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesBarnesiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides barnesiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesBarnesiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121094.protein.info.v11.5.txt",
		        "node_list_path": "1121094.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusParalvinellae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus paralvinellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusParalvinellae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582419.protein.sequences.v11.5.fa",
		        "enrichment_path": "582419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582419.protein.info.v11.5.txt",
		        "node_list_path": "582419.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaConsociataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia consociata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaConsociataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "760117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "760117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "760117.clusters.proteins.v11.5.txt",
		        "sequence_path": "760117.protein.sequences.v11.5.fa",
		        "enrichment_path": "760117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "760117.protein.info.v11.5.txt",
		        "node_list_path": "760117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "760117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MotiliproteusSpMsk221Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Motiliproteus sp. MSK22-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MotiliproteusSpMsk221Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897630.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897630.protein.info.v11.5.txt",
		        "node_list_path": "1897630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumLimigenitumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium limigenitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumLimigenitumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1612149.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1612149.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1612149.clusters.proteins.v11.5.txt",
		        "sequence_path": "1612149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1612149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1612149.protein.info.v11.5.txt",
		        "node_list_path": "1612149.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1612149.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumVentriculiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium ventriculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumVentriculiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267.protein.info.v11.5.txt",
		        "node_list_path": "1267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full4328(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_43_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full4328", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798287.protein.info.v11.5.txt",
		        "node_list_path": "1798287.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesFragilis3112Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis 3112 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFragilis3112Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "457424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "457424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "457424.clusters.proteins.v11.5.txt",
		        "sequence_path": "457424.protein.sequences.v11.5.fa",
		        "enrichment_path": "457424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457424.protein.info.v11.5.txt",
		        "node_list_path": "457424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "457424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AuricoccusIndicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Auricoccus indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AuricoccusIndicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849491.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849491.protein.info.v11.5.txt",
		        "node_list_path": "1849491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpTf25(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. tf2-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpTf25", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761889.protein.info.v11.5.txt",
		        "node_list_path": "1761889.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpA9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. A9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpA9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1284352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284352.protein.info.v11.5.txt",
		        "node_list_path": "1284352.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg136510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_65_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg136510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797835.protein.info.v11.5.txt",
		        "node_list_path": "1797835.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrocarboniphagaEffusaAp103(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga effusa AP103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrocarboniphagaEffusaAp103", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1172194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172194.protein.info.v11.5.txt",
		        "node_list_path": "1172194.protein.complete.v11.5.txt"
		    }
		]
    )()

def KitasatosporaAzatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora azatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaAzatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449346.protein.info.v11.5.txt",
		        "node_list_path": "1449346.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumTrifolii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum trifolii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumTrifolii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5466.protein.sequences.v11.5.fa",
		        "enrichment_path": "5466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5466.protein.info.v11.5.txt",
		        "node_list_path": "5466.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaPiriflorinigransCfbp5888Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia piriflorinigrans CFBP 5888 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaPiriflorinigransCfbp5888Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1161919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1161919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1161919.clusters.proteins.v11.5.txt",
		        "sequence_path": "1161919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1161919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1161919.protein.info.v11.5.txt",
		        "node_list_path": "1161919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1161919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TolypothrixBouteilleiVb521301(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tolypothrix bouteillei VB521301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolypothrixBouteilleiVb521301", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1479485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479485.protein.info.v11.5.txt",
		        "node_list_path": "1479485.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumGw2011Gwa1418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011_GWA1_41_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011Gwa1418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619103.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619103.protein.info.v11.5.txt",
		        "node_list_path": "1619103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpHmsc76g11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. HMSC76G11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpHmsc76g11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1608910.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1608910.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1608910.clusters.proteins.v11.5.txt",
		        "sequence_path": "1608910.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608910.protein.info.v11.5.txt",
		        "node_list_path": "1608910.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1608910.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumXinjiangenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium xinjiangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumXinjiangenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "178356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "178356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "178356.clusters.proteins.v11.5.txt",
		        "sequence_path": "178356.protein.sequences.v11.5.fa",
		        "enrichment_path": "178356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178356.protein.info.v11.5.txt",
		        "node_list_path": "178356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "178356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaDonghaiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina donghaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaDonghaiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "519452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "519452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "519452.clusters.proteins.v11.5.txt",
		        "sequence_path": "519452.protein.sequences.v11.5.fa",
		        "enrichment_path": "519452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519452.protein.info.v11.5.txt",
		        "node_list_path": "519452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "519452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerosporomusaSubterraneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerosporomusa subterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerosporomusaSubterraneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1794912.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1794912.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1794912.clusters.proteins.v11.5.txt",
		        "sequence_path": "1794912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1794912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1794912.protein.info.v11.5.txt",
		        "node_list_path": "1794912.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1794912.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumPhenoliresistensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium phenoliresistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumPhenoliresistensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "396014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "396014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "396014.clusters.proteins.v11.5.txt",
		        "sequence_path": "396014.protein.sequences.v11.5.fa",
		        "enrichment_path": "396014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396014.protein.info.v11.5.txt",
		        "node_list_path": "396014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "396014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpS23321(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. S23321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpS23321", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "335659.protein.sequences.v11.5.fa",
		        "enrichment_path": "335659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335659.protein.info.v11.5.txt",
		        "node_list_path": "335659.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1934988.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934988.protein.info.v11.5.txt",
		        "node_list_path": "1934988.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsplowo201Full3613Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_36_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3613Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798614.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798614.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798614.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798614.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798614.protein.info.v11.5.txt",
		        "node_list_path": "1798614.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798614.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYonathbacteriaBacteriumRifoxyc2Full479Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFOXYC2_FULL_47_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifoxyc2Full479Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802729.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802729.protein.info.v11.5.txt",
		        "node_list_path": "1802729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UrsusMaritimusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ursus maritimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UrsusMaritimusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29073.clusters.proteins.v11.5.txt",
		        "sequence_path": "29073.protein.sequences.v11.5.fa",
		        "enrichment_path": "29073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29073.protein.info.v11.5.txt",
		        "node_list_path": "29073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpHot20860m813o14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. HOT208_60m_813O14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpHot20860m813o14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1961094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961094.protein.info.v11.5.txt",
		        "node_list_path": "1961094.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaPneumoniaeCwl029Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae CWL029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaPneumoniaeCwl029Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "115713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "115713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "115713.clusters.proteins.v11.5.txt",
		        "sequence_path": "115713.protein.sequences.v11.5.fa",
		        "enrichment_path": "115713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115713.protein.info.v11.5.txt",
		        "node_list_path": "115713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "115713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxRadicisN35(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax radicis N35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxRadicisN35", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999386.protein.sequences.v11.5.fa",
		        "enrichment_path": "999386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999386.protein.info.v11.5.txt",
		        "node_list_path": "999386.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4215Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_42_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4215Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797716.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797716.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797716.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797716.protein.info.v11.5.txt",
		        "node_list_path": "1797716.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797716.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlebsiellaSpRitPiD(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella sp. RIT-PI-d graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaSpRitPiD", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1681196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1681196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1681196.protein.info.v11.5.txt",
		        "node_list_path": "1681196.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusKwashiorkoriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus kwashiorkori Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusKwashiorkoriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1522318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1522318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1522318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1522318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522318.protein.info.v11.5.txt",
		        "node_list_path": "1522318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1522318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaCherriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella cherrii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaCherriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28084.clusters.proteins.v11.5.txt",
		        "sequence_path": "28084.protein.sequences.v11.5.fa",
		        "enrichment_path": "28084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28084.protein.info.v11.5.txt",
		        "node_list_path": "28084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlF4489(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL F-4489 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlF4489", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1609095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1609095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1609095.protein.info.v11.5.txt",
		        "node_list_path": "1609095.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterPapayaeJcm25143Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter papayae JCM 25143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterPapayaeJcm25143Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1234671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1234671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1234671.clusters.proteins.v11.5.txt",
		        "sequence_path": "1234671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234671.protein.info.v11.5.txt",
		        "node_list_path": "1234671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1234671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121897.protein.info.v11.5.txt",
		        "node_list_path": "1121897.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfurellaAcetivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurella acetivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurellaAcetivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "694431.protein.sequences.v11.5.fa",
		        "enrichment_path": "694431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694431.protein.info.v11.5.txt",
		        "node_list_path": "694431.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumBouchesdurhonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium bouchesdurhonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumBouchesdurhonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720192.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720192.protein.info.v11.5.txt",
		        "node_list_path": "1720192.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonasSpRcc299Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonas sp. RCC299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonasSpRcc299Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "296587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "296587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "296587.clusters.proteins.v11.5.txt",
		        "sequence_path": "296587.protein.sequences.v11.5.fa",
		        "enrichment_path": "296587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "296587.protein.info.v11.5.txt",
		        "node_list_path": "296587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "296587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelomonasSpRoot1237(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1237 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelomonasSpRoot1237", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736434.protein.info.v11.5.txt",
		        "node_list_path": "1736434.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsplowo202Full468(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_02_FULL_46_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo202Full468", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797879.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797879.protein.info.v11.5.txt",
		        "node_list_path": "1797879.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpScn6822Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. SCN 68-22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpScn6822Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660087.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660087.protein.info.v11.5.txt",
		        "node_list_path": "1660087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AkkermansiaMuciniphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Akkermansia muciniphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AkkermansiaMuciniphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349741.protein.sequences.v11.5.fa",
		        "enrichment_path": "349741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349741.protein.info.v11.5.txt",
		        "node_list_path": "349741.protein.complete.v11.5.txt"
		    }
		]
    )()

def IsosphaeraPallidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Isosphaera pallida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IsosphaeraPallidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575540.clusters.proteins.v11.5.txt",
		        "sequence_path": "575540.protein.sequences.v11.5.fa",
		        "enrichment_path": "575540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575540.protein.info.v11.5.txt",
		        "node_list_path": "575540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloactinobacteriumAlbumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloactinobacterium album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloactinobacteriumAlbumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "648782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "648782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "648782.clusters.proteins.v11.5.txt",
		        "sequence_path": "648782.protein.sequences.v11.5.fa",
		        "enrichment_path": "648782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "648782.protein.info.v11.5.txt",
		        "node_list_path": "648782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "648782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFermentibacterDaniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fermentibacter daniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFermentibacterDaniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729713.protein.info.v11.5.txt",
		        "node_list_path": "1729713.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarivirgaSpAntB6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marivirga sp. ANT-B6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivirgaSpAntB6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1844760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1844760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1844760.protein.info.v11.5.txt",
		        "node_list_path": "1844760.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4515(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFCSPLOWO2_02_FULL_45_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4515", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797988.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797988.protein.info.v11.5.txt",
		        "node_list_path": "1797988.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumRhizosphaerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumRhizosphaerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1638985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638985.protein.info.v11.5.txt",
		        "node_list_path": "1638985.protein.complete.v11.5.txt"
		    }
		]
    )()

def TidjanibacterMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tidjanibacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TidjanibacterMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871003.protein.info.v11.5.txt",
		        "node_list_path": "1871003.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusThermophilusHb27(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus HB27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusThermophilusHb27", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262724.protein.sequences.v11.5.fa",
		        "enrichment_path": "262724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262724.protein.info.v11.5.txt",
		        "node_list_path": "262724.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfCulexCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Culex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfCulexCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "570417.clusters.info.v11.5.txt",
		        "cluster_tree_path": "570417.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "570417.clusters.proteins.v11.5.txt",
		        "sequence_path": "570417.protein.sequences.v11.5.fa",
		        "enrichment_path": "570417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570417.protein.info.v11.5.txt",
		        "node_list_path": "570417.cluster.nodes.v11.5.txt",
		        "edge_list_path": "570417.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807734.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807734.protein.info.v11.5.txt",
		        "node_list_path": "1807734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCarsonellaRuddiiPv(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii PV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCarsonellaRuddiiPv", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "387662.protein.sequences.v11.5.fa",
		        "enrichment_path": "387662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "387662.protein.info.v11.5.txt",
		        "node_list_path": "387662.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesMediterranea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces mediterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesMediterranea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871028.protein.info.v11.5.txt",
		        "node_list_path": "1871028.protein.complete.v11.5.txt"
		    }
		]
    )()

def MillisiaBrevisNbrc105863(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Millisia brevis NBRC 105863 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MillisiaBrevisNbrc105863", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219361.protein.info.v11.5.txt",
		        "node_list_path": "1219361.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat29814Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-29814 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat29814Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729688.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729688.protein.info.v11.5.txt",
		        "node_list_path": "1729688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpilithonimonasSpFh1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas sp. FH1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpilithonimonasSpFh1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1233951.protein.sequences.v11.5.fa",
		        "enrichment_path": "1233951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1233951.protein.info.v11.5.txt",
		        "node_list_path": "1233951.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZunongwangiaAtlantica22ii1410f7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zunongwangia atlantica 22II14-10F7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZunongwangiaAtlantica22ii1410f7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1185767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1185767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1185767.clusters.proteins.v11.5.txt",
		        "sequence_path": "1185767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185767.protein.info.v11.5.txt",
		        "node_list_path": "1185767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1185767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacterium13140cm6927Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_1_40CM_69_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacterium13140cm6927Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805367.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805367.protein.info.v11.5.txt",
		        "node_list_path": "1805367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterSpCag977(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter sp. CAG:977 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterSpCag977", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262685.protein.info.v11.5.txt",
		        "node_list_path": "1262685.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteipulveratusMongoliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteipulveratus mongoliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteipulveratusMongoliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "571913.protein.sequences.v11.5.fa",
		        "enrichment_path": "571913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571913.protein.info.v11.5.txt",
		        "node_list_path": "571913.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseobacterSpAzwk3bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. AzwK3b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterSpAzwk3bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351016.clusters.proteins.v11.5.txt",
		        "sequence_path": "351016.protein.sequences.v11.5.fa",
		        "enrichment_path": "351016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351016.protein.info.v11.5.txt",
		        "node_list_path": "351016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAespoeensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio aespoeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAespoeensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "643562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "643562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "643562.clusters.proteins.v11.5.txt",
		        "sequence_path": "643562.protein.sequences.v11.5.fa",
		        "enrichment_path": "643562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "643562.protein.info.v11.5.txt",
		        "node_list_path": "643562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "643562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpKk3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. KK3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpKk3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855728.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855728.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855728.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855728.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855728.protein.info.v11.5.txt",
		        "node_list_path": "1855728.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855728.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusPaucivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paucivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPaucivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "616990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "616990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "616990.clusters.proteins.v11.5.txt",
		        "sequence_path": "616990.protein.sequences.v11.5.fa",
		        "enrichment_path": "616990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "616990.protein.info.v11.5.txt",
		        "node_list_path": "616990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "616990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusBrasiliensisCbs101740(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus brasiliensis CBS 101740 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusBrasiliensisCbs101740", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "767769.protein.sequences.v11.5.fa",
		        "enrichment_path": "767769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767769.protein.info.v11.5.txt",
		        "node_list_path": "767769.protein.complete.v11.5.txt"
		    }
		]
    )()

def OperophteraBrumata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Operophtera brumata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OperophteraBrumata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "104452.protein.sequences.v11.5.fa",
		        "enrichment_path": "104452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104452.protein.info.v11.5.txt",
		        "node_list_path": "104452.protein.complete.v11.5.txt"
		    }
		]
    )()

def KandleriaVitulinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kandleria vitulina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KandleriaVitulinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410658.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410658.protein.info.v11.5.txt",
		        "node_list_path": "1410658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRbg165811(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_58_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRbg165811", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797476.protein.info.v11.5.txt",
		        "node_list_path": "1797476.protein.complete.v11.5.txt"
		    }
		]
    )()

def KocuriaRhizophilaP74(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kocuria rhizophila P74 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaRhizophilaP74", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1029824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1029824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1029824.protein.info.v11.5.txt",
		        "node_list_path": "1029824.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerticilliumLongisporumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verticillium longisporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerticilliumLongisporumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "100787.clusters.info.v11.5.txt",
		        "cluster_tree_path": "100787.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "100787.clusters.proteins.v11.5.txt",
		        "sequence_path": "100787.protein.sequences.v11.5.fa",
		        "enrichment_path": "100787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "100787.protein.info.v11.5.txt",
		        "node_list_path": "100787.cluster.nodes.v11.5.txt",
		        "edge_list_path": "100787.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MuricaudaSpMar201075(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Muricauda sp. MAR201075 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuricaudaSpMar201075", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1250232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250232.protein.info.v11.5.txt",
		        "node_list_path": "1250232.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrigoribacteriumSpLeaf415Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf415 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrigoribacteriumSpLeaf415Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736372.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736372.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736372.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736372.protein.info.v11.5.txt",
		        "node_list_path": "1736372.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736372.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumGwc24544Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWC2_45_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumGwc24544Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801952.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801952.protein.info.v11.5.txt",
		        "node_list_path": "1801952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonCaspThauma3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon casp-thauma3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonCaspThauma3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1661713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1661713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1661713.clusters.proteins.v11.5.txt",
		        "sequence_path": "1661713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661713.protein.info.v11.5.txt",
		        "node_list_path": "1661713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1661713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumEuropaeumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium europaeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumEuropaeumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "761804.clusters.info.v11.5.txt",
		        "cluster_tree_path": "761804.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "761804.clusters.proteins.v11.5.txt",
		        "sequence_path": "761804.protein.sequences.v11.5.fa",
		        "enrichment_path": "761804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "761804.protein.info.v11.5.txt",
		        "node_list_path": "761804.cluster.nodes.v11.5.txt",
		        "edge_list_path": "761804.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMosseliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mosselii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMosseliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1388763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1388763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1388763.clusters.proteins.v11.5.txt",
		        "sequence_path": "1388763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1388763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1388763.protein.info.v11.5.txt",
		        "node_list_path": "1388763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1388763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronorubrumBangenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronorubrum bangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronorubrumBangenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227500.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227500.protein.info.v11.5.txt",
		        "node_list_path": "1227500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpWmmb714Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. WMMB 714 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpWmmb714Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1286822.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1286822.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1286822.clusters.proteins.v11.5.txt",
		        "sequence_path": "1286822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286822.protein.info.v11.5.txt",
		        "node_list_path": "1286822.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1286822.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumMolleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium molle Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumMolleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216903.clusters.proteins.v11.5.txt",
		        "sequence_path": "216903.protein.sequences.v11.5.fa",
		        "enrichment_path": "216903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216903.protein.info.v11.5.txt",
		        "node_list_path": "216903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterNicotinovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter nicotinovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterNicotinovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304876.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304876.protein.info.v11.5.txt",
		        "node_list_path": "1304876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinilactibacillusPiezotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinilactibacillus piezotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinilactibacillusPiezotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "258723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "258723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "258723.clusters.proteins.v11.5.txt",
		        "sequence_path": "258723.protein.sequences.v11.5.fa",
		        "enrichment_path": "258723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "258723.protein.info.v11.5.txt",
		        "node_list_path": "258723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "258723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphriteaJaponica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amphritea japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphriteaJaponica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278309.protein.info.v11.5.txt",
		        "node_list_path": "1278309.protein.complete.v11.5.txt"
		    }
		]
    )()

def AvibacteriumParagallinarum72Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum 72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AvibacteriumParagallinarum72Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "948565.clusters.info.v11.5.txt",
		        "cluster_tree_path": "948565.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "948565.clusters.proteins.v11.5.txt",
		        "sequence_path": "948565.protein.sequences.v11.5.fa",
		        "enrichment_path": "948565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "948565.protein.info.v11.5.txt",
		        "node_list_path": "948565.cluster.nodes.v11.5.txt",
		        "edge_list_path": "948565.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrnithinibacillusContaminans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ornithinibacillus contaminans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithinibacillusContaminans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "694055.protein.sequences.v11.5.fa",
		        "enrichment_path": "694055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694055.protein.info.v11.5.txt",
		        "node_list_path": "694055.protein.complete.v11.5.txt"
		    }
		]
    )()

def DickeyaDadantii3937(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii 3937 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaDadantii3937", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "198628.protein.sequences.v11.5.fa",
		        "enrichment_path": "198628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198628.protein.info.v11.5.txt",
		        "node_list_path": "198628.protein.complete.v11.5.txt"
		    }
		]
    )()

def UliginosibacteriumGangwonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Uliginosibacterium gangwonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UliginosibacteriumGangwonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123487.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123487.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123487.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123487.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123487.protein.info.v11.5.txt",
		        "node_list_path": "1123487.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123487.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumRifcsphigho202Full4012(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPHIGHO2_02_FULL_40_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumRifcsphigho202Full4012", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801974.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801974.protein.info.v11.5.txt",
		        "node_list_path": "1801974.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaAnserinaEs(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia anserina Es graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaAnserinaEs", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1365188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1365188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1365188.protein.info.v11.5.txt",
		        "node_list_path": "1365188.protein.complete.v11.5.txt"
		    }
		]
    )()

def KingellaKingae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kingella kingae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KingellaKingae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "887327.protein.sequences.v11.5.fa",
		        "enrichment_path": "887327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "887327.protein.info.v11.5.txt",
		        "node_list_path": "887327.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumAntarcticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumAntarcticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266748.clusters.proteins.v11.5.txt",
		        "sequence_path": "266748.protein.sequences.v11.5.fa",
		        "enrichment_path": "266748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266748.protein.info.v11.5.txt",
		        "node_list_path": "266748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanoculleusChikugoensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus chikugoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusChikugoensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118126.protein.sequences.v11.5.fa",
		        "enrichment_path": "118126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118126.protein.info.v11.5.txt",
		        "node_list_path": "118126.protein.complete.v11.5.txt"
		    }
		]
    )()

def KluyveromycesLactisNrrlY1140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kluyveromyces lactis NRRL Y-1140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KluyveromycesLactisNrrlY1140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "284590.clusters.info.v11.5.txt",
		        "cluster_tree_path": "284590.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "284590.clusters.proteins.v11.5.txt",
		        "sequence_path": "284590.protein.sequences.v11.5.fa",
		        "enrichment_path": "284590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284590.protein.info.v11.5.txt",
		        "node_list_path": "284590.cluster.nodes.v11.5.txt",
		        "edge_list_path": "284590.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAmylovorusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus amylovorus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAmylovorusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1604.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1604.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1604.clusters.proteins.v11.5.txt",
		        "sequence_path": "1604.protein.sequences.v11.5.fa",
		        "enrichment_path": "1604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1604.protein.info.v11.5.txt",
		        "node_list_path": "1604.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1604.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpHiyo8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Hiyo8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpHiyo8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1588023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588023.protein.info.v11.5.txt",
		        "node_list_path": "1588023.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusNigrescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus nigrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusNigrescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1070870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1070870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1070870.protein.info.v11.5.txt",
		        "node_list_path": "1070870.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacterLovleyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter lovleyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterLovleyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398767.clusters.proteins.v11.5.txt",
		        "sequence_path": "398767.protein.sequences.v11.5.fa",
		        "enrichment_path": "398767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398767.protein.info.v11.5.txt",
		        "node_list_path": "398767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasAzotifigensNbrc15497(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas azotifigens NBRC 15497 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasAzotifigensNbrc15497", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219041.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219041.protein.info.v11.5.txt",
		        "node_list_path": "1219041.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaGenomosp13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaGenomosp13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "463040.protein.sequences.v11.5.fa",
		        "enrichment_path": "463040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "463040.protein.info.v11.5.txt",
		        "node_list_path": "463040.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterOrleanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter orleanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterOrleanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "104099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "104099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "104099.clusters.proteins.v11.5.txt",
		        "sequence_path": "104099.protein.sequences.v11.5.fa",
		        "enrichment_path": "104099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104099.protein.info.v11.5.txt",
		        "node_list_path": "104099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "104099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumIntestinale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium intestinale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumIntestinale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1294142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294142.protein.info.v11.5.txt",
		        "node_list_path": "1294142.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalocynthiibacterNamhaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halocynthiibacter namhaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalocynthiibacterNamhaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1290553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1290553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1290553.protein.info.v11.5.txt",
		        "node_list_path": "1290553.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirillosporaAlbida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirillospora albida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirillosporaAlbida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "58123.protein.sequences.v11.5.fa",
		        "enrichment_path": "58123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58123.protein.info.v11.5.txt",
		        "node_list_path": "58123.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaricaPapaya(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carica papaya graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaricaPapaya", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3649.protein.sequences.v11.5.fa",
		        "enrichment_path": "3649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3649.protein.info.v11.5.txt",
		        "node_list_path": "3649.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaSativaIndicaGroupCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Indica Group Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaSativaIndicaGroupCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39946.clusters.proteins.v11.5.txt",
		        "sequence_path": "39946.protein.sequences.v11.5.fa",
		        "enrichment_path": "39946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39946.protein.info.v11.5.txt",
		        "node_list_path": "39946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full4414Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_44_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full4414Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802525.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802525.protein.info.v11.5.txt",
		        "node_list_path": "1802525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterSwuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter swuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSwuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227739.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227739.protein.info.v11.5.txt",
		        "node_list_path": "1227739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosopelagicusBrevis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosopelagicus brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosopelagicusBrevis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410606.protein.info.v11.5.txt",
		        "node_list_path": "1410606.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAtribacteriaBacteriumRbg19ftCombo3514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atribacteria bacterium RBG_19FT_COMBO_35_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAtribacteriaBacteriumRbg19ftCombo3514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797291.protein.info.v11.5.txt",
		        "node_list_path": "1797291.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulosilyticumSpI15g10i2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulosilyticum sp. I15G10I2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulosilyticumSpI15g10i2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1892843.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892843.protein.info.v11.5.txt",
		        "node_list_path": "1892843.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaJamestowniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella jamestowniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaJamestowniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "455.clusters.info.v11.5.txt",
		        "cluster_tree_path": "455.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "455.clusters.proteins.v11.5.txt",
		        "sequence_path": "455.protein.sequences.v11.5.fa",
		        "enrichment_path": "455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "455.protein.info.v11.5.txt",
		        "node_list_path": "455.cluster.nodes.v11.5.txt",
		        "edge_list_path": "455.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EctothiorhodospiraSpPhs1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ectothiorhodospira sp. PHS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctothiorhodospiraSpPhs1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "519989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "519989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "519989.clusters.proteins.v11.5.txt",
		        "sequence_path": "519989.protein.sequences.v11.5.fa",
		        "enrichment_path": "519989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519989.protein.info.v11.5.txt",
		        "node_list_path": "519989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "519989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterHenricii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter henricii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterHenricii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69395.protein.sequences.v11.5.fa",
		        "enrichment_path": "69395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69395.protein.info.v11.5.txt",
		        "node_list_path": "69395.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumValentinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium valentinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumValentinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1518501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1518501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1518501.protein.info.v11.5.txt",
		        "node_list_path": "1518501.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpNt26Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. NT-26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpNt26Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125847.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125847.protein.info.v11.5.txt",
		        "node_list_path": "1125847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAgilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus agilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAgilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1601.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1601.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1601.clusters.proteins.v11.5.txt",
		        "sequence_path": "1601.protein.sequences.v11.5.fa",
		        "enrichment_path": "1601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1601.protein.info.v11.5.txt",
		        "node_list_path": "1601.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1601.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelotomaculumSpDtu098(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelotomaculum sp. DTU098 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelotomaculumSpDtu098", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671628.protein.info.v11.5.txt",
		        "node_list_path": "1671628.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldisphaeraLagunensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldisphaera lagunensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldisphaeraLagunensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1056495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1056495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1056495.clusters.proteins.v11.5.txt",
		        "sequence_path": "1056495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1056495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1056495.protein.info.v11.5.txt",
		        "node_list_path": "1056495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1056495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraInfestansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora infestans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraInfestansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4787.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4787.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4787.clusters.proteins.v11.5.txt",
		        "sequence_path": "4787.protein.sequences.v11.5.fa",
		        "enrichment_path": "4787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4787.protein.info.v11.5.txt",
		        "node_list_path": "4787.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4787.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_41_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798676.protein.info.v11.5.txt",
		        "node_list_path": "1798676.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesMerdaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides merdae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesMerdaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411477.clusters.proteins.v11.5.txt",
		        "sequence_path": "411477.protein.sequences.v11.5.fa",
		        "enrichment_path": "411477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411477.protein.info.v11.5.txt",
		        "node_list_path": "411477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesMirabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces mirabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesMirabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68239.protein.sequences.v11.5.fa",
		        "enrichment_path": "68239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68239.protein.info.v11.5.txt",
		        "node_list_path": "68239.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasUreae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas ureae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasUreae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44577.protein.sequences.v11.5.fa",
		        "enrichment_path": "44577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44577.protein.info.v11.5.txt",
		        "node_list_path": "44577.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaAvicenniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora avicenniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaAvicenniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1198245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198245.protein.info.v11.5.txt",
		        "node_list_path": "1198245.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteimonasMephitisDsm12574(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas mephitis DSM 12574 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteimonasMephitisDsm12574", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122183.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122183.protein.info.v11.5.txt",
		        "node_list_path": "1122183.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumCg1023722(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium CG1_02_37_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumCg1023722", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805209.protein.info.v11.5.txt",
		        "node_list_path": "1805209.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacillusPleuropneumoniae14074Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae 1 4074 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusPleuropneumoniae14074Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "228399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "228399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "228399.clusters.proteins.v11.5.txt",
		        "sequence_path": "228399.protein.sequences.v11.5.fa",
		        "enrichment_path": "228399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228399.protein.info.v11.5.txt",
		        "node_list_path": "228399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "228399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGilvigriseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces gilvigriseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGilvigriseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1428644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1428644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1428644.protein.info.v11.5.txt",
		        "node_list_path": "1428644.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrcinusOrca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Orcinus orca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrcinusOrca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9733.protein.sequences.v11.5.fa",
		        "enrichment_path": "9733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9733.protein.info.v11.5.txt",
		        "node_list_path": "9733.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpSt904Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. ST904 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpSt904Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1684385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1684385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1684385.clusters.proteins.v11.5.txt",
		        "sequence_path": "1684385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1684385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1684385.protein.info.v11.5.txt",
		        "node_list_path": "1684385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1684385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DickeyaDadantiiEch703Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii Ech703 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaDadantiiEch703Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "579405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "579405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "579405.clusters.proteins.v11.5.txt",
		        "sequence_path": "579405.protein.sequences.v11.5.fa",
		        "enrichment_path": "579405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579405.protein.info.v11.5.txt",
		        "node_list_path": "579405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "579405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumYuanmingense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium yuanmingense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumYuanmingense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "108015.protein.sequences.v11.5.fa",
		        "enrichment_path": "108015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "108015.protein.info.v11.5.txt",
		        "node_list_path": "108015.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrococcusSpSt04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus sp. ST04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusSpSt04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1183377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1183377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1183377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1183377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1183377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1183377.protein.info.v11.5.txt",
		        "node_list_path": "1183377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1183377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizopusMicrosporusAtcc52813Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus microsporus ATCC 52813 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopusMicrosporusAtcc52813Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1340429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1340429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1340429.clusters.proteins.v11.5.txt",
		        "sequence_path": "1340429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1340429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1340429.protein.info.v11.5.txt",
		        "node_list_path": "1340429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1340429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumBrhC0Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium BRH_c0 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumBrhC0Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629722.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629722.protein.info.v11.5.txt",
		        "node_list_path": "1629722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaFrigidimarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella frigidimarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaFrigidimarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "318167.clusters.info.v11.5.txt",
		        "cluster_tree_path": "318167.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "318167.clusters.proteins.v11.5.txt",
		        "sequence_path": "318167.protein.sequences.v11.5.fa",
		        "enrichment_path": "318167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318167.protein.info.v11.5.txt",
		        "node_list_path": "318167.cluster.nodes.v11.5.txt",
		        "edge_list_path": "318167.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CycloclasticusSpSymbiontOfBathymodiolusHeckerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Bathymodiolus heckerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CycloclasticusSpSymbiontOfBathymodiolusHeckerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1284675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284675.protein.info.v11.5.txt",
		        "node_list_path": "1284675.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisJsc3b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris JSC-3b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisJsc3b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1421013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1421013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1421013.protein.info.v11.5.txt",
		        "node_list_path": "1421013.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaCanadensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia canadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaCanadensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "293613.protein.sequences.v11.5.fa",
		        "enrichment_path": "293613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "293613.protein.info.v11.5.txt",
		        "node_list_path": "293613.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanicolaSpHl35Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola sp. HL35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaSpHl35Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1305735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1305735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1305735.clusters.proteins.v11.5.txt",
		        "sequence_path": "1305735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305735.protein.info.v11.5.txt",
		        "node_list_path": "1305735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1305735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraLicerasiaeStrMmd4847Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira licerasiae str. MMD4847 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraLicerasiaeStrMmd4847Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1049971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1049971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1049971.clusters.proteins.v11.5.txt",
		        "sequence_path": "1049971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1049971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1049971.protein.info.v11.5.txt",
		        "node_list_path": "1049971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1049971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FormosaSpAk20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Formosa sp. AK20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaSpAk20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1137281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137281.protein.info.v11.5.txt",
		        "node_list_path": "1137281.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumJeanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium jeanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumJeanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "858640.protein.sequences.v11.5.fa",
		        "enrichment_path": "858640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "858640.protein.info.v11.5.txt",
		        "node_list_path": "858640.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24117Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_41_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24117Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619048.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619048.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619048.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619048.protein.info.v11.5.txt",
		        "node_list_path": "1619048.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619048.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusVersmoldensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus versmoldensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusVersmoldensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423815.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423815.protein.info.v11.5.txt",
		        "node_list_path": "1423815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusGobiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus gobiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGobiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1441095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1441095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1441095.clusters.proteins.v11.5.txt",
		        "sequence_path": "1441095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1441095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1441095.protein.info.v11.5.txt",
		        "node_list_path": "1441095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1441095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumSpRv1423(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. RV1423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumSpRv1423", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1443993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443993.protein.info.v11.5.txt",
		        "node_list_path": "1443993.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusSputorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus sputorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusSputorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035839.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035839.protein.info.v11.5.txt",
		        "node_list_path": "1035839.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpSa39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. SA39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpSa39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263625.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263625.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263625.protein.info.v11.5.txt",
		        "node_list_path": "1263625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedArchaeonA07hr60Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HR60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedArchaeonA07hr60Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1412874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1412874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1412874.clusters.proteins.v11.5.txt",
		        "sequence_path": "1412874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1412874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1412874.protein.info.v11.5.txt",
		        "node_list_path": "1412874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1412874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpEhc04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. EhC04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpEhc04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849168.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849168.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849168.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849168.protein.info.v11.5.txt",
		        "node_list_path": "1849168.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849168.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParamicrosporidiumSaccamoebae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paramicrosporidium saccamoebae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParamicrosporidiumSaccamoebae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246581.protein.info.v11.5.txt",
		        "node_list_path": "1246581.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpHl58Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. HL58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpHl58Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1479237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1479237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1479237.clusters.proteins.v11.5.txt",
		        "sequence_path": "1479237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479237.protein.info.v11.5.txt",
		        "node_list_path": "1479237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1479237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerolineaThermolimosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerolinea thermolimosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaThermolimosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "229919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "229919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "229919.clusters.proteins.v11.5.txt",
		        "sequence_path": "229919.protein.sequences.v11.5.fa",
		        "enrichment_path": "229919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229919.protein.info.v11.5.txt",
		        "node_list_path": "229919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "229919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenoxybacterAcetivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenoxybacter acetivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenoxybacterAcetivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123296.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123296.protein.info.v11.5.txt",
		        "node_list_path": "1123296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpCg2304434(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. CG2_30_44_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpCg2304434", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805397.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805397.protein.info.v11.5.txt",
		        "node_list_path": "1805397.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSpPbn3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. PBN3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpPbn3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397528.protein.info.v11.5.txt",
		        "node_list_path": "1397528.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacillusSuis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus suis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusSuis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "696748.protein.sequences.v11.5.fa",
		        "enrichment_path": "696748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696748.protein.info.v11.5.txt",
		        "node_list_path": "696748.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaChrysopicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma chrysopicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaChrysopicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1276227.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1276227.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1276227.clusters.proteins.v11.5.txt",
		        "sequence_path": "1276227.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276227.protein.info.v11.5.txt",
		        "node_list_path": "1276227.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1276227.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifoxyc12Full3455(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYC12_FULL_34_55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyc12Full3455", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798000.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798000.protein.info.v11.5.txt",
		        "node_list_path": "1798000.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusGastricusPs3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gastricus PS3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGastricusPs3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144300.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144300.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144300.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144300.protein.info.v11.5.txt",
		        "node_list_path": "1144300.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144300.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusFlavithermusAk1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus AK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusFlavithermusAk1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1297581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1297581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1297581.clusters.proteins.v11.5.txt",
		        "sequence_path": "1297581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297581.protein.info.v11.5.txt",
		        "node_list_path": "1297581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1297581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumSenegalenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium senegalense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumSenegalenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033736.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033736.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033736.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033736.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033736.protein.info.v11.5.txt",
		        "node_list_path": "1033736.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033736.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExophialaDermatitidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exophiala dermatitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaDermatitidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5970.clusters.proteins.v11.5.txt",
		        "sequence_path": "5970.protein.sequences.v11.5.fa",
		        "enrichment_path": "5970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5970.protein.info.v11.5.txt",
		        "node_list_path": "5970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpTtu2014080asc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TTU2014-080ASC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpTtu2014080asc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729724.protein.info.v11.5.txt",
		        "node_list_path": "1729724.protein.complete.v11.5.txt"
		    }
		]
    )()

def PusillimonasNoertemanniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pusillimonas noertemannii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PusillimonasNoertemanniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231391.protein.info.v11.5.txt",
		        "node_list_path": "1231391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1024025Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_40_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024025Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805305.protein.info.v11.5.txt",
		        "node_list_path": "1805305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaAxanthumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma axanthum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaAxanthumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278311.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278311.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278311.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278311.protein.info.v11.5.txt",
		        "node_list_path": "1278311.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278311.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaAfricana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta africana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaAfricana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "889378.protein.sequences.v11.5.fa",
		        "enrichment_path": "889378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "889378.protein.info.v11.5.txt",
		        "node_list_path": "889378.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycesSpShPl62Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces sp. SH-PL62 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycesSpShPl62Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1636152.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1636152.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1636152.clusters.proteins.v11.5.txt",
		        "sequence_path": "1636152.protein.sequences.v11.5.fa",
		        "enrichment_path": "1636152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1636152.protein.info.v11.5.txt",
		        "node_list_path": "1636152.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1636152.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StrongylocentrotusPurpuratusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Strongylocentrotus purpuratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrongylocentrotusPurpuratusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7668.clusters.proteins.v11.5.txt",
		        "sequence_path": "7668.protein.sequences.v11.5.fa",
		        "enrichment_path": "7668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7668.protein.info.v11.5.txt",
		        "node_list_path": "7668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErysipelothrixLarvae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erysipelothrix larvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelothrixLarvae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1514105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1514105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1514105.protein.info.v11.5.txt",
		        "node_list_path": "1514105.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaNiigatensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia niigatensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaNiigatensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206733.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206733.protein.info.v11.5.txt",
		        "node_list_path": "1206733.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeovisonVison(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neovison vison graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeovisonVison", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "452646.protein.sequences.v11.5.fa",
		        "enrichment_path": "452646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452646.protein.info.v11.5.txt",
		        "node_list_path": "452646.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpSoil787Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil787 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpSoil787Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736411.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736411.protein.info.v11.5.txt",
		        "node_list_path": "1736411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumGwa24518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_45_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa24518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801839.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801839.protein.info.v11.5.txt",
		        "node_list_path": "1801839.protein.complete.v11.5.txt"
		    }
		]
    )()

def NesterenkoniaAlbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesterenkoniaAlbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122602.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122602.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122602.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122602.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122602.protein.info.v11.5.txt",
		        "node_list_path": "1122602.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122602.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwf1496Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWF1_49_6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwf1496Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802189.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802189.protein.info.v11.5.txt",
		        "node_list_path": "1802189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu058Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu058Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671653.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671653.protein.info.v11.5.txt",
		        "node_list_path": "1671653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopirellulaIslandica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopirellula islandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopirellulaIslandica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "595434.protein.sequences.v11.5.fa",
		        "enrichment_path": "595434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595434.protein.info.v11.5.txt",
		        "node_list_path": "595434.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndozoicomonasMontiporaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas montiporae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndozoicomonasMontiporaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1027273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1027273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1027273.clusters.proteins.v11.5.txt",
		        "sequence_path": "1027273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1027273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1027273.protein.info.v11.5.txt",
		        "node_list_path": "1027273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1027273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaMaceachernii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella maceachernii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaMaceachernii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "466.protein.sequences.v11.5.fa",
		        "enrichment_path": "466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "466.protein.info.v11.5.txt",
		        "node_list_path": "466.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChelatococcusSpGw1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chelatococcus sp. GW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelatococcusSpGw1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211115.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211115.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211115.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211115.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211115.protein.info.v11.5.txt",
		        "node_list_path": "1211115.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211115.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasLuteoviolaceaBAtcc29581(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas luteoviolacea B  ATCC 29581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasLuteoviolaceaBAtcc29581", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1268239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268239.protein.info.v11.5.txt",
		        "node_list_path": "1268239.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumMs0243cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium MS024-3C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumMs0243cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "487797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "487797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "487797.clusters.proteins.v11.5.txt",
		        "sequence_path": "487797.protein.sequences.v11.5.fa",
		        "enrichment_path": "487797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487797.protein.info.v11.5.txt",
		        "node_list_path": "487797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "487797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacinutrixHimadriensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix himadriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixHimadriensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641549.clusters.proteins.v11.5.txt",
		        "sequence_path": "641549.protein.sequences.v11.5.fa",
		        "enrichment_path": "641549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641549.protein.info.v11.5.txt",
		        "node_list_path": "641549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SordariaMacrospora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sordaria macrospora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SordariaMacrospora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5147.protein.sequences.v11.5.fa",
		        "enrichment_path": "5147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5147.protein.info.v11.5.txt",
		        "node_list_path": "5147.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaSartisoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia sartisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaSartisoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83784.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83784.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83784.clusters.proteins.v11.5.txt",
		        "sequence_path": "83784.protein.sequences.v11.5.fa",
		        "enrichment_path": "83784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83784.protein.info.v11.5.txt",
		        "node_list_path": "83784.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83784.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSpNrrlB16802Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora sp. NRRL B-16802 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSpNrrlB16802Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415541.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415541.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415541.protein.info.v11.5.txt",
		        "node_list_path": "1415541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgibacterAlginicilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algibacter alginicilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgibacterAlginicilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736674.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736674.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736674.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736674.protein.info.v11.5.txt",
		        "node_list_path": "1736674.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736674.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterCloacaeAtcc13047(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae ATCC13047 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterCloacaeAtcc13047", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "716541.protein.sequences.v11.5.fa",
		        "enrichment_path": "716541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "716541.protein.info.v11.5.txt",
		        "node_list_path": "716541.protein.complete.v11.5.txt"
		    }
		]
    )()

def DictyocaulusViviparus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dictyocaulus viviparus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DictyocaulusViviparus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29172.protein.sequences.v11.5.fa",
		        "enrichment_path": "29172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29172.protein.info.v11.5.txt",
		        "node_list_path": "29172.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpUnc363mftsu51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. UNC363MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpUnc363mftsu51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449069.protein.info.v11.5.txt",
		        "node_list_path": "1449069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSp3131(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. 3_1_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSp3131", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "457402.protein.sequences.v11.5.fa",
		        "enrichment_path": "457402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457402.protein.info.v11.5.txt",
		        "node_list_path": "457402.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpAcs1612(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS1612 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpAcs1612", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834117.protein.info.v11.5.txt",
		        "node_list_path": "1834117.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlligatorSinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alligator sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlligatorSinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "38654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "38654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "38654.clusters.proteins.v11.5.txt",
		        "sequence_path": "38654.protein.sequences.v11.5.fa",
		        "enrichment_path": "38654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38654.protein.info.v11.5.txt",
		        "node_list_path": "38654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "38654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpHl93Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. HL-93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpHl93Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1666906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1666906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1666906.clusters.proteins.v11.5.txt",
		        "sequence_path": "1666906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666906.protein.info.v11.5.txt",
		        "node_list_path": "1666906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1666906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnditaleaAndensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anditalea andensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnditaleaAndensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1048983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1048983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1048983.clusters.proteins.v11.5.txt",
		        "sequence_path": "1048983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048983.protein.info.v11.5.txt",
		        "node_list_path": "1048983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1048983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaledivibacterHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maledivibacter halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaledivibacterHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36842.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36842.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36842.clusters.proteins.v11.5.txt",
		        "sequence_path": "36842.protein.sequences.v11.5.fa",
		        "enrichment_path": "36842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36842.protein.info.v11.5.txt",
		        "node_list_path": "36842.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36842.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylibiumSpRoot1272(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylibium sp. Root1272 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylibiumSpRoot1272", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736441.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736441.protein.info.v11.5.txt",
		        "node_list_path": "1736441.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterFulvusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter fulvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterFulvusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1163408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1163408.clusters.proteins.v11.5.txt",
		        "sequence_path": "1163408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163408.protein.info.v11.5.txt",
		        "node_list_path": "1163408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1163408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusSiccatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus siccatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusSiccatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1137991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1137991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1137991.clusters.proteins.v11.5.txt",
		        "sequence_path": "1137991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137991.protein.info.v11.5.txt",
		        "node_list_path": "1137991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1137991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FabibacterSp4d4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fabibacter sp. 4D4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FabibacterSp4d4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1889784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889784.protein.info.v11.5.txt",
		        "node_list_path": "1889784.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaVeroralisDsm19559(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella veroralis DSM19559 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaVeroralisDsm19559", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122993.protein.info.v11.5.txt",
		        "node_list_path": "1122993.protein.complete.v11.5.txt"
		    }
		]
    )()

def HumibacillusSpDsm29435(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Humibacillus sp. DSM 29435 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HumibacillusSpDsm29435", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1869167.protein.sequences.v11.5.fa",
		        "enrichment_path": "1869167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1869167.protein.info.v11.5.txt",
		        "node_list_path": "1869167.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumBarkeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium barkeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumBarkeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1528.clusters.proteins.v11.5.txt",
		        "sequence_path": "1528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1528.protein.info.v11.5.txt",
		        "node_list_path": "1528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaDisiensFb03509anCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella disiens FB03509AN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaDisiensFb03509anCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "866771.clusters.info.v11.5.txt",
		        "cluster_tree_path": "866771.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "866771.clusters.proteins.v11.5.txt",
		        "sequence_path": "866771.protein.sequences.v11.5.fa",
		        "enrichment_path": "866771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866771.protein.info.v11.5.txt",
		        "node_list_path": "866771.cluster.nodes.v11.5.txt",
		        "edge_list_path": "866771.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb14912Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_49_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb14912Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618882.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618882.protein.info.v11.5.txt",
		        "node_list_path": "1618882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumGwf2339(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWF2_33_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumGwf2339", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798430.protein.info.v11.5.txt",
		        "node_list_path": "1798430.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1024431Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_44_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024431Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805310.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805310.protein.info.v11.5.txt",
		        "node_list_path": "1805310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho212Full4422bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_12_FULL_44_22b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho212Full4422bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801763.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801763.protein.info.v11.5.txt",
		        "node_list_path": "1801763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterActinosclerus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter actinosclerus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterActinosclerus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "82805.protein.sequences.v11.5.fa",
		        "enrichment_path": "82805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82805.protein.info.v11.5.txt",
		        "node_list_path": "82805.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpTkp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TKP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpTkp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415630.protein.info.v11.5.txt",
		        "node_list_path": "1415630.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerobrancaGottschalkiiDsm13577Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobranca gottschalkii DSM 13577 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobrancaGottschalkiiDsm13577Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120990.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120990.protein.info.v11.5.txt",
		        "node_list_path": "1120990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaBillingiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia billingiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaBillingiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634500.clusters.proteins.v11.5.txt",
		        "sequence_path": "634500.protein.sequences.v11.5.fa",
		        "enrichment_path": "634500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634500.protein.info.v11.5.txt",
		        "node_list_path": "634500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeminocystisSpNies3708Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geminocystis sp. NIES-3708 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeminocystisSpNies3708Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1615909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1615909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1615909.clusters.proteins.v11.5.txt",
		        "sequence_path": "1615909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1615909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1615909.protein.info.v11.5.txt",
		        "node_list_path": "1615909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1615909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeosporaCaninum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neospora caninum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeosporaCaninum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29176.protein.sequences.v11.5.fa",
		        "enrichment_path": "29176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29176.protein.info.v11.5.txt",
		        "node_list_path": "29176.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSpMebic08052Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. MEBiC08052 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpMebic08052Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761910.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761910.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761910.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761910.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761910.protein.info.v11.5.txt",
		        "node_list_path": "1761910.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761910.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophilusSp5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. 5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusSp5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1112274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112274.protein.info.v11.5.txt",
		        "node_list_path": "1112274.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacillusTrivialis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacillus trivialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacillusTrivialis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798.protein.info.v11.5.txt",
		        "node_list_path": "1798.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusPraediiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus praedii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPraediiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1742358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1742358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1742358.clusters.proteins.v11.5.txt",
		        "sequence_path": "1742358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742358.protein.info.v11.5.txt",
		        "node_list_path": "1742358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1742358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronincolaPeptidivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronincola peptidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronincolaPeptidivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426128.clusters.proteins.v11.5.txt",
		        "sequence_path": "426128.protein.sequences.v11.5.fa",
		        "enrichment_path": "426128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426128.protein.info.v11.5.txt",
		        "node_list_path": "426128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaVinsoniiArupensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella vinsonii arupensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaVinsoniiArupensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094561.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094561.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094561.protein.info.v11.5.txt",
		        "node_list_path": "1094561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteroidesChelonaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacteroides chelonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteroidesChelonaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1774.protein.info.v11.5.txt",
		        "node_list_path": "1774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiolapillusBrandeumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiolapillus brandeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiolapillusBrandeumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1076588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1076588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1076588.clusters.proteins.v11.5.txt",
		        "sequence_path": "1076588.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076588.protein.info.v11.5.txt",
		        "node_list_path": "1076588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1076588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSanguinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSanguinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33051.protein.sequences.v11.5.fa",
		        "enrichment_path": "33051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33051.protein.info.v11.5.txt",
		        "node_list_path": "33051.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaCulicicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma culicicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaCulicicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1276246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1276246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1276246.clusters.proteins.v11.5.txt",
		        "sequence_path": "1276246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276246.protein.info.v11.5.txt",
		        "node_list_path": "1276246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1276246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusMicrotiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus microti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusMicrotiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "569857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "569857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "569857.clusters.proteins.v11.5.txt",
		        "sequence_path": "569857.protein.sequences.v11.5.fa",
		        "enrichment_path": "569857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "569857.protein.info.v11.5.txt",
		        "node_list_path": "569857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "569857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiK12W3110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 W3110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiK12W3110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316407.clusters.info.v11.0.txt",
		        "cluster_tree_path": "316407.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "316407.clusters.proteins.v11.0.txt",
		        "sequence_path": "316407.protein.sequences.v11.0.fa",
		        "enrichment_path": "316407.protein.enrichment.terms.v11.0.txt",
		        "info_path": "316407.protein.info.v11.0.txt",
		        "node_list_path": "316407.cluster.nodes.v11.0.txt",
		        "edge_list_path": "316407.protein.cluster.v11.0.txt"
		    }
		]
    )()

def BerkelbacteriaBacteriumGw2011Gwb1385Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011_GWB1_38_5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BerkelbacteriaBacteriumGw2011Gwb1385Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618336.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618336.protein.info.v11.5.txt",
		        "node_list_path": "1618336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumHuakuii7653rCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium huakuii 7653R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumHuakuii7653rCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "763057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "763057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "763057.clusters.proteins.v11.5.txt",
		        "sequence_path": "763057.protein.sequences.v11.5.fa",
		        "enrichment_path": "763057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "763057.protein.info.v11.5.txt",
		        "node_list_path": "763057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "763057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzonexusHydrophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azonexus hydrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzonexusHydrophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "418702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "418702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "418702.clusters.proteins.v11.5.txt",
		        "sequence_path": "418702.protein.sequences.v11.5.fa",
		        "enrichment_path": "418702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "418702.protein.info.v11.5.txt",
		        "node_list_path": "418702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "418702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesCellostaticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces cellostaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCellostaticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67285.protein.sequences.v11.5.fa",
		        "enrichment_path": "67285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67285.protein.info.v11.5.txt",
		        "node_list_path": "67285.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumLotiR88b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti R88b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumLotiR88b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935548.protein.sequences.v11.5.fa",
		        "enrichment_path": "935548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935548.protein.info.v11.5.txt",
		        "node_list_path": "935548.protein.complete.v11.5.txt"
		    }
		]
    )()

def CronobacterCondimenti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter condimenti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CronobacterCondimenti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1073999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073999.protein.info.v11.5.txt",
		        "node_list_path": "1073999.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumPsychroaquaticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium psychroaquaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumPsychroaquaticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "561061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "561061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "561061.clusters.proteins.v11.5.txt",
		        "sequence_path": "561061.protein.sequences.v11.5.fa",
		        "enrichment_path": "561061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561061.protein.info.v11.5.txt",
		        "node_list_path": "561061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "561061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelianthusAnnuus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helianthus annuus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelianthusAnnuus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4232.protein.sequences.v11.5.fa",
		        "enrichment_path": "4232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4232.protein.info.v11.5.txt",
		        "node_list_path": "4232.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusGuaymasensisDsm11113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus guaymasensis DSM 11113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusGuaymasensisDsm11113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1432656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432656.protein.info.v11.5.txt",
		        "node_list_path": "1432656.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg165817Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_58_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165817Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797845.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797845.protein.info.v11.5.txt",
		        "node_list_path": "1797845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhynchosporiumCommuneCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhynchosporium commune Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhynchosporiumCommuneCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "914237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "914237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "914237.clusters.proteins.v11.5.txt",
		        "sequence_path": "914237.protein.sequences.v11.5.fa",
		        "enrichment_path": "914237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "914237.protein.info.v11.5.txt",
		        "node_list_path": "914237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "914237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpB29Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. B29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpB29Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1933220.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1933220.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1933220.clusters.proteins.v11.5.txt",
		        "sequence_path": "1933220.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933220.protein.info.v11.5.txt",
		        "node_list_path": "1933220.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1933220.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumTuscaniense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium tuscaniense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumTuscaniense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1401064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401064.protein.info.v11.5.txt",
		        "node_list_path": "1401064.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpMarseilleP299Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. Marseille-P299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpMarseilleP299Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805477.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805477.protein.info.v11.5.txt",
		        "node_list_path": "1805477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumHydatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium hydatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumHydatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "991.protein.sequences.v11.5.fa",
		        "enrichment_path": "991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "991.protein.info.v11.5.txt",
		        "node_list_path": "991.protein.complete.v11.5.txt"
		    }
		]
    )()

def KingellaDenitrificansAtcc33394Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kingella denitrificans ATCC 33394 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KingellaDenitrificansAtcc33394Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888741.clusters.proteins.v11.5.txt",
		        "sequence_path": "888741.protein.sequences.v11.5.fa",
		        "enrichment_path": "888741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888741.protein.info.v11.5.txt",
		        "node_list_path": "888741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAgassizii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma agassizii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAgassizii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33922.protein.sequences.v11.5.fa",
		        "enrichment_path": "33922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33922.protein.info.v11.5.txt",
		        "node_list_path": "33922.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusVogelbacteriaBacteriumRifoxyd1Full4432Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_44_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full4432Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802438.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802438.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802438.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802438.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802438.protein.info.v11.5.txt",
		        "node_list_path": "1802438.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802438.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaMaltosaXu316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida maltosa Xu316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaMaltosaXu316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1245528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245528.protein.info.v11.5.txt",
		        "node_list_path": "1245528.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho201Full399Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_39_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full399Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801735.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801735.protein.info.v11.5.txt",
		        "node_list_path": "1801735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNctc7422(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NCTC 7422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNctc7422", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "981223.protein.sequences.v11.5.fa",
		        "enrichment_path": "981223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981223.protein.info.v11.5.txt",
		        "node_list_path": "981223.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriaSymbiontBfo2OfFrankliniellaOccidentalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo2 of Frankliniella occidentalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriaSymbiontBfo2OfFrankliniellaOccidentalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1628856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628856.protein.info.v11.5.txt",
		        "node_list_path": "1628856.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumFrediiNgr234(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii NGR234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumFrediiNgr234", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "394.protein.sequences.v11.5.fa",
		        "enrichment_path": "394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394.protein.info.v11.5.txt",
		        "node_list_path": "394.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumJosuiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium josui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumJosuiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1291050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1291050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1291050.clusters.proteins.v11.5.txt",
		        "sequence_path": "1291050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291050.protein.info.v11.5.txt",
		        "node_list_path": "1291050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1291050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusBrantaeDsm23927Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus brantae DSM 23927 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBrantaeDsm23927Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423727.protein.info.v11.5.txt",
		        "node_list_path": "1423727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93064.clusters.proteins.v11.5.txt",
		        "sequence_path": "93064.protein.sequences.v11.5.fa",
		        "enrichment_path": "93064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93064.protein.info.v11.5.txt",
		        "node_list_path": "93064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoccomyxaSubellipsoideaC169Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coccomyxa subellipsoidea C-169 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccomyxaSubellipsoideaC169Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "574566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "574566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "574566.clusters.proteins.v11.5.txt",
		        "sequence_path": "574566.protein.sequences.v11.5.fa",
		        "enrichment_path": "574566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574566.protein.info.v11.5.txt",
		        "node_list_path": "574566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "574566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSwuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus swuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSwuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1178515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1178515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1178515.protein.info.v11.5.txt",
		        "node_list_path": "1178515.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinicoccusAlbusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusAlbusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123230.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123230.protein.info.v11.5.txt",
		        "node_list_path": "1123230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterSpClo3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. CLO-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSpClo3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "211.protein.sequences.v11.5.fa",
		        "enrichment_path": "211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211.protein.info.v11.5.txt",
		        "node_list_path": "211.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaceaeBacteriumIbvucb2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium IBVUCB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaceaeBacteriumIbvucb2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1985174.protein.sequences.v11.5.fa",
		        "enrichment_path": "1985174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1985174.protein.info.v11.5.txt",
		        "node_list_path": "1985174.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumSpRoot700Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. Root700 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumSpRoot700Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736591.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736591.protein.info.v11.5.txt",
		        "node_list_path": "1736591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnaportheOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnaporthe oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnaportheOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "318829.protein.sequences.v11.5.fa",
		        "enrichment_path": "318829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318829.protein.info.v11.5.txt",
		        "node_list_path": "318829.protein.complete.v11.5.txt"
		    }
		]
    )()

def AliivibrioWodanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aliivibrio wodanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliivibrioWodanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "80852.protein.sequences.v11.5.fa",
		        "enrichment_path": "80852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80852.protein.info.v11.5.txt",
		        "node_list_path": "80852.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasAlcaliphilaJab1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alcaliphila JAB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAlcaliphilaJab1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "741155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "741155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "741155.clusters.proteins.v11.5.txt",
		        "sequence_path": "741155.protein.sequences.v11.5.fa",
		        "enrichment_path": "741155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "741155.protein.info.v11.5.txt",
		        "node_list_path": "741155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "741155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumPoae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium poae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumPoae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36050.protein.sequences.v11.5.fa",
		        "enrichment_path": "36050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36050.protein.info.v11.5.txt",
		        "node_list_path": "36050.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTremblayaPhenacolaPaveCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tremblaya phenacola PAVE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTremblayaPhenacolaPaveCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1266371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1266371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1266371.clusters.proteins.v11.5.txt",
		        "sequence_path": "1266371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266371.protein.info.v11.5.txt",
		        "node_list_path": "1266371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1266371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpUsba49Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. USBA 49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpUsba49Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881060.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881060.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881060.protein.info.v11.5.txt",
		        "node_list_path": "1881060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaConjunctivaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma conjunctivae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaConjunctivaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45361.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45361.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45361.clusters.proteins.v11.5.txt",
		        "sequence_path": "45361.protein.sequences.v11.5.fa",
		        "enrichment_path": "45361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45361.protein.info.v11.5.txt",
		        "node_list_path": "45361.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45361.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwd23333(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWD2_33_33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwd23333", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797328.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797328.protein.info.v11.5.txt",
		        "node_list_path": "1797328.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinivirgaCyanobacteriivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinivirga cyanobacteriivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivirgaCyanobacteriivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1307839.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1307839.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1307839.clusters.proteins.v11.5.txt",
		        "sequence_path": "1307839.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307839.protein.info.v11.5.txt",
		        "node_list_path": "1307839.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1307839.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HistoplasmaCapsulatumNam1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum NAm1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HistoplasmaCapsulatumNam1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "339724.protein.sequences.v11.5.fa",
		        "enrichment_path": "339724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "339724.protein.info.v11.5.txt",
		        "node_list_path": "339724.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidithiobacillusThiooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus thiooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithiobacillusThiooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "637390.protein.sequences.v11.5.fa",
		        "enrichment_path": "637390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637390.protein.info.v11.5.txt",
		        "node_list_path": "637390.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot483d2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root483D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot483d2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736545.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736545.protein.info.v11.5.txt",
		        "node_list_path": "1736545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumOxysporum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumOxysporum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5507.protein.sequences.v11.5.fa",
		        "enrichment_path": "5507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5507.protein.info.v11.5.txt",
		        "node_list_path": "5507.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesIhuaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides ihuae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesIhuaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852362.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852362.protein.info.v11.5.txt",
		        "node_list_path": "1852362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BipolarisSorokiniana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris sorokiniana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisSorokiniana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45130.protein.sequences.v11.5.fa",
		        "enrichment_path": "45130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45130.protein.info.v11.5.txt",
		        "node_list_path": "45130.protein.complete.v11.5.txt"
		    }
		]
    )()

def WinogradskyellaThalassocolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Winogradskyella thalassocola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinogradskyellaThalassocolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "262004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "262004.clusters.proteins.v11.5.txt",
		        "sequence_path": "262004.protein.sequences.v11.5.fa",
		        "enrichment_path": "262004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262004.protein.info.v11.5.txt",
		        "node_list_path": "262004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "262004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxParadoxusEps(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax paradoxus EPS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxParadoxusEps", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "595537.protein.sequences.v11.5.fa",
		        "enrichment_path": "595537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595537.protein.info.v11.5.txt",
		        "node_list_path": "595537.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaPapuae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichinella papuae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaPapuae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "268474.protein.sequences.v11.5.fa",
		        "enrichment_path": "268474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "268474.protein.info.v11.5.txt",
		        "node_list_path": "268474.protein.complete.v11.5.txt"
		    }
		]
    )()

def BettaSplendens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betta splendens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BettaSplendens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "158456.protein.sequences.v11.5.fa",
		        "enrichment_path": "158456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158456.protein.info.v11.5.txt",
		        "node_list_path": "158456.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisSk569Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK569 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisSk569Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035187.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035187.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035187.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035187.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035187.protein.info.v11.5.txt",
		        "node_list_path": "1035187.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035187.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSpRoot413d1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. Root413D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpRoot413d1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736531.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736531.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736531.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736531.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736531.protein.info.v11.5.txt",
		        "node_list_path": "1736531.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736531.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfuromonasSpDdh964(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromonas sp. DDH964 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromonasSpDdh964", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1823759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1823759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1823759.protein.info.v11.5.txt",
		        "node_list_path": "1823759.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaAurantiaca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaAurantiaca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644283.protein.sequences.v11.5.fa",
		        "enrichment_path": "644283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644283.protein.info.v11.5.txt",
		        "node_list_path": "644283.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryptococcusAmylolentusCbs6039(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus amylolentus CBS 6039 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptococcusAmylolentusCbs6039", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1295533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1295533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1295533.protein.info.v11.5.txt",
		        "node_list_path": "1295533.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaOulorumF0390Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oulorum F0390 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOulorumF0390Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "702438.clusters.info.v11.5.txt",
		        "cluster_tree_path": "702438.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "702438.clusters.proteins.v11.5.txt",
		        "sequence_path": "702438.protein.sequences.v11.5.fa",
		        "enrichment_path": "702438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702438.protein.info.v11.5.txt",
		        "node_list_path": "702438.cluster.nodes.v11.5.txt",
		        "edge_list_path": "702438.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaHypogeia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia hypogeia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaHypogeia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777140.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777140.protein.info.v11.5.txt",
		        "node_list_path": "1777140.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusUdagawae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus udagawae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusUdagawae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "91492.protein.sequences.v11.5.fa",
		        "enrichment_path": "91492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91492.protein.info.v11.5.txt",
		        "node_list_path": "91492.protein.complete.v11.5.txt"
		    }
		]
    )()

def AttaCephalotes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atta cephalotes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AttaCephalotes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "12957.protein.sequences.v11.5.fa",
		        "enrichment_path": "12957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "12957.protein.info.v11.5.txt",
		        "node_list_path": "12957.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumGa0077545Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077545 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumGa0077545Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752225.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752225.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752225.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752225.protein.info.v11.5.txt",
		        "node_list_path": "1752225.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752225.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSpHgb0015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. HGB0015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSpHgb0015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1078083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1078083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1078083.clusters.proteins.v11.5.txt",
		        "sequence_path": "1078083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078083.protein.info.v11.5.txt",
		        "node_list_path": "1078083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1078083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5135Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5135Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463858.protein.info.v11.5.txt",
		        "node_list_path": "1463858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrocinitomixAlgicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crocinitomix algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrocinitomixAlgicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1740263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1740263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1740263.protein.info.v11.5.txt",
		        "node_list_path": "1740263.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesHimastatinicusAtcc53653(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces himastatinicus ATCC 53653 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesHimastatinicusAtcc53653", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "457427.protein.sequences.v11.5.fa",
		        "enrichment_path": "457427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457427.protein.info.v11.5.txt",
		        "node_list_path": "457427.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanimonasSmirnoviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanimonas smirnovii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanimonasSmirnoviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1279015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1279015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1279015.clusters.proteins.v11.5.txt",
		        "sequence_path": "1279015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1279015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1279015.protein.info.v11.5.txt",
		        "node_list_path": "1279015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1279015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusLactarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus lactaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusLactarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471875.clusters.proteins.v11.5.txt",
		        "sequence_path": "471875.protein.sequences.v11.5.fa",
		        "enrichment_path": "471875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471875.protein.info.v11.5.txt",
		        "node_list_path": "471875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioSpEr1a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. ER1A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpEr1a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1517681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1517681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1517681.protein.info.v11.5.txt",
		        "node_list_path": "1517681.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalispirochaetaAlkalicaDsm8900Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalispirochaeta alkalica DSM 8900 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalispirochaetaAlkalicaDsm8900Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "942938.clusters.info.v11.5.txt",
		        "cluster_tree_path": "942938.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "942938.clusters.proteins.v11.5.txt",
		        "sequence_path": "942938.protein.sequences.v11.5.fa",
		        "enrichment_path": "942938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "942938.protein.info.v11.5.txt",
		        "node_list_path": "942938.cluster.nodes.v11.5.txt",
		        "edge_list_path": "942938.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumMiluonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium miluonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumMiluonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411945.protein.sequences.v11.5.fa",
		        "enrichment_path": "411945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411945.protein.info.v11.5.txt",
		        "node_list_path": "411945.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterSpMit055293Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT 05-5293 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSpMit055293Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1548149.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1548149.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1548149.clusters.proteins.v11.5.txt",
		        "sequence_path": "1548149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548149.protein.info.v11.5.txt",
		        "node_list_path": "1548149.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1548149.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaritimibacterSpHl12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maritimibacter sp. HL-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaritimibacterSpHl12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1162418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1162418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1162418.clusters.proteins.v11.5.txt",
		        "sequence_path": "1162418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1162418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1162418.protein.info.v11.5.txt",
		        "node_list_path": "1162418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1162418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaBuccalisDnf00985(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccalis DNF00985 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBuccalisDnf00985", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1401078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401078.protein.info.v11.5.txt",
		        "node_list_path": "1401078.protein.complete.v11.5.txt"
		    }
		]
    )()

def FonsecaeaErectaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fonsecaea erecta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FonsecaeaErectaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1367422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1367422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1367422.clusters.proteins.v11.5.txt",
		        "sequence_path": "1367422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1367422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1367422.protein.info.v11.5.txt",
		        "node_list_path": "1367422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1367422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AneurinibacillusSpXh2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aneurinibacillus sp. XH2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AneurinibacillusSpXh2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1450761.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1450761.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1450761.clusters.proteins.v11.5.txt",
		        "sequence_path": "1450761.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450761.protein.info.v11.5.txt",
		        "node_list_path": "1450761.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1450761.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRu36d(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. RU36D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRu36d", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907415.protein.info.v11.5.txt",
		        "node_list_path": "1907415.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusColumbae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus columbae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusColumbae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121865.protein.info.v11.5.txt",
		        "node_list_path": "1121865.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpPcc7002(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpPcc7002", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32049.protein.sequences.v11.5.fa",
		        "enrichment_path": "32049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32049.protein.info.v11.5.txt",
		        "node_list_path": "32049.protein.complete.v11.5.txt"
		    }
		]
    )()

def AstyanaxMexicanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Astyanax mexicanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AstyanaxMexicanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7994.clusters.proteins.v11.5.txt",
		        "sequence_path": "7994.protein.sequences.v11.5.fa",
		        "enrichment_path": "7994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7994.protein.info.v11.5.txt",
		        "node_list_path": "7994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisSpYbe204(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. YBE204 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisSpYbe204", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1282363.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282363.protein.info.v11.5.txt",
		        "node_list_path": "1282363.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZimmermannellaFaecalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zimmermannella faecalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZimmermannellaFaecalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278308.protein.info.v11.5.txt",
		        "node_list_path": "1278308.protein.complete.v11.5.txt"
		    }
		]
    )()

def TomitellaBiformataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tomitella biformata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TomitellaBiformataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1448389.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1448389.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1448389.clusters.proteins.v11.5.txt",
		        "sequence_path": "1448389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448389.protein.info.v11.5.txt",
		        "node_list_path": "1448389.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1448389.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaNigraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora nigra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaNigraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "145857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "145857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "145857.clusters.proteins.v11.5.txt",
		        "sequence_path": "145857.protein.sequences.v11.5.fa",
		        "enrichment_path": "145857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "145857.protein.info.v11.5.txt",
		        "node_list_path": "145857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "145857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNecrophorumD12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum D12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNecrophorumD12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "556263.protein.sequences.v11.5.fa",
		        "enrichment_path": "556263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556263.protein.info.v11.5.txt",
		        "node_list_path": "556263.protein.complete.v11.5.txt"
		    }
		]
    )()

def LechevalieriaAerocolonigenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lechevalieria aerocolonigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LechevalieriaAerocolonigenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68170.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68170.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68170.clusters.proteins.v11.5.txt",
		        "sequence_path": "68170.protein.sequences.v11.5.fa",
		        "enrichment_path": "68170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68170.protein.info.v11.5.txt",
		        "node_list_path": "68170.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68170.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FicedulaAlbicollis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ficedula albicollis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FicedulaAlbicollis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59894.protein.sequences.v11.5.fa",
		        "enrichment_path": "59894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59894.protein.info.v11.5.txt",
		        "node_list_path": "59894.protein.complete.v11.5.txt"
		    }
		]
    )()

def DethiosulfovibrioPeptidovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dethiosulfovibrio peptidovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DethiosulfovibrioPeptidovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469381.clusters.proteins.v11.5.txt",
		        "sequence_path": "469381.protein.sequences.v11.5.fa",
		        "enrichment_path": "469381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469381.protein.info.v11.5.txt",
		        "node_list_path": "469381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MuricaudaRuestringensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Muricauda ruestringensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuricaudaRuestringensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "886377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "886377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "886377.clusters.proteins.v11.5.txt",
		        "sequence_path": "886377.protein.sequences.v11.5.fa",
		        "enrichment_path": "886377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "886377.protein.info.v11.5.txt",
		        "node_list_path": "886377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "886377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryomorphaceaeBacteriumBacl7Mag120322Bin74Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL7 MAG-120322-bin74 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryomorphaceaeBacteriumBacl7Mag120322Bin74Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1655596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1655596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1655596.clusters.proteins.v11.5.txt",
		        "sequence_path": "1655596.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655596.protein.info.v11.5.txt",
		        "node_list_path": "1655596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1655596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JannaschiaSpEhc01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia sp. EhC01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaSpEhc01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849359.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849359.protein.info.v11.5.txt",
		        "node_list_path": "1849359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaVarigenaUsdaarsusmarc1261Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia varigena USDAARSUSMARC1261 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaVarigenaUsdaarsusmarc1261Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1432056.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1432056.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1432056.clusters.proteins.v11.5.txt",
		        "sequence_path": "1432056.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432056.protein.info.v11.5.txt",
		        "node_list_path": "1432056.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1432056.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot482Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root482 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot482Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736543.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736543.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736543.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736543.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736543.protein.info.v11.5.txt",
		        "node_list_path": "1736543.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736543.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumXanthum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium xanthum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumXanthum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69322.protein.sequences.v11.5.fa",
		        "enrichment_path": "69322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69322.protein.info.v11.5.txt",
		        "node_list_path": "69322.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalyomorphaHalys(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halyomorpha halys graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalyomorphaHalys", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235990.protein.info.v11.5.txt",
		        "node_list_path": "1235990.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesFunestusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles funestus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesFunestusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "62324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "62324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "62324.clusters.proteins.v11.5.txt",
		        "sequence_path": "62324.protein.sequences.v11.5.fa",
		        "enrichment_path": "62324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62324.protein.info.v11.5.txt",
		        "node_list_path": "62324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "62324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa23813Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_38_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa23813Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618811.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618811.protein.info.v11.5.txt",
		        "node_list_path": "1618811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAcetothermiaBacteriumJdfr52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acetothermia bacterium JdFR-52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAcetothermiaBacteriumJdfr52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935106.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935106.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935106.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935106.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935106.protein.info.v11.5.txt",
		        "node_list_path": "1935106.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935106.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg166615(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_66_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg166615", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797847.protein.info.v11.5.txt",
		        "node_list_path": "1797847.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumLactisRw25Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium lactis RW2-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumLactisRw25Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408189.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408189.protein.info.v11.5.txt",
		        "node_list_path": "1408189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc23210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC2_32_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc23210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618918.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618918.protein.info.v11.5.txt",
		        "node_list_path": "1618918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGlassbacteriaBacteriumRifcsplowo212Full5811(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Glassbacteria bacterium RIFCSPLOWO2_12_FULL_58_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGlassbacteriaBacteriumRifcsplowo212Full5811", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817867.protein.info.v11.5.txt",
		        "node_list_path": "1817867.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyaloscyphaVariabilisFCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyaloscypha variabilis F Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyaloscyphaVariabilisFCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1149755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1149755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1149755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1149755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1149755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1149755.protein.info.v11.5.txt",
		        "node_list_path": "1149755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1149755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumRaac4Od11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium RAAC4_OD1_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumRaac4Od11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1394712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1394712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1394712.clusters.proteins.v11.5.txt",
		        "sequence_path": "1394712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394712.protein.info.v11.5.txt",
		        "node_list_path": "1394712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1394712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichosporonAsahiiVarAsahiiCbs8904Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichosporon asahii var. asahii CBS 8904 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichosporonAsahiiVarAsahiiCbs8904Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220162.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220162.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220162.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220162.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220162.protein.info.v11.5.txt",
		        "node_list_path": "1220162.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220162.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraRamorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora ramorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraRamorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "164328.protein.sequences.v11.5.fa",
		        "enrichment_path": "164328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "164328.protein.info.v11.5.txt",
		        "node_list_path": "164328.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumGw2011Gwc13712(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWC1_37_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwc13712", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618483.protein.info.v11.5.txt",
		        "node_list_path": "1618483.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassilimaliaeMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilimaliae massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassilimaliaeMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852384.protein.info.v11.5.txt",
		        "node_list_path": "1852384.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumRuminantium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium ruminantium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumRuminantium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "78346.protein.sequences.v11.5.fa",
		        "enrichment_path": "78346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78346.protein.info.v11.5.txt",
		        "node_list_path": "78346.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwa25510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_55_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797809.protein.info.v11.5.txt",
		        "node_list_path": "1797809.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpC105kso13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. C105KSO13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpC105kso13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776045.protein.info.v11.5.txt",
		        "node_list_path": "1776045.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporomusaAcidovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporomusa acidovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporomusaAcidovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "112900.protein.sequences.v11.5.fa",
		        "enrichment_path": "112900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112900.protein.info.v11.5.txt",
		        "node_list_path": "112900.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeomicrococcusAestuariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neomicrococcus aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeomicrococcusAestuariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "556325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "556325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "556325.clusters.proteins.v11.5.txt",
		        "sequence_path": "556325.protein.sequences.v11.5.fa",
		        "enrichment_path": "556325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556325.protein.info.v11.5.txt",
		        "node_list_path": "556325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "556325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IctalurusPunctatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ictalurus punctatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IctalurusPunctatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7998.protein.sequences.v11.5.fa",
		        "enrichment_path": "7998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7998.protein.info.v11.5.txt",
		        "node_list_path": "7998.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiribacterSpUahsp71(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiribacter sp. UAHSP71 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiribacterSpUahsp71", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1335757.protein.sequences.v11.5.fa",
		        "enrichment_path": "1335757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1335757.protein.info.v11.5.txt",
		        "node_list_path": "1335757.protein.complete.v11.5.txt"
		    }
		]
    )()

def RubrivivaxGelatinosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubrivivax gelatinosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrivivaxGelatinosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983917.protein.sequences.v11.5.fa",
		        "enrichment_path": "983917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983917.protein.info.v11.5.txt",
		        "node_list_path": "983917.protein.complete.v11.5.txt"
		    }
		]
    )()

def AliiroseovariusSediminilitoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aliiroseovarius sediminilitoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliiroseovariusSediminilitoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173584.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173584.protein.info.v11.5.txt",
		        "node_list_path": "1173584.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacillusSpOk032Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacillus sp. OK032 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacillusSpOk032Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884358.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884358.protein.info.v11.5.txt",
		        "node_list_path": "1884358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSpechtbacteriaBacteriumRifcsphigho201Full4330(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPHIGHO2_01_FULL_43_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsphigho201Full4330", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802158.protein.info.v11.5.txt",
		        "node_list_path": "1802158.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScardoviaWiggsiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scardovia wiggsiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScardoviaWiggsiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "857290.protein.sequences.v11.5.fa",
		        "enrichment_path": "857290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857290.protein.info.v11.5.txt",
		        "node_list_path": "857290.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4620Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_FULL_46_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4620Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798338.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798338.protein.info.v11.5.txt",
		        "node_list_path": "1798338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpLeaf363(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Leaf363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpLeaf363", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736353.protein.info.v11.5.txt",
		        "node_list_path": "1736353.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinococcusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinococcus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinococcusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1371.protein.info.v11.5.txt",
		        "node_list_path": "1371.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacterium4081Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 40-81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacterium4081Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895835.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895835.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895835.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895835.protein.info.v11.5.txt",
		        "node_list_path": "1895835.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895835.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifoxyd1Full3935Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFOXYD1_FULL_39_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifoxyd1Full3935Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802780.protein.info.v11.5.txt",
		        "node_list_path": "1802780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSp520p1No423(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 520P1 No. 423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSp520p1No423", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1690037.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690037.protein.info.v11.5.txt",
		        "node_list_path": "1690037.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumParvumAcb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium parvum ACB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumParvumAcb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "796943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "796943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "796943.clusters.proteins.v11.5.txt",
		        "sequence_path": "796943.protein.sequences.v11.5.fa",
		        "enrichment_path": "796943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796943.protein.info.v11.5.txt",
		        "node_list_path": "796943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "796943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsathyrellaAberdarensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psathyrella aberdarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsathyrellaAberdarensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2316362.protein.sequences.v11.5.fa",
		        "enrichment_path": "2316362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2316362.protein.info.v11.5.txt",
		        "node_list_path": "2316362.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKerfeldbacteriaBacteriumRifcsphigho212Full4817Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPHIGHO2_12_FULL_48_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsphigho212Full4817Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798542.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798542.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798542.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798542.protein.info.v11.5.txt",
		        "node_list_path": "1798542.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798542.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiopsisSpTsri0078Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. TSRI0078 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisSpTsri0078Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1718951.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1718951.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1718951.clusters.proteins.v11.5.txt",
		        "sequence_path": "1718951.protein.sequences.v11.5.fa",
		        "enrichment_path": "1718951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1718951.protein.info.v11.5.txt",
		        "node_list_path": "1718951.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1718951.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TaeniopygiaGuttata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Taeniopygia guttata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TaeniopygiaGuttata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59729.protein.sequences.v11.5.fa",
		        "enrichment_path": "59729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59729.protein.info.v11.5.txt",
		        "node_list_path": "59729.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpInlla21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. INlla21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpInlla21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520811.protein.info.v11.5.txt",
		        "node_list_path": "1520811.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixibacteriaBacteriumRbg16439Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium RBG_16_43_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumRbg16439Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802784.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802784.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802784.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802784.protein.info.v11.5.txt",
		        "node_list_path": "1802784.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802784.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMuralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus muralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMuralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264697.protein.sequences.v11.5.fa",
		        "enrichment_path": "264697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264697.protein.info.v11.5.txt",
		        "node_list_path": "264697.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArenimonasMetalli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas metalli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenimonasMetalli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1384056.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384056.protein.info.v11.5.txt",
		        "node_list_path": "1384056.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpLc81Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LC81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpLc81Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502850.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502850.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502850.protein.info.v11.5.txt",
		        "node_list_path": "1502850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiumAgarilyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobium agarilyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiumAgarilyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122194.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122194.protein.info.v11.5.txt",
		        "node_list_path": "1122194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaThermophilaDsm6578(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta thermophila DSM 6578 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaThermophilaDsm6578", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "869211.protein.sequences.v11.5.fa",
		        "enrichment_path": "869211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869211.protein.info.v11.5.txt",
		        "node_list_path": "869211.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaTaeniospiralisNbrc102512(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga taeniospiralis NBRC 102512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaTaeniospiralisNbrc102512", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349793.protein.info.v11.5.txt",
		        "node_list_path": "1349793.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpC561(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. C561 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpC561", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "563031.protein.sequences.v11.5.fa",
		        "enrichment_path": "563031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563031.protein.info.v11.5.txt",
		        "node_list_path": "563031.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterSkirrowii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter skirrowii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSkirrowii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28200.protein.sequences.v11.5.fa",
		        "enrichment_path": "28200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28200.protein.info.v11.5.txt",
		        "node_list_path": "28200.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFraserbacteriaBacteriumRbg16559(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fraserbacteria bacterium RBG_16_55_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFraserbacteriaBacteriumRbg16559", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817864.protein.info.v11.5.txt",
		        "node_list_path": "1817864.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSpMarseilleP3519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sp. Marseille-P3519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSpMarseilleP3519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926284.protein.info.v11.5.txt",
		        "node_list_path": "1926284.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho201Full6320(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_01_FULL_63_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho201Full6320", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802385.protein.info.v11.5.txt",
		        "node_list_path": "1802385.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlloscardoviaMacacaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alloscardovia macacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloscardoviaMacacaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1160091.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1160091.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1160091.clusters.proteins.v11.5.txt",
		        "sequence_path": "1160091.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160091.protein.info.v11.5.txt",
		        "node_list_path": "1160091.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1160091.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinimicrobiumCatenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinimicrobium catena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinimicrobiumCatenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "390640.clusters.info.v11.5.txt",
		        "cluster_tree_path": "390640.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "390640.clusters.proteins.v11.5.txt",
		        "sequence_path": "390640.protein.sequences.v11.5.fa",
		        "enrichment_path": "390640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390640.protein.info.v11.5.txt",
		        "node_list_path": "390640.cluster.nodes.v11.5.txt",
		        "edge_list_path": "390640.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronomonasSpCba1134(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronomonas sp. CBA1134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronomonasSpCba1134", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906246.protein.info.v11.5.txt",
		        "node_list_path": "1906246.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSinaloensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sinaloensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSinaloensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "945550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "945550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "945550.clusters.proteins.v11.5.txt",
		        "sequence_path": "945550.protein.sequences.v11.5.fa",
		        "enrichment_path": "945550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "945550.protein.info.v11.5.txt",
		        "node_list_path": "945550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "945550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusHelveticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHelveticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1587.clusters.proteins.v11.5.txt",
		        "sequence_path": "1587.protein.sequences.v11.5.fa",
		        "enrichment_path": "1587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1587.protein.info.v11.5.txt",
		        "node_list_path": "1587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusFlavithermusYunnanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus yunnanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusFlavithermusYunnanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380408.protein.info.v11.5.txt",
		        "node_list_path": "1380408.protein.complete.v11.5.txt"
		    }
		]
    )()

def EwingellaAmericana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ewingella americana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EwingellaAmericana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "910964.protein.sequences.v11.5.fa",
		        "enrichment_path": "910964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "910964.protein.info.v11.5.txt",
		        "node_list_path": "910964.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisTerraeSubspTerraeNbrc15098(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis terrae subsp. terrae NBRC 15098 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisTerraeSubspTerraeNbrc15098", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219058.protein.info.v11.5.txt",
		        "node_list_path": "1219058.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb245a520k10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a520K10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb245a520k10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1471522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1471522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1471522.clusters.proteins.v11.5.txt",
		        "sequence_path": "1471522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471522.protein.info.v11.5.txt",
		        "node_list_path": "1471522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1471522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhoceaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phocea massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhoceaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841867.protein.info.v11.5.txt",
		        "node_list_path": "1841867.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelaginellaMoellendorffiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selaginella moellendorffii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelaginellaMoellendorffiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "88036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "88036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "88036.clusters.proteins.v11.5.txt",
		        "sequence_path": "88036.protein.sequences.v11.5.fa",
		        "enrichment_path": "88036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "88036.protein.info.v11.5.txt",
		        "node_list_path": "88036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "88036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifoxyb1Full5435Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFOXYB1_FULL_54_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifoxyb1Full5435Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801934.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801934.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801934.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801934.protein.info.v11.5.txt",
		        "node_list_path": "1801934.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801934.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColwelliaPsychrerythraea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia psychrerythraea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaPsychrerythraea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28229.protein.sequences.v11.5.fa",
		        "enrichment_path": "28229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28229.protein.info.v11.5.txt",
		        "node_list_path": "28229.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioOxyclinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio oxyclinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioOxyclinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121459.protein.info.v11.5.txt",
		        "node_list_path": "1121459.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermobifidaFuscaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermobifida fusca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobifidaFuscaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "269800.clusters.info.v11.5.txt",
		        "cluster_tree_path": "269800.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "269800.clusters.proteins.v11.5.txt",
		        "sequence_path": "269800.protein.sequences.v11.5.fa",
		        "enrichment_path": "269800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269800.protein.info.v11.5.txt",
		        "node_list_path": "269800.cluster.nodes.v11.5.txt",
		        "edge_list_path": "269800.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpC100Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. C100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpC100Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1207055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1207055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1207055.clusters.proteins.v11.5.txt",
		        "sequence_path": "1207055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1207055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1207055.protein.info.v11.5.txt",
		        "node_list_path": "1207055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1207055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGlaucescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces glaucescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGlaucescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907.protein.info.v11.5.txt",
		        "node_list_path": "1907.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3911(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3911", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798382.protein.info.v11.5.txt",
		        "node_list_path": "1798382.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusBromiiL263Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus bromii L2-63 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusBromiiL263Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "657321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "657321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "657321.clusters.proteins.v11.5.txt",
		        "sequence_path": "657321.protein.sequences.v11.5.fa",
		        "enrichment_path": "657321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657321.protein.info.v11.5.txt",
		        "node_list_path": "657321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "657321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShimiaSpSk013Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shimia sp. SK013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShimiaSpSk013Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1389006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1389006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1389006.clusters.proteins.v11.5.txt",
		        "sequence_path": "1389006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1389006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1389006.protein.info.v11.5.txt",
		        "node_list_path": "1389006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1389006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerotruncusSpCag528Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. CAG:528 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotruncusSpCag528Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262700.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262700.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262700.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262700.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262700.protein.info.v11.5.txt",
		        "node_list_path": "1262700.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262700.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumRbg134015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_13_40_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg134015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802593.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802593.protein.info.v11.5.txt",
		        "node_list_path": "1802593.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetonemaLongumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetonema longum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetonemaLongumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1009370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1009370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1009370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1009370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009370.protein.info.v11.5.txt",
		        "node_list_path": "1009370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1009370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KwoniellaPiniCbs10737Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella pini CBS 10737 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KwoniellaPiniCbs10737Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1296096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1296096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1296096.clusters.proteins.v11.5.txt",
		        "sequence_path": "1296096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296096.protein.info.v11.5.txt",
		        "node_list_path": "1296096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1296096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumScardoviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium scardovii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumScardoviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "158787.clusters.info.v11.5.txt",
		        "cluster_tree_path": "158787.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "158787.clusters.proteins.v11.5.txt",
		        "sequence_path": "158787.protein.sequences.v11.5.fa",
		        "enrichment_path": "158787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158787.protein.info.v11.5.txt",
		        "node_list_path": "158787.cluster.nodes.v11.5.txt",
		        "edge_list_path": "158787.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesGordoniiMs1Dsm23371(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides gordonii MS-1 DSM 23371 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesGordoniiMs1Dsm23371", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203610.protein.info.v11.5.txt",
		        "node_list_path": "1203610.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium4572128Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 4572_128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium4572128Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1971633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1971633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1971633.clusters.proteins.v11.5.txt",
		        "sequence_path": "1971633.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971633.protein.info.v11.5.txt",
		        "node_list_path": "1971633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1971633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMegateriumMsp201(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus megaterium MSP201 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMegateriumMsp201", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348908.protein.info.v11.5.txt",
		        "node_list_path": "1348908.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophagaMuralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga muralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaMuralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "291169.protein.sequences.v11.5.fa",
		        "enrichment_path": "291169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "291169.protein.info.v11.5.txt",
		        "node_list_path": "291169.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioThiocyanoxidansArh2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArh2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1279019.protein.sequences.v11.5.fa",
		        "enrichment_path": "1279019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1279019.protein.info.v11.5.txt",
		        "node_list_path": "1279019.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusInersCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus iners Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusInersCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "713605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "713605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "713605.clusters.proteins.v11.5.txt",
		        "sequence_path": "713605.protein.sequences.v11.5.fa",
		        "enrichment_path": "713605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713605.protein.info.v11.5.txt",
		        "node_list_path": "713605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "713605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaHydrophobicaNbrc16057(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia hydrophobica NBRC 16057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaHydrophobicaNbrc16057", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223541.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223541.protein.info.v11.5.txt",
		        "node_list_path": "1223541.protein.complete.v11.5.txt"
		    }
		]
    )()

def YangiaSpCcbMm3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yangia sp. CCB-MM3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YangiaSpCcbMm3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1792508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1792508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1792508.clusters.proteins.v11.5.txt",
		        "sequence_path": "1792508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792508.protein.info.v11.5.txt",
		        "node_list_path": "1792508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1792508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumKutscheriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium kutscheri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumKutscheriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35755.clusters.proteins.v11.5.txt",
		        "sequence_path": "35755.protein.sequences.v11.5.fa",
		        "enrichment_path": "35755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35755.protein.info.v11.5.txt",
		        "node_list_path": "35755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusSpLm3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. LM3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusSpLm3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1938608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938608.protein.info.v11.5.txt",
		        "node_list_path": "1938608.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmatimonadetesBacteriumJgi0000077K19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium JGI 0000077-K19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmatimonadetesBacteriumJgi0000077K19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1104605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1104605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1104605.clusters.proteins.v11.5.txt",
		        "sequence_path": "1104605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104605.protein.info.v11.5.txt",
		        "node_list_path": "1104605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1104605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpP2b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. P2b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpP2b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1938741.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938741.protein.info.v11.5.txt",
		        "node_list_path": "1938741.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterSpAf1028Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. AF1028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSpAf1028Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1355368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1355368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1355368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1355368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1355368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1355368.protein.info.v11.5.txt",
		        "node_list_path": "1355368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1355368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhycicoccusSpSoil748(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Soil748 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycicoccusSpSoil748", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736397.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736397.protein.info.v11.5.txt",
		        "node_list_path": "1736397.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusIainarchaeumAndersoniiScgcAaa011E11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Iainarchaeum andersonii SCGC AAA011-E11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusIainarchaeumAndersoniiScgcAaa011E11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1104576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104576.protein.info.v11.5.txt",
		        "node_list_path": "1104576.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldicoprobacterFaecalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldicoprobacter faecalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicoprobacterFaecalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "937334.protein.sequences.v11.5.fa",
		        "enrichment_path": "937334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937334.protein.info.v11.5.txt",
		        "node_list_path": "937334.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterBrevis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterBrevis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "74348.protein.sequences.v11.5.fa",
		        "enrichment_path": "74348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74348.protein.info.v11.5.txt",
		        "node_list_path": "74348.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellvibrioSpPsbb023Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio sp. PSBB023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioSpPsbb023Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945512.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945512.protein.info.v11.5.txt",
		        "node_list_path": "1945512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatenulisporaAcidiphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catenulispora acidiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenulisporaAcidiphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "479433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "479433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "479433.clusters.proteins.v11.5.txt",
		        "sequence_path": "479433.protein.sequences.v11.5.fa",
		        "enrichment_path": "479433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479433.protein.info.v11.5.txt",
		        "node_list_path": "479433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "479433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSalariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter salarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSalariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420917.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420917.protein.info.v11.5.txt",
		        "node_list_path": "1420917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpAbgCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. ABG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpAbgCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423322.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423322.protein.info.v11.5.txt",
		        "node_list_path": "1423322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BilophilaWadsworthia316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia 316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BilophilaWadsworthia316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "563192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "563192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "563192.clusters.proteins.v11.5.txt",
		        "sequence_path": "563192.protein.sequences.v11.5.fa",
		        "enrichment_path": "563192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563192.protein.info.v11.5.txt",
		        "node_list_path": "563192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "563192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusPlantarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus plantarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPlantarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "220668.protein.sequences.v11.5.fa",
		        "enrichment_path": "220668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220668.protein.info.v11.5.txt",
		        "node_list_path": "220668.protein.complete.v11.5.txt"
		    }
		]
    )()

def JannaschiaHelgolandensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia helgolandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaHelgolandensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "188906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "188906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "188906.clusters.proteins.v11.5.txt",
		        "sequence_path": "188906.protein.sequences.v11.5.fa",
		        "enrichment_path": "188906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188906.protein.info.v11.5.txt",
		        "node_list_path": "188906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "188906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoruegeriaMarinistellae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoruegeria marinistellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoruegeriaMarinistellae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739787.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739787.protein.info.v11.5.txt",
		        "node_list_path": "1739787.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSpMc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. MC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSpMc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717785.clusters.proteins.v11.5.txt",
		        "sequence_path": "717785.protein.sequences.v11.5.fa",
		        "enrichment_path": "717785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717785.protein.info.v11.5.txt",
		        "node_list_path": "717785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpCcge1002Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpCcge1002Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "640511.clusters.info.v11.5.txt",
		        "cluster_tree_path": "640511.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "640511.clusters.proteins.v11.5.txt",
		        "sequence_path": "640511.protein.sequences.v11.5.fa",
		        "enrichment_path": "640511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640511.protein.info.v11.5.txt",
		        "node_list_path": "640511.cluster.nodes.v11.5.txt",
		        "edge_list_path": "640511.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpA3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. A3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpA3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "595593.protein.sequences.v11.5.fa",
		        "enrichment_path": "595593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595593.protein.info.v11.5.txt",
		        "node_list_path": "595593.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1659200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1659200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1659200.clusters.proteins.v11.5.txt",
		        "sequence_path": "1659200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659200.protein.info.v11.5.txt",
		        "node_list_path": "1659200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1659200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaBrunensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella brunensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaBrunensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29422.protein.sequences.v11.5.fa",
		        "enrichment_path": "29422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29422.protein.info.v11.5.txt",
		        "node_list_path": "29422.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaceaeBacteriumFsla50209Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeriaceae bacterium FSLA50209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaceaeBacteriumFsla50209Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1497679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1497679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1497679.clusters.proteins.v11.5.txt",
		        "sequence_path": "1497679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1497679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1497679.protein.info.v11.5.txt",
		        "node_list_path": "1497679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1497679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusHaemoperoxidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus haemoperoxidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusHaemoperoxidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158608.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158608.protein.info.v11.5.txt",
		        "node_list_path": "1158608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BasileaPsittacipulmonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Basilea psittacipulmonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BasileaPsittacipulmonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1072685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1072685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1072685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1072685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1072685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1072685.protein.info.v11.5.txt",
		        "node_list_path": "1072685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1072685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OpitutusSpGas368(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Opitutus sp. GAS368 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpitutusSpGas368", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882749.protein.info.v11.5.txt",
		        "node_list_path": "1882749.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeliponaQuadrifasciataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Melipona quadrifasciata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeliponaQuadrifasciataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "166423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "166423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "166423.clusters.proteins.v11.5.txt",
		        "sequence_path": "166423.protein.sequences.v11.5.fa",
		        "enrichment_path": "166423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "166423.protein.info.v11.5.txt",
		        "node_list_path": "166423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "166423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubrobacterXylanophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubrobacter xylanophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrobacterXylanophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266117.protein.sequences.v11.5.fa",
		        "enrichment_path": "266117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266117.protein.info.v11.5.txt",
		        "node_list_path": "266117.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusNamurensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus namurensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusNamurensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1302286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302286.protein.info.v11.5.txt",
		        "node_list_path": "1302286.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumCitreum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium citreum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumCitreum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2036.protein.sequences.v11.5.fa",
		        "enrichment_path": "2036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2036.protein.info.v11.5.txt",
		        "node_list_path": "2036.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSymbiosumWal14163(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium symbiosum WAL14163 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSymbiosumWal14163", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742740.protein.sequences.v11.5.fa",
		        "enrichment_path": "742740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742740.protein.info.v11.5.txt",
		        "node_list_path": "742740.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorOwensensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor owensensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorOwensensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "632518.protein.sequences.v11.5.fa",
		        "enrichment_path": "632518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632518.protein.info.v11.5.txt",
		        "node_list_path": "632518.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrancisellaPersicaAtccVr331Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella persica ATCC VR-331 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaPersicaAtccVr331Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1086726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1086726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1086726.clusters.proteins.v11.5.txt",
		        "sequence_path": "1086726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1086726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1086726.protein.info.v11.5.txt",
		        "node_list_path": "1086726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1086726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterCryohalolentis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter cryohalolentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterCryohalolentis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "335284.protein.sequences.v11.5.fa",
		        "enrichment_path": "335284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335284.protein.info.v11.5.txt",
		        "node_list_path": "335284.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIs836Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-836 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIs836Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834160.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834160.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834160.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834160.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834160.protein.info.v11.5.txt",
		        "node_list_path": "1834160.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834160.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitromicrobiumSpJlt1363(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citromicrobium sp. JLT1363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitromicrobiumSpJlt1363", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "517722.protein.sequences.v11.5.fa",
		        "enrichment_path": "517722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "517722.protein.info.v11.5.txt",
		        "node_list_path": "517722.protein.complete.v11.5.txt"
		    }
		]
    )()

def LitoreibacterAlbidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Litoreibacter albidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LitoreibacterAlbidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "670155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "670155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "670155.clusters.proteins.v11.5.txt",
		        "sequence_path": "670155.protein.sequences.v11.5.fa",
		        "enrichment_path": "670155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670155.protein.info.v11.5.txt",
		        "node_list_path": "670155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "670155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwe23640(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE2_36_40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe23640", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618713.protein.info.v11.5.txt",
		        "node_list_path": "1618713.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpU5l(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. U5L graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpU5l", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596152.protein.sequences.v11.5.fa",
		        "enrichment_path": "596152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596152.protein.info.v11.5.txt",
		        "node_list_path": "596152.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumBeijerinckii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium beijerinckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBeijerinckii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290402.protein.sequences.v11.5.fa",
		        "enrichment_path": "290402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290402.protein.info.v11.5.txt",
		        "node_list_path": "290402.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumPasteurianumDsm525(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum DSM525 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPasteurianumDsm525", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262449.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262449.protein.info.v11.5.txt",
		        "node_list_path": "1262449.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusRaoultiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus raoultii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusRaoultiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776387.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776387.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776387.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776387.protein.info.v11.5.txt",
		        "node_list_path": "1776387.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776387.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaElongataSubspGlycolyticaAtcc29315(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria elongata subsp. glycolytica ATCC 29315 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaElongataSubspGlycolyticaAtcc29315", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546263.protein.sequences.v11.5.fa",
		        "enrichment_path": "546263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546263.protein.info.v11.5.txt",
		        "node_list_path": "546263.protein.complete.v11.5.txt"
		    }
		]
    )()

def HordeumVulgareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hordeum vulgare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HordeumVulgareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4513.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4513.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4513.clusters.proteins.v11.5.txt",
		        "sequence_path": "4513.protein.sequences.v11.5.fa",
		        "enrichment_path": "4513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4513.protein.info.v11.5.txt",
		        "node_list_path": "4513.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4513.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacterChinhatensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter chinhatensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterChinhatensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1436961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1436961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1436961.protein.info.v11.5.txt",
		        "node_list_path": "1436961.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSuisR61Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis R61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSuisR61Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "996306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "996306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "996306.clusters.proteins.v11.5.txt",
		        "sequence_path": "996306.protein.sequences.v11.5.fa",
		        "enrichment_path": "996306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "996306.protein.info.v11.5.txt",
		        "node_list_path": "996306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "996306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MalasseziaGlobosaCbs7966Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Malassezia globosa CBS 7966 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalasseziaGlobosaCbs7966Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "425265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "425265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "425265.clusters.proteins.v11.5.txt",
		        "sequence_path": "425265.protein.sequences.v11.5.fa",
		        "enrichment_path": "425265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425265.protein.info.v11.5.txt",
		        "node_list_path": "425265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "425265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag567(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:567 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag567", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262820.protein.info.v11.5.txt",
		        "node_list_path": "1262820.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulophagaTyrosinoxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga tyrosinoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaTyrosinoxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "504486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "504486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "504486.clusters.proteins.v11.5.txt",
		        "sequence_path": "504486.protein.sequences.v11.5.fa",
		        "enrichment_path": "504486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504486.protein.info.v11.5.txt",
		        "node_list_path": "504486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "504486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EggerthellaSp519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eggerthella sp. 51_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthellaSp519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897000.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897000.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897000.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897000.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897000.protein.info.v11.5.txt",
		        "node_list_path": "1897000.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897000.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SclerotiniaSclerotiorum1980Uf70Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sclerotinia sclerotiorum 1980 UF-70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SclerotiniaSclerotiorum1980Uf70Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665079.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665079.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665079.clusters.proteins.v11.5.txt",
		        "sequence_path": "665079.protein.sequences.v11.5.fa",
		        "enrichment_path": "665079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665079.protein.info.v11.5.txt",
		        "node_list_path": "665079.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665079.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnaporthiopsisPoaeAtcc64411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnaporthiopsis poae ATCC 64411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnaporthiopsisPoaeAtcc64411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644358.clusters.proteins.v11.5.txt",
		        "sequence_path": "644358.protein.sequences.v11.5.fa",
		        "enrichment_path": "644358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644358.protein.info.v11.5.txt",
		        "node_list_path": "644358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaMassilioguelmaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia massilioguelmaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaMassilioguelmaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1604354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1604354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1604354.protein.info.v11.5.txt",
		        "node_list_path": "1604354.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumZagget2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Zagget2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumZagget2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930015.protein.info.v11.5.txt",
		        "node_list_path": "1930015.protein.complete.v11.5.txt"
		    }
		]
    )()

def WilliamsiaSp1135(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Williamsia sp. 1135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WilliamsiaSp1135", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1889262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889262.protein.info.v11.5.txt",
		        "node_list_path": "1889262.protein.complete.v11.5.txt"
		    }
		]
    )()

def CycloclasticusSpSymbiontOfPoeciloscleridaSpN(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Poecilosclerida sp. N graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CycloclasticusSpSymbiontOfPoeciloscleridaSpN", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1840472.protein.sequences.v11.5.fa",
		        "enrichment_path": "1840472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1840472.protein.info.v11.5.txt",
		        "node_list_path": "1840472.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidocellaFacilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidocella facilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidocellaFacilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408419.protein.info.v11.5.txt",
		        "node_list_path": "1408419.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterInsulaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter insulae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterInsulaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "414048.clusters.info.v11.5.txt",
		        "cluster_tree_path": "414048.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "414048.clusters.proteins.v11.5.txt",
		        "sequence_path": "414048.protein.sequences.v11.5.fa",
		        "enrichment_path": "414048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "414048.protein.info.v11.5.txt",
		        "node_list_path": "414048.cluster.nodes.v11.5.txt",
		        "edge_list_path": "414048.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAidingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aidingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAidingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "910347.clusters.info.v11.5.txt",
		        "cluster_tree_path": "910347.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "910347.clusters.proteins.v11.5.txt",
		        "sequence_path": "910347.protein.sequences.v11.5.fa",
		        "enrichment_path": "910347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "910347.protein.info.v11.5.txt",
		        "node_list_path": "910347.cluster.nodes.v11.5.txt",
		        "edge_list_path": "910347.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeptunomonasPhycophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neptunomonas phycophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptunomonasPhycophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1572645.protein.sequences.v11.5.fa",
		        "enrichment_path": "1572645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1572645.protein.info.v11.5.txt",
		        "node_list_path": "1572645.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumOlb8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumOlb8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617419.protein.info.v11.5.txt",
		        "node_list_path": "1617419.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeorhizobiumGalegaeBvOfficinalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae bv. officinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorhizobiumGalegaeBvOfficinalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "323656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "323656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "323656.clusters.proteins.v11.5.txt",
		        "sequence_path": "323656.protein.sequences.v11.5.fa",
		        "enrichment_path": "323656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323656.protein.info.v11.5.txt",
		        "node_list_path": "323656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "323656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaSartisoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia sartisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaSartisoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83784.protein.sequences.v11.5.fa",
		        "enrichment_path": "83784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83784.protein.info.v11.5.txt",
		        "node_list_path": "83784.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArenitaleaLuteaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenitalea lutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenitaleaLuteaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1178825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1178825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1178825.clusters.proteins.v11.5.txt",
		        "sequence_path": "1178825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1178825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1178825.protein.info.v11.5.txt",
		        "node_list_path": "1178825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1178825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanothermobacterSpCat2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter sp. CaT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermobacterSpCat2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "866790.protein.sequences.v11.5.fa",
		        "enrichment_path": "866790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866790.protein.info.v11.5.txt",
		        "node_list_path": "866790.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusSpHmp52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. HMP52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusSpHmp52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1487923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1487923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1487923.protein.info.v11.5.txt",
		        "node_list_path": "1487923.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumGp1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium GP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumGp1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807745.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807745.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807745.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807745.protein.info.v11.5.txt",
		        "node_list_path": "1807745.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807745.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpStBin5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. ST-bin5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpStBin5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1978765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978765.protein.info.v11.5.txt",
		        "node_list_path": "1978765.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterArseniciresistens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter arseniciresistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterArseniciresistens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "913325.protein.sequences.v11.5.fa",
		        "enrichment_path": "913325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913325.protein.info.v11.5.txt",
		        "node_list_path": "913325.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeogobiusMelanostomusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neogobius melanostomus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeogobiusMelanostomusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47308.clusters.proteins.v11.5.txt",
		        "sequence_path": "47308.protein.sequences.v11.5.fa",
		        "enrichment_path": "47308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47308.protein.info.v11.5.txt",
		        "node_list_path": "47308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloteneraSp73sCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera sp. 73s Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraSp73sCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1165096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1165096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1165096.clusters.proteins.v11.5.txt",
		        "sequence_path": "1165096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1165096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1165096.protein.info.v11.5.txt",
		        "node_list_path": "1165096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1165096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMuproteobacteriaBacteriumRifcsplowo201Full6018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RIFCSPLOWO2_01_FULL_60_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRifcsplowo201Full6018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817768.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817768.protein.info.v11.5.txt",
		        "node_list_path": "1817768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesBicolor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces bicolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesBicolor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66874.protein.sequences.v11.5.fa",
		        "enrichment_path": "66874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66874.protein.info.v11.5.txt",
		        "node_list_path": "66874.protein.complete.v11.5.txt"
		    }
		]
    )()

def AggregatibacterActinomycetemcomitansHk1651Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans HK1651 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterActinomycetemcomitansHk1651Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272556.clusters.proteins.v11.5.txt",
		        "sequence_path": "272556.protein.sequences.v11.5.fa",
		        "enrichment_path": "272556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272556.protein.info.v11.5.txt",
		        "node_list_path": "272556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumGaetbulicolaGung47Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium gaetbulicola Gung47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumGaetbulicolaGung47Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658445.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658445.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658445.clusters.proteins.v11.5.txt",
		        "sequence_path": "658445.protein.sequences.v11.5.fa",
		        "enrichment_path": "658445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658445.protein.info.v11.5.txt",
		        "node_list_path": "658445.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658445.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobacillusDevoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacillus devorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobacillusDevoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "279813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "279813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "279813.clusters.proteins.v11.5.txt",
		        "sequence_path": "279813.protein.sequences.v11.5.fa",
		        "enrichment_path": "279813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279813.protein.info.v11.5.txt",
		        "node_list_path": "279813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "279813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusXylanexedens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus xylanexedens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusXylanexedens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "528191.protein.sequences.v11.5.fa",
		        "enrichment_path": "528191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "528191.protein.info.v11.5.txt",
		        "node_list_path": "528191.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_42_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802068.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802068.protein.info.v11.5.txt",
		        "node_list_path": "1802068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CardiobacteriumValvarumF0432(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cardiobacterium valvarum F0432 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CardiobacteriumValvarumF0432", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "797473.protein.sequences.v11.5.fa",
		        "enrichment_path": "797473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797473.protein.info.v11.5.txt",
		        "node_list_path": "797473.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp4fCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 4F Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp4fCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1751294.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1751294.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1751294.clusters.proteins.v11.5.txt",
		        "sequence_path": "1751294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1751294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1751294.protein.info.v11.5.txt",
		        "node_list_path": "1751294.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1751294.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliellaBurgdorferiB31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borreliella burgdorferi B31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliellaBurgdorferiB31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "224326.protein.sequences.v11.5.fa",
		        "enrichment_path": "224326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224326.protein.info.v11.5.txt",
		        "node_list_path": "224326.protein.complete.v11.5.txt"
		    }
		]
    )()

def Sar86ClusterBacteriumSar86eCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium SAR86E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar86ClusterBacteriumSar86eCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208365.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208365.protein.info.v11.5.txt",
		        "node_list_path": "1208365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBaumanniiAtcc17978(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii ATCC 17978 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBaumanniiAtcc17978", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "400667.protein.sequences.v11.5.fa",
		        "enrichment_path": "400667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400667.protein.info.v11.5.txt",
		        "node_list_path": "400667.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirosomaSp4814(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma sp. 48-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaSp4814", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895854.protein.info.v11.5.txt",
		        "node_list_path": "1895854.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfitobacteriumHafniense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium hafniense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitobacteriumHafniense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "138119.protein.sequences.v11.5.fa",
		        "enrichment_path": "138119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "138119.protein.info.v11.5.txt",
		        "node_list_path": "138119.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaLactamicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria lactamica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaLactamicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "489653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "489653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "489653.clusters.proteins.v11.5.txt",
		        "sequence_path": "489653.protein.sequences.v11.5.fa",
		        "enrichment_path": "489653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "489653.protein.info.v11.5.txt",
		        "node_list_path": "489653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "489653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpLeaf201(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf201 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpLeaf201", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735672.protein.info.v11.5.txt",
		        "node_list_path": "1735672.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumDiernhoferi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium diernhoferi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumDiernhoferi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801.protein.info.v11.5.txt",
		        "node_list_path": "1801.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioParadoxusArh1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio paradoxus ARh 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioParadoxusArh1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "713585.protein.sequences.v11.5.fa",
		        "enrichment_path": "713585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713585.protein.info.v11.5.txt",
		        "node_list_path": "713585.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwa23816Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_38_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa23816Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797802.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797802.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797802.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797802.protein.info.v11.5.txt",
		        "node_list_path": "1797802.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797802.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatagonusWagneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catagonus wagneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatagonusWagneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "51154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "51154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "51154.clusters.proteins.v11.5.txt",
		        "sequence_path": "51154.protein.sequences.v11.5.fa",
		        "enrichment_path": "51154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51154.protein.info.v11.5.txt",
		        "node_list_path": "51154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "51154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3818Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_38_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3818Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797795.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797795.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797795.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797795.protein.info.v11.5.txt",
		        "node_list_path": "1797795.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797795.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnt360(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT360 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnt360", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288080.protein.info.v11.5.txt",
		        "node_list_path": "1288080.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumSp20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium sp. 20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumSp20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798803.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798803.protein.info.v11.5.txt",
		        "node_list_path": "1798803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpMwb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. MWB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpMwb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1537715.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1537715.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1537715.clusters.proteins.v11.5.txt",
		        "sequence_path": "1537715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1537715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1537715.protein.info.v11.5.txt",
		        "node_list_path": "1537715.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1537715.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpExBiomphalariaGlabrata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. (ex Biomphalaria glabrata) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpExBiomphalariaGlabrata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1749074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1749074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1749074.protein.info.v11.5.txt",
		        "node_list_path": "1749074.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumThalpophilumDsm11723(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium thalpophilum DSM 11723 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumThalpophilumDsm11723", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123265.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123265.protein.info.v11.5.txt",
		        "node_list_path": "1123265.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaceaeBacteriumDnf00626Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonellaceae bacterium DNF00626 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaceaeBacteriumDnf00626Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1588754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1588754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1588754.clusters.proteins.v11.5.txt",
		        "sequence_path": "1588754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588754.protein.info.v11.5.txt",
		        "node_list_path": "1588754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1588754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychroserpensSpPamc27130Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens sp. PAMC27130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroserpensSpPamc27130Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1484460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1484460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1484460.clusters.proteins.v11.5.txt",
		        "sequence_path": "1484460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484460.protein.info.v11.5.txt",
		        "node_list_path": "1484460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1484460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusIgniterrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus igniterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusIgniterrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123388.protein.info.v11.5.txt",
		        "node_list_path": "1123388.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacterium1109Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium 1109 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacterium1109Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1655638.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1655638.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1655638.clusters.proteins.v11.5.txt",
		        "sequence_path": "1655638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655638.protein.info.v11.5.txt",
		        "node_list_path": "1655638.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1655638.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LaccariaAmethystinaLaam081(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Laccaria amethystina LaAM-08-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LaccariaAmethystinaLaam081", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095629.protein.info.v11.5.txt",
		        "node_list_path": "1095629.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiumSpLsA18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobium sp. LS-A18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiumSpLsA18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1381596.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381596.protein.info.v11.5.txt",
		        "node_list_path": "1381596.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlaesserellaParasuisSh0165Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaesserella parasuis SH0165 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaesserellaParasuisSh0165Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "557723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "557723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "557723.clusters.proteins.v11.5.txt",
		        "sequence_path": "557723.protein.sequences.v11.5.fa",
		        "enrichment_path": "557723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "557723.protein.info.v11.5.txt",
		        "node_list_path": "557723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "557723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RodentibacterGenomosp2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter genomosp. 2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterGenomosp2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1908266.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1908266.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1908266.clusters.proteins.v11.5.txt",
		        "sequence_path": "1908266.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908266.protein.info.v11.5.txt",
		        "node_list_path": "1908266.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1908266.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4613(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_46_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4613", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802312.protein.info.v11.5.txt",
		        "node_list_path": "1802312.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusOralisUo5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis Uo5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOralisUo5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "927666.clusters.info.v11.5.txt",
		        "cluster_tree_path": "927666.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "927666.clusters.proteins.v11.5.txt",
		        "sequence_path": "927666.protein.sequences.v11.5.fa",
		        "enrichment_path": "927666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927666.protein.info.v11.5.txt",
		        "node_list_path": "927666.cluster.nodes.v11.5.txt",
		        "edge_list_path": "927666.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpMit0701Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0701 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpMit0701Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499502.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499502.protein.info.v11.5.txt",
		        "node_list_path": "1499502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaDiminutumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma diminutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaDiminutumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1276221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1276221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1276221.clusters.proteins.v11.5.txt",
		        "sequence_path": "1276221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276221.protein.info.v11.5.txt",
		        "node_list_path": "1276221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1276221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassilibacillusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassilibacillusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1806837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806837.protein.info.v11.5.txt",
		        "node_list_path": "1806837.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumVignaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium vignae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumVignaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "690585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "690585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "690585.clusters.proteins.v11.5.txt",
		        "sequence_path": "690585.protein.sequences.v11.5.fa",
		        "enrichment_path": "690585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690585.protein.info.v11.5.txt",
		        "node_list_path": "690585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "690585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudacidovoraxIntermediusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudacidovorax intermedius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudacidovoraxIntermediusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "433924.clusters.info.v11.5.txt",
		        "cluster_tree_path": "433924.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "433924.clusters.proteins.v11.5.txt",
		        "sequence_path": "433924.protein.sequences.v11.5.fa",
		        "enrichment_path": "433924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "433924.protein.info.v11.5.txt",
		        "node_list_path": "433924.cluster.nodes.v11.5.txt",
		        "edge_list_path": "433924.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CardiobacteriumHominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cardiobacterium hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CardiobacteriumHominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2718.clusters.proteins.v11.5.txt",
		        "sequence_path": "2718.protein.sequences.v11.5.fa",
		        "enrichment_path": "2718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2718.protein.info.v11.5.txt",
		        "node_list_path": "2718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GramellaSpMar2010147(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gramella sp. MAR_2010_147 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaSpMar2010147", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1250205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250205.protein.info.v11.5.txt",
		        "node_list_path": "1250205.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusClavatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus clavatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusClavatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5057.clusters.proteins.v11.5.txt",
		        "sequence_path": "5057.protein.sequences.v11.5.fa",
		        "enrichment_path": "5057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5057.protein.info.v11.5.txt",
		        "node_list_path": "5057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexusIslandicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexus islandicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexusIslandicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1707952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1707952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1707952.clusters.proteins.v11.5.txt",
		        "sequence_path": "1707952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1707952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1707952.protein.info.v11.5.txt",
		        "node_list_path": "1707952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1707952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpM47t1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. M47T1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpM47t1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1179778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1179778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1179778.clusters.proteins.v11.5.txt",
		        "sequence_path": "1179778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179778.protein.info.v11.5.txt",
		        "node_list_path": "1179778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1179778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaModicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma modicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaModicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408417.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408417.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408417.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408417.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408417.protein.info.v11.5.txt",
		        "node_list_path": "1408417.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408417.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GiardiaLambliaAtcc50803Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Giardia lamblia ATCC 50803 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GiardiaLambliaAtcc50803Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "184922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "184922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "184922.clusters.proteins.v11.5.txt",
		        "sequence_path": "184922.protein.sequences.v11.5.fa",
		        "enrichment_path": "184922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "184922.protein.info.v11.5.txt",
		        "node_list_path": "184922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "184922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthobacterSoliDsm19599(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthobacter soli DSM 19599 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthobacterSoliDsm19599", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123029.protein.info.v11.5.txt",
		        "node_list_path": "1123029.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumGwc23612(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWC2_36_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumGwc23612", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798427.protein.info.v11.5.txt",
		        "node_list_path": "1798427.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilariopsisChorda(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gracilariopsis chorda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilariopsisChorda", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "448386.protein.sequences.v11.5.fa",
		        "enrichment_path": "448386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "448386.protein.info.v11.5.txt",
		        "node_list_path": "448386.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterNonchromogenicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter nonchromogenicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterNonchromogenicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1782.clusters.proteins.v11.5.txt",
		        "sequence_path": "1782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1782.protein.info.v11.5.txt",
		        "node_list_path": "1782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpGfaj1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. GFAJ1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpGfaj1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118153.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118153.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118153.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118153.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118153.protein.info.v11.5.txt",
		        "node_list_path": "1118153.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118153.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermocrinisRuberCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermocrinis ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocrinisRuberCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "932678.clusters.info.v11.5.txt",
		        "cluster_tree_path": "932678.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "932678.clusters.proteins.v11.5.txt",
		        "sequence_path": "932678.protein.sequences.v11.5.fa",
		        "enrichment_path": "932678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932678.protein.info.v11.5.txt",
		        "node_list_path": "932678.cluster.nodes.v11.5.txt",
		        "edge_list_path": "932678.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaSolanacearumPsi07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum PSI07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSolanacearumPsi07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "859657.protein.sequences.v11.5.fa",
		        "enrichment_path": "859657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "859657.protein.info.v11.5.txt",
		        "node_list_path": "859657.protein.complete.v11.5.txt"
		    }
		]
    )()

def BabesiaBovisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Babesia bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BabesiaBovisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5865.clusters.proteins.v11.5.txt",
		        "sequence_path": "5865.protein.sequences.v11.5.fa",
		        "enrichment_path": "5865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5865.protein.info.v11.5.txt",
		        "node_list_path": "5865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpRoot720(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root720 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpRoot720", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736595.protein.info.v11.5.txt",
		        "node_list_path": "1736595.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldisericumSpCg2303611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldisericum sp. CG2_30_36_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldisericumSpCg2303611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805053.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805053.protein.info.v11.5.txt",
		        "node_list_path": "1805053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PucciniaStriiformisFSpTriticiPst78(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Puccinia striiformis f. sp. tritici PST-78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PucciniaStriiformisFSpTriticiPst78", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1165861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1165861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1165861.protein.info.v11.5.txt",
		        "node_list_path": "1165861.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlochmanniaEndosymbiontOfPolyrhachisHedomyrmaTurneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Polyrhachis (Hedomyrma) turneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlochmanniaEndosymbiontOfPolyrhachisHedomyrmaTurneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1505596.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505596.protein.info.v11.5.txt",
		        "node_list_path": "1505596.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetalesBacteriumSpiro07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetalesBacteriumSpiro07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674863.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674863.protein.info.v11.5.txt",
		        "node_list_path": "1674863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JeotgalicoccusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalicoccus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalicoccusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "586411.protein.sequences.v11.5.fa",
		        "enrichment_path": "586411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "586411.protein.info.v11.5.txt",
		        "node_list_path": "586411.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasStellipolaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas stellipolaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasStellipolaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "233316.protein.sequences.v11.5.fa",
		        "enrichment_path": "233316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "233316.protein.info.v11.5.txt",
		        "node_list_path": "233316.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinomicrobiumOceaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinomicrobium oceani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinomicrobiumOceaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150368.protein.info.v11.5.txt",
		        "node_list_path": "1150368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeishmaniaPanamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leishmania panamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeishmaniaPanamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5679.protein.sequences.v11.5.fa",
		        "enrichment_path": "5679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5679.protein.info.v11.5.txt",
		        "node_list_path": "5679.protein.complete.v11.5.txt"
		    }
		]
    )()

def DendrosporobacterQuercicolusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dendrosporobacter quercicolus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DendrosporobacterQuercicolusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "146817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "146817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "146817.clusters.proteins.v11.5.txt",
		        "sequence_path": "146817.protein.sequences.v11.5.fa",
		        "enrichment_path": "146817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146817.protein.info.v11.5.txt",
		        "node_list_path": "146817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "146817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumSp64120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. 64-120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumSp64120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895778.protein.info.v11.5.txt",
		        "node_list_path": "1895778.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudovibrioSpAb134(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. Ab134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioSpAb134", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1898042.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898042.protein.info.v11.5.txt",
		        "node_list_path": "1898042.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacterium13220cm6814(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium 13_2_20CM_68_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacterium13220cm6814", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803496.protein.info.v11.5.txt",
		        "node_list_path": "1803496.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumCg2304315Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CG2_30_43_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumCg2304315Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805125.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805125.protein.info.v11.5.txt",
		        "node_list_path": "1805125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf22910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_29_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf22910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797340.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797340.protein.info.v11.5.txt",
		        "node_list_path": "1797340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaProteamaculansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia proteamaculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaProteamaculansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "399741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "399741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "399741.clusters.proteins.v11.5.txt",
		        "sequence_path": "399741.protein.sequences.v11.5.fa",
		        "enrichment_path": "399741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399741.protein.info.v11.5.txt",
		        "node_list_path": "399741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "399741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumAggregansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium aggregans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumAggregansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "81409.clusters.info.v11.5.txt",
		        "cluster_tree_path": "81409.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "81409.clusters.proteins.v11.5.txt",
		        "sequence_path": "81409.protein.sequences.v11.5.fa",
		        "enrichment_path": "81409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81409.protein.info.v11.5.txt",
		        "node_list_path": "81409.cluster.nodes.v11.5.txt",
		        "edge_list_path": "81409.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KurthiaSp11kri321Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kurthia sp. 11kri321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KurthiaSp11kri321Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1750719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1750719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1750719.clusters.proteins.v11.5.txt",
		        "sequence_path": "1750719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1750719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1750719.protein.info.v11.5.txt",
		        "node_list_path": "1750719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1750719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinisporaPacifica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinispora pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisporaPacifica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1136417.protein.sequences.v11.5.fa",
		        "enrichment_path": "1136417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1136417.protein.info.v11.5.txt",
		        "node_list_path": "1136417.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesMassiliensis4401292(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces massiliensis 4401292 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesMassiliensis4401292", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1167628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1167628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1167628.protein.info.v11.5.txt",
		        "node_list_path": "1167628.protein.complete.v11.5.txt"
		    }
		]
    )()

def KrasilnikoviellaFlavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Krasilnikoviella flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KrasilnikoviellaFlavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "526729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "526729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "526729.clusters.proteins.v11.5.txt",
		        "sequence_path": "526729.protein.sequences.v11.5.fa",
		        "enrichment_path": "526729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526729.protein.info.v11.5.txt",
		        "node_list_path": "526729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "526729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaprevotellaClara(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraprevotella clara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaprevotellaClara", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762968.protein.sequences.v11.5.fa",
		        "enrichment_path": "762968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762968.protein.info.v11.5.txt",
		        "node_list_path": "762968.protein.complete.v11.5.txt"
		    }
		]
    )()

def BalneolaVulgarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Balneola vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BalneolaVulgarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121104.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121104.protein.info.v11.5.txt",
		        "node_list_path": "1121104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3912Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_39_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3912Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797785.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797785.protein.info.v11.5.txt",
		        "node_list_path": "1797785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UrsusMaritimus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ursus maritimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UrsusMaritimus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29073.protein.sequences.v11.5.fa",
		        "enrichment_path": "29073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29073.protein.info.v11.5.txt",
		        "node_list_path": "29073.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterSpCit045(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. CIT045 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSpCit045", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1448857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448857.protein.info.v11.5.txt",
		        "node_list_path": "1448857.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThraustothecaClavata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thraustotheca clavata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThraustothecaClavata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "74557.protein.sequences.v11.5.fa",
		        "enrichment_path": "74557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74557.protein.info.v11.5.txt",
		        "node_list_path": "74557.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumPropionicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium propionicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumPropionicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "767029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "767029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "767029.clusters.proteins.v11.5.txt",
		        "sequence_path": "767029.protein.sequences.v11.5.fa",
		        "enrichment_path": "767029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767029.protein.info.v11.5.txt",
		        "node_list_path": "767029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "767029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaEnhydraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia enhydra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaEnhydraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665118.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665118.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665118.clusters.proteins.v11.5.txt",
		        "sequence_path": "665118.protein.sequences.v11.5.fa",
		        "enrichment_path": "665118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665118.protein.info.v11.5.txt",
		        "node_list_path": "665118.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665118.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaSymbiotica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia symbiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSymbiotica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "568817.protein.sequences.v11.5.fa",
		        "enrichment_path": "568817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568817.protein.info.v11.5.txt",
		        "node_list_path": "568817.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaRochalimae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella rochalimae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaRochalimae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "685782.protein.sequences.v11.5.fa",
		        "enrichment_path": "685782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "685782.protein.info.v11.5.txt",
		        "node_list_path": "685782.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusXiangfangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus xiangfangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusXiangfangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "942150.clusters.info.v11.5.txt",
		        "cluster_tree_path": "942150.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "942150.clusters.proteins.v11.5.txt",
		        "sequence_path": "942150.protein.sequences.v11.5.fa",
		        "enrichment_path": "942150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "942150.protein.info.v11.5.txt",
		        "node_list_path": "942150.cluster.nodes.v11.5.txt",
		        "edge_list_path": "942150.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium637(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 63-7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium637", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895813.protein.info.v11.5.txt",
		        "node_list_path": "1895813.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusArgenteusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus argenteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusArgenteusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "985002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "985002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "985002.clusters.proteins.v11.5.txt",
		        "sequence_path": "985002.protein.sequences.v11.5.fa",
		        "enrichment_path": "985002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985002.protein.info.v11.5.txt",
		        "node_list_path": "985002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "985002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumFalciparumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium falciparum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumFalciparumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5833.clusters.proteins.v11.5.txt",
		        "sequence_path": "5833.protein.sequences.v11.5.fa",
		        "enrichment_path": "5833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5833.protein.info.v11.5.txt",
		        "node_list_path": "5833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumUc511d10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-1D10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumUc511d10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1697787.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1697787.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1697787.clusters.proteins.v11.5.txt",
		        "sequence_path": "1697787.protein.sequences.v11.5.fa",
		        "enrichment_path": "1697787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1697787.protein.info.v11.5.txt",
		        "node_list_path": "1697787.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1697787.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpOv118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ov118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpOv118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761747.protein.info.v11.5.txt",
		        "node_list_path": "1761747.protein.complete.v11.5.txt"
		    }
		]
    )()

def HungateiclostridiaceaeBacteriumKb18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hungateiclostridiaceae bacterium KB18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HungateiclostridiaceaeBacteriumKb18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834198.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834198.protein.info.v11.5.txt",
		        "node_list_path": "1834198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpN324Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. N324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpN324Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703969.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703969.protein.info.v11.5.txt",
		        "node_list_path": "1703969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSaccharolyticumWm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium saccharolyticum WM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSaccharolyticumWm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "610130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "610130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "610130.clusters.proteins.v11.5.txt",
		        "sequence_path": "610130.protein.sequences.v11.5.fa",
		        "enrichment_path": "610130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "610130.protein.info.v11.5.txt",
		        "node_list_path": "610130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "610130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwc25213Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWC2_52_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwc25213Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802181.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802181.protein.info.v11.5.txt",
		        "node_list_path": "1802181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterLuteolusNbrc107841Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter luteolus NBRC 107841 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterLuteolusNbrc107841Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216973.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216973.protein.info.v11.5.txt",
		        "node_list_path": "1216973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillibacterSpKle1728Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. KLE1728 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSpKle1728Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1226322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1226322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1226322.clusters.proteins.v11.5.txt",
		        "sequence_path": "1226322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1226322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1226322.protein.info.v11.5.txt",
		        "node_list_path": "1226322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1226322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumKh2t8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium KH2T8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumKh2t8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855400.protein.info.v11.5.txt",
		        "node_list_path": "1855400.protein.complete.v11.5.txt"
		    }
		]
    )()

def PediococcusEthanoliduransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus ethanolidurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusEthanoliduransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "319653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "319653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "319653.clusters.proteins.v11.5.txt",
		        "sequence_path": "319653.protein.sequences.v11.5.fa",
		        "enrichment_path": "319653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319653.protein.info.v11.5.txt",
		        "node_list_path": "319653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "319653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodovibrioSalinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodovibrio salinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovibrioSalinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089552.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089552.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089552.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089552.protein.info.v11.5.txt",
		        "node_list_path": "1089552.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089552.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumCeleriflavum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium celeriflavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumCeleriflavum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1249101.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249101.protein.info.v11.5.txt",
		        "node_list_path": "1249101.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho202Full4219Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_42_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full4219Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801756.protein.info.v11.5.txt",
		        "node_list_path": "1801756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosocosmicusExaquareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosocosmicus exaquare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosocosmicusExaquareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1826872.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1826872.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1826872.clusters.proteins.v11.5.txt",
		        "sequence_path": "1826872.protein.sequences.v11.5.fa",
		        "enrichment_path": "1826872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1826872.protein.info.v11.5.txt",
		        "node_list_path": "1826872.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1826872.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifcsphigho201Full5431Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_01_FULL_54_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho201Full5431Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801637.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801637.protein.info.v11.5.txt",
		        "node_list_path": "1801637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloarculaMarismortui(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula marismortui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaMarismortui", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272569.protein.sequences.v11.5.fa",
		        "enrichment_path": "272569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272569.protein.info.v11.5.txt",
		        "node_list_path": "272569.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumArgentoratense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium argentoratense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumArgentoratense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348662.protein.info.v11.5.txt",
		        "node_list_path": "1348662.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusFervens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus fervens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusFervens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573064.protein.sequences.v11.5.fa",
		        "enrichment_path": "573064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573064.protein.info.v11.5.txt",
		        "node_list_path": "573064.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseomonasMucosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas mucosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseomonasMucosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "207340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "207340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "207340.clusters.proteins.v11.5.txt",
		        "sequence_path": "207340.protein.sequences.v11.5.fa",
		        "enrichment_path": "207340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "207340.protein.info.v11.5.txt",
		        "node_list_path": "207340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "207340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisBriggsae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis briggsae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisBriggsae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6238.protein.sequences.v11.5.fa",
		        "enrichment_path": "6238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6238.protein.info.v11.5.txt",
		        "node_list_path": "6238.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudothermotogaHypogeaDsm11164Nbrc106472(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudothermotoga hypogea DSM 11164 NBRC 106472 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudothermotogaHypogeaDsm11164Nbrc106472", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123384.protein.info.v11.5.txt",
		        "node_list_path": "1123384.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusPlantarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus plantarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusPlantarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1077675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1077675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1077675.clusters.proteins.v11.5.txt",
		        "sequence_path": "1077675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077675.protein.info.v11.5.txt",
		        "node_list_path": "1077675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1077675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1414718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1414718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1414718.clusters.proteins.v11.5.txt",
		        "sequence_path": "1414718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414718.protein.info.v11.5.txt",
		        "node_list_path": "1414718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1414718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpAcam123(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. ACAM123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpAcam123", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1189620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1189620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1189620.protein.info.v11.5.txt",
		        "node_list_path": "1189620.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpS6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. S6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpS6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1479623.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1479623.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1479623.clusters.proteins.v11.5.txt",
		        "sequence_path": "1479623.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479623.protein.info.v11.5.txt",
		        "node_list_path": "1479623.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1479623.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumGastriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium gastri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumGastriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777.protein.info.v11.5.txt",
		        "node_list_path": "1777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriiaBacterium4080Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriia bacterium 40-80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriiaBacterium4080Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895763.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895763.protein.info.v11.5.txt",
		        "node_list_path": "1895763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillatoriaAcuminataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoria acuminata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillatoriaAcuminataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56110.clusters.proteins.v11.5.txt",
		        "sequence_path": "56110.protein.sequences.v11.5.fa",
		        "enrichment_path": "56110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56110.protein.info.v11.5.txt",
		        "node_list_path": "56110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubrivivaxBenzoatilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubrivivax benzoatilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrivivaxBenzoatilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "987059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "987059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "987059.clusters.proteins.v11.5.txt",
		        "sequence_path": "987059.protein.sequences.v11.5.fa",
		        "enrichment_path": "987059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "987059.protein.info.v11.5.txt",
		        "node_list_path": "987059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "987059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumJdfr86Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumJdfr86Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935147.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935147.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935147.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935147.protein.info.v11.5.txt",
		        "node_list_path": "1935147.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935147.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetragenococcusMuriaticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetragenococcus muriaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetragenococcusMuriaticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123359.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123359.protein.info.v11.5.txt",
		        "node_list_path": "1123359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusIntermediusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus intermedius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusIntermediusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "862967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "862967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "862967.clusters.proteins.v11.5.txt",
		        "sequence_path": "862967.protein.sequences.v11.5.fa",
		        "enrichment_path": "862967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862967.protein.info.v11.5.txt",
		        "node_list_path": "862967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "862967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesBacteriumScgcAaa011B20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates bacterium SCGC AAA011-B20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesBacteriumScgcAaa011B20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1104610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104610.protein.info.v11.5.txt",
		        "node_list_path": "1104610.protein.complete.v11.5.txt"
		    }
		]
    )()

def SneathiaSanguinegens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sneathia sanguinegens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SneathiaSanguinegens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40543.protein.sequences.v11.5.fa",
		        "enrichment_path": "40543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40543.protein.info.v11.5.txt",
		        "node_list_path": "40543.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndomicrobiumProavitum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Endomicrobium proavitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndomicrobiumProavitum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408281.protein.info.v11.5.txt",
		        "node_list_path": "1408281.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3317Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_33_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3317Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801764.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801764.protein.info.v11.5.txt",
		        "node_list_path": "1801764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalegentibacterSalinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter salinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterSalinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "447422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "447422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "447422.clusters.proteins.v11.5.txt",
		        "sequence_path": "447422.protein.sequences.v11.5.fa",
		        "enrichment_path": "447422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "447422.protein.info.v11.5.txt",
		        "node_list_path": "447422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "447422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpTdk1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. TDK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpTdk1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "453247.protein.sequences.v11.5.fa",
		        "enrichment_path": "453247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "453247.protein.info.v11.5.txt",
		        "node_list_path": "453247.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpL250Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. L250 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpL250Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411489.clusters.proteins.v11.5.txt",
		        "sequence_path": "411489.protein.sequences.v11.5.fa",
		        "enrichment_path": "411489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411489.protein.info.v11.5.txt",
		        "node_list_path": "411489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumCentrolobiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium centrolobii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumCentrolobiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1505087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1505087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1505087.clusters.proteins.v11.5.txt",
		        "sequence_path": "1505087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505087.protein.info.v11.5.txt",
		        "node_list_path": "1505087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1505087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicoccusAlbus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusAlbus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123230.protein.info.v11.5.txt",
		        "node_list_path": "1123230.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusRhizosphaeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusRhizosphaeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "297318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "297318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "297318.clusters.proteins.v11.5.txt",
		        "sequence_path": "297318.protein.sequences.v11.5.fa",
		        "enrichment_path": "297318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "297318.protein.info.v11.5.txt",
		        "node_list_path": "297318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "297318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromatialesBacteriumUscgTaylor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chromatiales bacterium USCg_Taylor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromatialesBacteriumUscgTaylor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1934255.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934255.protein.info.v11.5.txt",
		        "node_list_path": "1934255.protein.complete.v11.5.txt"
		    }
		]
    )()

def NostocSpPcc7524Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7524 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocSpPcc7524Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28072.clusters.proteins.v11.5.txt",
		        "sequence_path": "28072.protein.sequences.v11.5.fa",
		        "enrichment_path": "28072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28072.protein.info.v11.5.txt",
		        "node_list_path": "28072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EmticiciaOligotrophicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Emticicia oligotrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmticiciaOligotrophicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "929562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "929562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "929562.clusters.proteins.v11.5.txt",
		        "sequence_path": "929562.protein.sequences.v11.5.fa",
		        "enrichment_path": "929562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929562.protein.info.v11.5.txt",
		        "node_list_path": "929562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "929562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucunaPruriensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucuna pruriens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucunaPruriensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "157652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "157652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "157652.clusters.proteins.v11.5.txt",
		        "sequence_path": "157652.protein.sequences.v11.5.fa",
		        "enrichment_path": "157652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157652.protein.info.v11.5.txt",
		        "node_list_path": "157652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "157652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobulbusSpTolSrCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus sp. Tol-SR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbusSpTolSrCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1536652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1536652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1536652.clusters.proteins.v11.5.txt",
		        "sequence_path": "1536652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536652.protein.info.v11.5.txt",
		        "node_list_path": "1536652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1536652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpHw567(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. HW567 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpHw567", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1034769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034769.protein.info.v11.5.txt",
		        "node_list_path": "1034769.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4035(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_40_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4035", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797534.protein.info.v11.5.txt",
		        "node_list_path": "1797534.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpWcd3002(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. WCD3002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpWcd3002", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280676.protein.info.v11.5.txt",
		        "node_list_path": "1280676.protein.complete.v11.5.txt"
		    }
		]
    )()

def NotechisScutatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Notechis scutatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NotechisScutatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8663.protein.sequences.v11.5.fa",
		        "enrichment_path": "8663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8663.protein.info.v11.5.txt",
		        "node_list_path": "8663.protein.complete.v11.5.txt"
		    }
		]
    )()

def OnchocercaOchengi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Onchocerca ochengi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OnchocercaOchengi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42157.protein.sequences.v11.5.fa",
		        "enrichment_path": "42157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42157.protein.info.v11.5.txt",
		        "node_list_path": "42157.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolymorphumGilvumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polymorphum gilvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolymorphumGilvumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "991905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "991905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "991905.clusters.proteins.v11.5.txt",
		        "sequence_path": "991905.protein.sequences.v11.5.fa",
		        "enrichment_path": "991905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "991905.protein.info.v11.5.txt",
		        "node_list_path": "991905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "991905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillibacterSpCag241(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. CAG:241 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSpCag241", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262911.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262911.protein.info.v11.5.txt",
		        "node_list_path": "1262911.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgarivoransAlbusMkt106Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agarivorans albus MKT 106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgarivoransAlbusMkt106Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1331007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1331007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1331007.clusters.proteins.v11.5.txt",
		        "sequence_path": "1331007.protein.sequences.v11.5.fa",
		        "enrichment_path": "1331007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1331007.protein.info.v11.5.txt",
		        "node_list_path": "1331007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1331007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureococcusAnophagefferensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureococcus anophagefferens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureococcusAnophagefferensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44056.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44056.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44056.clusters.proteins.v11.5.txt",
		        "sequence_path": "44056.protein.sequences.v11.5.fa",
		        "enrichment_path": "44056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44056.protein.info.v11.5.txt",
		        "node_list_path": "44056.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44056.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaVarigenaUsmarc1261(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena USMARC1261 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaVarigenaUsmarc1261", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1432056.protein.sequences.v11.0.fa",
		        "enrichment_path": "1432056.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1432056.protein.info.v11.0.txt",
		        "node_list_path": "1432056.protein.complete.v11.0.txt"
		    }
		]
    )()

def AnophelesSinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesSinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "74873.protein.sequences.v11.5.fa",
		        "enrichment_path": "74873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74873.protein.info.v11.5.txt",
		        "node_list_path": "74873.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacillusKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacillus koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacillusKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1069220.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069220.protein.info.v11.5.txt",
		        "node_list_path": "1069220.protein.complete.v11.5.txt"
		    }
		]
    )()

def LebetimonasSpJs170Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lebetimonas sp. JS170 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LebetimonasSpJs170Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "990073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "990073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "990073.clusters.proteins.v11.5.txt",
		        "sequence_path": "990073.protein.sequences.v11.5.fa",
		        "enrichment_path": "990073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990073.protein.info.v11.5.txt",
		        "node_list_path": "990073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "990073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumArcachonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum arcachonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumArcachonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123326.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123326.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123326.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123326.protein.info.v11.5.txt",
		        "node_list_path": "1123326.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123326.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag964(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:964 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag964", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262848.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262848.protein.info.v11.5.txt",
		        "node_list_path": "1262848.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrococcusHorikoshiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus horikoshii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusHorikoshiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "70601.clusters.info.v11.5.txt",
		        "cluster_tree_path": "70601.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "70601.clusters.proteins.v11.5.txt",
		        "sequence_path": "70601.protein.sequences.v11.5.fa",
		        "enrichment_path": "70601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "70601.protein.info.v11.5.txt",
		        "node_list_path": "70601.cluster.nodes.v11.5.txt",
		        "edge_list_path": "70601.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicoccusQingdaonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus qingdaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusQingdaonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "576118.protein.sequences.v11.5.fa",
		        "enrichment_path": "576118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "576118.protein.info.v11.5.txt",
		        "node_list_path": "576118.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaSubspDiarizonaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. diarizonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaSubspDiarizonaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59204.clusters.proteins.v11.5.txt",
		        "sequence_path": "59204.protein.sequences.v11.5.fa",
		        "enrichment_path": "59204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59204.protein.info.v11.5.txt",
		        "node_list_path": "59204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaribacterAtrinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter atrinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterAtrinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1333662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1333662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1333662.clusters.proteins.v11.5.txt",
		        "sequence_path": "1333662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333662.protein.info.v11.5.txt",
		        "node_list_path": "1333662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1333662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaWeihenstephanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria weihenstephanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaWeihenstephanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265845.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265845.protein.info.v11.5.txt",
		        "node_list_path": "1265845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumIntracellulareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium intracellulare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumIntracellulareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "487521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "487521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "487521.clusters.proteins.v11.5.txt",
		        "sequence_path": "487521.protein.sequences.v11.5.fa",
		        "enrichment_path": "487521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487521.protein.info.v11.5.txt",
		        "node_list_path": "487521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "487521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRu33bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. RU33B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRu33bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907390.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907390.protein.info.v11.5.txt",
		        "node_list_path": "1907390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSpH5989(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. H5989 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpH5989", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1643450.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643450.protein.info.v11.5.txt",
		        "node_list_path": "1643450.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesDokdonensisFr1436Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides dokdonensis FR1436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesDokdonensisFr1436Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1300347.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1300347.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1300347.clusters.proteins.v11.5.txt",
		        "sequence_path": "1300347.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300347.protein.info.v11.5.txt",
		        "node_list_path": "1300347.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1300347.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpGw1013h11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. GW101-3H11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpGw1013h11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1813946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1813946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1813946.clusters.proteins.v11.5.txt",
		        "sequence_path": "1813946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1813946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1813946.protein.info.v11.5.txt",
		        "node_list_path": "1813946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1813946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpTnhr37b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. TNHR37B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpTnhr37b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1775956.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775956.protein.info.v11.5.txt",
		        "node_list_path": "1775956.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioFibrisolvensNd3005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens ND3005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioFibrisolvensNd3005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280696.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280696.protein.info.v11.5.txt",
		        "node_list_path": "1280696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastococcusSpDsm44205Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 44205 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusSpDsm44205Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1550233.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1550233.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1550233.clusters.proteins.v11.5.txt",
		        "sequence_path": "1550233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550233.protein.info.v11.5.txt",
		        "node_list_path": "1550233.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1550233.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaSpJc230Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta sp. JC230 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaSpJc230Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1480694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1480694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1480694.clusters.proteins.v11.5.txt",
		        "sequence_path": "1480694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1480694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1480694.protein.info.v11.5.txt",
		        "node_list_path": "1480694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1480694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalegentibacterMishustinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter mishustinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterMishustinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "270918.protein.sequences.v11.5.fa",
		        "enrichment_path": "270918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "270918.protein.info.v11.5.txt",
		        "node_list_path": "270918.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioHepatarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio hepatarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioHepatarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "171383.protein.sequences.v11.5.fa",
		        "enrichment_path": "171383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "171383.protein.info.v11.5.txt",
		        "node_list_path": "171383.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSp4425Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. 44-25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSp4425Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895794.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895794.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895794.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895794.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895794.protein.info.v11.5.txt",
		        "node_list_path": "1895794.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895794.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterCibariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter cibarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterCibariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "282669.clusters.info.v11.5.txt",
		        "cluster_tree_path": "282669.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "282669.clusters.proteins.v11.5.txt",
		        "sequence_path": "282669.protein.sequences.v11.5.fa",
		        "enrichment_path": "282669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "282669.protein.info.v11.5.txt",
		        "node_list_path": "282669.cluster.nodes.v11.5.txt",
		        "edge_list_path": "282669.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalegentibacterSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930251.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930251.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930251.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930251.protein.info.v11.5.txt",
		        "node_list_path": "1930251.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930251.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MogibacteriumSpCm50Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mogibacterium sp. CM50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MogibacteriumSpCm50Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936375.clusters.proteins.v11.5.txt",
		        "sequence_path": "936375.protein.sequences.v11.5.fa",
		        "enrichment_path": "936375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936375.protein.info.v11.5.txt",
		        "node_list_path": "936375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpMl3w(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. ML3W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpMl3w", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1538644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1538644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1538644.protein.info.v11.5.txt",
		        "node_list_path": "1538644.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylocellaSilvestrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylocella silvestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocellaSilvestrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "395965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "395965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "395965.clusters.proteins.v11.5.txt",
		        "sequence_path": "395965.protein.sequences.v11.5.fa",
		        "enrichment_path": "395965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395965.protein.info.v11.5.txt",
		        "node_list_path": "395965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "395965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactococcusChungangensisCau28Dsm22330(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus chungangensis CAU 28 DSM 22330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusChungangensisCau28Dsm22330", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122154.protein.info.v11.5.txt",
		        "node_list_path": "1122154.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusSpAm4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sp. AM4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSpAm4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246969.clusters.proteins.v11.5.txt",
		        "sequence_path": "246969.protein.sequences.v11.5.fa",
		        "enrichment_path": "246969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246969.protein.info.v11.5.txt",
		        "node_list_path": "246969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasHelleri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas helleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasHelleri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1608996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608996.protein.info.v11.5.txt",
		        "node_list_path": "1608996.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMesonaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mesonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMesonaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193713.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193713.protein.info.v11.5.txt",
		        "node_list_path": "1193713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeeksellaVirosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weeksella virosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeeksellaVirosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "865938.protein.sequences.v11.5.fa",
		        "enrichment_path": "865938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "865938.protein.info.v11.5.txt",
		        "node_list_path": "865938.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaInohanensisNbrc100128Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia inohanensis NBRC 100128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaInohanensisNbrc100128Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210077.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210077.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210077.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210077.protein.info.v11.5.txt",
		        "node_list_path": "1210077.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210077.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumVaginaePb189t14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium vaginae PB189T14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumVaginaePb189t14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "866774.protein.sequences.v11.5.fa",
		        "enrichment_path": "866774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866774.protein.info.v11.5.txt",
		        "node_list_path": "866774.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiorhodovibrioSp970(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiorhodovibrio sp. 970 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiorhodovibrioSp970", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "631362.protein.sequences.v11.5.fa",
		        "enrichment_path": "631362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "631362.protein.info.v11.5.txt",
		        "node_list_path": "631362.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpHmsc76g11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. HMSC76G11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpHmsc76g11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1608910.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608910.protein.info.v11.5.txt",
		        "node_list_path": "1608910.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterRectusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter rectus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterRectusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553218.clusters.proteins.v11.5.txt",
		        "sequence_path": "553218.protein.sequences.v11.5.fa",
		        "enrichment_path": "553218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553218.protein.info.v11.5.txt",
		        "node_list_path": "553218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacillusGlycogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacillus glycogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacillusGlycogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236959.protein.info.v11.5.txt",
		        "node_list_path": "1236959.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeribacillusPallidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeribacillus pallidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeribacillusPallidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33936.protein.sequences.v11.5.fa",
		        "enrichment_path": "33936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33936.protein.info.v11.5.txt",
		        "node_list_path": "33936.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpRoot154Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. Root154 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpRoot154Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736476.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736476.protein.info.v11.5.txt",
		        "node_list_path": "1736476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumD16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium D16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumD16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "552398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "552398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "552398.clusters.proteins.v11.5.txt",
		        "sequence_path": "552398.protein.sequences.v11.5.fa",
		        "enrichment_path": "552398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "552398.protein.info.v11.5.txt",
		        "node_list_path": "552398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "552398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacillusLaterosporusLmg15441(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus laterosporus LMG15441 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusLaterosporusLmg15441", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1042163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042163.protein.info.v11.5.txt",
		        "node_list_path": "1042163.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidaceaeBacteriumBroad1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioidaceae bacterium Broad1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidaceaeBacteriumBroad1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "408672.protein.sequences.v11.5.fa",
		        "enrichment_path": "408672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408672.protein.info.v11.5.txt",
		        "node_list_path": "408672.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4322(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_43_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4322", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802695.protein.info.v11.5.txt",
		        "node_list_path": "1802695.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensSbw25Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens SBW25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensSbw25Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216595.clusters.proteins.v11.5.txt",
		        "sequence_path": "216595.protein.sequences.v11.5.fa",
		        "enrichment_path": "216595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216595.protein.info.v11.5.txt",
		        "node_list_path": "216595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaGallinaceum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallinaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaGallinaceum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29556.protein.sequences.v11.5.fa",
		        "enrichment_path": "29556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29556.protein.info.v11.5.txt",
		        "node_list_path": "29556.protein.complete.v11.5.txt"
		    }
		]
    )()

def MangrovimonasYunxiaonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mangrovimonas yunxiaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MangrovimonasYunxiaonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1197477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1197477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1197477.clusters.proteins.v11.5.txt",
		        "sequence_path": "1197477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197477.protein.info.v11.5.txt",
		        "node_list_path": "1197477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1197477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAutolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces autolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAutolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "75293.protein.sequences.v11.5.fa",
		        "enrichment_path": "75293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75293.protein.info.v11.5.txt",
		        "node_list_path": "75293.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaEpidermidihirudinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia epidermidihirudinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaEpidermidihirudinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293439.protein.info.v11.5.txt",
		        "node_list_path": "1293439.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospinaSpLsNob(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospina sp. LS_NOB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospinaSpLsNob", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671875.protein.info.v11.5.txt",
		        "node_list_path": "1671875.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfonatronumThiosulfatophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronum thiosulfatophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronumThiosulfatophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "617002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "617002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "617002.clusters.proteins.v11.5.txt",
		        "sequence_path": "617002.protein.sequences.v11.5.fa",
		        "enrichment_path": "617002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "617002.protein.info.v11.5.txt",
		        "node_list_path": "617002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "617002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseinatronobacterThiooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseinatronobacter thiooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseinatronobacterThiooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "121821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "121821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "121821.clusters.proteins.v11.5.txt",
		        "sequence_path": "121821.protein.sequences.v11.5.fa",
		        "enrichment_path": "121821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121821.protein.info.v11.5.txt",
		        "node_list_path": "121821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "121821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusVogelbacteriaBacteriumRifoxyd1Full4619(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_46_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full4619", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802439.protein.info.v11.5.txt",
		        "node_list_path": "1802439.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwf23566Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWF2_35_66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwf23566Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618773.protein.info.v11.5.txt",
		        "node_list_path": "1618773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PusillimonasNoertemannii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pusillimonas noertemannii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PusillimonasNoertemannii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231391.protein.info.v11.5.txt",
		        "node_list_path": "1231391.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumGanghwenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium ganghwense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumGanghwenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "320778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "320778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "320778.clusters.proteins.v11.5.txt",
		        "sequence_path": "320778.protein.sequences.v11.5.fa",
		        "enrichment_path": "320778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "320778.protein.info.v11.5.txt",
		        "node_list_path": "320778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "320778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ValsaMalicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Valsa malicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ValsaMalicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "356882.protein.sequences.v11.5.fa",
		        "enrichment_path": "356882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "356882.protein.info.v11.5.txt",
		        "node_list_path": "356882.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtribacteriaBacteriumScgcAaa252M02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atribacteria bacterium SCGC AAA252-M02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtribacteriaBacteriumScgcAaa252M02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "913317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "913317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "913317.clusters.proteins.v11.5.txt",
		        "sequence_path": "913317.protein.sequences.v11.5.fa",
		        "enrichment_path": "913317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913317.protein.info.v11.5.txt",
		        "node_list_path": "913317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "913317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxDieseloleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax dieselolei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxDieseloleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930169.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930169.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930169.clusters.proteins.v11.5.txt",
		        "sequence_path": "930169.protein.sequences.v11.5.fa",
		        "enrichment_path": "930169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930169.protein.info.v11.5.txt",
		        "node_list_path": "930169.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930169.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TardibacterChloracetimidivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tardibacter chloracetimidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TardibacterChloracetimidivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1921510.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1921510.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1921510.clusters.proteins.v11.5.txt",
		        "sequence_path": "1921510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921510.protein.info.v11.5.txt",
		        "node_list_path": "1921510.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1921510.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaSpH567Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella sp. H567 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaSpH567Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1697043.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1697043.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1697043.clusters.proteins.v11.5.txt",
		        "sequence_path": "1697043.protein.sequences.v11.5.fa",
		        "enrichment_path": "1697043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1697043.protein.info.v11.5.txt",
		        "node_list_path": "1697043.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1697043.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpWsf3629Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. WSF 3629 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpWsf3629Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1622147.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1622147.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1622147.clusters.proteins.v11.5.txt",
		        "sequence_path": "1622147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622147.protein.info.v11.5.txt",
		        "node_list_path": "1622147.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1622147.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaParva(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora parva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaParva", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1464048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1464048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1464048.protein.info.v11.5.txt",
		        "node_list_path": "1464048.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh7803Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 7803 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh7803Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32051.clusters.proteins.v11.5.txt",
		        "sequence_path": "32051.protein.sequences.v11.5.fa",
		        "enrichment_path": "32051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32051.protein.info.v11.5.txt",
		        "node_list_path": "32051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag1944415(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG_194_44_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag1944415", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897037.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897037.protein.info.v11.5.txt",
		        "node_list_path": "1897037.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchizophyllumCommuneH48(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schizophyllum commune H4-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizophyllumCommuneH48", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "578458.protein.sequences.v11.5.fa",
		        "enrichment_path": "578458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578458.protein.info.v11.5.txt",
		        "node_list_path": "578458.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraRubrobruneaNbrc15275Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura rubrobrunea NBRC 15275 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraRubrobruneaNbrc15275Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220567.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220567.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220567.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220567.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220567.protein.info.v11.5.txt",
		        "node_list_path": "1220567.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220567.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsplowo201Full4211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO2_01_FULL_42_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201Full4211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802627.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802627.protein.info.v11.5.txt",
		        "node_list_path": "1802627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasEuvesicatoria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas euvesicatoria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasEuvesicatoria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "456327.protein.sequences.v11.5.fa",
		        "enrichment_path": "456327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "456327.protein.info.v11.5.txt",
		        "node_list_path": "456327.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpYr247(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. yr247 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpYr247", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761880.protein.info.v11.5.txt",
		        "node_list_path": "1761880.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriaceaeBacteriumChkci004(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacteriaceae bacterium CHKCI004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriaceaeBacteriumChkci004", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1780380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780380.protein.info.v11.5.txt",
		        "node_list_path": "1780380.protein.complete.v11.5.txt"
		    }
		]
    )()

def HylemonellaGracilisAtcc19624Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hylemonella gracilis ATCC19624 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HylemonellaGracilisAtcc19624Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "887062.clusters.info.v11.5.txt",
		        "cluster_tree_path": "887062.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "887062.clusters.proteins.v11.5.txt",
		        "sequence_path": "887062.protein.sequences.v11.5.fa",
		        "enrichment_path": "887062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "887062.protein.info.v11.5.txt",
		        "node_list_path": "887062.cluster.nodes.v11.5.txt",
		        "edge_list_path": "887062.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PiscibacillusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Piscibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiscibacillusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "571933.clusters.info.v11.5.txt",
		        "cluster_tree_path": "571933.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "571933.clusters.proteins.v11.5.txt",
		        "sequence_path": "571933.protein.sequences.v11.5.fa",
		        "enrichment_path": "571933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571933.protein.info.v11.5.txt",
		        "node_list_path": "571933.cluster.nodes.v11.5.txt",
		        "edge_list_path": "571933.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusSilesiacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus silesiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSilesiacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "332949.protein.sequences.v11.5.fa",
		        "enrichment_path": "332949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332949.protein.info.v11.5.txt",
		        "node_list_path": "332949.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacterSpM18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter sp. M18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterSpM18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "443143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "443143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "443143.clusters.proteins.v11.5.txt",
		        "sequence_path": "443143.protein.sequences.v11.5.fa",
		        "enrichment_path": "443143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443143.protein.info.v11.5.txt",
		        "node_list_path": "443143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "443143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumFacileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium facile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumFacileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "51670.clusters.info.v11.5.txt",
		        "cluster_tree_path": "51670.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "51670.clusters.proteins.v11.5.txt",
		        "sequence_path": "51670.protein.sequences.v11.5.fa",
		        "enrichment_path": "51670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51670.protein.info.v11.5.txt",
		        "node_list_path": "51670.cluster.nodes.v11.5.txt",
		        "edge_list_path": "51670.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200210029Sch5224772Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-10029_SCH5224772 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200210029Sch5224772Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834083.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834083.protein.info.v11.5.txt",
		        "node_list_path": "1834083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumRbg164921Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_16_49_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumRbg164921Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802195.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802195.protein.info.v11.5.txt",
		        "node_list_path": "1802195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexusSpMsg(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexus sp. MSG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexusSpMsg", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1521187.protein.sequences.v11.5.fa",
		        "enrichment_path": "1521187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1521187.protein.info.v11.5.txt",
		        "node_list_path": "1521187.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaDiminutum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma diminutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaDiminutum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1276221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276221.protein.info.v11.5.txt",
		        "node_list_path": "1276221.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrialbaMagadiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialba magadii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaMagadiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "547559.clusters.info.v11.5.txt",
		        "cluster_tree_path": "547559.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "547559.clusters.proteins.v11.5.txt",
		        "sequence_path": "547559.protein.sequences.v11.5.fa",
		        "enrichment_path": "547559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547559.protein.info.v11.5.txt",
		        "node_list_path": "547559.cluster.nodes.v11.5.txt",
		        "edge_list_path": "547559.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedArchaeonA07hr67(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HR67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedArchaeonA07hr67", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1412871.protein.sequences.v11.5.fa",
		        "enrichment_path": "1412871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1412871.protein.info.v11.5.txt",
		        "node_list_path": "1412871.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaPersimilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila persimilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaPersimilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7234.clusters.proteins.v11.5.txt",
		        "sequence_path": "7234.protein.sequences.v11.5.fa",
		        "enrichment_path": "7234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7234.protein.info.v11.5.txt",
		        "node_list_path": "7234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinidiaChinensisVarChinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinidia chinensis var. chinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinidiaChinensisVarChinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1590841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1590841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1590841.protein.info.v11.5.txt",
		        "node_list_path": "1590841.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodoplanesSpZ2Yc6860Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodoplanes sp. Z2-YC6860 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodoplanesSpZ2Yc6860Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "674703.clusters.info.v11.5.txt",
		        "cluster_tree_path": "674703.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "674703.clusters.proteins.v11.5.txt",
		        "sequence_path": "674703.protein.sequences.v11.5.fa",
		        "enrichment_path": "674703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "674703.protein.info.v11.5.txt",
		        "node_list_path": "674703.cluster.nodes.v11.5.txt",
		        "edge_list_path": "674703.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpLeaf2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Leaf2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpLeaf2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735670.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735670.protein.info.v11.5.txt",
		        "node_list_path": "1735670.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasRuminantium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasRuminantium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "971.protein.sequences.v11.5.fa",
		        "enrichment_path": "971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "971.protein.info.v11.5.txt",
		        "node_list_path": "971.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesoflavibacterZeaxanthS86Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanth. S86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "MesoflavibacterZeaxanthS86Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1004149.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1004149.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1004149.clusters.proteins.v11.0.txt",
		        "sequence_path": "1004149.protein.sequences.v11.0.fa",
		        "enrichment_path": "1004149.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1004149.protein.info.v11.0.txt",
		        "node_list_path": "1004149.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1004149.protein.cluster.v11.0.txt"
		    }
		]
    )()

def CordycepsJavanicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps javanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CordycepsJavanicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43265.clusters.proteins.v11.5.txt",
		        "sequence_path": "43265.protein.sequences.v11.5.fa",
		        "enrichment_path": "43265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43265.protein.info.v11.5.txt",
		        "node_list_path": "43265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumGwa2509Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium GWA2_50_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumGwa2509Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798474.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798474.protein.info.v11.5.txt",
		        "node_list_path": "1798474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpH103(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. H103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpH103", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761893.protein.info.v11.5.txt",
		        "node_list_path": "1761893.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumExtorquensPa1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium extorquens PA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumExtorquensPa1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "419610.protein.sequences.v11.5.fa",
		        "enrichment_path": "419610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419610.protein.info.v11.5.txt",
		        "node_list_path": "419610.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSpCs1bsmeth3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. CS1BSMeth3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSpCs1bsmeth3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1892844.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892844.protein.info.v11.5.txt",
		        "node_list_path": "1892844.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesNordii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides nordii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesNordii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "997884.protein.sequences.v11.5.fa",
		        "enrichment_path": "997884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997884.protein.info.v11.5.txt",
		        "node_list_path": "997884.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumHeckeshornense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium heckeshornense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumHeckeshornense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "110505.protein.sequences.v11.5.fa",
		        "enrichment_path": "110505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "110505.protein.info.v11.5.txt",
		        "node_list_path": "110505.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSwezeyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus swezeyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSwezeyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1925020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1925020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1925020.protein.info.v11.5.txt",
		        "node_list_path": "1925020.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalimicrobiumSpMj3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salimicrobium sp. MJ3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalimicrobiumSpMj3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230341.protein.info.v11.5.txt",
		        "node_list_path": "1230341.protein.complete.v11.5.txt"
		    }
		]
    )()

def FournierellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fournierella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FournierellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1650663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1650663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1650663.clusters.proteins.v11.5.txt",
		        "sequence_path": "1650663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1650663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1650663.protein.info.v11.5.txt",
		        "node_list_path": "1650663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1650663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaBryantiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bryantii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBryantiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "77095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "77095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "77095.clusters.proteins.v11.5.txt",
		        "sequence_path": "77095.protein.sequences.v11.5.fa",
		        "enrichment_path": "77095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77095.protein.info.v11.5.txt",
		        "node_list_path": "77095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "77095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusDictyosporusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus dictyosporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusDictyosporusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523247.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523247.protein.info.v11.5.txt",
		        "node_list_path": "1523247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpMit0602Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0602 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpMit0602Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499499.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499499.protein.info.v11.5.txt",
		        "node_list_path": "1499499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusParcubacteriaBacterium4484255Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Parcubacteria bacterium 4484_255 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusParcubacteriaBacterium4484255Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1970769.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1970769.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1970769.clusters.proteins.v11.5.txt",
		        "sequence_path": "1970769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970769.protein.info.v11.5.txt",
		        "node_list_path": "1970769.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1970769.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumCarboxydivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum carboxydivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumCarboxydivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "868595.protein.sequences.v11.5.fa",
		        "enrichment_path": "868595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "868595.protein.info.v11.5.txt",
		        "node_list_path": "868595.protein.complete.v11.5.txt"
		    }
		]
    )()

def DracunculusMedinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dracunculus medinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DracunculusMedinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "318479.protein.sequences.v11.5.fa",
		        "enrichment_path": "318479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318479.protein.info.v11.5.txt",
		        "node_list_path": "318479.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioFluvialisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio fluvialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioFluvialisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "676.clusters.proteins.v11.5.txt",
		        "sequence_path": "676.protein.sequences.v11.5.fa",
		        "enrichment_path": "676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "676.protein.info.v11.5.txt",
		        "node_list_path": "676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSp9120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. 9120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSp9120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500897.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500897.protein.info.v11.5.txt",
		        "node_list_path": "1500897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumVe20221Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20221 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumVe20221Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232453.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232453.protein.info.v11.5.txt",
		        "node_list_path": "1232453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrodermaOtaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthroderma otae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrodermaOtaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "63405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "63405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "63405.clusters.proteins.v11.5.txt",
		        "sequence_path": "63405.protein.sequences.v11.5.fa",
		        "enrichment_path": "63405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63405.protein.info.v11.5.txt",
		        "node_list_path": "63405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "63405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FontibacillusPanacisegetisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fontibacillus panacisegetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FontibacillusPanacisegetisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "670482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "670482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "670482.clusters.proteins.v11.5.txt",
		        "sequence_path": "670482.protein.sequences.v11.5.fa",
		        "enrichment_path": "670482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670482.protein.info.v11.5.txt",
		        "node_list_path": "670482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "670482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CystobacterFerrugineusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cystobacter ferrugineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CystobacterFerrugineusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83449.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83449.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83449.clusters.proteins.v11.5.txt",
		        "sequence_path": "83449.protein.sequences.v11.5.fa",
		        "enrichment_path": "83449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83449.protein.info.v11.5.txt",
		        "node_list_path": "83449.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83449.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraYanagawaeSerovarSaopauloStrSaoPauloAtcc700523(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira yanagawae serovar Saopaulo str. Sao Paulo ATCC 700523 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraYanagawaeSerovarSaopauloStrSaoPauloAtcc700523", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1249483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249483.protein.info.v11.5.txt",
		        "node_list_path": "1249483.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaPomeroyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria pomeroyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaPomeroyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246200.protein.sequences.v11.5.fa",
		        "enrichment_path": "246200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246200.protein.info.v11.5.txt",
		        "node_list_path": "246200.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassilimicrobiotaTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilimicrobiota timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassilimicrobiotaTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776392.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776392.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776392.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776392.protein.info.v11.5.txt",
		        "node_list_path": "1776392.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776392.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAidingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aidingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAidingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "910347.protein.sequences.v11.5.fa",
		        "enrichment_path": "910347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "910347.protein.info.v11.5.txt",
		        "node_list_path": "910347.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwc23941Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWC2_39_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwc23941Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618754.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618754.protein.info.v11.5.txt",
		        "node_list_path": "1618754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CloacibacillusPorcorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cloacibacillus porcorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CloacibacillusPorcorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1197717.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1197717.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1197717.clusters.proteins.v11.5.txt",
		        "sequence_path": "1197717.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197717.protein.info.v11.5.txt",
		        "node_list_path": "1197717.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1197717.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LottiaGiganteaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lottia gigantea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LottiaGiganteaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "225164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "225164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "225164.clusters.proteins.v11.5.txt",
		        "sequence_path": "225164.protein.sequences.v11.5.fa",
		        "enrichment_path": "225164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225164.protein.info.v11.5.txt",
		        "node_list_path": "225164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "225164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full4622(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_46_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full4622", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798475.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798475.protein.info.v11.5.txt",
		        "node_list_path": "1798475.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharothrixSpAli22I(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharothrix sp. ALI-22-I graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharothrixSpAli22I", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1933778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933778.protein.info.v11.5.txt",
		        "node_list_path": "1933778.protein.complete.v11.5.txt"
		    }
		]
    )()

def PediococcusClausseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus claussenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusClausseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "701521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "701521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "701521.clusters.proteins.v11.5.txt",
		        "sequence_path": "701521.protein.sequences.v11.5.fa",
		        "enrichment_path": "701521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "701521.protein.info.v11.5.txt",
		        "node_list_path": "701521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "701521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumHeckeshornenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium heckeshornense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumHeckeshornenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "110505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "110505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "110505.clusters.proteins.v11.5.txt",
		        "sequence_path": "110505.protein.sequences.v11.5.fa",
		        "enrichment_path": "110505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "110505.protein.info.v11.5.txt",
		        "node_list_path": "110505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "110505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAdiutrixIntracellularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adiutrix intracellularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAdiutrixIntracellularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1705730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1705730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1705730.clusters.proteins.v11.5.txt",
		        "sequence_path": "1705730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705730.protein.info.v11.5.txt",
		        "node_list_path": "1705730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1705730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisTolypomycinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis tolypomycina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisTolypomycinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "208445.clusters.info.v11.5.txt",
		        "cluster_tree_path": "208445.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "208445.clusters.proteins.v11.5.txt",
		        "sequence_path": "208445.protein.sequences.v11.5.fa",
		        "enrichment_path": "208445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208445.protein.info.v11.5.txt",
		        "node_list_path": "208445.cluster.nodes.v11.5.txt",
		        "edge_list_path": "208445.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674847.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674847.protein.info.v11.5.txt",
		        "node_list_path": "1674847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyellaJaponicaDsm16301Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyella japonica DSM 16301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaJaponicaDsm16301Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1440762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1440762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1440762.clusters.proteins.v11.5.txt",
		        "sequence_path": "1440762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1440762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1440762.protein.info.v11.5.txt",
		        "node_list_path": "1440762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1440762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesSinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesSinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "74873.clusters.info.v11.5.txt",
		        "cluster_tree_path": "74873.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "74873.clusters.proteins.v11.5.txt",
		        "sequence_path": "74873.protein.sequences.v11.5.fa",
		        "enrichment_path": "74873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74873.protein.info.v11.5.txt",
		        "node_list_path": "74873.cluster.nodes.v11.5.txt",
		        "edge_list_path": "74873.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusNakamuraiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus nakamurai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusNakamuraiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1793963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1793963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1793963.clusters.proteins.v11.5.txt",
		        "sequence_path": "1793963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1793963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1793963.protein.info.v11.5.txt",
		        "node_list_path": "1793963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1793963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WohlfahrtiimonasChitiniclastica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas chitiniclastica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WohlfahrtiimonasChitiniclastica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123502.protein.info.v11.5.txt",
		        "node_list_path": "1123502.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaPutidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia putida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaPutidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1141883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1141883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1141883.clusters.proteins.v11.5.txt",
		        "sequence_path": "1141883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141883.protein.info.v11.5.txt",
		        "node_list_path": "1141883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1141883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PristionchusPacificusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pristionchus pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PristionchusPacificusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "54126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "54126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "54126.clusters.proteins.v11.5.txt",
		        "sequence_path": "54126.protein.sequences.v11.5.fa",
		        "enrichment_path": "54126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54126.protein.info.v11.5.txt",
		        "node_list_path": "54126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "54126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesSpAsf519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides sp. ASF519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesSpAsf519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235803.protein.info.v11.5.txt",
		        "node_list_path": "1235803.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonadalesBacteriumGa0077531(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium Ga0077531 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonadalesBacteriumGa0077531", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752231.protein.info.v11.5.txt",
		        "node_list_path": "1752231.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifoxyc2Full3812(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFOXYC2_FULL_38_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifoxyc2Full3812", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801877.protein.info.v11.5.txt",
		        "node_list_path": "1801877.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophomonasZehnderiOl4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas zehnderi OL-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophomonasZehnderiOl4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "690567.clusters.info.v11.5.txt",
		        "cluster_tree_path": "690567.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "690567.clusters.proteins.v11.5.txt",
		        "sequence_path": "690567.protein.sequences.v11.5.fa",
		        "enrichment_path": "690567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690567.protein.info.v11.5.txt",
		        "node_list_path": "690567.cluster.nodes.v11.5.txt",
		        "edge_list_path": "690567.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioIshigakensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ishigakensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioIshigakensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1481914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1481914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1481914.protein.info.v11.5.txt",
		        "node_list_path": "1481914.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumCrudilactisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium crudilactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumCrudilactisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "327277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "327277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "327277.clusters.proteins.v11.5.txt",
		        "sequence_path": "327277.protein.sequences.v11.5.fa",
		        "enrichment_path": "327277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "327277.protein.info.v11.5.txt",
		        "node_list_path": "327277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "327277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioAlginolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioAlginolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "663.clusters.proteins.v11.5.txt",
		        "sequence_path": "663.protein.sequences.v11.5.fa",
		        "enrichment_path": "663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663.protein.info.v11.5.txt",
		        "node_list_path": "663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHimb11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HIMB11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHimb11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1366046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1366046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1366046.protein.info.v11.5.txt",
		        "node_list_path": "1366046.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaOtitidisNbrc100426(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia otitidis NBRC 100426 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaOtitidisNbrc100426", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1108044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1108044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1108044.protein.info.v11.5.txt",
		        "node_list_path": "1108044.protein.complete.v11.5.txt"
		    }
		]
    )()

def AminomonasPaucivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aminomonas paucivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminomonasPaucivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "584708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "584708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "584708.clusters.proteins.v11.5.txt",
		        "sequence_path": "584708.protein.sequences.v11.5.fa",
		        "enrichment_path": "584708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "584708.protein.info.v11.5.txt",
		        "node_list_path": "584708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "584708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacteraceaeBacterium4572351Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium 4572_35.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteraceaeBacterium4572351Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1971627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1971627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1971627.clusters.proteins.v11.5.txt",
		        "sequence_path": "1971627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971627.protein.info.v11.5.txt",
		        "node_list_path": "1971627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1971627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "318161.protein.sequences.v11.5.fa",
		        "enrichment_path": "318161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318161.protein.info.v11.5.txt",
		        "node_list_path": "318161.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusUrinalis228597Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus urinalis 228597 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusUrinalis228597Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "764291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "764291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "764291.clusters.proteins.v11.5.txt",
		        "sequence_path": "764291.protein.sequences.v11.5.fa",
		        "enrichment_path": "764291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "764291.protein.info.v11.5.txt",
		        "node_list_path": "764291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "764291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizopogonVesiculosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizopogon vesiculosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopogonVesiculosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "180088.protein.sequences.v11.5.fa",
		        "enrichment_path": "180088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180088.protein.info.v11.5.txt",
		        "node_list_path": "180088.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisBisb5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisB5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisBisb5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316057.clusters.proteins.v11.5.txt",
		        "sequence_path": "316057.protein.sequences.v11.5.fa",
		        "enrichment_path": "316057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316057.protein.info.v11.5.txt",
		        "node_list_path": "316057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRbg163611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_36_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg163611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802481.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802481.protein.info.v11.5.txt",
		        "node_list_path": "1802481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp2622Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 26_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp2622Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896978.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896978.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896978.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896978.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896978.protein.info.v11.5.txt",
		        "node_list_path": "1896978.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896978.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZobelliaUliginosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zobellia uliginosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZobelliaUliginosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "143224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "143224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "143224.clusters.proteins.v11.5.txt",
		        "sequence_path": "143224.protein.sequences.v11.5.fa",
		        "enrichment_path": "143224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "143224.protein.info.v11.5.txt",
		        "node_list_path": "143224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "143224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacterPostgateiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacter postgatei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacterPostgateiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "879212.clusters.info.v11.5.txt",
		        "cluster_tree_path": "879212.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "879212.clusters.proteins.v11.5.txt",
		        "sequence_path": "879212.protein.sequences.v11.5.fa",
		        "enrichment_path": "879212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879212.protein.info.v11.5.txt",
		        "node_list_path": "879212.cluster.nodes.v11.5.txt",
		        "edge_list_path": "879212.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WheatBlue(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wheat blue graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WheatBlue", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321961.protein.sequences.v11.5.fa",
		        "enrichment_path": "321961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321961.protein.info.v11.5.txt",
		        "node_list_path": "321961.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumUrocaniciphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium urocaniciphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumUrocaniciphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1299341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1299341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1299341.protein.info.v11.5.txt",
		        "node_list_path": "1299341.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4519Fw2642Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4519 (FW-2642) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4519Fw2642Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420914.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420914.protein.info.v11.5.txt",
		        "node_list_path": "1420914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumRifcsplowo201Full3912(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFCSPLOWO2_01_FULL_39_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifcsplowo201Full3912", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801897.protein.info.v11.5.txt",
		        "node_list_path": "1801897.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaballeroniaTemerariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia temeraria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaTemerariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777137.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777137.protein.info.v11.5.txt",
		        "node_list_path": "1777137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KriegellaAquimaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kriegella aquimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KriegellaAquimaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "192904.protein.sequences.v11.5.fa",
		        "enrichment_path": "192904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192904.protein.info.v11.5.txt",
		        "node_list_path": "192904.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioFructosivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio fructosivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioFructosivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596151.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596151.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596151.clusters.proteins.v11.5.txt",
		        "sequence_path": "596151.protein.sequences.v11.5.fa",
		        "enrichment_path": "596151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596151.protein.info.v11.5.txt",
		        "node_list_path": "596151.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596151.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SciscionellaSpSe31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sciscionella sp. SE31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SciscionellaSpSe31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1445613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1445613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1445613.clusters.proteins.v11.5.txt",
		        "sequence_path": "1445613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1445613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1445613.protein.info.v11.5.txt",
		        "node_list_path": "1445613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1445613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilaceaeBacteriumUrhb0048(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHB0048 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilaceaeBacteriumUrhb0048", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380347.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380347.protein.info.v11.5.txt",
		        "node_list_path": "1380347.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpCf394(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF394 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpCf394", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500304.protein.info.v11.5.txt",
		        "node_list_path": "1500304.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpZagget11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. Zagget11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpZagget11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930004.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930004.protein.info.v11.5.txt",
		        "node_list_path": "1930004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiribacterSalinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiribacter salinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiribacterSalinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1260251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1260251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1260251.protein.info.v11.5.txt",
		        "node_list_path": "1260251.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyroidesPhaeusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myroides phaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyroidesPhaeusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "702745.clusters.info.v11.5.txt",
		        "cluster_tree_path": "702745.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "702745.clusters.proteins.v11.5.txt",
		        "sequence_path": "702745.protein.sequences.v11.5.fa",
		        "enrichment_path": "702745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702745.protein.info.v11.5.txt",
		        "node_list_path": "702745.cluster.nodes.v11.5.txt",
		        "edge_list_path": "702745.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TilletiariaAnomalaUbc951(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tilletiaria anomala UBC 951 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TilletiariaAnomalaUbc951", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1037660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1037660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1037660.protein.info.v11.5.txt",
		        "node_list_path": "1037660.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaArctica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaArctica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1470200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470200.protein.info.v11.5.txt",
		        "node_list_path": "1470200.protein.complete.v11.5.txt"
		    }
		]
    )()

def VittaformaCorneaeAtcc50505Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vittaforma corneae ATCC 50505 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VittaformaCorneaeAtcc50505Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "993615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "993615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "993615.clusters.proteins.v11.5.txt",
		        "sequence_path": "993615.protein.sequences.v11.5.fa",
		        "enrichment_path": "993615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "993615.protein.info.v11.5.txt",
		        "node_list_path": "993615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "993615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EptesicusFuscusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eptesicus fuscus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EptesicusFuscusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29078.clusters.proteins.v11.5.txt",
		        "sequence_path": "29078.protein.sequences.v11.5.fa",
		        "enrichment_path": "29078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29078.protein.info.v11.5.txt",
		        "node_list_path": "29078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaSpiritensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella spiritensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaSpiritensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "452.protein.sequences.v11.5.fa",
		        "enrichment_path": "452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452.protein.info.v11.5.txt",
		        "node_list_path": "452.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenedentesBacteriumJgi0000039J10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenedentes bacterium JGI 0000039-J10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenedentesBacteriumJgi0000039J10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1046982.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1046982.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1046982.clusters.proteins.v11.5.txt",
		        "sequence_path": "1046982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046982.protein.info.v11.5.txt",
		        "node_list_path": "1046982.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1046982.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsaccharosporaIrregularisDsm2635(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asaccharospora irregularis DSM 2635 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsaccharosporaIrregularisDsm2635", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121321.protein.info.v11.5.txt",
		        "node_list_path": "1121321.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsphigho201Full4111(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_01_FULL_41_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho201Full4111", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797711.protein.info.v11.5.txt",
		        "node_list_path": "1797711.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSp2a57ct2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 2A57CT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp2a57ct2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665959.protein.sequences.v11.5.fa",
		        "enrichment_path": "665959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665959.protein.info.v11.5.txt",
		        "node_list_path": "665959.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumDiphtheriae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium diphtheriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumDiphtheriae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "698964.protein.sequences.v11.5.fa",
		        "enrichment_path": "698964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698964.protein.info.v11.5.txt",
		        "node_list_path": "698964.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf343(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf343 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf343", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736345.protein.info.v11.5.txt",
		        "node_list_path": "1736345.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaSpN(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella sp. N graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaSpN", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1746199.protein.sequences.v11.5.fa",
		        "enrichment_path": "1746199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1746199.protein.info.v11.5.txt",
		        "node_list_path": "1746199.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusEquiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus equi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusEquiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "685727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "685727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "685727.clusters.proteins.v11.5.txt",
		        "sequence_path": "685727.protein.sequences.v11.5.fa",
		        "enrichment_path": "685727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "685727.protein.info.v11.5.txt",
		        "node_list_path": "685727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "685727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelobacterSpSfb93(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter sp. SFB93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelobacterSpSfb93", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1842532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842532.protein.info.v11.5.txt",
		        "node_list_path": "1842532.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaBovoculiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella bovoculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaBovoculiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743974.clusters.proteins.v11.5.txt",
		        "sequence_path": "743974.protein.sequences.v11.5.fa",
		        "enrichment_path": "743974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743974.protein.info.v11.5.txt",
		        "node_list_path": "743974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DuganellaSpOv510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. OV510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpOv510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881039.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881039.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881039.protein.info.v11.5.txt",
		        "node_list_path": "1881039.protein.complete.v11.5.txt"
		    }
		]
    )()

def HungateiclostridiumStraminisolvensJcm21531Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hungateiclostridium straminisolvens JCM 21531 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HungateiclostridiumStraminisolvensJcm21531Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1294263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1294263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1294263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1294263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294263.protein.info.v11.5.txt",
		        "node_list_path": "1294263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1294263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSpSk01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSpSk01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1457154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1457154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1457154.clusters.proteins.v11.5.txt",
		        "sequence_path": "1457154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1457154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1457154.protein.info.v11.5.txt",
		        "node_list_path": "1457154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1457154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium6322Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 63-22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium6322Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895812.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895812.protein.info.v11.5.txt",
		        "node_list_path": "1895812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusRatti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus ratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusRatti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "150033.protein.sequences.v11.5.fa",
		        "enrichment_path": "150033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150033.protein.info.v11.5.txt",
		        "node_list_path": "150033.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusButanolivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus butanolivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusButanolivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "421767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "421767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "421767.clusters.proteins.v11.5.txt",
		        "sequence_path": "421767.protein.sequences.v11.5.fa",
		        "enrichment_path": "421767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "421767.protein.info.v11.5.txt",
		        "node_list_path": "421767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "421767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1814128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1814128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1814128.clusters.proteins.v11.5.txt",
		        "sequence_path": "1814128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1814128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1814128.protein.info.v11.5.txt",
		        "node_list_path": "1814128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1814128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMatruchotii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium matruchotii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMatruchotii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553207.protein.sequences.v11.5.fa",
		        "enrichment_path": "553207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553207.protein.info.v11.5.txt",
		        "node_list_path": "553207.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisXinjiangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisXinjiangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246474.protein.info.v11.5.txt",
		        "node_list_path": "1246474.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumGw2011Gwa13716Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWA1_37_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwa13716Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618452.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618452.protein.info.v11.5.txt",
		        "node_list_path": "1618452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TateyamariaSpAngS1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tateyamaria sp. ANG-S1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TateyamariaSpAngS1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577905.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577905.protein.info.v11.5.txt",
		        "node_list_path": "1577905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaG002Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola G002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaG002Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1009858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1009858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1009858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1009858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009858.protein.info.v11.5.txt",
		        "node_list_path": "1009858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1009858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasAzotifigensNbrc15497Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas azotifigens NBRC 15497 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasAzotifigensNbrc15497Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219041.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219041.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219041.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219041.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219041.protein.info.v11.5.txt",
		        "node_list_path": "1219041.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219041.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAnimalisSubspLactisAd011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium animalis subsp. lactis AD011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAnimalisSubspLactisAd011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "442563.protein.sequences.v11.5.fa",
		        "enrichment_path": "442563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "442563.protein.info.v11.5.txt",
		        "node_list_path": "442563.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusHorikoshiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus horikoshii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHorikoshiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "79883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "79883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "79883.clusters.proteins.v11.5.txt",
		        "sequence_path": "79883.protein.sequences.v11.5.fa",
		        "enrichment_path": "79883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79883.protein.info.v11.5.txt",
		        "node_list_path": "79883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "79883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisSk321Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisSk321Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585202.clusters.proteins.v11.5.txt",
		        "sequence_path": "585202.protein.sequences.v11.5.fa",
		        "enrichment_path": "585202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585202.protein.info.v11.5.txt",
		        "node_list_path": "585202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusMurinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus murinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMurinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235801.protein.info.v11.5.txt",
		        "node_list_path": "1235801.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasMarginalisIcmp9505Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas marginalis ICMP 9505 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMarginalisIcmp9505Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1198317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1198317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1198317.clusters.proteins.v11.5.txt",
		        "sequence_path": "1198317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198317.protein.info.v11.5.txt",
		        "node_list_path": "1198317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1198317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAdolescentisAtcc15703Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium adolescentis ATCC 15703 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAdolescentisAtcc15703Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "367928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "367928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "367928.clusters.proteins.v11.5.txt",
		        "sequence_path": "367928.protein.sequences.v11.5.fa",
		        "enrichment_path": "367928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "367928.protein.info.v11.5.txt",
		        "node_list_path": "367928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "367928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesCanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces canus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "58343.protein.sequences.v11.5.fa",
		        "enrichment_path": "58343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58343.protein.info.v11.5.txt",
		        "node_list_path": "58343.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesLiubingyangii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces liubingyangii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesLiubingyangii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1921764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921764.protein.info.v11.5.txt",
		        "node_list_path": "1921764.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusLactaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus lactaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusLactaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471875.protein.sequences.v11.5.fa",
		        "enrichment_path": "471875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471875.protein.info.v11.5.txt",
		        "node_list_path": "471875.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichodesmiumErythraeum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichodesmium erythraeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodesmiumErythraeum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "203124.protein.sequences.v11.5.fa",
		        "enrichment_path": "203124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203124.protein.info.v11.5.txt",
		        "node_list_path": "203124.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPulmonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma pulmonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPulmonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272635.protein.sequences.v11.5.fa",
		        "enrichment_path": "272635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272635.protein.info.v11.5.txt",
		        "node_list_path": "272635.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCaatingaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces caatingaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCaatingaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1678637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678637.protein.info.v11.5.txt",
		        "node_list_path": "1678637.protein.complete.v11.5.txt"
		    }
		]
    )()

def DacryopinaxPrimogenitusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dacryopinax primogenitus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DacryopinaxPrimogenitusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1858805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1858805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1858805.clusters.proteins.v11.5.txt",
		        "sequence_path": "1858805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1858805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1858805.protein.info.v11.5.txt",
		        "node_list_path": "1858805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1858805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumCoprophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium coprophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumCoprophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36646.clusters.proteins.v11.5.txt",
		        "sequence_path": "36646.protein.sequences.v11.5.fa",
		        "enrichment_path": "36646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36646.protein.info.v11.5.txt",
		        "node_list_path": "36646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YooniaTamlensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yoonia tamlensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YooniaTamlensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "390270.protein.sequences.v11.5.fa",
		        "enrichment_path": "390270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390270.protein.info.v11.5.txt",
		        "node_list_path": "390270.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpEan1pecCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. EAN1pec Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpEan1pecCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "298653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "298653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "298653.clusters.proteins.v11.5.txt",
		        "sequence_path": "298653.protein.sequences.v11.5.fa",
		        "enrichment_path": "298653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "298653.protein.info.v11.5.txt",
		        "node_list_path": "298653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "298653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DehalococcoidesMccartyiVsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi VS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalococcoidesMccartyiVsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "311424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "311424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "311424.clusters.proteins.v11.5.txt",
		        "sequence_path": "311424.protein.sequences.v11.5.fa",
		        "enrichment_path": "311424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311424.protein.info.v11.5.txt",
		        "node_list_path": "311424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "311424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifoxyb1Full5435(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFOXYB1_FULL_54_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifoxyb1Full5435", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801934.protein.info.v11.5.txt",
		        "node_list_path": "1801934.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAsteroides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium asteroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAsteroides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1147128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1147128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1147128.protein.info.v11.5.txt",
		        "node_list_path": "1147128.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSymbiosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] symbiosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSymbiosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1512.protein.info.v11.5.txt",
		        "node_list_path": "1512.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhinopithecusRoxellanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhinopithecus roxellana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhinopithecusRoxellanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61622.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61622.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61622.clusters.proteins.v11.5.txt",
		        "sequence_path": "61622.protein.sequences.v11.5.fa",
		        "enrichment_path": "61622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61622.protein.info.v11.5.txt",
		        "node_list_path": "61622.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61622.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumZavarzinii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium zavarzinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumZavarzinii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267005.protein.info.v11.5.txt",
		        "node_list_path": "1267005.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5024(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_50_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5024", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798507.protein.info.v11.5.txt",
		        "node_list_path": "1798507.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusFlavithermusTno09006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus TNO09006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusFlavithermusTno09006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267580.protein.info.v11.5.txt",
		        "node_list_path": "1267580.protein.complete.v11.5.txt"
		    }
		]
    )()

def NicotianaSylvestrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nicotiana sylvestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NicotianaSylvestrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4096.clusters.proteins.v11.5.txt",
		        "sequence_path": "4096.protein.sequences.v11.5.fa",
		        "enrichment_path": "4096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4096.protein.info.v11.5.txt",
		        "node_list_path": "4096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudorhodoferaxSpLeaf274Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf274 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodoferaxSpLeaf274Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736318.protein.info.v11.5.txt",
		        "node_list_path": "1736318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag413Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:413 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag413Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262803.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262803.protein.info.v11.5.txt",
		        "node_list_path": "1262803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NostocAzollae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nostoc azollae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocAzollae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "551115.protein.sequences.v11.5.fa",
		        "enrichment_path": "551115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551115.protein.info.v11.5.txt",
		        "node_list_path": "551115.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445961.clusters.proteins.v11.5.txt",
		        "sequence_path": "445961.protein.sequences.v11.5.fa",
		        "enrichment_path": "445961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445961.protein.info.v11.5.txt",
		        "node_list_path": "445961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusClarkiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Bacillus] clarkii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusClarkiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "79879.clusters.info.v11.5.txt",
		        "cluster_tree_path": "79879.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "79879.clusters.proteins.v11.5.txt",
		        "sequence_path": "79879.protein.sequences.v11.5.fa",
		        "enrichment_path": "79879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79879.protein.info.v11.5.txt",
		        "node_list_path": "79879.cluster.nodes.v11.5.txt",
		        "edge_list_path": "79879.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSp68310Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. 68-3-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSp68310Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1261640.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1261640.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1261640.clusters.proteins.v11.5.txt",
		        "sequence_path": "1261640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261640.protein.info.v11.5.txt",
		        "node_list_path": "1261640.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1261640.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwf26230(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWF2_62_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwf26230", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797939.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797939.protein.info.v11.5.txt",
		        "node_list_path": "1797939.protein.complete.v11.5.txt"
		    }
		]
    )()

def FundulusHeteroclitus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fundulus heteroclitus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FundulusHeteroclitus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8078.protein.sequences.v11.5.fa",
		        "enrichment_path": "8078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8078.protein.info.v11.5.txt",
		        "node_list_path": "8078.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSatsumensisDsm16230Jcm12392(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus satsumensis DSM 16230 JCM 12392 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSatsumensisDsm16230Jcm12392", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423801.protein.info.v11.5.txt",
		        "node_list_path": "1423801.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacterium628(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 62-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacterium628", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895708.protein.info.v11.5.txt",
		        "node_list_path": "1895708.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospirillumPhotometricumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillum photometricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillumPhotometricumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150469.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150469.protein.info.v11.5.txt",
		        "node_list_path": "1150469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpCf384(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. CF384 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpCf384", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884382.protein.info.v11.5.txt",
		        "node_list_path": "1884382.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5050Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_50_50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5050Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798492.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798492.protein.info.v11.5.txt",
		        "node_list_path": "1798492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPacebacteriaBacteriumRifcsphigho201Full4616Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFCSPHIGHO2_01_FULL_46_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifcsphigho201Full4616Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801885.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801885.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801885.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801885.protein.info.v11.5.txt",
		        "node_list_path": "1801885.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801885.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyxococcusFulvus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus fulvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcusFulvus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "483219.protein.sequences.v11.5.fa",
		        "enrichment_path": "483219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483219.protein.info.v11.5.txt",
		        "node_list_path": "483219.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag1320(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1320 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag1320", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262922.protein.info.v11.5.txt",
		        "node_list_path": "1262922.protein.complete.v11.5.txt"
		    }
		]
    )()

def VirgibacillusSpVm5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus sp. Vm5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusSpVm5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1462526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462526.protein.info.v11.5.txt",
		        "node_list_path": "1462526.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacteralesBacteriumRifoxyb1Full6716(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacterales bacterium RIFOXYB1_FULL_67_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacteralesBacteriumRifoxyb1Full6716", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797588.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797588.protein.info.v11.5.txt",
		        "node_list_path": "1797588.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanobacteriumPcc7702Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return cyanobacterium PCC7702 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobacteriumPcc7702Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173021.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173021.protein.info.v11.5.txt",
		        "node_list_path": "1173021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliiroseovariusCrassostreaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliiroseovarius crassostreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliiroseovariusCrassostreaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "154981.clusters.info.v11.5.txt",
		        "cluster_tree_path": "154981.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "154981.clusters.proteins.v11.5.txt",
		        "sequence_path": "154981.protein.sequences.v11.5.fa",
		        "enrichment_path": "154981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "154981.protein.info.v11.5.txt",
		        "node_list_path": "154981.cluster.nodes.v11.5.txt",
		        "edge_list_path": "154981.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMarinisedimentorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus marinisedimentorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMarinisedimentorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1821260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1821260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1821260.protein.info.v11.5.txt",
		        "node_list_path": "1821260.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusSpYim77859(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. YIM77859 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusSpYim77859", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1540221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1540221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1540221.protein.info.v11.5.txt",
		        "node_list_path": "1540221.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrischellaPerrara(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frischella perrara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrischellaPerrara", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267021.protein.info.v11.5.txt",
		        "node_list_path": "1267021.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpLeaf344Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. Leaf344 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpLeaf344Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736346.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736346.protein.info.v11.5.txt",
		        "node_list_path": "1736346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulforhabdusNorvegica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulforhabdus norvegica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulforhabdusNorvegica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39841.protein.sequences.v11.5.fa",
		        "enrichment_path": "39841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39841.protein.info.v11.5.txt",
		        "node_list_path": "39841.protein.complete.v11.5.txt"
		    }
		]
    )()

def CeleribacterMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Celeribacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeleribacterMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397108.protein.info.v11.5.txt",
		        "node_list_path": "1397108.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosphaeraSpWgk6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosphaera sp. WGK6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosphaeraSpWgk6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1561964.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1561964.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1561964.clusters.proteins.v11.5.txt",
		        "sequence_path": "1561964.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561964.protein.info.v11.5.txt",
		        "node_list_path": "1561964.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1561964.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasNitroreducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasNitroreducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46680.clusters.proteins.v11.5.txt",
		        "sequence_path": "46680.protein.sequences.v11.5.fa",
		        "enrichment_path": "46680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46680.protein.info.v11.5.txt",
		        "node_list_path": "46680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpXt11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. XT11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpXt11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "367477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "367477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "367477.clusters.proteins.v11.5.txt",
		        "sequence_path": "367477.protein.sequences.v11.5.fa",
		        "enrichment_path": "367477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "367477.protein.info.v11.5.txt",
		        "node_list_path": "367477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "367477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaTuberolachnusSalignus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Tuberolachnus salignus) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaTuberolachnusSalignus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "98804.protein.sequences.v11.5.fa",
		        "enrichment_path": "98804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "98804.protein.info.v11.5.txt",
		        "node_list_path": "98804.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumRifcsplowo201Full4710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RIFCSPLOWO2_01_FULL_47_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumRifcsplowo201Full4710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817751.protein.info.v11.5.txt",
		        "node_list_path": "1817751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasFlueggei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas flueggei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasFlueggei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "638302.protein.sequences.v11.5.fa",
		        "enrichment_path": "638302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "638302.protein.info.v11.5.txt",
		        "node_list_path": "638302.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParusMajor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parus major graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParusMajor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9157.protein.sequences.v11.5.fa",
		        "enrichment_path": "9157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9157.protein.info.v11.5.txt",
		        "node_list_path": "9157.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarmotaMarmotaMarmota(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marmota marmota marmota graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarmotaMarmotaMarmota", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9994.protein.sequences.v11.5.fa",
		        "enrichment_path": "9994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9994.protein.info.v11.5.txt",
		        "node_list_path": "9994.protein.complete.v11.5.txt"
		    }
		]
    )()

def SiccibacterColletis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Siccibacter colletis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SiccibacterColletis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1505757.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505757.protein.info.v11.5.txt",
		        "node_list_path": "1505757.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpBcIso3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. Bc-iso-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpBcIso3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1848158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848158.protein.info.v11.5.txt",
		        "node_list_path": "1848158.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusElongatusPcc7942(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus elongatus PCC7942 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusElongatusPcc7942", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1140.protein.sequences.v11.5.fa",
		        "enrichment_path": "1140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1140.protein.info.v11.5.txt",
		        "node_list_path": "1140.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaAnserinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia anserina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaAnserinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1313293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1313293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1313293.clusters.proteins.v11.5.txt",
		        "sequence_path": "1313293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313293.protein.info.v11.5.txt",
		        "node_list_path": "1313293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1313293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumSgBin4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SG_bin4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumSgBin4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1827381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1827381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1827381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1827381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827381.protein.info.v11.5.txt",
		        "node_list_path": "1827381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1827381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedArchaeon(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedArchaeon", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "115547.protein.sequences.v11.5.fa",
		        "enrichment_path": "115547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115547.protein.info.v11.5.txt",
		        "node_list_path": "115547.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterSp1485eCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. 1485E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSp1485eCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1244531.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1244531.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1244531.clusters.proteins.v11.5.txt",
		        "sequence_path": "1244531.protein.sequences.v11.5.fa",
		        "enrichment_path": "1244531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1244531.protein.info.v11.5.txt",
		        "node_list_path": "1244531.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1244531.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinophytocolaXinjiangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinophytocola xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinophytocolaXinjiangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "485602.protein.sequences.v11.5.fa",
		        "enrichment_path": "485602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485602.protein.info.v11.5.txt",
		        "node_list_path": "485602.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinilyticumLitopenaeiDsm21440Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinilyticum litopenaei DSM 21440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinilyticumLitopenaeiDsm21440Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "529086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "529086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "529086.clusters.proteins.v11.5.txt",
		        "sequence_path": "529086.protein.sequences.v11.5.fa",
		        "enrichment_path": "529086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529086.protein.info.v11.5.txt",
		        "node_list_path": "529086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "529086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankineaeBacteriumMt45(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankineae bacterium MT45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankineaeBacteriumMt45", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882833.protein.info.v11.5.txt",
		        "node_list_path": "1882833.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumProvencense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium provencense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumProvencense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1737425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1737425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1737425.protein.info.v11.5.txt",
		        "node_list_path": "1737425.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinokineosporaTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinokineosporaTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "155974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "155974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "155974.clusters.proteins.v11.5.txt",
		        "sequence_path": "155974.protein.sequences.v11.5.fa",
		        "enrichment_path": "155974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "155974.protein.info.v11.5.txt",
		        "node_list_path": "155974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "155974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpLb2008(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. LB2008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpLb2008", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408305.protein.info.v11.5.txt",
		        "node_list_path": "1408305.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacteraceaeBacteriumAt5844(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacteraceae bacterium AT5844 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacteraceaeBacteriumAt5844", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1054213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1054213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1054213.protein.info.v11.5.txt",
		        "node_list_path": "1054213.protein.complete.v11.5.txt"
		    }
		]
    )()

def AdvenellaMimigardefordensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Advenella mimigardefordensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AdvenellaMimigardefordensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1247726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1247726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1247726.clusters.proteins.v11.5.txt",
		        "sequence_path": "1247726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1247726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1247726.protein.info.v11.5.txt",
		        "node_list_path": "1247726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1247726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisJejuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisJejuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "330084.protein.sequences.v11.5.fa",
		        "enrichment_path": "330084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "330084.protein.info.v11.5.txt",
		        "node_list_path": "330084.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeminocystisSpNies3709Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geminocystis sp. NIES-3709 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeminocystisSpNies3709Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617448.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617448.protein.info.v11.5.txt",
		        "node_list_path": "1617448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PodosporaAnserinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Podospora anserina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PodosporaAnserinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5145.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5145.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5145.clusters.proteins.v11.5.txt",
		        "sequence_path": "5145.protein.sequences.v11.5.fa",
		        "enrichment_path": "5145.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5145.protein.info.v11.5.txt",
		        "node_list_path": "5145.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5145.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroherpetonThalassium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroherpeton thalassium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroherpetonThalassium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "517418.protein.sequences.v11.5.fa",
		        "enrichment_path": "517418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "517418.protein.info.v11.5.txt",
		        "node_list_path": "517418.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryptococcusGattiiVgiiR265Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus gattii VGII R265 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptococcusGattiiVgiiR265Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "294750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "294750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "294750.clusters.proteins.v11.5.txt",
		        "sequence_path": "294750.protein.sequences.v11.5.fa",
		        "enrichment_path": "294750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294750.protein.info.v11.5.txt",
		        "node_list_path": "294750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "294750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseobacterSpSk20926Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. SK20926 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterSpSk20926Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "388739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "388739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "388739.clusters.proteins.v11.5.txt",
		        "sequence_path": "388739.protein.sequences.v11.5.fa",
		        "enrichment_path": "388739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388739.protein.info.v11.5.txt",
		        "node_list_path": "388739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "388739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteibacterSp9143(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter sp. 9143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterSp9143", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500890.protein.info.v11.5.txt",
		        "node_list_path": "1500890.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassobiusMediterraneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassobius mediterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobiusMediterraneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "340021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "340021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "340021.clusters.proteins.v11.5.txt",
		        "sequence_path": "340021.protein.sequences.v11.5.fa",
		        "enrichment_path": "340021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340021.protein.info.v11.5.txt",
		        "node_list_path": "340021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "340021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GluconobacterFrateuriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter frateurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterFrateuriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1307834.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1307834.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1307834.clusters.proteins.v11.5.txt",
		        "sequence_path": "1307834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307834.protein.info.v11.5.txt",
		        "node_list_path": "1307834.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1307834.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag624043(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:62_40_43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag624043", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896990.protein.info.v11.5.txt",
		        "node_list_path": "1896990.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoramibacterAlactolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoramibacter alactolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoramibacterAlactolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "887929.protein.sequences.v11.5.fa",
		        "enrichment_path": "887929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "887929.protein.info.v11.5.txt",
		        "node_list_path": "887929.protein.complete.v11.5.txt"
		    }
		]
    )()

def CholoepusHoffmanni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Choloepus hoffmanni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CholoepusHoffmanni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9358.protein.sequences.v11.5.fa",
		        "enrichment_path": "9358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9358.protein.info.v11.5.txt",
		        "node_list_path": "9358.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchistosomaCurassoniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma curassoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaCurassoniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6186.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6186.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6186.clusters.proteins.v11.5.txt",
		        "sequence_path": "6186.protein.sequences.v11.5.fa",
		        "enrichment_path": "6186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6186.protein.info.v11.5.txt",
		        "node_list_path": "6186.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6186.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TessaracoccusOleiagri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus oleiagri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusOleiagri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "686624.protein.sequences.v11.5.fa",
		        "enrichment_path": "686624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686624.protein.info.v11.5.txt",
		        "node_list_path": "686624.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnoanaerobaculumSpMsx33(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum sp. MSX33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoanaerobaculumSpMsx33", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936596.protein.sequences.v11.5.fa",
		        "enrichment_path": "936596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936596.protein.info.v11.5.txt",
		        "node_list_path": "936596.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag791Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:791 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag791Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262993.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262993.protein.info.v11.5.txt",
		        "node_list_path": "1262993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumNigeriense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium nigeriense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumNigeriense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805470.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805470.protein.info.v11.5.txt",
		        "node_list_path": "1805470.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumDenitrificans1nes1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium denitrificans 1NES1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumDenitrificans1nes1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "670307.protein.sequences.v11.5.fa",
		        "enrichment_path": "670307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670307.protein.info.v11.5.txt",
		        "node_list_path": "670307.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaPalleroniiNbrc102513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga palleronii NBRC 102513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaPalleroniiNbrc102513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349791.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349791.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349791.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349791.protein.info.v11.5.txt",
		        "node_list_path": "1349791.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349791.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfohalobiumRetbaenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfohalobium retbaense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfohalobiumRetbaenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "485915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "485915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "485915.clusters.proteins.v11.5.txt",
		        "sequence_path": "485915.protein.sequences.v11.5.fa",
		        "enrichment_path": "485915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485915.protein.info.v11.5.txt",
		        "node_list_path": "485915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "485915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelobacterSeleniigenesDsm18267(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter seleniigenes DSM 18267 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelobacterSeleniigenesDsm18267", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122946.protein.info.v11.5.txt",
		        "node_list_path": "1122946.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full5114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_51_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full5114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798683.protein.info.v11.5.txt",
		        "node_list_path": "1798683.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusJensenii272chn(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii 272CHN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusJensenii272chn", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575606.protein.sequences.v11.5.fa",
		        "enrichment_path": "575606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575606.protein.info.v11.5.txt",
		        "node_list_path": "575606.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpHeron(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. Heron graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpHeron", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385935.protein.info.v11.5.txt",
		        "node_list_path": "1385935.protein.complete.v11.5.txt"
		    }
		]
    )()

def SordariaMacrosporaKHellCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sordaria macrospora k-hell Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SordariaMacrosporaKHellCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "771870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "771870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "771870.clusters.proteins.v11.5.txt",
		        "sequence_path": "771870.protein.sequences.v11.5.fa",
		        "enrichment_path": "771870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "771870.protein.info.v11.5.txt",
		        "node_list_path": "771870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "771870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusSphaerophysae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sphaerophysae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSphaerophysae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "690417.protein.sequences.v11.5.fa",
		        "enrichment_path": "690417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690417.protein.info.v11.5.txt",
		        "node_list_path": "690417.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpRit328(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. RIT328 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpRit328", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1470591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470591.protein.info.v11.5.txt",
		        "node_list_path": "1470591.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErysipelotrichaceaeBacteriumI46(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium I46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelotrichaceaeBacteriumI46", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834207.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834207.protein.info.v11.5.txt",
		        "node_list_path": "1834207.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumOmnivorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium omnivorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumOmnivorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "178355.protein.sequences.v11.5.fa",
		        "enrichment_path": "178355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178355.protein.info.v11.5.txt",
		        "node_list_path": "178355.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesAlkalitoleransDsm16699(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides alkalitolerans DSM 16699 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesAlkalitoleransDsm16699", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122608.protein.info.v11.5.txt",
		        "node_list_path": "1122608.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusSpMarseilleP2143Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. Marseille-P2143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusSpMarseilleP2143Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1745712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1745712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1745712.clusters.proteins.v11.5.txt",
		        "sequence_path": "1745712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1745712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1745712.protein.info.v11.5.txt",
		        "node_list_path": "1745712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1745712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingorhabdusMarinaDsm22363Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingorhabdus marina DSM 22363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingorhabdusMarinaDsm22363Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123272.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123272.protein.info.v11.5.txt",
		        "node_list_path": "1123272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinopolysporaXinjiangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolysporaXinjiangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "405564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "405564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "405564.clusters.proteins.v11.5.txt",
		        "sequence_path": "405564.protein.sequences.v11.5.fa",
		        "enrichment_path": "405564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405564.protein.info.v11.5.txt",
		        "node_list_path": "405564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "405564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumCg1024134(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium CG1_02_41_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumCg1024134", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805239.protein.info.v11.5.txt",
		        "node_list_path": "1805239.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumRifoxyd1Full3611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFOXYD1_FULL_36_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifoxyd1Full3611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798656.protein.info.v11.5.txt",
		        "node_list_path": "1798656.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetarhiziumRileyiRcef4871Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium rileyi RCEF 4871 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetarhiziumRileyiRcef4871Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1081105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1081105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1081105.clusters.proteins.v11.5.txt",
		        "sequence_path": "1081105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081105.protein.info.v11.5.txt",
		        "node_list_path": "1081105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1081105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumInnocuum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium innocuum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumInnocuum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999413.protein.sequences.v11.5.fa",
		        "enrichment_path": "999413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999413.protein.info.v11.5.txt",
		        "node_list_path": "999413.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasNitroreducensTx1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens TX1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasNitroreducensTx1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1226994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1226994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1226994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1226994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1226994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1226994.protein.info.v11.5.txt",
		        "node_list_path": "1226994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1226994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumGw2011Gwa14429(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWA1_44_29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwa14429", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618646.protein.info.v11.5.txt",
		        "node_list_path": "1618646.protein.complete.v11.5.txt"
		    }
		]
    )()

def MusSpretusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mus spretus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusSpretusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10096.clusters.proteins.v11.5.txt",
		        "sequence_path": "10096.protein.sequences.v11.5.fa",
		        "enrichment_path": "10096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10096.protein.info.v11.5.txt",
		        "node_list_path": "10096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronomonasPharaonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronomonas pharaonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronomonasPharaonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "348780.protein.sequences.v11.5.fa",
		        "enrichment_path": "348780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "348780.protein.info.v11.5.txt",
		        "node_list_path": "348780.protein.complete.v11.5.txt"
		    }
		]
    )()

def CamelinaSativa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Camelina sativa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CamelinaSativa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "90675.protein.sequences.v11.5.fa",
		        "enrichment_path": "90675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90675.protein.info.v11.5.txt",
		        "node_list_path": "90675.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaMalaquaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia malaquae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaMalaquaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223542.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223542.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223542.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223542.protein.info.v11.5.txt",
		        "node_list_path": "1223542.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223542.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDadabacteriaBacteriumCsp12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dadabacteria bacterium CSP1-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDadabacteriaBacteriumCsp12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1640508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640508.protein.info.v11.5.txt",
		        "node_list_path": "1640508.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaErectaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila erecta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaErectaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7220.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7220.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7220.clusters.proteins.v11.5.txt",
		        "sequence_path": "7220.protein.sequences.v11.5.fa",
		        "enrichment_path": "7220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7220.protein.info.v11.5.txt",
		        "node_list_path": "7220.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7220.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArabidopsisLyrataSubspLyrataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arabidopsis lyrata subsp. lyrata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArabidopsisLyrataSubspLyrataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "81972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "81972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "81972.clusters.proteins.v11.5.txt",
		        "sequence_path": "81972.protein.sequences.v11.5.fa",
		        "enrichment_path": "81972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81972.protein.info.v11.5.txt",
		        "node_list_path": "81972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "81972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusTubingensisCbs13448(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus tubingensis CBS 134.48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusTubingensisCbs13448", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "767770.protein.sequences.v11.5.fa",
		        "enrichment_path": "767770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767770.protein.info.v11.5.txt",
		        "node_list_path": "767770.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaplasmaPhagocytophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma phagocytophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaplasmaPhagocytophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "212042.protein.sequences.v11.5.fa",
		        "enrichment_path": "212042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "212042.protein.info.v11.5.txt",
		        "node_list_path": "212042.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpAc23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. AC-23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpAc23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1879031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1879031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1879031.protein.info.v11.5.txt",
		        "node_list_path": "1879031.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAmyloliquefaciensDsm7Atcc23350(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens DSM 7 ATCC 23350 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAmyloliquefaciensDsm7Atcc23350", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "692420.protein.sequences.v11.5.fa",
		        "enrichment_path": "692420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "692420.protein.info.v11.5.txt",
		        "node_list_path": "692420.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho201Full3819Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_38_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full3819Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801732.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801732.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801732.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801732.protein.info.v11.5.txt",
		        "node_list_path": "1801732.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801732.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpGm95Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. GM95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpGm95Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881043.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881043.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881043.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881043.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881043.protein.info.v11.5.txt",
		        "node_list_path": "1881043.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881043.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermocrinisAlbusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermocrinis albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocrinisAlbusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "638303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "638303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "638303.clusters.proteins.v11.5.txt",
		        "sequence_path": "638303.protein.sequences.v11.5.fa",
		        "enrichment_path": "638303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "638303.protein.info.v11.5.txt",
		        "node_list_path": "638303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "638303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraMeyeriSerovarHardjoStrWent5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira meyeri serovar Hardjo str. Went 5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraMeyeriSerovarHardjoStrWent5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193051.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193051.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193051.protein.info.v11.5.txt",
		        "node_list_path": "1193051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBeijerinckiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter beijerinckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBeijerinckiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217648.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217648.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217648.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217648.protein.info.v11.5.txt",
		        "node_list_path": "1217648.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217648.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesVulturis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces vulturis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesVulturis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1857645.protein.sequences.v11.5.fa",
		        "enrichment_path": "1857645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1857645.protein.info.v11.5.txt",
		        "node_list_path": "1857645.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsphigho202Full4513b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_02_FULL_45_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho202Full4513b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802117.protein.info.v11.5.txt",
		        "node_list_path": "1802117.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalohastaLitchfieldiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halohasta litchfieldiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalohastaLitchfieldiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1073996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1073996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1073996.clusters.proteins.v11.5.txt",
		        "sequence_path": "1073996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073996.protein.info.v11.5.txt",
		        "node_list_path": "1073996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1073996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiothrixNiveaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix nivea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiothrixNiveaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "870187.clusters.info.v11.5.txt",
		        "cluster_tree_path": "870187.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "870187.clusters.proteins.v11.5.txt",
		        "sequence_path": "870187.protein.sequences.v11.5.fa",
		        "enrichment_path": "870187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "870187.protein.info.v11.5.txt",
		        "node_list_path": "870187.cluster.nodes.v11.5.txt",
		        "edge_list_path": "870187.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPolysaccharolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polysaccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPolysaccharolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582692.protein.sequences.v11.5.fa",
		        "enrichment_path": "582692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582692.protein.info.v11.5.txt",
		        "node_list_path": "582692.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpJcm9796(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 9796 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpJcm9796", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298602.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298602.protein.info.v11.5.txt",
		        "node_list_path": "1298602.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumGwa24615Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium GWA2_46_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumGwa24615Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802443.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802443.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802443.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802443.protein.info.v11.5.txt",
		        "node_list_path": "1802443.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802443.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyperthermusButylicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyperthermus butylicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyperthermusButylicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "415426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "415426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "415426.clusters.proteins.v11.5.txt",
		        "sequence_path": "415426.protein.sequences.v11.5.fa",
		        "enrichment_path": "415426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "415426.protein.info.v11.5.txt",
		        "node_list_path": "415426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "415426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrospiraInopinataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira inopinata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrospiraInopinataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1715989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1715989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1715989.clusters.proteins.v11.5.txt",
		        "sequence_path": "1715989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715989.protein.info.v11.5.txt",
		        "node_list_path": "1715989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1715989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedCoprococcusSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Coprococcus sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedCoprococcusSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "458253.clusters.info.v11.5.txt",
		        "cluster_tree_path": "458253.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "458253.clusters.proteins.v11.5.txt",
		        "sequence_path": "458253.protein.sequences.v11.5.fa",
		        "enrichment_path": "458253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "458253.protein.info.v11.5.txt",
		        "node_list_path": "458253.cluster.nodes.v11.5.txt",
		        "edge_list_path": "458253.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizopusMicrosporusAtcc52813(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus microsporus ATCC 52813 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopusMicrosporusAtcc52813", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1340429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1340429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1340429.protein.info.v11.5.txt",
		        "node_list_path": "1340429.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribiusSalinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribius salinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribiusSalinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313368.clusters.proteins.v11.5.txt",
		        "sequence_path": "313368.protein.sequences.v11.5.fa",
		        "enrichment_path": "313368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313368.protein.info.v11.5.txt",
		        "node_list_path": "313368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE740(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E740 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE740", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834149.protein.info.v11.5.txt",
		        "node_list_path": "1834149.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSpCg3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. CG3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSpCg3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1075768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1075768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1075768.clusters.proteins.v11.5.txt",
		        "sequence_path": "1075768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1075768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1075768.protein.info.v11.5.txt",
		        "node_list_path": "1075768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1075768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusFerrarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ferrarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusFerrarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1469647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469647.protein.info.v11.5.txt",
		        "node_list_path": "1469647.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpCf097Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF097 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpCf097Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500301.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500301.protein.info.v11.5.txt",
		        "node_list_path": "1500301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquabacteriumSpNj1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquabacterium sp. NJ1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquabacteriumSpNj1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1538295.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1538295.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1538295.clusters.proteins.v11.5.txt",
		        "sequence_path": "1538295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1538295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1538295.protein.info.v11.5.txt",
		        "node_list_path": "1538295.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1538295.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PragiaFontium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pragia fontium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PragiaFontium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "82985.protein.sequences.v11.5.fa",
		        "enrichment_path": "82985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82985.protein.info.v11.5.txt",
		        "node_list_path": "82985.protein.complete.v11.5.txt"
		    }
		]
    )()

def GilliamellaBombicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gilliamella bombicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilliamellaBombicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798182.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798182.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798182.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798182.protein.info.v11.5.txt",
		        "node_list_path": "1798182.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798182.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwr3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWR3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwr3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896217.protein.info.v11.5.txt",
		        "node_list_path": "1896217.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterColi76339Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter coli 76339 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterColi76339Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1367491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1367491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1367491.clusters.proteins.v11.5.txt",
		        "sequence_path": "1367491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1367491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1367491.protein.info.v11.5.txt",
		        "node_list_path": "1367491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1367491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermostaphylosporaChromogenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermostaphylospora chromogena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermostaphylosporaChromogenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35622.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35622.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35622.clusters.proteins.v11.5.txt",
		        "sequence_path": "35622.protein.sequences.v11.5.fa",
		        "enrichment_path": "35622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35622.protein.info.v11.5.txt",
		        "node_list_path": "35622.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35622.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprinopsisMarcescibilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprinopsis marcescibilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprinopsisMarcescibilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "230819.protein.sequences.v11.5.fa",
		        "enrichment_path": "230819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "230819.protein.info.v11.5.txt",
		        "node_list_path": "230819.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterZhejiangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter zhejiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterZhejiangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "488535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "488535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "488535.clusters.proteins.v11.5.txt",
		        "sequence_path": "488535.protein.sequences.v11.5.fa",
		        "enrichment_path": "488535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "488535.protein.info.v11.5.txt",
		        "node_list_path": "488535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "488535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteiniphilumSaccharofermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteiniphilum saccharofermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteiniphilumSaccharofermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1642647.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1642647.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1642647.clusters.proteins.v11.5.txt",
		        "sequence_path": "1642647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1642647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1642647.protein.info.v11.5.txt",
		        "node_list_path": "1642647.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1642647.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaMannitolilyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia mannitolilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaMannitolilyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "105219.clusters.info.v11.5.txt",
		        "cluster_tree_path": "105219.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "105219.clusters.proteins.v11.5.txt",
		        "sequence_path": "105219.protein.sequences.v11.5.fa",
		        "enrichment_path": "105219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105219.protein.info.v11.5.txt",
		        "node_list_path": "105219.cluster.nodes.v11.5.txt",
		        "edge_list_path": "105219.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AggregatibacterActinomycetemcomitansD7s1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans D7S1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterActinomycetemcomitansD7s1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "694569.clusters.info.v11.5.txt",
		        "cluster_tree_path": "694569.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "694569.clusters.proteins.v11.5.txt",
		        "sequence_path": "694569.protein.sequences.v11.5.fa",
		        "enrichment_path": "694569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694569.protein.info.v11.5.txt",
		        "node_list_path": "694569.cluster.nodes.v11.5.txt",
		        "edge_list_path": "694569.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachanceaMirantina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachancea mirantina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachanceaMirantina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230905.protein.info.v11.5.txt",
		        "node_list_path": "1230905.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807731.protein.info.v11.5.txt",
		        "node_list_path": "1807731.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinomonasAquimarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas aquimarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasAquimarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "295068.protein.sequences.v11.5.fa",
		        "enrichment_path": "295068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "295068.protein.info.v11.5.txt",
		        "node_list_path": "295068.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureimonasUreilyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas ureilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasUreilyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121028.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121028.protein.info.v11.5.txt",
		        "node_list_path": "1121028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlebsiellaPneumoniaeSubspPneumoniaeMgh78578(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. pneumoniae MGH 78578 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaPneumoniaeSubspPneumoniaeMgh78578", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272620.protein.sequences.v11.5.fa",
		        "enrichment_path": "272620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272620.protein.info.v11.5.txt",
		        "node_list_path": "272620.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinopolysporaXinjiangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolysporaXinjiangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "405564.protein.sequences.v11.5.fa",
		        "enrichment_path": "405564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405564.protein.info.v11.5.txt",
		        "node_list_path": "405564.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesViscosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces viscosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesViscosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "562973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "562973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "562973.clusters.proteins.v11.5.txt",
		        "sequence_path": "562973.protein.sequences.v11.5.fa",
		        "enrichment_path": "562973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562973.protein.info.v11.5.txt",
		        "node_list_path": "562973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "562973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TarenayaHassleriana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tarenaya hassleriana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TarenayaHassleriana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28532.protein.sequences.v11.5.fa",
		        "enrichment_path": "28532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28532.protein.info.v11.5.txt",
		        "node_list_path": "28532.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParambassisRanga(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parambassis ranga graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParambassisRanga", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "210632.protein.sequences.v11.5.fa",
		        "enrichment_path": "210632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "210632.protein.info.v11.5.txt",
		        "node_list_path": "210632.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumRbg16399bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_39_9b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg16399bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802595.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802595.protein.info.v11.5.txt",
		        "node_list_path": "1802595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg135136(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_51_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg135136", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797625.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797625.protein.info.v11.5.txt",
		        "node_list_path": "1797625.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmatimonadetesBacteriumRbg166712(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium RBG_16_67_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmatimonadetesBacteriumRbg166712", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797288.protein.info.v11.5.txt",
		        "node_list_path": "1797288.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFirestonebacteriaBacteriumRifoxyc2Full3967(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Firestonebacteria bacterium RIFOXYC2_FULL_39_67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFirestonebacteriaBacteriumRifoxyc2Full3967", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817861.protein.info.v11.5.txt",
		        "node_list_path": "1817861.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaVinsoniiArupensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella vinsonii arupensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaVinsoniiArupensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094561.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094561.protein.info.v11.5.txt",
		        "node_list_path": "1094561.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF3557Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-3557 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF3557Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437433.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437433.protein.info.v11.5.txt",
		        "node_list_path": "1437433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumGordonae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium gordonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumGordonae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1778.protein.info.v11.5.txt",
		        "node_list_path": "1778.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusNubinhibens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius nubinhibens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusNubinhibens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "89187.protein.sequences.v11.5.fa",
		        "enrichment_path": "89187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89187.protein.info.v11.5.txt",
		        "node_list_path": "89187.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumCg2303210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium CG2_30_32_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumCg2303210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805032.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805032.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805032.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805032.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805032.protein.info.v11.5.txt",
		        "node_list_path": "1805032.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805032.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1689271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1689271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1689271.clusters.proteins.v11.5.txt",
		        "sequence_path": "1689271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1689271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1689271.protein.info.v11.5.txt",
		        "node_list_path": "1689271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1689271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlbugoLaibachiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Albugo laibachii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlbugoLaibachiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "653948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "653948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "653948.clusters.proteins.v11.5.txt",
		        "sequence_path": "653948.protein.sequences.v11.5.fa",
		        "enrichment_path": "653948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "653948.protein.info.v11.5.txt",
		        "node_list_path": "653948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "653948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgromycesItalicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agromyces italicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesItalicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120959.protein.info.v11.5.txt",
		        "node_list_path": "1120959.protein.complete.v11.5.txt"
		    }
		]
    )()

def JannaschiaAquimarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia aquimarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaAquimarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935700.protein.sequences.v11.5.fa",
		        "enrichment_path": "935700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935700.protein.info.v11.5.txt",
		        "node_list_path": "935700.protein.complete.v11.5.txt"
		    }
		]
    )()

def HumibacterAlbusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Humibacter albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HumibacterAlbusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121952.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121952.protein.info.v11.5.txt",
		        "node_list_path": "1121952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesPectinophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides pectinophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesPectinophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "483218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "483218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "483218.clusters.proteins.v11.5.txt",
		        "sequence_path": "483218.protein.sequences.v11.5.fa",
		        "enrichment_path": "483218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483218.protein.info.v11.5.txt",
		        "node_list_path": "483218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "483218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenibacterLatericius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arenibacter latericius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenibacterLatericius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121012.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121012.protein.info.v11.5.txt",
		        "node_list_path": "1121012.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsaiaPlatycodiSf21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asaia platycodi SF21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsaiaPlatycodiSf21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1382230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1382230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1382230.clusters.proteins.v11.5.txt",
		        "sequence_path": "1382230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382230.protein.info.v11.5.txt",
		        "node_list_path": "1382230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1382230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BatrachochytriumDendrobatidisJel423Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis JEL423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BatrachochytriumDendrobatidisJel423Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "403673.clusters.info.v11.5.txt",
		        "cluster_tree_path": "403673.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "403673.clusters.proteins.v11.5.txt",
		        "sequence_path": "403673.protein.sequences.v11.5.fa",
		        "enrichment_path": "403673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "403673.protein.info.v11.5.txt",
		        "node_list_path": "403673.cluster.nodes.v11.5.txt",
		        "edge_list_path": "403673.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaQuateirensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella quateirensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaQuateirensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45072.protein.sequences.v11.5.fa",
		        "enrichment_path": "45072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45072.protein.info.v11.5.txt",
		        "node_list_path": "45072.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163671.protein.info.v11.5.txt",
		        "node_list_path": "1163671.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassilimicrobiotaTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilimicrobiota timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassilimicrobiotaTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776392.protein.info.v11.5.txt",
		        "node_list_path": "1776392.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsanoaIshikariensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asanoa ishikariensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsanoaIshikariensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "137265.protein.sequences.v11.5.fa",
		        "enrichment_path": "137265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137265.protein.info.v11.5.txt",
		        "node_list_path": "137265.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRaac2Wwe31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RAAC2_WWE3_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRaac2Wwe31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1394710.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1394710.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1394710.clusters.proteins.v11.5.txt",
		        "sequence_path": "1394710.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394710.protein.info.v11.5.txt",
		        "node_list_path": "1394710.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1394710.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfobacillusAcidophilusDsm10332Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfobacillus acidophilus DSM 10332 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfobacillusAcidophilusDsm10332Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679936.clusters.proteins.v11.5.txt",
		        "sequence_path": "679936.protein.sequences.v11.5.fa",
		        "enrichment_path": "679936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679936.protein.info.v11.5.txt",
		        "node_list_path": "679936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachyspiraPilosicoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira pilosicoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraPilosicoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "759914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "759914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "759914.clusters.proteins.v11.5.txt",
		        "sequence_path": "759914.protein.sequences.v11.5.fa",
		        "enrichment_path": "759914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759914.protein.info.v11.5.txt",
		        "node_list_path": "759914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "759914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OgataeaParapolymorphaDl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ogataea parapolymorpha DL-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OgataeaParapolymorphaDl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "871575.clusters.info.v11.5.txt",
		        "cluster_tree_path": "871575.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "871575.clusters.proteins.v11.5.txt",
		        "sequence_path": "871575.protein.sequences.v11.5.fa",
		        "enrichment_path": "871575.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871575.protein.info.v11.5.txt",
		        "node_list_path": "871575.cluster.nodes.v11.5.txt",
		        "edge_list_path": "871575.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls37Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls37Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463903.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463903.protein.info.v11.5.txt",
		        "node_list_path": "1463903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumMetallidurans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium metallidurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumMetallidurans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1297569.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297569.protein.info.v11.5.txt",
		        "node_list_path": "1297569.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSpLeaf194Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf194 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpLeaf194Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736297.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736297.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736297.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736297.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736297.protein.info.v11.5.txt",
		        "node_list_path": "1736297.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736297.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumBica17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BICA1-7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumBica17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1531961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1531961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1531961.protein.info.v11.5.txt",
		        "node_list_path": "1531961.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusOpacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus opacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusOpacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37919.protein.sequences.v11.5.fa",
		        "enrichment_path": "37919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37919.protein.info.v11.5.txt",
		        "node_list_path": "37919.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomonasSpFb6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas sp. FB-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomonasSpFb6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158291.protein.info.v11.5.txt",
		        "node_list_path": "1158291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033734.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033734.protein.info.v11.5.txt",
		        "node_list_path": "1033734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RikenellaceaeBacteriumDtu001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium DTU001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RikenellaceaeBacteriumDtu001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671664.protein.info.v11.5.txt",
		        "node_list_path": "1671664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4967(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_49_67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4967", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802337.protein.info.v11.5.txt",
		        "node_list_path": "1802337.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpB72017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. B7(2017) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpB72017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1981712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1981712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1981712.protein.info.v11.5.txt",
		        "node_list_path": "1981712.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumIndicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium indicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumIndicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094466.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094466.protein.info.v11.5.txt",
		        "node_list_path": "1094466.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpJhl3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. JHL-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpJhl3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1276755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276755.protein.info.v11.5.txt",
		        "node_list_path": "1276755.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaDuttoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia duttonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaDuttoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "412419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "412419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "412419.clusters.proteins.v11.5.txt",
		        "sequence_path": "412419.protein.sequences.v11.5.fa",
		        "enrichment_path": "412419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "412419.protein.info.v11.5.txt",
		        "node_list_path": "412419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "412419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaHisticola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella histicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaHisticola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236504.protein.info.v11.5.txt",
		        "node_list_path": "1236504.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxyb2Full487Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2_FULL_48_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2Full487Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797967.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797967.protein.info.v11.5.txt",
		        "node_list_path": "1797967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlesiomonasShigelloidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plesiomonas shigelloides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlesiomonasShigelloidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "703.clusters.info.v11.5.txt",
		        "cluster_tree_path": "703.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "703.clusters.proteins.v11.5.txt",
		        "sequence_path": "703.protein.sequences.v11.5.fa",
		        "enrichment_path": "703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "703.protein.info.v11.5.txt",
		        "node_list_path": "703.cluster.nodes.v11.5.txt",
		        "edge_list_path": "703.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPseudotuberculosisC231Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pseudotuberculosis C231 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPseudotuberculosisC231Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "681645.clusters.info.v11.5.txt",
		        "cluster_tree_path": "681645.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "681645.clusters.proteins.v11.5.txt",
		        "sequence_path": "681645.protein.sequences.v11.5.fa",
		        "enrichment_path": "681645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "681645.protein.info.v11.5.txt",
		        "node_list_path": "681645.cluster.nodes.v11.5.txt",
		        "edge_list_path": "681645.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasShengliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas shengliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasShengliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "419597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "419597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "419597.clusters.proteins.v11.5.txt",
		        "sequence_path": "419597.protein.sequences.v11.5.fa",
		        "enrichment_path": "419597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419597.protein.info.v11.5.txt",
		        "node_list_path": "419597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "419597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OctodonDegus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Octodon degus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OctodonDegus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10160.protein.sequences.v11.5.fa",
		        "enrichment_path": "10160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10160.protein.info.v11.5.txt",
		        "node_list_path": "10160.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndozoicomonasElysicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas elysicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndozoicomonasElysicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "305900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "305900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "305900.clusters.proteins.v11.5.txt",
		        "sequence_path": "305900.protein.sequences.v11.5.fa",
		        "enrichment_path": "305900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "305900.protein.info.v11.5.txt",
		        "node_list_path": "305900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "305900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AedesAegypti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aedes aegypti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AedesAegypti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7159.protein.sequences.v11.5.fa",
		        "enrichment_path": "7159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7159.protein.info.v11.5.txt",
		        "node_list_path": "7159.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloarculaVallismortisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula vallismortis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaVallismortisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28442.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28442.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28442.clusters.proteins.v11.5.txt",
		        "sequence_path": "28442.protein.sequences.v11.5.fa",
		        "enrichment_path": "28442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28442.protein.info.v11.5.txt",
		        "node_list_path": "28442.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28442.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaXyliCynodontis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia xyli cynodontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaXyliCynodontis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1389489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1389489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1389489.protein.info.v11.5.txt",
		        "node_list_path": "1389489.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentibacillusPersicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus persicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentibacillusPersicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "640948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "640948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "640948.clusters.proteins.v11.5.txt",
		        "sequence_path": "640948.protein.sequences.v11.5.fa",
		        "enrichment_path": "640948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640948.protein.info.v11.5.txt",
		        "node_list_path": "640948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "640948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumFlorentinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium florentinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumFlorentinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "292462.protein.sequences.v11.5.fa",
		        "enrichment_path": "292462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292462.protein.info.v11.5.txt",
		        "node_list_path": "292462.protein.complete.v11.5.txt"
		    }
		]
    )()

def CronobacterCondimentiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter condimenti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CronobacterCondimentiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1073999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1073999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1073999.clusters.proteins.v11.5.txt",
		        "sequence_path": "1073999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073999.protein.info.v11.5.txt",
		        "node_list_path": "1073999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1073999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KwoniellaMangroviensisCbs10435(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella mangroviensis CBS 10435 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KwoniellaMangroviensisCbs10435", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1331196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1331196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1331196.protein.info.v11.5.txt",
		        "node_list_path": "1331196.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpUnc280mftsu51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UNC280MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpUnc280mftsu51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449048.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449048.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449048.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449048.protein.info.v11.5.txt",
		        "node_list_path": "1449048.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449048.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusSpMctg156Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius sp. MCTG156 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusSpMctg156Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354722.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354722.protein.info.v11.5.txt",
		        "node_list_path": "1354722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxSpNbrc102024(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. NBRC 102024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxSpNbrc102024", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1113895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1113895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1113895.protein.info.v11.5.txt",
		        "node_list_path": "1113895.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinilyticumAquatileDsm21506Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinilyticum aquatile DSM 21506 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinilyticumAquatileDsm21506Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121275.protein.info.v11.5.txt",
		        "node_list_path": "1121275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262816.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262816.protein.info.v11.5.txt",
		        "node_list_path": "1262816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColwelliaPiezophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia piezophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaPiezophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265503.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265503.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265503.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265503.protein.info.v11.5.txt",
		        "node_list_path": "1265503.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265503.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterYangtzensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter yangtzensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterYangtzensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1743159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743159.protein.info.v11.5.txt",
		        "node_list_path": "1743159.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanotorrisFormicicusMcS70Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanotorris formicicus Mc-S-70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanotorrisFormicicusMcS70Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "647171.clusters.info.v11.5.txt",
		        "cluster_tree_path": "647171.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "647171.clusters.proteins.v11.5.txt",
		        "sequence_path": "647171.protein.sequences.v11.5.fa",
		        "enrichment_path": "647171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "647171.protein.info.v11.5.txt",
		        "node_list_path": "647171.cluster.nodes.v11.5.txt",
		        "edge_list_path": "647171.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelotomaculumThermopropionicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelotomaculum thermopropionicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelotomaculumThermopropionicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "370438.protein.sequences.v11.5.fa",
		        "enrichment_path": "370438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "370438.protein.info.v11.5.txt",
		        "node_list_path": "370438.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudocercosporaMusaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudocercospora musae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudocercosporaMusaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "113226.clusters.info.v11.5.txt",
		        "cluster_tree_path": "113226.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "113226.clusters.proteins.v11.5.txt",
		        "sequence_path": "113226.protein.sequences.v11.5.fa",
		        "enrichment_path": "113226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113226.protein.info.v11.5.txt",
		        "node_list_path": "113226.cluster.nodes.v11.5.txt",
		        "edge_list_path": "113226.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HandroanthusImpetiginosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Handroanthus impetiginosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HandroanthusImpetiginosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "429701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "429701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "429701.clusters.proteins.v11.5.txt",
		        "sequence_path": "429701.protein.sequences.v11.5.fa",
		        "enrichment_path": "429701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "429701.protein.info.v11.5.txt",
		        "node_list_path": "429701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "429701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacteriumHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacterium halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacteriumHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1082931.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1082931.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1082931.clusters.proteins.v11.5.txt",
		        "sequence_path": "1082931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1082931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1082931.protein.info.v11.5.txt",
		        "node_list_path": "1082931.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1082931.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumGenomosp3StrCfbp6623Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium genomosp. 3 str. CFBP 6623 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumGenomosp3StrCfbp6623Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1183432.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1183432.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1183432.clusters.proteins.v11.5.txt",
		        "sequence_path": "1183432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1183432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1183432.protein.info.v11.5.txt",
		        "node_list_path": "1183432.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1183432.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumGwf23885Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWF2_38_85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumGwf23885Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797683.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797683.protein.info.v11.5.txt",
		        "node_list_path": "1797683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTuberculosisH37raCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis H37Ra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTuberculosisH37raCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "419947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "419947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "419947.clusters.proteins.v11.5.txt",
		        "sequence_path": "419947.protein.sequences.v11.5.fa",
		        "enrichment_path": "419947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419947.protein.info.v11.5.txt",
		        "node_list_path": "419947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "419947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSp6626(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. 66-26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSp6626", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895689.protein.info.v11.5.txt",
		        "node_list_path": "1895689.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasVeroniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas veronii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasVeroniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "998088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "998088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "998088.clusters.proteins.v11.5.txt",
		        "sequence_path": "998088.protein.sequences.v11.5.fa",
		        "enrichment_path": "998088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "998088.protein.info.v11.5.txt",
		        "node_list_path": "998088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "998088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerocolumnaXylanovoransDsm12503Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerocolumna xylanovorans DSM 12503 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerocolumnaXylanovoransDsm12503Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121345.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121345.protein.info.v11.5.txt",
		        "node_list_path": "1121345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DendrobiumCatenatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dendrobium catenatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DendrobiumCatenatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "906689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "906689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "906689.clusters.proteins.v11.5.txt",
		        "sequence_path": "906689.protein.sequences.v11.5.fa",
		        "enrichment_path": "906689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "906689.protein.info.v11.5.txt",
		        "node_list_path": "906689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "906689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSp63ed372(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 63ED37-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSp63ed372", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1678128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678128.protein.info.v11.5.txt",
		        "node_list_path": "1678128.protein.complete.v11.5.txt"
		    }
		]
    )()

def SmithellaSpScadc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Smithella sp. SCADC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmithellaSpScadc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499107.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499107.protein.info.v11.5.txt",
		        "node_list_path": "1499107.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythruraGouldiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrura gouldiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythruraGouldiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44316.protein.sequences.v11.5.fa",
		        "enrichment_path": "44316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44316.protein.info.v11.5.txt",
		        "node_list_path": "44316.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaPseudospiralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichinella pseudospiralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaPseudospiralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6337.clusters.proteins.v11.5.txt",
		        "sequence_path": "6337.protein.sequences.v11.5.fa",
		        "enrichment_path": "6337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6337.protein.info.v11.5.txt",
		        "node_list_path": "6337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermofilumUzonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum uzonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermofilumUzonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1550241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550241.protein.info.v11.5.txt",
		        "node_list_path": "1550241.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaRubraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaRubraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348338.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348338.protein.info.v11.5.txt",
		        "node_list_path": "1348338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeratitisCapitata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ceratitis capitata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeratitisCapitata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7213.protein.sequences.v11.5.fa",
		        "enrichment_path": "7213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7213.protein.info.v11.5.txt",
		        "node_list_path": "7213.protein.complete.v11.5.txt"
		    }
		]
    )()

def PapilioXuthusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Papilio xuthus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PapilioXuthusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66420.clusters.proteins.v11.5.txt",
		        "sequence_path": "66420.protein.sequences.v11.5.fa",
		        "enrichment_path": "66420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66420.protein.info.v11.5.txt",
		        "node_list_path": "66420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FormosaSpHel133131(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Formosa sp. Hel1_33_131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaSpHel133131", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336794.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336794.protein.info.v11.5.txt",
		        "node_list_path": "1336794.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusMindensisDsm14500(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mindensis DSM 14500 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMindensisDsm14500", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423770.protein.info.v11.5.txt",
		        "node_list_path": "1423770.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9322Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9322 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9322Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "167550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "167550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "167550.clusters.proteins.v11.5.txt",
		        "sequence_path": "167550.protein.sequences.v11.5.fa",
		        "enrichment_path": "167550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167550.protein.info.v11.5.txt",
		        "node_list_path": "167550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "167550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyxococcalesBacteriumSg838Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myxococcales bacterium SG8_38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcalesBacteriumSg838Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703407.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703407.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703407.protein.info.v11.5.txt",
		        "node_list_path": "1703407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusVersicolorCbs58365(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus versicolor CBS 583.65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusVersicolorCbs58365", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1036611.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036611.protein.info.v11.5.txt",
		        "node_list_path": "1036611.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaSpAg1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. Ag1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpAg1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1524467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1524467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1524467.clusters.proteins.v11.5.txt",
		        "sequence_path": "1524467.protein.sequences.v11.5.fa",
		        "enrichment_path": "1524467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1524467.protein.info.v11.5.txt",
		        "node_list_path": "1524467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1524467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24023Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_40_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24023Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618816.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618816.protein.info.v11.5.txt",
		        "node_list_path": "1618816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NaumovozymaDairenensisCbs421(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma dairenensis CBS 421 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NaumovozymaDairenensisCbs421", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071378.protein.info.v11.5.txt",
		        "node_list_path": "1071378.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasLipolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas lipolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasLipolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1856405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1856405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1856405.protein.info.v11.5.txt",
		        "node_list_path": "1856405.protein.complete.v11.5.txt"
		    }
		]
    )()

def GryllotalpicolaGinsengisoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gryllotalpicola ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GryllotalpicolaGinsengisoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121372.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121372.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121372.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121372.protein.info.v11.5.txt",
		        "node_list_path": "1121372.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121372.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaSpAs16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. AS16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaSpAs16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936589.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936589.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936589.clusters.proteins.v11.5.txt",
		        "sequence_path": "936589.protein.sequences.v11.5.fa",
		        "enrichment_path": "936589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936589.protein.info.v11.5.txt",
		        "node_list_path": "936589.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936589.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusShackletoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus shackletonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusShackletoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "157838.clusters.info.v11.5.txt",
		        "cluster_tree_path": "157838.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "157838.clusters.proteins.v11.5.txt",
		        "sequence_path": "157838.protein.sequences.v11.5.fa",
		        "enrichment_path": "157838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157838.protein.info.v11.5.txt",
		        "node_list_path": "157838.cluster.nodes.v11.5.txt",
		        "edge_list_path": "157838.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrancourtellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drancourtella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrancourtellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1632013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1632013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1632013.clusters.proteins.v11.5.txt",
		        "sequence_path": "1632013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1632013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1632013.protein.info.v11.5.txt",
		        "node_list_path": "1632013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1632013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeobacterPorticola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter porticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterPorticola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1844006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1844006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1844006.protein.info.v11.5.txt",
		        "node_list_path": "1844006.protein.complete.v11.5.txt"
		    }
		]
    )()

def OttowiaThiooxydansDsm14619Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ottowia thiooxydans DSM 14619 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OttowiaThiooxydansDsm14619Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122623.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122623.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122623.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122623.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122623.protein.info.v11.5.txt",
		        "node_list_path": "1122623.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122623.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxParadoxusEpsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax paradoxus EPS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxParadoxusEpsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "595537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "595537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "595537.clusters.proteins.v11.5.txt",
		        "sequence_path": "595537.protein.sequences.v11.5.fa",
		        "enrichment_path": "595537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595537.protein.info.v11.5.txt",
		        "node_list_path": "595537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "595537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumRifcsplowo201Full4613Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RIFCSPLOWO2_01_FULL_46_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumRifcsplowo201Full4613Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817750.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817750.protein.info.v11.5.txt",
		        "node_list_path": "1817750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpKp2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. Kp2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpKp2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123518.protein.info.v11.5.txt",
		        "node_list_path": "1123518.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeosporobacterSubterraneusDsm17957(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geosporobacter subterraneus DSM 17957 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeosporobacterSubterraneusDsm17957", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121919.protein.info.v11.5.txt",
		        "node_list_path": "1121919.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacterium13120cm3538(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_1_20CM_3_53_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacterium13120cm3538", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803431.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803431.protein.info.v11.5.txt",
		        "node_list_path": "1803431.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArsukibacteriumSpMj3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arsukibacterium sp. MJ3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArsukibacteriumSpMj3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1632859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1632859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1632859.clusters.proteins.v11.5.txt",
		        "sequence_path": "1632859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1632859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1632859.protein.info.v11.5.txt",
		        "node_list_path": "1632859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1632859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaCrocodyliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma crocodyli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaCrocodyliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "512564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "512564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "512564.clusters.proteins.v11.5.txt",
		        "sequence_path": "512564.protein.sequences.v11.5.fa",
		        "enrichment_path": "512564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512564.protein.info.v11.5.txt",
		        "node_list_path": "512564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "512564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu070(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU070 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu070", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671655.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671655.protein.info.v11.5.txt",
		        "node_list_path": "1671655.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsphigho212Full4422(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_12_FULL_44_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho212Full4422", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798342.protein.info.v11.5.txt",
		        "node_list_path": "1798342.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumSpAk22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium sp. AK22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumSpAk22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229520.protein.info.v11.5.txt",
		        "node_list_path": "1229520.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusWeihaiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus weihaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusWeihaiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1547283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1547283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1547283.protein.info.v11.5.txt",
		        "node_list_path": "1547283.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloplasmaContractile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloplasma contractile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloplasmaContractile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033810.protein.info.v11.5.txt",
		        "node_list_path": "1033810.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaVietnamiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia vietnamiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaVietnamiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "269482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "269482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "269482.clusters.proteins.v11.5.txt",
		        "sequence_path": "269482.protein.sequences.v11.5.fa",
		        "enrichment_path": "269482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269482.protein.info.v11.5.txt",
		        "node_list_path": "269482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "269482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaStewartii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea stewartii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaStewartii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66269.protein.sequences.v11.5.fa",
		        "enrichment_path": "66269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66269.protein.info.v11.5.txt",
		        "node_list_path": "66269.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenopusLaevis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenopus laevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenopusLaevis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8355.protein.sequences.v11.5.fa",
		        "enrichment_path": "8355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8355.protein.info.v11.5.txt",
		        "node_list_path": "8355.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc136108(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_36_108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc136108", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618894.protein.info.v11.5.txt",
		        "node_list_path": "1618894.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaenispirillumSalinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caenispirillum salinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenispirillumSalinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1238182.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1238182.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1238182.clusters.proteins.v11.5.txt",
		        "sequence_path": "1238182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238182.protein.info.v11.5.txt",
		        "node_list_path": "1238182.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1238182.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFlorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus florum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFlorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1221537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1221537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1221537.protein.info.v11.5.txt",
		        "node_list_path": "1221537.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioTubiashiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio tubiashii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioTubiashiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1051646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1051646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1051646.clusters.proteins.v11.5.txt",
		        "sequence_path": "1051646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051646.protein.info.v11.5.txt",
		        "node_list_path": "1051646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1051646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethermicoccusShengliensisDsm18856Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methermicoccus shengliensis DSM 18856 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethermicoccusShengliensisDsm18856Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122233.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122233.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122233.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122233.protein.info.v11.5.txt",
		        "node_list_path": "1122233.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122233.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapsasporaOwczarzaki(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capsaspora owczarzaki graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsasporaOwczarzaki", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "192875.protein.sequences.v11.5.fa",
		        "enrichment_path": "192875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192875.protein.info.v11.5.txt",
		        "node_list_path": "192875.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrancisellaSpMa067296(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella sp. MA067296 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaSpMa067296", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "475375.protein.sequences.v11.5.fa",
		        "enrichment_path": "475375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "475375.protein.info.v11.5.txt",
		        "node_list_path": "475375.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetragenococcusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetragenococcus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetragenococcusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "945021.protein.sequences.v11.5.fa",
		        "enrichment_path": "945021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "945021.protein.info.v11.5.txt",
		        "node_list_path": "945021.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacteraceaeBacteriumGwc25844Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_58_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacteraceaeBacteriumGwc25844Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798318.protein.info.v11.5.txt",
		        "node_list_path": "1798318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwa13330Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_33_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa13330Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618542.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618542.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618542.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618542.protein.info.v11.5.txt",
		        "node_list_path": "1618542.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618542.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SegniliparusRotundus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Segniliparus rotundus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SegniliparusRotundus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "640132.protein.sequences.v11.5.fa",
		        "enrichment_path": "640132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640132.protein.info.v11.5.txt",
		        "node_list_path": "640132.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCsiVCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CSI-V Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCsiVCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1933777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1933777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1933777.clusters.proteins.v11.5.txt",
		        "sequence_path": "1933777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933777.protein.info.v11.5.txt",
		        "node_list_path": "1933777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1933777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylovorusSpMm2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylovorus sp. MM2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylovorusSpMm2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1848038.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848038.protein.info.v11.5.txt",
		        "node_list_path": "1848038.protein.complete.v11.5.txt"
		    }
		]
    )()

def MuricaudaSpCp2aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Muricauda sp. CP2A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuricaudaSpCp2aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1848189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1848189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1848189.clusters.proteins.v11.5.txt",
		        "sequence_path": "1848189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848189.protein.info.v11.5.txt",
		        "node_list_path": "1848189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1848189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicoccusLuteusDsm17002Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus luteus DSM 17002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusLuteusDsm17002Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123233.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123233.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123233.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123233.protein.info.v11.5.txt",
		        "node_list_path": "1123233.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123233.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicycliphilusDenitrificansBcCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans BC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicycliphilusDenitrificansBcCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596153.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596153.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596153.clusters.proteins.v11.5.txt",
		        "sequence_path": "596153.protein.sequences.v11.5.fa",
		        "enrichment_path": "596153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596153.protein.info.v11.5.txt",
		        "node_list_path": "596153.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596153.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24721(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_47_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24721", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618843.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618843.protein.info.v11.5.txt",
		        "node_list_path": "1618843.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusInfantariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusInfantariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1069533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1069533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1069533.clusters.proteins.v11.5.txt",
		        "sequence_path": "1069533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069533.protein.info.v11.5.txt",
		        "node_list_path": "1069533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1069533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusLindneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus lindneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusLindneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53444.clusters.proteins.v11.5.txt",
		        "sequence_path": "53444.protein.sequences.v11.5.fa",
		        "enrichment_path": "53444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53444.protein.info.v11.5.txt",
		        "node_list_path": "53444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033730.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033730.protein.info.v11.5.txt",
		        "node_list_path": "1033730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CylindrobasidiumTorrendiiFp15055Ss10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cylindrobasidium torrendii FP15055 ss-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CylindrobasidiumTorrendiiFp15055Ss10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314674.protein.info.v11.5.txt",
		        "node_list_path": "1314674.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumLavalense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] lavalense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumLavalense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "460384.protein.sequences.v11.5.fa",
		        "enrichment_path": "460384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "460384.protein.info.v11.5.txt",
		        "node_list_path": "460384.protein.complete.v11.5.txt"
		    }
		]
    )()

def SmittiumSimulii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Smittium simulii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmittiumSimulii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "133385.protein.sequences.v11.5.fa",
		        "enrichment_path": "133385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133385.protein.info.v11.5.txt",
		        "node_list_path": "133385.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpUrhd0024(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. URHD0024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpUrhd0024", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1302620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302620.protein.info.v11.5.txt",
		        "node_list_path": "1302620.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermithiobacillusTepidarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermithiobacillus tepidarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermithiobacillusTepidarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123368.protein.info.v11.5.txt",
		        "node_list_path": "1123368.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpIso805nCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Iso805N Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpIso805nCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1283287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1283287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1283287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1283287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283287.protein.info.v11.5.txt",
		        "node_list_path": "1283287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1283287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBrennerbacteriaBacteriumRifoxyd1Full4116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brennerbacteria bacterium RIFOXYD1_FULL_41_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBrennerbacteriaBacteriumRifoxyd1Full4116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797529.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797529.protein.info.v11.5.txt",
		        "node_list_path": "1797529.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusPrevotiiDsm20548(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus prevotii DSM20548 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusPrevotiiDsm20548", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525919.protein.sequences.v11.5.fa",
		        "enrichment_path": "525919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525919.protein.info.v11.5.txt",
		        "node_list_path": "525919.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptobacillusMoniliformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptobacillus moniliformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptobacillusMoniliformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "519441.clusters.info.v11.5.txt",
		        "cluster_tree_path": "519441.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "519441.clusters.proteins.v11.5.txt",
		        "sequence_path": "519441.protein.sequences.v11.5.fa",
		        "enrichment_path": "519441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519441.protein.info.v11.5.txt",
		        "node_list_path": "519441.cluster.nodes.v11.5.txt",
		        "edge_list_path": "519441.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3925(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3925", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802521.protein.info.v11.5.txt",
		        "node_list_path": "1802521.protein.complete.v11.5.txt"
		    }
		]
    )()

def EggerthellaLenta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eggerthella lenta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthellaLenta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "479437.protein.sequences.v11.5.fa",
		        "enrichment_path": "479437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479437.protein.info.v11.5.txt",
		        "node_list_path": "479437.protein.complete.v11.5.txt"
		    }
		]
    )()

def FulvimarinaPelagiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fulvimarina pelagi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FulvimarinaPelagiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314231.clusters.proteins.v11.5.txt",
		        "sequence_path": "314231.protein.sequences.v11.5.fa",
		        "enrichment_path": "314231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314231.protein.info.v11.5.txt",
		        "node_list_path": "314231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasOtitidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas otitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasOtitidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "319939.clusters.info.v11.5.txt",
		        "cluster_tree_path": "319939.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "319939.clusters.proteins.v11.5.txt",
		        "sequence_path": "319939.protein.sequences.v11.5.fa",
		        "enrichment_path": "319939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319939.protein.info.v11.5.txt",
		        "node_list_path": "319939.cluster.nodes.v11.5.txt",
		        "edge_list_path": "319939.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPortieraAleyrodidarumTv(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portiera aleyrodidarum TV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPortieraAleyrodidarumTv", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1297582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297582.protein.info.v11.5.txt",
		        "node_list_path": "1297582.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasCampestrisCampestris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Xanthomonas campestris campestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCampestrisCampestris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "340.protein.sequences.v11.0.fa",
		        "enrichment_path": "340.protein.enrichment.terms.v11.0.txt",
		        "info_path": "340.protein.info.v11.0.txt",
		        "node_list_path": "340.protein.complete.v11.0.txt"
		    }
		]
    )()

def GeobacillusSpLemmy01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. LEMMY01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusSpLemmy01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1954237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1954237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1954237.clusters.proteins.v11.5.txt",
		        "sequence_path": "1954237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1954237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1954237.protein.info.v11.5.txt",
		        "node_list_path": "1954237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1954237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KtedonobacterSp13120cm45311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ktedonobacter sp. 13_1_20CM_4_53_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KtedonobacterSp13120cm45311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805225.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805225.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805225.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805225.protein.info.v11.5.txt",
		        "node_list_path": "1805225.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805225.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAmbofaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces ambofaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAmbofaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1889.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1889.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1889.clusters.proteins.v11.5.txt",
		        "sequence_path": "1889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889.protein.info.v11.5.txt",
		        "node_list_path": "1889.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1889.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NiabellaSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Niabella soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiabellaSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "929713.protein.sequences.v11.5.fa",
		        "enrichment_path": "929713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929713.protein.info.v11.5.txt",
		        "node_list_path": "929713.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwc14615(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWC1_46_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwc14615", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618526.protein.info.v11.5.txt",
		        "node_list_path": "1618526.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaPecorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pecorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaPecorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "331635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "331635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "331635.clusters.proteins.v11.5.txt",
		        "sequence_path": "331635.protein.sequences.v11.5.fa",
		        "enrichment_path": "331635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331635.protein.info.v11.5.txt",
		        "node_list_path": "331635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "331635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807735.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807735.protein.info.v11.5.txt",
		        "node_list_path": "1807735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LasiusNigerCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lasius niger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LasiusNigerCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67767.clusters.proteins.v11.5.txt",
		        "sequence_path": "67767.protein.sequences.v11.5.fa",
		        "enrichment_path": "67767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67767.protein.info.v11.5.txt",
		        "node_list_path": "67767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1689271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1689271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1689271.protein.info.v11.5.txt",
		        "node_list_path": "1689271.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNe2001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NE2001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNe2001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520823.protein.info.v11.5.txt",
		        "node_list_path": "1520823.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesPsychrotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesPsychrotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005945.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005945.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005945.protein.info.v11.5.txt",
		        "node_list_path": "1005945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusLonarensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus lonarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLonarensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1464122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1464122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1464122.protein.info.v11.5.txt",
		        "node_list_path": "1464122.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumFrisingense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum frisingense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumFrisingense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "864073.protein.sequences.v11.5.fa",
		        "enrichment_path": "864073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864073.protein.info.v11.5.txt",
		        "node_list_path": "864073.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorhodospiraHalochlorisStrACluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorhodospira halochloris str. A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorhodospiraHalochlorisStrACluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354791.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354791.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354791.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354791.protein.info.v11.5.txt",
		        "node_list_path": "1354791.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354791.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaGlumaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia glumae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaGlumaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "626418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "626418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "626418.clusters.proteins.v11.5.txt",
		        "sequence_path": "626418.protein.sequences.v11.5.fa",
		        "enrichment_path": "626418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626418.protein.info.v11.5.txt",
		        "node_list_path": "626418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "626418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpKpl1860(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1860 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpKpl1860", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203567.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203567.protein.info.v11.5.txt",
		        "node_list_path": "1203567.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchmidhempeliaBombi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schmidhempelia bombi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchmidhempeliaBombi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1387197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387197.protein.info.v11.5.txt",
		        "node_list_path": "1387197.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryziasMelastigmaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryzias melastigma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryziasMelastigmaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "30732.clusters.info.v11.5.txt",
		        "cluster_tree_path": "30732.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "30732.clusters.proteins.v11.5.txt",
		        "sequence_path": "30732.protein.sequences.v11.5.fa",
		        "enrichment_path": "30732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30732.protein.info.v11.5.txt",
		        "node_list_path": "30732.cluster.nodes.v11.5.txt",
		        "edge_list_path": "30732.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRoot240(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root240 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRoot240", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736500.protein.info.v11.5.txt",
		        "node_list_path": "1736500.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSpAl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. AL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSpAl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "861530.clusters.info.v11.5.txt",
		        "cluster_tree_path": "861530.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "861530.clusters.proteins.v11.5.txt",
		        "sequence_path": "861530.protein.sequences.v11.5.fa",
		        "enrichment_path": "861530.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861530.protein.info.v11.5.txt",
		        "node_list_path": "861530.cluster.nodes.v11.5.txt",
		        "edge_list_path": "861530.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumCopahuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum copahuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumCopahuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1838280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1838280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1838280.protein.info.v11.5.txt",
		        "node_list_path": "1838280.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomycesCerevisiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomyces cerevisiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomycesCerevisiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4932.protein.sequences.v11.5.fa",
		        "enrichment_path": "4932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4932.protein.info.v11.5.txt",
		        "node_list_path": "4932.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumYl45(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium YL45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumYl45", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834205.protein.info.v11.5.txt",
		        "node_list_path": "1834205.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpLeaf69(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf69 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpLeaf69", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736232.protein.info.v11.5.txt",
		        "node_list_path": "1736232.protein.complete.v11.5.txt"
		    }
		]
    )()

def CobetiaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cobetia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CobetiaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28258.protein.sequences.v11.5.fa",
		        "enrichment_path": "28258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28258.protein.info.v11.5.txt",
		        "node_list_path": "28258.protein.complete.v11.5.txt"
		    }
		]
    )()

def CicerArietinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cicer arietinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CicerArietinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3827.clusters.proteins.v11.5.txt",
		        "sequence_path": "3827.protein.sequences.v11.5.fa",
		        "enrichment_path": "3827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3827.protein.info.v11.5.txt",
		        "node_list_path": "3827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoccidioidesImmitisRmscc2394Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis RMSCC 2394 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesImmitisRmscc2394Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "404692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "404692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "404692.clusters.proteins.v11.5.txt",
		        "sequence_path": "404692.protein.sequences.v11.5.fa",
		        "enrichment_path": "404692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "404692.protein.info.v11.5.txt",
		        "node_list_path": "404692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "404692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCihuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cihuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCihuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208599.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208599.protein.info.v11.5.txt",
		        "node_list_path": "1208599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterSpGwa24521(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. GWA2_45_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterSpGwa24521", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801989.protein.info.v11.5.txt",
		        "node_list_path": "1801989.protein.complete.v11.5.txt"
		    }
		]
    )()

def OreochromisNiloticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oreochromis niloticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OreochromisNiloticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8128.protein.sequences.v11.5.fa",
		        "enrichment_path": "8128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8128.protein.info.v11.5.txt",
		        "node_list_path": "8128.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacteraceaeBacterium4484166(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacteraceae bacterium 4484_166 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacteraceaeBacterium4484166", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1956165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1956165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1956165.protein.info.v11.5.txt",
		        "node_list_path": "1956165.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaballeroniaTurbansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia turbans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaTurbansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777134.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777134.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777134.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777134.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777134.protein.info.v11.5.txt",
		        "node_list_path": "1777134.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777134.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwf23566(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWF2_35_66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwf23566", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618773.protein.info.v11.5.txt",
		        "node_list_path": "1618773.protein.complete.v11.5.txt"
		    }
		]
    )()

def DebaryomycesHanseniiCbs767(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Debaryomyces hansenii CBS767 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DebaryomycesHanseniiCbs767", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "284592.protein.sequences.v11.5.fa",
		        "enrichment_path": "284592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284592.protein.info.v11.5.txt",
		        "node_list_path": "284592.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaFrederikseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia frederiksenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaFrederikseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349966.clusters.proteins.v11.5.txt",
		        "sequence_path": "349966.protein.sequences.v11.5.fa",
		        "enrichment_path": "349966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349966.protein.info.v11.5.txt",
		        "node_list_path": "349966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacterSpSw2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter sp. SW2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterSpSw2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "371731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "371731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "371731.clusters.proteins.v11.5.txt",
		        "sequence_path": "371731.protein.sequences.v11.5.fa",
		        "enrichment_path": "371731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "371731.protein.info.v11.5.txt",
		        "node_list_path": "371731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "371731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPullorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma pullorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPullorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "48003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "48003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "48003.clusters.proteins.v11.5.txt",
		        "sequence_path": "48003.protein.sequences.v11.5.fa",
		        "enrichment_path": "48003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48003.protein.info.v11.5.txt",
		        "node_list_path": "48003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "48003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusSp9402080(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. 9402080 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusSp9402080", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "938293.protein.sequences.v11.5.fa",
		        "enrichment_path": "938293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938293.protein.info.v11.5.txt",
		        "node_list_path": "938293.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisSaalfeldensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis saalfeldensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisSaalfeldensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "394193.clusters.info.v11.5.txt",
		        "cluster_tree_path": "394193.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "394193.clusters.proteins.v11.5.txt",
		        "sequence_path": "394193.protein.sequences.v11.5.fa",
		        "enrichment_path": "394193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394193.protein.info.v11.5.txt",
		        "node_list_path": "394193.cluster.nodes.v11.5.txt",
		        "edge_list_path": "394193.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioSplendidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio splendidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSplendidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "617140.protein.sequences.v11.5.fa",
		        "enrichment_path": "617140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "617140.protein.info.v11.5.txt",
		        "node_list_path": "617140.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaBovisM02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bovis m02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaBovisM02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094492.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094492.protein.info.v11.5.txt",
		        "node_list_path": "1094492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoritellaSpJt01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moritella sp. JT01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoritellaSpJt01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "756698.protein.sequences.v11.5.fa",
		        "enrichment_path": "756698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "756698.protein.info.v11.5.txt",
		        "node_list_path": "756698.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4716bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_47_16b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4716bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802142.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802142.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802142.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802142.protein.info.v11.5.txt",
		        "node_list_path": "1802142.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802142.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanibacterHoyleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janibacter hoylei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterHoyleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210046.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210046.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210046.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210046.protein.info.v11.5.txt",
		        "node_list_path": "1210046.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210046.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XiphophorusMaculatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xiphophorus maculatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XiphophorusMaculatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8083.protein.sequences.v11.5.fa",
		        "enrichment_path": "8083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8083.protein.info.v11.5.txt",
		        "node_list_path": "8083.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusFujiensisJcm16395Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus fujiensis JCM 16395 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusFujiensisJcm16395Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1291764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1291764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1291764.clusters.proteins.v11.5.txt",
		        "sequence_path": "1291764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291764.protein.info.v11.5.txt",
		        "node_list_path": "1291764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1291764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpCf614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. CF614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpCf614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884364.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884364.protein.info.v11.5.txt",
		        "node_list_path": "1884364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFutsaiiJcm17355(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus futsaii JCM 17355 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFutsaiiJcm17355", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423818.protein.info.v11.5.txt",
		        "node_list_path": "1423818.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumChlorophytiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum chlorophyti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumChlorophytiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "708187.clusters.info.v11.5.txt",
		        "cluster_tree_path": "708187.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "708187.clusters.proteins.v11.5.txt",
		        "sequence_path": "708187.protein.sequences.v11.5.fa",
		        "enrichment_path": "708187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "708187.protein.info.v11.5.txt",
		        "node_list_path": "708187.cluster.nodes.v11.5.txt",
		        "edge_list_path": "708187.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HoefleaSpBrhC9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hoeflea sp. BRH_c9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoefleaSpBrhC9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629712.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629712.protein.info.v11.5.txt",
		        "node_list_path": "1629712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EndosymbiontOfUnidentifiedScalySnailIsolateMonju(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of unidentified scaly snail isolate Monju graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndosymbiontOfUnidentifiedScalySnailIsolateMonju", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1248727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1248727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1248727.protein.info.v11.5.txt",
		        "node_list_path": "1248727.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrueperaRadiovictrixCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Truepera radiovictrix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrueperaRadiovictrixCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649638.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649638.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649638.clusters.proteins.v11.5.txt",
		        "sequence_path": "649638.protein.sequences.v11.5.fa",
		        "enrichment_path": "649638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649638.protein.info.v11.5.txt",
		        "node_list_path": "649638.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649638.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPhaeomarinobacterEctocarpi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phaeomarinobacter ectocarpi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPhaeomarinobacterEctocarpi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1458461.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458461.protein.info.v11.5.txt",
		        "node_list_path": "1458461.protein.complete.v11.5.txt"
		    }
		]
    )()

def GluconobacterOxydans621h(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans 621H graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterOxydans621h", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290633.protein.sequences.v11.5.fa",
		        "enrichment_path": "290633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290633.protein.info.v11.5.txt",
		        "node_list_path": "290633.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterSkirrowiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter skirrowii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSkirrowiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28200.clusters.proteins.v11.5.txt",
		        "sequence_path": "28200.protein.sequences.v11.5.fa",
		        "enrichment_path": "28200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28200.protein.info.v11.5.txt",
		        "node_list_path": "28200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifoxyc2Full4719(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYC2_FULL_47_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyc2Full4719", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802424.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802424.protein.info.v11.5.txt",
		        "node_list_path": "1802424.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalimicrobiumCyclicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalimicrobium cyclicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalimicrobiumCyclicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717773.protein.sequences.v11.5.fa",
		        "enrichment_path": "717773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717773.protein.info.v11.5.txt",
		        "node_list_path": "717773.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaFryxellensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella fryxellensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaFryxellensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "245187.clusters.info.v11.5.txt",
		        "cluster_tree_path": "245187.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "245187.clusters.proteins.v11.5.txt",
		        "sequence_path": "245187.protein.sequences.v11.5.fa",
		        "enrichment_path": "245187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "245187.protein.info.v11.5.txt",
		        "node_list_path": "245187.cluster.nodes.v11.5.txt",
		        "edge_list_path": "245187.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpO77Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. O-77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpO77Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1080068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1080068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1080068.clusters.proteins.v11.5.txt",
		        "sequence_path": "1080068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1080068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1080068.protein.info.v11.5.txt",
		        "node_list_path": "1080068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1080068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpNies2104Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. NIES-2104 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpNies2104Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1552121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1552121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1552121.clusters.proteins.v11.5.txt",
		        "sequence_path": "1552121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1552121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1552121.protein.info.v11.5.txt",
		        "node_list_path": "1552121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1552121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsSinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsSinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "72228.protein.sequences.v11.5.fa",
		        "enrichment_path": "72228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72228.protein.info.v11.5.txt",
		        "node_list_path": "72228.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaSpF0557Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. F0557 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaSpF0557Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227268.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227268.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227268.protein.info.v11.5.txt",
		        "node_list_path": "1227268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanibacterSpSoil728(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janibacter sp. Soil728 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterSpSoil728", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736393.protein.info.v11.5.txt",
		        "node_list_path": "1736393.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfacinumHydrothermaleDsm13146(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfacinum hydrothermale DSM 13146 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfacinumHydrothermaleDsm13146", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121390.protein.info.v11.5.txt",
		        "node_list_path": "1121390.protein.complete.v11.5.txt"
		    }
		]
    )()

def FenollariaTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fenollaria timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FenollariaTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1723384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1723384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1723384.clusters.proteins.v11.5.txt",
		        "sequence_path": "1723384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1723384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1723384.protein.info.v11.5.txt",
		        "node_list_path": "1723384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1723384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColi536Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli 536 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColi536Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "362663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "362663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "362663.clusters.proteins.v11.5.txt",
		        "sequence_path": "362663.protein.sequences.v11.5.fa",
		        "enrichment_path": "362663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362663.protein.info.v11.5.txt",
		        "node_list_path": "362663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "362663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EutremaSalsugineum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eutrema salsugineum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EutremaSalsugineum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "72664.protein.sequences.v11.5.fa",
		        "enrichment_path": "72664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72664.protein.info.v11.5.txt",
		        "node_list_path": "72664.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full4515(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_45_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full4515", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798649.protein.info.v11.5.txt",
		        "node_list_path": "1798649.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumCg10264396(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium CG1_02_64_396 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumCg10264396", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805333.protein.info.v11.5.txt",
		        "node_list_path": "1805333.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag488Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:488 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag488Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262959.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262959.protein.info.v11.5.txt",
		        "node_list_path": "1262959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpMm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. MM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpMm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "745310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "745310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "745310.clusters.proteins.v11.5.txt",
		        "sequence_path": "745310.protein.sequences.v11.5.fa",
		        "enrichment_path": "745310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745310.protein.info.v11.5.txt",
		        "node_list_path": "745310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "745310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674846.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674846.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674846.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674846.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674846.protein.info.v11.5.txt",
		        "node_list_path": "1674846.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674846.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaBpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Bp Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaBpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "224915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "224915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "224915.clusters.proteins.v11.5.txt",
		        "sequence_path": "224915.protein.sequences.v11.5.fa",
		        "enrichment_path": "224915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224915.protein.info.v11.5.txt",
		        "node_list_path": "224915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "224915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_33_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802210.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802210.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802210.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802210.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802210.protein.info.v11.5.txt",
		        "node_list_path": "1802210.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802210.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNealsonbacteriaBacteriumRifcsplowo201Full4332(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFCSPLOWO2_01_FULL_43_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifcsplowo201Full4332", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801672.protein.info.v11.5.txt",
		        "node_list_path": "1801672.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaFerrariaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia ferrariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaFerrariaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218076.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218076.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218076.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218076.protein.info.v11.5.txt",
		        "node_list_path": "1218076.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218076.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HypoxylonSpCo275Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hypoxylon sp. CO27-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HypoxylonSpCo275Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1001938.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1001938.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1001938.clusters.proteins.v11.5.txt",
		        "sequence_path": "1001938.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001938.protein.info.v11.5.txt",
		        "node_list_path": "1001938.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1001938.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DechloromonasAromatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dechloromonas aromatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DechloromonasAromatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "159087.protein.sequences.v11.5.fa",
		        "enrichment_path": "159087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "159087.protein.info.v11.5.txt",
		        "node_list_path": "159087.protein.complete.v11.5.txt"
		    }
		]
    )()

def ApteryxHaastii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Apteryx haastii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApteryxHaastii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8823.protein.sequences.v11.5.fa",
		        "enrichment_path": "8823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8823.protein.info.v11.5.txt",
		        "node_list_path": "8823.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaWadei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia wadei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaWadei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888055.protein.sequences.v11.5.fa",
		        "enrichment_path": "888055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888055.protein.info.v11.5.txt",
		        "node_list_path": "888055.protein.complete.v11.5.txt"
		    }
		]
    )()

def BelliellaPelovolcani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Belliella pelovolcani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BelliellaPelovolcani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "529505.protein.sequences.v11.5.fa",
		        "enrichment_path": "529505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529505.protein.info.v11.5.txt",
		        "node_list_path": "529505.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAccolensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium accolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAccolensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525260.clusters.proteins.v11.5.txt",
		        "sequence_path": "525260.protein.sequences.v11.5.fa",
		        "enrichment_path": "525260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525260.protein.info.v11.5.txt",
		        "node_list_path": "525260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ModestobacterSpDsm44400(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Modestobacter sp. DSM 44400 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ModestobacterSpDsm44400", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1550230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550230.protein.info.v11.5.txt",
		        "node_list_path": "1550230.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifcsphigho201Full5431(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_01_FULL_54_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho201Full5431", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801637.protein.info.v11.5.txt",
		        "node_list_path": "1801637.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrovirgaAerilataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microvirga aerilata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaAerilataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "670292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "670292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "670292.clusters.proteins.v11.5.txt",
		        "sequence_path": "670292.protein.sequences.v11.5.fa",
		        "enrichment_path": "670292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670292.protein.info.v11.5.txt",
		        "node_list_path": "670292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "670292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzohydromonasAustralicaDsm1124(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azohydromonas australica DSM 1124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzohydromonasAustralicaDsm1124", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121030.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121030.protein.info.v11.5.txt",
		        "node_list_path": "1121030.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterDuraquae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter duraquae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterDuraquae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1835254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1835254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1835254.protein.info.v11.5.txt",
		        "node_list_path": "1835254.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpHiyo8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Hiyo8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpHiyo8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1588023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1588023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1588023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1588023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588023.protein.info.v11.5.txt",
		        "node_list_path": "1588023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1588023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitratiruptorTergarcusDsm16512(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitratiruptor tergarcus DSM 16512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratiruptorTergarcusDsm16512", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1069081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069081.protein.info.v11.5.txt",
		        "node_list_path": "1069081.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeisingeraCaerulea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leisingera caerulea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraCaerulea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999549.protein.sequences.v11.5.fa",
		        "enrichment_path": "999549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999549.protein.info.v11.5.txt",
		        "node_list_path": "999549.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalanaerobiumCongolenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halanaerobium congolense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaerobiumCongolenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "54121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "54121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "54121.clusters.proteins.v11.5.txt",
		        "sequence_path": "54121.protein.sequences.v11.5.fa",
		        "enrichment_path": "54121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54121.protein.info.v11.5.txt",
		        "node_list_path": "54121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "54121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StachybotrysChlorohalonataIbt40285(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stachybotrys chlorohalonata IBT 40285 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StachybotrysChlorohalonataIbt40285", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1283841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283841.protein.info.v11.5.txt",
		        "node_list_path": "1283841.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaRettgeriDmel1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Providencia rettgeri Dmel1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaRettgeriDmel1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1141663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141663.protein.info.v11.5.txt",
		        "node_list_path": "1141663.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureispiraSpCcbqb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureispira sp. CCBQB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureispiraSpCcbqb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1313421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1313421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1313421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1313421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313421.protein.info.v11.5.txt",
		        "node_list_path": "1313421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1313421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesTimonensisJc136(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes timonensis JC136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesTimonensisJc136", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033731.protein.info.v11.5.txt",
		        "node_list_path": "1033731.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasGulae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gulae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasGulae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "111105.protein.sequences.v11.5.fa",
		        "enrichment_path": "111105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "111105.protein.info.v11.5.txt",
		        "node_list_path": "111105.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusCohniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus cohnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusCohniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29382.clusters.proteins.v11.5.txt",
		        "sequence_path": "29382.protein.sequences.v11.5.fa",
		        "enrichment_path": "29382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29382.protein.info.v11.5.txt",
		        "node_list_path": "29382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidiphiliumAngustum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidiphilium angustum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidiphiliumAngustum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408418.protein.info.v11.5.txt",
		        "node_list_path": "1408418.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyadobacterCrusticolaDsm16708(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter crusticola DSM 16708 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterCrusticolaDsm16708", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121483.protein.info.v11.5.txt",
		        "node_list_path": "1121483.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaAnaemiaeNbrc100462Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia anaemiae NBRC 100462 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAnaemiaeNbrc100462Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210065.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210065.protein.info.v11.5.txt",
		        "node_list_path": "1210065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CycloclasticusSpSymbiontOfBathymodiolusHeckeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Bathymodiolus heckerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CycloclasticusSpSymbiontOfBathymodiolusHeckeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1284675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1284675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1284675.clusters.proteins.v11.5.txt",
		        "sequence_path": "1284675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284675.protein.info.v11.5.txt",
		        "node_list_path": "1284675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1284675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliifodinibiusRoseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliifodinibius roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliifodinibiusRoseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1194090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1194090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1194090.clusters.proteins.v11.5.txt",
		        "sequence_path": "1194090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194090.protein.info.v11.5.txt",
		        "node_list_path": "1194090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1194090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonasMacleodiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasMacleodiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28108.clusters.proteins.v11.5.txt",
		        "sequence_path": "28108.protein.sequences.v11.5.fa",
		        "enrichment_path": "28108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28108.protein.info.v11.5.txt",
		        "node_list_path": "28108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacinutrixSp5h374Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix sp. 5H374 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixSp5h374Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983544.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983544.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983544.clusters.proteins.v11.5.txt",
		        "sequence_path": "983544.protein.sequences.v11.5.fa",
		        "enrichment_path": "983544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983544.protein.info.v11.5.txt",
		        "node_list_path": "983544.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983544.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaCaviaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila caviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaCaviaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "227941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "227941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "227941.clusters.proteins.v11.5.txt",
		        "sequence_path": "227941.protein.sequences.v11.5.fa",
		        "enrichment_path": "227941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227941.protein.info.v11.5.txt",
		        "node_list_path": "227941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "227941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasAsaccharolyticaNbrc15499(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas asaccharolytica NBRC 15499 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasAsaccharolyticaNbrc15499", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219040.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219040.protein.info.v11.5.txt",
		        "node_list_path": "1219040.protein.complete.v11.5.txt"
		    }
		]
    )()

def MastigocladusLaminosusUu774(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mastigocladus laminosus UU774 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MastigocladusLaminosusUu774", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1594576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1594576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1594576.protein.info.v11.5.txt",
		        "node_list_path": "1594576.protein.complete.v11.5.txt"
		    }
		]
    )()

def NostocSpPcc7120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocSpPcc7120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "103690.protein.sequences.v11.5.fa",
		        "enrichment_path": "103690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103690.protein.info.v11.5.txt",
		        "node_list_path": "103690.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusPiezophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus piezophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusPiezophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1712654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1712654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1712654.clusters.proteins.v11.5.txt",
		        "sequence_path": "1712654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1712654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1712654.protein.info.v11.5.txt",
		        "node_list_path": "1712654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1712654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrigoribacteriumSpLeaf172Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf172 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrigoribacteriumSpLeaf172Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736285.protein.info.v11.5.txt",
		        "node_list_path": "1736285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumNor53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium NOR53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumNor53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "566466.clusters.info.v11.0.txt",
		        "cluster_tree_path": "566466.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "566466.clusters.proteins.v11.0.txt",
		        "sequence_path": "566466.protein.sequences.v11.0.fa",
		        "enrichment_path": "566466.protein.enrichment.terms.v11.0.txt",
		        "info_path": "566466.protein.info.v11.0.txt",
		        "node_list_path": "566466.cluster.nodes.v11.0.txt",
		        "edge_list_path": "566466.protein.cluster.v11.0.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumDtu037Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium DTU037 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumDtu037Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671662.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671662.protein.info.v11.5.txt",
		        "node_list_path": "1671662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisSacchari(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisSacchari", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "115433.protein.sequences.v11.5.fa",
		        "enrichment_path": "115433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115433.protein.info.v11.5.txt",
		        "node_list_path": "115433.protein.complete.v11.5.txt"
		    }
		]
    )()

def YokenellaRegensburgeiAtcc43003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yokenella regensburgei ATCC 43003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YokenellaRegensburgeiAtcc43003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1002368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002368.protein.info.v11.5.txt",
		        "node_list_path": "1002368.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumRbg134015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_13_40_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg134015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802593.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802593.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802593.protein.info.v11.5.txt",
		        "node_list_path": "1802593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanisphaeraPsychrotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanisphaera psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanisphaeraPsychrotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1414654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1414654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1414654.clusters.proteins.v11.5.txt",
		        "sequence_path": "1414654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414654.protein.info.v11.5.txt",
		        "node_list_path": "1414654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1414654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrackiellaOedipodisDsm13743(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brackiella oedipodis DSM 13743 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrackiellaOedipodisDsm13743", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121118.protein.info.v11.5.txt",
		        "node_list_path": "1121118.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpVt162Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. VT 162 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpVt162Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1419814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1419814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1419814.clusters.proteins.v11.5.txt",
		        "sequence_path": "1419814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1419814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1419814.protein.info.v11.5.txt",
		        "node_list_path": "1419814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1419814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DehalococcoidesMccartyiVs(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi VS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalococcoidesMccartyiVs", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "311424.protein.sequences.v11.5.fa",
		        "enrichment_path": "311424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311424.protein.info.v11.5.txt",
		        "node_list_path": "311424.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxParadoxusS110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax paradoxus S110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxParadoxusS110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "543728.protein.sequences.v11.5.fa",
		        "enrichment_path": "543728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543728.protein.info.v11.5.txt",
		        "node_list_path": "543728.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitriliruptorAlkaliphilusDsm45188Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitriliruptor alkaliphilus DSM 45188 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitriliruptorAlkaliphilusDsm45188Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1069448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1069448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1069448.clusters.proteins.v11.5.txt",
		        "sequence_path": "1069448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069448.protein.info.v11.5.txt",
		        "node_list_path": "1069448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1069448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyxococcusSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcusSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1297742.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297742.protein.info.v11.5.txt",
		        "node_list_path": "1297742.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27251(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27251", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1684142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1684142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1684142.protein.info.v11.5.txt",
		        "node_list_path": "1684142.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterCinaediPagu611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi PAGU611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterCinaediPagu611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1172562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1172562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1172562.clusters.proteins.v11.5.txt",
		        "sequence_path": "1172562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172562.protein.info.v11.5.txt",
		        "node_list_path": "1172562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1172562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfofarcimenIntricatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfofarcimen intricatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfofarcimenIntricatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1285191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1285191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1285191.clusters.proteins.v11.5.txt",
		        "sequence_path": "1285191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1285191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1285191.protein.info.v11.5.txt",
		        "node_list_path": "1285191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1285191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasAcidaminiphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas acidaminiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasAcidaminiphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "128780.protein.sequences.v11.5.fa",
		        "enrichment_path": "128780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "128780.protein.info.v11.5.txt",
		        "node_list_path": "128780.protein.complete.v11.5.txt"
		    }
		]
    )()

def SedimentisphaeraCyanobacteriorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sedimentisphaera cyanobacteriorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SedimentisphaeraCyanobacteriorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1940790.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1940790.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1940790.clusters.proteins.v11.5.txt",
		        "sequence_path": "1940790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1940790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1940790.protein.info.v11.5.txt",
		        "node_list_path": "1940790.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1940790.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5719Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_57_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5719Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802391.protein.info.v11.5.txt",
		        "node_list_path": "1802391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaW619Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida W619 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaW619Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "390235.clusters.info.v11.5.txt",
		        "cluster_tree_path": "390235.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "390235.clusters.proteins.v11.5.txt",
		        "sequence_path": "390235.protein.sequences.v11.5.fa",
		        "enrichment_path": "390235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390235.protein.info.v11.5.txt",
		        "node_list_path": "390235.cluster.nodes.v11.5.txt",
		        "edge_list_path": "390235.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LutimaribacterSaemankumensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lutimaribacter saemankumensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutimaribacterSaemankumensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "490829.clusters.info.v11.5.txt",
		        "cluster_tree_path": "490829.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "490829.clusters.proteins.v11.5.txt",
		        "sequence_path": "490829.protein.sequences.v11.5.fa",
		        "enrichment_path": "490829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "490829.protein.info.v11.5.txt",
		        "node_list_path": "490829.cluster.nodes.v11.5.txt",
		        "edge_list_path": "490829.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitritaleaHalalkaliphilaLw7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitritalea halalkaliphila LW7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitritaleaHalalkaliphilaLw7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1189621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1189621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1189621.protein.info.v11.5.txt",
		        "node_list_path": "1189621.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusAcidiphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus acidiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusAcidiphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "646529.clusters.info.v11.5.txt",
		        "cluster_tree_path": "646529.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "646529.clusters.proteins.v11.5.txt",
		        "sequence_path": "646529.protein.sequences.v11.5.fa",
		        "enrichment_path": "646529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "646529.protein.info.v11.5.txt",
		        "node_list_path": "646529.cluster.nodes.v11.5.txt",
		        "edge_list_path": "646529.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaMaltosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida maltosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaMaltosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5479.protein.sequences.v11.5.fa",
		        "enrichment_path": "5479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5479.protein.info.v11.5.txt",
		        "node_list_path": "5479.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogulbenkianiaSpNh8b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania sp. NH8B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogulbenkianiaSpNh8b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "748280.protein.sequences.v11.5.fa",
		        "enrichment_path": "748280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748280.protein.info.v11.5.txt",
		        "node_list_path": "748280.protein.complete.v11.5.txt"
		    }
		]
    )()

def GluconobacterAlbidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter albidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterAlbidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "318683.protein.sequences.v11.5.fa",
		        "enrichment_path": "318683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318683.protein.info.v11.5.txt",
		        "node_list_path": "318683.protein.complete.v11.5.txt"
		    }
		]
    )()

def GiesbergeriaAnulus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Giesbergeria anulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GiesbergeriaAnulus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "180197.protein.sequences.v11.5.fa",
		        "enrichment_path": "180197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180197.protein.info.v11.5.txt",
		        "node_list_path": "180197.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterovibrioCalviensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio calviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioCalviensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1190606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1190606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1190606.clusters.proteins.v11.5.txt",
		        "sequence_path": "1190606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1190606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1190606.protein.info.v11.5.txt",
		        "node_list_path": "1190606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1190606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0332(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0332 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0332", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649743.protein.sequences.v11.5.fa",
		        "enrichment_path": "649743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649743.protein.info.v11.5.txt",
		        "node_list_path": "649743.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterDaepoensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter daepoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterDaepoensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122197.protein.info.v11.5.txt",
		        "node_list_path": "1122197.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprinopsisCinerea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprinopsis cinerea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprinopsisCinerea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5346.protein.sequences.v11.5.fa",
		        "enrichment_path": "5346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5346.protein.info.v11.5.txt",
		        "node_list_path": "5346.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasSalmonicidaSubspMasoucidaNbrc13784(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. masoucida NBRC 13784 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSalmonicidaSubspMasoucidaNbrc13784", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216980.protein.info.v11.5.txt",
		        "node_list_path": "1216980.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerendipitaIndicaDsm11827(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serendipita indica DSM 11827 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerendipitaIndicaDsm11827", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1109443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1109443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1109443.protein.info.v11.5.txt",
		        "node_list_path": "1109443.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhycicoccusSpRoot563(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Root563 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycicoccusSpRoot563", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736562.protein.info.v11.5.txt",
		        "node_list_path": "1736562.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlautiaProductaAtcc27340Dsm2950Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia producta ATCC 27340 DSM 2950 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaProductaAtcc27340Dsm2950Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121114.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121114.protein.info.v11.5.txt",
		        "node_list_path": "1121114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumKa00344Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KA00344 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumKa00344Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1497954.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1497954.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1497954.clusters.proteins.v11.5.txt",
		        "sequence_path": "1497954.protein.sequences.v11.5.fa",
		        "enrichment_path": "1497954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1497954.protein.info.v11.5.txt",
		        "node_list_path": "1497954.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1497954.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AestuariivitaBoseongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aestuariivita boseongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AestuariivitaBoseongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1470562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1470562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1470562.clusters.proteins.v11.5.txt",
		        "sequence_path": "1470562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470562.protein.info.v11.5.txt",
		        "node_list_path": "1470562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1470562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumSpMb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium sp. MB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumSpMb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379702.protein.info.v11.5.txt",
		        "node_list_path": "1379702.protein.complete.v11.5.txt"
		    }
		]
    )()

def CupriavidusSpUsmaa24(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. USMAA2-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusSpUsmaa24", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "876364.protein.sequences.v11.5.fa",
		        "enrichment_path": "876364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "876364.protein.info.v11.5.txt",
		        "node_list_path": "876364.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumBranderiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium branderi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumBranderiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43348.clusters.proteins.v11.5.txt",
		        "sequence_path": "43348.protein.sequences.v11.5.fa",
		        "enrichment_path": "43348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43348.protein.info.v11.5.txt",
		        "node_list_path": "43348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacillusThermodenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus thermodenitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusThermodenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "420246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "420246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "420246.clusters.proteins.v11.5.txt",
		        "sequence_path": "420246.protein.sequences.v11.5.fa",
		        "enrichment_path": "420246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420246.protein.info.v11.5.txt",
		        "node_list_path": "420246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "420246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchistosomaMansoniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma mansoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaMansoniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6183.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6183.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6183.clusters.proteins.v11.5.txt",
		        "sequence_path": "6183.protein.sequences.v11.5.fa",
		        "enrichment_path": "6183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6183.protein.info.v11.5.txt",
		        "node_list_path": "6183.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6183.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConiosporiumApollinisCbs100218(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coniosporium apollinis CBS 100218 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConiosporiumApollinisCbs100218", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1168221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168221.protein.info.v11.5.txt",
		        "node_list_path": "1168221.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumC6a11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium C6A11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumC6a11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410622.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410622.protein.info.v11.5.txt",
		        "node_list_path": "1410622.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasYangmingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas yangmingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasYangmingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720063.protein.info.v11.5.txt",
		        "node_list_path": "1720063.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpN3c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. N3C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpN3c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776758.protein.info.v11.5.txt",
		        "node_list_path": "1776758.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusOvis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus ovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOvis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123312.protein.info.v11.5.txt",
		        "node_list_path": "1123312.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyberlindneraJadiniiNrrlY1542(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyberlindnera jadinii NRRL Y-1542 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyberlindneraJadiniiNrrlY1542", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983966.protein.sequences.v11.5.fa",
		        "enrichment_path": "983966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983966.protein.info.v11.5.txt",
		        "node_list_path": "983966.protein.complete.v11.5.txt"
		    }
		]
    )()

def WoeseiaOceani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Woeseia oceani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WoeseiaOceani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1548547.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548547.protein.info.v11.5.txt",
		        "node_list_path": "1548547.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesInsulaeDsm17944(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides insulae DSM 17944 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesInsulaeDsm17944", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122610.protein.info.v11.5.txt",
		        "node_list_path": "1122610.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1023713Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_37_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023713Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805302.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805302.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805302.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805302.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805302.protein.info.v11.5.txt",
		        "node_list_path": "1805302.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805302.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbiconiuxSolaniNbrc106740(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbiconiux solani NBRC 106740 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbiconiuxSolaniNbrc106740", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220584.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220584.protein.info.v11.5.txt",
		        "node_list_path": "1220584.protein.complete.v11.5.txt"
		    }
		]
    )()

def PasteurellaMultocidaSubspMultocidaOh4807Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida subsp. multocida OH4807 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaMultocidaSubspMultocidaOh4807Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304873.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304873.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304873.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304873.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304873.protein.info.v11.5.txt",
		        "node_list_path": "1304873.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304873.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomicrobiumAlcaliphilum20zCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomicrobium alcaliphilum 20Z Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomicrobiumAlcaliphilum20zCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1091494.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1091494.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1091494.clusters.proteins.v11.5.txt",
		        "sequence_path": "1091494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1091494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1091494.protein.info.v11.5.txt",
		        "node_list_path": "1091494.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1091494.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterAcetiAtcc23746(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter aceti ATCC23746 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterAcetiAtcc23746", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "663932.protein.sequences.v11.5.fa",
		        "enrichment_path": "663932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663932.protein.info.v11.5.txt",
		        "node_list_path": "663932.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesPutredinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes putredinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesPutredinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445970.clusters.proteins.v11.5.txt",
		        "sequence_path": "445970.protein.sequences.v11.5.fa",
		        "enrichment_path": "445970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445970.protein.info.v11.5.txt",
		        "node_list_path": "445970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumKansasiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumKansasiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1768.clusters.proteins.v11.5.txt",
		        "sequence_path": "1768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768.protein.info.v11.5.txt",
		        "node_list_path": "1768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAcidiproducensDsm23148Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus acidiproducens DSM 23148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAcidiproducensDsm23148Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "444461.clusters.info.v11.5.txt",
		        "cluster_tree_path": "444461.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "444461.clusters.proteins.v11.5.txt",
		        "sequence_path": "444461.protein.sequences.v11.5.fa",
		        "enrichment_path": "444461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444461.protein.info.v11.5.txt",
		        "node_list_path": "444461.cluster.nodes.v11.5.txt",
		        "edge_list_path": "444461.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MonosporascusSpMg162Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. mg162 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSpMg162Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1081914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1081914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1081914.clusters.proteins.v11.5.txt",
		        "sequence_path": "1081914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081914.protein.info.v11.5.txt",
		        "node_list_path": "1081914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1081914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag709Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:709 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag709Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262748.protein.info.v11.5.txt",
		        "node_list_path": "1262748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacteriumGwa27335Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium GWA2_73_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacteriumGwa27335Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802096.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802096.protein.info.v11.5.txt",
		        "node_list_path": "1802096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DietziaTimorensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dietzia timorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DietziaTimorensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "499555.protein.sequences.v11.5.fa",
		        "enrichment_path": "499555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "499555.protein.info.v11.5.txt",
		        "node_list_path": "499555.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterSpYs13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter sp. YS13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterSpYs13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1511746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1511746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1511746.protein.info.v11.5.txt",
		        "node_list_path": "1511746.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonB261(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B26-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB261", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1779370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1779370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1779370.protein.info.v11.5.txt",
		        "node_list_path": "1779370.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaThiooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea thiooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaThiooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53254.protein.sequences.v11.5.fa",
		        "enrichment_path": "53254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53254.protein.info.v11.5.txt",
		        "node_list_path": "53254.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpBls98Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. BLS98 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpBls98Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "885586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "885586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "885586.clusters.proteins.v11.5.txt",
		        "sequence_path": "885586.protein.sequences.v11.5.fa",
		        "enrichment_path": "885586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "885586.protein.info.v11.5.txt",
		        "node_list_path": "885586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "885586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCellulovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cellulovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCellulovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573061.protein.sequences.v11.5.fa",
		        "enrichment_path": "573061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573061.protein.info.v11.5.txt",
		        "node_list_path": "573061.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporomusaAcidovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporomusa acidovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporomusaAcidovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "112900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "112900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "112900.clusters.proteins.v11.5.txt",
		        "sequence_path": "112900.protein.sequences.v11.5.fa",
		        "enrichment_path": "112900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112900.protein.info.v11.5.txt",
		        "node_list_path": "112900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "112900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinivibrioSocompensisS10bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio socompensis S10B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivibrioSocompensisS10bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "868280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "868280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "868280.clusters.proteins.v11.5.txt",
		        "sequence_path": "868280.protein.sequences.v11.5.fa",
		        "enrichment_path": "868280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "868280.protein.info.v11.5.txt",
		        "node_list_path": "868280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "868280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKimchicusJcm15530Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kimchicus JCM 15530 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKimchicusJcm15530Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1302272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1302272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1302272.clusters.proteins.v11.5.txt",
		        "sequence_path": "1302272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302272.protein.info.v11.5.txt",
		        "node_list_path": "1302272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1302272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacteriumCg1024614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_46_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805288.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805288.protein.info.v11.5.txt",
		        "node_list_path": "1805288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CedeceaDavisaeDsm4568Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cedecea davisae DSM 4568 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CedeceaDavisaeDsm4568Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "566551.clusters.info.v11.5.txt",
		        "cluster_tree_path": "566551.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "566551.clusters.proteins.v11.5.txt",
		        "sequence_path": "566551.protein.sequences.v11.5.fa",
		        "enrichment_path": "566551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "566551.protein.info.v11.5.txt",
		        "node_list_path": "566551.cluster.nodes.v11.5.txt",
		        "edge_list_path": "566551.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaInulinivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseburia inulinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaInulinivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "622312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "622312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "622312.clusters.proteins.v11.5.txt",
		        "sequence_path": "622312.protein.sequences.v11.5.fa",
		        "enrichment_path": "622312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "622312.protein.info.v11.5.txt",
		        "node_list_path": "622312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "622312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeomonachusSchauinslandi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neomonachus schauinslandi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeomonachusSchauinslandi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29088.protein.sequences.v11.5.fa",
		        "enrichment_path": "29088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29088.protein.info.v11.5.txt",
		        "node_list_path": "29088.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusAlveiDsm29Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alvei DSM 29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusAlveiDsm29Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206781.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206781.protein.info.v11.5.txt",
		        "node_list_path": "1206781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaCanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaCanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117644.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1117644.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1117644.clusters.proteins.v11.5.txt",
		        "sequence_path": "1117644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117644.protein.info.v11.5.txt",
		        "node_list_path": "1117644.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1117644.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidihalobacterFerrooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidihalobacter ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidihalobacterFerrooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1765967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765967.protein.info.v11.5.txt",
		        "node_list_path": "1765967.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumTofieldiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum tofieldiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumTofieldiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "708197.protein.sequences.v11.5.fa",
		        "enrichment_path": "708197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "708197.protein.info.v11.5.txt",
		        "node_list_path": "708197.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeorhizobiumGalegaeOrientalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorhizobiumGalegaeOrientalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1028800.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1028800.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1028800.clusters.proteins.v11.5.txt",
		        "sequence_path": "1028800.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028800.protein.info.v11.5.txt",
		        "node_list_path": "1028800.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1028800.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RamlibacterSpLeaf400Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ramlibacter sp. Leaf400 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RamlibacterSpLeaf400Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736365.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736365.protein.info.v11.5.txt",
		        "node_list_path": "1736365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AneurinibacillusTerranovensisDsm18919(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aneurinibacillus terranovensis DSM 18919 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AneurinibacillusTerranovensisDsm18919", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121002.protein.info.v11.5.txt",
		        "node_list_path": "1121002.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiothrixFlexilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix flexilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiothrixFlexilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123400.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123400.protein.info.v11.5.txt",
		        "node_list_path": "1123400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycetalesBacterium7110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 71-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetalesBacterium7110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895807.protein.info.v11.5.txt",
		        "node_list_path": "1895807.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinospirillumMinutulum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinospirillum minutulum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinospirillumMinutulum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122212.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122212.protein.info.v11.5.txt",
		        "node_list_path": "1122212.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaRara(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella rara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaRara", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1676614.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676614.protein.info.v11.5.txt",
		        "node_list_path": "1676614.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumStylosanthisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium stylosanthis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumStylosanthisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803665.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803665.protein.info.v11.5.txt",
		        "node_list_path": "1803665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudorhodobacterAntarcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodobacter antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodobacterAntarcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1077947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1077947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1077947.clusters.proteins.v11.5.txt",
		        "sequence_path": "1077947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077947.protein.info.v11.5.txt",
		        "node_list_path": "1077947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1077947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParvimonasMicra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parvimonas micra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvimonasMicra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411465.protein.sequences.v11.5.fa",
		        "enrichment_path": "411465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411465.protein.info.v11.5.txt",
		        "node_list_path": "411465.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerrimonasBalearica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas balearica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrimonasBalearica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "550540.protein.sequences.v11.5.fa",
		        "enrichment_path": "550540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "550540.protein.info.v11.5.txt",
		        "node_list_path": "550540.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacterium281(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 28-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacterium281", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1962177.protein.sequences.v11.5.fa",
		        "enrichment_path": "1962177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1962177.protein.info.v11.5.txt",
		        "node_list_path": "1962177.protein.complete.v11.5.txt"
		    }
		]
    )()

def DanioRerioCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Danio rerio Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DanioRerioCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7955.clusters.proteins.v11.5.txt",
		        "sequence_path": "7955.protein.sequences.v11.5.fa",
		        "enrichment_path": "7955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7955.protein.info.v11.5.txt",
		        "node_list_path": "7955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoplasmaVolcaniumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasma volcanium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmaVolcaniumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "273116.clusters.info.v11.5.txt",
		        "cluster_tree_path": "273116.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "273116.clusters.proteins.v11.5.txt",
		        "sequence_path": "273116.protein.sequences.v11.5.fa",
		        "enrichment_path": "273116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273116.protein.info.v11.5.txt",
		        "node_list_path": "273116.cluster.nodes.v11.5.txt",
		        "edge_list_path": "273116.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp10819081Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1081908.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp10819081Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834066.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834066.protein.info.v11.5.txt",
		        "node_list_path": "1834066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnothrixRoseaIamM220Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnothrix rosea IAM M-220 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnothrixRoseaIamM220Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "454133.clusters.info.v11.5.txt",
		        "cluster_tree_path": "454133.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "454133.clusters.proteins.v11.5.txt",
		        "sequence_path": "454133.protein.sequences.v11.5.fa",
		        "enrichment_path": "454133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454133.protein.info.v11.5.txt",
		        "node_list_path": "454133.cluster.nodes.v11.5.txt",
		        "edge_list_path": "454133.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasSpL53140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. L53140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSpL53140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1207058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1207058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1207058.clusters.proteins.v11.5.txt",
		        "sequence_path": "1207058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1207058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1207058.protein.info.v11.5.txt",
		        "node_list_path": "1207058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1207058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodovulumSpNi22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. NI22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovulumSpNi22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1469613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469613.protein.info.v11.5.txt",
		        "node_list_path": "1469613.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeishmaniaMajorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leishmania major Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeishmaniaMajorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5664.clusters.proteins.v11.5.txt",
		        "sequence_path": "5664.protein.sequences.v11.5.fa",
		        "enrichment_path": "5664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5664.protein.info.v11.5.txt",
		        "node_list_path": "5664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JiangellaMuralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jiangella muralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JiangellaMuralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "702383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "702383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "702383.clusters.proteins.v11.5.txt",
		        "sequence_path": "702383.protein.sequences.v11.5.fa",
		        "enrichment_path": "702383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702383.protein.info.v11.5.txt",
		        "node_list_path": "702383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "702383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicolaGranulosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola granulosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaGranulosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314256.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314256.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314256.clusters.proteins.v11.5.txt",
		        "sequence_path": "314256.protein.sequences.v11.5.fa",
		        "enrichment_path": "314256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314256.protein.info.v11.5.txt",
		        "node_list_path": "314256.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314256.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CedeceaDavisaeDsm4568(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cedecea davisae DSM 4568 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CedeceaDavisaeDsm4568", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "566551.protein.sequences.v11.5.fa",
		        "enrichment_path": "566551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "566551.protein.info.v11.5.txt",
		        "node_list_path": "566551.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusThiodiazotrophaEndolucinida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thiodiazotropha endolucinida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThiodiazotrophaEndolucinida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1655433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655433.protein.info.v11.5.txt",
		        "node_list_path": "1655433.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCallunaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium callunae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCallunaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121353.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121353.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121353.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121353.protein.info.v11.5.txt",
		        "node_list_path": "1121353.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121353.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho202Full3713(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_37_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full3713", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798602.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798602.protein.info.v11.5.txt",
		        "node_list_path": "1798602.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloferulaSpBvorr071(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloferula sp. BvORR071 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloferulaSpBvorr071", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1396141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1396141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1396141.protein.info.v11.5.txt",
		        "node_list_path": "1396141.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifoxya2Full4528(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFOXYA2_FULL_45_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifoxya2Full4528", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802713.protein.info.v11.5.txt",
		        "node_list_path": "1802713.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaProteobacteriumMl8F1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return delta proteobacterium ML8_F1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaProteobacteriumMl8F1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1775671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1775671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1775671.clusters.proteins.v11.5.txt",
		        "sequence_path": "1775671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775671.protein.info.v11.5.txt",
		        "node_list_path": "1775671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1775671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumConspicuumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium conspicuum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumConspicuumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44010.clusters.proteins.v11.5.txt",
		        "sequence_path": "44010.protein.sequences.v11.5.fa",
		        "enrichment_path": "44010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44010.protein.info.v11.5.txt",
		        "node_list_path": "44010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachanceaThermotoleransCbs6340Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachancea thermotolerans CBS 6340 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachanceaThermotoleransCbs6340Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "559295.clusters.info.v11.5.txt",
		        "cluster_tree_path": "559295.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "559295.clusters.proteins.v11.5.txt",
		        "sequence_path": "559295.protein.sequences.v11.5.fa",
		        "enrichment_path": "559295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559295.protein.info.v11.5.txt",
		        "node_list_path": "559295.cluster.nodes.v11.5.txt",
		        "edge_list_path": "559295.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaSalinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina salinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaSalinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "435908.protein.sequences.v11.5.fa",
		        "enrichment_path": "435908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435908.protein.info.v11.5.txt",
		        "node_list_path": "435908.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterFennelliae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter fennelliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterFennelliae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1325130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325130.protein.info.v11.5.txt",
		        "node_list_path": "1325130.protein.complete.v11.5.txt"
		    }
		]
    )()

def UreaplasmaParvumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ureaplasma parvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UreaplasmaParvumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "273119.clusters.info.v11.5.txt",
		        "cluster_tree_path": "273119.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "273119.clusters.proteins.v11.5.txt",
		        "sequence_path": "273119.protein.sequences.v11.5.fa",
		        "enrichment_path": "273119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273119.protein.info.v11.5.txt",
		        "node_list_path": "273119.cluster.nodes.v11.5.txt",
		        "edge_list_path": "273119.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSp77Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSp77Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1101192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1101192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1101192.clusters.proteins.v11.5.txt",
		        "sequence_path": "1101192.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101192.protein.info.v11.5.txt",
		        "node_list_path": "1101192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1101192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaEntomophaga(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia entomophaga graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaEntomophaga", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935293.protein.sequences.v11.5.fa",
		        "enrichment_path": "935293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935293.protein.info.v11.5.txt",
		        "node_list_path": "935293.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasPhyllosphaerae52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas phyllosphaerae 52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasPhyllosphaerae52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1090318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1090318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1090318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1090318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1090318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1090318.protein.info.v11.5.txt",
		        "node_list_path": "1090318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1090318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisTaiwanensisDsm45107Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis taiwanensis DSM 45107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisTaiwanensisDsm45107Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120984.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120984.protein.info.v11.5.txt",
		        "node_list_path": "1120984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumCrhCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CRH Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumCrhCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1742859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1742859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1742859.clusters.proteins.v11.5.txt",
		        "sequence_path": "1742859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742859.protein.info.v11.5.txt",
		        "node_list_path": "1742859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1742859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpRoot552(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root552 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpRoot552", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736555.protein.info.v11.5.txt",
		        "node_list_path": "1736555.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidithiobacillusFerrooxidansAtcc23270Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans ATCC23270 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithiobacillusFerrooxidansAtcc23270Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243159.clusters.proteins.v11.5.txt",
		        "sequence_path": "243159.protein.sequences.v11.5.fa",
		        "enrichment_path": "243159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243159.protein.info.v11.5.txt",
		        "node_list_path": "243159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BigelowiellaNatansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bigelowiella natans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BigelowiellaNatansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "227086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "227086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "227086.clusters.proteins.v11.5.txt",
		        "sequence_path": "227086.protein.sequences.v11.5.fa",
		        "enrichment_path": "227086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227086.protein.info.v11.5.txt",
		        "node_list_path": "227086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "227086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChristensenellaceaeBacteriumPhil1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Christensenellaceae bacterium Phil1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChristensenellaceaeBacteriumPhil1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930012.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930012.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930012.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930012.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930012.protein.info.v11.5.txt",
		        "node_list_path": "1930012.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930012.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophagaLonarensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga lonarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaLonarensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1286106.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1286106.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1286106.clusters.proteins.v11.5.txt",
		        "sequence_path": "1286106.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286106.protein.info.v11.5.txt",
		        "node_list_path": "1286106.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1286106.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwa25713Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_57_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25713Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797811.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797811.protein.info.v11.5.txt",
		        "node_list_path": "1797811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesmosporaSp8437(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desmospora sp. 8437 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesmosporaSp8437", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "997346.protein.sequences.v11.5.fa",
		        "enrichment_path": "997346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997346.protein.info.v11.5.txt",
		        "node_list_path": "997346.protein.complete.v11.5.txt"
		    }
		]
    )()

def WallemiaIchthyophaga(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wallemia ichthyophaga graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WallemiaIchthyophaga", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "245174.protein.sequences.v11.5.fa",
		        "enrichment_path": "245174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "245174.protein.info.v11.5.txt",
		        "node_list_path": "245174.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumDesertiGimn1010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium deserti GIMN1.010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumDesertiGimn1010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "931089.protein.sequences.v11.5.fa",
		        "enrichment_path": "931089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "931089.protein.info.v11.5.txt",
		        "node_list_path": "931089.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacterium7064Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 70-64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacterium7064Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895733.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895733.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895733.protein.info.v11.5.txt",
		        "node_list_path": "1895733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusIsoporae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus isoporae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusIsoporae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "591205.protein.sequences.v11.5.fa",
		        "enrichment_path": "591205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591205.protein.info.v11.5.txt",
		        "node_list_path": "591205.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaDuttonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia duttonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaDuttonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "412419.protein.sequences.v11.5.fa",
		        "enrichment_path": "412419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "412419.protein.info.v11.5.txt",
		        "node_list_path": "412419.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterVariabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter variabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterVariabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "70346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "70346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "70346.clusters.proteins.v11.5.txt",
		        "sequence_path": "70346.protein.sequences.v11.5.fa",
		        "enrichment_path": "70346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "70346.protein.info.v11.5.txt",
		        "node_list_path": "70346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "70346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellvibrioGilvusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio gilvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioGilvusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "593907.clusters.info.v11.5.txt",
		        "cluster_tree_path": "593907.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "593907.clusters.proteins.v11.5.txt",
		        "sequence_path": "593907.protein.sequences.v11.5.fa",
		        "enrichment_path": "593907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "593907.protein.info.v11.5.txt",
		        "node_list_path": "593907.cluster.nodes.v11.5.txt",
		        "edge_list_path": "593907.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpWsm2793(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM2793 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpWsm2793", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1038866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038866.protein.info.v11.5.txt",
		        "node_list_path": "1038866.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaBerlinenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema berlinense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaBerlinenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "225004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "225004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "225004.clusters.proteins.v11.5.txt",
		        "sequence_path": "225004.protein.sequences.v11.5.fa",
		        "enrichment_path": "225004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225004.protein.info.v11.5.txt",
		        "node_list_path": "225004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "225004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpMilost2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. MilosT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpMilost2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "90814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "90814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "90814.clusters.proteins.v11.5.txt",
		        "sequence_path": "90814.protein.sequences.v11.5.fa",
		        "enrichment_path": "90814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90814.protein.info.v11.5.txt",
		        "node_list_path": "90814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "90814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonRbg135212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_52_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg135212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797379.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797379.protein.info.v11.5.txt",
		        "node_list_path": "1797379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpLeaf160Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf160 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpLeaf160Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736280.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736280.protein.info.v11.5.txt",
		        "node_list_path": "1736280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumOrbiscindensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium orbiscindens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumOrbiscindensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742738.clusters.proteins.v11.5.txt",
		        "sequence_path": "742738.protein.sequences.v11.5.fa",
		        "enrichment_path": "742738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742738.protein.info.v11.5.txt",
		        "node_list_path": "742738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumChoerinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium choerinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumChoerinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35760.clusters.proteins.v11.5.txt",
		        "sequence_path": "35760.protein.sequences.v11.5.fa",
		        "enrichment_path": "35760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35760.protein.info.v11.5.txt",
		        "node_list_path": "35760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpIso805n(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Iso805N graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpIso805n", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1283287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283287.protein.info.v11.5.txt",
		        "node_list_path": "1283287.protein.complete.v11.5.txt"
		    }
		]
    )()

def AndreprevotiaLacusDsm23236Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Andreprevotia lacus DSM 23236 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AndreprevotiaLacusDsm23236Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121001.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121001.protein.info.v11.5.txt",
		        "node_list_path": "1121001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChaetomiumGlobosumCbs14851Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium globosum CBS 148.51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChaetomiumGlobosumCbs14851Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "306901.clusters.info.v11.5.txt",
		        "cluster_tree_path": "306901.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "306901.clusters.proteins.v11.5.txt",
		        "sequence_path": "306901.protein.sequences.v11.5.fa",
		        "enrichment_path": "306901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306901.protein.info.v11.5.txt",
		        "node_list_path": "306901.cluster.nodes.v11.5.txt",
		        "edge_list_path": "306901.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasNitritireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas nitritireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasNitritireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83617.clusters.proteins.v11.5.txt",
		        "sequence_path": "83617.protein.sequences.v11.5.fa",
		        "enrichment_path": "83617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83617.protein.info.v11.5.txt",
		        "node_list_path": "83617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusPlantarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus plantarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusPlantarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1077675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077675.protein.info.v11.5.txt",
		        "node_list_path": "1077675.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrodictiumDelaneyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrodictium delaneyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrodictiumDelaneyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1273541.protein.sequences.v11.5.fa",
		        "enrichment_path": "1273541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1273541.protein.info.v11.5.txt",
		        "node_list_path": "1273541.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterSpQlwP1data2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. QLW-P1DATA-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterSpQlwP1data2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1743167.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1743167.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1743167.clusters.proteins.v11.5.txt",
		        "sequence_path": "1743167.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743167.protein.info.v11.5.txt",
		        "node_list_path": "1743167.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1743167.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaF1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida F1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaF1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351746.clusters.proteins.v11.5.txt",
		        "sequence_path": "351746.protein.sequences.v11.5.fa",
		        "enrichment_path": "351746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351746.protein.info.v11.5.txt",
		        "node_list_path": "351746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumKansasii732(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii 732 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumKansasii732", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1299327.protein.sequences.v11.5.fa",
		        "enrichment_path": "1299327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1299327.protein.info.v11.5.txt",
		        "node_list_path": "1299327.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpPamc28711Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. PAMC 28711 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpPamc28711Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1795631.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1795631.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1795631.clusters.proteins.v11.5.txt",
		        "sequence_path": "1795631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795631.protein.info.v11.5.txt",
		        "node_list_path": "1795631.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1795631.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlaviflexusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flaviflexus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlaviflexusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1522309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1522309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1522309.clusters.proteins.v11.5.txt",
		        "sequence_path": "1522309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522309.protein.info.v11.5.txt",
		        "node_list_path": "1522309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1522309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaseolusVulgaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaseolus vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaseolusVulgaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3885.protein.sequences.v11.5.fa",
		        "enrichment_path": "3885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3885.protein.info.v11.5.txt",
		        "node_list_path": "3885.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpecialisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces specialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpecialisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "498367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "498367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "498367.clusters.proteins.v11.5.txt",
		        "sequence_path": "498367.protein.sequences.v11.5.fa",
		        "enrichment_path": "498367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498367.protein.info.v11.5.txt",
		        "node_list_path": "498367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "498367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DoreaFormicigenerans4653afaaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea formicigenerans 4653AFAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaFormicigenerans4653afaaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742765.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742765.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742765.clusters.proteins.v11.5.txt",
		        "sequence_path": "742765.protein.sequences.v11.5.fa",
		        "enrichment_path": "742765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742765.protein.info.v11.5.txt",
		        "node_list_path": "742765.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742765.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GardnerellaVaginalis101Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis 101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GardnerellaVaginalis101Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "904144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "904144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "904144.clusters.proteins.v11.5.txt",
		        "sequence_path": "904144.protein.sequences.v11.5.fa",
		        "enrichment_path": "904144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904144.protein.info.v11.5.txt",
		        "node_list_path": "904144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "904144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBlochmanniaVaferStrBvafCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blochmannia vafer str. BVAF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBlochmanniaVaferStrBvafCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "859654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "859654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "859654.clusters.proteins.v11.5.txt",
		        "sequence_path": "859654.protein.sequences.v11.5.fa",
		        "enrichment_path": "859654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "859654.protein.info.v11.5.txt",
		        "node_list_path": "859654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "859654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasFragariaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas fragariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasFragariaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131451.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131451.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131451.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131451.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131451.protein.info.v11.5.txt",
		        "node_list_path": "1131451.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131451.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermosphaeraAggregans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermosphaera aggregans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosphaeraAggregans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "633148.protein.sequences.v11.5.fa",
		        "enrichment_path": "633148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633148.protein.info.v11.5.txt",
		        "node_list_path": "633148.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaCoubleaeNbrc108252(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia coubleae NBRC 108252 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaCoubleaeNbrc108252", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210069.protein.info.v11.5.txt",
		        "node_list_path": "1210069.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumRifcsplowo202Full4814(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFCSPLOWO2_02_FULL_48_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifcsplowo202Full4814", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801900.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801900.protein.info.v11.5.txt",
		        "node_list_path": "1801900.protein.complete.v11.5.txt"
		    }
		]
    )()

def SimiduiaAgarivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Simiduia agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SimiduiaAgarivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117647.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1117647.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1117647.clusters.proteins.v11.5.txt",
		        "sequence_path": "1117647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117647.protein.info.v11.5.txt",
		        "node_list_path": "1117647.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1117647.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasVasicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas vasicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasVasicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56459.clusters.proteins.v11.5.txt",
		        "sequence_path": "56459.protein.sequences.v11.5.fa",
		        "enrichment_path": "56459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56459.protein.info.v11.5.txt",
		        "node_list_path": "56459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TsukamurellaPulmonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tsukamurella pulmonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TsukamurellaPulmonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47312.clusters.proteins.v11.5.txt",
		        "sequence_path": "47312.protein.sequences.v11.5.fa",
		        "enrichment_path": "47312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47312.protein.info.v11.5.txt",
		        "node_list_path": "47312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaHydrophobicaNbrc16057Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia hydrophobica NBRC 16057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaHydrophobicaNbrc16057Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223541.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223541.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223541.protein.info.v11.5.txt",
		        "node_list_path": "1223541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonBa1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon BA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonBa1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1700835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1700835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1700835.protein.info.v11.5.txt",
		        "node_list_path": "1700835.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydialesBacterium3826Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiales bacterium 38-26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydialesBacterium3826Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895743.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895743.protein.info.v11.5.txt",
		        "node_list_path": "1895743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptosporidiumMurisRn66(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporidium muris RN66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptosporidiumMurisRn66", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "441375.protein.sequences.v11.5.fa",
		        "enrichment_path": "441375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441375.protein.info.v11.5.txt",
		        "node_list_path": "441375.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaSeptica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea septica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSeptica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "472695.protein.sequences.v11.5.fa",
		        "enrichment_path": "472695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472695.protein.info.v11.5.txt",
		        "node_list_path": "472695.protein.complete.v11.5.txt"
		    }
		]
    )()

def KallipygaGabonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kallipyga gabonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KallipygaGabonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1686287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1686287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1686287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1686287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686287.protein.info.v11.5.txt",
		        "node_list_path": "1686287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1686287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeucobacterSpAg1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter sp. Ag1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterSpAg1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1642040.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1642040.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1642040.clusters.proteins.v11.5.txt",
		        "sequence_path": "1642040.protein.sequences.v11.5.fa",
		        "enrichment_path": "1642040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1642040.protein.info.v11.5.txt",
		        "node_list_path": "1642040.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1642040.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxSpDg881(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. DG881 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxSpDg881", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "236097.protein.sequences.v11.5.fa",
		        "enrichment_path": "236097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "236097.protein.info.v11.5.txt",
		        "node_list_path": "236097.protein.complete.v11.5.txt"
		    }
		]
    )()

def DermatophilusCongolensisDsm44180Nbrc105199Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dermatophilus congolensis DSM 44180 NBRC 105199 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DermatophilusCongolensisDsm44180Nbrc105199Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121387.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121387.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121387.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121387.protein.info.v11.5.txt",
		        "node_list_path": "1121387.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121387.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumChlorophenolicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium chlorophenolicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumChlorophenolicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46429.clusters.proteins.v11.5.txt",
		        "sequence_path": "46429.protein.sequences.v11.5.fa",
		        "enrichment_path": "46429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46429.protein.info.v11.5.txt",
		        "node_list_path": "46429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhycicoccusSpSoil803(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Soil803 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycicoccusSpSoil803", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736415.protein.info.v11.5.txt",
		        "node_list_path": "1736415.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumOvolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum ovolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumOvolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "104270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "104270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "104270.clusters.proteins.v11.5.txt",
		        "sequence_path": "104270.protein.sequences.v11.5.fa",
		        "enrichment_path": "104270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104270.protein.info.v11.5.txt",
		        "node_list_path": "104270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "104270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PersephonellaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Persephonella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PersephonellaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "123214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "123214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "123214.clusters.proteins.v11.5.txt",
		        "sequence_path": "123214.protein.sequences.v11.5.fa",
		        "enrichment_path": "123214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "123214.protein.info.v11.5.txt",
		        "node_list_path": "123214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "123214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanibacterTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janibacter terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "103817.protein.sequences.v11.5.fa",
		        "enrichment_path": "103817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103817.protein.info.v11.5.txt",
		        "node_list_path": "103817.protein.complete.v11.5.txt"
		    }
		]
    )()

def OnchocercaOchengiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Onchocerca ochengi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OnchocercaOchengiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42157.clusters.proteins.v11.5.txt",
		        "sequence_path": "42157.protein.sequences.v11.5.fa",
		        "enrichment_path": "42157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42157.protein.info.v11.5.txt",
		        "node_list_path": "42157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AfipiaBroomeae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Afipia broomeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaBroomeae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883078.protein.sequences.v11.5.fa",
		        "enrichment_path": "883078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883078.protein.info.v11.5.txt",
		        "node_list_path": "883078.protein.complete.v11.5.txt"
		    }
		]
    )()

def DinothrombiumTinctoriumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dinothrombium tinctorium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DinothrombiumTinctoriumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1965070.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1965070.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1965070.clusters.proteins.v11.5.txt",
		        "sequence_path": "1965070.protein.sequences.v11.5.fa",
		        "enrichment_path": "1965070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1965070.protein.info.v11.5.txt",
		        "node_list_path": "1965070.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1965070.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterFetusSubspTestudinumSp3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. testudinum Sp3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterFetusSubspTestudinumSp3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1244529.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1244529.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1244529.clusters.proteins.v11.5.txt",
		        "sequence_path": "1244529.protein.sequences.v11.5.fa",
		        "enrichment_path": "1244529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1244529.protein.info.v11.5.txt",
		        "node_list_path": "1244529.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1244529.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MitsuokellaSpW9106(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mitsuokella sp. W9106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MitsuokellaSpW9106", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321781.protein.info.v11.5.txt",
		        "node_list_path": "1321781.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwa13921Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_39_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa13921Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618550.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618550.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618550.protein.info.v11.5.txt",
		        "node_list_path": "1618550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpT32Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. T32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpT32Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776083.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776083.protein.info.v11.5.txt",
		        "node_list_path": "1776083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptoalloteichusHindustanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptoalloteichus hindustanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptoalloteichusHindustanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2017.clusters.proteins.v11.5.txt",
		        "sequence_path": "2017.protein.sequences.v11.5.fa",
		        "enrichment_path": "2017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2017.protein.info.v11.5.txt",
		        "node_list_path": "2017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassilibacteroidesVaginaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilibacteroides vaginae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassilibacteroidesVaginaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1673718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1673718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1673718.clusters.proteins.v11.5.txt",
		        "sequence_path": "1673718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673718.protein.info.v11.5.txt",
		        "node_list_path": "1673718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1673718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColinusVirginianus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colinus virginianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColinusVirginianus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9014.protein.sequences.v11.5.fa",
		        "enrichment_path": "9014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9014.protein.info.v11.5.txt",
		        "node_list_path": "9014.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCb00455Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB00455 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCb00455Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703927.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703927.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703927.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703927.protein.info.v11.5.txt",
		        "node_list_path": "1703927.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703927.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaSymbiontCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia symbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSymbiontCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "656024.clusters.info.v11.5.txt",
		        "cluster_tree_path": "656024.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "656024.clusters.proteins.v11.5.txt",
		        "sequence_path": "656024.protein.sequences.v11.5.fa",
		        "enrichment_path": "656024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656024.protein.info.v11.5.txt",
		        "node_list_path": "656024.cluster.nodes.v11.5.txt",
		        "edge_list_path": "656024.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMegateriumMsp201Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus megaterium MSP201 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMegateriumMsp201Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348908.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348908.protein.info.v11.5.txt",
		        "node_list_path": "1348908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BalaenopteraAcutorostrata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Balaenoptera acutorostrata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BalaenopteraAcutorostrata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9767.protein.sequences.v11.5.fa",
		        "enrichment_path": "9767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9767.protein.info.v11.5.txt",
		        "node_list_path": "9767.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterovibrioNorvegicusDsm15893Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus DSM 15893 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioNorvegicusDsm15893Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121869.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121869.protein.info.v11.5.txt",
		        "node_list_path": "1121869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifoxyb2Full3713(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFOXYB2_FULL_37_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2Full3713", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802579.protein.info.v11.5.txt",
		        "node_list_path": "1802579.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaSpF0517Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0517 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaSpF0517Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227266.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227266.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227266.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227266.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227266.protein.info.v11.5.txt",
		        "node_list_path": "1227266.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227266.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpCf080(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF080 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpCf080", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144310.protein.info.v11.5.txt",
		        "node_list_path": "1144310.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumRbg19ftCombo7019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_19FT_COMBO_70_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumRbg19ftCombo7019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797208.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797208.protein.info.v11.5.txt",
		        "node_list_path": "1797208.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaSp2742308(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia sp. 2742-308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaSp2742308", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1806891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806891.protein.info.v11.5.txt",
		        "node_list_path": "1806891.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterShowaeCsunswcdCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter showae CSUNSWCD Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterShowaeCsunswcdCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1244083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1244083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1244083.clusters.proteins.v11.5.txt",
		        "sequence_path": "1244083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1244083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1244083.protein.info.v11.5.txt",
		        "node_list_path": "1244083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1244083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpSy8519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. SY8519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpSy8519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1042156.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042156.protein.info.v11.5.txt",
		        "node_list_path": "1042156.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumK1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium K1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumK1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807743.protein.info.v11.5.txt",
		        "node_list_path": "1807743.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumLactosutens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium lactosutens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumLactosutens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1331060.protein.sequences.v11.5.fa",
		        "enrichment_path": "1331060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1331060.protein.info.v11.5.txt",
		        "node_list_path": "1331060.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumSpOccitanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium sp. occitanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumSpOccitanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290292.clusters.proteins.v11.5.txt",
		        "sequence_path": "290292.protein.sequences.v11.5.fa",
		        "enrichment_path": "290292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290292.protein.info.v11.5.txt",
		        "node_list_path": "290292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium4718(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 47-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium4718", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895926.protein.info.v11.5.txt",
		        "node_list_path": "1895926.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobiumPhaeobacteroidesDsm266Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium phaeobacteroides DSM266 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumPhaeobacteroidesDsm266Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290317.clusters.proteins.v11.5.txt",
		        "sequence_path": "290317.protein.sequences.v11.5.fa",
		        "enrichment_path": "290317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290317.protein.info.v11.5.txt",
		        "node_list_path": "290317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusRhinitidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus rhinitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusRhinitidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "875454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "875454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "875454.clusters.proteins.v11.5.txt",
		        "sequence_path": "875454.protein.sequences.v11.5.fa",
		        "enrichment_path": "875454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "875454.protein.info.v11.5.txt",
		        "node_list_path": "875454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "875454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpDi166Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. DI166 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpDi166Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1839783.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1839783.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1839783.clusters.proteins.v11.5.txt",
		        "sequence_path": "1839783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1839783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1839783.protein.info.v11.5.txt",
		        "node_list_path": "1839783.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1839783.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusZilligiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus zilligii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusZilligiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1151117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1151117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1151117.clusters.proteins.v11.5.txt",
		        "sequence_path": "1151117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151117.protein.info.v11.5.txt",
		        "node_list_path": "1151117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1151117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifoxyc1Full3818Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYC1_FULL_38_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyc1Full3818Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802229.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802229.protein.info.v11.5.txt",
		        "node_list_path": "1802229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumSoil82(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium SOIL82 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumSoil82", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1655312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655312.protein.info.v11.5.txt",
		        "node_list_path": "1655312.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasXinjiangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasXinjiangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1166948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1166948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1166948.clusters.proteins.v11.5.txt",
		        "sequence_path": "1166948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166948.protein.info.v11.5.txt",
		        "node_list_path": "1166948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1166948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanotheceSpPcc7822(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7822 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanotheceSpPcc7822", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "497965.protein.sequences.v11.5.fa",
		        "enrichment_path": "497965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "497965.protein.info.v11.5.txt",
		        "node_list_path": "497965.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonodelphisDomesticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monodelphis domestica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonodelphisDomesticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13616.clusters.proteins.v11.5.txt",
		        "sequence_path": "13616.protein.sequences.v11.5.fa",
		        "enrichment_path": "13616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13616.protein.info.v11.5.txt",
		        "node_list_path": "13616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSaelicesensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora saelicesensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSaelicesensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "285676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "285676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "285676.clusters.proteins.v11.5.txt",
		        "sequence_path": "285676.protein.sequences.v11.5.fa",
		        "enrichment_path": "285676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285676.protein.info.v11.5.txt",
		        "node_list_path": "285676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "285676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterCuniculorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter cuniculorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterCuniculorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121267.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121267.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121267.protein.info.v11.5.txt",
		        "node_list_path": "1121267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SegniliparusRugosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Segniliparus rugosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SegniliparusRugosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679197.clusters.proteins.v11.5.txt",
		        "sequence_path": "679197.protein.sequences.v11.5.fa",
		        "enrichment_path": "679197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679197.protein.info.v11.5.txt",
		        "node_list_path": "679197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNecrophorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNecrophorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "859.clusters.proteins.v11.5.txt",
		        "sequence_path": "859.protein.sequences.v11.5.fa",
		        "enrichment_path": "859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "859.protein.info.v11.5.txt",
		        "node_list_path": "859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisMediterraneiS699(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis mediterranei S699 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisMediterraneiS699", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "713604.protein.sequences.v11.5.fa",
		        "enrichment_path": "713604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713604.protein.info.v11.5.txt",
		        "node_list_path": "713604.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusChisholmbacteriaBacteriumRifcsplowo201Full4914(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPLOWO2_01_FULL_49_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsplowo201Full4914", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797593.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797593.protein.info.v11.5.txt",
		        "node_list_path": "1797593.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAuratus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces auratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAuratus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1160718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160718.protein.info.v11.5.txt",
		        "node_list_path": "1160718.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpHensoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. hensonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpHensoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1922337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1922337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1922337.clusters.proteins.v11.5.txt",
		        "sequence_path": "1922337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1922337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1922337.protein.info.v11.5.txt",
		        "node_list_path": "1922337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1922337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacterium1147(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 1147 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacterium1147", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469610.protein.sequences.v11.5.fa",
		        "enrichment_path": "469610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469610.protein.info.v11.5.txt",
		        "node_list_path": "469610.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpJhl3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. JHL-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpJhl3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1276755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1276755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1276755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1276755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276755.protein.info.v11.5.txt",
		        "node_list_path": "1276755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1276755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasXinjiangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasXinjiangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1166948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166948.protein.info.v11.5.txt",
		        "node_list_path": "1166948.protein.complete.v11.5.txt"
		    }
		]
    )()

def BipolarisMaydisC5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris maydis C5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisMaydisC5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "701091.protein.sequences.v11.5.fa",
		        "enrichment_path": "701091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "701091.protein.info.v11.5.txt",
		        "node_list_path": "701091.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelosinusPropionicusDsm13327(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus propionicus DSM 13327 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelosinusPropionicusDsm13327", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123291.protein.info.v11.5.txt",
		        "node_list_path": "1123291.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816696.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816696.protein.info.v11.5.txt",
		        "node_list_path": "1816696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaMiyunensisNbrc108239Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia miyunensis NBRC 108239 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaMiyunensisNbrc108239Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210084.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210084.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210084.protein.info.v11.5.txt",
		        "node_list_path": "1210084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioclavaSpF366Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. F36-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaSpF366Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1915316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1915316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1915316.clusters.proteins.v11.5.txt",
		        "sequence_path": "1915316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915316.protein.info.v11.5.txt",
		        "node_list_path": "1915316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1915316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852387.protein.info.v11.5.txt",
		        "node_list_path": "1852387.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpWsm1253Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM1253 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpWsm1253Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "319003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "319003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "319003.clusters.proteins.v11.5.txt",
		        "sequence_path": "319003.protein.sequences.v11.5.fa",
		        "enrichment_path": "319003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319003.protein.info.v11.5.txt",
		        "node_list_path": "319003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "319003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGalbus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces galbus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGalbus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33898.protein.sequences.v11.5.fa",
		        "enrichment_path": "33898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33898.protein.info.v11.5.txt",
		        "node_list_path": "33898.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasSacchariCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasSacchariCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56458.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56458.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56458.clusters.proteins.v11.5.txt",
		        "sequence_path": "56458.protein.sequences.v11.5.fa",
		        "enrichment_path": "56458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56458.protein.info.v11.5.txt",
		        "node_list_path": "56458.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56458.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinopolysporaMortivallis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora mortivallis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolysporaMortivallis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1050202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1050202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1050202.protein.info.v11.5.txt",
		        "node_list_path": "1050202.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaeniclostridiumSordellii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paeniclostridium sordellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaeniclostridiumSordellii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505.protein.info.v11.5.txt",
		        "node_list_path": "1505.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5053Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5053 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5053Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463854.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463854.protein.info.v11.5.txt",
		        "node_list_path": "1463854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactococcusFujiensisJcm16395(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus fujiensis JCM 16395 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusFujiensisJcm16395", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1291764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291764.protein.info.v11.5.txt",
		        "node_list_path": "1291764.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaAllii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea allii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaAllii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "574096.protein.sequences.v11.5.fa",
		        "enrichment_path": "574096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574096.protein.info.v11.5.txt",
		        "node_list_path": "574096.protein.complete.v11.5.txt"
		    }
		]
    )()

def TeredinibacterTurneraeT7901Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Teredinibacter turnerae T7901 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TeredinibacterTurneraeT7901Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "377629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "377629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "377629.clusters.proteins.v11.5.txt",
		        "sequence_path": "377629.protein.sequences.v11.5.fa",
		        "enrichment_path": "377629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "377629.protein.info.v11.5.txt",
		        "node_list_path": "377629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "377629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpOralTaxon431(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. oral taxon 431 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpOralTaxon431", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "712633.protein.sequences.v11.5.fa",
		        "enrichment_path": "712633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712633.protein.info.v11.5.txt",
		        "node_list_path": "712633.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaWoodyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella woodyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaWoodyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "392500.protein.sequences.v11.5.fa",
		        "enrichment_path": "392500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392500.protein.info.v11.5.txt",
		        "node_list_path": "392500.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesWuyuanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces wuyuanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesWuyuanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196353.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196353.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196353.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196353.protein.info.v11.5.txt",
		        "node_list_path": "1196353.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196353.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterSpM21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter sp. M21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterSpM21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "443144.protein.sequences.v11.5.fa",
		        "enrichment_path": "443144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443144.protein.info.v11.5.txt",
		        "node_list_path": "443144.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusBouchesdurhonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus bouchesdurhonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusBouchesdurhonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1870990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1870990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1870990.clusters.proteins.v11.5.txt",
		        "sequence_path": "1870990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870990.protein.info.v11.5.txt",
		        "node_list_path": "1870990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1870990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSubterraneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSubterraneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "285983.protein.sequences.v11.5.fa",
		        "enrichment_path": "285983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285983.protein.info.v11.5.txt",
		        "node_list_path": "285983.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusSp2319x1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sp. 2319x1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSp2319x1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674923.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674923.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674923.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674923.protein.info.v11.5.txt",
		        "node_list_path": "1674923.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674923.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCoahuilensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coahuilensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCoahuilensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "441769.protein.sequences.v11.5.fa",
		        "enrichment_path": "441769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441769.protein.info.v11.5.txt",
		        "node_list_path": "441769.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusThioglobusSpRedseaS12B1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus sp. REDSEA-S12_B1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThioglobusSpRedseaS12B1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811594.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811594.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811594.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811594.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811594.protein.info.v11.5.txt",
		        "node_list_path": "1811594.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811594.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaSprentiaeWsm5005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia sprentiae WSM5005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaSprentiaeWsm5005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "754502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "754502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "754502.clusters.proteins.v11.5.txt",
		        "sequence_path": "754502.protein.sequences.v11.5.fa",
		        "enrichment_path": "754502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754502.protein.info.v11.5.txt",
		        "node_list_path": "754502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "754502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisJaponica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisJaponica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "281687.protein.sequences.v11.5.fa",
		        "enrichment_path": "281687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "281687.protein.info.v11.5.txt",
		        "node_list_path": "281687.protein.complete.v11.5.txt"
		    }
		]
    )()

def TalaromycesIslandicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces islandicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesIslandicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28573.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28573.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28573.clusters.proteins.v11.5.txt",
		        "sequence_path": "28573.protein.sequences.v11.5.fa",
		        "enrichment_path": "28573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28573.protein.info.v11.5.txt",
		        "node_list_path": "28573.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28573.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedFlavonifractorSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Flavonifractor sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedFlavonifractorSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193534.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193534.protein.info.v11.5.txt",
		        "node_list_path": "1193534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeothermobacterSpEprM(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geothermobacter sp. EPR-M graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeothermobacterSpEprM", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1969733.protein.sequences.v11.5.fa",
		        "enrichment_path": "1969733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1969733.protein.info.v11.5.txt",
		        "node_list_path": "1969733.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedBlautiaSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Blautia sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedBlautiaSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765821.protein.sequences.v11.5.fa",
		        "enrichment_path": "765821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765821.protein.info.v11.5.txt",
		        "node_list_path": "765821.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumHallii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium hallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumHallii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411469.protein.sequences.v11.5.fa",
		        "enrichment_path": "411469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411469.protein.info.v11.5.txt",
		        "node_list_path": "411469.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisPrasinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis prasina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisPrasinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1245475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1245475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1245475.clusters.proteins.v11.5.txt",
		        "sequence_path": "1245475.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245475.protein.info.v11.5.txt",
		        "node_list_path": "1245475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1245475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusOceanisediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus oceanisediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusOceanisediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196031.protein.info.v11.5.txt",
		        "node_list_path": "1196031.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudarthrobacterSulfonivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudarthrobacter sulfonivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudarthrobacterSulfonivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "121292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "121292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "121292.clusters.proteins.v11.5.txt",
		        "sequence_path": "121292.protein.sequences.v11.5.fa",
		        "enrichment_path": "121292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121292.protein.info.v11.5.txt",
		        "node_list_path": "121292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "121292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpibacteriumUlvaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epibacterium ulvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpibacteriumUlvaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1156985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1156985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1156985.clusters.proteins.v11.5.txt",
		        "sequence_path": "1156985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156985.protein.info.v11.5.txt",
		        "node_list_path": "1156985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1156985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphimedonQueenslandicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amphimedon queenslandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphimedonQueenslandicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "400682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "400682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "400682.clusters.proteins.v11.5.txt",
		        "sequence_path": "400682.protein.sequences.v11.5.fa",
		        "enrichment_path": "400682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400682.protein.info.v11.5.txt",
		        "node_list_path": "400682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "400682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanohalophilusPortucalensisFdf1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus portucalensis FDF-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanohalophilusPortucalensisFdf1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "523843.clusters.info.v11.5.txt",
		        "cluster_tree_path": "523843.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "523843.clusters.proteins.v11.5.txt",
		        "sequence_path": "523843.protein.sequences.v11.5.fa",
		        "enrichment_path": "523843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523843.protein.info.v11.5.txt",
		        "node_list_path": "523843.cluster.nodes.v11.5.txt",
		        "edge_list_path": "523843.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeucaenaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leucaenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeucaenaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041147.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041147.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041147.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041147.protein.info.v11.5.txt",
		        "node_list_path": "1041147.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041147.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpLeaf180Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf180 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpLeaf180Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736289.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736289.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736289.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736289.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736289.protein.info.v11.5.txt",
		        "node_list_path": "1736289.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736289.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "425104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "425104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "425104.clusters.proteins.v11.5.txt",
		        "sequence_path": "425104.protein.sequences.v11.5.fa",
		        "enrichment_path": "425104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425104.protein.info.v11.5.txt",
		        "node_list_path": "425104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "425104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpNuni2hMbin001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nuni2H_MBin001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpNuni2hMbin001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884656.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884656.protein.info.v11.5.txt",
		        "node_list_path": "1884656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DokdonellaImmobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dokdonella immobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DokdonellaImmobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "578942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "578942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "578942.clusters.proteins.v11.5.txt",
		        "sequence_path": "578942.protein.sequences.v11.5.fa",
		        "enrichment_path": "578942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578942.protein.info.v11.5.txt",
		        "node_list_path": "578942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "578942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumSiligurienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium siliguriense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumSiligurienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1136497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1136497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1136497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1136497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1136497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1136497.protein.info.v11.5.txt",
		        "node_list_path": "1136497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1136497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaueraButanivoransNbrc103042Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera butanivorans NBRC 103042 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraButanivoransNbrc103042Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219356.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219356.protein.info.v11.5.txt",
		        "node_list_path": "1219356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmatimonadaceaeBacterium4484173Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadaceae bacterium 4484_173 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonadaceaeBacterium4484173Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1956166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1956166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1956166.clusters.proteins.v11.5.txt",
		        "sequence_path": "1956166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1956166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1956166.protein.info.v11.5.txt",
		        "node_list_path": "1956166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1956166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriumSar116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Alphaproteobacterium SAR116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriumSar116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "909943.protein.sequences.v11.0.fa",
		        "enrichment_path": "909943.protein.enrichment.terms.v11.0.txt",
		        "info_path": "909943.protein.info.v11.0.txt",
		        "node_list_path": "909943.protein.complete.v11.0.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifoxyd1Full4224(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYD1_FULL_42_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyd1Full4224", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802651.protein.info.v11.5.txt",
		        "node_list_path": "1802651.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioCyclitrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cyclitrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCyclitrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1136163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1136163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1136163.protein.info.v11.5.txt",
		        "node_list_path": "1136163.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCadaveris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cadaveris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCadaveris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280692.protein.info.v11.5.txt",
		        "node_list_path": "1280692.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfofundulusThermosubterraneusDsm16057(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfofundulus thermosubterraneus DSM 16057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfofundulusThermosubterraneusDsm16057", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121432.protein.info.v11.5.txt",
		        "node_list_path": "1121432.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumGlycinophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium glycinophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumGlycinophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1404245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1404245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1404245.clusters.proteins.v11.5.txt",
		        "sequence_path": "1404245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1404245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1404245.protein.info.v11.5.txt",
		        "node_list_path": "1404245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1404245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmorphothecaResinaeAtcc22711(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amorphotheca resinae ATCC 22711 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmorphothecaResinaeAtcc22711", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "857342.protein.sequences.v11.5.fa",
		        "enrichment_path": "857342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857342.protein.info.v11.5.txt",
		        "node_list_path": "857342.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAquilaeDsm44791(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium aquilae DSM 44791 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAquilaeDsm44791", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1431546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1431546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1431546.protein.info.v11.5.txt",
		        "node_list_path": "1431546.protein.complete.v11.5.txt"
		    }
		]
    )()

def FuchsiellaAlkaliacetigena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fuchsiella alkaliacetigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FuchsiellaAlkaliacetigena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "957042.protein.sequences.v11.5.fa",
		        "enrichment_path": "957042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "957042.protein.info.v11.5.txt",
		        "node_list_path": "957042.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitratireductorSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitratireductor soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratireductorSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1670619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1670619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1670619.protein.info.v11.5.txt",
		        "node_list_path": "1670619.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867007Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867007Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1659201.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1659201.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1659201.clusters.proteins.v11.5.txt",
		        "sequence_path": "1659201.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659201.protein.info.v11.5.txt",
		        "node_list_path": "1659201.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1659201.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasXanthomarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas xanthomarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasXanthomarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "271420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "271420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "271420.clusters.proteins.v11.5.txt",
		        "sequence_path": "271420.protein.sequences.v11.5.fa",
		        "enrichment_path": "271420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "271420.protein.info.v11.5.txt",
		        "node_list_path": "271420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "271420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusNidulansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus nidulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusNidulansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "162425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "162425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "162425.clusters.proteins.v11.5.txt",
		        "sequence_path": "162425.protein.sequences.v11.5.fa",
		        "enrichment_path": "162425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "162425.protein.info.v11.5.txt",
		        "node_list_path": "162425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "162425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpCcge1003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpCcge1003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "640512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "640512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "640512.clusters.proteins.v11.5.txt",
		        "sequence_path": "640512.protein.sequences.v11.5.fa",
		        "enrichment_path": "640512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640512.protein.info.v11.5.txt",
		        "node_list_path": "640512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "640512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpLeaf159(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf159 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpLeaf159", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736279.protein.info.v11.5.txt",
		        "node_list_path": "1736279.protein.complete.v11.5.txt"
		    }
		]
    )()

def LitoreibacterJanthinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Litoreibacter janthinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LitoreibacterJanthinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "670154.protein.sequences.v11.5.fa",
		        "enrichment_path": "670154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670154.protein.info.v11.5.txt",
		        "node_list_path": "670154.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumGwf24921Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_49_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumGwf24921Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798573.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798573.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798573.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798573.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798573.protein.info.v11.5.txt",
		        "node_list_path": "1798573.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798573.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1023751(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_37_51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023751", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805303.protein.info.v11.5.txt",
		        "node_list_path": "1805303.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaSpM24t3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. M24T3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpM24t3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "932213.clusters.info.v11.5.txt",
		        "cluster_tree_path": "932213.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "932213.clusters.proteins.v11.5.txt",
		        "sequence_path": "932213.protein.sequences.v11.5.fa",
		        "enrichment_path": "932213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932213.protein.info.v11.5.txt",
		        "node_list_path": "932213.cluster.nodes.v11.5.txt",
		        "edge_list_path": "932213.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAmoebophilusSp3638Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amoebophilus sp. 36-38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmoebophilusSp3638Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895716.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895716.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895716.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895716.protein.info.v11.5.txt",
		        "node_list_path": "1895716.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895716.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VanderwaltozymaPolysporaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vanderwaltozyma polyspora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VanderwaltozymaPolysporaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36033.clusters.proteins.v11.5.txt",
		        "sequence_path": "36033.protein.sequences.v11.5.fa",
		        "enrichment_path": "36033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36033.protein.info.v11.5.txt",
		        "node_list_path": "36033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucorCircinelloidesFCircinelloides1006phlCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. circinelloides 1006PhL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucorCircinelloidesFCircinelloides1006phlCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220926.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220926.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220926.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220926.protein.info.v11.5.txt",
		        "node_list_path": "1220926.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220926.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYonathbacteriaBacteriumRifcsphigho201Full5110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPHIGHO2_01_FULL_51_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsphigho201Full5110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802723.protein.info.v11.5.txt",
		        "node_list_path": "1802723.protein.complete.v11.5.txt"
		    }
		]
    )()

def SubdoligranulumSpCag314Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Subdoligranulum sp. CAG:314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SubdoligranulumSpCag314Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262970.protein.info.v11.5.txt",
		        "node_list_path": "1262970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumRifcsphigho201Full4822Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPHIGHO2_01_FULL_48_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsphigho201Full4822Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802555.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802555.protein.info.v11.5.txt",
		        "node_list_path": "1802555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterCitreusLama915(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter citreus LAMA 915 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterCitreusLama915", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1306953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306953.protein.info.v11.5.txt",
		        "node_list_path": "1306953.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfuromonasSpTfCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromonas sp. TF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromonasSpTfCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232410.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232410.protein.info.v11.5.txt",
		        "node_list_path": "1232410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeuconostocGelidumJb7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum JB7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocGelidumJb7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229756.protein.info.v11.5.txt",
		        "node_list_path": "1229756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TilletiaControversaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tilletia controversa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TilletiaControversaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13291.clusters.proteins.v11.5.txt",
		        "sequence_path": "13291.protein.sequences.v11.5.fa",
		        "enrichment_path": "13291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13291.protein.info.v11.5.txt",
		        "node_list_path": "13291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosospiraSp5618Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. 56-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraSp5618Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895901.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895901.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895901.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895901.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895901.protein.info.v11.5.txt",
		        "node_list_path": "1895901.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895901.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharopolysporaShandongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharopolyspora shandongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharopolysporaShandongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "418495.protein.sequences.v11.5.fa",
		        "enrichment_path": "418495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "418495.protein.info.v11.5.txt",
		        "node_list_path": "418495.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasSalmonicidaSubspAchromogenesAs03Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. achromogenes AS03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSalmonicidaSubspAchromogenesAs03Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1233098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1233098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1233098.clusters.proteins.v11.5.txt",
		        "sequence_path": "1233098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1233098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1233098.protein.info.v11.5.txt",
		        "node_list_path": "1233098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1233098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIs1590(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1590 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIs1590", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1772286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772286.protein.info.v11.5.txt",
		        "node_list_path": "1772286.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlautiaSpMarseilleP3201t(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blautia sp. Marseille-P3201T graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaSpMarseilleP3201t", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907659.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907659.protein.info.v11.5.txt",
		        "node_list_path": "1907659.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterFetusSubspVenerealisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. venerealis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterFetusSubspVenerealisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32020.clusters.proteins.v11.5.txt",
		        "sequence_path": "32020.protein.sequences.v11.5.fa",
		        "enrichment_path": "32020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32020.protein.info.v11.5.txt",
		        "node_list_path": "32020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumThermoresistibile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium thermoresistibile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumThermoresistibile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797.protein.info.v11.5.txt",
		        "node_list_path": "1797.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsplowo201Full4717(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_01_FULL_47_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo201Full4717", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802400.protein.info.v11.5.txt",
		        "node_list_path": "1802400.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc24031Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC2_40_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc24031Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618924.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618924.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618924.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618924.protein.info.v11.5.txt",
		        "node_list_path": "1618924.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618924.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0400Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0400 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0400Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888056.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888056.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888056.clusters.proteins.v11.5.txt",
		        "sequence_path": "888056.protein.sequences.v11.5.fa",
		        "enrichment_path": "888056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888056.protein.info.v11.5.txt",
		        "node_list_path": "888056.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888056.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumTaichungenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium taichungense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumTaichungenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "295069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "295069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "295069.clusters.proteins.v11.5.txt",
		        "sequence_path": "295069.protein.sequences.v11.5.fa",
		        "enrichment_path": "295069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "295069.protein.info.v11.5.txt",
		        "node_list_path": "295069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "295069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinivibrioProteolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio proteolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivibrioProteolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "334715.protein.sequences.v11.5.fa",
		        "enrichment_path": "334715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334715.protein.info.v11.5.txt",
		        "node_list_path": "334715.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumOvolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum ovolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumOvolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "104270.protein.sequences.v11.5.fa",
		        "enrichment_path": "104270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104270.protein.info.v11.5.txt",
		        "node_list_path": "104270.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisSk597Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK597 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisSk597Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585204.clusters.proteins.v11.5.txt",
		        "sequence_path": "585204.protein.sequences.v11.5.fa",
		        "enrichment_path": "585204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585204.protein.info.v11.5.txt",
		        "node_list_path": "585204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrchesellaCinctaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Orchesella cincta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrchesellaCinctaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "48709.clusters.info.v11.5.txt",
		        "cluster_tree_path": "48709.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "48709.clusters.proteins.v11.5.txt",
		        "sequence_path": "48709.protein.sequences.v11.5.fa",
		        "enrichment_path": "48709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48709.protein.info.v11.5.txt",
		        "node_list_path": "48709.cluster.nodes.v11.5.txt",
		        "edge_list_path": "48709.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicellaActignis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicella actignis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicellaActignis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1189325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1189325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1189325.protein.info.v11.5.txt",
		        "node_list_path": "1189325.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSherrisii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sherrisii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSherrisii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243061.protein.sequences.v11.5.fa",
		        "enrichment_path": "243061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243061.protein.info.v11.5.txt",
		        "node_list_path": "243061.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpMste9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. MSTE9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpMste9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1105031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1105031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1105031.clusters.proteins.v11.5.txt",
		        "sequence_path": "1105031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1105031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1105031.protein.info.v11.5.txt",
		        "node_list_path": "1105031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1105031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelobdellaRobusta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helobdella robusta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelobdellaRobusta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6412.protein.sequences.v11.5.fa",
		        "enrichment_path": "6412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6412.protein.info.v11.5.txt",
		        "node_list_path": "6412.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumOtitidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium otitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumOtitidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29321.protein.sequences.v11.5.fa",
		        "enrichment_path": "29321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29321.protein.info.v11.5.txt",
		        "node_list_path": "29321.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpRit357(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. RIT357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpRit357", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1470593.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470593.protein.info.v11.5.txt",
		        "node_list_path": "1470593.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpWchac010034Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. WCHAc010034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpWchac010034Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1879049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1879049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1879049.clusters.proteins.v11.5.txt",
		        "sequence_path": "1879049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1879049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1879049.protein.info.v11.5.txt",
		        "node_list_path": "1879049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1879049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaXiamenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaXiamenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "332186.clusters.info.v11.5.txt",
		        "cluster_tree_path": "332186.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "332186.clusters.proteins.v11.5.txt",
		        "sequence_path": "332186.protein.sequences.v11.5.fa",
		        "enrichment_path": "332186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332186.protein.info.v11.5.txt",
		        "node_list_path": "332186.cluster.nodes.v11.5.txt",
		        "edge_list_path": "332186.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriaceaeBacteriumP6a17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacteriaceae bacterium P6A17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriaceaeBacteriumP6a17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410634.protein.info.v11.5.txt",
		        "node_list_path": "1410634.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlochmanniaFloridanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia floridanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlochmanniaFloridanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "203907.clusters.info.v11.5.txt",
		        "cluster_tree_path": "203907.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "203907.clusters.proteins.v11.5.txt",
		        "sequence_path": "203907.protein.sequences.v11.5.fa",
		        "enrichment_path": "203907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203907.protein.info.v11.5.txt",
		        "node_list_path": "203907.cluster.nodes.v11.5.txt",
		        "edge_list_path": "203907.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumPlurifarium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium plurifarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumPlurifarium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69974.protein.sequences.v11.5.fa",
		        "enrichment_path": "69974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69974.protein.info.v11.5.txt",
		        "node_list_path": "69974.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaPsychrophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaPsychrophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1476.clusters.proteins.v11.5.txt",
		        "sequence_path": "1476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1476.protein.info.v11.5.txt",
		        "node_list_path": "1476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeanutWitchesbroom(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peanut witchesbroom graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeanutWitchesbroom", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163385.protein.info.v11.5.txt",
		        "node_list_path": "1163385.protein.complete.v11.5.txt"
		    }
		]
    )()

def LewinellaPersica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lewinella persica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LewinellaPersica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122179.protein.info.v11.5.txt",
		        "node_list_path": "1122179.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwd24214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWD2_42_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwd24214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618944.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618944.protein.info.v11.5.txt",
		        "node_list_path": "1618944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaNovaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia nova Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaNovaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415166.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415166.protein.info.v11.5.txt",
		        "node_list_path": "1415166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeratocystisFimbriataCbs114723Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ceratocystis fimbriata CBS 114723 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeratocystisFimbriataCbs114723Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035309.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035309.protein.info.v11.5.txt",
		        "node_list_path": "1035309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchistosomaRodhainiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma rodhaini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaRodhainiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6188.clusters.proteins.v11.5.txt",
		        "sequence_path": "6188.protein.sequences.v11.5.fa",
		        "enrichment_path": "6188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6188.protein.info.v11.5.txt",
		        "node_list_path": "6188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NostocAzollaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nostoc azollae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocAzollaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "551115.clusters.info.v11.5.txt",
		        "cluster_tree_path": "551115.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "551115.clusters.proteins.v11.5.txt",
		        "sequence_path": "551115.protein.sequences.v11.5.fa",
		        "enrichment_path": "551115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551115.protein.info.v11.5.txt",
		        "node_list_path": "551115.cluster.nodes.v11.5.txt",
		        "edge_list_path": "551115.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaAichiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia aichiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaAichiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220583.protein.info.v11.5.txt",
		        "node_list_path": "1220583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg135211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_52_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg135211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797829.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797829.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797829.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797829.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797829.protein.info.v11.5.txt",
		        "node_list_path": "1797829.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797829.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumBranchiophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium branchiophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumBranchiophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1034807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034807.protein.info.v11.5.txt",
		        "node_list_path": "1034807.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpWy10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. WY10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpWy10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1920667.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920667.protein.info.v11.5.txt",
		        "node_list_path": "1920667.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag95Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag95Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262988.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262988.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262988.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262988.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262988.protein.info.v11.5.txt",
		        "node_list_path": "1262988.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262988.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CylindrospermopsisRaciborskii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cylindrospermopsis raciborskii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CylindrospermopsisRaciborskii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "533240.protein.sequences.v11.5.fa",
		        "enrichment_path": "533240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "533240.protein.info.v11.5.txt",
		        "node_list_path": "533240.protein.complete.v11.5.txt"
		    }
		]
    )()

def TheileriaAnnulataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Theileria annulata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheileriaAnnulataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5874.clusters.proteins.v11.5.txt",
		        "sequence_path": "5874.protein.sequences.v11.5.fa",
		        "enrichment_path": "5874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5874.protein.info.v11.5.txt",
		        "node_list_path": "5874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_44_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798689.protein.info.v11.5.txt",
		        "node_list_path": "1798689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpLm2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. LM2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpLm2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1938605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938605.protein.info.v11.5.txt",
		        "node_list_path": "1938605.protein.complete.v11.5.txt"
		    }
		]
    )()

def WenzhouxiangellaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wenzhouxiangella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WenzhouxiangellaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1579979.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1579979.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1579979.clusters.proteins.v11.5.txt",
		        "sequence_path": "1579979.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579979.protein.info.v11.5.txt",
		        "node_list_path": "1579979.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1579979.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeonGw2011Ar18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return archaeon GW2011_AR18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeonGw2011Ar18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1579376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1579376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1579376.clusters.proteins.v11.5.txt",
		        "sequence_path": "1579376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579376.protein.info.v11.5.txt",
		        "node_list_path": "1579376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1579376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalpingoecaRosettaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salpingoeca rosetta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalpingoecaRosettaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "946362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "946362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "946362.clusters.proteins.v11.5.txt",
		        "sequence_path": "946362.protein.sequences.v11.5.fa",
		        "enrichment_path": "946362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946362.protein.info.v11.5.txt",
		        "node_list_path": "946362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "946362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaXyliCynodontisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia xyli cynodontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaXyliCynodontisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1389489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1389489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1389489.clusters.proteins.v11.5.txt",
		        "sequence_path": "1389489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1389489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1389489.protein.info.v11.5.txt",
		        "node_list_path": "1389489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1389489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesRapamycinicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces rapamycinicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRapamycinicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1343740.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1343740.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1343740.clusters.proteins.v11.5.txt",
		        "sequence_path": "1343740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1343740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1343740.protein.info.v11.5.txt",
		        "node_list_path": "1343740.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1343740.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlB1140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL B-1140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlB1140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415549.protein.info.v11.5.txt",
		        "node_list_path": "1415549.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusRaffinolactisNbrc100932(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis NBRC 100932 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusRaffinolactisNbrc100932", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348633.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348633.protein.info.v11.5.txt",
		        "node_list_path": "1348633.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4315b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_01_FULL_43_15b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4315b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797513.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797513.protein.info.v11.5.txt",
		        "node_list_path": "1797513.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBrocadiaSpUtamx2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sp. UTAMX2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBrocadiaSpUtamx2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1961114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961114.protein.info.v11.5.txt",
		        "node_list_path": "1961114.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusUltunensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ultunensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusUltunensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525365.clusters.proteins.v11.5.txt",
		        "sequence_path": "525365.protein.sequences.v11.5.fa",
		        "enrichment_path": "525365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525365.protein.info.v11.5.txt",
		        "node_list_path": "525365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusNiameyensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus niameyensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusNiameyensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1522308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1522308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1522308.clusters.proteins.v11.5.txt",
		        "sequence_path": "1522308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522308.protein.info.v11.5.txt",
		        "node_list_path": "1522308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1522308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium4316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 43-16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium4316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895923.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895923.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895923.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895923.protein.info.v11.5.txt",
		        "node_list_path": "1895923.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895923.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GolovinomycesCichoracearumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Golovinomyces cichoracearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GolovinomycesCichoracearumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "62708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "62708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "62708.clusters.proteins.v11.5.txt",
		        "sequence_path": "62708.protein.sequences.v11.5.fa",
		        "enrichment_path": "62708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62708.protein.info.v11.5.txt",
		        "node_list_path": "62708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "62708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusGammatoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus gammatolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusGammatoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "593117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "593117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "593117.clusters.proteins.v11.5.txt",
		        "sequence_path": "593117.protein.sequences.v11.5.fa",
		        "enrichment_path": "593117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "593117.protein.info.v11.5.txt",
		        "node_list_path": "593117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "593117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GracilibacillusKekensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus kekensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusKekensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1027249.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1027249.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1027249.clusters.proteins.v11.5.txt",
		        "sequence_path": "1027249.protein.sequences.v11.5.fa",
		        "enrichment_path": "1027249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1027249.protein.info.v11.5.txt",
		        "node_list_path": "1027249.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1027249.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumScgcAaa536N21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA536-N21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumScgcAaa536N21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1009711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009711.protein.info.v11.5.txt",
		        "node_list_path": "1009711.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesKanasensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces kanasensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesKanasensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936756.protein.sequences.v11.5.fa",
		        "enrichment_path": "936756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936756.protein.info.v11.5.txt",
		        "node_list_path": "936756.protein.complete.v11.5.txt"
		    }
		]
    )()

def FontimonasThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fontimonas thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FontimonasThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1076937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1076937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1076937.clusters.proteins.v11.5.txt",
		        "sequence_path": "1076937.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076937.protein.info.v11.5.txt",
		        "node_list_path": "1076937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1076937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMg1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Mg1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMg1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "465541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "465541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "465541.clusters.proteins.v11.5.txt",
		        "sequence_path": "465541.protein.sequences.v11.5.fa",
		        "enrichment_path": "465541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "465541.protein.info.v11.5.txt",
		        "node_list_path": "465541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "465541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusHaemoperoxidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus haemoperoxidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusHaemoperoxidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158608.protein.info.v11.5.txt",
		        "node_list_path": "1158608.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonasJohnsoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas johnsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasJohnsoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280950.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280950.protein.info.v11.5.txt",
		        "node_list_path": "1280950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichomonasVaginalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichomonas vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichomonasVaginalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5722.protein.sequences.v11.5.fa",
		        "enrichment_path": "5722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5722.protein.info.v11.5.txt",
		        "node_list_path": "5722.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSpRc586(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. RC586 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpRc586", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675815.protein.sequences.v11.5.fa",
		        "enrichment_path": "675815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675815.protein.info.v11.5.txt",
		        "node_list_path": "675815.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraPelophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira pelophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraPelophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123517.protein.info.v11.5.txt",
		        "node_list_path": "1123517.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioThiocyanoxidansArh(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArh", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "713587.protein.sequences.v11.5.fa",
		        "enrichment_path": "713587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713587.protein.info.v11.5.txt",
		        "node_list_path": "713587.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpHmsc067h01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. HMSC067H01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpHmsc067h01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739491.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739491.protein.info.v11.5.txt",
		        "node_list_path": "1739491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MangrovibacterPhragmitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mangrovibacter phragmitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MangrovibacterPhragmitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1691903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1691903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1691903.protein.info.v11.5.txt",
		        "node_list_path": "1691903.protein.complete.v11.5.txt"
		    }
		]
    )()

def EctothiorhodospiraMobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ectothiorhodospira mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctothiorhodospiraMobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "195064.protein.sequences.v11.5.fa",
		        "enrichment_path": "195064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195064.protein.info.v11.5.txt",
		        "node_list_path": "195064.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanococcusAntarcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planococcus antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusAntarcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1185653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1185653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1185653.clusters.proteins.v11.5.txt",
		        "sequence_path": "1185653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185653.protein.info.v11.5.txt",
		        "node_list_path": "1185653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1185653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermotogaProfundaAzm34c06Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga profunda AZM34c06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaProfundaAzm34c06Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408160.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408160.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408160.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408160.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408160.protein.info.v11.5.txt",
		        "node_list_path": "1408160.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408160.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumGw2011Gwc23423(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWC2_34_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwc23423", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618484.protein.info.v11.5.txt",
		        "node_list_path": "1618484.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacteriumGwa27335(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium GWA2_73_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacteriumGwa27335", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802096.protein.info.v11.5.txt",
		        "node_list_path": "1802096.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3713Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_37_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3713Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802057.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802057.protein.info.v11.5.txt",
		        "node_list_path": "1802057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaSpAap35Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. AAP35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpAap35Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523417.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523417.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523417.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523417.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523417.protein.info.v11.5.txt",
		        "node_list_path": "1523417.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523417.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SorghumBicolor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sorghum bicolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SorghumBicolor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4558.protein.sequences.v11.5.fa",
		        "enrichment_path": "4558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4558.protein.info.v11.5.txt",
		        "node_list_path": "4558.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpUrmo17wk12i8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. URMO17WK12I8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpUrmo17wk12i8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265490.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265490.protein.info.v11.5.txt",
		        "node_list_path": "1265490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumSg830(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium SG8_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumSg830", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703404.protein.info.v11.5.txt",
		        "node_list_path": "1703404.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArenibacterTroitsensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arenibacter troitsensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenibacterTroitsensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "188872.protein.sequences.v11.5.fa",
		        "enrichment_path": "188872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188872.protein.info.v11.5.txt",
		        "node_list_path": "188872.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaAdelaidensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella adelaidensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaAdelaidensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45056.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45056.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45056.clusters.proteins.v11.5.txt",
		        "sequence_path": "45056.protein.sequences.v11.5.fa",
		        "enrichment_path": "45056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45056.protein.info.v11.5.txt",
		        "node_list_path": "45056.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45056.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaGenomosp13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaGenomosp13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "463040.clusters.info.v11.5.txt",
		        "cluster_tree_path": "463040.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "463040.clusters.proteins.v11.5.txt",
		        "sequence_path": "463040.protein.sequences.v11.5.fa",
		        "enrichment_path": "463040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "463040.protein.info.v11.5.txt",
		        "node_list_path": "463040.cluster.nodes.v11.5.txt",
		        "edge_list_path": "463040.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "874156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "874156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "874156.clusters.proteins.v11.5.txt",
		        "sequence_path": "874156.protein.sequences.v11.5.fa",
		        "enrichment_path": "874156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "874156.protein.info.v11.5.txt",
		        "node_list_path": "874156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "874156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumMar2010188Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium MAR_2010_188 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumMar2010188Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1250295.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1250295.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1250295.clusters.proteins.v11.5.txt",
		        "sequence_path": "1250295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250295.protein.info.v11.5.txt",
		        "node_list_path": "1250295.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1250295.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AminobacterAminovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aminobacter aminovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminobacterAminovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83263.protein.sequences.v11.5.fa",
		        "enrichment_path": "83263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83263.protein.info.v11.5.txt",
		        "node_list_path": "83263.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusCanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusCanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "214095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "214095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "214095.clusters.proteins.v11.5.txt",
		        "sequence_path": "214095.protein.sequences.v11.5.fa",
		        "enrichment_path": "214095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "214095.protein.info.v11.5.txt",
		        "node_list_path": "214095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "214095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosospiraSpNsp11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraSpNsp11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855338.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855338.protein.info.v11.5.txt",
		        "node_list_path": "1855338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusLacustrisStrTous(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus lacustris str. Tous graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusLacustrisStrTous", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1910958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1910958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1910958.protein.info.v11.5.txt",
		        "node_list_path": "1910958.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpCf149Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CF149 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpCf149Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "911239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "911239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "911239.clusters.proteins.v11.5.txt",
		        "sequence_path": "911239.protein.sequences.v11.5.fa",
		        "enrichment_path": "911239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "911239.protein.info.v11.5.txt",
		        "node_list_path": "911239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "911239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UliginosibacteriumGangwonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Uliginosibacterium gangwonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UliginosibacteriumGangwonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123487.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123487.protein.info.v11.5.txt",
		        "node_list_path": "1123487.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpWaoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. WAO Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpWaoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "406341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "406341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "406341.clusters.proteins.v11.5.txt",
		        "sequence_path": "406341.protein.sequences.v11.5.fa",
		        "enrichment_path": "406341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406341.protein.info.v11.5.txt",
		        "node_list_path": "406341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "406341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeonGw2011Ar10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return archaeon GW2011_AR10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeonGw2011Ar10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1579370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1579370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1579370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1579370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579370.protein.info.v11.5.txt",
		        "node_list_path": "1579370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1579370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusLehensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus lehensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLehensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246626.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246626.protein.info.v11.5.txt",
		        "node_list_path": "1246626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusNematophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus nematophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusNematophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "406817.protein.sequences.v11.5.fa",
		        "enrichment_path": "406817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406817.protein.info.v11.5.txt",
		        "node_list_path": "406817.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeorhizobiumGalegaeOfficinalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae officinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorhizobiumGalegaeOfficinalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1028801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028801.protein.info.v11.5.txt",
		        "node_list_path": "1028801.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumScgcAaa536G10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA536-G10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumScgcAaa536G10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1009708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009708.protein.info.v11.5.txt",
		        "node_list_path": "1009708.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumDrakei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium drakei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumDrakei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "332101.protein.sequences.v11.5.fa",
		        "enrichment_path": "332101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332101.protein.info.v11.5.txt",
		        "node_list_path": "332101.protein.complete.v11.5.txt"
		    }
		]
    )()

def SteroidobacterDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Steroidobacter denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SteroidobacterDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "465721.protein.sequences.v11.5.fa",
		        "enrichment_path": "465721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "465721.protein.info.v11.5.txt",
		        "node_list_path": "465721.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterFetusVenerealisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus venerealis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterFetusVenerealisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983328.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983328.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983328.clusters.proteins.v11.5.txt",
		        "sequence_path": "983328.protein.sequences.v11.5.fa",
		        "enrichment_path": "983328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983328.protein.info.v11.5.txt",
		        "node_list_path": "983328.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983328.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PluralibacterGergoviae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pluralibacter gergoviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PluralibacterGergoviae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61647.protein.sequences.v11.5.fa",
		        "enrichment_path": "61647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61647.protein.info.v11.5.txt",
		        "node_list_path": "61647.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4718(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_47_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4718", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802313.protein.info.v11.5.txt",
		        "node_list_path": "1802313.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumScgcAaa536K22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA536-K22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumScgcAaa536K22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1009709.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1009709.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1009709.clusters.proteins.v11.5.txt",
		        "sequence_path": "1009709.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009709.protein.info.v11.5.txt",
		        "node_list_path": "1009709.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1009709.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterSpLa11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. LA11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSpLa11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1898176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1898176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1898176.clusters.proteins.v11.5.txt",
		        "sequence_path": "1898176.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898176.protein.info.v11.5.txt",
		        "node_list_path": "1898176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1898176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrochothrixCampestrisFslF61037Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brochothrix campestris FSL F6-1037 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrochothrixCampestrisFslF61037Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265861.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265861.protein.info.v11.5.txt",
		        "node_list_path": "1265861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollinsellaIhuaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collinsella ihuae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaIhuaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720204.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720204.protein.info.v11.5.txt",
		        "node_list_path": "1720204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpPcc6406(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC6406 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpPcc6406", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173264.protein.info.v11.5.txt",
		        "node_list_path": "1173264.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsplowo201Full4510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO2_01_FULL_45_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo201Full4510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801826.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801826.protein.info.v11.5.txt",
		        "node_list_path": "1801826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusEndophyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus endophyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusEndophyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196029.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196029.protein.info.v11.5.txt",
		        "node_list_path": "1196029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BelnapiaMoabensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Belnapia moabensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BelnapiaMoabensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121106.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121106.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121106.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121106.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121106.protein.info.v11.5.txt",
		        "node_list_path": "1121106.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121106.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorhabdusTiamateaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorhabdus tiamatea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorhabdusTiamateaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033806.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033806.protein.info.v11.5.txt",
		        "node_list_path": "1033806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaeCc1417Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1417 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaeCc1417Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1357272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1357272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1357272.clusters.proteins.v11.5.txt",
		        "sequence_path": "1357272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357272.protein.info.v11.5.txt",
		        "node_list_path": "1357272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1357272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumCosmeticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium cosmeticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumCosmeticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "258533.protein.sequences.v11.5.fa",
		        "enrichment_path": "258533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "258533.protein.info.v11.5.txt",
		        "node_list_path": "258533.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumAcidiphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium acidiphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumAcidiphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122612.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122612.protein.info.v11.5.txt",
		        "node_list_path": "1122612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaOrisDsm18711Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris DSM18711 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOrisDsm18711Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122989.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122989.protein.info.v11.5.txt",
		        "node_list_path": "1122989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlloactinosynnemaAlbumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alloactinosynnema album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloactinosynnemaAlbumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "504798.clusters.info.v11.5.txt",
		        "cluster_tree_path": "504798.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "504798.clusters.proteins.v11.5.txt",
		        "sequence_path": "504798.protein.sequences.v11.5.fa",
		        "enrichment_path": "504798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504798.protein.info.v11.5.txt",
		        "node_list_path": "504798.cluster.nodes.v11.5.txt",
		        "edge_list_path": "504798.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioDiazotrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio diazotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioDiazotrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348635.protein.info.v11.5.txt",
		        "node_list_path": "1348635.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumScgcAaa015N04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA015-N04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumScgcAaa015N04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "939296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "939296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "939296.clusters.proteins.v11.5.txt",
		        "sequence_path": "939296.protein.sequences.v11.5.fa",
		        "enrichment_path": "939296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939296.protein.info.v11.5.txt",
		        "node_list_path": "939296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "939296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSp6736(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 67-36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSp6736", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895849.protein.info.v11.5.txt",
		        "node_list_path": "1895849.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaLaidlawiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma laidlawii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaLaidlawiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "441768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "441768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "441768.clusters.proteins.v11.5.txt",
		        "sequence_path": "441768.protein.sequences.v11.5.fa",
		        "enrichment_path": "441768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441768.protein.info.v11.5.txt",
		        "node_list_path": "441768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "441768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpLeaf404Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf404 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpLeaf404Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736366.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736366.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736366.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736366.protein.info.v11.5.txt",
		        "node_list_path": "1736366.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736366.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterSpLm6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. LM 6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterSpLm6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896196.protein.info.v11.5.txt",
		        "node_list_path": "1896196.protein.complete.v11.5.txt"
		    }
		]
    )()

def RivulariaSpPcc7116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rivularia sp. PCC7116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RivulariaSpPcc7116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "373994.protein.sequences.v11.5.fa",
		        "enrichment_path": "373994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "373994.protein.info.v11.5.txt",
		        "node_list_path": "373994.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyncephalastrumRacemosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syncephalastrum racemosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyncephalastrumRacemosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13706.protein.sequences.v11.5.fa",
		        "enrichment_path": "13706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13706.protein.info.v11.5.txt",
		        "node_list_path": "13706.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsphigho202Full4114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_02_FULL_41_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho202Full4114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797775.protein.info.v11.5.txt",
		        "node_list_path": "1797775.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalariasFasciatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salarias fasciatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalariasFasciatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "181472.clusters.info.v11.5.txt",
		        "cluster_tree_path": "181472.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "181472.clusters.proteins.v11.5.txt",
		        "sequence_path": "181472.protein.sequences.v11.5.fa",
		        "enrichment_path": "181472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "181472.protein.info.v11.5.txt",
		        "node_list_path": "181472.cluster.nodes.v11.5.txt",
		        "edge_list_path": "181472.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacinutrixVenerupis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix venerupis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixVenerupis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1486034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1486034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1486034.protein.info.v11.5.txt",
		        "node_list_path": "1486034.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaSteelei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella steelei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaSteelei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "947033.protein.sequences.v11.5.fa",
		        "enrichment_path": "947033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "947033.protein.info.v11.5.txt",
		        "node_list_path": "947033.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusThioglobusAutotrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus autotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThioglobusAutotrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1705394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705394.protein.info.v11.5.txt",
		        "node_list_path": "1705394.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiastellaVici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Niastella vici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiastellaVici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703345.protein.info.v11.5.txt",
		        "node_list_path": "1703345.protein.complete.v11.5.txt"
		    }
		]
    )()

def JeongeupiaSpUsm3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jeongeupia sp. USM3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeongeupiaSpUsm3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906741.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906741.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906741.protein.info.v11.5.txt",
		        "node_list_path": "1906741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumSporotrichioidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium sporotrichioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumSporotrichioidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5514.clusters.proteins.v11.5.txt",
		        "sequence_path": "5514.protein.sequences.v11.5.fa",
		        "enrichment_path": "5514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5514.protein.info.v11.5.txt",
		        "node_list_path": "5514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaOralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28134.protein.sequences.v11.5.fa",
		        "enrichment_path": "28134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28134.protein.info.v11.5.txt",
		        "node_list_path": "28134.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpC06(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpC06", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945854.protein.info.v11.5.txt",
		        "node_list_path": "1945854.protein.complete.v11.5.txt"
		    }
		]
    )()

def OgataeaParapolymorphaDl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ogataea parapolymorpha DL-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OgataeaParapolymorphaDl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "871575.protein.sequences.v11.5.fa",
		        "enrichment_path": "871575.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871575.protein.info.v11.5.txt",
		        "node_list_path": "871575.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzisolibacterPropanilivorax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryzisolibacter propanilivorax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzisolibacterPropanilivorax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1527607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1527607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1527607.protein.info.v11.5.txt",
		        "node_list_path": "1527607.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusDestructansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus destructans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusDestructansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655981.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655981.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655981.clusters.proteins.v11.5.txt",
		        "sequence_path": "655981.protein.sequences.v11.5.fa",
		        "enrichment_path": "655981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655981.protein.info.v11.5.txt",
		        "node_list_path": "655981.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655981.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacterium51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 5-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacterium51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1962178.protein.sequences.v11.5.fa",
		        "enrichment_path": "1962178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1962178.protein.info.v11.5.txt",
		        "node_list_path": "1962178.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanicolaLitoreus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola litoreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaLitoreus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217970.protein.info.v11.5.txt",
		        "node_list_path": "1217970.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterSpHtcc2170Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter sp. HTCC2170 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterSpHtcc2170Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313603.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313603.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313603.clusters.proteins.v11.5.txt",
		        "sequence_path": "313603.protein.sequences.v11.5.fa",
		        "enrichment_path": "313603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313603.protein.info.v11.5.txt",
		        "node_list_path": "313603.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313603.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesMegasporus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces megasporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesMegasporus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44060.protein.sequences.v11.5.fa",
		        "enrichment_path": "44060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44060.protein.info.v11.5.txt",
		        "node_list_path": "44060.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpPao19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. PAO19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpPao19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1096756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1096756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1096756.protein.info.v11.5.txt",
		        "node_list_path": "1096756.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpAc2796Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. AC27/96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpAc2796Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841653.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841653.protein.info.v11.5.txt",
		        "node_list_path": "1841653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpP5119(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. P5-119 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpP5119", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1602171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1602171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1602171.protein.info.v11.5.txt",
		        "node_list_path": "1602171.protein.complete.v11.5.txt"
		    }
		]
    )()

def IsoptericolaVariabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Isoptericola variabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IsoptericolaVariabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743718.clusters.proteins.v11.5.txt",
		        "sequence_path": "743718.protein.sequences.v11.5.fa",
		        "enrichment_path": "743718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743718.protein.info.v11.5.txt",
		        "node_list_path": "743718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSp83(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSp83", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131812.protein.info.v11.5.txt",
		        "node_list_path": "1131812.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsplowo201Full5421(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_54_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full5421", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802279.protein.info.v11.5.txt",
		        "node_list_path": "1802279.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtopobiumParvulum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium parvulum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumParvulum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521095.protein.sequences.v11.5.fa",
		        "enrichment_path": "521095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521095.protein.info.v11.5.txt",
		        "node_list_path": "521095.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraHibiscaNbrc15177(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura hibisca NBRC 15177 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraHibiscaNbrc15177", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220559.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220559.protein.info.v11.5.txt",
		        "node_list_path": "1220559.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThelaziaCallipaeda(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thelazia callipaeda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThelaziaCallipaeda", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "103827.protein.sequences.v11.5.fa",
		        "enrichment_path": "103827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103827.protein.info.v11.5.txt",
		        "node_list_path": "103827.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProsthecochlorisSpHl130GsbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prosthecochloris sp. HL-130-GSB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProsthecochlorisSpHl130GsbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1974213.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1974213.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1974213.clusters.proteins.v11.5.txt",
		        "sequence_path": "1974213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1974213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1974213.protein.info.v11.5.txt",
		        "node_list_path": "1974213.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1974213.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24023(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_40_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24023", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618816.protein.info.v11.5.txt",
		        "node_list_path": "1618816.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaSediminilitoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia sediminilitoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaSediminilitoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1820336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1820336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1820336.protein.info.v11.5.txt",
		        "node_list_path": "1820336.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsplowo212Full6019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_12_FULL_60_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo212Full6019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797894.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797894.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797894.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797894.protein.info.v11.5.txt",
		        "node_list_path": "1797894.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797894.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpPrM31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. PR-M31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpPrM31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1471202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471202.protein.info.v11.5.txt",
		        "node_list_path": "1471202.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureimonasSpAu4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpAu4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1638163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1638163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1638163.clusters.proteins.v11.5.txt",
		        "sequence_path": "1638163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638163.protein.info.v11.5.txt",
		        "node_list_path": "1638163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1638163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalothrixSpHk06Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Calothrix sp. HK-06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalothrixSpHk06Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1137096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1137096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1137096.clusters.proteins.v11.5.txt",
		        "sequence_path": "1137096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137096.protein.info.v11.5.txt",
		        "node_list_path": "1137096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1137096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusSp217(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius sp. 217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusSp217", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314264.protein.sequences.v11.5.fa",
		        "enrichment_path": "314264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314264.protein.info.v11.5.txt",
		        "node_list_path": "314264.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumChilenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium chilense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumChilenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "946677.clusters.info.v11.5.txt",
		        "cluster_tree_path": "946677.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "946677.clusters.proteins.v11.5.txt",
		        "sequence_path": "946677.protein.sequences.v11.5.fa",
		        "enrichment_path": "946677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946677.protein.info.v11.5.txt",
		        "node_list_path": "946677.cluster.nodes.v11.5.txt",
		        "edge_list_path": "946677.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwf1525(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWF1_52_5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwf1525", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618959.protein.info.v11.5.txt",
		        "node_list_path": "1618959.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb245a518a17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_518A17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb245a518a17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1471501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471501.protein.info.v11.5.txt",
		        "node_list_path": "1471501.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGa0077536(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0077536 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGa0077536", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752214.protein.info.v11.5.txt",
		        "node_list_path": "1752214.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusLentusNbrc16444(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus lentus NBRC 16444 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLentusNbrc16444", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348624.protein.info.v11.5.txt",
		        "node_list_path": "1348624.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaludisphaeraBorealis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paludisphaera borealis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaludisphaeraBorealis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1387353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387353.protein.info.v11.5.txt",
		        "node_list_path": "1387353.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColumbaLiviaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Columba livia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColumbaLiviaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8932.clusters.proteins.v11.5.txt",
		        "sequence_path": "8932.protein.sequences.v11.5.fa",
		        "enrichment_path": "8932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8932.protein.info.v11.5.txt",
		        "node_list_path": "8932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TenericutesBacteriumGwf235184Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWF2_35_184 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenericutesBacteriumGwf235184Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802352.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802352.protein.info.v11.5.txt",
		        "node_list_path": "1802352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaSpCag303Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSpCag303Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262944.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262944.protein.info.v11.5.txt",
		        "node_list_path": "1262944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloracidobacteriumThermophilumBCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloracidobacterium thermophilum B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloracidobacteriumThermophilumBCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "981222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "981222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "981222.clusters.proteins.v11.5.txt",
		        "sequence_path": "981222.protein.sequences.v11.5.fa",
		        "enrichment_path": "981222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981222.protein.info.v11.5.txt",
		        "node_list_path": "981222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "981222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaloramatorAustralicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caloramator australicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloramatorAustralicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "857293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "857293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "857293.clusters.proteins.v11.5.txt",
		        "sequence_path": "857293.protein.sequences.v11.5.fa",
		        "enrichment_path": "857293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857293.protein.info.v11.5.txt",
		        "node_list_path": "857293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "857293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioLitoralisDsm17657(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio litoralis DSM 17657 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioLitoralisDsm17657", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123493.protein.info.v11.5.txt",
		        "node_list_path": "1123493.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesPyogenesJcm10003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides pyogenes JCM10003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesPyogenesJcm10003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235813.protein.info.v11.5.txt",
		        "node_list_path": "1235813.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807738.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807738.protein.info.v11.5.txt",
		        "node_list_path": "1807738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusLuciferensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus luciferensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLuciferensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "178774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "178774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "178774.clusters.proteins.v11.5.txt",
		        "sequence_path": "178774.protein.sequences.v11.5.fa",
		        "enrichment_path": "178774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178774.protein.info.v11.5.txt",
		        "node_list_path": "178774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "178774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE183(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E183 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE183", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834129.protein.info.v11.5.txt",
		        "node_list_path": "1834129.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterPyloriSouthafrica7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori SouthAfrica7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterPyloriSouthafrica7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "907239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "907239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "907239.clusters.proteins.v11.5.txt",
		        "sequence_path": "907239.protein.sequences.v11.5.fa",
		        "enrichment_path": "907239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "907239.protein.info.v11.5.txt",
		        "node_list_path": "907239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "907239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivirgaSeohaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseivirga seohaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivirgaSeohaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1914963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1914963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1914963.clusters.proteins.v11.5.txt",
		        "sequence_path": "1914963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1914963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1914963.protein.info.v11.5.txt",
		        "node_list_path": "1914963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1914963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_40_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802064.protein.info.v11.5.txt",
		        "node_list_path": "1802064.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumEmbrapenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium embrapense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumEmbrapenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "630921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "630921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "630921.clusters.proteins.v11.5.txt",
		        "sequence_path": "630921.protein.sequences.v11.5.fa",
		        "enrichment_path": "630921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "630921.protein.info.v11.5.txt",
		        "node_list_path": "630921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "630921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho201Full4622b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_01_FULL_46_22b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho201Full4622b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802301.protein.info.v11.5.txt",
		        "node_list_path": "1802301.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumJensenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium jensenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumJensenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122997.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122997.protein.info.v11.5.txt",
		        "node_list_path": "1122997.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseivivaxMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379903.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379903.protein.info.v11.5.txt",
		        "node_list_path": "1379903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CanisLupusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Canis lupus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CanisLupusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9612.clusters.proteins.v11.5.txt",
		        "sequence_path": "9612.protein.sequences.v11.5.fa",
		        "enrichment_path": "9612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9612.protein.info.v11.5.txt",
		        "node_list_path": "9612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GilvimarinusPolysaccharolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gilvimarinus polysaccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilvimarinusPolysaccharolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "863921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "863921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "863921.clusters.proteins.v11.5.txt",
		        "sequence_path": "863921.protein.sequences.v11.5.fa",
		        "enrichment_path": "863921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "863921.protein.info.v11.5.txt",
		        "node_list_path": "863921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "863921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "487316.protein.sequences.v11.5.fa",
		        "enrichment_path": "487316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487316.protein.info.v11.5.txt",
		        "node_list_path": "487316.protein.complete.v11.5.txt"
		    }
		]
    )()

def PodarcisMuralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Podarcis muralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PodarcisMuralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "64176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "64176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "64176.clusters.proteins.v11.5.txt",
		        "sequence_path": "64176.protein.sequences.v11.5.fa",
		        "enrichment_path": "64176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64176.protein.info.v11.5.txt",
		        "node_list_path": "64176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "64176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColwelliaSpMt41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia sp. MT41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaSpMt41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "58049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "58049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "58049.clusters.proteins.v11.5.txt",
		        "sequence_path": "58049.protein.sequences.v11.5.fa",
		        "enrichment_path": "58049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58049.protein.info.v11.5.txt",
		        "node_list_path": "58049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "58049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PichiaKudriavzeviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pichia kudriavzevii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PichiaKudriavzeviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4909.clusters.proteins.v11.5.txt",
		        "sequence_path": "4909.protein.sequences.v11.5.fa",
		        "enrichment_path": "4909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4909.protein.info.v11.5.txt",
		        "node_list_path": "4909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPrasinopilosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces prasinopilosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPrasinopilosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67344.protein.sequences.v11.5.fa",
		        "enrichment_path": "67344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67344.protein.info.v11.5.txt",
		        "node_list_path": "67344.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobellusRufusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobellus rufus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobellusRufusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1448860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1448860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1448860.clusters.proteins.v11.5.txt",
		        "sequence_path": "1448860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448860.protein.info.v11.5.txt",
		        "node_list_path": "1448860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1448860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpUrha0036(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. URHA0036 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpUrha0036", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298860.protein.info.v11.5.txt",
		        "node_list_path": "1298860.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpLmtr3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LMTR 3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpLmtr3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "189873.clusters.info.v11.5.txt",
		        "cluster_tree_path": "189873.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "189873.clusters.proteins.v11.5.txt",
		        "sequence_path": "189873.protein.sequences.v11.5.fa",
		        "enrichment_path": "189873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189873.protein.info.v11.5.txt",
		        "node_list_path": "189873.cluster.nodes.v11.5.txt",
		        "edge_list_path": "189873.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5053(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5053 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5053", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463854.protein.info.v11.5.txt",
		        "node_list_path": "1463854.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarum248(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum 248 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarum248", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936136.protein.sequences.v11.0.fa",
		        "enrichment_path": "936136.protein.enrichment.terms.v11.0.txt",
		        "info_path": "936136.protein.info.v11.0.txt",
		        "node_list_path": "936136.protein.complete.v11.0.txt"
		    }
		]
    )()

def ClostridiumLitoraleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium litorale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumLitoraleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121324.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121324.protein.info.v11.5.txt",
		        "node_list_path": "1121324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumNepotum397Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium nepotum 39/7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumNepotum397Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1368418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1368418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1368418.clusters.proteins.v11.5.txt",
		        "sequence_path": "1368418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1368418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1368418.protein.info.v11.5.txt",
		        "node_list_path": "1368418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1368418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FormosaAgariphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Formosa agariphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaAgariphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1347342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347342.protein.info.v11.5.txt",
		        "node_list_path": "1347342.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobotryumIntermediumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbotryum intermedium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobotryumIntermediumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "269621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "269621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "269621.clusters.proteins.v11.5.txt",
		        "sequence_path": "269621.protein.sequences.v11.5.fa",
		        "enrichment_path": "269621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269621.protein.info.v11.5.txt",
		        "node_list_path": "269621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "269621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasBorbori(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas borbori graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBorbori", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "289003.protein.sequences.v11.5.fa",
		        "enrichment_path": "289003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "289003.protein.info.v11.5.txt",
		        "node_list_path": "289003.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachymonasDenitrificansDsm15123Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachymonas denitrificans DSM 15123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachymonasDenitrificansDsm15123Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121117.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121117.protein.info.v11.5.txt",
		        "node_list_path": "1121117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacterHiberniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter hiberniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterHiberniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29314.protein.sequences.v11.5.fa",
		        "enrichment_path": "29314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29314.protein.info.v11.5.txt",
		        "node_list_path": "29314.protein.complete.v11.5.txt"
		    }
		]
    )()

def InsolitispirillumPeregrinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Insolitispirillum peregrinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "InsolitispirillumPeregrinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "80876.protein.sequences.v11.5.fa",
		        "enrichment_path": "80876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80876.protein.info.v11.5.txt",
		        "node_list_path": "80876.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaProteobacteriumCbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return beta proteobacterium CB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaProteobacteriumCbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "543913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "543913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "543913.clusters.proteins.v11.5.txt",
		        "sequence_path": "543913.protein.sequences.v11.5.fa",
		        "enrichment_path": "543913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543913.protein.info.v11.5.txt",
		        "node_list_path": "543913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "543913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAccolens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium accolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAccolens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525260.protein.sequences.v11.5.fa",
		        "enrichment_path": "525260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525260.protein.info.v11.5.txt",
		        "node_list_path": "525260.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinisporaTropica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinispora tropica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisporaTropica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "369723.protein.sequences.v11.5.fa",
		        "enrichment_path": "369723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "369723.protein.info.v11.5.txt",
		        "node_list_path": "369723.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphaerochaetaCoccoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphaerochaeta coccoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerochaetaCoccoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "760011.protein.sequences.v11.5.fa",
		        "enrichment_path": "760011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "760011.protein.info.v11.5.txt",
		        "node_list_path": "760011.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxTemperansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax temperans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxTemperansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "80878.clusters.info.v11.5.txt",
		        "cluster_tree_path": "80878.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "80878.clusters.proteins.v11.5.txt",
		        "sequence_path": "80878.protein.sequences.v11.5.fa",
		        "enrichment_path": "80878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80878.protein.info.v11.5.txt",
		        "node_list_path": "80878.cluster.nodes.v11.5.txt",
		        "edge_list_path": "80878.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBrennerbacteriaBacteriumRifoxyd1Full4116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brennerbacteria bacterium RIFOXYD1_FULL_41_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBrennerbacteriaBacteriumRifoxyd1Full4116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797529.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797529.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797529.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797529.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797529.protein.info.v11.5.txt",
		        "node_list_path": "1797529.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797529.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwt2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwt2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896224.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896224.protein.info.v11.5.txt",
		        "node_list_path": "1896224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusIhumiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ihumii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusIhumiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "687436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "687436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "687436.clusters.proteins.v11.5.txt",
		        "sequence_path": "687436.protein.sequences.v11.5.fa",
		        "enrichment_path": "687436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "687436.protein.info.v11.5.txt",
		        "node_list_path": "687436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "687436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ApibacterMensalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Apibacter mensalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApibacterMensalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1586267.protein.sequences.v11.5.fa",
		        "enrichment_path": "1586267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1586267.protein.info.v11.5.txt",
		        "node_list_path": "1586267.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlossinaBrevipalpisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glossina brevipalpis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlossinaBrevipalpisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37001.clusters.proteins.v11.5.txt",
		        "sequence_path": "37001.protein.sequences.v11.5.fa",
		        "enrichment_path": "37001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37001.protein.info.v11.5.txt",
		        "node_list_path": "37001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloplanusVescus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloplanus vescus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloplanusVescus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "555874.protein.sequences.v11.5.fa",
		        "enrichment_path": "555874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555874.protein.info.v11.5.txt",
		        "node_list_path": "555874.protein.complete.v11.5.txt"
		    }
		]
    )()

def UreibacillusThermosphaericusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ureibacillus thermosphaericus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UreibacillusThermosphaericusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1160707.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1160707.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1160707.clusters.proteins.v11.5.txt",
		        "sequence_path": "1160707.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160707.protein.info.v11.5.txt",
		        "node_list_path": "1160707.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1160707.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpPcc7003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC 7003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpPcc7003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "374981.protein.sequences.v11.5.fa",
		        "enrichment_path": "374981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "374981.protein.info.v11.5.txt",
		        "node_list_path": "374981.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpCf8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. CF8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpCf8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "110319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "110319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "110319.clusters.proteins.v11.5.txt",
		        "sequence_path": "110319.protein.sequences.v11.5.fa",
		        "enrichment_path": "110319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "110319.protein.info.v11.5.txt",
		        "node_list_path": "110319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "110319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumGw2011Gwf24415Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWF2_44_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwf24415Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618404.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618404.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618404.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618404.protein.info.v11.5.txt",
		        "node_list_path": "1618404.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618404.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArmatimonadetesBacteriumDc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium DC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmatimonadetesBacteriumDc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1661583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661583.protein.info.v11.5.txt",
		        "node_list_path": "1661583.protein.complete.v11.5.txt"
		    }
		]
    )()

def DermabacterSpHfh0086Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dermabacter sp. HFH0086 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DermabacterSpHfh0086Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203568.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203568.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203568.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203568.protein.info.v11.5.txt",
		        "node_list_path": "1203568.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203568.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat29937(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-29937 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat29937", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720553.protein.info.v11.5.txt",
		        "node_list_path": "1720553.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulforudisAudaxviator(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulforudis audaxviator graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulforudisAudaxviator", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "477974.protein.sequences.v11.5.fa",
		        "enrichment_path": "477974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477974.protein.info.v11.5.txt",
		        "node_list_path": "477974.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaProteobacteriumMlsD(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return delta proteobacterium MLS_D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaProteobacteriumMlsD", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1775673.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775673.protein.info.v11.5.txt",
		        "node_list_path": "1775673.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitriliruptorAlkaliphilusDsm45188(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitriliruptor alkaliphilus DSM 45188 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitriliruptorAlkaliphilusDsm45188", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1069448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069448.protein.info.v11.5.txt",
		        "node_list_path": "1069448.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAviumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium avium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAviumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44454.clusters.proteins.v11.5.txt",
		        "sequence_path": "44454.protein.sequences.v11.5.fa",
		        "enrichment_path": "44454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44454.protein.info.v11.5.txt",
		        "node_list_path": "44454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSpBal39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. BAL39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpBal39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391596.protein.sequences.v11.5.fa",
		        "enrichment_path": "391596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391596.protein.info.v11.5.txt",
		        "node_list_path": "391596.protein.complete.v11.5.txt"
		    }
		]
    )()

def NesiotobacterExalbescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nesiotobacter exalbescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesiotobacterExalbescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "197461.clusters.info.v11.5.txt",
		        "cluster_tree_path": "197461.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "197461.clusters.proteins.v11.5.txt",
		        "sequence_path": "197461.protein.sequences.v11.5.fa",
		        "enrichment_path": "197461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "197461.protein.info.v11.5.txt",
		        "node_list_path": "197461.cluster.nodes.v11.5.txt",
		        "edge_list_path": "197461.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophilusMethylotrophusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus methylotrophus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusMethylotrophusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122236.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122236.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122236.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122236.protein.info.v11.5.txt",
		        "node_list_path": "1122236.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122236.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanolineaTardaNobi1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanolinea tarda NOBI-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolineaTardaNobi1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "882090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "882090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "882090.clusters.proteins.v11.5.txt",
		        "sequence_path": "882090.protein.sequences.v11.5.fa",
		        "enrichment_path": "882090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882090.protein.info.v11.5.txt",
		        "node_list_path": "882090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "882090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumTropiciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium tropici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumTropiciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "698761.clusters.info.v11.5.txt",
		        "cluster_tree_path": "698761.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "698761.clusters.proteins.v11.5.txt",
		        "sequence_path": "698761.protein.sequences.v11.5.fa",
		        "enrichment_path": "698761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698761.protein.info.v11.5.txt",
		        "node_list_path": "698761.cluster.nodes.v11.5.txt",
		        "edge_list_path": "698761.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaEnterocolitica8081Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica 8081 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaEnterocolitica8081Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "393305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "393305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "393305.clusters.proteins.v11.5.txt",
		        "sequence_path": "393305.protein.sequences.v11.5.fa",
		        "enrichment_path": "393305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393305.protein.info.v11.5.txt",
		        "node_list_path": "393305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "393305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaricaulisSpW15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maricaulis sp. W15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaricaulisSpW15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1772333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1772333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1772333.clusters.proteins.v11.5.txt",
		        "sequence_path": "1772333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772333.protein.info.v11.5.txt",
		        "node_list_path": "1772333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1772333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeptunomonasAntarcticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neptunomonas antarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptunomonasAntarcticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "619304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "619304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "619304.clusters.proteins.v11.5.txt",
		        "sequence_path": "619304.protein.sequences.v11.5.fa",
		        "enrichment_path": "619304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "619304.protein.info.v11.5.txt",
		        "node_list_path": "619304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "619304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaSpSos3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia sp. SOS3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaSpSos3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926494.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926494.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926494.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926494.protein.info.v11.5.txt",
		        "node_list_path": "1926494.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926494.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OryctolagusCuniculus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryctolagus cuniculus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryctolagusCuniculus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9986.protein.sequences.v11.5.fa",
		        "enrichment_path": "9986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9986.protein.info.v11.5.txt",
		        "node_list_path": "9986.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioBastiniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio bastinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioBastiniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121441.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121441.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121441.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121441.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121441.protein.info.v11.5.txt",
		        "node_list_path": "1121441.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121441.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaTrematum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella trematum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaTrematum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "123899.protein.sequences.v11.5.fa",
		        "enrichment_path": "123899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "123899.protein.info.v11.5.txt",
		        "node_list_path": "123899.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_10b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802517.protein.info.v11.5.txt",
		        "node_list_path": "1802517.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioFairfieldensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio fairfieldensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioFairfieldensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44742.protein.sequences.v11.5.fa",
		        "enrichment_path": "44742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44742.protein.info.v11.5.txt",
		        "node_list_path": "44742.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaSpEjp617Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia sp. Ejp617 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaSpEjp617Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "215689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "215689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "215689.clusters.proteins.v11.5.txt",
		        "sequence_path": "215689.protein.sequences.v11.5.fa",
		        "enrichment_path": "215689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215689.protein.info.v11.5.txt",
		        "node_list_path": "215689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "215689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlishewanellaJeotgaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alishewanella jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlishewanellaJeotgaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1129374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1129374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1129374.clusters.proteins.v11.5.txt",
		        "sequence_path": "1129374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1129374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1129374.protein.info.v11.5.txt",
		        "node_list_path": "1129374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1129374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudopodocesHumilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudopodoces humilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudopodocesHumilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "181119.protein.sequences.v11.5.fa",
		        "enrichment_path": "181119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "181119.protein.info.v11.5.txt",
		        "node_list_path": "181119.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumArcticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium arcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumArcticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "386456.clusters.info.v11.5.txt",
		        "cluster_tree_path": "386456.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "386456.clusters.proteins.v11.5.txt",
		        "sequence_path": "386456.protein.sequences.v11.5.fa",
		        "enrichment_path": "386456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "386456.protein.info.v11.5.txt",
		        "node_list_path": "386456.cluster.nodes.v11.5.txt",
		        "edge_list_path": "386456.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumFlaccumfaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium flaccumfaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumFlaccumfaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2035.clusters.proteins.v11.5.txt",
		        "sequence_path": "2035.protein.sequences.v11.5.fa",
		        "enrichment_path": "2035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2035.protein.info.v11.5.txt",
		        "node_list_path": "2035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusFulgidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus fulgidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusFulgidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "224325.protein.sequences.v11.5.fa",
		        "enrichment_path": "224325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224325.protein.info.v11.5.txt",
		        "node_list_path": "224325.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfurispirillumIndicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurispirillum indicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurispirillumIndicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "653733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "653733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "653733.clusters.proteins.v11.5.txt",
		        "sequence_path": "653733.protein.sequences.v11.5.fa",
		        "enrichment_path": "653733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "653733.protein.info.v11.5.txt",
		        "node_list_path": "653733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "653733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaSpPba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. PBA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSpPba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "795666.protein.sequences.v11.5.fa",
		        "enrichment_path": "795666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "795666.protein.info.v11.5.txt",
		        "node_list_path": "795666.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusAlcaliphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus alcaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusAlcaliphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34002.clusters.proteins.v11.5.txt",
		        "sequence_path": "34002.protein.sequences.v11.5.fa",
		        "enrichment_path": "34002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34002.protein.info.v11.5.txt",
		        "node_list_path": "34002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrovirgaVignae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microvirga vignae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaVignae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1225564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225564.protein.info.v11.5.txt",
		        "node_list_path": "1225564.protein.complete.v11.5.txt"
		    }
		]
    )()

def TigriopusCalifornicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tigriopus californicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TigriopusCalifornicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6832.clusters.proteins.v11.5.txt",
		        "sequence_path": "6832.protein.sequences.v11.5.fa",
		        "enrichment_path": "6832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6832.protein.info.v11.5.txt",
		        "node_list_path": "6832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaSaccharophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema saccharophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSaccharophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "907348.protein.sequences.v11.5.fa",
		        "enrichment_path": "907348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "907348.protein.info.v11.5.txt",
		        "node_list_path": "907348.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27245Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27245 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27245Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1684144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1684144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1684144.clusters.proteins.v11.5.txt",
		        "sequence_path": "1684144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1684144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1684144.protein.info.v11.5.txt",
		        "node_list_path": "1684144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1684144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasBorboriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas borbori Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBorboriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "289003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "289003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "289003.clusters.proteins.v11.5.txt",
		        "sequence_path": "289003.protein.sequences.v11.5.fa",
		        "enrichment_path": "289003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "289003.protein.info.v11.5.txt",
		        "node_list_path": "289003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "289003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "693986.clusters.info.v11.5.txt",
		        "cluster_tree_path": "693986.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "693986.clusters.proteins.v11.5.txt",
		        "sequence_path": "693986.protein.sequences.v11.5.fa",
		        "enrichment_path": "693986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693986.protein.info.v11.5.txt",
		        "node_list_path": "693986.cluster.nodes.v11.5.txt",
		        "edge_list_path": "693986.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusSpSb3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. SB3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusSpSb3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1673719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1673719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1673719.clusters.proteins.v11.5.txt",
		        "sequence_path": "1673719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673719.protein.info.v11.5.txt",
		        "node_list_path": "1673719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1673719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastomycesDermatitidisEr3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces dermatitidis ER-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomycesDermatitidisEr3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "559297.protein.sequences.v11.5.fa",
		        "enrichment_path": "559297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559297.protein.info.v11.5.txt",
		        "node_list_path": "559297.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaSyrphidicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma syrphidicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaSyrphidicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1276229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1276229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1276229.clusters.proteins.v11.5.txt",
		        "sequence_path": "1276229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276229.protein.info.v11.5.txt",
		        "node_list_path": "1276229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1276229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaitozymaPodzolica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saitozyma podzolica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaitozymaPodzolica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1890683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1890683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1890683.protein.info.v11.5.txt",
		        "node_list_path": "1890683.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa2499Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_49_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa2499Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618852.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618852.protein.info.v11.5.txt",
		        "node_list_path": "1618852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaSpCua673(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. CUA-673 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaSpCua673", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1904969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904969.protein.info.v11.5.txt",
		        "node_list_path": "1904969.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpK31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. K31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpK31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "366602.clusters.info.v11.5.txt",
		        "cluster_tree_path": "366602.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "366602.clusters.proteins.v11.5.txt",
		        "sequence_path": "366602.protein.sequences.v11.5.fa",
		        "enrichment_path": "366602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366602.protein.info.v11.5.txt",
		        "node_list_path": "366602.cluster.nodes.v11.5.txt",
		        "edge_list_path": "366602.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPhocae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium phocae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPhocae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "161895.protein.sequences.v11.5.fa",
		        "enrichment_path": "161895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161895.protein.info.v11.5.txt",
		        "node_list_path": "161895.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacterSpOr1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter sp. OR-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterSpOr1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1266765.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1266765.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1266765.clusters.proteins.v11.5.txt",
		        "sequence_path": "1266765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266765.protein.info.v11.5.txt",
		        "node_list_path": "1266765.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1266765.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusLitoralisDsm5473Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus litoralis DSM 5473 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusLitoralisDsm5473Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "523849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "523849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "523849.clusters.proteins.v11.5.txt",
		        "sequence_path": "523849.protein.sequences.v11.5.fa",
		        "enrichment_path": "523849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523849.protein.info.v11.5.txt",
		        "node_list_path": "523849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "523849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixibacteriaBacterium448495(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium 4484_95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixibacteriaBacterium448495", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1970781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970781.protein.info.v11.5.txt",
		        "node_list_path": "1970781.protein.complete.v11.5.txt"
		    }
		]
    )()

def RobinsoniellaPeoriensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Robinsoniella peoriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RobinsoniellaPeoriensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "180332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "180332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "180332.clusters.proteins.v11.5.txt",
		        "sequence_path": "180332.protein.sequences.v11.5.fa",
		        "enrichment_path": "180332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180332.protein.info.v11.5.txt",
		        "node_list_path": "180332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "180332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsplowo212Full5011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO2_12_FULL_50_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo212Full5011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801834.protein.info.v11.5.txt",
		        "node_list_path": "1801834.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrinemaSpJ72(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrinema sp. J72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrinemaSpJ72", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "406552.protein.sequences.v11.5.fa",
		        "enrichment_path": "406552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406552.protein.info.v11.5.txt",
		        "node_list_path": "406552.protein.complete.v11.5.txt"
		    }
		]
    )()

def FontimonasThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fontimonas thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FontimonasThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1076937.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076937.protein.info.v11.5.txt",
		        "node_list_path": "1076937.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4323Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_43_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4323Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817822.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817822.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817822.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817822.protein.info.v11.5.txt",
		        "node_list_path": "1817822.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817822.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaSaccharevitansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena saccharevitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaSaccharevitansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "301967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "301967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "301967.clusters.proteins.v11.5.txt",
		        "sequence_path": "301967.protein.sequences.v11.5.fa",
		        "enrichment_path": "301967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "301967.protein.info.v11.5.txt",
		        "node_list_path": "301967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "301967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermomicrobialesSpKi4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Thermomicrobiales sp. KI4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "ThermomicrobialesSpKi4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1382356.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1382356.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1382356.clusters.proteins.v11.0.txt",
		        "sequence_path": "1382356.protein.sequences.v11.0.fa",
		        "enrichment_path": "1382356.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1382356.protein.info.v11.0.txt",
		        "node_list_path": "1382356.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1382356.protein.cluster.v11.0.txt"
		    }
		]
    )()

def FusobacteriumNucleatumAnimalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum animalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumAnimalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "457405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "457405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "457405.clusters.proteins.v11.5.txt",
		        "sequence_path": "457405.protein.sequences.v11.5.fa",
		        "enrichment_path": "457405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457405.protein.info.v11.5.txt",
		        "node_list_path": "457405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "457405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAquilunaSpUbMaderosw2redCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aquiluna sp. UB-MaderosW2red Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAquilunaSpUbMaderosw2redCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855377.protein.info.v11.5.txt",
		        "node_list_path": "1855377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteimonasSpJm171Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas sp. JM171 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteimonasSpJm171Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896164.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896164.protein.info.v11.5.txt",
		        "node_list_path": "1896164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EhrlichiaChaffeensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia chaffeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EhrlichiaChaffeensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "205920.protein.sequences.v11.5.fa",
		        "enrichment_path": "205920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "205920.protein.info.v11.5.txt",
		        "node_list_path": "205920.protein.complete.v11.5.txt"
		    }
		]
    )()

def BulleidiaExtructa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bulleidia extructa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BulleidiaExtructa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679192.protein.sequences.v11.5.fa",
		        "enrichment_path": "679192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679192.protein.info.v11.5.txt",
		        "node_list_path": "679192.protein.complete.v11.5.txt"
		    }
		]
    )()

def StappiaSp22iiS9Z10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stappia sp. 22II-S9-Z10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StappiaSp22iiS9Z10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1317123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317123.protein.info.v11.5.txt",
		        "node_list_path": "1317123.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwc12715Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWC1_27_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwc12715Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802179.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802179.protein.info.v11.5.txt",
		        "node_list_path": "1802179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4967Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_49_67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4967Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802337.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802337.protein.info.v11.5.txt",
		        "node_list_path": "1802337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RunellaZeaeDsm19591(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Runella zeae DSM 19591 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RunellaZeaeDsm19591", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123078.protein.info.v11.5.txt",
		        "node_list_path": "1123078.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumErythrophleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium erythrophlei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumErythrophleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437360.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437360.protein.info.v11.5.txt",
		        "node_list_path": "1437360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisJaponica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisJaponica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "208439.protein.sequences.v11.5.fa",
		        "enrichment_path": "208439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208439.protein.info.v11.5.txt",
		        "node_list_path": "208439.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlbimonasDonghaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Albimonas donghaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlbimonasDonghaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "356660.protein.sequences.v11.5.fa",
		        "enrichment_path": "356660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "356660.protein.info.v11.5.txt",
		        "node_list_path": "356660.protein.complete.v11.5.txt"
		    }
		]
    )()

def NematostellaVectensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nematostella vectensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NematostellaVectensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45351.protein.sequences.v11.5.fa",
		        "enrichment_path": "45351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45351.protein.info.v11.5.txt",
		        "node_list_path": "45351.protein.complete.v11.5.txt"
		    }
		]
    )()

def PasteurellaPneumotropicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella pneumotropica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaPneumotropicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "758.clusters.proteins.v11.5.txt",
		        "sequence_path": "758.protein.sequences.v11.5.fa",
		        "enrichment_path": "758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758.protein.info.v11.5.txt",
		        "node_list_path": "758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaHelveticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia helvetica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaHelveticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144888.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144888.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144888.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144888.protein.info.v11.5.txt",
		        "node_list_path": "1144888.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144888.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpTb67(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. TB67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpTb67", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1055815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1055815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1055815.protein.info.v11.5.txt",
		        "node_list_path": "1055815.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusCecorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus cecorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusCecorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121864.protein.info.v11.5.txt",
		        "node_list_path": "1121864.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumBrumaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium brumae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumBrumaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "85968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "85968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "85968.clusters.proteins.v11.5.txt",
		        "sequence_path": "85968.protein.sequences.v11.5.fa",
		        "enrichment_path": "85968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85968.protein.info.v11.5.txt",
		        "node_list_path": "85968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "85968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalovenusAranensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halovenus aranensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalovenusAranensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "890420.protein.sequences.v11.5.fa",
		        "enrichment_path": "890420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "890420.protein.info.v11.5.txt",
		        "node_list_path": "890420.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpAnt17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. Ant17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpAnt17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461752.protein.info.v11.5.txt",
		        "node_list_path": "1461752.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseivirgaEhrenbergiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseivirga ehrenbergii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivirgaEhrenbergiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "279360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "279360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "279360.clusters.proteins.v11.5.txt",
		        "sequence_path": "279360.protein.sequences.v11.5.fa",
		        "enrichment_path": "279360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279360.protein.info.v11.5.txt",
		        "node_list_path": "279360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "279360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpYr519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpYr519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500259.protein.info.v11.5.txt",
		        "node_list_path": "1500259.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaRustigianii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Providencia rustigianii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaRustigianii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "500637.protein.sequences.v11.5.fa",
		        "enrichment_path": "500637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500637.protein.info.v11.5.txt",
		        "node_list_path": "500637.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCarsonellaRuddiiCeIsolateThao2000(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii CE isolate Thao2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCarsonellaRuddiiCeIsolateThao2000", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1202536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202536.protein.info.v11.5.txt",
		        "node_list_path": "1202536.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumOlb13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumOlb13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617414.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617414.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617414.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617414.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617414.protein.info.v11.5.txt",
		        "node_list_path": "1617414.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617414.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterLuteolusNbrc107841(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter luteolus NBRC 107841 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterLuteolusNbrc107841", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216973.protein.info.v11.5.txt",
		        "node_list_path": "1216973.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusMaceransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus macerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusMaceransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44252.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44252.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44252.clusters.proteins.v11.5.txt",
		        "sequence_path": "44252.protein.sequences.v11.5.fa",
		        "enrichment_path": "44252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44252.protein.info.v11.5.txt",
		        "node_list_path": "44252.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44252.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylothermusMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylothermus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylothermusMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "399550.protein.sequences.v11.5.fa",
		        "enrichment_path": "399550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399550.protein.info.v11.5.txt",
		        "node_list_path": "399550.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSpWkb8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sp. wkB8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSpWkb8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1545702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1545702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1545702.clusters.proteins.v11.5.txt",
		        "sequence_path": "1545702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545702.protein.info.v11.5.txt",
		        "node_list_path": "1545702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1545702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PleomorphomonasKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pleomorphomonas koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PleomorphomonasKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122962.protein.info.v11.5.txt",
		        "node_list_path": "1122962.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifcsplowo201Full5912(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO2_01_FULL_59_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201Full5912", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797946.protein.info.v11.5.txt",
		        "node_list_path": "1797946.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRbg136816(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RBG_13_68_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRbg136816", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797171.protein.info.v11.5.txt",
		        "node_list_path": "1797171.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenaeusVannameiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penaeus vannamei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenaeusVannameiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6689.clusters.proteins.v11.5.txt",
		        "sequence_path": "6689.protein.sequences.v11.5.fa",
		        "enrichment_path": "6689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6689.protein.info.v11.5.txt",
		        "node_list_path": "6689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumLeptumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium leptum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumLeptumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "428125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "428125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "428125.clusters.proteins.v11.5.txt",
		        "sequence_path": "428125.protein.sequences.v11.5.fa",
		        "enrichment_path": "428125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428125.protein.info.v11.5.txt",
		        "node_list_path": "428125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "428125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KangiellaGeojedonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kangiella geojedonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KangiellaGeojedonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "914150.protein.sequences.v11.5.fa",
		        "enrichment_path": "914150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "914150.protein.info.v11.5.txt",
		        "node_list_path": "914150.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusSteyniiIbt23096Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus steynii IBT 23096 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusSteyniiIbt23096Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392250.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392250.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392250.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392250.protein.info.v11.5.txt",
		        "node_list_path": "1392250.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392250.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarineGroupIiiEuryarchaeoteCgEpi1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marine Group III euryarchaeote CG-Epi1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineGroupIiiEuryarchaeoteCgEpi1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1888995.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1888995.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1888995.clusters.proteins.v11.5.txt",
		        "sequence_path": "1888995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1888995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1888995.protein.info.v11.5.txt",
		        "node_list_path": "1888995.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1888995.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpCsm2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. CSM-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpCsm2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1975722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1975722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1975722.protein.info.v11.5.txt",
		        "node_list_path": "1975722.protein.complete.v11.5.txt"
		    }
		]
    )()

def DomibacillusIndicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusIndicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437523.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437523.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437523.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437523.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437523.protein.info.v11.5.txt",
		        "node_list_path": "1437523.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437523.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpEe36Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. EE36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpEe36Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52598.clusters.proteins.v11.5.txt",
		        "sequence_path": "52598.protein.sequences.v11.5.fa",
		        "enrichment_path": "52598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52598.protein.info.v11.5.txt",
		        "node_list_path": "52598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpKh9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. KH9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpKh9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855324.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855324.protein.info.v11.5.txt",
		        "node_list_path": "1855324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAc2031Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2031 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAc2031Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392493.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392493.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392493.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392493.protein.info.v11.5.txt",
		        "node_list_path": "1392493.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392493.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanoprotosteliumFungivorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planoprotostelium fungivorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanoprotosteliumFungivorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1890364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1890364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1890364.clusters.proteins.v11.5.txt",
		        "sequence_path": "1890364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1890364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1890364.protein.info.v11.5.txt",
		        "node_list_path": "1890364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1890364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMarisflaviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus marisflavi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMarisflaviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "189381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "189381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "189381.clusters.proteins.v11.5.txt",
		        "sequence_path": "189381.protein.sequences.v11.5.fa",
		        "enrichment_path": "189381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189381.protein.info.v11.5.txt",
		        "node_list_path": "189381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "189381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychromonasOssibalaenaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas ossibalaenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychromonasOssibalaenaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278307.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278307.protein.info.v11.5.txt",
		        "node_list_path": "1278307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermithiobacillusTepidariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermithiobacillus tepidarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermithiobacillusTepidariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123368.protein.info.v11.5.txt",
		        "node_list_path": "1123368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumTaiwanenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium taiwanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumTaiwanenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "363331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "363331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "363331.clusters.proteins.v11.5.txt",
		        "sequence_path": "363331.protein.sequences.v11.5.fa",
		        "enrichment_path": "363331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "363331.protein.info.v11.5.txt",
		        "node_list_path": "363331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "363331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoactinomycesSpDsm45891(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. DSM 45891 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoactinomycesSpDsm45891", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761907.protein.info.v11.5.txt",
		        "node_list_path": "1761907.protein.complete.v11.5.txt"
		    }
		]
    )()

def OreochromisNiloticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oreochromis niloticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OreochromisNiloticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8128.clusters.proteins.v11.5.txt",
		        "sequence_path": "8128.protein.sequences.v11.5.fa",
		        "enrichment_path": "8128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8128.protein.info.v11.5.txt",
		        "node_list_path": "8128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumScadc123Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium SCADC1_2_3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumScadc123Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1487582.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1487582.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1487582.clusters.proteins.v11.5.txt",
		        "sequence_path": "1487582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1487582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1487582.protein.info.v11.5.txt",
		        "node_list_path": "1487582.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1487582.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IlumatobacterCoccineusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ilumatobacter coccineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IlumatobacterCoccineusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1313172.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1313172.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1313172.clusters.proteins.v11.5.txt",
		        "sequence_path": "1313172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313172.protein.info.v11.5.txt",
		        "node_list_path": "1313172.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1313172.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetohalobiumArabaticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetohalobium arabaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetohalobiumArabaticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "574087.protein.sequences.v11.5.fa",
		        "enrichment_path": "574087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574087.protein.info.v11.5.txt",
		        "node_list_path": "574087.protein.complete.v11.5.txt"
		    }
		]
    )()

def TriboliumCastaneumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tribolium castaneum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TriboliumCastaneumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7070.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7070.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7070.clusters.proteins.v11.5.txt",
		        "sequence_path": "7070.protein.sequences.v11.5.fa",
		        "enrichment_path": "7070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7070.protein.info.v11.5.txt",
		        "node_list_path": "7070.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7070.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpCipa165(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIPA165 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpCipa165", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40373.protein.sequences.v11.5.fa",
		        "enrichment_path": "40373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40373.protein.info.v11.5.txt",
		        "node_list_path": "40373.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118054.protein.info.v11.5.txt",
		        "node_list_path": "1118054.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium3713(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 37-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium3713", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895921.protein.info.v11.5.txt",
		        "node_list_path": "1895921.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChondromycesApiculatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chondromyces apiculatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChondromycesApiculatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1192034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192034.protein.info.v11.5.txt",
		        "node_list_path": "1192034.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHtcc9022(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC9022 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHtcc9022", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265756.protein.info.v11.5.txt",
		        "node_list_path": "1265756.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidaminococcusSpCag917(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidaminococcus sp. CAG:917 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminococcusSpCag917", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262688.protein.info.v11.5.txt",
		        "node_list_path": "1262688.protein.complete.v11.5.txt"
		    }
		]
    )()

def SeriolaDumeriliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Seriola dumerili Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SeriolaDumeriliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "41447.clusters.info.v11.5.txt",
		        "cluster_tree_path": "41447.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "41447.clusters.proteins.v11.5.txt",
		        "sequence_path": "41447.protein.sequences.v11.5.fa",
		        "enrichment_path": "41447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41447.protein.info.v11.5.txt",
		        "node_list_path": "41447.cluster.nodes.v11.5.txt",
		        "edge_list_path": "41447.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpPamc28711(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. PAMC 28711 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpPamc28711", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1795631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795631.protein.info.v11.5.txt",
		        "node_list_path": "1795631.protein.complete.v11.5.txt"
		    }
		]
    )()

def LodderomycesElongisporusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lodderomyces elongisporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LodderomycesElongisporusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36914.clusters.proteins.v11.5.txt",
		        "sequence_path": "36914.protein.sequences.v11.5.fa",
		        "enrichment_path": "36914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36914.protein.info.v11.5.txt",
		        "node_list_path": "36914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacterSpS108(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter sp. S10-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterSpS108", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797110.protein.info.v11.5.txt",
		        "node_list_path": "1797110.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrococcusMobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrococcus mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrococcusMobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314278.clusters.proteins.v11.5.txt",
		        "sequence_path": "314278.protein.sequences.v11.5.fa",
		        "enrichment_path": "314278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314278.protein.info.v11.5.txt",
		        "node_list_path": "314278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumSpIcm42bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. ICM42b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumSpIcm42bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1190620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1190620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1190620.clusters.proteins.v11.5.txt",
		        "sequence_path": "1190620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1190620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1190620.protein.info.v11.5.txt",
		        "node_list_path": "1190620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1190620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacterChinhatensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter chinhatensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterChinhatensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1436961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1436961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1436961.clusters.proteins.v11.5.txt",
		        "sequence_path": "1436961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1436961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1436961.protein.info.v11.5.txt",
		        "node_list_path": "1436961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1436961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesHelcogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides helcogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesHelcogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "693979.clusters.info.v11.5.txt",
		        "cluster_tree_path": "693979.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "693979.clusters.proteins.v11.5.txt",
		        "sequence_path": "693979.protein.sequences.v11.5.fa",
		        "enrichment_path": "693979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693979.protein.info.v11.5.txt",
		        "node_list_path": "693979.cluster.nodes.v11.5.txt",
		        "edge_list_path": "693979.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaRhamnosiphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia rhamnosiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaRhamnosiphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426716.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426716.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426716.clusters.proteins.v11.5.txt",
		        "sequence_path": "426716.protein.sequences.v11.5.fa",
		        "enrichment_path": "426716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426716.protein.info.v11.5.txt",
		        "node_list_path": "426716.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426716.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMassiliosenegalensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus massiliosenegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMassiliosenegalensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1034347.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1034347.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1034347.clusters.proteins.v11.5.txt",
		        "sequence_path": "1034347.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034347.protein.info.v11.5.txt",
		        "node_list_path": "1034347.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1034347.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LitorimicrobiumTaeanense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Litorimicrobium taeanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LitorimicrobiumTaeanense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "657014.protein.sequences.v11.5.fa",
		        "enrichment_path": "657014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657014.protein.info.v11.5.txt",
		        "node_list_path": "657014.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho212Full5423(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_12_FULL_54_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho212Full5423", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802397.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802397.protein.info.v11.5.txt",
		        "node_list_path": "1802397.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumStylosanthis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium stylosanthis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumStylosanthis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803665.protein.info.v11.5.txt",
		        "node_list_path": "1803665.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSpLeaf176Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf176 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpLeaf176Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736286.protein.info.v11.5.txt",
		        "node_list_path": "1736286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SharpeaAzabuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sharpea azabuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SharpeaAzabuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410674.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410674.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410674.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410674.protein.info.v11.5.txt",
		        "node_list_path": "1410674.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410674.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptococcusDepauperatusCbs7841(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus depauperatus CBS 7841 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptococcusDepauperatusCbs7841", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1295531.protein.sequences.v11.5.fa",
		        "enrichment_path": "1295531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1295531.protein.info.v11.5.txt",
		        "node_list_path": "1295531.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParapedobacterLuteus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parapedobacter luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParapedobacterLuteus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "623280.protein.sequences.v11.5.fa",
		        "enrichment_path": "623280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "623280.protein.info.v11.5.txt",
		        "node_list_path": "623280.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodonellumPsychrophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodonellum psychrophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodonellumPsychrophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123057.protein.info.v11.5.txt",
		        "node_list_path": "1123057.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGa0077536Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0077536 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGa0077536Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752214.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752214.protein.info.v11.5.txt",
		        "node_list_path": "1752214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaBirtlesii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella birtlesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaBirtlesii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1201035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1201035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1201035.protein.info.v11.5.txt",
		        "node_list_path": "1201035.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpH3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. H3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpH3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1402135.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1402135.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1402135.clusters.proteins.v11.5.txt",
		        "sequence_path": "1402135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1402135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1402135.protein.info.v11.5.txt",
		        "node_list_path": "1402135.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1402135.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaSchoenbuchensisR1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella schoenbuchensis R1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSchoenbuchensisR1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "687861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "687861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "687861.clusters.proteins.v11.5.txt",
		        "sequence_path": "687861.protein.sequences.v11.5.fa",
		        "enrichment_path": "687861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "687861.protein.info.v11.5.txt",
		        "node_list_path": "687861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "687861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSubterraneum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium subterraneum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSubterraneum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "48936.protein.sequences.v11.5.fa",
		        "enrichment_path": "48936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48936.protein.info.v11.5.txt",
		        "node_list_path": "48936.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPLOWO2_01_FULL_51_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797243.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797243.protein.info.v11.5.txt",
		        "node_list_path": "1797243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisBriggsaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis briggsae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisBriggsaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6238.clusters.proteins.v11.5.txt",
		        "sequence_path": "6238.protein.sequences.v11.5.fa",
		        "enrichment_path": "6238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6238.protein.info.v11.5.txt",
		        "node_list_path": "6238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetallibacteriumScheffleriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metallibacterium scheffleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetallibacteriumScheffleriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "993689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "993689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "993689.clusters.proteins.v11.5.txt",
		        "sequence_path": "993689.protein.sequences.v11.5.fa",
		        "enrichment_path": "993689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "993689.protein.info.v11.5.txt",
		        "node_list_path": "993689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "993689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSenegalensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSenegalensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033732.protein.info.v11.5.txt",
		        "node_list_path": "1033732.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumSporotrichioides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium sporotrichioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumSporotrichioides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5514.protein.sequences.v11.5.fa",
		        "enrichment_path": "5514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5514.protein.info.v11.5.txt",
		        "node_list_path": "5514.protein.complete.v11.5.txt"
		    }
		]
    )()

def CroceitaleaDokdonensisDokdo023(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Croceitalea dokdonensis DOKDO 023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CroceitaleaDokdonensisDokdo023", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1300341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300341.protein.info.v11.5.txt",
		        "node_list_path": "1300341.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumGwf24416Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_44_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumGwf24416Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798571.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798571.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798571.protein.info.v11.5.txt",
		        "node_list_path": "1798571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpMn802worker(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Mn802worker graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpMn802worker", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "629773.protein.sequences.v11.5.fa",
		        "enrichment_path": "629773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "629773.protein.info.v11.5.txt",
		        "node_list_path": "629773.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacterium4484702(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_70.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484702", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1970783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970783.protein.info.v11.5.txt",
		        "node_list_path": "1970783.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumSetense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium setense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumSetense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "431269.protein.sequences.v11.5.fa",
		        "enrichment_path": "431269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431269.protein.info.v11.5.txt",
		        "node_list_path": "431269.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusLaterosporusDsm25Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus laterosporus DSM25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusLaterosporusDsm25Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121121.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121121.protein.info.v11.5.txt",
		        "node_list_path": "1121121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EucalyptusGrandis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eucalyptus grandis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EucalyptusGrandis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "71139.protein.sequences.v11.5.fa",
		        "enrichment_path": "71139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "71139.protein.info.v11.5.txt",
		        "node_list_path": "71139.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlagellimonasFlavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flagellimonas flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlagellimonasFlavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "570519.clusters.info.v11.5.txt",
		        "cluster_tree_path": "570519.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "570519.clusters.proteins.v11.5.txt",
		        "sequence_path": "570519.protein.sequences.v11.5.fa",
		        "enrichment_path": "570519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570519.protein.info.v11.5.txt",
		        "node_list_path": "570519.cluster.nodes.v11.5.txt",
		        "edge_list_path": "570519.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EremococcusColeocolaAcs139vcol8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eremococcus coleocola ACS139VCol8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremococcusColeocolaAcs139vcol8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "908337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "908337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "908337.clusters.proteins.v11.5.txt",
		        "sequence_path": "908337.protein.sequences.v11.5.fa",
		        "enrichment_path": "908337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908337.protein.info.v11.5.txt",
		        "node_list_path": "908337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "908337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumGw2011Gwa13413(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA1_34_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa13413", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618434.protein.info.v11.5.txt",
		        "node_list_path": "1618434.protein.complete.v11.5.txt"
		    }
		]
    )()

def FictibacillusSolisalsiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fictibacillus solisalsi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FictibacillusSolisalsiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "459525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "459525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "459525.clusters.proteins.v11.5.txt",
		        "sequence_path": "459525.protein.sequences.v11.5.fa",
		        "enrichment_path": "459525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "459525.protein.info.v11.5.txt",
		        "node_list_path": "459525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "459525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfonatronumThiosulfatophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronum thiosulfatophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronumThiosulfatophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "617002.protein.sequences.v11.5.fa",
		        "enrichment_path": "617002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "617002.protein.info.v11.5.txt",
		        "node_list_path": "617002.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaWadsworthiiDsm21896Atcc33877(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella wadsworthii DSM 21896 ATCC 33877 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaWadsworthiiDsm21896Atcc33877", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122170.protein.info.v11.5.txt",
		        "node_list_path": "1122170.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumRhodesiaeJs60Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rhodesiae JS60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumRhodesiaeJs60Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "931627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "931627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "931627.clusters.proteins.v11.5.txt",
		        "sequence_path": "931627.protein.sequences.v11.5.fa",
		        "enrichment_path": "931627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "931627.protein.info.v11.5.txt",
		        "node_list_path": "931627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "931627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LoktanellaAtriluteaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella atrilutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaAtriluteaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "366533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "366533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "366533.clusters.proteins.v11.5.txt",
		        "sequence_path": "366533.protein.sequences.v11.5.fa",
		        "enrichment_path": "366533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366533.protein.info.v11.5.txt",
		        "node_list_path": "366533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "366533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumDoricumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium doricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumDoricumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "126673.clusters.info.v11.5.txt",
		        "cluster_tree_path": "126673.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "126673.clusters.proteins.v11.5.txt",
		        "sequence_path": "126673.protein.sequences.v11.5.fa",
		        "enrichment_path": "126673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "126673.protein.info.v11.5.txt",
		        "node_list_path": "126673.cluster.nodes.v11.5.txt",
		        "edge_list_path": "126673.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterovibrioNorvegicusDsm15893(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus DSM 15893 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioNorvegicusDsm15893", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121869.protein.info.v11.5.txt",
		        "node_list_path": "1121869.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_43_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618825.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618825.protein.info.v11.5.txt",
		        "node_list_path": "1618825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeishmaniaBraziliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leishmania braziliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeishmaniaBraziliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5660.protein.sequences.v11.5.fa",
		        "enrichment_path": "5660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5660.protein.info.v11.5.txt",
		        "node_list_path": "5660.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParastrongyloidesTrichosuriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parastrongyloides trichosuri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParastrongyloidesTrichosuriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "131310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "131310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "131310.clusters.proteins.v11.5.txt",
		        "sequence_path": "131310.protein.sequences.v11.5.fa",
		        "enrichment_path": "131310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "131310.protein.info.v11.5.txt",
		        "node_list_path": "131310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "131310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YoungiibacterFragilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Youngiibacter fragilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YoungiibacterFragilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "994573.protein.sequences.v11.5.fa",
		        "enrichment_path": "994573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "994573.protein.info.v11.5.txt",
		        "node_list_path": "994573.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaNiwaeNbrc108934Dsm45340(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia niwae NBRC 108934 DSM 45340 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaNiwaeNbrc108934Dsm45340", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223489.protein.info.v11.5.txt",
		        "node_list_path": "1223489.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAlkalescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma alkalescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAlkalescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1188234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1188234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1188234.clusters.proteins.v11.5.txt",
		        "sequence_path": "1188234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188234.protein.info.v11.5.txt",
		        "node_list_path": "1188234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1188234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusInfantisSk1076Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis SK1076 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusInfantisSk1076Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005705.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005705.protein.info.v11.5.txt",
		        "node_list_path": "1005705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaTurkmenicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena turkmenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaTurkmenicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "543526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "543526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "543526.clusters.proteins.v11.5.txt",
		        "sequence_path": "543526.protein.sequences.v11.5.fa",
		        "enrichment_path": "543526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543526.protein.info.v11.5.txt",
		        "node_list_path": "543526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "543526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRu33aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. RU33A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRu33aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907413.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907413.protein.info.v11.5.txt",
		        "node_list_path": "1907413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumOlb19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium OLB19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumOlb19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617425.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617425.protein.info.v11.5.txt",
		        "node_list_path": "1617425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaAdelaidensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella adelaidensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaAdelaidensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45056.protein.sequences.v11.5.fa",
		        "enrichment_path": "45056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45056.protein.info.v11.5.txt",
		        "node_list_path": "45056.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetarhiziumAlbumArsef1941Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium album ARSEF 1941 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetarhiziumAlbumArsef1941Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1081103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1081103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1081103.clusters.proteins.v11.5.txt",
		        "sequence_path": "1081103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081103.protein.info.v11.5.txt",
		        "node_list_path": "1081103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1081103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumInfirmum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium infirmum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumInfirmum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883109.protein.sequences.v11.5.fa",
		        "enrichment_path": "883109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883109.protein.info.v11.5.txt",
		        "node_list_path": "883109.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaAcetivoransC2a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina acetivorans C2A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaAcetivoransC2a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "188937.protein.sequences.v11.5.fa",
		        "enrichment_path": "188937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188937.protein.info.v11.5.txt",
		        "node_list_path": "188937.protein.complete.v11.5.txt"
		    }
		]
    )()

def PopulusTrichocarpa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Populus trichocarpa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PopulusTrichocarpa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3694.protein.sequences.v11.5.fa",
		        "enrichment_path": "3694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3694.protein.info.v11.5.txt",
		        "node_list_path": "3694.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetanaerobacteriumElongatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetanaerobacterium elongatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetanaerobacteriumElongatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "258515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "258515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "258515.clusters.proteins.v11.5.txt",
		        "sequence_path": "258515.protein.sequences.v11.5.fa",
		        "enrichment_path": "258515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "258515.protein.info.v11.5.txt",
		        "node_list_path": "258515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "258515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpAt0102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. AT01-02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpAt0102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1571877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1571877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1571877.clusters.proteins.v11.5.txt",
		        "sequence_path": "1571877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1571877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1571877.protein.info.v11.5.txt",
		        "node_list_path": "1571877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1571877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium3713Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 37-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium3713Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895921.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895921.protein.info.v11.5.txt",
		        "node_list_path": "1895921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalopigerSalifodinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halopiger salifodinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalopigerSalifodinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1202768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202768.protein.info.v11.5.txt",
		        "node_list_path": "1202768.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudocercosporaEumusae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudocercospora eumusae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudocercosporaEumusae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321146.protein.sequences.v11.5.fa",
		        "enrichment_path": "321146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321146.protein.info.v11.5.txt",
		        "node_list_path": "321146.protein.complete.v11.5.txt"
		    }
		]
    )()

def HenriciellaLitoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Henriciella litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HenriciellaLitoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "568102.protein.sequences.v11.5.fa",
		        "enrichment_path": "568102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568102.protein.info.v11.5.txt",
		        "node_list_path": "568102.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpGm21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. GM21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpGm21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144325.protein.info.v11.5.txt",
		        "node_list_path": "1144325.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumParaconglomeratum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium paraconglomeratum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumParaconglomeratum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1064537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1064537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1064537.protein.info.v11.5.txt",
		        "node_list_path": "1064537.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumUmmarienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium ummariense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumUmmarienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1346791.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1346791.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1346791.clusters.proteins.v11.5.txt",
		        "sequence_path": "1346791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346791.protein.info.v11.5.txt",
		        "node_list_path": "1346791.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1346791.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh8102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh8102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84588.clusters.proteins.v11.5.txt",
		        "sequence_path": "84588.protein.sequences.v11.5.fa",
		        "enrichment_path": "84588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84588.protein.info.v11.5.txt",
		        "node_list_path": "84588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulophagaSpHelI12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga sp. Hel_I_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaSpHelI12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1249972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249972.protein.info.v11.5.txt",
		        "node_list_path": "1249972.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChthonomonasCalidiroseaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chthonomonas calidirosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChthonomonasCalidiroseaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1303518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1303518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1303518.clusters.proteins.v11.5.txt",
		        "sequence_path": "1303518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1303518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1303518.protein.info.v11.5.txt",
		        "node_list_path": "1303518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1303518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OenococcusOeni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oenococcus oeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OenococcusOeni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "203123.protein.sequences.v11.5.fa",
		        "enrichment_path": "203123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203123.protein.info.v11.5.txt",
		        "node_list_path": "203123.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpRoot444d2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Root444D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpRoot444d2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736538.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736538.protein.info.v11.5.txt",
		        "node_list_path": "1736538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCoagulans36d1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coagulans 36D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCoagulans36d1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "345219.protein.sequences.v11.5.fa",
		        "enrichment_path": "345219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "345219.protein.info.v11.5.txt",
		        "node_list_path": "345219.protein.complete.v11.5.txt"
		    }
		]
    )()

def WenxiniaSaemankumensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wenxinia saemankumensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WenxiniaSaemankumensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1447782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1447782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1447782.clusters.proteins.v11.5.txt",
		        "sequence_path": "1447782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1447782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1447782.protein.info.v11.5.txt",
		        "node_list_path": "1447782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1447782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolyangiumBrachysporumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Polyangium] brachysporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolyangiumBrachysporumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "413882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "413882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "413882.clusters.proteins.v11.5.txt",
		        "sequence_path": "413882.protein.sequences.v11.5.fa",
		        "enrichment_path": "413882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "413882.protein.info.v11.5.txt",
		        "node_list_path": "413882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "413882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FischerellaSpPcc9605Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FischerellaSpPcc9605Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173024.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173024.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173024.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173024.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173024.protein.info.v11.5.txt",
		        "node_list_path": "1173024.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173024.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpilithonimonasLactis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas lactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpilithonimonasLactis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "421072.protein.sequences.v11.5.fa",
		        "enrichment_path": "421072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "421072.protein.info.v11.5.txt",
		        "node_list_path": "421072.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumGw2011Gwa2447Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWA2_44_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwa2447Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619057.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619057.protein.info.v11.5.txt",
		        "node_list_path": "1619057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrugiaTimoriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brugia timori Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrugiaTimoriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42155.clusters.proteins.v11.5.txt",
		        "sequence_path": "42155.protein.sequences.v11.5.fa",
		        "enrichment_path": "42155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42155.protein.info.v11.5.txt",
		        "node_list_path": "42155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxya2Full5338(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2_FULL_53_38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2Full5338", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797961.protein.info.v11.5.txt",
		        "node_list_path": "1797961.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumSolitumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium solitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumSolitumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "60172.clusters.info.v11.5.txt",
		        "cluster_tree_path": "60172.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "60172.clusters.proteins.v11.5.txt",
		        "sequence_path": "60172.protein.sequences.v11.5.fa",
		        "enrichment_path": "60172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60172.protein.info.v11.5.txt",
		        "node_list_path": "60172.cluster.nodes.v11.5.txt",
		        "edge_list_path": "60172.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChrysochlorisAsiatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chrysochloris asiatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChrysochlorisAsiatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "185453.protein.sequences.v11.5.fa",
		        "enrichment_path": "185453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "185453.protein.info.v11.5.txt",
		        "node_list_path": "185453.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpP32e(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P32E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpP32e", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349434.protein.info.v11.5.txt",
		        "node_list_path": "1349434.protein.complete.v11.5.txt"
		    }
		]
    )()

def NodulariaSpumigenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nodularia spumigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NodulariaSpumigenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313624.clusters.proteins.v11.5.txt",
		        "sequence_path": "313624.protein.sequences.v11.5.fa",
		        "enrichment_path": "313624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313624.protein.info.v11.5.txt",
		        "node_list_path": "313624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumRbg19ftCombo7019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_19FT_COMBO_70_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumRbg19ftCombo7019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797208.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797208.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797208.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797208.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797208.protein.info.v11.5.txt",
		        "node_list_path": "1797208.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797208.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactococcusPisciumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus piscium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusPisciumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1364.clusters.proteins.v11.5.txt",
		        "sequence_path": "1364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1364.protein.info.v11.5.txt",
		        "node_list_path": "1364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaribacterOrientalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterOrientalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "228957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "228957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "228957.clusters.proteins.v11.5.txt",
		        "sequence_path": "228957.protein.sequences.v11.5.fa",
		        "enrichment_path": "228957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228957.protein.info.v11.5.txt",
		        "node_list_path": "228957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "228957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterLignolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter lignolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterLignolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "701347.protein.sequences.v11.5.fa",
		        "enrichment_path": "701347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "701347.protein.info.v11.5.txt",
		        "node_list_path": "701347.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasHortorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas hortorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasHortorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "863365.protein.sequences.v11.5.fa",
		        "enrichment_path": "863365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "863365.protein.info.v11.5.txt",
		        "node_list_path": "863365.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonRbg164813Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_16_48_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg164813Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797381.protein.info.v11.5.txt",
		        "node_list_path": "1797381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoriobacterialesBacteriumDnf00809Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriales bacterium DNF00809 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacterialesBacteriumDnf00809Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1588753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1588753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1588753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1588753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588753.protein.info.v11.5.txt",
		        "node_list_path": "1588753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1588753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MorchellaConicaCcbas932Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Morchella conica CCBAS932 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MorchellaConicaCcbas932Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392247.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392247.protein.info.v11.5.txt",
		        "node_list_path": "1392247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetallosphaeraSedula(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metallosphaera sedula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetallosphaeraSedula", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "399549.protein.sequences.v11.5.fa",
		        "enrichment_path": "399549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399549.protein.info.v11.5.txt",
		        "node_list_path": "399549.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpB1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. B1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpB1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1938756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938756.protein.info.v11.5.txt",
		        "node_list_path": "1938756.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaAldovae67083Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia aldovae 670-83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaAldovae67083Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1453495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1453495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1453495.clusters.proteins.v11.5.txt",
		        "sequence_path": "1453495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453495.protein.info.v11.5.txt",
		        "node_list_path": "1453495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1453495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrapisisporaBlattaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora blattae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrapisisporaBlattaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071379.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071379.protein.info.v11.5.txt",
		        "node_list_path": "1071379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlivibacterSitiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olivibacter sitiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlivibacterSitiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122621.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122621.protein.info.v11.5.txt",
		        "node_list_path": "1122621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanobiumSpCaciam14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanobium sp. CACIAM14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobiumSpCaciam14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1496688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1496688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1496688.clusters.proteins.v11.5.txt",
		        "sequence_path": "1496688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1496688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1496688.protein.info.v11.5.txt",
		        "node_list_path": "1496688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1496688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5421b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPLOWO2_01_FULL_54_21b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5421b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797245.protein.info.v11.5.txt",
		        "node_list_path": "1797245.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusRaffinosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus raffinosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusRaffinosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158602.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158602.protein.info.v11.5.txt",
		        "node_list_path": "1158602.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumPsychrophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium psychrophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumPsychrophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "402612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "402612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "402612.clusters.proteins.v11.5.txt",
		        "sequence_path": "402612.protein.sequences.v11.5.fa",
		        "enrichment_path": "402612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402612.protein.info.v11.5.txt",
		        "node_list_path": "402612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "402612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaDiazotrophicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia diazotrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaDiazotrophicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "667676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "667676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "667676.clusters.proteins.v11.5.txt",
		        "sequence_path": "667676.protein.sequences.v11.5.fa",
		        "enrichment_path": "667676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667676.protein.info.v11.5.txt",
		        "node_list_path": "667676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "667676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulochytriumProtostelioides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulochytrium protostelioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulochytriumProtostelioides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1555241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1555241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1555241.protein.info.v11.5.txt",
		        "node_list_path": "1555241.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusHaemolyticusM21639Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M21639 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusHaemolyticusM21639Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1028806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1028806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1028806.clusters.proteins.v11.5.txt",
		        "sequence_path": "1028806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028806.protein.info.v11.5.txt",
		        "node_list_path": "1028806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1028806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpBlattaOrientalisStrTarazona(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. (Blatta orientalis) str. Tarazona graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpBlattaOrientalisStrTarazona", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1072467.protein.sequences.v11.5.fa",
		        "enrichment_path": "1072467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1072467.protein.info.v11.5.txt",
		        "node_list_path": "1072467.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumGa0077534(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0077534 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumGa0077534", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752184.protein.info.v11.5.txt",
		        "node_list_path": "1752184.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpUrhd0024Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. URHD0024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpUrhd0024Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1302620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1302620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1302620.clusters.proteins.v11.5.txt",
		        "sequence_path": "1302620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302620.protein.info.v11.5.txt",
		        "node_list_path": "1302620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1302620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumCg10247685(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_47_685 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg10247685", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805282.protein.info.v11.5.txt",
		        "node_list_path": "1805282.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodocyclaceaeBacteriumPaddy1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodocyclaceae bacterium Paddy-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodocyclaceaeBacteriumPaddy1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1691980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1691980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1691980.protein.info.v11.5.txt",
		        "node_list_path": "1691980.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpH105Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. H105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpH105Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348393.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348393.protein.info.v11.5.txt",
		        "node_list_path": "1348393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFuchuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fuchuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFuchuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423747.protein.info.v11.5.txt",
		        "node_list_path": "1423747.protein.complete.v11.5.txt"
		    }
		]
    )()

def UreaplasmaDiversum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ureaplasma diversum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UreaplasmaDiversum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1188241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188241.protein.info.v11.5.txt",
		        "node_list_path": "1188241.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalogenimonasLykanthroporepellensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalogenimonas lykanthroporepellens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalogenimonasLykanthroporepellensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "552811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "552811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "552811.clusters.proteins.v11.5.txt",
		        "sequence_path": "552811.protein.sequences.v11.5.fa",
		        "enrichment_path": "552811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "552811.protein.info.v11.5.txt",
		        "node_list_path": "552811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "552811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumParvulumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium parvulum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumParvulumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521095.clusters.proteins.v11.5.txt",
		        "sequence_path": "521095.protein.sequences.v11.5.fa",
		        "enrichment_path": "521095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521095.protein.info.v11.5.txt",
		        "node_list_path": "521095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumFossorDsm15642(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium fossor DSM 15642 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumFossorDsm15642", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121023.protein.info.v11.5.txt",
		        "node_list_path": "1121023.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiobacillusDenitrificansAtcc25259(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus denitrificans ATCC25259 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusDenitrificansAtcc25259", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "292415.protein.sequences.v11.5.fa",
		        "enrichment_path": "292415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292415.protein.info.v11.5.txt",
		        "node_list_path": "292415.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAnginosusC238Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus C238 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAnginosusC238Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "862971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "862971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "862971.clusters.proteins.v11.5.txt",
		        "sequence_path": "862971.protein.sequences.v11.5.fa",
		        "enrichment_path": "862971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862971.protein.info.v11.5.txt",
		        "node_list_path": "862971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "862971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedLachnospiraSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Lachnospira sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedLachnospiraSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "446043.protein.sequences.v11.5.fa",
		        "enrichment_path": "446043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446043.protein.info.v11.5.txt",
		        "node_list_path": "446043.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpLeaf359Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Leaf359 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpLeaf359Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736351.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736351.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736351.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736351.protein.info.v11.5.txt",
		        "node_list_path": "1736351.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736351.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicycliphilusDenitrificansK601(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans K601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicycliphilusDenitrificansK601", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596154.protein.sequences.v11.5.fa",
		        "enrichment_path": "596154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596154.protein.info.v11.5.txt",
		        "node_list_path": "596154.protein.complete.v11.5.txt"
		    }
		]
    )()

def FacklamiaMiroungae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Facklamia miroungae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FacklamiaMiroungae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "120956.protein.sequences.v11.5.fa",
		        "enrichment_path": "120956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "120956.protein.info.v11.5.txt",
		        "node_list_path": "120956.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriiaBacteriumRifoxyc2Full3518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriia bacterium RIFOXYC2_FULL_35_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriiaBacteriumRifoxyc2Full3518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802166.protein.info.v11.5.txt",
		        "node_list_path": "1802166.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterLwoffiiSh145Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii SH145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterLwoffiiSh145Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575588.clusters.proteins.v11.5.txt",
		        "sequence_path": "575588.protein.sequences.v11.5.fa",
		        "enrichment_path": "575588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575588.protein.info.v11.5.txt",
		        "node_list_path": "575588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnabaenaSpWa102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anabaena sp. WA102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabaenaSpWa102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1647413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1647413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1647413.clusters.proteins.v11.5.txt",
		        "sequence_path": "1647413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1647413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1647413.protein.info.v11.5.txt",
		        "node_list_path": "1647413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1647413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusSpD1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus sp. D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusSpD1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "72304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "72304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "72304.clusters.proteins.v11.5.txt",
		        "sequence_path": "72304.protein.sequences.v11.5.fa",
		        "enrichment_path": "72304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72304.protein.info.v11.5.txt",
		        "node_list_path": "72304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "72304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3734(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_37_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3734", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798277.protein.info.v11.5.txt",
		        "node_list_path": "1798277.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaBarkeriMsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri MS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaBarkeriMsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434108.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434108.protein.info.v11.5.txt",
		        "node_list_path": "1434108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TsukamurellaPulmonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tsukamurella pulmonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TsukamurellaPulmonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47312.protein.sequences.v11.5.fa",
		        "enrichment_path": "47312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47312.protein.info.v11.5.txt",
		        "node_list_path": "47312.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumGw2011Gwa2377Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_37_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa2377Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618481.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618481.protein.info.v11.5.txt",
		        "node_list_path": "1618481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusGraminisDsm20719Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus graminis DSM 20719 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGraminisDsm20719Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423752.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423752.protein.info.v11.5.txt",
		        "node_list_path": "1423752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpArr65Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. ARR65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpArr65Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1040989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1040989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1040989.clusters.proteins.v11.5.txt",
		        "sequence_path": "1040989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1040989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1040989.protein.info.v11.5.txt",
		        "node_list_path": "1040989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1040989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilaceaeBacteriumUrha0031(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHA0031 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilaceaeBacteriumUrha0031", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380393.protein.info.v11.5.txt",
		        "node_list_path": "1380393.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumSit11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium SIT11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumSit11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1673726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1673726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1673726.clusters.proteins.v11.5.txt",
		        "sequence_path": "1673726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673726.protein.info.v11.5.txt",
		        "node_list_path": "1673726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1673726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SparassisCrispa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sparassis crispa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SparassisCrispa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "139825.protein.sequences.v11.5.fa",
		        "enrichment_path": "139825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "139825.protein.info.v11.5.txt",
		        "node_list_path": "139825.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusHalosaccharovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus halosaccharovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHalosaccharovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930124.protein.sequences.v11.5.fa",
		        "enrichment_path": "930124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930124.protein.info.v11.5.txt",
		        "node_list_path": "930124.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrodermaBenhamiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthroderma benhamiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrodermaBenhamiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "63400.protein.sequences.v11.5.fa",
		        "enrichment_path": "63400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63400.protein.info.v11.5.txt",
		        "node_list_path": "63400.protein.complete.v11.5.txt"
		    }
		]
    )()

def DimargarisCristalligenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dimargaris cristalligena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DimargarisCristalligenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "215637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "215637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "215637.clusters.proteins.v11.5.txt",
		        "sequence_path": "215637.protein.sequences.v11.5.fa",
		        "enrichment_path": "215637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215637.protein.info.v11.5.txt",
		        "node_list_path": "215637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "215637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19056Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19056 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19056Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1460650.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1460650.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1460650.clusters.proteins.v11.5.txt",
		        "sequence_path": "1460650.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460650.protein.info.v11.5.txt",
		        "node_list_path": "1460650.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1460650.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumScgcAaa288N07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA288-N07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumScgcAaa288N07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "939346.protein.sequences.v11.5.fa",
		        "enrichment_path": "939346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939346.protein.info.v11.5.txt",
		        "node_list_path": "939346.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSpAtcc39149Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora sp. ATCC39149 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSpAtcc39149Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "219305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "219305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "219305.clusters.proteins.v11.5.txt",
		        "sequence_path": "219305.protein.sequences.v11.5.fa",
		        "enrichment_path": "219305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "219305.protein.info.v11.5.txt",
		        "node_list_path": "219305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "219305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumOlb13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumOlb13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617414.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617414.protein.info.v11.5.txt",
		        "node_list_path": "1617414.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123307.protein.info.v11.5.txt",
		        "node_list_path": "1123307.protein.complete.v11.5.txt"
		    }
		]
    )()

def TaphrinaDeformansPycc5710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Taphrina deformans PYCC 5710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TaphrinaDeformansPycc5710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1097556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1097556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1097556.protein.info.v11.5.txt",
		        "node_list_path": "1097556.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylovulumMiyakonenseHt12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylovulum miyakonense HT12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylovulumMiyakonenseHt12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1078846.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1078846.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1078846.clusters.proteins.v11.5.txt",
		        "sequence_path": "1078846.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078846.protein.info.v11.5.txt",
		        "node_list_path": "1078846.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1078846.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpKbs0703Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. KBS0703 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpKbs0703Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1955698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1955698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1955698.clusters.proteins.v11.5.txt",
		        "sequence_path": "1955698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1955698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1955698.protein.info.v11.5.txt",
		        "node_list_path": "1955698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1955698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevrieseaAgamarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devriesea agamarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevrieseaAgamarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "472569.protein.sequences.v11.5.fa",
		        "enrichment_path": "472569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472569.protein.info.v11.5.txt",
		        "node_list_path": "472569.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeptunomonasQingdaonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neptunomonas qingdaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptunomonasQingdaonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1045558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045558.protein.info.v11.5.txt",
		        "node_list_path": "1045558.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSolventivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus solventivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSolventivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53463.protein.sequences.v11.5.fa",
		        "enrichment_path": "53463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53463.protein.info.v11.5.txt",
		        "node_list_path": "53463.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumAcmicro1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium acMicro-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumAcmicro1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1504316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1504316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1504316.clusters.proteins.v11.5.txt",
		        "sequence_path": "1504316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504316.protein.info.v11.5.txt",
		        "node_list_path": "1504316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1504316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpPcc7003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC 7003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpPcc7003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "374981.clusters.info.v11.5.txt",
		        "cluster_tree_path": "374981.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "374981.clusters.proteins.v11.5.txt",
		        "sequence_path": "374981.protein.sequences.v11.5.fa",
		        "enrichment_path": "374981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "374981.protein.info.v11.5.txt",
		        "node_list_path": "374981.cluster.nodes.v11.5.txt",
		        "edge_list_path": "374981.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterLapidariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter lapidarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterLapidariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1908237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1908237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1908237.clusters.proteins.v11.5.txt",
		        "sequence_path": "1908237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908237.protein.info.v11.5.txt",
		        "node_list_path": "1908237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1908237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloteneraSpRifcsplowo202Full4514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera sp. RIFCSPLOWO2_02_FULL_45_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraSpRifcsplowo202Full4514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801615.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801615.protein.info.v11.5.txt",
		        "node_list_path": "1801615.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiobacillusThioparusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus thioparus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusThioparusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123393.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123393.protein.info.v11.5.txt",
		        "node_list_path": "1123393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachyspiraPilosicoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira pilosicoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraPilosicoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "759914.protein.sequences.v11.5.fa",
		        "enrichment_path": "759914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759914.protein.info.v11.5.txt",
		        "node_list_path": "759914.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag403(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:403 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag403", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262958.protein.info.v11.5.txt",
		        "node_list_path": "1262958.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaSiciliaeC2j(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina siciliae C2J graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaSiciliaeC2j", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434118.protein.info.v11.5.txt",
		        "node_list_path": "1434118.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGa0077526Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077526 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077526Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752199.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752199.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752199.protein.info.v11.5.txt",
		        "node_list_path": "1752199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArdenticatenaMaritima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ardenticatena maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArdenticatenaMaritima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "872965.protein.sequences.v11.5.fa",
		        "enrichment_path": "872965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "872965.protein.info.v11.5.txt",
		        "node_list_path": "872965.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlaciecolaLipolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola lipolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaLipolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1127673.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127673.protein.info.v11.5.txt",
		        "node_list_path": "1127673.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumGw2011Gwc23313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWC2_33_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwc23313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619061.protein.info.v11.5.txt",
		        "node_list_path": "1619061.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85201452450Sch5900713Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852014-52450_SCH5900713 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85201452450Sch5900713Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834116.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834116.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834116.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834116.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834116.protein.info.v11.5.txt",
		        "node_list_path": "1834116.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834116.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeisingeraDaeponensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leisingera daeponensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraDaeponensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999547.clusters.proteins.v11.5.txt",
		        "sequence_path": "999547.protein.sequences.v11.5.fa",
		        "enrichment_path": "999547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999547.protein.info.v11.5.txt",
		        "node_list_path": "999547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesVariegatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces variegatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesVariegatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "284040.protein.sequences.v11.5.fa",
		        "enrichment_path": "284040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284040.protein.info.v11.5.txt",
		        "node_list_path": "284040.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSp24mn13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 24MN13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSp24mn13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1622150.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1622150.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1622150.clusters.proteins.v11.5.txt",
		        "sequence_path": "1622150.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622150.protein.info.v11.5.txt",
		        "node_list_path": "1622150.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1622150.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpAntimn1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. AntiMn-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpAntimn1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720344.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720344.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720344.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720344.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720344.protein.info.v11.5.txt",
		        "node_list_path": "1720344.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720344.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CloacimonetesBacteriumScgcAaa252P10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium SCGC AAA252-P10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CloacimonetesBacteriumScgcAaa252P10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1046972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1046972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1046972.clusters.proteins.v11.5.txt",
		        "sequence_path": "1046972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046972.protein.info.v11.5.txt",
		        "node_list_path": "1046972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1046972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinophagaSanctiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga sancti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaSanctiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1004.clusters.proteins.v11.5.txt",
		        "sequence_path": "1004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004.protein.info.v11.5.txt",
		        "node_list_path": "1004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodospirillalesBacteriumBbd199114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium BBD 1991-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillalesBacteriumBbd199114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852621.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852621.protein.info.v11.5.txt",
		        "node_list_path": "1852621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpGa1199Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1199 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpGa1199Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1772287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1772287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1772287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1772287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772287.protein.info.v11.5.txt",
		        "node_list_path": "1772287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1772287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JonquetellaAnthropiE333e1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jonquetella anthropi E333E1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JonquetellaAnthropiE333e1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "645512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "645512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "645512.clusters.proteins.v11.5.txt",
		        "sequence_path": "645512.protein.sequences.v11.5.fa",
		        "enrichment_path": "645512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645512.protein.info.v11.5.txt",
		        "node_list_path": "645512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "645512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylibiumSpRoot1272Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylibium sp. Root1272 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylibiumSpRoot1272Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736441.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736441.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736441.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736441.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736441.protein.info.v11.5.txt",
		        "node_list_path": "1736441.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736441.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrueperellaPyogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trueperella pyogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrueperellaPyogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1661.clusters.proteins.v11.5.txt",
		        "sequence_path": "1661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661.protein.info.v11.5.txt",
		        "node_list_path": "1661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteralesBacteriumHtcc2255Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium HTCC2255 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteralesBacteriumHtcc2255Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "367336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "367336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "367336.clusters.proteins.v11.5.txt",
		        "sequence_path": "367336.protein.sequences.v11.5.fa",
		        "enrichment_path": "367336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "367336.protein.info.v11.5.txt",
		        "node_list_path": "367336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "367336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmanitaMuscariaKoideBx008(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amanita muscaria Koide BX008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmanitaMuscariaKoideBx008", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "946122.protein.sequences.v11.5.fa",
		        "enrichment_path": "946122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946122.protein.info.v11.5.txt",
		        "node_list_path": "946122.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusLautus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus lautus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusLautus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401.protein.info.v11.5.txt",
		        "node_list_path": "1401.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccidioidesBrasiliensisPb18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides brasiliensis Pb18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccidioidesBrasiliensisPb18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "502780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "502780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "502780.clusters.proteins.v11.5.txt",
		        "sequence_path": "502780.protein.sequences.v11.5.fa",
		        "enrichment_path": "502780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502780.protein.info.v11.5.txt",
		        "node_list_path": "502780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "502780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinisporaTropicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinispora tropica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisporaTropicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "369723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "369723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "369723.clusters.proteins.v11.5.txt",
		        "sequence_path": "369723.protein.sequences.v11.5.fa",
		        "enrichment_path": "369723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "369723.protein.info.v11.5.txt",
		        "node_list_path": "369723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "369723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusParainfluenzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus parainfluenzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusParainfluenzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "862965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "862965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "862965.clusters.proteins.v11.5.txt",
		        "sequence_path": "862965.protein.sequences.v11.5.fa",
		        "enrichment_path": "862965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862965.protein.info.v11.5.txt",
		        "node_list_path": "862965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "862965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnetococcusMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetococcus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetococcusMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "156889.clusters.info.v11.5.txt",
		        "cluster_tree_path": "156889.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "156889.clusters.proteins.v11.5.txt",
		        "sequence_path": "156889.protein.sequences.v11.5.fa",
		        "enrichment_path": "156889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156889.protein.info.v11.5.txt",
		        "node_list_path": "156889.cluster.nodes.v11.5.txt",
		        "edge_list_path": "156889.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudocercosporaFijiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudocercospora fijiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudocercosporaFijiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83344.protein.sequences.v11.5.fa",
		        "enrichment_path": "83344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83344.protein.info.v11.5.txt",
		        "node_list_path": "83344.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasLutea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas lutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasLutea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243924.protein.sequences.v11.5.fa",
		        "enrichment_path": "243924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243924.protein.info.v11.5.txt",
		        "node_list_path": "243924.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeofilumRubicundumJcm15548(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geofilum rubicundum JCM 15548 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeofilumRubicundumJcm15548", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236989.protein.info.v11.5.txt",
		        "node_list_path": "1236989.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlossinaPallidipes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glossina pallidipes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlossinaPallidipes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7398.protein.sequences.v11.5.fa",
		        "enrichment_path": "7398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7398.protein.info.v11.5.txt",
		        "node_list_path": "7398.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasHelleriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas helleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasHelleriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1608996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1608996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1608996.clusters.proteins.v11.5.txt",
		        "sequence_path": "1608996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608996.protein.info.v11.5.txt",
		        "node_list_path": "1608996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1608996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg2303638(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_36_38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2303638", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805316.protein.info.v11.5.txt",
		        "node_list_path": "1805316.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusAviumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus avium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusAviumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1140002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1140002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1140002.clusters.proteins.v11.5.txt",
		        "sequence_path": "1140002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1140002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1140002.protein.info.v11.5.txt",
		        "node_list_path": "1140002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1140002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp11649854Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1164985.4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp11649854Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834069.protein.info.v11.5.txt",
		        "node_list_path": "1834069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanococcusHalocryophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planococcus halocryophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusHalocryophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1215089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1215089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1215089.clusters.proteins.v11.5.txt",
		        "sequence_path": "1215089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215089.protein.info.v11.5.txt",
		        "node_list_path": "1215089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1215089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasChlororaphis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas chlororaphis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasChlororaphis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "587753.protein.sequences.v11.5.fa",
		        "enrichment_path": "587753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "587753.protein.info.v11.5.txt",
		        "node_list_path": "587753.protein.complete.v11.5.txt"
		    }
		]
    )()

def SilicibacterSpTrichch4bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Silicibacter sp. TrichCH4B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SilicibacterSpTrichch4bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644076.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644076.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644076.clusters.proteins.v11.5.txt",
		        "sequence_path": "644076.protein.sequences.v11.5.fa",
		        "enrichment_path": "644076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644076.protein.info.v11.5.txt",
		        "node_list_path": "644076.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644076.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpDd10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpDd10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777878.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777878.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777878.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777878.protein.info.v11.5.txt",
		        "node_list_path": "1777878.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777878.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpHgCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. HG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpHgCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1638643.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1638643.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1638643.clusters.proteins.v11.5.txt",
		        "sequence_path": "1638643.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638643.protein.info.v11.5.txt",
		        "node_list_path": "1638643.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1638643.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpP1xp2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P1XP2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpP1xp2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1472719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1472719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1472719.protein.info.v11.5.txt",
		        "node_list_path": "1472719.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpSrsW22016Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. SRS-W-2-2016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpSrsW22016Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926878.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926878.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926878.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926878.protein.info.v11.5.txt",
		        "node_list_path": "1926878.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926878.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BelnapiaRosea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Belnapia rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BelnapiaRosea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "938405.protein.sequences.v11.5.fa",
		        "enrichment_path": "938405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938405.protein.info.v11.5.txt",
		        "node_list_path": "938405.protein.complete.v11.5.txt"
		    }
		]
    )()

def XylariaGrammicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylaria grammica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylariaGrammicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "363999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "363999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "363999.clusters.proteins.v11.5.txt",
		        "sequence_path": "363999.protein.sequences.v11.5.fa",
		        "enrichment_path": "363999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "363999.protein.info.v11.5.txt",
		        "node_list_path": "363999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "363999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusTetradius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus tetradius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusTetradius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525255.protein.sequences.v11.5.fa",
		        "enrichment_path": "525255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525255.protein.info.v11.5.txt",
		        "node_list_path": "525255.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpBh333(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. BH-3-3-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpBh333", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906742.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906742.protein.info.v11.5.txt",
		        "node_list_path": "1906742.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaCornellensisFslF60969Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria cornellensis FSL F6-0969 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaCornellensisFslF60969Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265820.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265820.protein.info.v11.5.txt",
		        "node_list_path": "1265820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYonathbacteriaBacteriumRifcsplowo201Full4327(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPLOWO2_01_FULL_43_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsplowo201Full4327", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802726.protein.info.v11.5.txt",
		        "node_list_path": "1802726.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomycesKudriavzeviiIfo1802(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomyces kudriavzevii IFO 1802 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomycesKudriavzeviiIfo1802", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "226230.protein.sequences.v11.5.fa",
		        "enrichment_path": "226230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226230.protein.info.v11.5.txt",
		        "node_list_path": "226230.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaChersinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora chersina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaChersinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47854.clusters.proteins.v11.5.txt",
		        "sequence_path": "47854.protein.sequences.v11.5.fa",
		        "enrichment_path": "47854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47854.protein.info.v11.5.txt",
		        "node_list_path": "47854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisElegansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis elegans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisElegansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6239.clusters.proteins.v11.5.txt",
		        "sequence_path": "6239.protein.sequences.v11.5.fa",
		        "enrichment_path": "6239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6239.protein.info.v11.5.txt",
		        "node_list_path": "6239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSp12014mblMicdivCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. 1_2014MBL_MicDiv Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSp12014mblMicdivCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1644131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1644131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1644131.clusters.proteins.v11.5.txt",
		        "sequence_path": "1644131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1644131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1644131.protein.info.v11.5.txt",
		        "node_list_path": "1644131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1644131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumLindaniclasticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium lindaniclasticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumLindaniclasticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1096930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1096930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1096930.protein.info.v11.5.txt",
		        "node_list_path": "1096930.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesDistasonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides distasonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesDistasonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "435591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "435591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "435591.clusters.proteins.v11.5.txt",
		        "sequence_path": "435591.protein.sequences.v11.5.fa",
		        "enrichment_path": "435591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435591.protein.info.v11.5.txt",
		        "node_list_path": "435591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "435591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumLepromatosisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium lepromatosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumLepromatosisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "480418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "480418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "480418.clusters.proteins.v11.5.txt",
		        "sequence_path": "480418.protein.sequences.v11.5.fa",
		        "enrichment_path": "480418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "480418.protein.info.v11.5.txt",
		        "node_list_path": "480418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "480418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacterSpImcc9063Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter sp. IMCC9063 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterSpImcc9063Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1002672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1002672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1002672.clusters.proteins.v11.5.txt",
		        "sequence_path": "1002672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002672.protein.info.v11.5.txt",
		        "node_list_path": "1002672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1002672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcoidesBurtoniiDsm6242Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanococcoides burtonii DSM 6242 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcoidesBurtoniiDsm6242Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "259564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "259564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "259564.clusters.proteins.v11.5.txt",
		        "sequence_path": "259564.protein.sequences.v11.5.fa",
		        "enrichment_path": "259564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "259564.protein.info.v11.5.txt",
		        "node_list_path": "259564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "259564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinovumAlgicolaDg898(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinovum algicola DG 898 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinovumAlgicolaDg898", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "988812.protein.sequences.v11.5.fa",
		        "enrichment_path": "988812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "988812.protein.info.v11.5.txt",
		        "node_list_path": "988812.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpUrhb0020Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. URHB0020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpUrhb0020Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380385.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380385.protein.info.v11.5.txt",
		        "node_list_path": "1380385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodotorulaTaiwanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodotorulaTaiwanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "741276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "741276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "741276.clusters.proteins.v11.5.txt",
		        "sequence_path": "741276.protein.sequences.v11.5.fa",
		        "enrichment_path": "741276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "741276.protein.info.v11.5.txt",
		        "node_list_path": "741276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "741276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifoxyd12Full5712(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12_FULL_57_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12Full5712", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797906.protein.info.v11.5.txt",
		        "node_list_path": "1797906.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParvularculaSpBbd199113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parvularcula sp. BBD 1991-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvularculaSpBbd199113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852618.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852618.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852618.protein.info.v11.5.txt",
		        "node_list_path": "1852618.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpS17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. S17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpS17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1007104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1007104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1007104.clusters.proteins.v11.5.txt",
		        "sequence_path": "1007104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007104.protein.info.v11.5.txt",
		        "node_list_path": "1007104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1007104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpLig30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. lig30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpLig30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1192124.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1192124.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1192124.clusters.proteins.v11.5.txt",
		        "sequence_path": "1192124.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192124.protein.info.v11.5.txt",
		        "node_list_path": "1192124.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1192124.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasHydrothermalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas hydrothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasHydrothermalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "115561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "115561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "115561.clusters.proteins.v11.5.txt",
		        "sequence_path": "115561.protein.sequences.v11.5.fa",
		        "enrichment_path": "115561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115561.protein.info.v11.5.txt",
		        "node_list_path": "115561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "115561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OpisthocomusHoazin(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Opisthocomus hoazin graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpisthocomusHoazin", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "30419.protein.sequences.v11.5.fa",
		        "enrichment_path": "30419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30419.protein.info.v11.5.txt",
		        "node_list_path": "30419.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaPneumoniaeCwl029(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae CWL029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaPneumoniaeCwl029", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "115713.protein.sequences.v11.5.fa",
		        "enrichment_path": "115713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115713.protein.info.v11.5.txt",
		        "node_list_path": "115713.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusLactolyticusAtcc51172(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus ATCC51172 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusLactolyticusAtcc51172", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525254.protein.sequences.v11.5.fa",
		        "enrichment_path": "525254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525254.protein.info.v11.5.txt",
		        "node_list_path": "525254.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaOralTaxonTm7xCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria oral taxon TM7x Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaOralTaxonTm7xCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1476577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1476577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1476577.clusters.proteins.v11.5.txt",
		        "sequence_path": "1476577.protein.sequences.v11.5.fa",
		        "enrichment_path": "1476577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1476577.protein.info.v11.5.txt",
		        "node_list_path": "1476577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1476577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalypteAnna(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Calypte anna graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalypteAnna", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9244.protein.sequences.v11.5.fa",
		        "enrichment_path": "9244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9244.protein.info.v11.5.txt",
		        "node_list_path": "9244.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho201Full3819(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_38_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full3819", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801732.protein.info.v11.5.txt",
		        "node_list_path": "1801732.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSp142Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. 142 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSp142Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235790.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235790.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235790.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235790.protein.info.v11.5.txt",
		        "node_list_path": "1235790.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235790.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp292mfCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 292MF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp292mfCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1151122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1151122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1151122.clusters.proteins.v11.5.txt",
		        "sequence_path": "1151122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151122.protein.info.v11.5.txt",
		        "node_list_path": "1151122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1151122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSp21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. 21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSp21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743722.clusters.proteins.v11.5.txt",
		        "sequence_path": "743722.protein.sequences.v11.5.fa",
		        "enrichment_path": "743722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743722.protein.info.v11.5.txt",
		        "node_list_path": "743722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DoreaLongicatenaAgr2136Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea longicatena AGR2136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaLongicatenaAgr2136Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280698.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280698.protein.info.v11.5.txt",
		        "node_list_path": "1280698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquifexAeolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquifex aeolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquifexAeolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "224324.protein.sequences.v11.5.fa",
		        "enrichment_path": "224324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224324.protein.info.v11.5.txt",
		        "node_list_path": "224324.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPseudoporcinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pseudoporcinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPseudoporcinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "910313.protein.sequences.v11.5.fa",
		        "enrichment_path": "910313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "910313.protein.info.v11.5.txt",
		        "node_list_path": "910313.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmatimonadetesBacteriumJgi0000077K19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium JGI 0000077-K19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmatimonadetesBacteriumJgi0000077K19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1104605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104605.protein.info.v11.5.txt",
		        "node_list_path": "1104605.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStreptomycesMassiliensisAp10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Streptomyces massiliensis AP10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStreptomycesMassiliensisAp10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211820.protein.info.v11.5.txt",
		        "node_list_path": "1211820.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioFerrireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioFerrireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246191.protein.sequences.v11.5.fa",
		        "enrichment_path": "246191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246191.protein.info.v11.5.txt",
		        "node_list_path": "246191.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpFc2011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. FC2011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpFc2011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408311.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408311.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408311.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408311.protein.info.v11.5.txt",
		        "node_list_path": "1408311.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408311.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpAtcc6931Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. ATCC6931 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpAtcc6931Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1487956.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1487956.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1487956.clusters.proteins.v11.5.txt",
		        "sequence_path": "1487956.protein.sequences.v11.5.fa",
		        "enrichment_path": "1487956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1487956.protein.info.v11.5.txt",
		        "node_list_path": "1487956.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1487956.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PterulaGracilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pterula gracilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PterulaGracilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884261.protein.info.v11.5.txt",
		        "node_list_path": "1884261.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumScn6937Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium SCN 69-37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumScn6937Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660160.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660160.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660160.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660160.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660160.protein.info.v11.5.txt",
		        "node_list_path": "1660160.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660160.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwe24214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWE2_42_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwe24214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618952.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618952.protein.info.v11.5.txt",
		        "node_list_path": "1618952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def Bacterium2013ark19iCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium 2013Ark19i Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Bacterium2013ark19iCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1561004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1561004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1561004.clusters.proteins.v11.5.txt",
		        "sequence_path": "1561004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561004.protein.info.v11.5.txt",
		        "node_list_path": "1561004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1561004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxEbreusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax ebreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxEbreusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "535289.clusters.info.v11.5.txt",
		        "cluster_tree_path": "535289.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "535289.clusters.proteins.v11.5.txt",
		        "sequence_path": "535289.protein.sequences.v11.5.fa",
		        "enrichment_path": "535289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "535289.protein.info.v11.5.txt",
		        "node_list_path": "535289.cluster.nodes.v11.5.txt",
		        "edge_list_path": "535289.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumElkaniiWsm2783Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii WSM2783 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumElkaniiWsm2783Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1038860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1038860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1038860.clusters.proteins.v11.5.txt",
		        "sequence_path": "1038860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038860.protein.info.v11.5.txt",
		        "node_list_path": "1038860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1038860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CloacimonetesBacteriumScgcAaa252N14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium SCGC AAA252-N14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CloacimonetesBacteriumScgcAaa252N14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1046965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1046965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1046965.clusters.proteins.v11.5.txt",
		        "sequence_path": "1046965.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046965.protein.info.v11.5.txt",
		        "node_list_path": "1046965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1046965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaueraSp27Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. 27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraSp27Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "305700.clusters.info.v11.5.txt",
		        "cluster_tree_path": "305700.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "305700.clusters.proteins.v11.5.txt",
		        "sequence_path": "305700.protein.sequences.v11.5.fa",
		        "enrichment_path": "305700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "305700.protein.info.v11.5.txt",
		        "node_list_path": "305700.cluster.nodes.v11.5.txt",
		        "edge_list_path": "305700.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumCg10239135Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium CG1_02_39_135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumCg10239135Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805425.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805425.protein.info.v11.5.txt",
		        "node_list_path": "1805425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacillusMangroviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus mangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusMangroviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "402384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "402384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "402384.clusters.proteins.v11.5.txt",
		        "sequence_path": "402384.protein.sequences.v11.5.fa",
		        "enrichment_path": "402384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402384.protein.info.v11.5.txt",
		        "node_list_path": "402384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "402384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasGingivalisW83Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis W83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasGingivalisW83Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "242619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "242619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "242619.clusters.proteins.v11.5.txt",
		        "sequence_path": "242619.protein.sequences.v11.5.fa",
		        "enrichment_path": "242619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "242619.protein.info.v11.5.txt",
		        "node_list_path": "242619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "242619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LoktanellaHongkongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaHongkongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122180.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122180.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122180.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122180.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122180.protein.info.v11.5.txt",
		        "node_list_path": "1122180.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122180.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesCellulosae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces cellulosae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCellulosae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1968.protein.info.v11.5.txt",
		        "node_list_path": "1968.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterWinghamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter winghamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterWinghamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "556267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "556267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "556267.clusters.proteins.v11.5.txt",
		        "sequence_path": "556267.protein.sequences.v11.5.fa",
		        "enrichment_path": "556267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556267.protein.info.v11.5.txt",
		        "node_list_path": "556267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "556267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaPickettii12j(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia pickettii 12J graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaPickettii12j", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "402626.protein.sequences.v11.5.fa",
		        "enrichment_path": "402626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402626.protein.info.v11.5.txt",
		        "node_list_path": "402626.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfocurvusVexinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfocurvus vexinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfocurvusVexinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121406.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121406.protein.info.v11.5.txt",
		        "node_list_path": "1121406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrotusOchrogasterCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microtus ochrogaster Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrotusOchrogasterCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "79684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "79684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "79684.clusters.proteins.v11.5.txt",
		        "sequence_path": "79684.protein.sequences.v11.5.fa",
		        "enrichment_path": "79684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79684.protein.info.v11.5.txt",
		        "node_list_path": "79684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "79684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpFb24(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. FB24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpFb24", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290399.protein.sequences.v11.5.fa",
		        "enrichment_path": "290399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290399.protein.info.v11.5.txt",
		        "node_list_path": "290399.protein.complete.v11.5.txt"
		    }
		]
    )()

def DefluviimonasSp20v17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Defluviimonas sp. 20V17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DefluviimonasSp20v17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1417296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1417296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1417296.clusters.proteins.v11.5.txt",
		        "sequence_path": "1417296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1417296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1417296.protein.info.v11.5.txt",
		        "node_list_path": "1417296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1417296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaHansenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blautia hansenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaHansenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "537007.protein.sequences.v11.5.fa",
		        "enrichment_path": "537007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537007.protein.info.v11.5.txt",
		        "node_list_path": "537007.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpHl58(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. HL58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpHl58", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1479237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479237.protein.info.v11.5.txt",
		        "node_list_path": "1479237.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumTumefaciensCherry(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens Cherry graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumTumefaciensCherry", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1281779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1281779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1281779.protein.info.v11.5.txt",
		        "node_list_path": "1281779.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobiusVermicularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobius vermicularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobiusVermicularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "51028.protein.sequences.v11.5.fa",
		        "enrichment_path": "51028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51028.protein.info.v11.5.txt",
		        "node_list_path": "51028.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumPorcinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium porcinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumPorcinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39693.protein.sequences.v11.5.fa",
		        "enrichment_path": "39693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39693.protein.info.v11.5.txt",
		        "node_list_path": "39693.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrondihabitansSpPamc28766(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frondihabitans sp. PAMC 28766 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrondihabitansSpPamc28766", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1795630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795630.protein.info.v11.5.txt",
		        "node_list_path": "1795630.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarineActinobacteriumMedacidiG2b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G2B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineActinobacteriumMedacidiG2b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1550401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550401.protein.info.v11.5.txt",
		        "node_list_path": "1550401.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag115(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:115 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag115", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262878.protein.info.v11.5.txt",
		        "node_list_path": "1262878.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumParaputrificumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium paraputrificum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumParaputrificumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280689.protein.info.v11.5.txt",
		        "node_list_path": "1280689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaMaritima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaMaritima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "519453.protein.sequences.v11.5.fa",
		        "enrichment_path": "519453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519453.protein.info.v11.5.txt",
		        "node_list_path": "519453.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriovoraxSpSeq25vCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. Seq25V Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriovoraxSpSeq25vCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1201288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1201288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1201288.clusters.proteins.v11.5.txt",
		        "sequence_path": "1201288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1201288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1201288.protein.info.v11.5.txt",
		        "node_list_path": "1201288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1201288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusNatl1a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus NATL1A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusNatl1a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "167555.protein.sequences.v11.5.fa",
		        "enrichment_path": "167555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167555.protein.info.v11.5.txt",
		        "node_list_path": "167555.protein.complete.v11.5.txt"
		    }
		]
    )()

def NonlabensSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "319236.clusters.info.v11.5.txt",
		        "cluster_tree_path": "319236.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "319236.clusters.proteins.v11.5.txt",
		        "sequence_path": "319236.protein.sequences.v11.5.fa",
		        "enrichment_path": "319236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319236.protein.info.v11.5.txt",
		        "node_list_path": "319236.cluster.nodes.v11.5.txt",
		        "edge_list_path": "319236.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanoprotosteliumFungivorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planoprotostelium fungivorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanoprotosteliumFungivorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1890364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1890364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1890364.protein.info.v11.5.txt",
		        "node_list_path": "1890364.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumMarisnigri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum marisnigri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumMarisnigri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1285242.protein.sequences.v11.5.fa",
		        "enrichment_path": "1285242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1285242.protein.info.v11.5.txt",
		        "node_list_path": "1285242.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionicicellaSuperfundiaDsm22317(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionicicella superfundia DSM 22317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionicicellaSuperfundiaDsm22317", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122999.protein.info.v11.5.txt",
		        "node_list_path": "1122999.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumWce2008Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium WCE2008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumWce2008Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945891.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945891.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945891.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945891.protein.info.v11.5.txt",
		        "node_list_path": "1945891.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945891.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaSchinkiiDsm10518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blautia schinkii DSM 10518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaSchinkiiDsm10518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410649.protein.info.v11.5.txt",
		        "node_list_path": "1410649.protein.complete.v11.5.txt"
		    }
		]
    )()

def EutypaLataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eutypa lata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EutypaLataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "97096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "97096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "97096.clusters.proteins.v11.5.txt",
		        "sequence_path": "97096.protein.sequences.v11.5.fa",
		        "enrichment_path": "97096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97096.protein.info.v11.5.txt",
		        "node_list_path": "97096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "97096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumCg2304142Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_41_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumCg2304142Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805277.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805277.protein.info.v11.5.txt",
		        "node_list_path": "1805277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaSpDc12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. DC12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpDc12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "683315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "683315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "683315.clusters.proteins.v11.5.txt",
		        "sequence_path": "683315.protein.sequences.v11.5.fa",
		        "enrichment_path": "683315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683315.protein.info.v11.5.txt",
		        "node_list_path": "683315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "683315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpFxj1172(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. FXJ1.172 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpFxj1172", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "710705.protein.sequences.v11.5.fa",
		        "enrichment_path": "710705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710705.protein.info.v11.5.txt",
		        "node_list_path": "710705.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5329(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_53_29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5329", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798480.protein.info.v11.5.txt",
		        "node_list_path": "1798480.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasHalophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas halophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasHalophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44576.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44576.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44576.clusters.proteins.v11.5.txt",
		        "sequence_path": "44576.protein.sequences.v11.5.fa",
		        "enrichment_path": "44576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44576.protein.info.v11.5.txt",
		        "node_list_path": "44576.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44576.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhialemoniopsisCurvata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phialemoniopsis curvata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhialemoniopsisCurvata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1093900.protein.sequences.v11.5.fa",
		        "enrichment_path": "1093900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1093900.protein.info.v11.5.txt",
		        "node_list_path": "1093900.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasAliena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas aliena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasAliena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "247523.protein.sequences.v11.5.fa",
		        "enrichment_path": "247523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247523.protein.info.v11.5.txt",
		        "node_list_path": "247523.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwb13322Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_33_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13322Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618566.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618566.protein.info.v11.5.txt",
		        "node_list_path": "1618566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DendrosporobacterQuercicolus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dendrosporobacter quercicolus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DendrosporobacterQuercicolus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "146817.protein.sequences.v11.5.fa",
		        "enrichment_path": "146817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146817.protein.info.v11.5.txt",
		        "node_list_path": "146817.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidimangrovimonasIndicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidimangrovimonas indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidimangrovimonasIndicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765699.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765699.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765699.clusters.proteins.v11.5.txt",
		        "sequence_path": "765699.protein.sequences.v11.5.fa",
		        "enrichment_path": "765699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765699.protein.info.v11.5.txt",
		        "node_list_path": "765699.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765699.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3925Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_01_FULL_39_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3925Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802202.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802202.protein.info.v11.5.txt",
		        "node_list_path": "1802202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusPlantarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus plantarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPlantarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "220668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "220668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "220668.clusters.proteins.v11.5.txt",
		        "sequence_path": "220668.protein.sequences.v11.5.fa",
		        "enrichment_path": "220668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220668.protein.info.v11.5.txt",
		        "node_list_path": "220668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "220668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellalesBacteriumRifcsphigho212Full3511Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionellales bacterium RIFCSPHIGHO2_12_FULL_35_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellalesBacteriumRifcsphigho212Full3511Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798567.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798567.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798567.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798567.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798567.protein.info.v11.5.txt",
		        "node_list_path": "1798567.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798567.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifcsplowo202Full5736(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO2_02_FULL_57_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo202Full5736", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797562.protein.info.v11.5.txt",
		        "node_list_path": "1797562.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusGaemokensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus gaemokensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGaemokensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "574375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "574375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "574375.clusters.proteins.v11.5.txt",
		        "sequence_path": "574375.protein.sequences.v11.5.fa",
		        "enrichment_path": "574375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574375.protein.info.v11.5.txt",
		        "node_list_path": "574375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "574375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KocuriaFlava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kocuria flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaFlava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "446860.protein.sequences.v11.5.fa",
		        "enrichment_path": "446860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446860.protein.info.v11.5.txt",
		        "node_list_path": "446860.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasHumi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasHumi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "405444.protein.sequences.v11.5.fa",
		        "enrichment_path": "405444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405444.protein.info.v11.5.txt",
		        "node_list_path": "405444.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetrasphaeraElongataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera elongata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrasphaeraElongataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193181.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193181.protein.info.v11.5.txt",
		        "node_list_path": "1193181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaPyrifoliaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia pyrifoliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaPyrifoliaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634499.clusters.proteins.v11.5.txt",
		        "sequence_path": "634499.protein.sequences.v11.5.fa",
		        "enrichment_path": "634499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634499.protein.info.v11.5.txt",
		        "node_list_path": "634499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMikellaEndobiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mikella endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMikellaEndobiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1778264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1778264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1778264.clusters.proteins.v11.5.txt",
		        "sequence_path": "1778264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1778264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1778264.protein.info.v11.5.txt",
		        "node_list_path": "1778264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1778264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminobacterSpRm87Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminobacter sp. RM87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminobacterSpRm87Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1200567.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1200567.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1200567.clusters.proteins.v11.5.txt",
		        "sequence_path": "1200567.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200567.protein.info.v11.5.txt",
		        "node_list_path": "1200567.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1200567.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE1214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E1214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE1214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834123.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834123.protein.info.v11.5.txt",
		        "node_list_path": "1834123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf67Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf67Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736230.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736230.protein.info.v11.5.txt",
		        "node_list_path": "1736230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaTropicalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida tropicalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaTropicalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5482.protein.sequences.v11.5.fa",
		        "enrichment_path": "5482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5482.protein.info.v11.5.txt",
		        "node_list_path": "5482.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSilesiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas silesiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSilesiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1853130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1853130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1853130.protein.info.v11.5.txt",
		        "node_list_path": "1853130.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusAcidiphilusNbrc100859(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidiphilus NBRC 100859 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusAcidiphilusNbrc100859", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1255277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1255277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1255277.protein.info.v11.5.txt",
		        "node_list_path": "1255277.protein.complete.v11.5.txt"
		    }
		]
    )()

def SistotremastrumSuecicumHhb10207Ss3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sistotremastrum suecicum HHB10207 ss-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SistotremastrumSuecicumHhb10207Ss3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314776.protein.info.v11.5.txt",
		        "node_list_path": "1314776.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetragenococcusMuriaticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetragenococcus muriaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetragenococcusMuriaticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123359.protein.info.v11.5.txt",
		        "node_list_path": "1123359.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusCleftensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus cleftensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusCleftensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "163003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "163003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "163003.clusters.proteins.v11.5.txt",
		        "sequence_path": "163003.protein.sequences.v11.5.fa",
		        "enrichment_path": "163003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "163003.protein.info.v11.5.txt",
		        "node_list_path": "163003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "163003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FomitopsisPinicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fomitopsis pinicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FomitopsisPinicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40483.protein.sequences.v11.5.fa",
		        "enrichment_path": "40483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40483.protein.info.v11.5.txt",
		        "node_list_path": "40483.protein.complete.v11.5.txt"
		    }
		]
    )()

def PatulibacterMinatonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Patulibacter minatonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PatulibacterMinatonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "929712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "929712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "929712.clusters.proteins.v11.5.txt",
		        "sequence_path": "929712.protein.sequences.v11.5.fa",
		        "enrichment_path": "929712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929712.protein.info.v11.5.txt",
		        "node_list_path": "929712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "929712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxyd2Full3415Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYD2_FULL_34_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyd2Full3415Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797973.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797973.protein.info.v11.5.txt",
		        "node_list_path": "1797973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesCuracoi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces curacoi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCuracoi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "146536.protein.sequences.v11.5.fa",
		        "enrichment_path": "146536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146536.protein.info.v11.5.txt",
		        "node_list_path": "146536.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpTb15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. TB15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpTb15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "494416.protein.sequences.v11.5.fa",
		        "enrichment_path": "494416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "494416.protein.info.v11.5.txt",
		        "node_list_path": "494416.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesNaeslundiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces naeslundii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesNaeslundiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1115803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1115803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1115803.clusters.proteins.v11.5.txt",
		        "sequence_path": "1115803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1115803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1115803.protein.info.v11.5.txt",
		        "node_list_path": "1115803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1115803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumMerycicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium merycicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumMerycicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "78345.protein.sequences.v11.5.fa",
		        "enrichment_path": "78345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78345.protein.info.v11.5.txt",
		        "node_list_path": "78345.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusSpG1w1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. G1w1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusSpG1w1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1430331.protein.sequences.v11.5.fa",
		        "enrichment_path": "1430331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1430331.protein.info.v11.5.txt",
		        "node_list_path": "1430331.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumSpOl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. OL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumSpOl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1504822.protein.sequences.v11.0.fa",
		        "enrichment_path": "1504822.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1504822.protein.info.v11.0.txt",
		        "node_list_path": "1504822.protein.complete.v11.0.txt"
		    }
		]
    )()

def VolvoxCarteri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Volvox carteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VolvoxCarteri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3067.protein.sequences.v11.5.fa",
		        "enrichment_path": "3067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3067.protein.info.v11.5.txt",
		        "node_list_path": "3067.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaSativaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaSativaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4530.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4530.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4530.clusters.proteins.v11.5.txt",
		        "sequence_path": "4530.protein.sequences.v11.5.fa",
		        "enrichment_path": "4530.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4530.protein.info.v11.5.txt",
		        "node_list_path": "4530.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4530.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpAp49Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. AP49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpAp49Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144307.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144307.protein.info.v11.5.txt",
		        "node_list_path": "1144307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumAlbumDsm18261(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium album DSM 18261 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumAlbumDsm18261", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121122.protein.info.v11.5.txt",
		        "node_list_path": "1121122.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSpN418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. N418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpN418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "701176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "701176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "701176.clusters.proteins.v11.5.txt",
		        "sequence_path": "701176.protein.sequences.v11.5.fa",
		        "enrichment_path": "701176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "701176.protein.info.v11.5.txt",
		        "node_list_path": "701176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "701176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPabuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus pabuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPabuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1472.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1472.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1472.clusters.proteins.v11.5.txt",
		        "sequence_path": "1472.protein.sequences.v11.5.fa",
		        "enrichment_path": "1472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1472.protein.info.v11.5.txt",
		        "node_list_path": "1472.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1472.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2034155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2034155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2034155.clusters.proteins.v11.5.txt",
		        "sequence_path": "2034155.protein.sequences.v11.5.fa",
		        "enrichment_path": "2034155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2034155.protein.info.v11.5.txt",
		        "node_list_path": "2034155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2034155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhycicoccusDokdonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phycicoccus dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycicoccusDokdonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "443156.protein.sequences.v11.5.fa",
		        "enrichment_path": "443156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443156.protein.info.v11.5.txt",
		        "node_list_path": "443156.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZetaproteobacteriaBacteriumTag1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium TAG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaproteobacteriaBacteriumTag1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1485545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1485545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1485545.protein.info.v11.5.txt",
		        "node_list_path": "1485545.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaSpeluncaeNbrc108251Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia speluncae NBRC 108251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSpeluncaeNbrc108251Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210094.protein.info.v11.5.txt",
		        "node_list_path": "1210094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwd24019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWD2_40_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwd24019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618595.protein.info.v11.5.txt",
		        "node_list_path": "1618595.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioclavaPacifica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioclava pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaPacifica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1353537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353537.protein.info.v11.5.txt",
		        "node_list_path": "1353537.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioMimicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio mimicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioMimicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675806.clusters.proteins.v11.5.txt",
		        "sequence_path": "675806.protein.sequences.v11.5.fa",
		        "enrichment_path": "675806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675806.protein.info.v11.5.txt",
		        "node_list_path": "675806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinagarivoransAlgicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinagarivorans algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinagarivoransAlgicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1513270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1513270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1513270.clusters.proteins.v11.5.txt",
		        "sequence_path": "1513270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1513270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1513270.protein.info.v11.5.txt",
		        "node_list_path": "1513270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1513270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicaulisSpHtcc2633Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. HTCC2633 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicaulisSpHtcc2633Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314254.clusters.proteins.v11.5.txt",
		        "sequence_path": "314254.protein.sequences.v11.5.fa",
		        "enrichment_path": "314254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314254.protein.info.v11.5.txt",
		        "node_list_path": "314254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PanaeolusCyanescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Panaeolus cyanescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PanaeolusCyanescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "181874.protein.sequences.v11.5.fa",
		        "enrichment_path": "181874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "181874.protein.info.v11.5.txt",
		        "node_list_path": "181874.protein.complete.v11.5.txt"
		    }
		]
    )()

def AuricoccusIndicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Auricoccus indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AuricoccusIndicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849491.protein.info.v11.5.txt",
		        "node_list_path": "1849491.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumChromiireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium chromiireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumChromiireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "225345.protein.sequences.v11.5.fa",
		        "enrichment_path": "225345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225345.protein.info.v11.5.txt",
		        "node_list_path": "225345.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaMazeiS6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina mazei S-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaMazeiS6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "213585.protein.sequences.v11.5.fa",
		        "enrichment_path": "213585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "213585.protein.info.v11.5.txt",
		        "node_list_path": "213585.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasMarincolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas marincola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMarincolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "437900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "437900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "437900.clusters.proteins.v11.5.txt",
		        "sequence_path": "437900.protein.sequences.v11.5.fa",
		        "enrichment_path": "437900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "437900.protein.info.v11.5.txt",
		        "node_list_path": "437900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "437900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCystitidisDsm20524Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium cystitidis DSM 20524 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCystitidisDsm20524Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121357.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121357.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121357.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121357.protein.info.v11.5.txt",
		        "node_list_path": "1121357.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121357.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpA37(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. A37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpA37", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945864.protein.info.v11.5.txt",
		        "node_list_path": "1945864.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumBact10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumBact10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674824.protein.info.v11.5.txt",
		        "node_list_path": "1674824.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusEndophyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus endophyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusEndophyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196029.protein.info.v11.5.txt",
		        "node_list_path": "1196029.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionCpr1BacteriumGw2011Gwc14913(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR1 bacterium GW2011_GWC1_49_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionCpr1BacteriumGw2011Gwc14913", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618342.protein.info.v11.5.txt",
		        "node_list_path": "1618342.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpSr15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. SR1/5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpSr15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "657323.protein.sequences.v11.5.fa",
		        "enrichment_path": "657323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657323.protein.info.v11.5.txt",
		        "node_list_path": "657323.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSunkiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sunkii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSunkiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "481719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "481719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "481719.clusters.proteins.v11.5.txt",
		        "sequence_path": "481719.protein.sequences.v11.5.fa",
		        "enrichment_path": "481719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481719.protein.info.v11.5.txt",
		        "node_list_path": "481719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "481719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumGw2011Gwa13716(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWA1_37_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwa13716", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618452.protein.info.v11.5.txt",
		        "node_list_path": "1618452.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesBacteriumUtcpr1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates bacterium UTCPR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesBacteriumUtcpr1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1961107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1961107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1961107.clusters.proteins.v11.5.txt",
		        "sequence_path": "1961107.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961107.protein.info.v11.5.txt",
		        "node_list_path": "1961107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1961107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OxalobacterFormigenesHoxblsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes HOxBLS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OxalobacterFormigenesHoxblsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "556268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "556268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "556268.clusters.proteins.v11.5.txt",
		        "sequence_path": "556268.protein.sequences.v11.5.fa",
		        "enrichment_path": "556268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556268.protein.info.v11.5.txt",
		        "node_list_path": "556268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "556268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMuproteobacteriaBacteriumRbg166213(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_62_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166213", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817756.protein.info.v11.5.txt",
		        "node_list_path": "1817756.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidaminobacterHydrogenoformansDsm2784Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidaminobacter hydrogenoformans DSM 2784 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminobacterHydrogenoformansDsm2784Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120920.protein.info.v11.5.txt",
		        "node_list_path": "1120920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801776.protein.info.v11.5.txt",
		        "node_list_path": "1801776.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirosomaMontaniterrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma montaniterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaMontaniterrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1178516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1178516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1178516.protein.info.v11.5.txt",
		        "node_list_path": "1178516.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesPratensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces pratensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPratensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "591167.clusters.info.v11.5.txt",
		        "cluster_tree_path": "591167.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "591167.clusters.proteins.v11.5.txt",
		        "sequence_path": "591167.protein.sequences.v11.5.fa",
		        "enrichment_path": "591167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591167.protein.info.v11.5.txt",
		        "node_list_path": "591167.cluster.nodes.v11.5.txt",
		        "edge_list_path": "591167.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaSihwensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sihwensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSihwensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223544.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223544.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223544.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223544.protein.info.v11.5.txt",
		        "node_list_path": "1223544.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223544.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumPiperi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium piperi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumPiperi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "558152.protein.sequences.v11.5.fa",
		        "enrichment_path": "558152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558152.protein.info.v11.5.txt",
		        "node_list_path": "558152.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPohangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pohangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPohangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "364197.protein.sequences.v11.5.fa",
		        "enrichment_path": "364197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "364197.protein.info.v11.5.txt",
		        "node_list_path": "364197.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaIvanoviiLondoniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria ivanovii londoniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaIvanoviiLondoniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "202752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "202752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "202752.clusters.proteins.v11.5.txt",
		        "sequence_path": "202752.protein.sequences.v11.5.fa",
		        "enrichment_path": "202752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202752.protein.info.v11.5.txt",
		        "node_list_path": "202752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "202752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesF0058(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes F0058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesF0058", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575590.protein.sequences.v11.5.fa",
		        "enrichment_path": "575590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575590.protein.info.v11.5.txt",
		        "node_list_path": "575590.protein.complete.v11.5.txt"
		    }
		]
    )()

def DuganellaSpOv510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. OV510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpOv510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881039.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881039.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881039.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881039.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881039.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881039.protein.info.v11.5.txt",
		        "node_list_path": "1881039.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881039.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CholoepusHoffmanniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Choloepus hoffmanni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CholoepusHoffmanniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9358.clusters.proteins.v11.5.txt",
		        "sequence_path": "9358.protein.sequences.v11.5.fa",
		        "enrichment_path": "9358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9358.protein.info.v11.5.txt",
		        "node_list_path": "9358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat44921Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-44921 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat44921Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1912214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1912214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1912214.clusters.proteins.v11.5.txt",
		        "sequence_path": "1912214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912214.protein.info.v11.5.txt",
		        "node_list_path": "1912214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1912214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRhodobacterLobularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rhodobacter lobularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRhodobacterLobularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1675527.protein.sequences.v11.5.fa",
		        "enrichment_path": "1675527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1675527.protein.info.v11.5.txt",
		        "node_list_path": "1675527.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsplowo202Full5710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO2_02_FULL_57_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo202Full5710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798299.protein.info.v11.5.txt",
		        "node_list_path": "1798299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpAc2796(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. AC27/96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpAc2796", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841653.protein.info.v11.5.txt",
		        "node_list_path": "1841653.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioRuminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioRuminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46206.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46206.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46206.clusters.proteins.v11.5.txt",
		        "sequence_path": "46206.protein.sequences.v11.5.fa",
		        "enrichment_path": "46206.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46206.protein.info.v11.5.txt",
		        "node_list_path": "46206.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46206.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriaceaeBacteriumChkci005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacteriaceae bacterium CHKCI005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriaceaeBacteriumChkci005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1780381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780381.protein.info.v11.5.txt",
		        "node_list_path": "1780381.protein.complete.v11.5.txt"
		    }
		]
    )()

def FriedmanniomycesSimplexCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Friedmanniomyces simplex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FriedmanniomycesSimplexCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "329884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "329884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "329884.clusters.proteins.v11.5.txt",
		        "sequence_path": "329884.protein.sequences.v11.5.fa",
		        "enrichment_path": "329884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "329884.protein.info.v11.5.txt",
		        "node_list_path": "329884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "329884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpPanFs17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. PAN_FS17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpPanFs17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855351.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855351.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855351.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855351.protein.info.v11.5.txt",
		        "node_list_path": "1855351.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855351.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellvibrioSpBrCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio sp. BR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioSpBrCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1134474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1134474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1134474.clusters.proteins.v11.5.txt",
		        "sequence_path": "1134474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134474.protein.info.v11.5.txt",
		        "node_list_path": "1134474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1134474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisBenevestitus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis benevestitus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisBenevestitus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121022.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121022.protein.info.v11.5.txt",
		        "node_list_path": "1121022.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumRbg19ftCombo5817(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_19FT_COMBO_58_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg19ftCombo5817", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797275.protein.info.v11.5.txt",
		        "node_list_path": "1797275.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaAlgae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella algae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaAlgae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "38313.protein.sequences.v11.5.fa",
		        "enrichment_path": "38313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38313.protein.info.v11.5.txt",
		        "node_list_path": "38313.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumAsp1004a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium ASP10-04a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumAsp1004a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1622230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622230.protein.info.v11.5.txt",
		        "node_list_path": "1622230.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSpF0131Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. F0131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSpF0131Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575609.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575609.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575609.clusters.proteins.v11.5.txt",
		        "sequence_path": "575609.protein.sequences.v11.5.fa",
		        "enrichment_path": "575609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575609.protein.info.v11.5.txt",
		        "node_list_path": "575609.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575609.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasBovisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasBovisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123250.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123250.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123250.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123250.protein.info.v11.5.txt",
		        "node_list_path": "1123250.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123250.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusPseudopneumoniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pseudopneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPseudopneumoniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1054460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1054460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1054460.protein.info.v11.5.txt",
		        "node_list_path": "1054460.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaTribocorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella tribocorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaTribocorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "382640.clusters.info.v11.5.txt",
		        "cluster_tree_path": "382640.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "382640.clusters.proteins.v11.5.txt",
		        "sequence_path": "382640.protein.sequences.v11.5.fa",
		        "enrichment_path": "382640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "382640.protein.info.v11.5.txt",
		        "node_list_path": "382640.cluster.nodes.v11.5.txt",
		        "edge_list_path": "382640.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBaylyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter baylyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBaylyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "202950.protein.sequences.v11.5.fa",
		        "enrichment_path": "202950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202950.protein.info.v11.5.txt",
		        "node_list_path": "202950.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanococcusAtlanticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanococcus atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanococcusAtlanticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1317117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1317117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1317117.clusters.proteins.v11.5.txt",
		        "sequence_path": "1317117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317117.protein.info.v11.5.txt",
		        "node_list_path": "1317117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1317117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpFd1Xmd(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. fd1-xmd graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpFd1Xmd", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1812480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1812480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1812480.protein.info.v11.5.txt",
		        "node_list_path": "1812480.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumZagget3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Zagget3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumZagget3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930016.protein.info.v11.5.txt",
		        "node_list_path": "1930016.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacterSegnis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter segnis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSegnis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "509190.protein.sequences.v11.5.fa",
		        "enrichment_path": "509190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "509190.protein.info.v11.5.txt",
		        "node_list_path": "509190.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaSpS4079(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella sp. S4079 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaSpS4079", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "579483.protein.sequences.v11.5.fa",
		        "enrichment_path": "579483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579483.protein.info.v11.5.txt",
		        "node_list_path": "579483.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosospiraSpNsp14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraSpNsp14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855333.protein.info.v11.5.txt",
		        "node_list_path": "1855333.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraAlexanderi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira alexanderi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraAlexanderi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "100053.protein.sequences.v11.5.fa",
		        "enrichment_path": "100053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "100053.protein.info.v11.5.txt",
		        "node_list_path": "100053.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumOlb9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumOlb9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617420.protein.info.v11.5.txt",
		        "node_list_path": "1617420.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFlexibilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas flexibilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFlexibilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "706570.protein.sequences.v11.5.fa",
		        "enrichment_path": "706570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706570.protein.info.v11.5.txt",
		        "node_list_path": "706570.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpJcm10914Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 10914 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpJcm10914Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236974.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236974.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236974.protein.info.v11.5.txt",
		        "node_list_path": "1236974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa25110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_51_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa25110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618855.protein.info.v11.5.txt",
		        "node_list_path": "1618855.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaTakedensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia takedensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaTakedensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206735.protein.info.v11.5.txt",
		        "node_list_path": "1206735.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraProfundimarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira profundimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraProfundimarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1177928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1177928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1177928.clusters.proteins.v11.5.txt",
		        "sequence_path": "1177928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177928.protein.info.v11.5.txt",
		        "node_list_path": "1177928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1177928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpCot239oh1446(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT239OH1446 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpCot239oh1446", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1515613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1515613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1515613.protein.info.v11.5.txt",
		        "node_list_path": "1515613.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusKitasatonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kitasatonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKitasatonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423767.protein.info.v11.5.txt",
		        "node_list_path": "1423767.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrachymyrmexSeptentrionalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trachymyrmex septentrionalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrachymyrmexSeptentrionalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34720.clusters.proteins.v11.5.txt",
		        "sequence_path": "34720.protein.sequences.v11.5.fa",
		        "enrichment_path": "34720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34720.protein.info.v11.5.txt",
		        "node_list_path": "34720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiobacillusDenitrificansDsm12475Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus denitrificans DSM12475 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusDenitrificansDsm12475Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123392.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123392.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123392.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123392.protein.info.v11.5.txt",
		        "node_list_path": "1123392.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123392.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusHaloduransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus halodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHaloduransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272558.clusters.proteins.v11.5.txt",
		        "sequence_path": "272558.protein.sequences.v11.5.fa",
		        "enrichment_path": "272558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272558.protein.info.v11.5.txt",
		        "node_list_path": "272558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusUvarumCbs121591Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus uvarum CBS 121591 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusUvarumCbs121591Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1448315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1448315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1448315.clusters.proteins.v11.5.txt",
		        "sequence_path": "1448315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448315.protein.info.v11.5.txt",
		        "node_list_path": "1448315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1448315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumPopuleti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] populeti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPopuleti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37658.protein.sequences.v11.5.fa",
		        "enrichment_path": "37658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37658.protein.info.v11.5.txt",
		        "node_list_path": "37658.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasTurrisvirgataeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas turrisvirgatae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasTurrisvirgataeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1888892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1888892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1888892.clusters.proteins.v11.5.txt",
		        "sequence_path": "1888892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1888892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1888892.protein.info.v11.5.txt",
		        "node_list_path": "1888892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1888892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaAquaticaFslS101188Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria aquatica FSL S10-1188 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaAquaticaFslS101188Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265818.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265818.protein.info.v11.5.txt",
		        "node_list_path": "1265818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryobacteriumLuteum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryobacterium luteum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryobacteriumLuteum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1424661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1424661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1424661.protein.info.v11.5.txt",
		        "node_list_path": "1424661.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeolamprologusBrichardiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neolamprologus brichardi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeolamprologusBrichardiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32507.clusters.proteins.v11.5.txt",
		        "sequence_path": "32507.protein.sequences.v11.5.fa",
		        "enrichment_path": "32507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32507.protein.info.v11.5.txt",
		        "node_list_path": "32507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaVaviloviaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea vaviloviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaVaviloviaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1526658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1526658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1526658.clusters.proteins.v11.5.txt",
		        "sequence_path": "1526658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1526658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1526658.protein.info.v11.5.txt",
		        "node_list_path": "1526658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1526658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccidioidesLutziiPb01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides lutzii Pb01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccidioidesLutziiPb01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "502779.protein.sequences.v11.5.fa",
		        "enrichment_path": "502779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502779.protein.info.v11.5.txt",
		        "node_list_path": "502779.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetovibrioBlakemoreiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetovibrio blakemorei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetovibrioBlakemoreiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28181.clusters.proteins.v11.5.txt",
		        "sequence_path": "28181.protein.sequences.v11.5.fa",
		        "enrichment_path": "28181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28181.protein.info.v11.5.txt",
		        "node_list_path": "28181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumRectaleAtcc33656(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Eubacterium] rectale ATCC 33656 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumRectaleAtcc33656", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "515619.protein.sequences.v11.5.fa",
		        "enrichment_path": "515619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515619.protein.info.v11.5.txt",
		        "node_list_path": "515619.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrococcusTerreusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micrococcus terreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcusTerreusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "574650.clusters.info.v11.5.txt",
		        "cluster_tree_path": "574650.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "574650.clusters.proteins.v11.5.txt",
		        "sequence_path": "574650.protein.sequences.v11.5.fa",
		        "enrichment_path": "574650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574650.protein.info.v11.5.txt",
		        "node_list_path": "574650.cluster.nodes.v11.5.txt",
		        "edge_list_path": "574650.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MacrococcusCanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Macrococcus canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacrococcusCanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855823.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855823.protein.info.v11.5.txt",
		        "node_list_path": "1855823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfolobusSpA20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus sp. A20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusSpA20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1891280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1891280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1891280.clusters.proteins.v11.5.txt",
		        "sequence_path": "1891280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891280.protein.info.v11.5.txt",
		        "node_list_path": "1891280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1891280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PararheinheimeraTexasensisDsm17496Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pararheinheimera texasensis DSM 17496 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PararheinheimeraTexasensisDsm17496Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123055.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123055.protein.info.v11.5.txt",
		        "node_list_path": "1123055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1034943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1034943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1034943.clusters.proteins.v11.5.txt",
		        "sequence_path": "1034943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034943.protein.info.v11.5.txt",
		        "node_list_path": "1034943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1034943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumMf105b01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium Mf 105b01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumMf105b01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1282876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1282876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1282876.clusters.proteins.v11.5.txt",
		        "sequence_path": "1282876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282876.protein.info.v11.5.txt",
		        "node_list_path": "1282876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1282876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCystitidisDsm20524(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium cystitidis DSM 20524 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCystitidisDsm20524", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121357.protein.info.v11.5.txt",
		        "node_list_path": "1121357.protein.complete.v11.5.txt"
		    }
		]
    )()

def RheinheimeraBaltica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera baltica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraBaltica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123053.protein.info.v11.5.txt",
		        "node_list_path": "1123053.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycesMaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces maris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycesMaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "344747.protein.sequences.v11.5.fa",
		        "enrichment_path": "344747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "344747.protein.info.v11.5.txt",
		        "node_list_path": "344747.protein.complete.v11.5.txt"
		    }
		]
    )()

def DomibacillusIocasae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus iocasae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusIocasae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1714016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714016.protein.info.v11.5.txt",
		        "node_list_path": "1714016.protein.complete.v11.5.txt"
		    }
		]
    )()

def JonesiaQuinghaiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jonesia quinghaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JonesiaQuinghaiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122130.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122130.protein.info.v11.5.txt",
		        "node_list_path": "1122130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeisingeraDaeponensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leisingera daeponensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraDaeponensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999547.protein.sequences.v11.5.fa",
		        "enrichment_path": "999547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999547.protein.info.v11.5.txt",
		        "node_list_path": "999547.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchizophyllumCommuneCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizophyllum commune Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizophyllumCommuneCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5334.clusters.proteins.v11.5.txt",
		        "sequence_path": "5334.protein.sequences.v11.5.fa",
		        "enrichment_path": "5334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5334.protein.info.v11.5.txt",
		        "node_list_path": "5334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacinutrixVenerupisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix venerupis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixVenerupisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1486034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1486034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1486034.clusters.proteins.v11.5.txt",
		        "sequence_path": "1486034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1486034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1486034.protein.info.v11.5.txt",
		        "node_list_path": "1486034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1486034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MustelaPutoriusFuroCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mustela putorius furo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MustelaPutoriusFuroCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9669.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9669.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9669.clusters.proteins.v11.5.txt",
		        "sequence_path": "9669.protein.sequences.v11.5.fa",
		        "enrichment_path": "9669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9669.protein.info.v11.5.txt",
		        "node_list_path": "9669.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9669.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EmpedobacterBrevisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Empedobacter brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmpedobacterBrevisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218108.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218108.protein.info.v11.5.txt",
		        "node_list_path": "1218108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MegasphaeraSpNm10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. NM10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraSpNm10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1273103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1273103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1273103.clusters.proteins.v11.5.txt",
		        "sequence_path": "1273103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1273103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1273103.protein.info.v11.5.txt",
		        "node_list_path": "1273103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1273103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpX2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. X2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpX2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "941449.protein.sequences.v11.5.fa",
		        "enrichment_path": "941449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "941449.protein.info.v11.5.txt",
		        "node_list_path": "941449.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpRoot227(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root227 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpRoot227", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736496.protein.info.v11.5.txt",
		        "node_list_path": "1736496.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpAcs4331(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS4331 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpAcs4331", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834121.protein.info.v11.5.txt",
		        "node_list_path": "1834121.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanococcusMaripaludisC5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusMaripaludisC5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "402880.protein.sequences.v11.5.fa",
		        "enrichment_path": "402880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402880.protein.info.v11.5.txt",
		        "node_list_path": "402880.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacteriumRifcsphigho202Full3412(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFCSPHIGHO2_02_FULL_34_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifcsphigho202Full3412", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801607.protein.info.v11.5.txt",
		        "node_list_path": "1801607.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumImitansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium imitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumImitansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "156978.clusters.info.v11.5.txt",
		        "cluster_tree_path": "156978.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "156978.clusters.proteins.v11.5.txt",
		        "sequence_path": "156978.protein.sequences.v11.5.fa",
		        "enrichment_path": "156978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156978.protein.info.v11.5.txt",
		        "node_list_path": "156978.cluster.nodes.v11.5.txt",
		        "edge_list_path": "156978.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterHenriciiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter henricii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterHenriciiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69395.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69395.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69395.clusters.proteins.v11.5.txt",
		        "sequence_path": "69395.protein.sequences.v11.5.fa",
		        "enrichment_path": "69395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69395.protein.info.v11.5.txt",
		        "node_list_path": "69395.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69395.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcusMaripaludisC5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusMaripaludisC5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "402880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "402880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "402880.clusters.proteins.v11.5.txt",
		        "sequence_path": "402880.protein.sequences.v11.5.fa",
		        "enrichment_path": "402880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402880.protein.info.v11.5.txt",
		        "node_list_path": "402880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "402880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGa0077554(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0077554 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGa0077554", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752215.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752215.protein.info.v11.5.txt",
		        "node_list_path": "1752215.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSpSk02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSpSk02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1453999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453999.protein.info.v11.5.txt",
		        "node_list_path": "1453999.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriumSar116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Alphaproteobacterium SAR116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriumSar116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "909943.clusters.info.v11.0.txt",
		        "cluster_tree_path": "909943.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "909943.clusters.proteins.v11.0.txt",
		        "sequence_path": "909943.protein.sequences.v11.0.fa",
		        "enrichment_path": "909943.protein.enrichment.terms.v11.0.txt",
		        "info_path": "909943.protein.info.v11.0.txt",
		        "node_list_path": "909943.cluster.nodes.v11.0.txt",
		        "edge_list_path": "909943.protein.cluster.v11.0.txt"
		    }
		]
    )()

def DesulfuromonadaceaeBacteriumGwc25813(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromonadaceae bacterium GWC2_58_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromonadaceaeBacteriumGwc25813", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801896.protein.info.v11.5.txt",
		        "node_list_path": "1801896.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacteriumSpCba1132Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium sp. CBA1132 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacteriumSpCba1132Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1765057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1765057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1765057.clusters.proteins.v11.5.txt",
		        "sequence_path": "1765057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765057.protein.info.v11.5.txt",
		        "node_list_path": "1765057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1765057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaS16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida S16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaS16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1042876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1042876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1042876.clusters.proteins.v11.5.txt",
		        "sequence_path": "1042876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042876.protein.info.v11.5.txt",
		        "node_list_path": "1042876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1042876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MobilibacteriumTimonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mobilibacterium timonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobilibacteriumTimonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871012.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871012.protein.info.v11.5.txt",
		        "node_list_path": "1871012.protein.complete.v11.5.txt"
		    }
		]
    )()

def KitasatosporaSetae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora setae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaSetae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "452652.protein.sequences.v11.5.fa",
		        "enrichment_path": "452652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452652.protein.info.v11.5.txt",
		        "node_list_path": "452652.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacteralesBacteriumRifcsphigho201Full7019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacterales bacterium RIFCSPHIGHO2_01_FULL_70_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacteralesBacteriumRifcsphigho201Full7019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797585.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797585.protein.info.v11.5.txt",
		        "node_list_path": "1797585.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentimicrobiumSaccharophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentimicrobium saccharophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentimicrobiumSaccharophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1678841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1678841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1678841.clusters.proteins.v11.5.txt",
		        "sequence_path": "1678841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678841.protein.info.v11.5.txt",
		        "node_list_path": "1678841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1678841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDichloromethanomonasElyunquensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dichloromethanomonas elyunquensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDichloromethanomonasElyunquensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1755312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1755312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1755312.clusters.proteins.v11.5.txt",
		        "sequence_path": "1755312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1755312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1755312.protein.info.v11.5.txt",
		        "node_list_path": "1755312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1755312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpUrha0036Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. URHA0036 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpUrha0036Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298860.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298860.protein.info.v11.5.txt",
		        "node_list_path": "1298860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZymoseptoriaTriticiSt99ch3d7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici ST99CH_3D7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymoseptoriaTriticiSt99ch3d7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1276538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276538.protein.info.v11.5.txt",
		        "node_list_path": "1276538.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaFlavaNbrc102514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga flava NBRC 102514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaFlavaNbrc102514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349752.protein.info.v11.5.txt",
		        "node_list_path": "1349752.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterThiooxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter thiooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterThiooxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163409.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1163409.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1163409.clusters.proteins.v11.5.txt",
		        "sequence_path": "1163409.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163409.protein.info.v11.5.txt",
		        "node_list_path": "1163409.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1163409.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonB25Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB25Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1779369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1779369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1779369.clusters.proteins.v11.5.txt",
		        "sequence_path": "1779369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1779369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1779369.protein.info.v11.5.txt",
		        "node_list_path": "1779369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1779369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpGr602Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. GR 6-02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpGr602Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1659194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1659194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1659194.clusters.proteins.v11.5.txt",
		        "sequence_path": "1659194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659194.protein.info.v11.5.txt",
		        "node_list_path": "1659194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1659194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaCorporisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella corporis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaCorporisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122981.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122981.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122981.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122981.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122981.protein.info.v11.5.txt",
		        "node_list_path": "1122981.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122981.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalegentibacterHolothuriorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter holothuriorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterHolothuriorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "241145.clusters.info.v11.5.txt",
		        "cluster_tree_path": "241145.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "241145.clusters.proteins.v11.5.txt",
		        "sequence_path": "241145.protein.sequences.v11.5.fa",
		        "enrichment_path": "241145.protein.enrichment.terms.v11.5.txt",
		        "info_path": "241145.protein.info.v11.5.txt",
		        "node_list_path": "241145.cluster.nodes.v11.5.txt",
		        "edge_list_path": "241145.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot483d2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root483D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot483d2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736545.protein.info.v11.5.txt",
		        "node_list_path": "1736545.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastococcusSpDsm44268Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 44268 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusSpDsm44268Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1550231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1550231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1550231.clusters.proteins.v11.5.txt",
		        "sequence_path": "1550231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550231.protein.info.v11.5.txt",
		        "node_list_path": "1550231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1550231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumGw2011Gwa14161Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium GW2011_GWA1_41_61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumGw2011Gwa14161Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618419.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618419.protein.info.v11.5.txt",
		        "node_list_path": "1618419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinilactibacillusSp15r(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinilactibacillus sp. 15R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinilactibacillusSp15r", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1911586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1911586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1911586.protein.info.v11.5.txt",
		        "node_list_path": "1911586.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSpSk12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSpSk12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1454001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454001.protein.info.v11.5.txt",
		        "node_list_path": "1454001.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCrK1w(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Cr-K1W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCrK1w", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1452537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1452537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1452537.protein.info.v11.5.txt",
		        "node_list_path": "1452537.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinopolymorphaCephalotaxiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinopolymorpha cephalotaxi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolymorphaCephalotaxiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "504797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "504797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "504797.clusters.proteins.v11.5.txt",
		        "sequence_path": "504797.protein.sequences.v11.5.fa",
		        "enrichment_path": "504797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504797.protein.info.v11.5.txt",
		        "node_list_path": "504797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "504797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElizabethkingiaMeningosepticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elizabethkingia meningoseptica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElizabethkingiaMeningosepticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216967.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216967.protein.info.v11.5.txt",
		        "node_list_path": "1216967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrellaAestuarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrella aestuarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrellaAestuarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1166018.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166018.protein.info.v11.5.txt",
		        "node_list_path": "1166018.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosospiraSpApg3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. APG3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraSpApg3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288494.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288494.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288494.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288494.protein.info.v11.5.txt",
		        "node_list_path": "1288494.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288494.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChroococcidiopsisThermalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chroococcidiopsis thermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChroococcidiopsisThermalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "251229.protein.sequences.v11.5.fa",
		        "enrichment_path": "251229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "251229.protein.info.v11.5.txt",
		        "node_list_path": "251229.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumMarseillenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium marseillense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumMarseillenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "701042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "701042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "701042.clusters.proteins.v11.5.txt",
		        "sequence_path": "701042.protein.sequences.v11.5.fa",
		        "enrichment_path": "701042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "701042.protein.info.v11.5.txt",
		        "node_list_path": "701042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "701042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RothiaDentocariosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rothia dentocariosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RothiaDentocariosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762948.protein.sequences.v11.5.fa",
		        "enrichment_path": "762948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762948.protein.info.v11.5.txt",
		        "node_list_path": "762948.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterAerophilusDsm13606Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter aerophilus DSM 13606 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterAerophilusDsm13606Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121953.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121953.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121953.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121953.protein.info.v11.5.txt",
		        "node_list_path": "1121953.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121953.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4322Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_43_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4322Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798688.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798688.protein.info.v11.5.txt",
		        "node_list_path": "1798688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrnithinibacillusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ornithinibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithinibacillusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930117.clusters.proteins.v11.5.txt",
		        "sequence_path": "930117.protein.sequences.v11.5.fa",
		        "enrichment_path": "930117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930117.protein.info.v11.5.txt",
		        "node_list_path": "930117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusInfernusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus infernus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusInfernusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573063.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573063.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573063.clusters.proteins.v11.5.txt",
		        "sequence_path": "573063.protein.sequences.v11.5.fa",
		        "enrichment_path": "573063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573063.protein.info.v11.5.txt",
		        "node_list_path": "573063.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573063.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterLari(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter lari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterLari", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "306263.protein.sequences.v11.5.fa",
		        "enrichment_path": "306263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306263.protein.info.v11.5.txt",
		        "node_list_path": "306263.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCellulosilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cellulosilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCellulosilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649639.protein.sequences.v11.5.fa",
		        "enrichment_path": "649639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649639.protein.info.v11.5.txt",
		        "node_list_path": "649639.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaPersimilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila persimilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaPersimilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7234.protein.sequences.v11.5.fa",
		        "enrichment_path": "7234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7234.protein.info.v11.5.txt",
		        "node_list_path": "7234.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumMor1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Mor1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumMor1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660251.protein.info.v11.5.txt",
		        "node_list_path": "1660251.protein.complete.v11.5.txt"
		    }
		]
    )()

def AequorivitaVladivostokensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aequorivita vladivostokensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AequorivitaVladivostokensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "171194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "171194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "171194.clusters.proteins.v11.5.txt",
		        "sequence_path": "171194.protein.sequences.v11.5.fa",
		        "enrichment_path": "171194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "171194.protein.info.v11.5.txt",
		        "node_list_path": "171194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "171194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAnthracisSterneCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis Sterne Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAnthracisSterneCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "260799.clusters.info.v11.5.txt",
		        "cluster_tree_path": "260799.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "260799.clusters.proteins.v11.5.txt",
		        "sequence_path": "260799.protein.sequences.v11.5.fa",
		        "enrichment_path": "260799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "260799.protein.info.v11.5.txt",
		        "node_list_path": "260799.cluster.nodes.v11.5.txt",
		        "edge_list_path": "260799.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioProteolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio proteolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioProteolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219065.protein.info.v11.5.txt",
		        "node_list_path": "1219065.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParamaledivibacterCaminithermalisDsm15212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paramaledivibacter caminithermalis DSM 15212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParamaledivibacterCaminithermalisDsm15212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121301.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121301.protein.info.v11.5.txt",
		        "node_list_path": "1121301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumTimonianum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium timonianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumTimonianum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805473.protein.info.v11.5.txt",
		        "node_list_path": "1805473.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusIndicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusIndicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246786.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246786.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246786.clusters.proteins.v11.5.txt",
		        "sequence_path": "246786.protein.sequences.v11.5.fa",
		        "enrichment_path": "246786.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246786.protein.info.v11.5.txt",
		        "node_list_path": "246786.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246786.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquamicrobiumSpLc103Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquamicrobium sp. LC103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquamicrobiumSpLc103Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120658.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120658.protein.info.v11.5.txt",
		        "node_list_path": "1120658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32002.clusters.proteins.v11.5.txt",
		        "sequence_path": "32002.protein.sequences.v11.5.fa",
		        "enrichment_path": "32002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32002.protein.info.v11.5.txt",
		        "node_list_path": "32002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphopichiaBurtoniiNrrlY1933Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphopichia burtonii NRRL Y-1933 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphopichiaBurtoniiNrrlY1933Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "984485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "984485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "984485.clusters.proteins.v11.5.txt",
		        "sequence_path": "984485.protein.sequences.v11.5.fa",
		        "enrichment_path": "984485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "984485.protein.info.v11.5.txt",
		        "node_list_path": "984485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "984485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PersephonellaSpKm09lau8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Persephonella sp. KM09Lau8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PersephonellaSpKm09lau8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158345.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158345.protein.info.v11.5.txt",
		        "node_list_path": "1158345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag770Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:770 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag770Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262751.protein.info.v11.5.txt",
		        "node_list_path": "1262751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollinsellaAerofaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collinsella aerofaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaAerofaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "74426.protein.sequences.v11.5.fa",
		        "enrichment_path": "74426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74426.protein.info.v11.5.txt",
		        "node_list_path": "74426.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicavibrioAeruginosavorusArl13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micavibrio aeruginosavorus ARL13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicavibrioAeruginosavorusArl13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "856793.protein.sequences.v11.5.fa",
		        "enrichment_path": "856793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "856793.protein.info.v11.5.txt",
		        "node_list_path": "856793.protein.complete.v11.5.txt"
		    }
		]
    )()

def MitsuokellaJalaludiniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mitsuokella jalaludinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MitsuokellaJalaludiniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410665.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410665.protein.info.v11.5.txt",
		        "node_list_path": "1410665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraInterrogansSerovarLaiStr56601(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira interrogans serovar Lai str. 56601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraInterrogansSerovarLaiStr56601", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "189518.protein.sequences.v11.5.fa",
		        "enrichment_path": "189518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189518.protein.info.v11.5.txt",
		        "node_list_path": "189518.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpXs5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. XS5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpXs5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1775636.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775636.protein.info.v11.5.txt",
		        "node_list_path": "1775636.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4520Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_01_FULL_45_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4520Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802444.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802444.protein.info.v11.5.txt",
		        "node_list_path": "1802444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesQaidamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces qaidamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesQaidamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1783515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1783515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1783515.protein.info.v11.5.txt",
		        "node_list_path": "1783515.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonasKerstersiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas kerstersii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasKerstersiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "225992.clusters.info.v11.5.txt",
		        "cluster_tree_path": "225992.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "225992.clusters.proteins.v11.5.txt",
		        "sequence_path": "225992.protein.sequences.v11.5.fa",
		        "enrichment_path": "225992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225992.protein.info.v11.5.txt",
		        "node_list_path": "225992.cluster.nodes.v11.5.txt",
		        "edge_list_path": "225992.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterSpAbm4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter sp. AbM4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterSpAbm4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "224719.protein.sequences.v11.5.fa",
		        "enrichment_path": "224719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224719.protein.info.v11.5.txt",
		        "node_list_path": "224719.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpRoot901Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root901 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpRoot901Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736605.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736605.protein.info.v11.5.txt",
		        "node_list_path": "1736605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BasidiobolusMeristosporusCbs93173Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Basidiobolus meristosporus CBS 931.73 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BasidiobolusMeristosporusCbs93173Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314790.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314790.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314790.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314790.protein.info.v11.5.txt",
		        "node_list_path": "1314790.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314790.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumProfundi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium profundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumProfundi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "450380.protein.sequences.v11.5.fa",
		        "enrichment_path": "450380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "450380.protein.info.v11.5.txt",
		        "node_list_path": "450380.protein.complete.v11.5.txt"
		    }
		]
    )()

def ReyranellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Reyranella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ReyranellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1205680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1205680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1205680.clusters.proteins.v11.5.txt",
		        "sequence_path": "1205680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1205680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1205680.protein.info.v11.5.txt",
		        "node_list_path": "1205680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1205680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSanguinisSk355(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK355 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSanguinisSk355", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888816.protein.sequences.v11.5.fa",
		        "enrichment_path": "888816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888816.protein.info.v11.5.txt",
		        "node_list_path": "888816.protein.complete.v11.5.txt"
		    }
		]
    )()

def EikenellaSpNml130454Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eikenella sp. NML130454 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EikenellaSpNml130454Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1795832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1795832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1795832.clusters.proteins.v11.5.txt",
		        "sequence_path": "1795832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795832.protein.info.v11.5.txt",
		        "node_list_path": "1795832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1795832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusPyridinivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus pyridinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusPyridinivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1435356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1435356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1435356.protein.info.v11.5.txt",
		        "node_list_path": "1435356.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpL74Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. L74 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpL74Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1560217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1560217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1560217.clusters.proteins.v11.5.txt",
		        "sequence_path": "1560217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1560217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1560217.protein.info.v11.5.txt",
		        "node_list_path": "1560217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1560217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiaceaeBacteriumSg6cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobiaceae bacterium SG6C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiaceaeBacteriumSg6cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "709797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "709797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "709797.clusters.proteins.v11.5.txt",
		        "sequence_path": "709797.protein.sequences.v11.5.fa",
		        "enrichment_path": "709797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709797.protein.info.v11.5.txt",
		        "node_list_path": "709797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "709797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanotorrisFormicicusMcS70(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanotorris formicicus Mc-S-70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanotorrisFormicicusMcS70", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "647171.protein.sequences.v11.5.fa",
		        "enrichment_path": "647171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "647171.protein.info.v11.5.txt",
		        "node_list_path": "647171.protein.complete.v11.5.txt"
		    }
		]
    )()

def KomagataellaPhaffiiGs115Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataella phaffii GS115 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataellaPhaffiiGs115Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644223.clusters.proteins.v11.5.txt",
		        "sequence_path": "644223.protein.sequences.v11.5.fa",
		        "enrichment_path": "644223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644223.protein.info.v11.5.txt",
		        "node_list_path": "644223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpAtcc31555Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. ATCC31555 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpAtcc31555Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "194867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "194867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "194867.clusters.proteins.v11.5.txt",
		        "sequence_path": "194867.protein.sequences.v11.5.fa",
		        "enrichment_path": "194867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "194867.protein.info.v11.5.txt",
		        "node_list_path": "194867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "194867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf339Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf339 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf339Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736343.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736343.protein.info.v11.5.txt",
		        "node_list_path": "1736343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfuricurvumSpPc0866Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. PC08-66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricurvumSpPc0866Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1539066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1539066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1539066.clusters.proteins.v11.5.txt",
		        "sequence_path": "1539066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1539066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1539066.protein.info.v11.5.txt",
		        "node_list_path": "1539066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1539066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusGonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus gonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusGonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "198467.protein.sequences.v11.5.fa",
		        "enrichment_path": "198467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198467.protein.info.v11.5.txt",
		        "node_list_path": "198467.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterEngbaekii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter engbaekii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterEngbaekii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "188915.protein.sequences.v11.5.fa",
		        "enrichment_path": "188915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188915.protein.info.v11.5.txt",
		        "node_list_path": "188915.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumSpMar201089Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. MAR_2010_89 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumSpMar201089Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1250198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1250198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1250198.clusters.proteins.v11.5.txt",
		        "sequence_path": "1250198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250198.protein.info.v11.5.txt",
		        "node_list_path": "1250198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1250198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterPiechaudiiHleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii HLE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterPiechaudiiHleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1156919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1156919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1156919.clusters.proteins.v11.5.txt",
		        "sequence_path": "1156919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156919.protein.info.v11.5.txt",
		        "node_list_path": "1156919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1156919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusFaecium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusFaecium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1352.protein.info.v11.5.txt",
		        "node_list_path": "1352.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosopumilusSpLsAoa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. LS_AOA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopumilusSpLsAoa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671876.protein.info.v11.5.txt",
		        "node_list_path": "1671876.protein.complete.v11.5.txt"
		    }
		]
    )()

def FervidicellaMetallireducensAebCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fervidicella metallireducens AeB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidicellaMetallireducensAebCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1403537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1403537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1403537.clusters.proteins.v11.5.txt",
		        "sequence_path": "1403537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403537.protein.info.v11.5.txt",
		        "node_list_path": "1403537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1403537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogulbenkianiaFerrooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogulbenkianiaFerrooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "279714.clusters.info.v11.5.txt",
		        "cluster_tree_path": "279714.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "279714.clusters.proteins.v11.5.txt",
		        "sequence_path": "279714.protein.sequences.v11.5.fa",
		        "enrichment_path": "279714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279714.protein.info.v11.5.txt",
		        "node_list_path": "279714.cluster.nodes.v11.5.txt",
		        "edge_list_path": "279714.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriTs44Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri TS44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriTs44Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "477228.clusters.info.v11.5.txt",
		        "cluster_tree_path": "477228.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "477228.clusters.proteins.v11.5.txt",
		        "sequence_path": "477228.protein.sequences.v11.5.fa",
		        "enrichment_path": "477228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477228.protein.info.v11.5.txt",
		        "node_list_path": "477228.cluster.nodes.v11.5.txt",
		        "edge_list_path": "477228.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumRivuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium rivuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumRivuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121895.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121895.protein.info.v11.5.txt",
		        "node_list_path": "1121895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaliobacillusSpPm2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraliobacillus sp. PM-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaliobacillusSpPm2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1462524.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1462524.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1462524.clusters.proteins.v11.5.txt",
		        "sequence_path": "1462524.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462524.protein.info.v11.5.txt",
		        "node_list_path": "1462524.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1462524.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNealsonbacteriaBacteriumRifoxyb1Full4015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFOXYB1_FULL_40_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifoxyb1Full4015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801677.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801677.protein.info.v11.5.txt",
		        "node_list_path": "1801677.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMutansUa159(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mutans UA159 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMutansUa159", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "210007.protein.sequences.v11.5.fa",
		        "enrichment_path": "210007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "210007.protein.info.v11.5.txt",
		        "node_list_path": "210007.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpMan2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. MAN2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpMan2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1101188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101188.protein.info.v11.5.txt",
		        "node_list_path": "1101188.protein.complete.v11.5.txt"
		    }
		]
    )()

def GramellaSpMar2010102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gramella sp. MAR_2010_102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaSpMar2010102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1250231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1250231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1250231.clusters.proteins.v11.5.txt",
		        "sequence_path": "1250231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250231.protein.info.v11.5.txt",
		        "node_list_path": "1250231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1250231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaSpWd162Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. WD16.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpWd162Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1933904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1933904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1933904.clusters.proteins.v11.5.txt",
		        "sequence_path": "1933904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933904.protein.info.v11.5.txt",
		        "node_list_path": "1933904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1933904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumMassiliodielmoense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium massiliodielmoense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumMassiliodielmoense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776385.protein.info.v11.5.txt",
		        "node_list_path": "1776385.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAgalactiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAgalactiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2110.clusters.proteins.v11.5.txt",
		        "sequence_path": "2110.protein.sequences.v11.5.fa",
		        "enrichment_path": "2110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2110.protein.info.v11.5.txt",
		        "node_list_path": "2110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumThoeniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium thoenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumThoeniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122998.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122998.protein.info.v11.5.txt",
		        "node_list_path": "1122998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesClarusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides clarus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesClarusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762984.clusters.proteins.v11.5.txt",
		        "sequence_path": "762984.protein.sequences.v11.5.fa",
		        "enrichment_path": "762984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762984.protein.info.v11.5.txt",
		        "node_list_path": "762984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaXenovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia xenovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaXenovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266265.clusters.proteins.v11.5.txt",
		        "sequence_path": "266265.protein.sequences.v11.5.fa",
		        "enrichment_path": "266265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266265.protein.info.v11.5.txt",
		        "node_list_path": "266265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpLf1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. LF1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpLf1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499688.protein.info.v11.5.txt",
		        "node_list_path": "1499688.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpB29(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. B29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpB29", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1933220.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933220.protein.info.v11.5.txt",
		        "node_list_path": "1933220.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwb1437Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWB1_43_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwb1437Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618747.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618747.protein.info.v11.5.txt",
		        "node_list_path": "1618747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldicoprobacterOshimaiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicoprobacter oshimai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicoprobacterOshimaiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304880.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304880.protein.info.v11.5.txt",
		        "node_list_path": "1304880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellvibrionaceaeBacterium1162tS0a05Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrionaceae bacterium 1162T.S.0a.05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrionaceaeBacterium1162tS0a05Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1286364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1286364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1286364.clusters.proteins.v11.5.txt",
		        "sequence_path": "1286364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286364.protein.info.v11.5.txt",
		        "node_list_path": "1286364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1286364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharothrixSpNrrlb16314Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharothrix sp. NRRLB16314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharothrixSpNrrlb16314Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463825.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463825.protein.info.v11.5.txt",
		        "node_list_path": "1463825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumSphagni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium sphagni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumSphagni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1903179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903179.protein.info.v11.5.txt",
		        "node_list_path": "1903179.protein.complete.v11.5.txt"
		    }
		]
    )()

def CallorhinchusMilii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Callorhinchus milii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CallorhinchusMilii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7868.protein.sequences.v11.5.fa",
		        "enrichment_path": "7868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7868.protein.info.v11.5.txt",
		        "node_list_path": "7868.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterSpLCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. L Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSpLCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "944547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "944547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "944547.clusters.proteins.v11.5.txt",
		        "sequence_path": "944547.protein.sequences.v11.5.fa",
		        "enrichment_path": "944547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944547.protein.info.v11.5.txt",
		        "node_list_path": "944547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "944547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSolani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus solani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSolani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1637975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1637975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1637975.protein.info.v11.5.txt",
		        "node_list_path": "1637975.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumReichenbachii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium reichenbachii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumReichenbachii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "362418.protein.sequences.v11.5.fa",
		        "enrichment_path": "362418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362418.protein.info.v11.5.txt",
		        "node_list_path": "362418.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZetaproteobacteriaBacteriumCg10255237Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_55_237 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaproteobacteriaBacteriumCg10255237Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805428.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805428.protein.info.v11.5.txt",
		        "node_list_path": "1805428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsplowo201Full3913Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO2_01_FULL_39_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201Full3913Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802624.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802624.protein.info.v11.5.txt",
		        "node_list_path": "1802624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusAminovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus aminovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusAminovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34004.clusters.proteins.v11.5.txt",
		        "sequence_path": "34004.protein.sequences.v11.5.fa",
		        "enrichment_path": "34004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34004.protein.info.v11.5.txt",
		        "node_list_path": "34004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaAnsorpii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella ansorpii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaAnsorpii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "288768.protein.sequences.v11.5.fa",
		        "enrichment_path": "288768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "288768.protein.info.v11.5.txt",
		        "node_list_path": "288768.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumHlucca01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium HLUCCA01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumHlucca01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1666909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666909.protein.info.v11.5.txt",
		        "node_list_path": "1666909.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumBrasilianum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium brasilianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumBrasilianum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "104259.protein.sequences.v11.5.fa",
		        "enrichment_path": "104259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104259.protein.info.v11.5.txt",
		        "node_list_path": "104259.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpSod10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. SOD10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpSod10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1505946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1505946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1505946.clusters.proteins.v11.5.txt",
		        "sequence_path": "1505946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505946.protein.info.v11.5.txt",
		        "node_list_path": "1505946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1505946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwa2378(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_37_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa2378", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619036.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619036.protein.info.v11.5.txt",
		        "node_list_path": "1619036.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumGa0077543(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium Ga0077543 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumGa0077543", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752205.protein.info.v11.5.txt",
		        "node_list_path": "1752205.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacterium3919(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 39-19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacterium3919", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895834.protein.info.v11.5.txt",
		        "node_list_path": "1895834.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumRhodesiaeNbb3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rhodesiae NBB3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumRhodesiaeNbb3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "710685.protein.sequences.v11.5.fa",
		        "enrichment_path": "710685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710685.protein.info.v11.5.txt",
		        "node_list_path": "710685.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSophorae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sophorae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSophorae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1333845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333845.protein.info.v11.5.txt",
		        "node_list_path": "1333845.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinospirillumCelereCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinospirillum celere Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinospirillumCelereCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122252.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122252.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122252.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122252.protein.info.v11.5.txt",
		        "node_list_path": "1122252.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122252.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumMagnumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium magnum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumMagnumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1692.clusters.proteins.v11.5.txt",
		        "sequence_path": "1692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1692.protein.info.v11.5.txt",
		        "node_list_path": "1692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioflavicoccusMobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioflavicoccus mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioflavicoccusMobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765912.protein.sequences.v11.5.fa",
		        "enrichment_path": "765912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765912.protein.info.v11.5.txt",
		        "node_list_path": "765912.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaTypographiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia typographi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaTypographiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "371042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "371042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "371042.clusters.proteins.v11.5.txt",
		        "sequence_path": "371042.protein.sequences.v11.5.fa",
		        "enrichment_path": "371042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "371042.protein.info.v11.5.txt",
		        "node_list_path": "371042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "371042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpLup30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. LUP30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpLup30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1890285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1890285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1890285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1890285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1890285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1890285.protein.info.v11.5.txt",
		        "node_list_path": "1890285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1890285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TupaiaBelangeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tupaia belangeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TupaiaBelangeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37347.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37347.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37347.clusters.proteins.v11.5.txt",
		        "sequence_path": "37347.protein.sequences.v11.5.fa",
		        "enrichment_path": "37347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37347.protein.info.v11.5.txt",
		        "node_list_path": "37347.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37347.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxyb2Full487(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2_FULL_48_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2Full487", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797967.protein.info.v11.5.txt",
		        "node_list_path": "1797967.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwc14720(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWC1_47_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwc14720", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618529.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618529.protein.info.v11.5.txt",
		        "node_list_path": "1618529.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpQssc122b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. QSSC1-22B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpQssc122b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1860125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860125.protein.info.v11.5.txt",
		        "node_list_path": "1860125.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetivibrioEthanolgignens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetivibrio ethanolgignens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetivibrioEthanolgignens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290052.protein.sequences.v11.5.fa",
		        "enrichment_path": "290052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290052.protein.info.v11.5.txt",
		        "node_list_path": "290052.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasLuteoviolacea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas luteoviolacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasLuteoviolacea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43657.protein.sequences.v11.5.fa",
		        "enrichment_path": "43657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43657.protein.info.v11.5.txt",
		        "node_list_path": "43657.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoesziomycesAntarcticusT34(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moesziomyces antarcticus T-34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoesziomycesAntarcticusT34", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1151754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151754.protein.info.v11.5.txt",
		        "node_list_path": "1151754.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlycomycesSambucus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glycomyces sambucus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlycomycesSambucus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "380244.protein.sequences.v11.5.fa",
		        "enrichment_path": "380244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380244.protein.info.v11.5.txt",
		        "node_list_path": "380244.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumOxysporumFSpCubenseRace1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. cubense race 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumOxysporumFSpCubenseRace1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229664.protein.info.v11.5.txt",
		        "node_list_path": "1229664.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaBalticaOs155Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella baltica OS155 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaBalticaOs155Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "325240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "325240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "325240.clusters.proteins.v11.5.txt",
		        "sequence_path": "325240.protein.sequences.v11.5.fa",
		        "enrichment_path": "325240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "325240.protein.info.v11.5.txt",
		        "node_list_path": "325240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "325240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumRifoxyb2Full327(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYB2_FULL_32_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxyb2Full327", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801906.protein.info.v11.5.txt",
		        "node_list_path": "1801906.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHtcc5015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC5015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc5015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391615.clusters.info.v11.0.txt",
		        "cluster_tree_path": "391615.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "391615.clusters.proteins.v11.0.txt",
		        "sequence_path": "391615.protein.sequences.v11.0.fa",
		        "enrichment_path": "391615.protein.enrichment.terms.v11.0.txt",
		        "info_path": "391615.protein.info.v11.0.txt",
		        "node_list_path": "391615.cluster.nodes.v11.0.txt",
		        "edge_list_path": "391615.protein.cluster.v11.0.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag449Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:449 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag449Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263023.protein.info.v11.5.txt",
		        "node_list_path": "1263023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumColumnareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium columnare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumColumnareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041826.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041826.protein.info.v11.5.txt",
		        "node_list_path": "1041826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterNitrophenolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter nitrophenolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterNitrophenolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "683150.protein.sequences.v11.5.fa",
		        "enrichment_path": "683150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683150.protein.info.v11.5.txt",
		        "node_list_path": "683150.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1898203.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898203.protein.info.v11.5.txt",
		        "node_list_path": "1898203.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf67(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf67", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736230.protein.info.v11.5.txt",
		        "node_list_path": "1736230.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusCorynebacterioidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus corynebacterioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusCorynebacterioidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53972.clusters.proteins.v11.5.txt",
		        "sequence_path": "53972.protein.sequences.v11.5.fa",
		        "enrichment_path": "53972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53972.protein.info.v11.5.txt",
		        "node_list_path": "53972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_41_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797727.protein.info.v11.5.txt",
		        "node_list_path": "1797727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TindalliaCaliforniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tindallia californiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TindalliaCaliforniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "159292.protein.sequences.v11.5.fa",
		        "enrichment_path": "159292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "159292.protein.info.v11.5.txt",
		        "node_list_path": "159292.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusInfernus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus infernus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusInfernus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573063.protein.sequences.v11.5.fa",
		        "enrichment_path": "573063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573063.protein.info.v11.5.txt",
		        "node_list_path": "573063.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumRifcsphigho212Full5236Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPHIGHO2_12_FULL_52_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumRifcsphigho212Full5236Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801980.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801980.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801980.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801980.protein.info.v11.5.txt",
		        "node_list_path": "1801980.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801980.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaricaulisSalignorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maricaulis salignorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaricaulisSalignorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "144026.protein.sequences.v11.5.fa",
		        "enrichment_path": "144026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "144026.protein.info.v11.5.txt",
		        "node_list_path": "144026.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_35_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802055.protein.info.v11.5.txt",
		        "node_list_path": "1802055.protein.complete.v11.5.txt"
		    }
		]
    )()

def BipolarisZeicola26R13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris zeicola 26-R-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisZeicola26R13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930089.clusters.proteins.v11.5.txt",
		        "sequence_path": "930089.protein.sequences.v11.5.fa",
		        "enrichment_path": "930089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930089.protein.info.v11.5.txt",
		        "node_list_path": "930089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumFujikuroiImi58289Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium fujikuroi IMI 58289 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumFujikuroiImi58289Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1279085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1279085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1279085.clusters.proteins.v11.5.txt",
		        "sequence_path": "1279085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1279085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1279085.protein.info.v11.5.txt",
		        "node_list_path": "1279085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1279085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaMali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytoplasma mali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaMali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37692.protein.sequences.v11.5.fa",
		        "enrichment_path": "37692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37692.protein.info.v11.5.txt",
		        "node_list_path": "37692.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag768(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:768 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag768", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262838.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262838.protein.info.v11.5.txt",
		        "node_list_path": "1262838.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSiliginisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus siliginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSiliginisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "348151.clusters.info.v11.5.txt",
		        "cluster_tree_path": "348151.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "348151.clusters.proteins.v11.5.txt",
		        "sequence_path": "348151.protein.sequences.v11.5.fa",
		        "enrichment_path": "348151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "348151.protein.info.v11.5.txt",
		        "node_list_path": "348151.cluster.nodes.v11.5.txt",
		        "edge_list_path": "348151.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinoalloteichusCyanogriseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoalloteichus cyanogriseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoalloteichusCyanogriseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "65497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "65497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "65497.clusters.proteins.v11.5.txt",
		        "sequence_path": "65497.protein.sequences.v11.5.fa",
		        "enrichment_path": "65497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65497.protein.info.v11.5.txt",
		        "node_list_path": "65497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "65497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpStBin4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. ST-bin4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpStBin4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1978764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978764.protein.info.v11.5.txt",
		        "node_list_path": "1978764.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE740Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E740 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE740Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834149.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834149.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834149.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834149.protein.info.v11.5.txt",
		        "node_list_path": "1834149.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834149.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumLarrymooreiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium larrymoorei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLarrymooreiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336249.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336249.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336249.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336249.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336249.protein.info.v11.5.txt",
		        "node_list_path": "1336249.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336249.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifcsphigho202Full5216(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_02_FULL_52_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho202Full5216", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801920.protein.info.v11.5.txt",
		        "node_list_path": "1801920.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassilioclostridiumColiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilioclostridium coli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassilioclostridiumColiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1870991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1870991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1870991.clusters.proteins.v11.5.txt",
		        "sequence_path": "1870991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870991.protein.info.v11.5.txt",
		        "node_list_path": "1870991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1870991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeucobacterChromiiresistens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter chromiiresistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterChromiiresistens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1079994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1079994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1079994.protein.info.v11.5.txt",
		        "node_list_path": "1079994.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaFlabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella flabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaFlabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "463014.protein.sequences.v11.5.fa",
		        "enrichment_path": "463014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "463014.protein.info.v11.5.txt",
		        "node_list_path": "463014.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumRbg134610Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RBG_13_46_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumRbg134610Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801961.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801961.protein.info.v11.5.txt",
		        "node_list_path": "1801961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumEtliCiat652(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli CIAT652 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumEtliCiat652", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "491916.protein.sequences.v11.5.fa",
		        "enrichment_path": "491916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "491916.protein.info.v11.5.txt",
		        "node_list_path": "491916.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxyb2Full497(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2_FULL_49_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2Full497", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797968.protein.info.v11.5.txt",
		        "node_list_path": "1797968.protein.complete.v11.5.txt"
		    }
		]
    )()

def GardnerellaVaginalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GardnerellaVaginalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2702.clusters.proteins.v11.5.txt",
		        "sequence_path": "2702.protein.sequences.v11.5.fa",
		        "enrichment_path": "2702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2702.protein.info.v11.5.txt",
		        "node_list_path": "2702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChelatococcusDaeguensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chelatococcus daeguensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelatococcusDaeguensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "444444.protein.sequences.v11.5.fa",
		        "enrichment_path": "444444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444444.protein.info.v11.5.txt",
		        "node_list_path": "444444.protein.complete.v11.5.txt"
		    }
		]
    )()

def KuraishiaCapsulataCbs1993Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kuraishia capsulata CBS 1993 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KuraishiaCapsulataCbs1993Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1382522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1382522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1382522.clusters.proteins.v11.5.txt",
		        "sequence_path": "1382522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382522.protein.info.v11.5.txt",
		        "node_list_path": "1382522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1382522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteipulveratusHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteipulveratus halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteipulveratusHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1631356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1631356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1631356.protein.info.v11.5.txt",
		        "node_list_path": "1631356.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusHyovaginalisDsm12219(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus hyovaginalis DSM 12219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusHyovaginalisDsm12219", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123305.protein.info.v11.5.txt",
		        "node_list_path": "1123305.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpSjsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. SJS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpSjsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423321.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423321.protein.info.v11.5.txt",
		        "node_list_path": "1423321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesKatrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces katrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesKatrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68223.protein.sequences.v11.5.fa",
		        "enrichment_path": "68223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68223.protein.info.v11.5.txt",
		        "node_list_path": "68223.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaSuisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia suis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaSuisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1405296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1405296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1405296.clusters.proteins.v11.5.txt",
		        "sequence_path": "1405296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1405296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1405296.protein.info.v11.5.txt",
		        "node_list_path": "1405296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1405296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSubterraniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter subterrani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSubterraniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658765.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658765.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658765.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658765.protein.info.v11.5.txt",
		        "node_list_path": "1658765.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658765.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GorillibacteriumTimonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gorillibacterium timonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GorillibacteriumTimonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1689269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1689269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1689269.protein.info.v11.5.txt",
		        "node_list_path": "1689269.protein.complete.v11.5.txt"
		    }
		]
    )()

def SciscionellaSpSe31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sciscionella sp. SE31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SciscionellaSpSe31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1445613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1445613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1445613.protein.info.v11.5.txt",
		        "node_list_path": "1445613.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGwf24113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWF2_41_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGwf24113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798263.protein.info.v11.5.txt",
		        "node_list_path": "1798263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentibacillusJeotgaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentibacillusJeotgaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "558169.clusters.info.v11.5.txt",
		        "cluster_tree_path": "558169.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "558169.clusters.proteins.v11.5.txt",
		        "sequence_path": "558169.protein.sequences.v11.5.fa",
		        "enrichment_path": "558169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558169.protein.info.v11.5.txt",
		        "node_list_path": "558169.cluster.nodes.v11.5.txt",
		        "edge_list_path": "558169.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaproniaEpimycesCbs60696(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capronia epimyces CBS 606.96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaproniaEpimycesCbs60696", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1182542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182542.protein.info.v11.5.txt",
		        "node_list_path": "1182542.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriovoraxSpBal6xCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. BAL6X Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriovoraxSpBal6xCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1201290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1201290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1201290.clusters.proteins.v11.5.txt",
		        "sequence_path": "1201290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1201290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1201290.protein.info.v11.5.txt",
		        "node_list_path": "1201290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1201290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkelbacteriaBacteriumRifcsplowo201Full5028(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFCSPLOWO2_01_FULL_50_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifcsplowo201Full5028", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797471.protein.info.v11.5.txt",
		        "node_list_path": "1797471.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaVincentiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema vincentii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaVincentiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596324.clusters.proteins.v11.5.txt",
		        "sequence_path": "596324.protein.sequences.v11.5.fa",
		        "enrichment_path": "596324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596324.protein.info.v11.5.txt",
		        "node_list_path": "596324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantheraTigrisAltaicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Panthera tigris altaica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantheraTigrisAltaicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "74533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "74533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "74533.clusters.proteins.v11.5.txt",
		        "sequence_path": "74533.protein.sequences.v11.5.fa",
		        "enrichment_path": "74533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74533.protein.info.v11.5.txt",
		        "node_list_path": "74533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "74533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaRatti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella ratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaRatti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883156.protein.sequences.v11.5.fa",
		        "enrichment_path": "883156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883156.protein.info.v11.5.txt",
		        "node_list_path": "883156.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpLshc420b00Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LSHC420B00 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpLshc420b00Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1287292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1287292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1287292.clusters.proteins.v11.5.txt",
		        "sequence_path": "1287292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287292.protein.info.v11.5.txt",
		        "node_list_path": "1287292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1287292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BerkelbacteriaBacteriumGw2011Gwe13912Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011_GWE1_39_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BerkelbacteriaBacteriumGw2011Gwe13912Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618337.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618337.protein.info.v11.5.txt",
		        "node_list_path": "1618337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpCg912Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. CG912 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpCg912Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1504672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1504672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1504672.clusters.proteins.v11.5.txt",
		        "sequence_path": "1504672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504672.protein.info.v11.5.txt",
		        "node_list_path": "1504672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1504672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSpChdcCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. ChDC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSpChdcCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354300.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354300.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354300.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354300.protein.info.v11.5.txt",
		        "node_list_path": "1354300.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354300.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BalaenopteraAcutorostrataScammoni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Balaenoptera acutorostrata scammoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BalaenopteraAcutorostrataScammoni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "310752.protein.sequences.v11.5.fa",
		        "enrichment_path": "310752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "310752.protein.info.v11.5.txt",
		        "node_list_path": "310752.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwc14518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWC1_45_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwc14518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618696.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618696.protein.info.v11.5.txt",
		        "node_list_path": "1618696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusBovimastitidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus bovimastitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusBovimastitidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1856638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1856638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1856638.protein.info.v11.5.txt",
		        "node_list_path": "1856638.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrondihabitansSpPamc28766Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frondihabitans sp. PAMC 28766 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrondihabitansSpPamc28766Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1795630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1795630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1795630.clusters.proteins.v11.5.txt",
		        "sequence_path": "1795630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795630.protein.info.v11.5.txt",
		        "node_list_path": "1795630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1795630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterGangotriensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter gangotriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterGangotriensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1276920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1276920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1276920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1276920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276920.protein.info.v11.5.txt",
		        "node_list_path": "1276920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1276920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RodentibacterHeidelbergensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter heidelbergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterHeidelbergensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1908258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908258.protein.info.v11.5.txt",
		        "node_list_path": "1908258.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumVaccae95051(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium vaccae 95051 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumVaccae95051", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354275.protein.info.v11.5.txt",
		        "node_list_path": "1354275.protein.complete.v11.5.txt"
		    }
		]
    )()

def EmmonsiaSpCac2015aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Emmonsia sp. CAC-2015a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmmonsiaSpCac2015aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658172.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658172.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658172.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658172.protein.info.v11.5.txt",
		        "node_list_path": "1658172.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658172.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OphiostomaPiceae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ophiostoma piceae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiostomaPiceae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61273.protein.sequences.v11.5.fa",
		        "enrichment_path": "61273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61273.protein.info.v11.5.txt",
		        "node_list_path": "61273.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinomonasMesophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinomonas mesophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinomonasMesophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1531955.protein.sequences.v11.5.fa",
		        "enrichment_path": "1531955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1531955.protein.info.v11.5.txt",
		        "node_list_path": "1531955.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacterium1747faa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 1747FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacterium1747faa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "457421.protein.sequences.v11.5.fa",
		        "enrichment_path": "457421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457421.protein.info.v11.5.txt",
		        "node_list_path": "457421.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisXinjiangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisXinjiangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246474.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246474.protein.info.v11.5.txt",
		        "node_list_path": "1246474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KallipygaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kallipyga massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KallipygaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118059.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118059.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118059.protein.info.v11.5.txt",
		        "node_list_path": "1118059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag156Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:156 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag156Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262880.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262880.protein.info.v11.5.txt",
		        "node_list_path": "1262880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FriedmanniellaSagamiharensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Friedmanniella sagamiharensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FriedmanniellaSagamiharensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546874.clusters.proteins.v11.5.txt",
		        "sequence_path": "546874.protein.sequences.v11.5.fa",
		        "enrichment_path": "546874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546874.protein.info.v11.5.txt",
		        "node_list_path": "546874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3610bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_36_10b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3610bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801766.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801766.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801766.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801766.protein.info.v11.5.txt",
		        "node_list_path": "1801766.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801766.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryomorphaceaeBacteriumBacl7Mag120322Bin74(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL7 MAG-120322-bin74 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryomorphaceaeBacteriumBacl7Mag120322Bin74", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1655596.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655596.protein.info.v11.5.txt",
		        "node_list_path": "1655596.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusApachensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus apachensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusApachensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121377.protein.info.v11.5.txt",
		        "node_list_path": "1121377.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaInconspicuaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Candida] inconspicua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaInconspicuaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52247.clusters.proteins.v11.5.txt",
		        "sequence_path": "52247.protein.sequences.v11.5.fa",
		        "enrichment_path": "52247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52247.protein.info.v11.5.txt",
		        "node_list_path": "52247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BabesiaBigemina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Babesia bigemina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BabesiaBigemina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5866.protein.sequences.v11.5.fa",
		        "enrichment_path": "5866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5866.protein.info.v11.5.txt",
		        "node_list_path": "5866.protein.complete.v11.5.txt"
		    }
		]
    )()

def GilliamellaMensalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gilliamella mensalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilliamellaMensalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1908520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908520.protein.info.v11.5.txt",
		        "node_list_path": "1908520.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusFiliformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus filiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusFiliformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "276.clusters.proteins.v11.5.txt",
		        "sequence_path": "276.protein.sequences.v11.5.fa",
		        "enrichment_path": "276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "276.protein.info.v11.5.txt",
		        "node_list_path": "276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp4212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 42_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp4212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896983.protein.info.v11.5.txt",
		        "node_list_path": "1896983.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaOakridgensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella oakridgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaOakridgensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1268635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1268635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1268635.clusters.proteins.v11.5.txt",
		        "sequence_path": "1268635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268635.protein.info.v11.5.txt",
		        "node_list_path": "1268635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1268635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSabulinigriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sabulinigri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSabulinigriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "472181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "472181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "472181.clusters.proteins.v11.5.txt",
		        "sequence_path": "472181.protein.sequences.v11.5.fa",
		        "enrichment_path": "472181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472181.protein.info.v11.5.txt",
		        "node_list_path": "472181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "472181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumStationis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium stationis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumStationis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705.protein.info.v11.5.txt",
		        "node_list_path": "1705.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumBrhC4bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRH_c4b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumBrhC4bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629717.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629717.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629717.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629717.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629717.protein.info.v11.5.txt",
		        "node_list_path": "1629717.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629717.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AncylostomaCeylanicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ancylostoma ceylanicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AncylostomaCeylanicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53326.protein.sequences.v11.5.fa",
		        "enrichment_path": "53326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53326.protein.info.v11.5.txt",
		        "node_list_path": "53326.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaPattaloongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora pattaloongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaPattaloongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "405436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "405436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "405436.clusters.proteins.v11.5.txt",
		        "sequence_path": "405436.protein.sequences.v11.5.fa",
		        "enrichment_path": "405436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405436.protein.info.v11.5.txt",
		        "node_list_path": "405436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "405436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHtcc2150(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HTCC2150 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHtcc2150", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "388401.protein.sequences.v11.5.fa",
		        "enrichment_path": "388401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388401.protein.info.v11.5.txt",
		        "node_list_path": "388401.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaAcaciae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia acaciae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaAcaciae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123023.protein.info.v11.5.txt",
		        "node_list_path": "1123023.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaueraSp28Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. 28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraSp28Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "303682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "303682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "303682.clusters.proteins.v11.5.txt",
		        "sequence_path": "303682.protein.sequences.v11.5.fa",
		        "enrichment_path": "303682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "303682.protein.info.v11.5.txt",
		        "node_list_path": "303682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "303682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeochlamydiaSpEps4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neochlamydia sp. EPS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeochlamydiaSpEps4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1478175.protein.sequences.v11.5.fa",
		        "enrichment_path": "1478175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1478175.protein.info.v11.5.txt",
		        "node_list_path": "1478175.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyricimonasVirosaDsm23226(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyricimonas virosa DSM 23226 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyricimonasVirosaDsm23226", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121130.protein.info.v11.5.txt",
		        "node_list_path": "1121130.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAgalactiae14628(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae 14628 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAgalactiae14628", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1110504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1110504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1110504.protein.info.v11.5.txt",
		        "node_list_path": "1110504.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterJaachi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter jaachi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterJaachi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1677920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1677920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1677920.protein.info.v11.5.txt",
		        "node_list_path": "1677920.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpH073(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H073 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpH073", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1759079.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759079.protein.info.v11.5.txt",
		        "node_list_path": "1759079.protein.complete.v11.5.txt"
		    }
		]
    )()

def HoefleaSpBal378(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hoeflea sp. BAL378 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoefleaSpBal378", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1547437.protein.sequences.v11.5.fa",
		        "enrichment_path": "1547437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1547437.protein.info.v11.5.txt",
		        "node_list_path": "1547437.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa14021(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA1_40_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa14021", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618784.protein.info.v11.5.txt",
		        "node_list_path": "1618784.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterDokdonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterDokdonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1300345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1300345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1300345.clusters.proteins.v11.5.txt",
		        "sequence_path": "1300345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300345.protein.info.v11.5.txt",
		        "node_list_path": "1300345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1300345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterHelveticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter helveticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterHelveticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28898.protein.sequences.v11.5.fa",
		        "enrichment_path": "28898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28898.protein.info.v11.5.txt",
		        "node_list_path": "28898.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmoparaHalstedii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmopara halstedii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmoparaHalstedii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4781.protein.sequences.v11.5.fa",
		        "enrichment_path": "4781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4781.protein.info.v11.5.txt",
		        "node_list_path": "4781.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaTracheiphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia tracheiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaTracheiphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "65700.protein.sequences.v11.5.fa",
		        "enrichment_path": "65700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65700.protein.info.v11.5.txt",
		        "node_list_path": "65700.protein.complete.v11.5.txt"
		    }
		]
    )()

def DuganellaSpCf402Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. CF402 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpCf402Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855289.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855289.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855289.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855289.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855289.protein.info.v11.5.txt",
		        "node_list_path": "1855289.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855289.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterPsychrophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter psychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterPsychrophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "651662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "651662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "651662.clusters.proteins.v11.5.txt",
		        "sequence_path": "651662.protein.sequences.v11.5.fa",
		        "enrichment_path": "651662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "651662.protein.info.v11.5.txt",
		        "node_list_path": "651662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "651662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumParadoxumJwYl7Dsm7308(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] paradoxum JW-YL-7 DSM 7308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumParadoxumJwYl7Dsm7308", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121328.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121328.protein.info.v11.5.txt",
		        "node_list_path": "1121328.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusOrisasini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus orisasini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOrisasini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1080071.protein.sequences.v11.5.fa",
		        "enrichment_path": "1080071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1080071.protein.info.v11.5.txt",
		        "node_list_path": "1080071.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpAkyn10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. AKYN10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpAkyn10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349820.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349820.protein.info.v11.5.txt",
		        "node_list_path": "1349820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusVarani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus varani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusVarani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1608583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608583.protein.info.v11.5.txt",
		        "node_list_path": "1608583.protein.complete.v11.5.txt"
		    }
		]
    )()

def KlebsiellaPneumoniaeSubspOzaenaeNbrc105683(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. ozaenae NBRC 105683 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaPneumoniaeSubspOzaenaeNbrc105683", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218098.protein.info.v11.5.txt",
		        "node_list_path": "1218098.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloteneraVersatilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera versatilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraVersatilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "666681.protein.sequences.v11.5.fa",
		        "enrichment_path": "666681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "666681.protein.info.v11.5.txt",
		        "node_list_path": "666681.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumArgentoratenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium argentoratense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumArgentoratenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348662.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348662.protein.info.v11.5.txt",
		        "node_list_path": "1348662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_44_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797535.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797535.protein.info.v11.5.txt",
		        "node_list_path": "1797535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumCg1025621Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_56_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumCg1025621Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805132.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805132.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805132.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805132.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805132.protein.info.v11.5.txt",
		        "node_list_path": "1805132.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805132.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnothrixSpP13c2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnothrix sp. P13C2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnothrixSpP13c2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1880902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1880902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1880902.protein.info.v11.5.txt",
		        "node_list_path": "1880902.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3813Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_38_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3813Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802768.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802768.protein.info.v11.5.txt",
		        "node_list_path": "1802768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisSk569(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK569 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisSk569", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035187.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035187.protein.info.v11.5.txt",
		        "node_list_path": "1035187.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpD16q13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. D16Q13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpD16q13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855657.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855657.protein.info.v11.5.txt",
		        "node_list_path": "1855657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusLugdunensisN920143Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis N920143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusLugdunensisN920143Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1034809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1034809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1034809.clusters.proteins.v11.5.txt",
		        "sequence_path": "1034809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034809.protein.info.v11.5.txt",
		        "node_list_path": "1034809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1034809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full4412bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_44_12b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full4412bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802772.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802772.protein.info.v11.5.txt",
		        "node_list_path": "1802772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusHenryiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus henryi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusHenryiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123304.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123304.protein.info.v11.5.txt",
		        "node_list_path": "1123304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag646(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:646 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag646", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262995.protein.info.v11.5.txt",
		        "node_list_path": "1262995.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusLonarensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus lonarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLonarensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1464122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1464122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1464122.clusters.proteins.v11.5.txt",
		        "sequence_path": "1464122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1464122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1464122.protein.info.v11.5.txt",
		        "node_list_path": "1464122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1464122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSpOk283Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK283 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSpOk283Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881049.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881049.protein.info.v11.5.txt",
		        "node_list_path": "1881049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MegasphaeraGenomosp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera genomosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraGenomosp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "699218.protein.sequences.v11.5.fa",
		        "enrichment_path": "699218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "699218.protein.info.v11.5.txt",
		        "node_list_path": "699218.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSp1513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. 1513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSp1513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1883416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1883416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1883416.clusters.proteins.v11.5.txt",
		        "sequence_path": "1883416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1883416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1883416.protein.info.v11.5.txt",
		        "node_list_path": "1883416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1883416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidaminococcusIntestiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidaminococcus intestini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminococcusIntestiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "568816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "568816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "568816.clusters.proteins.v11.5.txt",
		        "sequence_path": "568816.protein.sequences.v11.5.fa",
		        "enrichment_path": "568816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568816.protein.info.v11.5.txt",
		        "node_list_path": "568816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "568816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaKandleri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella kandleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaKandleri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1616.protein.info.v11.5.txt",
		        "node_list_path": "1616.protein.complete.v11.5.txt"
		    }
		]
    )()

def DraconibacteriumSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Draconibacterium sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DraconibacteriumSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1544798.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1544798.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1544798.clusters.proteins.v11.5.txt",
		        "sequence_path": "1544798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1544798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1544798.protein.info.v11.5.txt",
		        "node_list_path": "1544798.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1544798.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SarcinaSpDsm11001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sarcina sp. DSM 11001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SarcinaSpDsm11001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798184.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798184.protein.info.v11.5.txt",
		        "node_list_path": "1798184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SebaldellaTermitidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sebaldella termitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SebaldellaTermitidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "526218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "526218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "526218.clusters.proteins.v11.5.txt",
		        "sequence_path": "526218.protein.sequences.v11.5.fa",
		        "enrichment_path": "526218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526218.protein.info.v11.5.txt",
		        "node_list_path": "526218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "526218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaAmazonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella amazonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaAmazonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326297.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326297.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326297.clusters.proteins.v11.5.txt",
		        "sequence_path": "326297.protein.sequences.v11.5.fa",
		        "enrichment_path": "326297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326297.protein.info.v11.5.txt",
		        "node_list_path": "326297.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326297.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumDaejeonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium daejeonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumDaejeonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121887.protein.info.v11.5.txt",
		        "node_list_path": "1121887.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpKpl1859Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1859 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpKpl1859Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203566.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203566.protein.info.v11.5.txt",
		        "node_list_path": "1203566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusMali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618.protein.info.v11.5.txt",
		        "node_list_path": "1618.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4534b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_01_FULL_45_34b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4534b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802320.protein.info.v11.5.txt",
		        "node_list_path": "1802320.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfitobacteriumMetallireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium metallireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitobacteriumMetallireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "871968.protein.sequences.v11.5.fa",
		        "enrichment_path": "871968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871968.protein.info.v11.5.txt",
		        "node_list_path": "871968.protein.complete.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterRhaeticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter rhaeticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterRhaeticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1432055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1432055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1432055.clusters.proteins.v11.5.txt",
		        "sequence_path": "1432055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432055.protein.info.v11.5.txt",
		        "node_list_path": "1432055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1432055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpAp12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AP12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpAp12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144305.protein.info.v11.5.txt",
		        "node_list_path": "1144305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OxalobacteraceaeBacteriumAb14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacteraceae bacterium AB_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OxalobacteraceaeBacteriumAb14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158293.protein.info.v11.5.txt",
		        "node_list_path": "1158293.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoellerellaWisconsensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moellerella wisconsensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoellerellaWisconsensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "158849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "158849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "158849.clusters.proteins.v11.5.txt",
		        "sequence_path": "158849.protein.sequences.v11.5.fa",
		        "enrichment_path": "158849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158849.protein.info.v11.5.txt",
		        "node_list_path": "158849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "158849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusFlavefaciens007c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens 007c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusFlavefaciens007c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1341157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341157.protein.info.v11.5.txt",
		        "node_list_path": "1341157.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElephantulusEdwardii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elephantulus edwardii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElephantulusEdwardii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28737.protein.sequences.v11.5.fa",
		        "enrichment_path": "28737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28737.protein.info.v11.5.txt",
		        "node_list_path": "28737.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumRhizosphaeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumRhizosphaeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1638985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1638985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1638985.clusters.proteins.v11.5.txt",
		        "sequence_path": "1638985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638985.protein.info.v11.5.txt",
		        "node_list_path": "1638985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1638985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisSk579(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisSk579", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095737.protein.info.v11.5.txt",
		        "node_list_path": "1095737.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSpS2151(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. S2151 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpS2151", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "579478.protein.sequences.v11.5.fa",
		        "enrichment_path": "579478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579478.protein.info.v11.5.txt",
		        "node_list_path": "579478.protein.complete.v11.5.txt"
		    }
		]
    )()

def LiberibacterAsiaticusGxpsy(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus gxpsy graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LiberibacterAsiaticusGxpsy", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1174529.protein.sequences.v11.5.fa",
		        "enrichment_path": "1174529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1174529.protein.info.v11.5.txt",
		        "node_list_path": "1174529.protein.complete.v11.5.txt"
		    }
		]
    )()

def HypoxylonSpCi4aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hypoxylon sp. CI-4A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HypoxylonSpCi4aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1001833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1001833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1001833.clusters.proteins.v11.5.txt",
		        "sequence_path": "1001833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001833.protein.info.v11.5.txt",
		        "node_list_path": "1001833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1001833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAnimalisSubspLactisAd011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium animalis subsp. lactis AD011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAnimalisSubspLactisAd011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "442563.clusters.info.v11.5.txt",
		        "cluster_tree_path": "442563.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "442563.clusters.proteins.v11.5.txt",
		        "sequence_path": "442563.protein.sequences.v11.5.fa",
		        "enrichment_path": "442563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "442563.protein.info.v11.5.txt",
		        "node_list_path": "442563.cluster.nodes.v11.5.txt",
		        "edge_list_path": "442563.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAzambacteriaBacteriumRifcsplowo201Full4626(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPLOWO2_01_FULL_46_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsplowo201Full4626", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797299.protein.info.v11.5.txt",
		        "node_list_path": "1797299.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521393.protein.sequences.v11.5.fa",
		        "enrichment_path": "521393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521393.protein.info.v11.5.txt",
		        "node_list_path": "521393.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSuimastitidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces suimastitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSuimastitidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120946.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120946.protein.info.v11.5.txt",
		        "node_list_path": "1120946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbidosporaCretaceaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbidospora cretacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbidosporaCretaceaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28444.clusters.proteins.v11.5.txt",
		        "sequence_path": "28444.protein.sequences.v11.5.fa",
		        "enrichment_path": "28444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28444.protein.info.v11.5.txt",
		        "node_list_path": "28444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeocallimastixCaliforniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neocallimastix californiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeocallimastixCaliforniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1754190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1754190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1754190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1754190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1754190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1754190.protein.info.v11.5.txt",
		        "node_list_path": "1754190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1754190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumNeoaurumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium neoaurum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumNeoaurumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1795.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1795.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1795.clusters.proteins.v11.5.txt",
		        "sequence_path": "1795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795.protein.info.v11.5.txt",
		        "node_list_path": "1795.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1795.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterPickeringii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter pickeringii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterPickeringii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "345632.protein.sequences.v11.5.fa",
		        "enrichment_path": "345632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "345632.protein.info.v11.5.txt",
		        "node_list_path": "345632.protein.complete.v11.5.txt"
		    }
		]
    )()

def TissierellaPraeacutaDsm18095Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tissierella praeacuta DSM 18095 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TissierellaPraeacutaDsm18095Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123404.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123404.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123404.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123404.protein.info.v11.5.txt",
		        "node_list_path": "1123404.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123404.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSilesiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas silesiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSilesiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1853130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1853130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1853130.clusters.proteins.v11.5.txt",
		        "sequence_path": "1853130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1853130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1853130.protein.info.v11.5.txt",
		        "node_list_path": "1853130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1853130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronococcusJeotgaliDsm18795Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronococcus jeotgali DSM 18795 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronococcusJeotgaliDsm18795Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227498.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227498.protein.info.v11.5.txt",
		        "node_list_path": "1227498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptococcusNigerCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptococcus niger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcusNigerCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2741.clusters.proteins.v11.5.txt",
		        "sequence_path": "2741.protein.sequences.v11.5.fa",
		        "enrichment_path": "2741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2741.protein.info.v11.5.txt",
		        "node_list_path": "2741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaritimibacterAlkaliphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maritimibacter alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaritimibacterAlkaliphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314271.protein.sequences.v11.5.fa",
		        "enrichment_path": "314271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314271.protein.info.v11.5.txt",
		        "node_list_path": "314271.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRbg163710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RBG_16_37_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRbg163710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802610.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802610.protein.info.v11.5.txt",
		        "node_list_path": "1802610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GelatoporiaSubvermisporaBCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gelatoporia subvermispora B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GelatoporiaSubvermisporaBCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "914234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "914234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "914234.clusters.proteins.v11.5.txt",
		        "sequence_path": "914234.protein.sequences.v11.5.fa",
		        "enrichment_path": "914234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "914234.protein.info.v11.5.txt",
		        "node_list_path": "914234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "914234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus pini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236976.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236976.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236976.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236976.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236976.protein.info.v11.5.txt",
		        "node_list_path": "1236976.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236976.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolirubrobacteralesBacterium6714(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solirubrobacterales bacterium 67-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolirubrobacteralesBacterium6714", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895832.protein.info.v11.5.txt",
		        "node_list_path": "1895832.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioMaritimusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio maritimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioMaritimusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "990268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "990268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "990268.clusters.proteins.v11.5.txt",
		        "sequence_path": "990268.protein.sequences.v11.5.fa",
		        "enrichment_path": "990268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990268.protein.info.v11.5.txt",
		        "node_list_path": "990268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "990268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraMayottensis200901116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira mayottensis 200901116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraMayottensis200901116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1192864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192864.protein.info.v11.5.txt",
		        "node_list_path": "1192864.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosopumilusPiranensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus piranensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopumilusPiranensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1582439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1582439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1582439.protein.info.v11.5.txt",
		        "node_list_path": "1582439.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIec1808Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IEC1808 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIec1808Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1743230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1743230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1743230.clusters.proteins.v11.5.txt",
		        "sequence_path": "1743230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743230.protein.info.v11.5.txt",
		        "node_list_path": "1743230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1743230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusFaeciumC68Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecium C68 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusFaeciumC68Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "565664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "565664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "565664.clusters.proteins.v11.5.txt",
		        "sequence_path": "565664.protein.sequences.v11.5.fa",
		        "enrichment_path": "565664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565664.protein.info.v11.5.txt",
		        "node_list_path": "565664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "565664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LupinusAngustifolius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lupinus angustifolius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LupinusAngustifolius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3871.protein.sequences.v11.5.fa",
		        "enrichment_path": "3871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3871.protein.info.v11.5.txt",
		        "node_list_path": "3871.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf24914Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_49_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf24914Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797354.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797354.protein.info.v11.5.txt",
		        "node_list_path": "1797354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpOrs3359(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3359 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpOrs3359", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "408184.protein.sequences.v11.5.fa",
		        "enrichment_path": "408184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408184.protein.info.v11.5.txt",
		        "node_list_path": "408184.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaricaulisSalignoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maricaulis salignorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaricaulisSalignoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "144026.clusters.info.v11.5.txt",
		        "cluster_tree_path": "144026.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "144026.clusters.proteins.v11.5.txt",
		        "sequence_path": "144026.protein.sequences.v11.5.fa",
		        "enrichment_path": "144026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "144026.protein.info.v11.5.txt",
		        "node_list_path": "144026.cluster.nodes.v11.5.txt",
		        "edge_list_path": "144026.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumButyricum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium butyricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumButyricum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "632245.protein.sequences.v11.5.fa",
		        "enrichment_path": "632245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632245.protein.info.v11.5.txt",
		        "node_list_path": "632245.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizoctoniaSolani123e(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizoctonia solani 123E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizoctoniaSolani123e", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423351.protein.info.v11.5.txt",
		        "node_list_path": "1423351.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquamicrobiumSpLc103(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquamicrobium sp. LC103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquamicrobiumSpLc103", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120658.protein.info.v11.5.txt",
		        "node_list_path": "1120658.protein.complete.v11.5.txt"
		    }
		]
    )()

def CajanusCajanCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cajanus cajan Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CajanusCajanCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3821.clusters.proteins.v11.5.txt",
		        "sequence_path": "3821.protein.sequences.v11.5.fa",
		        "enrichment_path": "3821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3821.protein.info.v11.5.txt",
		        "node_list_path": "3821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArabiaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arabia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArabiaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1870985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870985.protein.info.v11.5.txt",
		        "node_list_path": "1870985.protein.complete.v11.5.txt"
		    }
		]
    )()

def SneathiellaGlossodoripedisJcm23214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sneathiella glossodoripedis JCM 23214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SneathiellaGlossodoripedisJcm23214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236958.protein.info.v11.5.txt",
		        "node_list_path": "1236958.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacterium281Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 28-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacterium281Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1962177.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1962177.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1962177.clusters.proteins.v11.5.txt",
		        "sequence_path": "1962177.protein.sequences.v11.5.fa",
		        "enrichment_path": "1962177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1962177.protein.info.v11.5.txt",
		        "node_list_path": "1962177.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1962177.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureimonasSpLeaf454Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf454 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpLeaf454Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736381.protein.info.v11.5.txt",
		        "node_list_path": "1736381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumSpScn7031(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. SCN 70-31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumSpScn7031", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660129.protein.info.v11.5.txt",
		        "node_list_path": "1660129.protein.complete.v11.5.txt"
		    }
		]
    )()

def DickeyaDianthicolaNcppb3534Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dianthicola NCPPB 3534 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaDianthicolaNcppb3534Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223570.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223570.protein.info.v11.5.txt",
		        "node_list_path": "1223570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRu33a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. RU33A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRu33a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907413.protein.info.v11.5.txt",
		        "node_list_path": "1907413.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiohalospiraHalophilaDsm15071Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiohalospira halophila DSM 15071 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiohalospiraHalophilaDsm15071Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123397.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123397.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123397.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123397.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123397.protein.info.v11.5.txt",
		        "node_list_path": "1123397.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123397.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf125Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf125 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf125Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736265.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736265.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736265.protein.info.v11.5.txt",
		        "node_list_path": "1736265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumAlterfunditum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium alterfunditum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumAlterfunditum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449335.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449335.protein.info.v11.5.txt",
		        "node_list_path": "1449335.protein.complete.v11.5.txt"
		    }
		]
    )()

def LacinutrixAlgicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixAlgicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "342954.clusters.info.v11.5.txt",
		        "cluster_tree_path": "342954.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "342954.clusters.proteins.v11.5.txt",
		        "sequence_path": "342954.protein.sequences.v11.5.fa",
		        "enrichment_path": "342954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342954.protein.info.v11.5.txt",
		        "node_list_path": "342954.cluster.nodes.v11.5.txt",
		        "edge_list_path": "342954.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAlimentariusDsm20249Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus alimentarius DSM 20249 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAlimentariusDsm20249Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423720.protein.info.v11.5.txt",
		        "node_list_path": "1423720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaOulorumJcm14966Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oulorum JCM14966 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOulorumJcm14966Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236497.protein.info.v11.5.txt",
		        "node_list_path": "1236497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeglectaTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neglecta timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeglectaTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776382.protein.info.v11.5.txt",
		        "node_list_path": "1776382.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesMutabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces mutabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesMutabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67332.protein.sequences.v11.5.fa",
		        "enrichment_path": "67332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67332.protein.info.v11.5.txt",
		        "node_list_path": "67332.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterAcinonychis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter acinonychis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterAcinonychis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "382638.protein.sequences.v11.5.fa",
		        "enrichment_path": "382638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "382638.protein.info.v11.5.txt",
		        "node_list_path": "382638.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaricaulisSpJl2009(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maricaulis sp. JL2009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaricaulisSpJl2009", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1161401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1161401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1161401.protein.info.v11.5.txt",
		        "node_list_path": "1161401.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaNodosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia nodosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaNodosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121127.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121127.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121127.protein.info.v11.5.txt",
		        "node_list_path": "1121127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButtiauxellaFerragutiaeAtcc51602Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buttiauxella ferragutiae ATCC 51602 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButtiauxellaFerragutiaeAtcc51602Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354252.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354252.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354252.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354252.protein.info.v11.5.txt",
		        "node_list_path": "1354252.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354252.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpSg611lCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SG61-1L Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpSg611lCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1603897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1603897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1603897.clusters.proteins.v11.5.txt",
		        "sequence_path": "1603897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603897.protein.info.v11.5.txt",
		        "node_list_path": "1603897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1603897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyprinodonVariegatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyprinodon variegatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyprinodonVariegatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28743.clusters.proteins.v11.5.txt",
		        "sequence_path": "28743.protein.sequences.v11.5.fa",
		        "enrichment_path": "28743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28743.protein.info.v11.5.txt",
		        "node_list_path": "28743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTusciaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tusciae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTusciaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "710687.clusters.info.v11.5.txt",
		        "cluster_tree_path": "710687.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "710687.clusters.proteins.v11.5.txt",
		        "sequence_path": "710687.protein.sequences.v11.5.fa",
		        "enrichment_path": "710687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710687.protein.info.v11.5.txt",
		        "node_list_path": "710687.cluster.nodes.v11.5.txt",
		        "edge_list_path": "710687.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnserCygnoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anser cygnoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnserCygnoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8845.clusters.proteins.v11.5.txt",
		        "sequence_path": "8845.protein.sequences.v11.5.fa",
		        "enrichment_path": "8845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8845.protein.info.v11.5.txt",
		        "node_list_path": "8845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusTyphae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus typhae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusTyphae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1174501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1174501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1174501.protein.info.v11.5.txt",
		        "node_list_path": "1174501.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumGwf23869(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_38_69 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumGwf23869", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798570.protein.info.v11.5.txt",
		        "node_list_path": "1798570.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumEquinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium equinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumEquinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "134605.protein.sequences.v11.5.fa",
		        "enrichment_path": "134605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134605.protein.info.v11.5.txt",
		        "node_list_path": "134605.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThecamonasTrahens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thecamonas trahens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThecamonasTrahens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "529818.protein.sequences.v11.5.fa",
		        "enrichment_path": "529818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529818.protein.info.v11.5.txt",
		        "node_list_path": "529818.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlagellimonasEckloniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flagellimonas eckloniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlagellimonasEckloniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "346185.protein.sequences.v11.5.fa",
		        "enrichment_path": "346185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "346185.protein.info.v11.5.txt",
		        "node_list_path": "346185.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioRuminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioRuminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46206.protein.sequences.v11.5.fa",
		        "enrichment_path": "46206.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46206.protein.info.v11.5.txt",
		        "node_list_path": "46206.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumEfficiensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium efficiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumEfficiensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "196164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "196164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "196164.clusters.proteins.v11.5.txt",
		        "sequence_path": "196164.protein.sequences.v11.5.fa",
		        "enrichment_path": "196164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "196164.protein.info.v11.5.txt",
		        "node_list_path": "196164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "196164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasProtegensCha0Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas protegens CHA0 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasProtegensCha0Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1124983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1124983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1124983.clusters.proteins.v11.5.txt",
		        "sequence_path": "1124983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1124983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1124983.protein.info.v11.5.txt",
		        "node_list_path": "1124983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1124983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaucibacterSpKctc42545Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paucibacter sp. KCTC 42545 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaucibacterSpKctc42545Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1768242.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1768242.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1768242.clusters.proteins.v11.5.txt",
		        "sequence_path": "1768242.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768242.protein.info.v11.5.txt",
		        "node_list_path": "1768242.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1768242.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioProteolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio proteolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioProteolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219065.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219065.protein.info.v11.5.txt",
		        "node_list_path": "1219065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzorhizobiumDoebereineraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azorhizobium doebereinerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzorhizobiumDoebereineraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1038858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1038858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1038858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1038858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038858.protein.info.v11.5.txt",
		        "node_list_path": "1038858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1038858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchizophyllumCommune(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schizophyllum commune graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizophyllumCommune", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5334.protein.sequences.v11.5.fa",
		        "enrichment_path": "5334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5334.protein.info.v11.5.txt",
		        "node_list_path": "5334.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalococcusMorrhuaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halococcus morrhuae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusMorrhuaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "931277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "931277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "931277.clusters.proteins.v11.5.txt",
		        "sequence_path": "931277.protein.sequences.v11.5.fa",
		        "enrichment_path": "931277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "931277.protein.info.v11.5.txt",
		        "node_list_path": "931277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "931277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HoldemaniaFiliformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Holdemania filiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoldemaniaFiliformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "545696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "545696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "545696.clusters.proteins.v11.5.txt",
		        "sequence_path": "545696.protein.sequences.v11.5.fa",
		        "enrichment_path": "545696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545696.protein.info.v11.5.txt",
		        "node_list_path": "545696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "545696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SedimentisphaeraCyanobacteriorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sedimentisphaera cyanobacteriorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SedimentisphaeraCyanobacteriorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1940790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1940790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1940790.protein.info.v11.5.txt",
		        "node_list_path": "1940790.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerpentinomonasRaicheiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serpentinomonas raichei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerpentinomonasRaicheiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1458425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1458425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1458425.clusters.proteins.v11.5.txt",
		        "sequence_path": "1458425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458425.protein.info.v11.5.txt",
		        "node_list_path": "1458425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1458425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerobacillusMacyae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobacillus macyae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobacillusMacyae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "157733.protein.sequences.v11.5.fa",
		        "enrichment_path": "157733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157733.protein.info.v11.5.txt",
		        "node_list_path": "157733.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocCarnosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc carnosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocCarnosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229758.protein.info.v11.5.txt",
		        "node_list_path": "1229758.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrialbaChahannaoensisJcm10990Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialba chahannaoensis JCM 10990 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaChahannaoensisJcm10990Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227492.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227492.protein.info.v11.5.txt",
		        "node_list_path": "1227492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterSpRm6137(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM6137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSpRm6137", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660073.protein.info.v11.5.txt",
		        "node_list_path": "1660073.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_43_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618825.protein.info.v11.5.txt",
		        "node_list_path": "1618825.protein.complete.v11.5.txt"
		    }
		]
    )()

def BaudoiniaPanamericanaUamh10762(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Baudoinia panamericana UAMH 10762 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BaudoiniaPanamericanaUamh10762", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717646.protein.sequences.v11.5.fa",
		        "enrichment_path": "717646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717646.protein.info.v11.5.txt",
		        "node_list_path": "717646.protein.complete.v11.5.txt"
		    }
		]
    )()

def CroceicoccusMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Croceicoccus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CroceicoccusMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "450378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "450378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "450378.clusters.proteins.v11.5.txt",
		        "sequence_path": "450378.protein.sequences.v11.5.fa",
		        "enrichment_path": "450378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "450378.protein.info.v11.5.txt",
		        "node_list_path": "450378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "450378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifoxyc1Full3814(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFOXYC1_FULL_38_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifoxyc1Full3814", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802089.protein.info.v11.5.txt",
		        "node_list_path": "1802089.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeeuwenhoekiellaSpMar2009132(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella sp. MAR2009132 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeeuwenhoekiellaSpMar2009132", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392489.protein.info.v11.5.txt",
		        "node_list_path": "1392489.protein.complete.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterNataicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter nataicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterNataicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "265960.protein.sequences.v11.5.fa",
		        "enrichment_path": "265960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265960.protein.info.v11.5.txt",
		        "node_list_path": "265960.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriMf28Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri MF28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriMf28Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1333856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1333856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1333856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1333856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333856.protein.info.v11.5.txt",
		        "node_list_path": "1333856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1333856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteibacterSpUncmf331sha31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter sp. UNCMF331Sha3.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterSpUncmf331sha31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502760.protein.info.v11.5.txt",
		        "node_list_path": "1502760.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMspmpm5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MspMPM5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMspmpm5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1155718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1155718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1155718.clusters.proteins.v11.5.txt",
		        "sequence_path": "1155718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1155718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1155718.protein.info.v11.5.txt",
		        "node_list_path": "1155718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1155718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSeohaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter seohaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSeohaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "281376.protein.sequences.v11.5.fa",
		        "enrichment_path": "281376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "281376.protein.info.v11.5.txt",
		        "node_list_path": "281376.protein.complete.v11.5.txt"
		    }
		]
    )()

def DickeyaSpNcppb569Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya sp. NCPPB569 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaSpNcppb569Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "568768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "568768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "568768.clusters.proteins.v11.5.txt",
		        "sequence_path": "568768.protein.sequences.v11.5.fa",
		        "enrichment_path": "568768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568768.protein.info.v11.5.txt",
		        "node_list_path": "568768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "568768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpCip642(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP 64.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpCip642", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217694.protein.info.v11.5.txt",
		        "node_list_path": "1217694.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPhytoplasmaSolaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma solani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPhytoplasmaSolaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69896.clusters.proteins.v11.5.txt",
		        "sequence_path": "69896.protein.sequences.v11.5.fa",
		        "enrichment_path": "69896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69896.protein.info.v11.5.txt",
		        "node_list_path": "69896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusHydrogenalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus hydrogenalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusHydrogenalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "561177.protein.sequences.v11.5.fa",
		        "enrichment_path": "561177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561177.protein.info.v11.5.txt",
		        "node_list_path": "561177.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumScophthalmum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium scophthalmum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumScophthalmum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59733.protein.sequences.v11.5.fa",
		        "enrichment_path": "59733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59733.protein.info.v11.5.txt",
		        "node_list_path": "59733.protein.complete.v11.5.txt"
		    }
		]
    )()

def DubosiellaNewyorkensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dubosiella newyorkensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DubosiellaNewyorkensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1862672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1862672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1862672.protein.info.v11.5.txt",
		        "node_list_path": "1862672.protein.complete.v11.5.txt"
		    }
		]
    )()

def LevilineaSaccharolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Levilinea saccharolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LevilineaSaccharolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "229921.protein.sequences.v11.5.fa",
		        "enrichment_path": "229921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229921.protein.info.v11.5.txt",
		        "node_list_path": "229921.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCollinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces collinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCollinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1214242.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1214242.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1214242.clusters.proteins.v11.5.txt",
		        "sequence_path": "1214242.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214242.protein.info.v11.5.txt",
		        "node_list_path": "1214242.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1214242.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusVogelbacteriaBacteriumGwa15114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium GWA1_51_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusVogelbacteriaBacteriumGwa15114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802435.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802435.protein.info.v11.5.txt",
		        "node_list_path": "1802435.protein.complete.v11.5.txt"
		    }
		]
    )()

def EggerthellaLentaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eggerthella lenta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthellaLentaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "479437.clusters.info.v11.5.txt",
		        "cluster_tree_path": "479437.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "479437.clusters.proteins.v11.5.txt",
		        "sequence_path": "479437.protein.sequences.v11.5.fa",
		        "enrichment_path": "479437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479437.protein.info.v11.5.txt",
		        "node_list_path": "479437.cluster.nodes.v11.5.txt",
		        "edge_list_path": "479437.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3919Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_39_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3919Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802062.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802062.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802062.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802062.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802062.protein.info.v11.5.txt",
		        "node_list_path": "1802062.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802062.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobaculumGomorrense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobaculum gomorrense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobaculumGomorrense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43928.protein.sequences.v11.5.fa",
		        "enrichment_path": "43928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43928.protein.info.v11.5.txt",
		        "node_list_path": "43928.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusAlbus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusAlbus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "105425.protein.sequences.v11.5.fa",
		        "enrichment_path": "105425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105425.protein.info.v11.5.txt",
		        "node_list_path": "105425.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNctc7422Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NCTC 7422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNctc7422Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "981223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "981223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "981223.clusters.proteins.v11.5.txt",
		        "sequence_path": "981223.protein.sequences.v11.5.fa",
		        "enrichment_path": "981223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981223.protein.info.v11.5.txt",
		        "node_list_path": "981223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "981223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsphigho202Full4528Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO2_02_FULL_45_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202Full4528Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801819.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801819.protein.info.v11.5.txt",
		        "node_list_path": "1801819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedButyricicoccusSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Butyricicoccus sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedButyricicoccusSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193532.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193532.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193532.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193532.protein.info.v11.5.txt",
		        "node_list_path": "1193532.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193532.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CognatiyooniaKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cognatiyoonia koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CognatiyooniaKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "364200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "364200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "364200.clusters.proteins.v11.5.txt",
		        "sequence_path": "364200.protein.sequences.v11.5.fa",
		        "enrichment_path": "364200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "364200.protein.info.v11.5.txt",
		        "node_list_path": "364200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "364200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaloramatorAustralicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caloramator australicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloramatorAustralicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "857293.protein.sequences.v11.5.fa",
		        "enrichment_path": "857293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857293.protein.info.v11.5.txt",
		        "node_list_path": "857293.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSwingsii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium swingsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSwingsii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "498292.protein.sequences.v11.5.fa",
		        "enrichment_path": "498292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498292.protein.info.v11.5.txt",
		        "node_list_path": "498292.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterFennelliaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter fennelliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterFennelliaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1325130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1325130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1325130.clusters.proteins.v11.5.txt",
		        "sequence_path": "1325130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325130.protein.info.v11.5.txt",
		        "node_list_path": "1325130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1325130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3921Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3921Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802519.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802519.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802519.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802519.protein.info.v11.5.txt",
		        "node_list_path": "1802519.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802519.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterGerneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter gerneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterGerneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "202952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "202952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "202952.clusters.proteins.v11.5.txt",
		        "sequence_path": "202952.protein.sequences.v11.5.fa",
		        "enrichment_path": "202952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202952.protein.info.v11.5.txt",
		        "node_list_path": "202952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "202952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpibacteriumMultivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epibacterium multivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpibacteriumMultivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "928856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "928856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "928856.clusters.proteins.v11.5.txt",
		        "sequence_path": "928856.protein.sequences.v11.5.fa",
		        "enrichment_path": "928856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "928856.protein.info.v11.5.txt",
		        "node_list_path": "928856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "928856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasMelonisTy(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas melonis TY graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasMelonisTy", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "621456.protein.sequences.v11.5.fa",
		        "enrichment_path": "621456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "621456.protein.info.v11.5.txt",
		        "node_list_path": "621456.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasAeruginosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas aeruginosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAeruginosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "287.clusters.proteins.v11.5.txt",
		        "sequence_path": "287.protein.sequences.v11.5.fa",
		        "enrichment_path": "287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "287.protein.info.v11.5.txt",
		        "node_list_path": "287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterAurescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter aurescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterAurescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290340.protein.sequences.v11.5.fa",
		        "enrichment_path": "290340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290340.protein.info.v11.5.txt",
		        "node_list_path": "290340.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiabellaGinsenosidivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Niabella ginsenosidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiabellaGinsenosidivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1176587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1176587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1176587.clusters.proteins.v11.5.txt",
		        "sequence_path": "1176587.protein.sequences.v11.5.fa",
		        "enrichment_path": "1176587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1176587.protein.info.v11.5.txt",
		        "node_list_path": "1176587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1176587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FaecalibacteriumPrausnitziiSl33Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii SL33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibacteriumPrausnitziiSl33Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "657322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "657322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "657322.clusters.proteins.v11.5.txt",
		        "sequence_path": "657322.protein.sequences.v11.5.fa",
		        "enrichment_path": "657322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657322.protein.info.v11.5.txt",
		        "node_list_path": "657322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "657322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelistegaSpMc2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelistega sp. MC2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelistegaSpMc2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720297.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720297.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720297.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720297.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720297.protein.info.v11.5.txt",
		        "node_list_path": "1720297.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720297.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumArcticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium arcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumArcticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "386456.protein.sequences.v11.5.fa",
		        "enrichment_path": "386456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "386456.protein.info.v11.5.txt",
		        "node_list_path": "386456.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachyspiraSpCag700Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira sp. CAG:700 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraSpCag700Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262760.protein.info.v11.5.txt",
		        "node_list_path": "1262760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterovibrioNorvegicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioNorvegicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1190603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1190603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1190603.protein.info.v11.5.txt",
		        "node_list_path": "1190603.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusHitonicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus hitonicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusHitonicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "435880.protein.sequences.v11.5.fa",
		        "enrichment_path": "435880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435880.protein.info.v11.5.txt",
		        "node_list_path": "435880.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumJaponicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumJaponicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "375.clusters.proteins.v11.5.txt",
		        "sequence_path": "375.protein.sequences.v11.5.fa",
		        "enrichment_path": "375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375.protein.info.v11.5.txt",
		        "node_list_path": "375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGalbusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces galbus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGalbusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33898.clusters.proteins.v11.5.txt",
		        "sequence_path": "33898.protein.sequences.v11.5.fa",
		        "enrichment_path": "33898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33898.protein.info.v11.5.txt",
		        "node_list_path": "33898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaeBacteriumGa0074140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium Ga0074140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaeBacteriumGa0074140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752208.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752208.protein.info.v11.5.txt",
		        "node_list_path": "1752208.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumViolaceum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium violaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumViolaceum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243365.protein.sequences.v11.5.fa",
		        "enrichment_path": "243365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243365.protein.info.v11.5.txt",
		        "node_list_path": "243365.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterCelticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter celticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterCelticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1891224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1891224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1891224.clusters.proteins.v11.5.txt",
		        "sequence_path": "1891224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891224.protein.info.v11.5.txt",
		        "node_list_path": "1891224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1891224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaDiazotrophica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia diazotrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaDiazotrophica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "667676.protein.sequences.v11.5.fa",
		        "enrichment_path": "667676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667676.protein.info.v11.5.txt",
		        "node_list_path": "667676.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesCongonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides congonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCongonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871006.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871006.protein.info.v11.5.txt",
		        "node_list_path": "1871006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaceaeBacterium457259(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetaceae bacterium 4572_59 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaceaeBacterium457259", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1971727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971727.protein.info.v11.5.txt",
		        "node_list_path": "1971727.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisPretoriensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis pretoriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisPretoriensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "218821.protein.sequences.v11.5.fa",
		        "enrichment_path": "218821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218821.protein.info.v11.5.txt",
		        "node_list_path": "218821.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAzambacteriaBacteriumRifcsphigho202Full4518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPHIGHO2_02_FULL_45_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsphigho202Full4518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797303.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797303.protein.info.v11.5.txt",
		        "node_list_path": "1797303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsplowo201Full3654(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_36_54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3654", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798615.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798615.protein.info.v11.5.txt",
		        "node_list_path": "1798615.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodotorulaSpJg1bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula sp. JG-1b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodotorulaSpJg1bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1305733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1305733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1305733.clusters.proteins.v11.5.txt",
		        "sequence_path": "1305733.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305733.protein.info.v11.5.txt",
		        "node_list_path": "1305733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1305733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SodalisGlossinidiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sodalis glossinidius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SodalisGlossinidiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "343509.clusters.info.v11.5.txt",
		        "cluster_tree_path": "343509.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "343509.clusters.proteins.v11.5.txt",
		        "sequence_path": "343509.protein.sequences.v11.5.fa",
		        "enrichment_path": "343509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "343509.protein.info.v11.5.txt",
		        "node_list_path": "343509.cluster.nodes.v11.5.txt",
		        "edge_list_path": "343509.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsplowo202Full4812Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_02_FULL_48_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo202Full4812Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802407.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802407.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802407.protein.info.v11.5.txt",
		        "node_list_path": "1802407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasSpLm091(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas sp. LM091 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasSpLm091", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1904944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904944.protein.info.v11.5.txt",
		        "node_list_path": "1904944.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermofilumAdornatus1505(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum adornatus 1505 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermofilumAdornatus1505", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "697581.protein.sequences.v11.5.fa",
		        "enrichment_path": "697581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "697581.protein.info.v11.5.txt",
		        "node_list_path": "697581.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaNodosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia nodosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaNodosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "392320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "392320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "392320.clusters.proteins.v11.5.txt",
		        "sequence_path": "392320.protein.sequences.v11.5.fa",
		        "enrichment_path": "392320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392320.protein.info.v11.5.txt",
		        "node_list_path": "392320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "392320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliihoefleaSp2wwCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliihoeflea sp. 2WW Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliihoefleaSp2wwCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1381123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1381123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1381123.clusters.proteins.v11.5.txt",
		        "sequence_path": "1381123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381123.protein.info.v11.5.txt",
		        "node_list_path": "1381123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1381123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DentipellisFragilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dentipellis fragilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DentipellisFragilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "205917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "205917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "205917.clusters.proteins.v11.5.txt",
		        "sequence_path": "205917.protein.sequences.v11.5.fa",
		        "enrichment_path": "205917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "205917.protein.info.v11.5.txt",
		        "node_list_path": "205917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "205917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KangiellaKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kangiella koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KangiellaKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "523791.protein.sequences.v11.5.fa",
		        "enrichment_path": "523791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523791.protein.info.v11.5.txt",
		        "node_list_path": "523791.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrospiraNitrosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira nitrosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrospiraNitrosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1742972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1742972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1742972.clusters.proteins.v11.5.txt",
		        "sequence_path": "1742972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742972.protein.info.v11.5.txt",
		        "node_list_path": "1742972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1742972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EremotheciumCymbalariaeDbvpg7215Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium cymbalariae DBVPG#7215 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremotheciumCymbalariaeDbvpg7215Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "931890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "931890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "931890.clusters.proteins.v11.5.txt",
		        "sequence_path": "931890.protein.sequences.v11.5.fa",
		        "enrichment_path": "931890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "931890.protein.info.v11.5.txt",
		        "node_list_path": "931890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "931890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpPao19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. PAO19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpPao19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1096756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1096756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1096756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1096756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1096756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1096756.protein.info.v11.5.txt",
		        "node_list_path": "1096756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1096756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterLuteusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterLuteusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1581420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1581420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1581420.clusters.proteins.v11.5.txt",
		        "sequence_path": "1581420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581420.protein.info.v11.5.txt",
		        "node_list_path": "1581420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1581420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicavibrioAeruginosavorusEpb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micavibrio aeruginosavorus EPB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicavibrioAeruginosavorusEpb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349215.protein.sequences.v11.5.fa",
		        "enrichment_path": "349215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349215.protein.info.v11.5.txt",
		        "node_list_path": "349215.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmodiumVinckeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium vinckei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumVinckeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5860.clusters.proteins.v11.5.txt",
		        "sequence_path": "5860.protein.sequences.v11.5.fa",
		        "enrichment_path": "5860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5860.protein.info.v11.5.txt",
		        "node_list_path": "5860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumOrbiculareMaff240422Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum orbiculare MAFF 240422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumOrbiculareMaff240422Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1213857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1213857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1213857.clusters.proteins.v11.5.txt",
		        "sequence_path": "1213857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1213857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1213857.protein.info.v11.5.txt",
		        "node_list_path": "1213857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1213857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaAtypica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella atypica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaAtypica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39777.protein.sequences.v11.5.fa",
		        "enrichment_path": "39777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39777.protein.info.v11.5.txt",
		        "node_list_path": "39777.protein.complete.v11.5.txt"
		    }
		]
    )()

def DanausPlexippusPlexippusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Danaus plexippus plexippus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DanausPlexippusPlexippusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "278856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "278856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "278856.clusters.proteins.v11.5.txt",
		        "sequence_path": "278856.protein.sequences.v11.5.fa",
		        "enrichment_path": "278856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278856.protein.info.v11.5.txt",
		        "node_list_path": "278856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "278856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VenturiaEffusaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Venturia effusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VenturiaEffusaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "50376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "50376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "50376.clusters.proteins.v11.5.txt",
		        "sequence_path": "50376.protein.sequences.v11.5.fa",
		        "enrichment_path": "50376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50376.protein.info.v11.5.txt",
		        "node_list_path": "50376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "50376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpRoot1310(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root1310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpRoot1310", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736452.protein.info.v11.5.txt",
		        "node_list_path": "1736452.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScardoviaInopinataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scardovia inopinata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScardoviaInopinataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641146.clusters.proteins.v11.5.txt",
		        "sequence_path": "641146.protein.sequences.v11.5.fa",
		        "enrichment_path": "641146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641146.protein.info.v11.5.txt",
		        "node_list_path": "641146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioLongus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio longus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioLongus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121456.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121456.protein.info.v11.5.txt",
		        "node_list_path": "1121456.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaSubspIndicaSerovar61425Z10127Str1121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. indica serovar 6,14,25:z10:1,(2),7 str. 1121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaSubspIndicaSerovar61425Z10127Str1121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173950.protein.info.v11.5.txt",
		        "node_list_path": "1173950.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterUpsaliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter upsaliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterUpsaliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "306264.protein.sequences.v11.5.fa",
		        "enrichment_path": "306264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306264.protein.info.v11.5.txt",
		        "node_list_path": "306264.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusRugosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus rugosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusRugosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "981369.protein.sequences.v11.5.fa",
		        "enrichment_path": "981369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981369.protein.info.v11.5.txt",
		        "node_list_path": "981369.protein.complete.v11.5.txt"
		    }
		]
    )()

def CommensalibacterSpMx01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Commensalibacter sp. MX01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CommensalibacterSpMx01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208583.protein.info.v11.5.txt",
		        "node_list_path": "1208583.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaSpAr153(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. AR 15-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpAr153", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "545617.protein.sequences.v11.5.fa",
		        "enrichment_path": "545617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545617.protein.info.v11.5.txt",
		        "node_list_path": "545617.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19034(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19034", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1481928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1481928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1481928.protein.info.v11.5.txt",
		        "node_list_path": "1481928.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobacteralesBacteriumGwb25626(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium GWB2_56_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteralesBacteriumGwb25626", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797913.protein.info.v11.5.txt",
		        "node_list_path": "1797913.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumRutilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium rutilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumRutilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "370526.protein.sequences.v11.5.fa",
		        "enrichment_path": "370526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "370526.protein.info.v11.5.txt",
		        "node_list_path": "370526.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpTb64(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. TB64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpTb64", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1938600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938600.protein.info.v11.5.txt",
		        "node_list_path": "1938600.protein.complete.v11.5.txt"
		    }
		]
    )()

def QuasibacillusThermotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Quasibacillus thermotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "QuasibacillusThermotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1221996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1221996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1221996.protein.info.v11.5.txt",
		        "node_list_path": "1221996.protein.complete.v11.5.txt"
		    }
		]
    )()

def NisaeaDenitrificansDsm18348Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nisaea denitrificans DSM 18348 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NisaeaDenitrificansDsm18348Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122607.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122607.protein.info.v11.5.txt",
		        "node_list_path": "1122607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichinellaMurrelli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichinella murrelli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaMurrelli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "144512.protein.sequences.v11.5.fa",
		        "enrichment_path": "144512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "144512.protein.info.v11.5.txt",
		        "node_list_path": "144512.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioplocaIngricaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioploca ingrica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioplocaIngricaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40754.clusters.proteins.v11.5.txt",
		        "sequence_path": "40754.protein.sequences.v11.5.fa",
		        "enrichment_path": "40754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40754.protein.info.v11.5.txt",
		        "node_list_path": "40754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteibacterSpUncmf366tsu51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter sp. UNCMF366Tsu5.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterSpUncmf366tsu51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502758.protein.info.v11.5.txt",
		        "node_list_path": "1502758.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPolymyxaSc2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa SC2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPolymyxaSc2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "886882.protein.sequences.v11.5.fa",
		        "enrichment_path": "886882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "886882.protein.info.v11.5.txt",
		        "node_list_path": "886882.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumWenxiniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium wenxiniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumWenxiniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "683125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "683125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "683125.clusters.proteins.v11.5.txt",
		        "sequence_path": "683125.protein.sequences.v11.5.fa",
		        "enrichment_path": "683125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683125.protein.info.v11.5.txt",
		        "node_list_path": "683125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "683125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NaumovozymaDairenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma dairenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NaumovozymaDairenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "27289.protein.sequences.v11.5.fa",
		        "enrichment_path": "27289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27289.protein.info.v11.5.txt",
		        "node_list_path": "27289.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasGardneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas gardneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasGardneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "90270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "90270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "90270.clusters.proteins.v11.5.txt",
		        "sequence_path": "90270.protein.sequences.v11.5.fa",
		        "enrichment_path": "90270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90270.protein.info.v11.5.txt",
		        "node_list_path": "90270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "90270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRbg16408(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RBG_16_40_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRbg16408", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797388.protein.info.v11.5.txt",
		        "node_list_path": "1797388.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaMallei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia mallei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaMallei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243160.protein.sequences.v11.5.fa",
		        "enrichment_path": "243160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243160.protein.info.v11.5.txt",
		        "node_list_path": "243160.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaSp6palisep08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. 6PALISEP08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaSp6palisep08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1225660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225660.protein.info.v11.5.txt",
		        "node_list_path": "1225660.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParvularculaBermudensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parvularcula bermudensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvularculaBermudensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314260.protein.sequences.v11.5.fa",
		        "enrichment_path": "314260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314260.protein.info.v11.5.txt",
		        "node_list_path": "314260.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusCeti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCeti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122146.protein.info.v11.5.txt",
		        "node_list_path": "1122146.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpMit0801Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0801 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpMit0801Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1501269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1501269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1501269.clusters.proteins.v11.5.txt",
		        "sequence_path": "1501269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1501269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1501269.protein.info.v11.5.txt",
		        "node_list_path": "1501269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1501269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumKoreenseCcug49689(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium koreense CCUG 49689 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumKoreenseCcug49689", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304281.protein.info.v11.5.txt",
		        "node_list_path": "1304281.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeiothermusRufusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus rufus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusRufusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "604331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "604331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "604331.clusters.proteins.v11.5.txt",
		        "sequence_path": "604331.protein.sequences.v11.5.fa",
		        "enrichment_path": "604331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "604331.protein.info.v11.5.txt",
		        "node_list_path": "604331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "604331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaAsymbioticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia asymbiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaAsymbioticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834516.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834516.protein.info.v11.5.txt",
		        "node_list_path": "1834516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpCch5A5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. CCH5-A5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpCch5A5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1768741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1768741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1768741.clusters.proteins.v11.5.txt",
		        "sequence_path": "1768741.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768741.protein.info.v11.5.txt",
		        "node_list_path": "1768741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1768741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpRoot901(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root901 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpRoot901", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736605.protein.info.v11.5.txt",
		        "node_list_path": "1736605.protein.complete.v11.5.txt"
		    }
		]
    )()

def EzakiellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ezakiella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EzakiellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852374.protein.info.v11.5.txt",
		        "node_list_path": "1852374.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlexistipesSinusarabici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flexistipes sinusarabici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlexistipesSinusarabici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717231.protein.sequences.v11.5.fa",
		        "enrichment_path": "717231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717231.protein.info.v11.5.txt",
		        "node_list_path": "717231.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwh6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWH6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwh6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896212.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896212.protein.info.v11.5.txt",
		        "node_list_path": "1896212.protein.complete.v11.5.txt"
		    }
		]
    )()

def PasteurellaceaeBacterium15036681Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurellaceae bacterium 15-036681 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaceaeBacterium15036681Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1924934.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1924934.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1924934.clusters.proteins.v11.5.txt",
		        "sequence_path": "1924934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1924934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1924934.protein.info.v11.5.txt",
		        "node_list_path": "1924934.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1924934.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RodentibacterHeyliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter heylii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterHeyliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906744.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906744.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906744.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906744.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906744.protein.info.v11.5.txt",
		        "node_list_path": "1906744.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906744.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterHepaticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter hepaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterHepaticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1813019.protein.sequences.v11.5.fa",
		        "enrichment_path": "1813019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1813019.protein.info.v11.5.txt",
		        "node_list_path": "1813019.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaWestfalica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia westfalica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaWestfalica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "158898.protein.sequences.v11.5.fa",
		        "enrichment_path": "158898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158898.protein.info.v11.5.txt",
		        "node_list_path": "158898.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytophthoraCactorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora cactorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraCactorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29920.protein.sequences.v11.5.fa",
		        "enrichment_path": "29920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29920.protein.info.v11.5.txt",
		        "node_list_path": "29920.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeyerozymaGuilliermondiiAtcc6260(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meyerozyma guilliermondii ATCC 6260 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeyerozymaGuilliermondiiAtcc6260", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "294746.protein.sequences.v11.5.fa",
		        "enrichment_path": "294746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294746.protein.info.v11.5.txt",
		        "node_list_path": "294746.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumDigitatumPhi26(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium digitatum PHI26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumDigitatumPhi26", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1170229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1170229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1170229.protein.info.v11.5.txt",
		        "node_list_path": "1170229.protein.complete.v11.5.txt"
		    }
		]
    )()

def LutibacterMaritimus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lutibacter maritimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutibacterMaritimus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "593133.protein.sequences.v11.5.fa",
		        "enrichment_path": "593133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "593133.protein.info.v11.5.txt",
		        "node_list_path": "593133.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusIngluviei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ingluviei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusIngluviei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203076.protein.info.v11.5.txt",
		        "node_list_path": "1203076.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusTyphaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus typhae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusTyphaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1174501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1174501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1174501.clusters.proteins.v11.5.txt",
		        "sequence_path": "1174501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1174501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1174501.protein.info.v11.5.txt",
		        "node_list_path": "1174501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1174501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasHaloplanktisTac125(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis TAC125 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasHaloplanktisTac125", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326442.protein.sequences.v11.5.fa",
		        "enrichment_path": "326442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326442.protein.info.v11.5.txt",
		        "node_list_path": "326442.protein.complete.v11.5.txt"
		    }
		]
    )()

def LabrenziaSuaedae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Labrenzia suaedae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrenziaSuaedae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "735517.protein.sequences.v11.5.fa",
		        "enrichment_path": "735517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "735517.protein.info.v11.5.txt",
		        "node_list_path": "735517.protein.complete.v11.5.txt"
		    }
		]
    )()

def YooniaVestfoldensisDsm16212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yoonia vestfoldensis DSM 16212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YooniaVestfoldensisDsm16212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122181.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122181.protein.info.v11.5.txt",
		        "node_list_path": "1122181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaSpYl58Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia sp. YL58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaSpYl58Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1796616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1796616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1796616.clusters.proteins.v11.5.txt",
		        "sequence_path": "1796616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796616.protein.info.v11.5.txt",
		        "node_list_path": "1796616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1796616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EmticiciaOligotrophica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Emticicia oligotrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmticiciaOligotrophica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "929562.protein.sequences.v11.5.fa",
		        "enrichment_path": "929562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929562.protein.info.v11.5.txt",
		        "node_list_path": "929562.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumGenavense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium genavense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumGenavense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408452.protein.info.v11.5.txt",
		        "node_list_path": "1408452.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAltiarchaealesArchaeonImc4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Altiarchaeales archaeon IMC4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAltiarchaealesArchaeonImc4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1878999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1878999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1878999.protein.info.v11.5.txt",
		        "node_list_path": "1878999.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioEzurae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ezurae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioEzurae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219080.protein.info.v11.5.txt",
		        "node_list_path": "1219080.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrigoribacteriumSpLeaf164(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf164 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrigoribacteriumSpLeaf164", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736282.protein.info.v11.5.txt",
		        "node_list_path": "1736282.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasHaloplanktisAtcc14393Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis ATCC14393 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasHaloplanktisAtcc14393Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1117315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1117315.clusters.proteins.v11.5.txt",
		        "sequence_path": "1117315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117315.protein.info.v11.5.txt",
		        "node_list_path": "1117315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1117315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusOrnithinivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus ornithinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusOrnithinivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "226506.clusters.info.v11.5.txt",
		        "cluster_tree_path": "226506.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "226506.clusters.proteins.v11.5.txt",
		        "sequence_path": "226506.protein.sequences.v11.5.fa",
		        "enrichment_path": "226506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226506.protein.info.v11.5.txt",
		        "node_list_path": "226506.cluster.nodes.v11.5.txt",
		        "edge_list_path": "226506.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SuricataSuricattaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Suricata suricatta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuricataSuricattaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37032.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37032.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37032.clusters.proteins.v11.5.txt",
		        "sequence_path": "37032.protein.sequences.v11.5.fa",
		        "enrichment_path": "37032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37032.protein.info.v11.5.txt",
		        "node_list_path": "37032.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37032.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicaulisAlexandrii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicaulis alexandrii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicaulisAlexandrii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122613.protein.info.v11.5.txt",
		        "node_list_path": "1122613.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonajaTextilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonaja textilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonajaTextilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8673.protein.sequences.v11.5.fa",
		        "enrichment_path": "8673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8673.protein.info.v11.5.txt",
		        "node_list_path": "8673.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpUnc402clcol(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. UNC402CLCol graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpUnc402clcol", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1510531.protein.sequences.v11.5.fa",
		        "enrichment_path": "1510531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1510531.protein.info.v11.5.txt",
		        "node_list_path": "1510531.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeropyrumPernix(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeropyrum pernix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeropyrumPernix", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272557.protein.sequences.v11.5.fa",
		        "enrichment_path": "272557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272557.protein.info.v11.5.txt",
		        "node_list_path": "272557.protein.complete.v11.5.txt"
		    }
		]
    )()

def KazachstaniaNaganishiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania naganishii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KazachstaniaNaganishiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "588726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "588726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "588726.clusters.proteins.v11.5.txt",
		        "sequence_path": "588726.protein.sequences.v11.5.fa",
		        "enrichment_path": "588726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588726.protein.info.v11.5.txt",
		        "node_list_path": "588726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "588726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf125(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf125 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf125", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736265.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736265.protein.info.v11.5.txt",
		        "node_list_path": "1736265.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4311b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_43_11b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4311b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798392.protein.info.v11.5.txt",
		        "node_list_path": "1798392.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsplowo202Full3811(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO2_02_FULL_38_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo202Full3811", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798293.protein.info.v11.5.txt",
		        "node_list_path": "1798293.protein.complete.v11.5.txt"
		    }
		]
    )()

def TalaromycesMarneffeiAtcc18224Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces marneffei ATCC 18224 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesMarneffeiAtcc18224Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "441960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "441960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "441960.clusters.proteins.v11.5.txt",
		        "sequence_path": "441960.protein.sequences.v11.5.fa",
		        "enrichment_path": "441960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441960.protein.info.v11.5.txt",
		        "node_list_path": "441960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "441960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumPhosphoreum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium phosphoreum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumPhosphoreum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1454202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454202.protein.info.v11.5.txt",
		        "node_list_path": "1454202.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCyaneogriseusSubspNoncyanogenusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces cyaneogriseus subsp. noncyanogenus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCyaneogriseusSubspNoncyanogenusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "477245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "477245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "477245.clusters.proteins.v11.5.txt",
		        "sequence_path": "477245.protein.sequences.v11.5.fa",
		        "enrichment_path": "477245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477245.protein.info.v11.5.txt",
		        "node_list_path": "477245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "477245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusLitoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLitoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "152268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "152268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "152268.clusters.proteins.v11.5.txt",
		        "sequence_path": "152268.protein.sequences.v11.5.fa",
		        "enrichment_path": "152268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "152268.protein.info.v11.5.txt",
		        "node_list_path": "152268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "152268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FilimonasLacunaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Filimonas lacunae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FilimonasLacunaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "477680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "477680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "477680.clusters.proteins.v11.5.txt",
		        "sequence_path": "477680.protein.sequences.v11.5.fa",
		        "enrichment_path": "477680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477680.protein.info.v11.5.txt",
		        "node_list_path": "477680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "477680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GaeumannomycesGraminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gaeumannomyces graminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GaeumannomycesGraminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29850.protein.sequences.v11.5.fa",
		        "enrichment_path": "29850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29850.protein.info.v11.5.txt",
		        "node_list_path": "29850.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonasBadiaDsm17552Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas badia DSM 17552 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasBadiaDsm17552Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121348.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121348.protein.info.v11.5.txt",
		        "node_list_path": "1121348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterorhabdusMucosicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterorhabdus mucosicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterorhabdusMucosicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121866.protein.info.v11.5.txt",
		        "node_list_path": "1121866.protein.complete.v11.5.txt"
		    }
		]
    )()

def DiploscapterPachys(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Diploscapter pachys graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiploscapterPachys", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2018661.protein.sequences.v11.5.fa",
		        "enrichment_path": "2018661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2018661.protein.info.v11.5.txt",
		        "node_list_path": "2018661.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonosporascusSpGib2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. GIB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSpGib2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2211647.protein.sequences.v11.5.fa",
		        "enrichment_path": "2211647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2211647.protein.info.v11.5.txt",
		        "node_list_path": "2211647.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusPantherisDsm15945Jcm12539Nbrc106106(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pantheris DSM 15945 JCM 12539 NBRC 106106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPantherisDsm15945Jcm12539Nbrc106106", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423783.protein.info.v11.5.txt",
		        "node_list_path": "1423783.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetranychusUrticae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetranychus urticae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetranychusUrticae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32264.protein.sequences.v11.5.fa",
		        "enrichment_path": "32264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32264.protein.info.v11.5.txt",
		        "node_list_path": "32264.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSphaericus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sphaericus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSphaericus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1421.protein.info.v11.5.txt",
		        "node_list_path": "1421.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActibacteriumAtlanticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actibacterium atlanticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActibacteriumAtlanticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461693.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461693.protein.info.v11.5.txt",
		        "node_list_path": "1461693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquimarinaMacrocephali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina macrocephali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaMacrocephali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1443665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443665.protein.info.v11.5.txt",
		        "node_list_path": "1443665.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloceanibacterSuperfactusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloceanibacter superfactus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloceanibacterSuperfactusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1774969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1774969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1774969.clusters.proteins.v11.5.txt",
		        "sequence_path": "1774969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1774969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1774969.protein.info.v11.5.txt",
		        "node_list_path": "1774969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1774969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5126Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5126Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463857.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463857.protein.info.v11.5.txt",
		        "node_list_path": "1463857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpHzmCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. HZM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpHzmCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1454010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1454010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1454010.clusters.proteins.v11.5.txt",
		        "sequence_path": "1454010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454010.protein.info.v11.5.txt",
		        "node_list_path": "1454010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1454010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesBarnesiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides barnesiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesBarnesiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121094.protein.info.v11.5.txt",
		        "node_list_path": "1121094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaLacunataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella lacunata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaLacunataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "477.clusters.proteins.v11.5.txt",
		        "sequence_path": "477.protein.sequences.v11.5.fa",
		        "enrichment_path": "477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477.protein.info.v11.5.txt",
		        "node_list_path": "477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusTaiwanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusTaiwanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "977880.protein.sequences.v11.5.fa",
		        "enrichment_path": "977880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "977880.protein.info.v11.5.txt",
		        "node_list_path": "977880.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryomorphaceaeBacteriumBacl21Mag121220Bin10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL21 MAG-121220-bin10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryomorphaceaeBacteriumBacl21Mag121220Bin10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1655592.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655592.protein.info.v11.5.txt",
		        "node_list_path": "1655592.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophilusSpTwe2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. TWE2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusSpTwe2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1662285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1662285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1662285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1662285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662285.protein.info.v11.5.txt",
		        "node_list_path": "1662285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1662285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobacterStenotrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacter stenotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobacterStenotrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266809.clusters.proteins.v11.5.txt",
		        "sequence_path": "266809.protein.sequences.v11.5.fa",
		        "enrichment_path": "266809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266809.protein.info.v11.5.txt",
		        "node_list_path": "266809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpNxc14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. NXC14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpNxc14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1981173.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1981173.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1981173.clusters.proteins.v11.5.txt",
		        "sequence_path": "1981173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1981173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1981173.protein.info.v11.5.txt",
		        "node_list_path": "1981173.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1981173.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaBenthicaKt99Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella benthica KT99 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaBenthicaKt99Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314608.clusters.proteins.v11.5.txt",
		        "sequence_path": "314608.protein.sequences.v11.5.fa",
		        "enrichment_path": "314608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314608.protein.info.v11.5.txt",
		        "node_list_path": "314608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaKururiensisM130(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia kururiensis M130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaKururiensisM130", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1268285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268285.protein.info.v11.5.txt",
		        "node_list_path": "1268285.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusMontanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus montanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusMontanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1830138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1830138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1830138.protein.info.v11.5.txt",
		        "node_list_path": "1830138.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifcsplowo212Full5515Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_12_FULL_55_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo212Full5515Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801931.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801931.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801931.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801931.protein.info.v11.5.txt",
		        "node_list_path": "1801931.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801931.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirosomaSp4814Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma sp. 48-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaSp4814Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895854.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895854.protein.info.v11.5.txt",
		        "node_list_path": "1895854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfuromonadalesBacteriumGwc26120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromonadales bacterium GWC2_61_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromonadalesBacteriumGwc26120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797916.protein.info.v11.5.txt",
		        "node_list_path": "1797916.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumAo1BCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium AO1-B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumAo1BCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1905358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1905358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1905358.clusters.proteins.v11.5.txt",
		        "sequence_path": "1905358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1905358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1905358.protein.info.v11.5.txt",
		        "node_list_path": "1905358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1905358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinifilumFragileJcm15579Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinifilum fragile JCM 15579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinifilumFragileJcm15579Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236979.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236979.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236979.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236979.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236979.protein.info.v11.5.txt",
		        "node_list_path": "1236979.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236979.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumBalustinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium balustinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumBalustinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246.protein.sequences.v11.5.fa",
		        "enrichment_path": "246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246.protein.info.v11.5.txt",
		        "node_list_path": "246.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydraVulgaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydra vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydraVulgaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6087.protein.sequences.v11.5.fa",
		        "enrichment_path": "6087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6087.protein.info.v11.5.txt",
		        "node_list_path": "6087.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusFonticola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus fonticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusFonticola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122918.protein.info.v11.5.txt",
		        "node_list_path": "1122918.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeeuwenhoekiellaSpHeli48(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella sp. HelI48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeeuwenhoekiellaSpHeli48", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392488.protein.info.v11.5.txt",
		        "node_list_path": "1392488.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodoferaxSaidenbachensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodoferax saidenbachensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodoferaxSaidenbachensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1484693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1484693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1484693.clusters.proteins.v11.5.txt",
		        "sequence_path": "1484693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484693.protein.info.v11.5.txt",
		        "node_list_path": "1484693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1484693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBolteae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium bolteae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBolteae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411902.protein.sequences.v11.5.fa",
		        "enrichment_path": "411902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411902.protein.info.v11.5.txt",
		        "node_list_path": "411902.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaceaeSpMortierella(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Burkholderiaceae sp. Mortierella graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaceaeSpMortierella", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1562701.protein.sequences.v11.0.fa",
		        "enrichment_path": "1562701.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1562701.protein.info.v11.0.txt",
		        "node_list_path": "1562701.protein.complete.v11.0.txt"
		    }
		]
    )()

def TumebacillusFlagellatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tumebacillus flagellatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TumebacillusFlagellatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157490.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157490.protein.info.v11.5.txt",
		        "node_list_path": "1157490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrenarchaeotaArchaeon13140cm35210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_52_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenarchaeotaArchaeon13140cm35210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805095.protein.info.v11.5.txt",
		        "node_list_path": "1805095.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterAquivivus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter aquivivus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterAquivivus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "228958.protein.sequences.v11.5.fa",
		        "enrichment_path": "228958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228958.protein.info.v11.5.txt",
		        "node_list_path": "228958.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSanguinisSk36(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSanguinisSk36", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "388919.protein.sequences.v11.5.fa",
		        "enrichment_path": "388919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388919.protein.info.v11.5.txt",
		        "node_list_path": "388919.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumEpidermidicanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium epidermidicanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumEpidermidicanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1050174.protein.sequences.v11.5.fa",
		        "enrichment_path": "1050174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1050174.protein.info.v11.5.txt",
		        "node_list_path": "1050174.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumReuteriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium reuteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumReuteriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437610.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437610.protein.info.v11.5.txt",
		        "node_list_path": "1437610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StagonosporaSpSrc1lsm3aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stagonospora sp. SRC1lsM3a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StagonosporaSpSrc1lsm3aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765868.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765868.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765868.clusters.proteins.v11.5.txt",
		        "sequence_path": "765868.protein.sequences.v11.5.fa",
		        "enrichment_path": "765868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765868.protein.info.v11.5.txt",
		        "node_list_path": "765868.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765868.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumGlycinesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium glycines Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumGlycinesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "551990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "551990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "551990.clusters.proteins.v11.5.txt",
		        "sequence_path": "551990.protein.sequences.v11.5.fa",
		        "enrichment_path": "551990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551990.protein.info.v11.5.txt",
		        "node_list_path": "551990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "551990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FerriphaselusAmnicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferriphaselus amnicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerriphaselusAmnicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1188319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188319.protein.info.v11.5.txt",
		        "node_list_path": "1188319.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSpWkb10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sp. wkB10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSpWkb10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1545701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545701.protein.info.v11.5.txt",
		        "node_list_path": "1545701.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpDw54Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. DW54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpDw54Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1178540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1178540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1178540.clusters.proteins.v11.5.txt",
		        "sequence_path": "1178540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1178540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1178540.protein.info.v11.5.txt",
		        "node_list_path": "1178540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1178540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIs1742Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1742 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIs1742Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1772285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1772285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1772285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1772285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772285.protein.info.v11.5.txt",
		        "node_list_path": "1772285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1772285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaPseudomalleiK96243(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei K96243 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaPseudomalleiK96243", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272560.protein.sequences.v11.5.fa",
		        "enrichment_path": "272560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272560.protein.info.v11.5.txt",
		        "node_list_path": "272560.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium6579Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 65-79 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium6579Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895815.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895815.protein.info.v11.5.txt",
		        "node_list_path": "1895815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSpRim28(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSpRim28", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1100720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1100720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1100720.protein.info.v11.5.txt",
		        "node_list_path": "1100720.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermanaerovibrioVelox(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermanaerovibrio velox graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermanaerovibrioVelox", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926567.protein.sequences.v11.5.fa",
		        "enrichment_path": "926567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926567.protein.info.v11.5.txt",
		        "node_list_path": "926567.protein.complete.v11.5.txt"
		    }
		]
    )()

def IdiomarinaSediminumDsm21906(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sediminum DSM 21906 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaSediminumDsm21906", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122124.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122124.protein.info.v11.5.txt",
		        "node_list_path": "1122124.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetaCellobiosiphilaDsm17781(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta cellobiosiphila DSM 17781 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaCellobiosiphilaDsm17781", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123275.protein.info.v11.5.txt",
		        "node_list_path": "1123275.protein.complete.v11.5.txt"
		    }
		]
    )()

def LutisporaThermophilaDsm19022Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lutispora thermophila DSM 19022 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutisporaThermophilaDsm19022Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122184.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122184.protein.info.v11.5.txt",
		        "node_list_path": "1122184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusSp6c8Div0013Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sp. 6C8_DIV0013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSp6c8Div0013Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1987385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1987385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1987385.clusters.proteins.v11.5.txt",
		        "sequence_path": "1987385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1987385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1987385.protein.info.v11.5.txt",
		        "node_list_path": "1987385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1987385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DickeyaDadantiiEch586(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii Ech586 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaDadantiiEch586", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "590409.protein.sequences.v11.5.fa",
		        "enrichment_path": "590409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "590409.protein.info.v11.5.txt",
		        "node_list_path": "590409.protein.complete.v11.5.txt"
		    }
		]
    )()

def EggerthellaSpCag368(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eggerthella sp. CAG:368 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthellaSpCag368", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262877.protein.info.v11.5.txt",
		        "node_list_path": "1262877.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfomicrobiumNorvegicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium norvegicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfomicrobiumNorvegicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52561.clusters.proteins.v11.5.txt",
		        "sequence_path": "52561.protein.sequences.v11.5.fa",
		        "enrichment_path": "52561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52561.protein.info.v11.5.txt",
		        "node_list_path": "52561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumGwa24915(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWA2_49_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumGwa24915", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797384.protein.info.v11.5.txt",
		        "node_list_path": "1797384.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpWb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. WB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpWb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1685380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1685380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1685380.clusters.proteins.v11.5.txt",
		        "sequence_path": "1685380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685380.protein.info.v11.5.txt",
		        "node_list_path": "1685380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1685380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CuniculiplasmaDivulgatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cuniculiplasma divulgatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CuniculiplasmaDivulgatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1673428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1673428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1673428.clusters.proteins.v11.5.txt",
		        "sequence_path": "1673428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673428.protein.info.v11.5.txt",
		        "node_list_path": "1673428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1673428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TropicimonasIsoalkanivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tropicimonas isoalkanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TropicimonasIsoalkanivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "441112.clusters.info.v11.5.txt",
		        "cluster_tree_path": "441112.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "441112.clusters.proteins.v11.5.txt",
		        "sequence_path": "441112.protein.sequences.v11.5.fa",
		        "enrichment_path": "441112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441112.protein.info.v11.5.txt",
		        "node_list_path": "441112.cluster.nodes.v11.5.txt",
		        "edge_list_path": "441112.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasPantelleriensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas pantelleriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasPantelleriensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "48727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "48727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "48727.clusters.proteins.v11.5.txt",
		        "sequence_path": "48727.protein.sequences.v11.5.fa",
		        "enrichment_path": "48727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48727.protein.info.v11.5.txt",
		        "node_list_path": "48727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "48727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusCelericrescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus celericrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusCelericrescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "227598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "227598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "227598.clusters.proteins.v11.5.txt",
		        "sequence_path": "227598.protein.sequences.v11.5.fa",
		        "enrichment_path": "227598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227598.protein.info.v11.5.txt",
		        "node_list_path": "227598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "227598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalothrixSpPcc6303Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC6303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalothrixSpPcc6303Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1170562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1170562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1170562.clusters.proteins.v11.5.txt",
		        "sequence_path": "1170562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1170562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1170562.protein.info.v11.5.txt",
		        "node_list_path": "1170562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1170562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa15613Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA1_56_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa15613Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618803.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618803.protein.info.v11.5.txt",
		        "node_list_path": "1618803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpMarseilleP2538Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. Marseille-P2538 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpMarseilleP2538Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816694.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816694.protein.info.v11.5.txt",
		        "node_list_path": "1816694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisDx1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris DX1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisDx1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "652103.protein.sequences.v11.5.fa",
		        "enrichment_path": "652103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "652103.protein.info.v11.5.txt",
		        "node_list_path": "652103.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaceaeBacteriumTaa166Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium TAA166 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaceaeBacteriumTaa166Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "278963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "278963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "278963.clusters.proteins.v11.5.txt",
		        "sequence_path": "278963.protein.sequences.v11.5.fa",
		        "enrichment_path": "278963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278963.protein.info.v11.5.txt",
		        "node_list_path": "278963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "278963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacterCapsulatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter capsulatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterCapsulatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272942.clusters.proteins.v11.5.txt",
		        "sequence_path": "272942.protein.sequences.v11.5.fa",
		        "enrichment_path": "272942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272942.protein.info.v11.5.txt",
		        "node_list_path": "272942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirosomaAerolatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma aerolatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaAerolatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211326.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211326.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211326.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211326.protein.info.v11.5.txt",
		        "node_list_path": "1211326.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211326.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SenegalimassiliaAnaerobiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Senegalimassilia anaerobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SenegalimassiliaAnaerobiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1034345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1034345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1034345.clusters.proteins.v11.5.txt",
		        "sequence_path": "1034345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034345.protein.info.v11.5.txt",
		        "node_list_path": "1034345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1034345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DickeyaSolaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya solani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaSolaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089444.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089444.protein.info.v11.5.txt",
		        "node_list_path": "1089444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerendipitaIndicaDsm11827Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serendipita indica DSM 11827 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerendipitaIndicaDsm11827Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1109443.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1109443.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1109443.clusters.proteins.v11.5.txt",
		        "sequence_path": "1109443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1109443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1109443.protein.info.v11.5.txt",
		        "node_list_path": "1109443.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1109443.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquilaChrysaetosChrysaetosCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquila chrysaetos chrysaetos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquilaChrysaetosChrysaetosCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "223781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "223781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "223781.clusters.proteins.v11.5.txt",
		        "sequence_path": "223781.protein.sequences.v11.5.fa",
		        "enrichment_path": "223781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223781.protein.info.v11.5.txt",
		        "node_list_path": "223781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "223781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusCaliditerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus caliditerrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusCaliditerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1330700.protein.sequences.v11.5.fa",
		        "enrichment_path": "1330700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1330700.protein.info.v11.5.txt",
		        "node_list_path": "1330700.protein.complete.v11.5.txt"
		    }
		]
    )()

def MuricaudaSpMar201075Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Muricauda sp. MAR201075 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuricaudaSpMar201075Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1250232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1250232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1250232.clusters.proteins.v11.5.txt",
		        "sequence_path": "1250232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250232.protein.info.v11.5.txt",
		        "node_list_path": "1250232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1250232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerolineaeBacteriumUtcfx1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium UTCFX1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaeBacteriumUtcfx1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1961100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961100.protein.info.v11.5.txt",
		        "node_list_path": "1961100.protein.complete.v11.5.txt"
		    }
		]
    )()

def KluyveromycesLactis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kluyveromyces lactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KluyveromycesLactis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28985.protein.sequences.v11.5.fa",
		        "enrichment_path": "28985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28985.protein.info.v11.5.txt",
		        "node_list_path": "28985.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumG41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium G41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumG41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1200749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200749.protein.info.v11.5.txt",
		        "node_list_path": "1200749.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacterium6732Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 67-32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacterium6732Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895729.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895729.protein.info.v11.5.txt",
		        "node_list_path": "1895729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KiloniellaSpongiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kiloniella spongiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KiloniellaSpongiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1489064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1489064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1489064.clusters.proteins.v11.5.txt",
		        "sequence_path": "1489064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1489064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1489064.protein.info.v11.5.txt",
		        "node_list_path": "1489064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1489064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DuganellaSpRoot336d2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. Root336D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpRoot336d2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736518.protein.info.v11.5.txt",
		        "node_list_path": "1736518.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanococcusVersutus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planococcus versutus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusVersutus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1302659.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302659.protein.info.v11.5.txt",
		        "node_list_path": "1302659.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCereus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cereus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCereus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1396.protein.sequences.v11.5.fa",
		        "enrichment_path": "1396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1396.protein.info.v11.5.txt",
		        "node_list_path": "1396.protein.complete.v11.5.txt"
		    }
		]
    )()

def StemphyliumLycopersici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stemphylium lycopersici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StemphyliumLycopersici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "183478.protein.sequences.v11.5.fa",
		        "enrichment_path": "183478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "183478.protein.info.v11.5.txt",
		        "node_list_path": "183478.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenovibrioMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenovibrio marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenovibrioMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28885.protein.sequences.v11.5.fa",
		        "enrichment_path": "28885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28885.protein.info.v11.5.txt",
		        "node_list_path": "28885.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpM2012083(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. M2012083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpM2012083", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1197706.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197706.protein.info.v11.5.txt",
		        "node_list_path": "1197706.protein.complete.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaStr5aAcyrthosiphonPisumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola str. 5A (Acyrthosiphon pisum) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaStr5aAcyrthosiphonPisumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "563178.clusters.info.v11.5.txt",
		        "cluster_tree_path": "563178.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "563178.clusters.proteins.v11.5.txt",
		        "sequence_path": "563178.protein.sequences.v11.5.fa",
		        "enrichment_path": "563178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563178.protein.info.v11.5.txt",
		        "node_list_path": "563178.cluster.nodes.v11.5.txt",
		        "edge_list_path": "563178.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerriglobusSpTaa43Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terriglobus sp. TAA 43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerriglobusSpTaa43Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "278961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "278961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "278961.clusters.proteins.v11.5.txt",
		        "sequence_path": "278961.protein.sequences.v11.5.fa",
		        "enrichment_path": "278961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278961.protein.info.v11.5.txt",
		        "node_list_path": "278961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "278961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LyngbyaSpPcc8106(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lyngbya sp. PCC8106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LyngbyaSpPcc8106", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313612.protein.sequences.v11.5.fa",
		        "enrichment_path": "313612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313612.protein.info.v11.5.txt",
		        "node_list_path": "313612.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfurococcusFermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurococcus fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurococcusFermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "768672.protein.sequences.v11.5.fa",
		        "enrichment_path": "768672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768672.protein.info.v11.5.txt",
		        "node_list_path": "768672.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachyspiraHampsoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira hampsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraHampsoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1289135.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1289135.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1289135.clusters.proteins.v11.5.txt",
		        "sequence_path": "1289135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1289135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1289135.protein.info.v11.5.txt",
		        "node_list_path": "1289135.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1289135.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfuribacillusStibiiarsenatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfuribacillus stibiiarsenatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuribacillusStibiiarsenatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1390249.protein.sequences.v11.5.fa",
		        "enrichment_path": "1390249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1390249.protein.info.v11.5.txt",
		        "node_list_path": "1390249.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrucellaAbortus2308Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brucella abortus 2308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrucellaAbortus2308Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "359391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "359391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "359391.clusters.proteins.v11.5.txt",
		        "sequence_path": "359391.protein.sequences.v11.5.fa",
		        "enrichment_path": "359391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "359391.protein.info.v11.5.txt",
		        "node_list_path": "359391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "359391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusHokkaidonensisJcm18461(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hokkaidonensis JCM 18461 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHokkaidonensisJcm18461", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1291742.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291742.protein.info.v11.5.txt",
		        "node_list_path": "1291742.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaSalinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena salina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaSalinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227488.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227488.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227488.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227488.protein.info.v11.5.txt",
		        "node_list_path": "1227488.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227488.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SingulisphaeraAcidiphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Singulisphaera acidiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SingulisphaeraAcidiphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "886293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "886293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "886293.clusters.proteins.v11.5.txt",
		        "sequence_path": "886293.protein.sequences.v11.5.fa",
		        "enrichment_path": "886293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "886293.protein.info.v11.5.txt",
		        "node_list_path": "886293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "886293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaSpAu1208Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. AU1208 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSpAu1208Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235457.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235457.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235457.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235457.protein.info.v11.5.txt",
		        "node_list_path": "1235457.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235457.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaLecithinolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema lecithinolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaLecithinolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321815.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321815.protein.info.v11.5.txt",
		        "node_list_path": "1321815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NanoarchaeotaArchaeonScgcAaa011G17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nanoarchaeota archaeon SCGC AAA011-G17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NanoarchaeotaArchaeonScgcAaa011G17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1104577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1104577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1104577.clusters.proteins.v11.5.txt",
		        "sequence_path": "1104577.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104577.protein.info.v11.5.txt",
		        "node_list_path": "1104577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1104577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpM26(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. M26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpM26", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1762962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1762962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1762962.protein.info.v11.5.txt",
		        "node_list_path": "1762962.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusTerreusNih2624Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus terreus NIH2624 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusTerreusNih2624Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "341663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "341663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "341663.clusters.proteins.v11.5.txt",
		        "sequence_path": "341663.protein.sequences.v11.5.fa",
		        "enrichment_path": "341663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "341663.protein.info.v11.5.txt",
		        "node_list_path": "341663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "341663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaMeleagridisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma meleagridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaMeleagridisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29561.clusters.proteins.v11.5.txt",
		        "sequence_path": "29561.protein.sequences.v11.5.fa",
		        "enrichment_path": "29561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29561.protein.info.v11.5.txt",
		        "node_list_path": "29561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VaribaculumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaribaculumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852372.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852372.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852372.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852372.protein.info.v11.5.txt",
		        "node_list_path": "1852372.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852372.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSuwonensisJ42(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis J42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSuwonensisJ42", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935566.protein.sequences.v11.5.fa",
		        "enrichment_path": "935566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935566.protein.info.v11.5.txt",
		        "node_list_path": "935566.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterUrativorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter urativorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterUrativorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45610.protein.sequences.v11.5.fa",
		        "enrichment_path": "45610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45610.protein.info.v11.5.txt",
		        "node_list_path": "45610.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumSaguiniDsm23967(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium saguini DSM 23967 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumSaguiniDsm23967", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437607.protein.info.v11.5.txt",
		        "node_list_path": "1437607.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb241528o2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241528O2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb241528o2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1471459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471459.protein.info.v11.5.txt",
		        "node_list_path": "1471459.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumPleistocenium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium pleistocenium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumPleistocenium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449343.protein.info.v11.5.txt",
		        "node_list_path": "1449343.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlochmanniaEndosymbiontOfCamponotusColobopsisObliquus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Camponotus (Colobopsis) obliquus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlochmanniaEndosymbiontOfCamponotusColobopsisObliquus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1505597.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505597.protein.info.v11.5.txt",
		        "node_list_path": "1505597.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosospiraBriensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira briensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraBriensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1266925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1266925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1266925.clusters.proteins.v11.5.txt",
		        "sequence_path": "1266925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266925.protein.info.v11.5.txt",
		        "node_list_path": "1266925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1266925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpKg01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. KG01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpKg01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674920.protein.info.v11.5.txt",
		        "node_list_path": "1674920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobotrysFlagransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobotrys flagrans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobotrysFlagransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "97331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "97331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "97331.clusters.proteins.v11.5.txt",
		        "sequence_path": "97331.protein.sequences.v11.5.fa",
		        "enrichment_path": "97331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97331.protein.info.v11.5.txt",
		        "node_list_path": "97331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "97331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumHqm9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium HQM9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumHqm9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "980584.protein.sequences.v11.5.fa",
		        "enrichment_path": "980584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "980584.protein.info.v11.5.txt",
		        "node_list_path": "980584.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeorickettsiaSennetsu(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neorickettsia sennetsu graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorickettsiaSennetsu", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "222891.protein.sequences.v11.5.fa",
		        "enrichment_path": "222891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "222891.protein.info.v11.5.txt",
		        "node_list_path": "222891.protein.complete.v11.5.txt"
		    }
		]
    )()

def TaphrinaDeformansPycc5710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Taphrina deformans PYCC 5710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TaphrinaDeformansPycc5710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1097556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1097556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1097556.clusters.proteins.v11.5.txt",
		        "sequence_path": "1097556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1097556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1097556.protein.info.v11.5.txt",
		        "node_list_path": "1097556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1097556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpNfr13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. NFR13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpNfr13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566285.protein.info.v11.5.txt",
		        "node_list_path": "1566285.protein.complete.v11.5.txt"
		    }
		]
    )()

def PediococcusDamnosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus damnosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusDamnosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "51663.protein.sequences.v11.5.fa",
		        "enrichment_path": "51663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51663.protein.info.v11.5.txt",
		        "node_list_path": "51663.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusSpC1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus sp. C1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusSpC1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1661745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661745.protein.info.v11.5.txt",
		        "node_list_path": "1661745.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpHeronCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. Heron Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpHeronCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385935.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385935.protein.info.v11.5.txt",
		        "node_list_path": "1385935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmazonaCollaria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amazona collaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmazonaCollaria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "241587.protein.sequences.v11.5.fa",
		        "enrichment_path": "241587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "241587.protein.info.v11.5.txt",
		        "node_list_path": "241587.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpCl95(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. cl95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpCl95", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761761.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761761.protein.info.v11.5.txt",
		        "node_list_path": "1761761.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusShapirobacteriaBacteriumCg2303520Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium CG2_30_35_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusShapirobacteriaBacteriumCg2303520Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805376.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805376.protein.info.v11.5.txt",
		        "node_list_path": "1805376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpYr527(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. YR527 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpYr527", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881028.protein.info.v11.5.txt",
		        "node_list_path": "1881028.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaOvis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella ovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaOvis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29433.protein.sequences.v11.5.fa",
		        "enrichment_path": "29433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29433.protein.info.v11.5.txt",
		        "node_list_path": "29433.protein.complete.v11.5.txt"
		    }
		]
    )()

def DethiobacterAlkaliphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dethiobacter alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DethiobacterAlkaliphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "555088.protein.sequences.v11.5.fa",
		        "enrichment_path": "555088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555088.protein.info.v11.5.txt",
		        "node_list_path": "555088.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumKhcpx20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium KHCPX20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumKhcpx20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855375.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855375.protein.info.v11.5.txt",
		        "node_list_path": "1855375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalolactibacillusAlkaliphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halolactibacillus alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolactibacillusAlkaliphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "442899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "442899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "442899.clusters.proteins.v11.5.txt",
		        "sequence_path": "442899.protein.sequences.v11.5.fa",
		        "enrichment_path": "442899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "442899.protein.info.v11.5.txt",
		        "node_list_path": "442899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "442899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSp32352(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 32352 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSp32352", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1969111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1969111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1969111.protein.info.v11.5.txt",
		        "node_list_path": "1969111.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfomonileTiedjeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfomonile tiedjei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfomonileTiedjeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "706587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "706587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "706587.clusters.proteins.v11.5.txt",
		        "sequence_path": "706587.protein.sequences.v11.5.fa",
		        "enrichment_path": "706587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706587.protein.info.v11.5.txt",
		        "node_list_path": "706587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "706587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgromycesCerinusSubspCerinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agromyces cerinus subsp. cerinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesCerinusSubspCerinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "232089.protein.sequences.v11.5.fa",
		        "enrichment_path": "232089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "232089.protein.info.v11.5.txt",
		        "node_list_path": "232089.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpYr768(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. YR768 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpYr768", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884365.protein.info.v11.5.txt",
		        "node_list_path": "1884365.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprothermobacterPlatensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprothermobacter platensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprothermobacterPlatensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1259795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1259795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1259795.protein.info.v11.5.txt",
		        "node_list_path": "1259795.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerotruncusRubiinfantis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerotruncus rubiinfantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotruncusRubiinfantis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720200.protein.info.v11.5.txt",
		        "node_list_path": "1720200.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpYi23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. YI23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpYi23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1097668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1097668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1097668.protein.info.v11.5.txt",
		        "node_list_path": "1097668.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterWoliniiSh(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter wolinii SH graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterWoliniiSh", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410664.protein.info.v11.5.txt",
		        "node_list_path": "1410664.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumCellulosolvensLd2006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens LD2006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumCellulosolvensLd2006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408436.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408436.protein.info.v11.5.txt",
		        "node_list_path": "1408436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusUvarumDsm19971(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus uvarum DSM 19971 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusUvarumDsm19971", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423812.protein.info.v11.5.txt",
		        "node_list_path": "1423812.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMinorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus minor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMinorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123309.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123309.protein.info.v11.5.txt",
		        "node_list_path": "1123309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpNsp222(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. NSP222 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpNsp222", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071073.protein.info.v11.5.txt",
		        "node_list_path": "1071073.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotogaNeapolitana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga neapolitana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaNeapolitana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "309803.protein.sequences.v11.5.fa",
		        "enrichment_path": "309803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "309803.protein.info.v11.5.txt",
		        "node_list_path": "309803.protein.complete.v11.5.txt"
		    }
		]
    )()

def NesterenkoniaSpAn1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. AN1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesterenkoniaSpAn1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "652017.protein.sequences.v11.5.fa",
		        "enrichment_path": "652017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "652017.protein.info.v11.5.txt",
		        "node_list_path": "652017.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaSaccharevitans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena saccharevitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaSaccharevitans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "301967.protein.sequences.v11.5.fa",
		        "enrichment_path": "301967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "301967.protein.info.v11.5.txt",
		        "node_list_path": "301967.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisBisb18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisB18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisBisb18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316056.protein.sequences.v11.5.fa",
		        "enrichment_path": "316056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316056.protein.info.v11.5.txt",
		        "node_list_path": "316056.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmatimonadetesBacteriumRbg166712Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium RBG_16_67_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmatimonadetesBacteriumRbg166712Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797288.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797288.protein.info.v11.5.txt",
		        "node_list_path": "1797288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellvibrioSpOa2007(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio sp. OA-2007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioSpOa2007", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "529823.protein.sequences.v11.5.fa",
		        "enrichment_path": "529823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529823.protein.info.v11.5.txt",
		        "node_list_path": "529823.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumGw2011Gwa23836Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWA2_38_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwa23836Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619055.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619055.protein.info.v11.5.txt",
		        "node_list_path": "1619055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RahnellaSpY9602(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rahnella sp. Y9602 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RahnellaSpY9602", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "741091.protein.sequences.v11.5.fa",
		        "enrichment_path": "741091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "741091.protein.info.v11.5.txt",
		        "node_list_path": "741091.protein.complete.v11.5.txt"
		    }
		]
    )()

def VaginellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vaginella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaginellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816680.protein.info.v11.5.txt",
		        "node_list_path": "1816680.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusSomnus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus somnus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusSomnus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "205914.protein.sequences.v11.5.fa",
		        "enrichment_path": "205914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "205914.protein.info.v11.5.txt",
		        "node_list_path": "205914.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusApodemiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus apodemi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusApodemiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423724.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423724.protein.info.v11.5.txt",
		        "node_list_path": "1423724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumCopahuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum copahuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumCopahuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1838280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1838280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1838280.clusters.proteins.v11.5.txt",
		        "sequence_path": "1838280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1838280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1838280.protein.info.v11.5.txt",
		        "node_list_path": "1838280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1838280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacteriumXylanolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium xylanolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacteriumXylanolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "858215.protein.sequences.v11.5.fa",
		        "enrichment_path": "858215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "858215.protein.info.v11.5.txt",
		        "node_list_path": "858215.protein.complete.v11.5.txt"
		    }
		]
    )()

def LabilibacterAurantiacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Labilibacter aurantiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabilibacterAurantiacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849719.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849719.protein.info.v11.5.txt",
		        "node_list_path": "1849719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurovumLithotrophicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum lithotrophicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurovumLithotrophicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "206403.clusters.info.v11.5.txt",
		        "cluster_tree_path": "206403.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "206403.clusters.proteins.v11.5.txt",
		        "sequence_path": "206403.protein.sequences.v11.5.fa",
		        "enrichment_path": "206403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "206403.protein.info.v11.5.txt",
		        "node_list_path": "206403.cluster.nodes.v11.5.txt",
		        "edge_list_path": "206403.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrahymenaThermophilaSb210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrahymena thermophila SB210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrahymenaThermophilaSb210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "312017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "312017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "312017.clusters.proteins.v11.5.txt",
		        "sequence_path": "312017.protein.sequences.v11.5.fa",
		        "enrichment_path": "312017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "312017.protein.info.v11.5.txt",
		        "node_list_path": "312017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "312017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterThiogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter thiogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterThiogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "115783.clusters.info.v11.5.txt",
		        "cluster_tree_path": "115783.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "115783.clusters.proteins.v11.5.txt",
		        "sequence_path": "115783.protein.sequences.v11.5.fa",
		        "enrichment_path": "115783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115783.protein.info.v11.5.txt",
		        "node_list_path": "115783.cluster.nodes.v11.5.txt",
		        "edge_list_path": "115783.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EndosymbiontOfAcanthamoeba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Acanthamoeba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndosymbiontOfAcanthamoeba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86106.protein.sequences.v11.5.fa",
		        "enrichment_path": "86106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86106.protein.info.v11.5.txt",
		        "node_list_path": "86106.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusNageliiDsm13675(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nagelii DSM 13675 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusNageliiDsm13675", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122150.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122150.protein.info.v11.5.txt",
		        "node_list_path": "1122150.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteimonasSpJ29(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas sp. J29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteimonasSpJ29", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935863.protein.sequences.v11.5.fa",
		        "enrichment_path": "935863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935863.protein.info.v11.5.txt",
		        "node_list_path": "935863.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionimicrobiumSpMarseilleP3275Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionimicrobium sp. Marseille-P3275 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionimicrobiumSpMarseilleP3275Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871034.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871034.protein.info.v11.5.txt",
		        "node_list_path": "1871034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychroflexusSalarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychroflexus salarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroflexusSalarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1155689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1155689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1155689.protein.info.v11.5.txt",
		        "node_list_path": "1155689.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesColeocanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces coleocanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesColeocanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525245.clusters.proteins.v11.5.txt",
		        "sequence_path": "525245.protein.sequences.v11.5.fa",
		        "enrichment_path": "525245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525245.protein.info.v11.5.txt",
		        "node_list_path": "525245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusParalvinellaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus paralvinellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusParalvinellaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582419.clusters.proteins.v11.5.txt",
		        "sequence_path": "582419.protein.sequences.v11.5.fa",
		        "enrichment_path": "582419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582419.protein.info.v11.5.txt",
		        "node_list_path": "582419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TurneriellaParvaDsm21527Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Turneriella parva DSM 21527 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TurneriellaParvaDsm21527Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "869212.clusters.info.v11.5.txt",
		        "cluster_tree_path": "869212.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "869212.clusters.proteins.v11.5.txt",
		        "sequence_path": "869212.protein.sequences.v11.5.fa",
		        "enrichment_path": "869212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869212.protein.info.v11.5.txt",
		        "node_list_path": "869212.cluster.nodes.v11.5.txt",
		        "edge_list_path": "869212.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumHydrothermaleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum hydrothermale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumHydrothermaleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121428.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121428.protein.info.v11.5.txt",
		        "node_list_path": "1121428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerobacillusAlkalidiazotrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobacillus alkalidiazotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobacillusAlkalidiazotrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "472963.protein.sequences.v11.5.fa",
		        "enrichment_path": "472963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472963.protein.info.v11.5.txt",
		        "node_list_path": "472963.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusFarraginis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus farraginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusFarraginis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "254757.protein.sequences.v11.5.fa",
		        "enrichment_path": "254757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "254757.protein.info.v11.5.txt",
		        "node_list_path": "254757.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterMuridarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter muridarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterMuridarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216.protein.sequences.v11.5.fa",
		        "enrichment_path": "216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216.protein.info.v11.5.txt",
		        "node_list_path": "216.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusMauleonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus mauleonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusMauleonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351675.protein.sequences.v11.5.fa",
		        "enrichment_path": "351675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351675.protein.info.v11.5.txt",
		        "node_list_path": "351675.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiorhodovibrioSp970Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiorhodovibrio sp. 970 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiorhodovibrioSp970Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "631362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "631362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "631362.clusters.proteins.v11.5.txt",
		        "sequence_path": "631362.protein.sequences.v11.5.fa",
		        "enrichment_path": "631362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "631362.protein.info.v11.5.txt",
		        "node_list_path": "631362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "631362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFructivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fructivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFructivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "941770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "941770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "941770.clusters.proteins.v11.5.txt",
		        "sequence_path": "941770.protein.sequences.v11.5.fa",
		        "enrichment_path": "941770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "941770.protein.info.v11.5.txt",
		        "node_list_path": "941770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "941770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TenacibaculumTodarodisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum todarodis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumTodarodisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1850252.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1850252.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1850252.clusters.proteins.v11.5.txt",
		        "sequence_path": "1850252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850252.protein.info.v11.5.txt",
		        "node_list_path": "1850252.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1850252.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RothiaSpNd6we1a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rothia sp. ND6WE1A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RothiaSpNd6we1a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1848190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848190.protein.info.v11.5.txt",
		        "node_list_path": "1848190.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenaeusVannamei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penaeus vannamei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenaeusVannamei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6689.protein.sequences.v11.5.fa",
		        "enrichment_path": "6689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6689.protein.info.v11.5.txt",
		        "node_list_path": "6689.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumCeb3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium CEB3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumCeb3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999898.protein.sequences.v11.5.fa",
		        "enrichment_path": "999898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999898.protein.info.v11.5.txt",
		        "node_list_path": "999898.protein.complete.v11.5.txt"
		    }
		]
    )()

def RufibacterTibetensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rufibacter tibetensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RufibacterTibetensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "512763.protein.sequences.v11.5.fa",
		        "enrichment_path": "512763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512763.protein.info.v11.5.txt",
		        "node_list_path": "512763.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaSpUcdKl12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. UCD-KL12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSpUcdKl12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1917163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917163.protein.info.v11.5.txt",
		        "node_list_path": "1917163.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpJsc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. JSC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpJsc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1487953.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1487953.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1487953.clusters.proteins.v11.5.txt",
		        "sequence_path": "1487953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1487953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1487953.protein.info.v11.5.txt",
		        "node_list_path": "1487953.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1487953.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidiaBacteriumGa0077558Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidia bacterium Ga0077558 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidiaBacteriumGa0077558Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752194.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752194.protein.info.v11.5.txt",
		        "node_list_path": "1752194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FungalSpNo14919Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return fungal sp. No.14919 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FungalSpNo14919Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1813822.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1813822.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1813822.clusters.proteins.v11.5.txt",
		        "sequence_path": "1813822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1813822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1813822.protein.info.v11.5.txt",
		        "node_list_path": "1813822.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1813822.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CamelliaSinensisVarSinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Camellia sinensis var. sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CamelliaSinensisVarSinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "542762.protein.sequences.v11.5.fa",
		        "enrichment_path": "542762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "542762.protein.info.v11.5.txt",
		        "node_list_path": "542762.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRbg16437Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_43_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg16437Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798373.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798373.protein.info.v11.5.txt",
		        "node_list_path": "1798373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerrisporobacterGlycolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terrisporobacter glycolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrisporobacterGlycolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36841.clusters.proteins.v11.5.txt",
		        "sequence_path": "36841.protein.sequences.v11.5.fa",
		        "enrichment_path": "36841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36841.protein.info.v11.5.txt",
		        "node_list_path": "36841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhoenicibacterCongonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phoenicibacter congonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhoenicibacterCongonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1944646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1944646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1944646.clusters.proteins.v11.5.txt",
		        "sequence_path": "1944646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1944646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1944646.protein.info.v11.5.txt",
		        "node_list_path": "1944646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1944646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaRuminicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella ruminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaRuminicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264731.protein.sequences.v11.5.fa",
		        "enrichment_path": "264731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264731.protein.info.v11.5.txt",
		        "node_list_path": "264731.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaHermannii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia hermannii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaHermannii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1115512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1115512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1115512.protein.info.v11.5.txt",
		        "node_list_path": "1115512.protein.complete.v11.5.txt"
		    }
		]
    )()

def MitsuariaChitosanitabidaAtccBaa476Nbrc102408Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mitsuaria chitosanitabida ATCC BAA-476 NBRC 102408 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MitsuariaChitosanitabidaAtccBaa476Nbrc102408Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336246.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336246.protein.info.v11.5.txt",
		        "node_list_path": "1336246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KangiellaAquimarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kangiella aquimarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KangiellaAquimarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122134.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122134.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122134.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122134.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122134.protein.info.v11.5.txt",
		        "node_list_path": "1122134.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122134.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaVietnamiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia vietnamiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaVietnamiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "269482.protein.sequences.v11.5.fa",
		        "enrichment_path": "269482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269482.protein.info.v11.5.txt",
		        "node_list_path": "269482.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermonemaRossianum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermonema rossianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermonemaRossianum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1313301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313301.protein.info.v11.5.txt",
		        "node_list_path": "1313301.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuciliaCuprinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lucilia cuprina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuciliaCuprinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7375.clusters.proteins.v11.5.txt",
		        "sequence_path": "7375.protein.sequences.v11.5.fa",
		        "enrichment_path": "7375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7375.protein.info.v11.5.txt",
		        "node_list_path": "7375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaGinsengisoliNbrc100965Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengisoli NBRC 100965 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaGinsengisoliNbrc100965Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218078.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218078.protein.info.v11.5.txt",
		        "node_list_path": "1218078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoclostridiumDifficileCd160Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoclostridium difficile CD160 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoclostridiumDifficileCd160Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1151292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1151292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1151292.clusters.proteins.v11.5.txt",
		        "sequence_path": "1151292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151292.protein.info.v11.5.txt",
		        "node_list_path": "1151292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1151292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SubdoligranulumSpCag314(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Subdoligranulum sp. CAG:314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SubdoligranulumSpCag314", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262970.protein.info.v11.5.txt",
		        "node_list_path": "1262970.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoxodontaAfricanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loxodonta africana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoxodontaAfricanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9785.clusters.proteins.v11.5.txt",
		        "sequence_path": "9785.protein.sequences.v11.5.fa",
		        "enrichment_path": "9785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9785.protein.info.v11.5.txt",
		        "node_list_path": "9785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpVkmB2647Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. VKM B-2647 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpVkmB2647Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1590651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1590651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1590651.clusters.proteins.v11.5.txt",
		        "sequence_path": "1590651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1590651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1590651.protein.info.v11.5.txt",
		        "node_list_path": "1590651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1590651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycetalesBacteriumActino01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomycetales bacterium Actino_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycetalesBacteriumActino01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674805.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674805.protein.info.v11.5.txt",
		        "node_list_path": "1674805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobaculaSpTsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacula sp. TS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobaculaSpTsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232437.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232437.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232437.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232437.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232437.protein.info.v11.5.txt",
		        "node_list_path": "1232437.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232437.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OphiostomaPiceaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ophiostoma piceae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiostomaPiceaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61273.clusters.proteins.v11.5.txt",
		        "sequence_path": "61273.protein.sequences.v11.5.fa",
		        "enrichment_path": "61273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61273.protein.info.v11.5.txt",
		        "node_list_path": "61273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LiberibacterAmericanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter americanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LiberibacterAmericanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1261131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1261131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1261131.clusters.proteins.v11.5.txt",
		        "sequence_path": "1261131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261131.protein.info.v11.5.txt",
		        "node_list_path": "1261131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1261131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumJosui(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium josui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumJosui", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1291050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291050.protein.info.v11.5.txt",
		        "node_list_path": "1291050.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanococcusDonghaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planococcus donghaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusDonghaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "933115.clusters.info.v11.5.txt",
		        "cluster_tree_path": "933115.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "933115.clusters.proteins.v11.5.txt",
		        "sequence_path": "933115.protein.sequences.v11.5.fa",
		        "enrichment_path": "933115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933115.protein.info.v11.5.txt",
		        "node_list_path": "933115.cluster.nodes.v11.5.txt",
		        "edge_list_path": "933115.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MacleayaCordata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Macleaya cordata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacleayaCordata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56857.protein.sequences.v11.5.fa",
		        "enrichment_path": "56857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56857.protein.info.v11.5.txt",
		        "node_list_path": "56857.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacterium4484171(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_171 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484171", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1956173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1956173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1956173.protein.info.v11.5.txt",
		        "node_list_path": "1956173.protein.complete.v11.5.txt"
		    }
		]
    )()

def RaphidocelisSubcapitata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Raphidocelis subcapitata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RaphidocelisSubcapitata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "307507.protein.sequences.v11.5.fa",
		        "enrichment_path": "307507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "307507.protein.info.v11.5.txt",
		        "node_list_path": "307507.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "294.protein.sequences.v11.5.fa",
		        "enrichment_path": "294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294.protein.info.v11.5.txt",
		        "node_list_path": "294.protein.complete.v11.5.txt"
		    }
		]
    )()

def NegativibacillusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Negativibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NegativibacillusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871035.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871035.protein.info.v11.5.txt",
		        "node_list_path": "1871035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumYad3003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium YAD3003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumYad3003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520816.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520816.protein.info.v11.5.txt",
		        "node_list_path": "1520816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KribbellaFlavida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kribbella flavida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KribbellaFlavida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "479435.protein.sequences.v11.5.fa",
		        "enrichment_path": "479435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479435.protein.info.v11.5.txt",
		        "node_list_path": "479435.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumSp46296(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum sp. 46_296 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumSp46296", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635262.protein.info.v11.5.txt",
		        "node_list_path": "1635262.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanobacillusOncorhynchiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus oncorhynchi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusOncorhynchiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "545501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "545501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "545501.clusters.proteins.v11.5.txt",
		        "sequence_path": "545501.protein.sequences.v11.5.fa",
		        "enrichment_path": "545501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545501.protein.info.v11.5.txt",
		        "node_list_path": "545501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "545501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivivaxRoseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxRoseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641238.clusters.proteins.v11.5.txt",
		        "sequence_path": "641238.protein.sequences.v11.5.fa",
		        "enrichment_path": "641238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641238.protein.info.v11.5.txt",
		        "node_list_path": "641238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrococcusSpNa2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus sp. NA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusSpNa2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "342949.protein.sequences.v11.5.fa",
		        "enrichment_path": "342949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342949.protein.info.v11.5.txt",
		        "node_list_path": "342949.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumRbg164410Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_44_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg164410Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802597.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802597.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802597.protein.info.v11.5.txt",
		        "node_list_path": "1802597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusAwamoriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus awamori Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusAwamoriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "105351.clusters.info.v11.5.txt",
		        "cluster_tree_path": "105351.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "105351.clusters.proteins.v11.5.txt",
		        "sequence_path": "105351.protein.sequences.v11.5.fa",
		        "enrichment_path": "105351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105351.protein.info.v11.5.txt",
		        "node_list_path": "105351.cluster.nodes.v11.5.txt",
		        "edge_list_path": "105351.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg166485(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_64_85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg166485", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797846.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797846.protein.info.v11.5.txt",
		        "node_list_path": "1797846.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphenodonPunctatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphenodon punctatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphenodonPunctatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8508.protein.sequences.v11.5.fa",
		        "enrichment_path": "8508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8508.protein.info.v11.5.txt",
		        "node_list_path": "8508.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioFurnissiiNctc11218Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio furnissii NCTC 11218 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioFurnissiiNctc11218Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "903510.clusters.info.v11.5.txt",
		        "cluster_tree_path": "903510.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "903510.clusters.proteins.v11.5.txt",
		        "sequence_path": "903510.protein.sequences.v11.5.fa",
		        "enrichment_path": "903510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903510.protein.info.v11.5.txt",
		        "node_list_path": "903510.cluster.nodes.v11.5.txt",
		        "edge_list_path": "903510.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpA3h3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. A3H3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpA3h3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1346287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346287.protein.info.v11.5.txt",
		        "node_list_path": "1346287.protein.complete.v11.5.txt"
		    }
		]
    )()

def LinderinaPennispora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Linderina pennispora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LinderinaPennispora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61395.protein.sequences.v11.5.fa",
		        "enrichment_path": "61395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61395.protein.info.v11.5.txt",
		        "node_list_path": "61395.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMg1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Mg1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMg1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "465541.protein.sequences.v11.5.fa",
		        "enrichment_path": "465541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "465541.protein.info.v11.5.txt",
		        "node_list_path": "465541.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlleyaNamhaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olleya namhaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlleyaNamhaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144750.protein.info.v11.5.txt",
		        "node_list_path": "1144750.protein.complete.v11.5.txt"
		    }
		]
    )()

def CatenuloplanesJaponicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catenuloplanes japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenuloplanesJaponicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33876.clusters.proteins.v11.5.txt",
		        "sequence_path": "33876.protein.sequences.v11.5.fa",
		        "enrichment_path": "33876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33876.protein.info.v11.5.txt",
		        "node_list_path": "33876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4112(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_41_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4112", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802138.protein.info.v11.5.txt",
		        "node_list_path": "1802138.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaPhenazinium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia phenazinium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaPhenazinium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "60549.protein.sequences.v11.5.fa",
		        "enrichment_path": "60549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60549.protein.info.v11.5.txt",
		        "node_list_path": "60549.protein.complete.v11.5.txt"
		    }
		]
    )()

def AttaColombicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atta colombica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AttaColombicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "520822.clusters.info.v11.5.txt",
		        "cluster_tree_path": "520822.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "520822.clusters.proteins.v11.5.txt",
		        "sequence_path": "520822.protein.sequences.v11.5.fa",
		        "enrichment_path": "520822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "520822.protein.info.v11.5.txt",
		        "node_list_path": "520822.cluster.nodes.v11.5.txt",
		        "edge_list_path": "520822.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HomoSapiensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Homo sapiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HomoSapiensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9606.clusters.proteins.v11.5.txt",
		        "sequence_path": "9606.protein.sequences.v11.5.fa",
		        "enrichment_path": "9606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9606.protein.info.v11.5.txt",
		        "node_list_path": "9606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BhargavaeaBeijingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bhargavaea beijingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BhargavaeaBeijingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426756.protein.sequences.v11.5.fa",
		        "enrichment_path": "426756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426756.protein.info.v11.5.txt",
		        "node_list_path": "426756.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterTrogontum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter trogontum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterTrogontum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "50960.protein.sequences.v11.5.fa",
		        "enrichment_path": "50960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50960.protein.info.v11.5.txt",
		        "node_list_path": "50960.protein.complete.v11.5.txt"
		    }
		]
    )()

def TindalliaCaliforniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tindallia californiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TindalliaCaliforniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "159292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "159292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "159292.clusters.proteins.v11.5.txt",
		        "sequence_path": "159292.protein.sequences.v11.5.fa",
		        "enrichment_path": "159292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "159292.protein.info.v11.5.txt",
		        "node_list_path": "159292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "159292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MobiluncusCurtisiiAtcc35241Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii ATCC35241 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobiluncusCurtisiiAtcc35241Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585198.clusters.proteins.v11.5.txt",
		        "sequence_path": "585198.protein.sequences.v11.5.fa",
		        "enrichment_path": "585198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585198.protein.info.v11.5.txt",
		        "node_list_path": "585198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WigglesworthiaGlossinidiaSpGmoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia sp. Gmo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WigglesworthiaGlossinidiaSpGmoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1142511.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1142511.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1142511.clusters.proteins.v11.0.txt",
		        "sequence_path": "1142511.protein.sequences.v11.0.fa",
		        "enrichment_path": "1142511.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1142511.protein.info.v11.0.txt",
		        "node_list_path": "1142511.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1142511.protein.cluster.v11.0.txt"
		    }
		]
    )()

def AnaerostipesSp992a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerostipes sp. 992a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerostipesSp992a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1261637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261637.protein.info.v11.5.txt",
		        "node_list_path": "1261637.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumWenxiniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium wenxiniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumWenxiniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "683125.protein.sequences.v11.5.fa",
		        "enrichment_path": "683125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683125.protein.info.v11.5.txt",
		        "node_list_path": "683125.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaYangpuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora yangpuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaYangpuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "683228.clusters.info.v11.5.txt",
		        "cluster_tree_path": "683228.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "683228.clusters.proteins.v11.5.txt",
		        "sequence_path": "683228.protein.sequences.v11.5.fa",
		        "enrichment_path": "683228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683228.protein.info.v11.5.txt",
		        "node_list_path": "683228.cluster.nodes.v11.5.txt",
		        "edge_list_path": "683228.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeeuwenhoekiellaMarinoflavaDsm3653(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella marinoflava DSM 3653 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeeuwenhoekiellaMarinoflavaDsm3653", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122159.protein.info.v11.5.txt",
		        "node_list_path": "1122159.protein.complete.v11.5.txt"
		    }
		]
    )()

def LabilibacterMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Labilibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabilibacterMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1477105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1477105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1477105.protein.info.v11.5.txt",
		        "node_list_path": "1477105.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho201Full4216Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_42_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full4216Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801743.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801743.protein.info.v11.5.txt",
		        "node_list_path": "1801743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumFioriniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum fioriniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumFioriniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "710243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "710243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "710243.clusters.proteins.v11.5.txt",
		        "sequence_path": "710243.protein.sequences.v11.5.fa",
		        "enrichment_path": "710243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710243.protein.info.v11.5.txt",
		        "node_list_path": "710243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "710243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag921(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:921 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag921", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262847.protein.info.v11.5.txt",
		        "node_list_path": "1262847.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumKansasii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumKansasii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768.protein.info.v11.5.txt",
		        "node_list_path": "1768.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumWanjuense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium wanjuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumWanjuense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "356305.protein.sequences.v11.5.fa",
		        "enrichment_path": "356305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "356305.protein.info.v11.5.txt",
		        "node_list_path": "356305.protein.complete.v11.5.txt"
		    }
		]
    )()

def RozellaAllomycisCsf55Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rozella allomycis CSF55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RozellaAllomycisCsf55Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "988480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "988480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "988480.clusters.proteins.v11.5.txt",
		        "sequence_path": "988480.protein.sequences.v11.5.fa",
		        "enrichment_path": "988480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "988480.protein.info.v11.5.txt",
		        "node_list_path": "988480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "988480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MalasseziaPachydermatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Malassezia pachydermatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalasseziaPachydermatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "77020.protein.sequences.v11.5.fa",
		        "enrichment_path": "77020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77020.protein.info.v11.5.txt",
		        "node_list_path": "77020.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSp6526Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 65-26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSp6526Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895781.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895781.protein.info.v11.5.txt",
		        "node_list_path": "1895781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisSk1080(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK1080 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisSk1080", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1008453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1008453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1008453.protein.info.v11.5.txt",
		        "node_list_path": "1008453.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeurosporaTetraspermaFgsc2509(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neurospora tetrasperma FGSC 2509 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeurosporaTetraspermaFgsc2509", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "510952.protein.sequences.v11.5.fa",
		        "enrichment_path": "510952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "510952.protein.info.v11.5.txt",
		        "node_list_path": "510952.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKomeilibacteriaBacteriumRifcsplowo201Full5215(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_01_FULL_52_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo201Full5215", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798551.protein.info.v11.5.txt",
		        "node_list_path": "1798551.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusObeumAtcc29174(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus obeum ATCC29174 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusObeumAtcc29174", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411459.protein.sequences.v11.5.fa",
		        "enrichment_path": "411459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411459.protein.info.v11.5.txt",
		        "node_list_path": "411459.protein.complete.v11.5.txt"
		    }
		]
    )()

def MangrovimonasSpSt2l12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. ST2L12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MangrovimonasSpSt2l12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1645915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1645915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1645915.protein.info.v11.5.txt",
		        "node_list_path": "1645915.protein.complete.v11.5.txt"
		    }
		]
    )()

def EctothiorhodospiraSpBsl9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ectothiorhodospira sp. BSL-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctothiorhodospiraSpBsl9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1442136.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1442136.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1442136.clusters.proteins.v11.5.txt",
		        "sequence_path": "1442136.protein.sequences.v11.5.fa",
		        "enrichment_path": "1442136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1442136.protein.info.v11.5.txt",
		        "node_list_path": "1442136.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1442136.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpF0108(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpF0108", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575615.protein.sequences.v11.5.fa",
		        "enrichment_path": "575615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575615.protein.info.v11.5.txt",
		        "node_list_path": "575615.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpAg1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ag1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpAg1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1642949.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1642949.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1642949.clusters.proteins.v11.5.txt",
		        "sequence_path": "1642949.protein.sequences.v11.5.fa",
		        "enrichment_path": "1642949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1642949.protein.info.v11.5.txt",
		        "node_list_path": "1642949.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1642949.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioJasicida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio jasicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioJasicida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280001.protein.info.v11.5.txt",
		        "node_list_path": "1280001.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusThorarchaeotaArchaeonAb25(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thorarchaeota archaeon AB_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThorarchaeotaArchaeonAb25", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1837170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1837170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1837170.protein.info.v11.5.txt",
		        "node_list_path": "1837170.protein.complete.v11.5.txt"
		    }
		]
    )()

def CetobacteriumSomerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cetobacterium somerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CetobacteriumSomerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1319815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1319815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1319815.protein.info.v11.5.txt",
		        "node_list_path": "1319815.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZymomonasMobilisAtcc10988Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymomonas mobilis ATCC10988 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymomonasMobilisAtcc10988Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "555217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "555217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "555217.clusters.proteins.v11.5.txt",
		        "sequence_path": "555217.protein.sequences.v11.5.fa",
		        "enrichment_path": "555217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555217.protein.info.v11.5.txt",
		        "node_list_path": "555217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "555217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumDg72Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumDg72Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703764.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703764.protein.info.v11.5.txt",
		        "node_list_path": "1703764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CohnellaLaeviribosiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cohnella laeviribosi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CohnellaLaeviribosiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121346.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121346.protein.info.v11.5.txt",
		        "node_list_path": "1121346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaueraHumireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera humireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraHumireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1134435.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1134435.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1134435.clusters.proteins.v11.5.txt",
		        "sequence_path": "1134435.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134435.protein.info.v11.5.txt",
		        "node_list_path": "1134435.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1134435.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalolaminaSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halolamina sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolaminaSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1480675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1480675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1480675.protein.info.v11.5.txt",
		        "node_list_path": "1480675.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobaculumUrinaleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum urinale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobaculumUrinaleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120933.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120933.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120933.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120933.protein.info.v11.5.txt",
		        "node_list_path": "1120933.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120933.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumPhenoliresistens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium phenoliresistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumPhenoliresistens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "396014.protein.sequences.v11.5.fa",
		        "enrichment_path": "396014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396014.protein.info.v11.5.txt",
		        "node_list_path": "396014.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriRch2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri RCH2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriRch2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644801.clusters.proteins.v11.5.txt",
		        "sequence_path": "644801.protein.sequences.v11.5.fa",
		        "enrichment_path": "644801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644801.protein.info.v11.5.txt",
		        "node_list_path": "644801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobacillusSpC254Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacillus sp. C254 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobacillusSpC254Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1225341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1225341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1225341.clusters.proteins.v11.5.txt",
		        "sequence_path": "1225341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225341.protein.info.v11.5.txt",
		        "node_list_path": "1225341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1225341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterRuminantiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter ruminantium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterRuminantiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634498.clusters.proteins.v11.5.txt",
		        "sequence_path": "634498.protein.sequences.v11.5.fa",
		        "enrichment_path": "634498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634498.protein.info.v11.5.txt",
		        "node_list_path": "634498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GallibacteriumSalpingitidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallibacterium salpingitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallibacteriumSalpingitidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "505341.protein.sequences.v11.5.fa",
		        "enrichment_path": "505341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "505341.protein.info.v11.5.txt",
		        "node_list_path": "505341.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpCf079(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. CF079 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpCf079", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882774.protein.info.v11.5.txt",
		        "node_list_path": "1882774.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1025068(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_50_68 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1025068", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805312.protein.info.v11.5.txt",
		        "node_list_path": "1805312.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpErg5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. ERG5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpErg5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1381597.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381597.protein.info.v11.5.txt",
		        "node_list_path": "1381597.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpNd2010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. ND2010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpNd2010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410618.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410618.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410618.protein.info.v11.5.txt",
		        "node_list_path": "1410618.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermobisporaBispora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermobispora bispora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobisporaBispora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469371.protein.sequences.v11.5.fa",
		        "enrichment_path": "469371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469371.protein.info.v11.5.txt",
		        "node_list_path": "469371.protein.complete.v11.5.txt"
		    }
		]
    )()

def CylindrospermumStagnale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cylindrospermum stagnale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CylindrospermumStagnale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56107.protein.sequences.v11.5.fa",
		        "enrichment_path": "56107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56107.protein.info.v11.5.txt",
		        "node_list_path": "56107.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterHarbinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter harbinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterHarbinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1353941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353941.protein.info.v11.5.txt",
		        "node_list_path": "1353941.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorHydrothermalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor hydrothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorHydrothermalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "632292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "632292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "632292.clusters.proteins.v11.5.txt",
		        "sequence_path": "632292.protein.sequences.v11.5.fa",
		        "enrichment_path": "632292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632292.protein.info.v11.5.txt",
		        "node_list_path": "632292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "632292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhormidiumSpOscr(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phormidium sp. OSCR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhormidiumSpOscr", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1666905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666905.protein.info.v11.5.txt",
		        "node_list_path": "1666905.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlS4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL S-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlS4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1519471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519471.protein.info.v11.5.txt",
		        "node_list_path": "1519471.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureimonasSpAu20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpAu20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349819.protein.info.v11.5.txt",
		        "node_list_path": "1349819.protein.complete.v11.5.txt"
		    }
		]
    )()

def AndreeseniaAngustaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Andreesenia angusta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AndreeseniaAngustaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39480.clusters.proteins.v11.5.txt",
		        "sequence_path": "39480.protein.sequences.v11.5.fa",
		        "enrichment_path": "39480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39480.protein.info.v11.5.txt",
		        "node_list_path": "39480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusBoroniphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus boroniphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusBoroniphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1294265.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294265.protein.info.v11.5.txt",
		        "node_list_path": "1294265.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAlbulus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces albulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAlbulus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68570.protein.sequences.v11.5.fa",
		        "enrichment_path": "68570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68570.protein.info.v11.5.txt",
		        "node_list_path": "68570.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriumSpPmmr2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacterium sp. PMMR2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriumSpPmmr2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1382359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382359.protein.info.v11.5.txt",
		        "node_list_path": "1382359.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedEubacteriumSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Eubacterium sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedEubacteriumSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "165185.protein.sequences.v11.5.fa",
		        "enrichment_path": "165185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "165185.protein.info.v11.5.txt",
		        "node_list_path": "165185.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full509bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_50_9b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full509bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798682.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798682.protein.info.v11.5.txt",
		        "node_list_path": "1798682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665571.protein.sequences.v11.5.fa",
		        "enrichment_path": "665571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665571.protein.info.v11.5.txt",
		        "node_list_path": "665571.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrococcusYayanosii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus yayanosii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusYayanosii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "529709.protein.sequences.v11.5.fa",
		        "enrichment_path": "529709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529709.protein.info.v11.5.txt",
		        "node_list_path": "529709.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterSpMit016242Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT 01-6242 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSpMit016242Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "222136.clusters.info.v11.5.txt",
		        "cluster_tree_path": "222136.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "222136.clusters.proteins.v11.5.txt",
		        "sequence_path": "222136.protein.sequences.v11.5.fa",
		        "enrichment_path": "222136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "222136.protein.info.v11.5.txt",
		        "node_list_path": "222136.cluster.nodes.v11.5.txt",
		        "edge_list_path": "222136.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpUnc363mftsu51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. UNC363MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpUnc363mftsu51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449069.protein.info.v11.5.txt",
		        "node_list_path": "1449069.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852388.protein.info.v11.5.txt",
		        "node_list_path": "1852388.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlutamicibacterHalophytocola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glutamicibacter halophytocola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlutamicibacterHalophytocola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1933880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933880.protein.info.v11.5.txt",
		        "node_list_path": "1933880.protein.complete.v11.5.txt"
		    }
		]
    )()

def VesicomyosociusOkutaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vesicomyosocius okutanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VesicomyosociusOkutaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "412965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "412965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "412965.clusters.proteins.v11.5.txt",
		        "sequence_path": "412965.protein.sequences.v11.5.fa",
		        "enrichment_path": "412965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "412965.protein.info.v11.5.txt",
		        "node_list_path": "412965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "412965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFf3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FF3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFf3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1347368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347368.protein.info.v11.5.txt",
		        "node_list_path": "1347368.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaPersica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia persica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaPersica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1417230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1417230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1417230.protein.info.v11.5.txt",
		        "node_list_path": "1417230.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucosisporaSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucosispora sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucosisporaSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "547162.protein.sequences.v11.5.fa",
		        "enrichment_path": "547162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547162.protein.info.v11.5.txt",
		        "node_list_path": "547162.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpAa0539Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. AA0539 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpAa0539Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210045.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210045.protein.info.v11.5.txt",
		        "node_list_path": "1210045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GynuellaSunshinyiiYc6258(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gynuella sunshinyii YC6258 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GynuellaSunshinyiiYc6258", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1445510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1445510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1445510.protein.info.v11.5.txt",
		        "node_list_path": "1445510.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaConfusaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella confusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaConfusaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1127131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1127131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1127131.clusters.proteins.v11.5.txt",
		        "sequence_path": "1127131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127131.protein.info.v11.5.txt",
		        "node_list_path": "1127131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1127131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumFujikuroi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium fujikuroi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumFujikuroi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5127.protein.sequences.v11.5.fa",
		        "enrichment_path": "5127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5127.protein.info.v11.5.txt",
		        "node_list_path": "5127.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioclavaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioclava marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1915077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915077.protein.info.v11.5.txt",
		        "node_list_path": "1915077.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4013Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4013Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798384.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798384.protein.info.v11.5.txt",
		        "node_list_path": "1798384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterAntarcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterAntarcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34086.clusters.proteins.v11.5.txt",
		        "sequence_path": "34086.protein.sequences.v11.5.fa",
		        "enrichment_path": "34086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34086.protein.info.v11.5.txt",
		        "node_list_path": "34086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusAgnetis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus agnetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusAgnetis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "985762.protein.sequences.v11.5.fa",
		        "enrichment_path": "985762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985762.protein.info.v11.5.txt",
		        "node_list_path": "985762.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfonisporaThiosulfatigenesDsm11270(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonispora thiosulfatigenes DSM 11270 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonisporaThiosulfatigenesDsm11270", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "656914.protein.sequences.v11.5.fa",
		        "enrichment_path": "656914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656914.protein.info.v11.5.txt",
		        "node_list_path": "656914.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaMultivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia multivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaMultivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "395019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "395019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "395019.clusters.proteins.v11.5.txt",
		        "sequence_path": "395019.protein.sequences.v11.5.fa",
		        "enrichment_path": "395019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395019.protein.info.v11.5.txt",
		        "node_list_path": "395019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "395019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpHysCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. HYS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpHysCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1163398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1163398.clusters.proteins.v11.5.txt",
		        "sequence_path": "1163398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163398.protein.info.v11.5.txt",
		        "node_list_path": "1163398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1163398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19046(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM19046 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19046", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1460640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460640.protein.info.v11.5.txt",
		        "node_list_path": "1460640.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchaaliaRadingae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schaalia radingae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchaaliaRadingae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "131110.protein.sequences.v11.5.fa",
		        "enrichment_path": "131110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "131110.protein.info.v11.5.txt",
		        "node_list_path": "131110.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusKalixensisDsm16043(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kalixensis DSM 16043 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKalixensisDsm16043", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423763.protein.info.v11.5.txt",
		        "node_list_path": "1423763.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaShahiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia shahii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaShahiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122172.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122172.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122172.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122172.protein.info.v11.5.txt",
		        "node_list_path": "1122172.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122172.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaRubra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaRubra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348338.protein.info.v11.5.txt",
		        "node_list_path": "1348338.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirosomaSp209(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma sp. 209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaSp209", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1955701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1955701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1955701.protein.info.v11.5.txt",
		        "node_list_path": "1955701.protein.complete.v11.5.txt"
		    }
		]
    )()

def PestalotiopsisFiciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pestalotiopsis fici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PestalotiopsisFiciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "393283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "393283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "393283.clusters.proteins.v11.5.txt",
		        "sequence_path": "393283.protein.sequences.v11.5.fa",
		        "enrichment_path": "393283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393283.protein.info.v11.5.txt",
		        "node_list_path": "393283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "393283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnsiferSpTw10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. TW10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferSpTw10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1353531.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353531.protein.info.v11.5.txt",
		        "node_list_path": "1353531.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumRifcsplowo201Full4825(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFCSPLOWO2_01_FULL_48_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifcsplowo201Full4825", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797259.protein.info.v11.5.txt",
		        "node_list_path": "1797259.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumPolysaccharolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] polysaccharolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPolysaccharolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29364.clusters.proteins.v11.5.txt",
		        "sequence_path": "29364.protein.sequences.v11.5.fa",
		        "enrichment_path": "29364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29364.protein.info.v11.5.txt",
		        "node_list_path": "29364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnetospiraSpQh2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospira sp. QH-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospiraSpQh2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288970.protein.info.v11.5.txt",
		        "node_list_path": "1288970.protein.complete.v11.5.txt"
		    }
		]
    )()

def MortierellaElongataAg77(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mortierella elongata AG-77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MortierellaElongataAg77", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314771.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314771.protein.info.v11.5.txt",
		        "node_list_path": "1314771.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusBrevisNbrc100599Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus brevis NBRC100599 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusBrevisNbrc100599Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "358681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "358681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "358681.clusters.proteins.v11.5.txt",
		        "sequence_path": "358681.protein.sequences.v11.5.fa",
		        "enrichment_path": "358681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "358681.protein.info.v11.5.txt",
		        "node_list_path": "358681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "358681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphaeramiaOrbicularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaeramia orbicularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaeramiaOrbicularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "375764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "375764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "375764.clusters.proteins.v11.5.txt",
		        "sequence_path": "375764.protein.sequences.v11.5.fa",
		        "enrichment_path": "375764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375764.protein.info.v11.5.txt",
		        "node_list_path": "375764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "375764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasHaloplanktisAnt505Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis ANT505 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasHaloplanktisAnt505Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "722419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "722419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "722419.clusters.proteins.v11.5.txt",
		        "sequence_path": "722419.protein.sequences.v11.5.fa",
		        "enrichment_path": "722419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "722419.protein.info.v11.5.txt",
		        "node_list_path": "722419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "722419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag167Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:167 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag167Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262777.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262777.protein.info.v11.5.txt",
		        "node_list_path": "1262777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KingellaOralisAtcc51147Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kingella oralis ATCC 51147 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KingellaOralisAtcc51147Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "629741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "629741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "629741.clusters.proteins.v11.5.txt",
		        "sequence_path": "629741.protein.sequences.v11.5.fa",
		        "enrichment_path": "629741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "629741.protein.info.v11.5.txt",
		        "node_list_path": "629741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "629741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCapitovis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium capitovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCapitovis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121354.protein.info.v11.5.txt",
		        "node_list_path": "1121354.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionimicrobiumSpMarseilleP3275(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionimicrobium sp. Marseille-P3275 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionimicrobiumSpMarseilleP3275", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871034.protein.info.v11.5.txt",
		        "node_list_path": "1871034.protein.complete.v11.5.txt"
		    }
		]
    )()

def LampropediaCohaerensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lampropedia cohaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LampropediaCohaerensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1610491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1610491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1610491.clusters.proteins.v11.5.txt",
		        "sequence_path": "1610491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1610491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1610491.protein.info.v11.5.txt",
		        "node_list_path": "1610491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1610491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "666685.protein.sequences.v11.5.fa",
		        "enrichment_path": "666685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "666685.protein.info.v11.5.txt",
		        "node_list_path": "666685.protein.complete.v11.5.txt"
		    }
		]
    )()

def GouaniaWilldenowiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gouania willdenowi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GouaniaWilldenowiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "441366.clusters.info.v11.5.txt",
		        "cluster_tree_path": "441366.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "441366.clusters.proteins.v11.5.txt",
		        "sequence_path": "441366.protein.sequences.v11.5.fa",
		        "enrichment_path": "441366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441366.protein.info.v11.5.txt",
		        "node_list_path": "441366.cluster.nodes.v11.5.txt",
		        "edge_list_path": "441366.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AllokutzneriaAlbataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Allokutzneria albata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllokutzneriaAlbataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "211114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "211114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "211114.clusters.proteins.v11.5.txt",
		        "sequence_path": "211114.protein.sequences.v11.5.fa",
		        "enrichment_path": "211114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211114.protein.info.v11.5.txt",
		        "node_list_path": "211114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "211114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19056(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19056 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19056", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1460650.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460650.protein.info.v11.5.txt",
		        "node_list_path": "1460650.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaSpNr41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. NR 4-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpNr41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1678028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1678028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1678028.clusters.proteins.v11.5.txt",
		        "sequence_path": "1678028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678028.protein.info.v11.5.txt",
		        "node_list_path": "1678028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1678028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaSpA28lCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sp. A28L Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaSpA28lCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1036674.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1036674.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1036674.clusters.proteins.v11.5.txt",
		        "sequence_path": "1036674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036674.protein.info.v11.5.txt",
		        "node_list_path": "1036674.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1036674.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FasciolaGiganticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fasciola gigantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FasciolaGiganticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46835.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46835.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46835.clusters.proteins.v11.5.txt",
		        "sequence_path": "46835.protein.sequences.v11.5.fa",
		        "enrichment_path": "46835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46835.protein.info.v11.5.txt",
		        "node_list_path": "46835.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46835.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSericytochromatiaBacteriumS15bMn24Raac196(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sericytochromatia bacterium S15B-MN24 RAAC_196 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSericytochromatiaBacteriumS15bMn24Raac196", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1919280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1919280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1919280.protein.info.v11.5.txt",
		        "node_list_path": "1919280.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumRifcsplowo201Full4925Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFCSPLOWO2_01_FULL_49_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifcsplowo201Full4925Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797261.protein.info.v11.5.txt",
		        "node_list_path": "1797261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TistliaConsotensisUsba355(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tistlia consotensis USBA 355 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TistliaConsotensisUsba355", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "560819.protein.sequences.v11.5.fa",
		        "enrichment_path": "560819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "560819.protein.info.v11.5.txt",
		        "node_list_path": "560819.protein.complete.v11.5.txt"
		    }
		]
    )()

def KangiellaAquimarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kangiella aquimarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KangiellaAquimarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122134.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122134.protein.info.v11.5.txt",
		        "node_list_path": "1122134.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporomusaOvataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporomusa ovata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporomusaOvataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123288.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123288.protein.info.v11.5.txt",
		        "node_list_path": "1123288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ApisCeranaCerana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Apis cerana cerana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApisCeranaCerana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "94128.protein.sequences.v11.5.fa",
		        "enrichment_path": "94128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94128.protein.info.v11.5.txt",
		        "node_list_path": "94128.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumAmericanumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium americanum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumAmericanumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408224.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408224.protein.info.v11.5.txt",
		        "node_list_path": "1408224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa23813b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_38_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa23813b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618780.protein.info.v11.5.txt",
		        "node_list_path": "1618780.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonadaceaeCot184oh4590Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonadaceae COT184OH4590 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonadaceaeCot184oh4590Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1517682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1517682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1517682.clusters.proteins.v11.5.txt",
		        "sequence_path": "1517682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1517682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1517682.protein.info.v11.5.txt",
		        "node_list_path": "1517682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1517682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AllochromatiumWarmingii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Allochromatium warmingii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllochromatiumWarmingii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61595.protein.sequences.v11.5.fa",
		        "enrichment_path": "61595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61595.protein.info.v11.5.txt",
		        "node_list_path": "61595.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAmyloliquefaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAmyloliquefaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326423.protein.sequences.v11.5.fa",
		        "enrichment_path": "326423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326423.protein.info.v11.5.txt",
		        "node_list_path": "326423.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaZoodegmatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria zoodegmatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaZoodegmatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326523.protein.sequences.v11.5.fa",
		        "enrichment_path": "326523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326523.protein.info.v11.5.txt",
		        "node_list_path": "326523.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterGlacialisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter glacialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterGlacialisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1908236.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1908236.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1908236.clusters.proteins.v11.5.txt",
		        "sequence_path": "1908236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908236.protein.info.v11.5.txt",
		        "node_list_path": "1908236.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1908236.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaHominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseburia hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaHominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585394.protein.sequences.v11.5.fa",
		        "enrichment_path": "585394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585394.protein.info.v11.5.txt",
		        "node_list_path": "585394.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesNigerCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces niger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesNigerCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66373.clusters.proteins.v11.5.txt",
		        "sequence_path": "66373.protein.sequences.v11.5.fa",
		        "enrichment_path": "66373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66373.protein.info.v11.5.txt",
		        "node_list_path": "66373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag534Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:534 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag534Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263027.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263027.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263027.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263027.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263027.protein.info.v11.5.txt",
		        "node_list_path": "1263027.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263027.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizophagusIrregularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizophagusIrregularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "588596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "588596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "588596.clusters.proteins.v11.5.txt",
		        "sequence_path": "588596.protein.sequences.v11.5.fa",
		        "enrichment_path": "588596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588596.protein.info.v11.5.txt",
		        "node_list_path": "588596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "588596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusSpPkCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sp. PK Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSpPkCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "913025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "913025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "913025.clusters.proteins.v11.5.txt",
		        "sequence_path": "913025.protein.sequences.v11.5.fa",
		        "enrichment_path": "913025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913025.protein.info.v11.5.txt",
		        "node_list_path": "913025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "913025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesBouchesdurhonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces bouchesdurhonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesBouchesdurhonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852361.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852361.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852361.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852361.protein.info.v11.5.txt",
		        "node_list_path": "1852361.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852361.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycosphaerellaPini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycosphaerella pini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycosphaerellaPini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "64363.protein.sequences.v11.5.fa",
		        "enrichment_path": "64363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64363.protein.info.v11.5.txt",
		        "node_list_path": "64363.protein.complete.v11.5.txt"
		    }
		]
    )()

def FinegoldiaMagnaAtcc53516Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Finegoldia magna ATCC53516 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FinegoldiaMagnaAtcc53516Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525282.clusters.proteins.v11.5.txt",
		        "sequence_path": "525282.protein.sequences.v11.5.fa",
		        "enrichment_path": "525282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525282.protein.info.v11.5.txt",
		        "node_list_path": "525282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpongiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas spongiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpongiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117319.protein.info.v11.5.txt",
		        "node_list_path": "1117319.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerroplasmaAcidiphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferroplasma acidiphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerroplasmaAcidiphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "74969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "74969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "74969.clusters.proteins.v11.5.txt",
		        "sequence_path": "74969.protein.sequences.v11.5.fa",
		        "enrichment_path": "74969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74969.protein.info.v11.5.txt",
		        "node_list_path": "74969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "74969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PleurocapsaSpPcc7327Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pleurocapsa sp. PCC7327 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PleurocapsaSpPcc7327Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118163.clusters.proteins.v11.5.txt",
		        "sequence_path": "118163.protein.sequences.v11.5.fa",
		        "enrichment_path": "118163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118163.protein.info.v11.5.txt",
		        "node_list_path": "118163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusHarbinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus harbinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHarbinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122147.protein.info.v11.5.txt",
		        "node_list_path": "1122147.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsphigho201Full4827(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_01_FULL_48_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho201Full4827", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802115.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802115.protein.info.v11.5.txt",
		        "node_list_path": "1802115.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCellulosilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cellulosilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCellulosilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649639.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649639.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649639.clusters.proteins.v11.5.txt",
		        "sequence_path": "649639.protein.sequences.v11.5.fa",
		        "enrichment_path": "649639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649639.protein.info.v11.5.txt",
		        "node_list_path": "649639.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649639.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VagococcusTeuberiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vagococcus teuberi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VagococcusTeuberiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "519472.clusters.info.v11.5.txt",
		        "cluster_tree_path": "519472.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "519472.clusters.proteins.v11.5.txt",
		        "sequence_path": "519472.protein.sequences.v11.5.fa",
		        "enrichment_path": "519472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519472.protein.info.v11.5.txt",
		        "node_list_path": "519472.cluster.nodes.v11.5.txt",
		        "edge_list_path": "519472.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumGwa25343(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_53_43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa25343", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801841.protein.info.v11.5.txt",
		        "node_list_path": "1801841.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpJdr2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JDR2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpJdr2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "324057.protein.sequences.v11.5.fa",
		        "enrichment_path": "324057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "324057.protein.info.v11.5.txt",
		        "node_list_path": "324057.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSpIng2D1gCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. ING2-D1G Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSpIng2D1gCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1912856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1912856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1912856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1912856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912856.protein.info.v11.5.txt",
		        "node_list_path": "1912856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1912856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpMed152Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. MED152 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpMed152Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313598.clusters.proteins.v11.5.txt",
		        "sequence_path": "313598.protein.sequences.v11.5.fa",
		        "enrichment_path": "313598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313598.protein.info.v11.5.txt",
		        "node_list_path": "313598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumIndologenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium indologenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumIndologenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218103.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218103.protein.info.v11.5.txt",
		        "node_list_path": "1218103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbidosporaMongoliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbidospora mongoliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbidosporaMongoliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "688067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "688067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "688067.clusters.proteins.v11.5.txt",
		        "sequence_path": "688067.protein.sequences.v11.5.fa",
		        "enrichment_path": "688067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688067.protein.info.v11.5.txt",
		        "node_list_path": "688067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "688067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpM2012083Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. M2012083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpM2012083Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1197706.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1197706.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1197706.clusters.proteins.v11.5.txt",
		        "sequence_path": "1197706.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197706.protein.info.v11.5.txt",
		        "node_list_path": "1197706.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1197706.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaeBacteriumDg1235Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobiae bacterium DG1235 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaeBacteriumDg1235Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "382464.clusters.info.v11.5.txt",
		        "cluster_tree_path": "382464.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "382464.clusters.proteins.v11.5.txt",
		        "sequence_path": "382464.protein.sequences.v11.5.fa",
		        "enrichment_path": "382464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "382464.protein.info.v11.5.txt",
		        "node_list_path": "382464.cluster.nodes.v11.5.txt",
		        "edge_list_path": "382464.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSulfidiphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sulfidiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSulfidiphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "396588.protein.sequences.v11.5.fa",
		        "enrichment_path": "396588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396588.protein.info.v11.5.txt",
		        "node_list_path": "396588.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermanaeromonasToyohensisTobe(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermanaeromonas toyohensis ToBE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermanaeromonasToyohensisTobe", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "698762.protein.sequences.v11.5.fa",
		        "enrichment_path": "698762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698762.protein.info.v11.5.txt",
		        "node_list_path": "698762.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusBifermentansDsm20003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus bifermentans DSM 20003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBifermentansDsm20003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423726.protein.info.v11.5.txt",
		        "node_list_path": "1423726.protein.complete.v11.5.txt"
		    }
		]
    )()

def TheionarchaeaArchaeonDg701(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Theionarchaea archaeon DG-70-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheionarchaeaArchaeonDg701", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803814.protein.info.v11.5.txt",
		        "node_list_path": "1803814.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnsiferAlkalisoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer alkalisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferAlkalisoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752398.protein.info.v11.5.txt",
		        "node_list_path": "1752398.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusicatenibacterSaccharivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusicatenibacter saccharivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusicatenibacterSaccharivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150298.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150298.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150298.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150298.protein.info.v11.5.txt",
		        "node_list_path": "1150298.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150298.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisAlaskensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis alaskensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisAlaskensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "317655.clusters.info.v11.5.txt",
		        "cluster_tree_path": "317655.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "317655.clusters.proteins.v11.5.txt",
		        "sequence_path": "317655.protein.sequences.v11.5.fa",
		        "enrichment_path": "317655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317655.protein.info.v11.5.txt",
		        "node_list_path": "317655.cluster.nodes.v11.5.txt",
		        "edge_list_path": "317655.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorKristjanssonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor kristjanssonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorKristjanssonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "632335.protein.sequences.v11.5.fa",
		        "enrichment_path": "632335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632335.protein.info.v11.5.txt",
		        "node_list_path": "632335.protein.complete.v11.5.txt"
		    }
		]
    )()

def PetrotogaMobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Petrotoga mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PetrotogaMobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "403833.protein.sequences.v11.5.fa",
		        "enrichment_path": "403833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "403833.protein.info.v11.5.txt",
		        "node_list_path": "403833.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph899Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH899 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph899Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217710.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217710.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217710.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217710.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217710.protein.info.v11.5.txt",
		        "node_list_path": "1217710.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217710.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloarculaJaponica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaJaponica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227453.protein.info.v11.5.txt",
		        "node_list_path": "1227453.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumAnimalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum animalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumAnimalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "457405.protein.sequences.v11.5.fa",
		        "enrichment_path": "457405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457405.protein.info.v11.5.txt",
		        "node_list_path": "457405.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterRuberCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterRuberCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "990371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "990371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "990371.clusters.proteins.v11.5.txt",
		        "sequence_path": "990371.protein.sequences.v11.5.fa",
		        "enrichment_path": "990371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990371.protein.info.v11.5.txt",
		        "node_list_path": "990371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "990371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusCallidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus callidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusCallidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411473.protein.sequences.v11.5.fa",
		        "enrichment_path": "411473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411473.protein.info.v11.5.txt",
		        "node_list_path": "411473.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumElkaniiWsm1741(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii WSM1741 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumElkaniiWsm1741", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1038859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038859.protein.info.v11.5.txt",
		        "node_list_path": "1038859.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumLjungdahlii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium ljungdahlii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumLjungdahlii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "748727.protein.sequences.v11.5.fa",
		        "enrichment_path": "748727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748727.protein.info.v11.5.txt",
		        "node_list_path": "748727.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrdosporaColligataOc4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ordospora colligata OC4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrdosporaColligataOc4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354746.protein.info.v11.5.txt",
		        "node_list_path": "1354746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAlkalescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma alkalescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAlkalescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1188234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188234.protein.info.v11.5.txt",
		        "node_list_path": "1188234.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacteraceaeBacterium4484166Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacteraceae bacterium 4484_166 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacteraceaeBacterium4484166Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1956165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1956165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1956165.clusters.proteins.v11.5.txt",
		        "sequence_path": "1956165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1956165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1956165.protein.info.v11.5.txt",
		        "node_list_path": "1956165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1956165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacterium13220cm5510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium 13_2_20CM_55_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacterium13220cm5510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805420.protein.info.v11.5.txt",
		        "node_list_path": "1805420.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpEan1pec(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. EAN1pec graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpEan1pec", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "298653.protein.sequences.v11.5.fa",
		        "enrichment_path": "298653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "298653.protein.info.v11.5.txt",
		        "node_list_path": "298653.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaIvanoviiPam55Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria ivanovii PAM55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaIvanoviiPam55Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "881621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "881621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "881621.clusters.proteins.v11.5.txt",
		        "sequence_path": "881621.protein.sequences.v11.5.fa",
		        "enrichment_path": "881621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "881621.protein.info.v11.5.txt",
		        "node_list_path": "881621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "881621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumSpF0494Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. F0494 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumSpF0494Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203602.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203602.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203602.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203602.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203602.protein.info.v11.5.txt",
		        "node_list_path": "1203602.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203602.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumIcenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium icense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumIcenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1274631.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1274631.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1274631.clusters.proteins.v11.5.txt",
		        "sequence_path": "1274631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274631.protein.info.v11.5.txt",
		        "node_list_path": "1274631.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1274631.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa23610Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_36_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa23610Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618808.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618808.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618808.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618808.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618808.protein.info.v11.5.txt",
		        "node_list_path": "1618808.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618808.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaCanimorsusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga canimorsus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaCanimorsusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "860228.clusters.info.v11.5.txt",
		        "cluster_tree_path": "860228.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "860228.clusters.proteins.v11.5.txt",
		        "sequence_path": "860228.protein.sequences.v11.5.fa",
		        "enrichment_path": "860228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "860228.protein.info.v11.5.txt",
		        "node_list_path": "860228.cluster.nodes.v11.5.txt",
		        "edge_list_path": "860228.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalofilumOchraceumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halofilum ochraceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalofilumOchraceumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1611323.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1611323.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1611323.clusters.proteins.v11.5.txt",
		        "sequence_path": "1611323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1611323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1611323.protein.info.v11.5.txt",
		        "node_list_path": "1611323.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1611323.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasSpBiir7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas sp. BIIR7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasSpBiir7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1904462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904462.protein.info.v11.5.txt",
		        "node_list_path": "1904462.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumLactisRw25(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium lactis RW2-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumLactisRw25", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408189.protein.info.v11.5.txt",
		        "node_list_path": "1408189.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasPorphyrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas porphyrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasPorphyrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "187330.protein.sequences.v11.5.fa",
		        "enrichment_path": "187330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "187330.protein.info.v11.5.txt",
		        "node_list_path": "187330.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot149(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root149 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot149", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736473.protein.info.v11.5.txt",
		        "node_list_path": "1736473.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsplowo202Full4516Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO2_02_FULL_45_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo202Full4516Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801831.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801831.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801831.protein.info.v11.5.txt",
		        "node_list_path": "1801831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpGa0074138Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. Ga0074138 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpGa0074138Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752217.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752217.protein.info.v11.5.txt",
		        "node_list_path": "1752217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSpLeaf41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpLeaf41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736218.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736218.protein.info.v11.5.txt",
		        "node_list_path": "1736218.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesFragilisNctc9343Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis NCTC 9343 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFragilisNctc9343Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272559.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272559.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272559.clusters.proteins.v11.5.txt",
		        "sequence_path": "272559.protein.sequences.v11.5.fa",
		        "enrichment_path": "272559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272559.protein.info.v11.5.txt",
		        "node_list_path": "272559.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272559.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaJiangxiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia jiangxiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaJiangxiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206731.protein.info.v11.5.txt",
		        "node_list_path": "1206731.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumPhosphoreumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium phosphoreum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumPhosphoreumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1454202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1454202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1454202.clusters.proteins.v11.5.txt",
		        "sequence_path": "1454202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454202.protein.info.v11.5.txt",
		        "node_list_path": "1454202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1454202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryomorphaceaeBacteriumAsp1005a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium ASP10-05a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryomorphaceaeBacteriumAsp1005a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1622232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622232.protein.info.v11.5.txt",
		        "node_list_path": "1622232.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrobaculumSp1860(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum sp. 1860 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumSp1860", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1104324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104324.protein.info.v11.5.txt",
		        "node_list_path": "1104324.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichophytonEquinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton equinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichophytonEquinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "63418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "63418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "63418.clusters.proteins.v11.5.txt",
		        "sequence_path": "63418.protein.sequences.v11.5.fa",
		        "enrichment_path": "63418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63418.protein.info.v11.5.txt",
		        "node_list_path": "63418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "63418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf22816(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_28_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf22816", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619077.protein.info.v11.5.txt",
		        "node_list_path": "1619077.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThecamonasTrahensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thecamonas trahens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThecamonasTrahensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "529818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "529818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "529818.clusters.proteins.v11.5.txt",
		        "sequence_path": "529818.protein.sequences.v11.5.fa",
		        "enrichment_path": "529818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529818.protein.info.v11.5.txt",
		        "node_list_path": "529818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "529818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusSpIdoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. IDO Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusSpIdoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1539142.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1539142.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1539142.clusters.proteins.v11.5.txt",
		        "sequence_path": "1539142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1539142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1539142.protein.info.v11.5.txt",
		        "node_list_path": "1539142.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1539142.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpPcc7336Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7336 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpPcc7336Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "195250.clusters.info.v11.5.txt",
		        "cluster_tree_path": "195250.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "195250.clusters.proteins.v11.5.txt",
		        "sequence_path": "195250.protein.sequences.v11.5.fa",
		        "enrichment_path": "195250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195250.protein.info.v11.5.txt",
		        "node_list_path": "195250.cluster.nodes.v11.5.txt",
		        "edge_list_path": "195250.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWs6BacteriumOlb21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium OLB21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWs6BacteriumOlb21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617427.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617427.protein.info.v11.5.txt",
		        "node_list_path": "1617427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusAssamensisDsm18201(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus assamensis DSM 18201 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusAssamensisDsm18201", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122916.protein.info.v11.5.txt",
		        "node_list_path": "1122916.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgicolaSagamiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algicola sagamiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgicolaSagamiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120963.protein.info.v11.5.txt",
		        "node_list_path": "1120963.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5065(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5065 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5065", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463855.protein.info.v11.5.txt",
		        "node_list_path": "1463855.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyberlindneraFabianiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyberlindnera fabianii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyberlindneraFabianiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36022.clusters.proteins.v11.5.txt",
		        "sequence_path": "36022.protein.sequences.v11.5.fa",
		        "enrichment_path": "36022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36022.protein.info.v11.5.txt",
		        "node_list_path": "36022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpN324(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. N324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpN324", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703969.protein.info.v11.5.txt",
		        "node_list_path": "1703969.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaCornellensisFslF60969(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria cornellensis FSL F6-0969 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaCornellensisFslF60969", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265820.protein.info.v11.5.txt",
		        "node_list_path": "1265820.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnabaenaSp90(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anabaena sp. 90 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabaenaSp90", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46234.protein.sequences.v11.5.fa",
		        "enrichment_path": "46234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46234.protein.info.v11.5.txt",
		        "node_list_path": "46234.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoruegeriaSpSk021(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoruegeria sp. SK021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoruegeriaSpSk021", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1933035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933035.protein.info.v11.5.txt",
		        "node_list_path": "1933035.protein.complete.v11.5.txt"
		    }
		]
    )()

def DysgonomonasSpHgc4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas sp. HGC4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasSpHgc4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658009.protein.info.v11.5.txt",
		        "node_list_path": "1658009.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSp6728(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. 67-28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSp6728", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895822.protein.info.v11.5.txt",
		        "node_list_path": "1895822.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAljt(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAljt", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158146.protein.info.v11.5.txt",
		        "node_list_path": "1158146.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprococcusComes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus comes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprococcusComes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "410072.protein.sequences.v11.5.fa",
		        "enrichment_path": "410072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "410072.protein.info.v11.5.txt",
		        "node_list_path": "410072.protein.complete.v11.5.txt"
		    }
		]
    )()

def EchinococcusMultilocularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Echinococcus multilocularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EchinococcusMultilocularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6211.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6211.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6211.clusters.proteins.v11.5.txt",
		        "sequence_path": "6211.protein.sequences.v11.5.fa",
		        "enrichment_path": "6211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6211.protein.info.v11.5.txt",
		        "node_list_path": "6211.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6211.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterPersicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter persicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterPersicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930118.protein.sequences.v11.5.fa",
		        "enrichment_path": "930118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930118.protein.info.v11.5.txt",
		        "node_list_path": "930118.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylovorusSpMm2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylovorus sp. MM2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylovorusSpMm2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1848038.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1848038.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1848038.clusters.proteins.v11.5.txt",
		        "sequence_path": "1848038.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848038.protein.info.v11.5.txt",
		        "node_list_path": "1848038.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1848038.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesLincolnensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces lincolnensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesLincolnensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915.protein.info.v11.5.txt",
		        "node_list_path": "1915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag552(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:552 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag552", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263029.protein.info.v11.5.txt",
		        "node_list_path": "1263029.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalogenimonasSpWbc2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dehalogenimonas sp. WBC-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalogenimonasSpWbc2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "943347.protein.sequences.v11.5.fa",
		        "enrichment_path": "943347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "943347.protein.info.v11.5.txt",
		        "node_list_path": "943347.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydialesBacterium3826(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiales bacterium 38-26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydialesBacterium3826", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895743.protein.info.v11.5.txt",
		        "node_list_path": "1895743.protein.complete.v11.5.txt"
		    }
		]
    )()

def BranchiostomaFloridaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Branchiostoma floridae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BranchiostomaFloridaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7739.clusters.proteins.v11.5.txt",
		        "sequence_path": "7739.protein.sequences.v11.5.fa",
		        "enrichment_path": "7739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7739.protein.info.v11.5.txt",
		        "node_list_path": "7739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusSpKu2611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. KU2-6(11) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusSpKu2611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1535751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1535751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1535751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1535751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1535751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1535751.protein.info.v11.5.txt",
		        "node_list_path": "1535751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1535751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharimonasAalborgensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharimonas aalborgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharimonasAalborgensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1332188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1332188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1332188.clusters.proteins.v11.5.txt",
		        "sequence_path": "1332188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1332188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1332188.protein.info.v11.5.txt",
		        "node_list_path": "1332188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1332188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpPamc26628(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. PAMC 26628 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpPamc26628", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1484118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484118.protein.info.v11.5.txt",
		        "node_list_path": "1484118.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMastitidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium mastitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMastitidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121365.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121365.protein.info.v11.5.txt",
		        "node_list_path": "1121365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyramidobacterPiscolensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyramidobacter piscolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyramidobacterPiscolensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "352165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "352165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "352165.clusters.proteins.v11.5.txt",
		        "sequence_path": "352165.protein.sequences.v11.5.fa",
		        "enrichment_path": "352165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "352165.protein.info.v11.5.txt",
		        "node_list_path": "352165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "352165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AequorivitaVladivostokensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aequorivita vladivostokensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AequorivitaVladivostokensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "171194.protein.sequences.v11.5.fa",
		        "enrichment_path": "171194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "171194.protein.info.v11.5.txt",
		        "node_list_path": "171194.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwc2458(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_45_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc2458", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619050.protein.info.v11.5.txt",
		        "node_list_path": "1619050.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusCatalpaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus catalpae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusCatalpaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1045775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1045775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1045775.clusters.proteins.v11.5.txt",
		        "sequence_path": "1045775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045775.protein.info.v11.5.txt",
		        "node_list_path": "1045775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1045775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCamporealensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium camporealensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCamporealensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "161896.protein.sequences.v11.5.fa",
		        "enrichment_path": "161896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161896.protein.info.v11.5.txt",
		        "node_list_path": "161896.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpOralTaxon126Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpOralTaxon126Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "712528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "712528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "712528.clusters.proteins.v11.5.txt",
		        "sequence_path": "712528.protein.sequences.v11.5.fa",
		        "enrichment_path": "712528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712528.protein.info.v11.5.txt",
		        "node_list_path": "712528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "712528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeucobacterSpG161(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter sp. G161 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterSpG161", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "663704.protein.sequences.v11.5.fa",
		        "enrichment_path": "663704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663704.protein.info.v11.5.txt",
		        "node_list_path": "663704.protein.complete.v11.5.txt"
		    }
		]
    )()

def TupaiaChinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tupaia chinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TupaiaChinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246437.protein.sequences.v11.5.fa",
		        "enrichment_path": "246437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246437.protein.info.v11.5.txt",
		        "node_list_path": "246437.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesDarlingi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles darlingi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesDarlingi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43151.protein.sequences.v11.5.fa",
		        "enrichment_path": "43151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43151.protein.info.v11.5.txt",
		        "node_list_path": "43151.protein.complete.v11.5.txt"
		    }
		]
    )()

def FervidobacteriumThailandenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium thailandense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidobacteriumThailandenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1008305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1008305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1008305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1008305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1008305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1008305.protein.info.v11.5.txt",
		        "node_list_path": "1008305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1008305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu069(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU069 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu069", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671654.protein.info.v11.5.txt",
		        "node_list_path": "1671654.protein.complete.v11.5.txt"
		    }
		]
    )()

def GloeobacterKilaueensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gloeobacter kilaueensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeobacterKilaueensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1183438.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1183438.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1183438.clusters.proteins.v11.5.txt",
		        "sequence_path": "1183438.protein.sequences.v11.5.fa",
		        "enrichment_path": "1183438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1183438.protein.info.v11.5.txt",
		        "node_list_path": "1183438.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1183438.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PopulusTrichocarpaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Populus trichocarpa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PopulusTrichocarpaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3694.clusters.proteins.v11.5.txt",
		        "sequence_path": "3694.protein.sequences.v11.5.fa",
		        "enrichment_path": "3694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3694.protein.info.v11.5.txt",
		        "node_list_path": "3694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterFetus8240(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus 8240 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterFetus8240", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "360106.protein.sequences.v11.5.fa",
		        "enrichment_path": "360106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360106.protein.info.v11.5.txt",
		        "node_list_path": "360106.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwelCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWEL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwelCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896209.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896209.protein.info.v11.5.txt",
		        "node_list_path": "1896209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomonasSpDh1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas sp. DH-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasSpDh1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1727196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1727196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1727196.protein.info.v11.5.txt",
		        "node_list_path": "1727196.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807740.protein.info.v11.5.txt",
		        "node_list_path": "1807740.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaFlavescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaFlavescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "484.clusters.proteins.v11.5.txt",
		        "sequence_path": "484.protein.sequences.v11.5.fa",
		        "enrichment_path": "484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484.protein.info.v11.5.txt",
		        "node_list_path": "484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumLividumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium lividum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumLividumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29581.clusters.proteins.v11.5.txt",
		        "sequence_path": "29581.protein.sequences.v11.5.fa",
		        "enrichment_path": "29581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29581.protein.info.v11.5.txt",
		        "node_list_path": "29581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliagarivoransTaiwanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aliagarivorans taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliagarivoransTaiwanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120970.protein.info.v11.5.txt",
		        "node_list_path": "1120970.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnsiferAdhaerensOv14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer adhaerens OV14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferAdhaerensOv14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1416753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416753.protein.info.v11.5.txt",
		        "node_list_path": "1416753.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallionellalesBacteriumRifcsplowo202Full5747(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallionellales bacterium RIFCSPLOWO2_02_FULL_57_47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallionellalesBacteriumRifcsplowo202Full5747", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798254.protein.info.v11.5.txt",
		        "node_list_path": "1798254.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumAcetoxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum acetoxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumAcetoxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "485916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "485916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "485916.clusters.proteins.v11.5.txt",
		        "sequence_path": "485916.protein.sequences.v11.5.fa",
		        "enrichment_path": "485916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485916.protein.info.v11.5.txt",
		        "node_list_path": "485916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "485916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumCg1024326Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium CG1_02_43_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumCg1024326Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805421.protein.info.v11.5.txt",
		        "node_list_path": "1805421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "592050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "592050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "592050.clusters.proteins.v11.5.txt",
		        "sequence_path": "592050.protein.sequences.v11.5.fa",
		        "enrichment_path": "592050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592050.protein.info.v11.5.txt",
		        "node_list_path": "592050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "592050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioFortisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio fortis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioFortisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "212667.clusters.info.v11.5.txt",
		        "cluster_tree_path": "212667.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "212667.clusters.proteins.v11.5.txt",
		        "sequence_path": "212667.protein.sequences.v11.5.fa",
		        "enrichment_path": "212667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "212667.protein.info.v11.5.txt",
		        "node_list_path": "212667.cluster.nodes.v11.5.txt",
		        "edge_list_path": "212667.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5630(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5630", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463864.protein.info.v11.5.txt",
		        "node_list_path": "1463864.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaeBacteriumRifcsplowo212Full4520Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPLOWO2_12_FULL_45_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaeBacteriumRifcsplowo212Full4520Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797610.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797610.protein.info.v11.5.txt",
		        "node_list_path": "1797610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumRedseaS34B6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium REDSEA-S34_B6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumRedseaS34B6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811624.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811624.protein.info.v11.5.txt",
		        "node_list_path": "1811624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumVaccinii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium vaccinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumVaccinii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1108595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1108595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1108595.protein.info.v11.5.txt",
		        "node_list_path": "1108595.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSpQhl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. QHL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpQhl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123773.protein.info.v11.5.txt",
		        "node_list_path": "1123773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlaciecolaMesophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola mesophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaMesophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1128912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128912.protein.info.v11.5.txt",
		        "node_list_path": "1128912.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf33(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf33", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736215.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736215.protein.info.v11.5.txt",
		        "node_list_path": "1736215.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrunusYedoensisVarNudifloraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prunus yedoensis var. nudiflora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrunusYedoensisVarNudifloraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2094558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2094558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2094558.clusters.proteins.v11.5.txt",
		        "sequence_path": "2094558.protein.sequences.v11.5.fa",
		        "enrichment_path": "2094558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2094558.protein.info.v11.5.txt",
		        "node_list_path": "2094558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2094558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisSacchariCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisSacchariCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "115433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "115433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "115433.clusters.proteins.v11.5.txt",
		        "sequence_path": "115433.protein.sequences.v11.5.fa",
		        "enrichment_path": "115433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115433.protein.info.v11.5.txt",
		        "node_list_path": "115433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "115433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SymbiobacterMobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Symbiobacter mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SymbiobacterMobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "946483.protein.sequences.v11.5.fa",
		        "enrichment_path": "946483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946483.protein.info.v11.5.txt",
		        "node_list_path": "946483.protein.complete.v11.5.txt"
		    }
		]
    )()

def YonghaparkiaSpRoot332(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yonghaparkia sp. Root332 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YonghaparkiaSpRoot332", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736516.protein.info.v11.5.txt",
		        "node_list_path": "1736516.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExidiaGlandulosaHhb12029Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exidia glandulosa HHB12029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExidiaGlandulosaHhb12029Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314781.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314781.protein.info.v11.5.txt",
		        "node_list_path": "1314781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpLsjc280b00(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LSJC280B00 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpLsjc280b00", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1287336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287336.protein.info.v11.5.txt",
		        "node_list_path": "1287336.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterConcretionisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter concretionis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterConcretionisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122185.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122185.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122185.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122185.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122185.protein.info.v11.5.txt",
		        "node_list_path": "1122185.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122185.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpYr568Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. YR568 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpYr568Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855301.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855301.protein.info.v11.5.txt",
		        "node_list_path": "1855301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacteriumJilantaiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium jilantaiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacteriumJilantaiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "355548.protein.sequences.v11.5.fa",
		        "enrichment_path": "355548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "355548.protein.info.v11.5.txt",
		        "node_list_path": "355548.protein.complete.v11.5.txt"
		    }
		]
    )()

def AchromobacterArsenitoxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter arsenitoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterArsenitoxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "477184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "477184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "477184.clusters.proteins.v11.5.txt",
		        "sequence_path": "477184.protein.sequences.v11.5.fa",
		        "enrichment_path": "477184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477184.protein.info.v11.5.txt",
		        "node_list_path": "477184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "477184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GanodermaSinenseZz02141(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ganoderma sinense ZZ0214-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GanodermaSinenseZz02141", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1077348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077348.protein.info.v11.5.txt",
		        "node_list_path": "1077348.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesNasicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces nasicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesNasicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "208480.protein.sequences.v11.5.fa",
		        "enrichment_path": "208480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208480.protein.info.v11.5.txt",
		        "node_list_path": "208480.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeyerozymaSpJa9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meyerozyma sp. JA9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeyerozymaSpJa9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2028340.protein.sequences.v11.5.fa",
		        "enrichment_path": "2028340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2028340.protein.info.v11.5.txt",
		        "node_list_path": "2028340.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusCaccaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus caccae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusCaccaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158612.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158612.protein.info.v11.5.txt",
		        "node_list_path": "1158612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpH073Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H073 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpH073Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1759079.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1759079.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1759079.clusters.proteins.v11.5.txt",
		        "sequence_path": "1759079.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759079.protein.info.v11.5.txt",
		        "node_list_path": "1759079.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1759079.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumScgcAaa300D14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA300-D14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumScgcAaa300D14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "939696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "939696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "939696.clusters.proteins.v11.5.txt",
		        "sequence_path": "939696.protein.sequences.v11.5.fa",
		        "enrichment_path": "939696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939696.protein.info.v11.5.txt",
		        "node_list_path": "939696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "939696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElaeophoraElaphi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elaeophora elaphi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElaeophoraElaphi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1147741.protein.sequences.v11.5.fa",
		        "enrichment_path": "1147741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1147741.protein.info.v11.5.txt",
		        "node_list_path": "1147741.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterCaeni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterCaeni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "288992.protein.sequences.v11.5.fa",
		        "enrichment_path": "288992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "288992.protein.info.v11.5.txt",
		        "node_list_path": "288992.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpMit0604Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0604 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpMit0604Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1501268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1501268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1501268.clusters.proteins.v11.5.txt",
		        "sequence_path": "1501268.protein.sequences.v11.5.fa",
		        "enrichment_path": "1501268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1501268.protein.info.v11.5.txt",
		        "node_list_path": "1501268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1501268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag465Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:465 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag465Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262811.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262811.protein.info.v11.5.txt",
		        "node_list_path": "1262811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusAcidocaldariusDsm446Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius DSM446 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusAcidocaldariusDsm446Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521098.clusters.proteins.v11.5.txt",
		        "sequence_path": "521098.protein.sequences.v11.5.fa",
		        "enrichment_path": "521098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521098.protein.info.v11.5.txt",
		        "node_list_path": "521098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharospirillumImpatiensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharospirillum impatiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharospirillumImpatiensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123228.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123228.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123228.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123228.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123228.protein.info.v11.5.txt",
		        "node_list_path": "1123228.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123228.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioSpEr1aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. ER1A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpEr1aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1517681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1517681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1517681.clusters.proteins.v11.5.txt",
		        "sequence_path": "1517681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1517681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1517681.protein.info.v11.5.txt",
		        "node_list_path": "1517681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1517681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AplysiaCalifornicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aplysia californica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AplysiaCalifornicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6500.clusters.proteins.v11.5.txt",
		        "sequence_path": "6500.protein.sequences.v11.5.fa",
		        "enrichment_path": "6500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6500.protein.info.v11.5.txt",
		        "node_list_path": "6500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMandeliiPd30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mandelii PD30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMandeliiPd30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1419583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1419583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1419583.protein.info.v11.5.txt",
		        "node_list_path": "1419583.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharothrixSpNrrlb16314(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharothrix sp. NRRLB16314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharothrixSpNrrlb16314", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463825.protein.info.v11.5.txt",
		        "node_list_path": "1463825.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenoanaerobacteriumSaccharovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenoanaerobacterium saccharovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenoanaerobacteriumSaccharovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "474960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "474960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "474960.clusters.proteins.v11.5.txt",
		        "sequence_path": "474960.protein.sequences.v11.5.fa",
		        "enrichment_path": "474960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "474960.protein.info.v11.5.txt",
		        "node_list_path": "474960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "474960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumFalciparum3d7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium falciparum 3D7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumFalciparum3d7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36329.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36329.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36329.clusters.proteins.v11.5.txt",
		        "sequence_path": "36329.protein.sequences.v11.5.fa",
		        "enrichment_path": "36329.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36329.protein.info.v11.5.txt",
		        "node_list_path": "36329.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36329.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudophaeobacterLeonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudophaeobacter leonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudophaeobacterLeonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144477.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144477.protein.info.v11.5.txt",
		        "node_list_path": "1144477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh7805Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 7805 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh7805Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59931.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59931.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59931.clusters.proteins.v11.5.txt",
		        "sequence_path": "59931.protein.sequences.v11.5.fa",
		        "enrichment_path": "59931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59931.protein.info.v11.5.txt",
		        "node_list_path": "59931.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59931.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaribacterThermophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterThermophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1197874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1197874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1197874.clusters.proteins.v11.5.txt",
		        "sequence_path": "1197874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197874.protein.info.v11.5.txt",
		        "node_list_path": "1197874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1197874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBohemicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter bohemicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBohemicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217715.protein.info.v11.5.txt",
		        "node_list_path": "1217715.protein.complete.v11.5.txt"
		    }
		]
    )()

def XylanimicrobiumPachnodaeJcm13526Nbrc107786Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylanimicrobium pachnodae JCM 13526 NBRC 107786 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylanimicrobiumPachnodaeJcm13526Nbrc107786Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1305855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1305855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1305855.clusters.proteins.v11.5.txt",
		        "sequence_path": "1305855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305855.protein.info.v11.5.txt",
		        "node_list_path": "1305855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1305855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSaudimassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas saudimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSaudimassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461581.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461581.protein.info.v11.5.txt",
		        "node_list_path": "1461581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpCch5A5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. CCH5-A5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpCch5A5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1768741.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768741.protein.info.v11.5.txt",
		        "node_list_path": "1768741.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteimonasSpJ29Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas sp. J29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteimonasSpJ29Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935863.clusters.proteins.v11.5.txt",
		        "sequence_path": "935863.protein.sequences.v11.5.fa",
		        "enrichment_path": "935863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935863.protein.info.v11.5.txt",
		        "node_list_path": "935863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumGw2011Gwb1397(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWB1_39_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwb1397", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618464.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618464.protein.info.v11.5.txt",
		        "node_list_path": "1618464.protein.complete.v11.5.txt"
		    }
		]
    )()

def HoefleaOlei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hoeflea olei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoefleaOlei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1480615.protein.sequences.v11.5.fa",
		        "enrichment_path": "1480615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1480615.protein.info.v11.5.txt",
		        "node_list_path": "1480615.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735689.protein.info.v11.5.txt",
		        "node_list_path": "1735689.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumCg1023735Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium CG1_02_37_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumCg1023735Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805220.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805220.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805220.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805220.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805220.protein.info.v11.5.txt",
		        "node_list_path": "1805220.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805220.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterAalborgensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter aalborgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterAalborgensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1860102.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860102.protein.info.v11.5.txt",
		        "node_list_path": "1860102.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp360mftsu51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 360MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp360mftsu51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1172186.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172186.protein.info.v11.5.txt",
		        "node_list_path": "1172186.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoplasmatalesArchaeonEPlasmaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon E-plasma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmatalesArchaeonEPlasmaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "667137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "667137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "667137.clusters.proteins.v11.5.txt",
		        "sequence_path": "667137.protein.sequences.v11.5.fa",
		        "enrichment_path": "667137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667137.protein.info.v11.5.txt",
		        "node_list_path": "667137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "667137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaceaeBacteriumHl53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarinaceae bacterium HL-53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaceaeBacteriumHl53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298881.protein.info.v11.5.txt",
		        "node_list_path": "1298881.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlbidovulumXiamenense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Albidovulum xiamenense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlbidovulumXiamenense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "990712.protein.sequences.v11.5.fa",
		        "enrichment_path": "990712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990712.protein.info.v11.5.txt",
		        "node_list_path": "990712.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaYeatsiiGm274b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma yeatsii GM274B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaYeatsiiGm274b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743967.protein.sequences.v11.5.fa",
		        "enrichment_path": "743967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743967.protein.info.v11.5.txt",
		        "node_list_path": "743967.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpUrhb0020(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. URHB0020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpUrhb0020", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380385.protein.info.v11.5.txt",
		        "node_list_path": "1380385.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaeroglobusGeminatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaeroglobus geminatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeroglobusGeminatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "861450.clusters.info.v11.5.txt",
		        "cluster_tree_path": "861450.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "861450.clusters.proteins.v11.5.txt",
		        "sequence_path": "861450.protein.sequences.v11.5.fa",
		        "enrichment_path": "861450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861450.protein.info.v11.5.txt",
		        "node_list_path": "861450.cluster.nodes.v11.5.txt",
		        "edge_list_path": "861450.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PasteurellaDagmatisAtcc43325(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella dagmatis ATCC 43325 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaDagmatisAtcc43325", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "667128.protein.sequences.v11.5.fa",
		        "enrichment_path": "667128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667128.protein.info.v11.5.txt",
		        "node_list_path": "667128.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867004(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867004", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1659198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659198.protein.info.v11.5.txt",
		        "node_list_path": "1659198.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosopumilusAdriaticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus adriaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopumilusAdriaticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1580092.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1580092.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1580092.clusters.proteins.v11.5.txt",
		        "sequence_path": "1580092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1580092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1580092.protein.info.v11.5.txt",
		        "node_list_path": "1580092.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1580092.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MonosporascusSpMg162(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. mg162 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSpMg162", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1081914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081914.protein.info.v11.5.txt",
		        "node_list_path": "1081914.protein.complete.v11.5.txt"
		    }
		]
    )()

def AiluropodaMelanoleucaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ailuropoda melanoleuca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AiluropodaMelanoleucaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9646.clusters.proteins.v11.5.txt",
		        "sequence_path": "9646.protein.sequences.v11.5.fa",
		        "enrichment_path": "9646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9646.protein.info.v11.5.txt",
		        "node_list_path": "9646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpTtu2014080ascCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TTU2014-080ASC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpTtu2014080ascCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729724.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729724.protein.info.v11.5.txt",
		        "node_list_path": "1729724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCl6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CL6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCl6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499683.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499683.protein.info.v11.5.txt",
		        "node_list_path": "1499683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumCoe1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium COE1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumCoe1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235793.protein.info.v11.5.txt",
		        "node_list_path": "1235793.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacteralesBacteriumRifoxyb1Full6716Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacterales bacterium RIFOXYB1_FULL_67_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacteralesBacteriumRifoxyb1Full6716Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797588.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797588.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797588.protein.info.v11.5.txt",
		        "node_list_path": "1797588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRifcsplowo202Full6721(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO2_02_FULL_67_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202Full6721", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797183.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797183.protein.info.v11.5.txt",
		        "node_list_path": "1797183.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh8102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh8102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84588.protein.sequences.v11.5.fa",
		        "enrichment_path": "84588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84588.protein.info.v11.5.txt",
		        "node_list_path": "84588.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifcsplowo202Full5736Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO2_02_FULL_57_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo202Full5736Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797562.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797562.protein.info.v11.5.txt",
		        "node_list_path": "1797562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpG5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. G5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpG5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1268068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1268068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1268068.clusters.proteins.v11.5.txt",
		        "sequence_path": "1268068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268068.protein.info.v11.5.txt",
		        "node_list_path": "1268068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1268068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacteraceaeBacteriumRaap1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium RAAP-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteraceaeBacteriumRaap1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735114.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735114.protein.info.v11.5.txt",
		        "node_list_path": "1735114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusGallinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusGallinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "565653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "565653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "565653.clusters.proteins.v11.5.txt",
		        "sequence_path": "565653.protein.sequences.v11.5.fa",
		        "enrichment_path": "565653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565653.protein.info.v11.5.txt",
		        "node_list_path": "565653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "565653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag169(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:169 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag169", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262778.protein.info.v11.5.txt",
		        "node_list_path": "1262778.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesMobaraensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces mobaraensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesMobaraensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223523.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223523.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223523.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223523.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223523.protein.info.v11.5.txt",
		        "node_list_path": "1223523.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223523.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChondromycesCrocatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chondromyces crocatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChondromycesCrocatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52.protein.sequences.v11.5.fa",
		        "enrichment_path": "52.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52.protein.info.v11.5.txt",
		        "node_list_path": "52.protein.complete.v11.5.txt"
		    }
		]
    )()

def JatrophihabitansEndophyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jatrophihabitans endophyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JatrophihabitansEndophyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206085.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206085.protein.info.v11.5.txt",
		        "node_list_path": "1206085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuegeriaSpAngS4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. ANG-S4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaSpAngS4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577904.protein.info.v11.5.txt",
		        "node_list_path": "1577904.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19059Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19059Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1481929.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1481929.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1481929.clusters.proteins.v11.5.txt",
		        "sequence_path": "1481929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1481929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1481929.protein.info.v11.5.txt",
		        "node_list_path": "1481929.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1481929.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaLansingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella lansingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaLansingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122164.protein.info.v11.5.txt",
		        "node_list_path": "1122164.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpGp183Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GP183 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpGp183Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882751.protein.info.v11.5.txt",
		        "node_list_path": "1882751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaceaeBacteriumFsla50281Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeriaceae bacterium FSLA50281 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaceaeBacteriumFsla50281Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1552123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1552123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1552123.clusters.proteins.v11.5.txt",
		        "sequence_path": "1552123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1552123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1552123.protein.info.v11.5.txt",
		        "node_list_path": "1552123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1552123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumSalicisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum salicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumSalicisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1209931.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1209931.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1209931.clusters.proteins.v11.5.txt",
		        "sequence_path": "1209931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1209931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1209931.protein.info.v11.5.txt",
		        "node_list_path": "1209931.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1209931.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSolimangrovi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus solimangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSolimangrovi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1305675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305675.protein.info.v11.5.txt",
		        "node_list_path": "1305675.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf456Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf456 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf456Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736382.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736382.protein.info.v11.5.txt",
		        "node_list_path": "1736382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def Bacterium2013arg42iCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium 2013Arg42i Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Bacterium2013arg42iCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1561003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1561003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1561003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1561003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561003.protein.info.v11.5.txt",
		        "node_list_path": "1561003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1561003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensNz007Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens NZ007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensNz007Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "690597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "690597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "690597.clusters.proteins.v11.5.txt",
		        "sequence_path": "690597.protein.sequences.v11.5.fa",
		        "enrichment_path": "690597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690597.protein.info.v11.5.txt",
		        "node_list_path": "690597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "690597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WenyingzhuangiaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wenyingzhuangia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WenyingzhuangiaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1195760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1195760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1195760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1195760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1195760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1195760.protein.info.v11.5.txt",
		        "node_list_path": "1195760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1195760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSpLeaf216(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf216 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpLeaf216", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735684.protein.info.v11.5.txt",
		        "node_list_path": "1735684.protein.complete.v11.5.txt"
		    }
		]
    )()

def RivulariaSpPcc7116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rivularia sp. PCC7116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RivulariaSpPcc7116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "373994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "373994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "373994.clusters.proteins.v11.5.txt",
		        "sequence_path": "373994.protein.sequences.v11.5.fa",
		        "enrichment_path": "373994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "373994.protein.info.v11.5.txt",
		        "node_list_path": "373994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "373994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZymoseptoriaTriticiIpo323(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici IPO323 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymoseptoriaTriticiIpo323", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "336722.protein.sequences.v11.5.fa",
		        "enrichment_path": "336722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336722.protein.info.v11.5.txt",
		        "node_list_path": "336722.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermomonosporaCurvataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermomonospora curvata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermomonosporaCurvataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471852.clusters.proteins.v11.5.txt",
		        "sequence_path": "471852.protein.sequences.v11.5.fa",
		        "enrichment_path": "471852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471852.protein.info.v11.5.txt",
		        "node_list_path": "471852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermosynechococcusSpNk55aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosynechococcus sp. NK55a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosynechococcusSpNk55aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1394889.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1394889.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1394889.clusters.proteins.v11.5.txt",
		        "sequence_path": "1394889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394889.protein.info.v11.5.txt",
		        "node_list_path": "1394889.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1394889.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumOxysporumFSpRadicisCucumerinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. radicis-cucumerinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumOxysporumFSpRadicisCucumerinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "327505.protein.sequences.v11.5.fa",
		        "enrichment_path": "327505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "327505.protein.info.v11.5.txt",
		        "node_list_path": "327505.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylomicrobiumAlbum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomicrobium album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomicrobiumAlbum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "686340.protein.sequences.v11.5.fa",
		        "enrichment_path": "686340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686340.protein.info.v11.5.txt",
		        "node_list_path": "686340.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterPyloriSa213a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori SA213A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterPyloriSa213a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1345592.protein.sequences.v11.5.fa",
		        "enrichment_path": "1345592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1345592.protein.info.v11.5.txt",
		        "node_list_path": "1345592.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasWeihenstephanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas weihenstephanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasWeihenstephanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1608994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1608994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1608994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1608994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608994.protein.info.v11.5.txt",
		        "node_list_path": "1608994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1608994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifoxyd1Full4023Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD1_FULL_40_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd1Full4023Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798705.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798705.protein.info.v11.5.txt",
		        "node_list_path": "1798705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZavarzinellaFormosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zavarzinella formosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZavarzinellaFormosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123508.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123508.protein.info.v11.5.txt",
		        "node_list_path": "1123508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassotaleaCrassostreaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassotalea crassostreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassotaleaCrassostreaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1763536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1763536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1763536.clusters.proteins.v11.5.txt",
		        "sequence_path": "1763536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1763536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1763536.protein.info.v11.5.txt",
		        "node_list_path": "1763536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1763536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumAethiopicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium aethiopicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumAethiopicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1138170.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1138170.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1138170.clusters.proteins.v11.5.txt",
		        "sequence_path": "1138170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1138170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1138170.protein.info.v11.5.txt",
		        "node_list_path": "1138170.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1138170.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidiferrobacterThiooxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidiferrobacter thiooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidiferrobacterThiooxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "163359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "163359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "163359.clusters.proteins.v11.5.txt",
		        "sequence_path": "163359.protein.sequences.v11.5.fa",
		        "enrichment_path": "163359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "163359.protein.info.v11.5.txt",
		        "node_list_path": "163359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "163359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaConcitansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia concitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaConcitansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777133.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777133.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777133.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777133.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777133.protein.info.v11.5.txt",
		        "node_list_path": "1777133.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777133.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacterLongobardus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter longobardus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterLongobardus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1108812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1108812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1108812.protein.info.v11.5.txt",
		        "node_list_path": "1108812.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSubterraneumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium subterraneum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSubterraneumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "48936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "48936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "48936.clusters.proteins.v11.5.txt",
		        "sequence_path": "48936.protein.sequences.v11.5.fa",
		        "enrichment_path": "48936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48936.protein.info.v11.5.txt",
		        "node_list_path": "48936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "48936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumPhoceensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium phoceensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPhoceensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1650661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1650661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1650661.clusters.proteins.v11.5.txt",
		        "sequence_path": "1650661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1650661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1650661.protein.info.v11.5.txt",
		        "node_list_path": "1650661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1650661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp3j1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 3J1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp3j1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "861269.protein.sequences.v11.5.fa",
		        "enrichment_path": "861269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861269.protein.info.v11.5.txt",
		        "node_list_path": "861269.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpHmsc08h08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. HMSC08H08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpHmsc08h08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1581143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581143.protein.info.v11.5.txt",
		        "node_list_path": "1581143.protein.complete.v11.5.txt"
		    }
		]
    )()

def SeinonellaPeptonophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Seinonella peptonophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SeinonellaPeptonophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "112248.clusters.info.v11.5.txt",
		        "cluster_tree_path": "112248.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "112248.clusters.proteins.v11.5.txt",
		        "sequence_path": "112248.protein.sequences.v11.5.fa",
		        "enrichment_path": "112248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112248.protein.info.v11.5.txt",
		        "node_list_path": "112248.cluster.nodes.v11.5.txt",
		        "edge_list_path": "112248.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronococcusAmylolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronococcus amylolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronococcusAmylolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227497.protein.info.v11.5.txt",
		        "node_list_path": "1227497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterSpFy07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter sp. FY-07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterSpFy07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1692238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1692238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1692238.clusters.proteins.v11.5.txt",
		        "sequence_path": "1692238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1692238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1692238.protein.info.v11.5.txt",
		        "node_list_path": "1692238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1692238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpWsm1743Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM1743 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpWsm1743Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "318996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "318996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "318996.clusters.proteins.v11.5.txt",
		        "sequence_path": "318996.protein.sequences.v11.5.fa",
		        "enrichment_path": "318996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318996.protein.info.v11.5.txt",
		        "node_list_path": "318996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "318996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonasAquatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasAquatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219031.protein.info.v11.5.txt",
		        "node_list_path": "1219031.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumLitoraleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium litorale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumLitoraleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122201.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122201.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122201.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122201.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122201.protein.info.v11.5.txt",
		        "node_list_path": "1122201.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122201.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TenacibaculumSpMar201089(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. MAR_2010_89 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumSpMar201089", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1250198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250198.protein.info.v11.5.txt",
		        "node_list_path": "1250198.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaOulorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oulorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOulorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28136.protein.sequences.v11.5.fa",
		        "enrichment_path": "28136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28136.protein.info.v11.5.txt",
		        "node_list_path": "28136.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaProwazekii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia prowazekii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaProwazekii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272947.protein.sequences.v11.5.fa",
		        "enrichment_path": "272947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272947.protein.info.v11.5.txt",
		        "node_list_path": "272947.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarboxydothermusPertinax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carboxydothermus pertinax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarboxydothermusPertinax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "870242.protein.sequences.v11.5.fa",
		        "enrichment_path": "870242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "870242.protein.info.v11.5.txt",
		        "node_list_path": "870242.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgarivoransGilvus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agarivorans gilvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgarivoransGilvus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "680279.protein.sequences.v11.5.fa",
		        "enrichment_path": "680279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "680279.protein.info.v11.5.txt",
		        "node_list_path": "680279.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumVe20214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumVe20214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232452.protein.info.v11.5.txt",
		        "node_list_path": "1232452.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpIhbb10380Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. IHBB 10380 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpIhbb10380Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566358.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566358.protein.info.v11.5.txt",
		        "node_list_path": "1566358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag927(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:927 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag927", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262753.protein.info.v11.5.txt",
		        "node_list_path": "1262753.protein.complete.v11.5.txt"
		    }
		]
    )()

def MuribacterMurisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Muribacter muris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuribacterMurisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67855.clusters.proteins.v11.5.txt",
		        "sequence_path": "67855.protein.sequences.v11.5.fa",
		        "enrichment_path": "67855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67855.protein.info.v11.5.txt",
		        "node_list_path": "67855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiumSp3cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. 3C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiumSp3cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1134055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1134055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1134055.clusters.proteins.v11.5.txt",
		        "sequence_path": "1134055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134055.protein.info.v11.5.txt",
		        "node_list_path": "1134055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1134055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirosomaPanaciterrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma panaciterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaPanaciterrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123277.protein.info.v11.5.txt",
		        "node_list_path": "1123277.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonCaspThauma4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon casp-thauma4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonCaspThauma4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1661714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661714.protein.info.v11.5.txt",
		        "node_list_path": "1661714.protein.complete.v11.5.txt"
		    }
		]
    )()

def GramellaSpMar2010102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gramella sp. MAR_2010_102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaSpMar2010102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1250231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250231.protein.info.v11.5.txt",
		        "node_list_path": "1250231.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnoanaerobaculumSaburreumDsm3986(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum DSM3986 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoanaerobaculumSaburreumDsm3986", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "887325.protein.sequences.v11.5.fa",
		        "enrichment_path": "887325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "887325.protein.info.v11.5.txt",
		        "node_list_path": "887325.protein.complete.v11.5.txt"
		    }
		]
    )()

def CongregibacterLitoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Congregibacter litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CongregibacterLitoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314285.clusters.proteins.v11.5.txt",
		        "sequence_path": "314285.protein.sequences.v11.5.fa",
		        "enrichment_path": "314285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314285.protein.info.v11.5.txt",
		        "node_list_path": "314285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprobacillusCateniformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus cateniformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprobacillusCateniformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "100884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "100884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "100884.clusters.proteins.v11.5.txt",
		        "sequence_path": "100884.protein.sequences.v11.5.fa",
		        "enrichment_path": "100884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "100884.protein.info.v11.5.txt",
		        "node_list_path": "100884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "100884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumUniformeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium uniforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumUniformeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39495.clusters.proteins.v11.5.txt",
		        "sequence_path": "39495.protein.sequences.v11.5.fa",
		        "enrichment_path": "39495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39495.protein.info.v11.5.txt",
		        "node_list_path": "39495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasHydrophilaYl17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila YL17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasHydrophilaYl17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1448139.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1448139.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1448139.clusters.proteins.v11.5.txt",
		        "sequence_path": "1448139.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448139.protein.info.v11.5.txt",
		        "node_list_path": "1448139.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1448139.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpBjgmmb45(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. BJGMMB45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpBjgmmb45", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1178482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1178482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1178482.protein.info.v11.5.txt",
		        "node_list_path": "1178482.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMp13118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MP131-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMp13118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1857892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1857892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1857892.protein.info.v11.5.txt",
		        "node_list_path": "1857892.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaProfundiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria profundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaProfundiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1685378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1685378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1685378.clusters.proteins.v11.5.txt",
		        "sequence_path": "1685378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685378.protein.info.v11.5.txt",
		        "node_list_path": "1685378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1685378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XylellaFastidiosa9a5c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xylella fastidiosa 9a5c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylellaFastidiosa9a5c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "160492.protein.sequences.v11.5.fa",
		        "enrichment_path": "160492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "160492.protein.info.v11.5.txt",
		        "node_list_path": "160492.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellvibrioSpOa2007Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio sp. OA-2007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioSpOa2007Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "529823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "529823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "529823.clusters.proteins.v11.5.txt",
		        "sequence_path": "529823.protein.sequences.v11.5.fa",
		        "enrichment_path": "529823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529823.protein.info.v11.5.txt",
		        "node_list_path": "529823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "529823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiCft073Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli CFT073 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiCft073Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "199310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "199310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "199310.clusters.proteins.v11.5.txt",
		        "sequence_path": "199310.protein.sequences.v11.5.fa",
		        "enrichment_path": "199310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "199310.protein.info.v11.5.txt",
		        "node_list_path": "199310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "199310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentibacillusAmyloliquefaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus amyloliquefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentibacillusAmyloliquefaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1472767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1472767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1472767.clusters.proteins.v11.5.txt",
		        "sequence_path": "1472767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1472767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1472767.protein.info.v11.5.txt",
		        "node_list_path": "1472767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1472767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpRoot52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Root52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpRoot52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736552.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736552.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736552.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736552.protein.info.v11.5.txt",
		        "node_list_path": "1736552.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736552.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraNicotianae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora nicotianae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraNicotianae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4790.protein.sequences.v11.5.fa",
		        "enrichment_path": "4790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4790.protein.info.v11.5.txt",
		        "node_list_path": "4790.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharothrixEspanaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharothrix espanaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharothrixEspanaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1179773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179773.protein.info.v11.5.txt",
		        "node_list_path": "1179773.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusThioglobusSingularisPs1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus singularis PS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThioglobusSingularisPs1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125411.protein.info.v11.5.txt",
		        "node_list_path": "1125411.protein.complete.v11.5.txt"
		    }
		]
    )()

def LutibacterSpLpb0138(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lutibacter sp. LPB0138 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutibacterSpLpb0138", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1850246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850246.protein.info.v11.5.txt",
		        "node_list_path": "1850246.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseatelesSpYr242Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseateles sp. YR242 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseatelesSpYr242Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855305.protein.info.v11.5.txt",
		        "node_list_path": "1855305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaTyphiStrB9991cwpp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia typhi str. B9991CWPP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaTyphiStrB9991cwpp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1003202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1003202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1003202.protein.info.v11.5.txt",
		        "node_list_path": "1003202.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensNcimb11764Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens NCIMB11764 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensNcimb11764Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1221522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1221522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1221522.clusters.proteins.v11.5.txt",
		        "sequence_path": "1221522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1221522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1221522.protein.info.v11.5.txt",
		        "node_list_path": "1221522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1221522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalipigerProfundus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salipiger profundus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalipigerProfundus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229727.protein.info.v11.5.txt",
		        "node_list_path": "1229727.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusSpOk042Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus sp. OK042 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusSpOk042Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884381.protein.info.v11.5.txt",
		        "node_list_path": "1884381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMendocinaNk01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina NK01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMendocinaNk01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1001585.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001585.protein.info.v11.5.txt",
		        "node_list_path": "1001585.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg2303621(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_36_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2303621", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805315.protein.info.v11.5.txt",
		        "node_list_path": "1805315.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaSpWwm596Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina sp. WWM596 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaSpWwm596Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434103.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434103.protein.info.v11.5.txt",
		        "node_list_path": "1434103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCb03911Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB03911 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCb03911Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1804758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1804758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1804758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1804758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1804758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1804758.protein.info.v11.5.txt",
		        "node_list_path": "1804758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1804758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaWeihenstephanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria weihenstephanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaWeihenstephanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265845.protein.info.v11.5.txt",
		        "node_list_path": "1265845.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloarchaeobiusIranensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloarchaeobius iranensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarchaeobiusIranensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "996166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "996166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "996166.clusters.proteins.v11.5.txt",
		        "sequence_path": "996166.protein.sequences.v11.5.fa",
		        "enrichment_path": "996166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "996166.protein.info.v11.5.txt",
		        "node_list_path": "996166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "996166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudochrobactrumSpB5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudochrobactrum sp. B5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudochrobactrumSpB5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1289478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1289478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1289478.clusters.proteins.v11.5.txt",
		        "sequence_path": "1289478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1289478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1289478.protein.info.v11.5.txt",
		        "node_list_path": "1289478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1289478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifoxyd2Full369(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFOXYD2_FULL_36_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifoxyd2Full369", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802338.protein.info.v11.5.txt",
		        "node_list_path": "1802338.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureobasidiumMelanogenumCbs110374(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium melanogenum CBS 110374 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureobasidiumMelanogenumCbs110374", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1043003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1043003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1043003.protein.info.v11.5.txt",
		        "node_list_path": "1043003.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasRuminantiumAtcc12561(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium ATCC12561 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasRuminantiumAtcc12561", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280706.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280706.protein.info.v11.5.txt",
		        "node_list_path": "1280706.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaAfzeliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia afzelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaAfzeliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "390236.clusters.info.v11.5.txt",
		        "cluster_tree_path": "390236.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "390236.clusters.proteins.v11.5.txt",
		        "sequence_path": "390236.protein.sequences.v11.5.fa",
		        "enrichment_path": "390236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390236.protein.info.v11.5.txt",
		        "node_list_path": "390236.cluster.nodes.v11.5.txt",
		        "edge_list_path": "390236.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichobilharziaRegenti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichobilharzia regenti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichobilharziaRegenti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "157069.protein.sequences.v11.5.fa",
		        "enrichment_path": "157069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157069.protein.info.v11.5.txt",
		        "node_list_path": "157069.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtopobiumSpBv3ac4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. BV3Ac4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumSpBv3ac4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111121.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111121.protein.info.v11.5.txt",
		        "node_list_path": "1111121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumGwc2579(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWC2_57_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumGwc2579", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801698.protein.info.v11.5.txt",
		        "node_list_path": "1801698.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanococcusPlakortidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planococcus plakortidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusPlakortidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1038856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1038856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1038856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1038856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038856.protein.info.v11.5.txt",
		        "node_list_path": "1038856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1038856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicoccusQingdaonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus qingdaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusQingdaonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "576118.clusters.info.v11.5.txt",
		        "cluster_tree_path": "576118.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "576118.clusters.proteins.v11.5.txt",
		        "sequence_path": "576118.protein.sequences.v11.5.fa",
		        "enrichment_path": "576118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "576118.protein.info.v11.5.txt",
		        "node_list_path": "576118.cluster.nodes.v11.5.txt",
		        "edge_list_path": "576118.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpRoot133Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. Root133 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpRoot133Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736455.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736455.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736455.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736455.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736455.protein.info.v11.5.txt",
		        "node_list_path": "1736455.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736455.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichoplaxAdhaerensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoplax adhaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichoplaxAdhaerensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10228.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10228.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10228.clusters.proteins.v11.5.txt",
		        "sequence_path": "10228.protein.sequences.v11.5.fa",
		        "enrichment_path": "10228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10228.protein.info.v11.5.txt",
		        "node_list_path": "10228.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10228.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumCoprostanoligenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium coprostanoligenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumCoprostanoligenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290054.protein.sequences.v11.5.fa",
		        "enrichment_path": "290054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290054.protein.info.v11.5.txt",
		        "node_list_path": "290054.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwh6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWH6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwh6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896212.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896212.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896212.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896212.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896212.protein.info.v11.5.txt",
		        "node_list_path": "1896212.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896212.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaHackeliaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella hackeliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaHackeliaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "449.clusters.info.v11.5.txt",
		        "cluster_tree_path": "449.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "449.clusters.proteins.v11.5.txt",
		        "sequence_path": "449.protein.sequences.v11.5.fa",
		        "enrichment_path": "449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "449.protein.info.v11.5.txt",
		        "node_list_path": "449.cluster.nodes.v11.5.txt",
		        "edge_list_path": "449.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSp4081Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 40-81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSp4081Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896169.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896169.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896169.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896169.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896169.protein.info.v11.5.txt",
		        "node_list_path": "1896169.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896169.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674845.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674845.protein.info.v11.5.txt",
		        "node_list_path": "1674845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinagarivoransAlgicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinagarivorans algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinagarivoransAlgicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1513270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1513270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1513270.protein.info.v11.5.txt",
		        "node_list_path": "1513270.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumStellenboschense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium stellenboschense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumStellenboschense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762211.protein.sequences.v11.5.fa",
		        "enrichment_path": "762211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762211.protein.info.v11.5.txt",
		        "node_list_path": "762211.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasHydrophilaAtcc7966Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila ATCC7966 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasHydrophilaAtcc7966Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "380703.clusters.info.v11.5.txt",
		        "cluster_tree_path": "380703.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "380703.clusters.proteins.v11.5.txt",
		        "sequence_path": "380703.protein.sequences.v11.5.fa",
		        "enrichment_path": "380703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380703.protein.info.v11.5.txt",
		        "node_list_path": "380703.cluster.nodes.v11.5.txt",
		        "edge_list_path": "380703.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSimiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium simiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSimiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1784.protein.info.v11.5.txt",
		        "node_list_path": "1784.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674850.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674850.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674850.protein.info.v11.5.txt",
		        "node_list_path": "1674850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinoplanesSpN902109(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes sp. N902109 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesSpN902109", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649831.protein.sequences.v11.5.fa",
		        "enrichment_path": "649831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649831.protein.info.v11.5.txt",
		        "node_list_path": "649831.protein.complete.v11.5.txt"
		    }
		]
    )()

def OvisAriesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ovis aries Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OvisAriesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9940.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9940.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9940.clusters.proteins.v11.5.txt",
		        "sequence_path": "9940.protein.sequences.v11.5.fa",
		        "enrichment_path": "9940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9940.protein.info.v11.5.txt",
		        "node_list_path": "9940.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9940.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaprolegniaParasiticaCbs22365Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saprolegnia parasitica CBS 223.65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaprolegniaParasiticaCbs22365Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "695850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "695850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "695850.clusters.proteins.v11.5.txt",
		        "sequence_path": "695850.protein.sequences.v11.5.fa",
		        "enrichment_path": "695850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "695850.protein.info.v11.5.txt",
		        "node_list_path": "695850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "695850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCt34(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CT34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCt34", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1553907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1553907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1553907.protein.info.v11.5.txt",
		        "node_list_path": "1553907.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaSpLc238(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. LC238 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpLc238", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502852.protein.info.v11.5.txt",
		        "node_list_path": "1502852.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumParmenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium parmense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumParmenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "185642.clusters.info.v11.5.txt",
		        "cluster_tree_path": "185642.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "185642.clusters.proteins.v11.5.txt",
		        "sequence_path": "185642.protein.sequences.v11.5.fa",
		        "enrichment_path": "185642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "185642.protein.info.v11.5.txt",
		        "node_list_path": "185642.cluster.nodes.v11.5.txt",
		        "edge_list_path": "185642.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaHofstadii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia hofstadii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaHofstadii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634994.protein.sequences.v11.5.fa",
		        "enrichment_path": "634994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634994.protein.info.v11.5.txt",
		        "node_list_path": "634994.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyunsoonleellaJejuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyunsoonleella jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyunsoonleellaJejuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "419940.clusters.info.v11.5.txt",
		        "cluster_tree_path": "419940.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "419940.clusters.proteins.v11.5.txt",
		        "sequence_path": "419940.protein.sequences.v11.5.fa",
		        "enrichment_path": "419940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419940.protein.info.v11.5.txt",
		        "node_list_path": "419940.cluster.nodes.v11.5.txt",
		        "edge_list_path": "419940.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusShapirobacteriaBacteriumGw2011Gwe23830(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium GW2011_GWE2_38_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusShapirobacteriaBacteriumGw2011Gwe23830", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618490.protein.info.v11.5.txt",
		        "node_list_path": "1618490.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaSpTw09308(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia sp. TW09308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaSpTw09308", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "754331.protein.sequences.v11.5.fa",
		        "enrichment_path": "754331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754331.protein.info.v11.5.txt",
		        "node_list_path": "754331.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusVersicolorCbs58365Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus versicolor CBS 583.65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusVersicolorCbs58365Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1036611.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1036611.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1036611.clusters.proteins.v11.5.txt",
		        "sequence_path": "1036611.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036611.protein.info.v11.5.txt",
		        "node_list_path": "1036611.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1036611.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurvibacterDelicatusNbrc14919(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter delicatus NBRC 14919 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurvibacterDelicatusNbrc14919", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349763.protein.info.v11.5.txt",
		        "node_list_path": "1349763.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfococcusMultivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfococcus multivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfococcusMultivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121405.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121405.protein.info.v11.5.txt",
		        "node_list_path": "1121405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaZhejiangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia zhejiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaZhejiangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "871203.clusters.info.v11.5.txt",
		        "cluster_tree_path": "871203.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "871203.clusters.proteins.v11.5.txt",
		        "sequence_path": "871203.protein.sequences.v11.5.fa",
		        "enrichment_path": "871203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871203.protein.info.v11.5.txt",
		        "node_list_path": "871203.cluster.nodes.v11.5.txt",
		        "edge_list_path": "871203.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumGp1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium GP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumGp1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807745.protein.info.v11.5.txt",
		        "node_list_path": "1807745.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimimonasHalophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limimonas halophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimimonasHalophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1082479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1082479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1082479.protein.info.v11.5.txt",
		        "node_list_path": "1082479.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisMediterraneiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis mediterranei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisMediterraneiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "749927.clusters.info.v11.5.txt",
		        "cluster_tree_path": "749927.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "749927.clusters.proteins.v11.5.txt",
		        "sequence_path": "749927.protein.sequences.v11.5.fa",
		        "enrichment_path": "749927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "749927.protein.info.v11.5.txt",
		        "node_list_path": "749927.cluster.nodes.v11.5.txt",
		        "edge_list_path": "749927.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriDsm10701Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri DSM10701 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriDsm10701Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123519.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123519.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123519.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123519.protein.info.v11.5.txt",
		        "node_list_path": "1123519.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123519.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwc24220Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWC2_42_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwc24220Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618756.protein.info.v11.5.txt",
		        "node_list_path": "1618756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumTepidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tepidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTepidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1962263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1962263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1962263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1962263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1962263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1962263.protein.info.v11.5.txt",
		        "node_list_path": "1962263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1962263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumTaibaishanenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium taibaishanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumTaibaishanenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "887144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "887144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "887144.clusters.proteins.v11.5.txt",
		        "sequence_path": "887144.protein.sequences.v11.5.fa",
		        "enrichment_path": "887144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "887144.protein.info.v11.5.txt",
		        "node_list_path": "887144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "887144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoflavibacterZeaxanthS86(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanth. S86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "MesoflavibacterZeaxanthS86", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1004149.protein.sequences.v11.0.fa",
		        "enrichment_path": "1004149.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1004149.protein.info.v11.0.txt",
		        "node_list_path": "1004149.protein.complete.v11.0.txt"
		    }
		]
    )()

def TerrapeneCarolinaTriunguis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terrapene carolina triunguis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrapeneCarolinaTriunguis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2587831.protein.sequences.v11.5.fa",
		        "enrichment_path": "2587831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2587831.protein.info.v11.5.txt",
		        "node_list_path": "2587831.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetrasphaeraAustraliensisBen110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera australiensis Ben110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrasphaeraAustraliensisBen110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193182.protein.info.v11.5.txt",
		        "node_list_path": "1193182.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSpLeaf420Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. Leaf420 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpLeaf420Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736374.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736374.protein.info.v11.5.txt",
		        "node_list_path": "1736374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusOdysseyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus odysseyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusOdysseyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220589.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220589.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220589.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220589.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220589.protein.info.v11.5.txt",
		        "node_list_path": "1220589.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220589.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRoot53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRoot53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736553.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736553.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736553.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736553.protein.info.v11.5.txt",
		        "node_list_path": "1736553.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736553.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaYeatsii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma yeatsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaYeatsii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1188240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188240.protein.info.v11.5.txt",
		        "node_list_path": "1188240.protein.complete.v11.5.txt"
		    }
		]
    )()

def HahellaGanghwensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hahella ganghwensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HahellaGanghwensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121935.protein.info.v11.5.txt",
		        "node_list_path": "1121935.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermosediminibacterOceaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosediminibacter oceani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosediminibacterOceaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "555079.clusters.info.v11.5.txt",
		        "cluster_tree_path": "555079.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "555079.clusters.proteins.v11.5.txt",
		        "sequence_path": "555079.protein.sequences.v11.5.fa",
		        "enrichment_path": "555079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555079.protein.info.v11.5.txt",
		        "node_list_path": "555079.cluster.nodes.v11.5.txt",
		        "edge_list_path": "555079.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph298(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH 298 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph298", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217692.protein.info.v11.5.txt",
		        "node_list_path": "1217692.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterNicotinovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter nicotinovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterNicotinovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304876.protein.info.v11.5.txt",
		        "node_list_path": "1304876.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPolysaccharolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polysaccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPolysaccharolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582692.clusters.proteins.v11.5.txt",
		        "sequence_path": "582692.protein.sequences.v11.5.fa",
		        "enrichment_path": "582692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582692.protein.info.v11.5.txt",
		        "node_list_path": "582692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusDurans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus durans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusDurans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1140001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1140001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1140001.protein.info.v11.5.txt",
		        "node_list_path": "1140001.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomicrobiumMukohataeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomicrobium mukohataei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomicrobiumMukohataeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "485914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "485914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "485914.clusters.proteins.v11.5.txt",
		        "sequence_path": "485914.protein.sequences.v11.5.fa",
		        "enrichment_path": "485914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485914.protein.info.v11.5.txt",
		        "node_list_path": "485914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "485914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3811Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_38_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3811Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798278.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798278.protein.info.v11.5.txt",
		        "node_list_path": "1798278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraMeyeriSerovarHardjoStrWent5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira meyeri serovar Hardjo str. Went 5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraMeyeriSerovarHardjoStrWent5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193051.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193051.protein.info.v11.5.txt",
		        "node_list_path": "1193051.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasMacleodiiBlackCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Black Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasMacleodiiBlackCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1004785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1004785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1004785.clusters.proteins.v11.5.txt",
		        "sequence_path": "1004785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004785.protein.info.v11.5.txt",
		        "node_list_path": "1004785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1004785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE2699Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2699 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE2699Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834137.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834137.protein.info.v11.5.txt",
		        "node_list_path": "1834137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesPombe(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces pombe graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesPombe", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4896.protein.sequences.v11.5.fa",
		        "enrichment_path": "4896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4896.protein.info.v11.5.txt",
		        "node_list_path": "4896.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasLuteaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas lutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasLuteaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243924.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243924.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243924.clusters.proteins.v11.5.txt",
		        "sequence_path": "243924.protein.sequences.v11.5.fa",
		        "enrichment_path": "243924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243924.protein.info.v11.5.txt",
		        "node_list_path": "243924.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243924.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpF0108Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpF0108Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575615.clusters.proteins.v11.5.txt",
		        "sequence_path": "575615.protein.sequences.v11.5.fa",
		        "enrichment_path": "575615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575615.protein.info.v11.5.txt",
		        "node_list_path": "575615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasYangmingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas yangmingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasYangmingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720063.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720063.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720063.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720063.protein.info.v11.5.txt",
		        "node_list_path": "1720063.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720063.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalimonasAmylolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalimonas amylolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalimonasAmylolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "152573.protein.sequences.v11.5.fa",
		        "enrichment_path": "152573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "152573.protein.info.v11.5.txt",
		        "node_list_path": "152573.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpCag318Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. CAG:318 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpCag318Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262761.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262761.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262761.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262761.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262761.protein.info.v11.5.txt",
		        "node_list_path": "1262761.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262761.protein.cluster.v11.5.txt"
		    }
		]
    )()

def Bacterium3363(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium 336/3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Bacterium3363", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1664068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1664068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1664068.protein.info.v11.5.txt",
		        "node_list_path": "1664068.protein.complete.v11.5.txt"
		    }
		]
    )()

def TardiphagaSpOk245Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tardiphaga sp. OK245 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TardiphagaSpOk245Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855306.protein.info.v11.5.txt",
		        "node_list_path": "1855306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumInnocuumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium innocuum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumInnocuumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999413.clusters.proteins.v11.5.txt",
		        "sequence_path": "999413.protein.sequences.v11.5.fa",
		        "enrichment_path": "999413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999413.protein.info.v11.5.txt",
		        "node_list_path": "999413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf23548Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_35_48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf23548Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797343.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797343.protein.info.v11.5.txt",
		        "node_list_path": "1797343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycesSpShPl14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces sp. SH-PL14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycesSpShPl14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1632864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1632864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1632864.protein.info.v11.5.txt",
		        "node_list_path": "1632864.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocGelidumJb7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum JB7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocGelidumJb7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229756.protein.info.v11.5.txt",
		        "node_list_path": "1229756.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlwc3773(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3773 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlwc3773", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463936.protein.info.v11.5.txt",
		        "node_list_path": "1463936.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyxococcusStipitatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus stipitatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcusStipitatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278073.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278073.protein.info.v11.5.txt",
		        "node_list_path": "1278073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyclobacteriumAmurskyenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacterium amurskyense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyclobacteriumAmurskyenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "320787.clusters.info.v11.5.txt",
		        "cluster_tree_path": "320787.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "320787.clusters.proteins.v11.5.txt",
		        "sequence_path": "320787.protein.sequences.v11.5.fa",
		        "enrichment_path": "320787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "320787.protein.info.v11.5.txt",
		        "node_list_path": "320787.cluster.nodes.v11.5.txt",
		        "edge_list_path": "320787.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphibacillusXylanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amphibacillus xylanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphibacillusXylanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "698758.protein.sequences.v11.5.fa",
		        "enrichment_path": "698758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698758.protein.info.v11.5.txt",
		        "node_list_path": "698758.protein.complete.v11.5.txt"
		    }
		]
    )()

def RachicladosporiumSpCcfee5018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rachicladosporium sp. CCFEE 5018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RachicladosporiumSpCcfee5018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1974281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1974281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1974281.clusters.proteins.v11.5.txt",
		        "sequence_path": "1974281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1974281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1974281.protein.info.v11.5.txt",
		        "node_list_path": "1974281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1974281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasElodea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas elodea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasElodea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1081640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081640.protein.info.v11.5.txt",
		        "node_list_path": "1081640.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaSalsinemorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina salsinemoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSalsinemorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "577470.clusters.info.v11.5.txt",
		        "cluster_tree_path": "577470.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "577470.clusters.proteins.v11.5.txt",
		        "sequence_path": "577470.protein.sequences.v11.5.fa",
		        "enrichment_path": "577470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "577470.protein.info.v11.5.txt",
		        "node_list_path": "577470.cluster.nodes.v11.5.txt",
		        "edge_list_path": "577470.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedFlavonifractorSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Flavonifractor sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedFlavonifractorSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193534.protein.info.v11.5.txt",
		        "node_list_path": "1193534.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpYr459Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR459 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpYr459Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500292.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500292.protein.info.v11.5.txt",
		        "node_list_path": "1500292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85201351886Sch5428379Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852013-51886_SCH5428379 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85201351886Sch5428379Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834111.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834111.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834111.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834111.protein.info.v11.5.txt",
		        "node_list_path": "1834111.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834111.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaAmniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella amnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaAmniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679191.clusters.proteins.v11.5.txt",
		        "sequence_path": "679191.protein.sequences.v11.5.fa",
		        "enrichment_path": "679191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679191.protein.info.v11.5.txt",
		        "node_list_path": "679191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SutterellaSpCag521Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sutterella sp. CAG:521 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SutterellaSpCag521Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262977.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262977.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262977.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262977.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262977.protein.info.v11.5.txt",
		        "node_list_path": "1262977.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262977.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwe13724Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_37_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe13724Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618709.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618709.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618709.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618709.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618709.protein.info.v11.5.txt",
		        "node_list_path": "1618709.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618709.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumJdfr78(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr78", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935108.protein.info.v11.5.txt",
		        "node_list_path": "1935108.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaPsychrerythraea34hCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia psychrerythraea 34H Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaPsychrerythraea34hCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "167879.clusters.info.v11.5.txt",
		        "cluster_tree_path": "167879.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "167879.clusters.proteins.v11.5.txt",
		        "sequence_path": "167879.protein.sequences.v11.5.fa",
		        "enrichment_path": "167879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167879.protein.info.v11.5.txt",
		        "node_list_path": "167879.cluster.nodes.v11.5.txt",
		        "edge_list_path": "167879.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumTumefaciensF2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens F2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumTumefaciensF2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1050720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1050720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1050720.protein.info.v11.5.txt",
		        "node_list_path": "1050720.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychroflexusSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychroflexus sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroflexusSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "470826.protein.sequences.v11.5.fa",
		        "enrichment_path": "470826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "470826.protein.info.v11.5.txt",
		        "node_list_path": "470826.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumCoprophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium coprophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumCoprophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36646.protein.sequences.v11.5.fa",
		        "enrichment_path": "36646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36646.protein.info.v11.5.txt",
		        "node_list_path": "36646.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumSp6654(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. 66-54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSp6654", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895845.protein.info.v11.5.txt",
		        "node_list_path": "1895845.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhoenixDactyliferaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phoenix dactylifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhoenixDactyliferaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42345.clusters.proteins.v11.5.txt",
		        "sequence_path": "42345.protein.sequences.v11.5.fa",
		        "enrichment_path": "42345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42345.protein.info.v11.5.txt",
		        "node_list_path": "42345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaSp83e34Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. 83E34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSp83e34Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1692264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1692264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1692264.clusters.proteins.v11.5.txt",
		        "sequence_path": "1692264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1692264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1692264.protein.info.v11.5.txt",
		        "node_list_path": "1692264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1692264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthromitusSpSfbratyitCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBratYit Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthromitusSpSfbratyitCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041504.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041504.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041504.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041504.protein.info.v11.5.txt",
		        "node_list_path": "1041504.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041504.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiopsisBaichengensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis baichengensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisBaichengensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236902.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236902.protein.info.v11.5.txt",
		        "node_list_path": "1236902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudozymaFlocculosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma flocculosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudozymaFlocculosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84751.clusters.proteins.v11.5.txt",
		        "sequence_path": "84751.protein.sequences.v11.5.fa",
		        "enrichment_path": "84751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84751.protein.info.v11.5.txt",
		        "node_list_path": "84751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerostipesCaccaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerostipes caccae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerostipesCaccaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411490.clusters.proteins.v11.5.txt",
		        "sequence_path": "411490.protein.sequences.v11.5.fa",
		        "enrichment_path": "411490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411490.protein.info.v11.5.txt",
		        "node_list_path": "411490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumFabrumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium fabrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumFabrumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "176299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "176299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "176299.clusters.proteins.v11.5.txt",
		        "sequence_path": "176299.protein.sequences.v11.5.fa",
		        "enrichment_path": "176299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "176299.protein.info.v11.5.txt",
		        "node_list_path": "176299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "176299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110057Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110057Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1570346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1570346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1570346.clusters.proteins.v11.5.txt",
		        "sequence_path": "1570346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570346.protein.info.v11.5.txt",
		        "node_list_path": "1570346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1570346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807755.protein.info.v11.5.txt",
		        "node_list_path": "1807755.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumDoricum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium doricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumDoricum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "126673.protein.sequences.v11.5.fa",
		        "enrichment_path": "126673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "126673.protein.info.v11.5.txt",
		        "node_list_path": "126673.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusCrispatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus crispatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCrispatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "748671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "748671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "748671.clusters.proteins.v11.5.txt",
		        "sequence_path": "748671.protein.sequences.v11.5.fa",
		        "enrichment_path": "748671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748671.protein.info.v11.5.txt",
		        "node_list_path": "748671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "748671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumNor53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium NOR53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumNor53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "566466.protein.sequences.v11.0.fa",
		        "enrichment_path": "566466.protein.enrichment.terms.v11.0.txt",
		        "info_path": "566466.protein.info.v11.0.txt",
		        "node_list_path": "566466.protein.complete.v11.0.txt"
		    }
		]
    )()

def MarinomonasUshuaiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas ushuaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasUshuaiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122207.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122207.protein.info.v11.5.txt",
		        "node_list_path": "1122207.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesColuzziiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles coluzzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesColuzziiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1518534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1518534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1518534.clusters.proteins.v11.5.txt",
		        "sequence_path": "1518534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1518534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1518534.protein.info.v11.5.txt",
		        "node_list_path": "1518534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1518534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CionaIntestinalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ciona intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CionaIntestinalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7719.clusters.proteins.v11.5.txt",
		        "sequence_path": "7719.protein.sequences.v11.5.fa",
		        "enrichment_path": "7719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7719.protein.info.v11.5.txt",
		        "node_list_path": "7719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TuberibacillusSpMarseilleP3662(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tuberibacillus sp. Marseille-P3662 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuberibacillusSpMarseilleP3662", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1965358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1965358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1965358.protein.info.v11.5.txt",
		        "node_list_path": "1965358.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlaciecolaSp4h37ye5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola sp. 4H37YE5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaSp4h37ye5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983545.clusters.proteins.v11.5.txt",
		        "sequence_path": "983545.protein.sequences.v11.5.fa",
		        "enrichment_path": "983545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983545.protein.info.v11.5.txt",
		        "node_list_path": "983545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumFrigidisoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium frigidisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumFrigidisoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125876.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125876.protein.info.v11.5.txt",
		        "node_list_path": "1125876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125718.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125718.protein.info.v11.5.txt",
		        "node_list_path": "1125718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TenacibaculumSp47agom205mCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. 47AGOM205m Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumSp47agom205mCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380384.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380384.protein.info.v11.5.txt",
		        "node_list_path": "1380384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesThermolilacinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces thermolilacinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesThermolilacinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1306406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306406.protein.info.v11.5.txt",
		        "node_list_path": "1306406.protein.complete.v11.5.txt"
		    }
		]
    )()

def MusaBalbisianaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Musa balbisiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusaBalbisianaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52838.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52838.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52838.clusters.proteins.v11.5.txt",
		        "sequence_path": "52838.protein.sequences.v11.5.fa",
		        "enrichment_path": "52838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52838.protein.info.v11.5.txt",
		        "node_list_path": "52838.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52838.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusHumiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHumiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "263474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "263474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "263474.clusters.proteins.v11.5.txt",
		        "sequence_path": "263474.protein.sequences.v11.5.fa",
		        "enrichment_path": "263474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263474.protein.info.v11.5.txt",
		        "node_list_path": "263474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "263474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NasoniaVitripennis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nasonia vitripennis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NasoniaVitripennis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7425.protein.sequences.v11.5.fa",
		        "enrichment_path": "7425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7425.protein.info.v11.5.txt",
		        "node_list_path": "7425.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioMytili(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio mytili graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioMytili", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "50718.protein.sequences.v11.5.fa",
		        "enrichment_path": "50718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50718.protein.info.v11.5.txt",
		        "node_list_path": "50718.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMmg1121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MMG1121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMmg1121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415544.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415544.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415544.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415544.protein.info.v11.5.txt",
		        "node_list_path": "1415544.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415544.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusBombycis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus bombycis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusBombycis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "109264.protein.sequences.v11.5.fa",
		        "enrichment_path": "109264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109264.protein.info.v11.5.txt",
		        "node_list_path": "109264.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolimonasAquaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solimonas aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolimonasAquaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "489703.clusters.info.v11.5.txt",
		        "cluster_tree_path": "489703.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "489703.clusters.proteins.v11.5.txt",
		        "sequence_path": "489703.protein.sequences.v11.5.fa",
		        "enrichment_path": "489703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "489703.protein.info.v11.5.txt",
		        "node_list_path": "489703.cluster.nodes.v11.5.txt",
		        "edge_list_path": "489703.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumKuznetsoviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum kuznetsovii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumKuznetsoviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "760568.clusters.info.v11.5.txt",
		        "cluster_tree_path": "760568.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "760568.clusters.proteins.v11.5.txt",
		        "sequence_path": "760568.protein.sequences.v11.5.fa",
		        "enrichment_path": "760568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "760568.protein.info.v11.5.txt",
		        "node_list_path": "760568.cluster.nodes.v11.5.txt",
		        "edge_list_path": "760568.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBrocadiaSinicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sinica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBrocadiaSinicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "795830.clusters.info.v11.5.txt",
		        "cluster_tree_path": "795830.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "795830.clusters.proteins.v11.5.txt",
		        "sequence_path": "795830.protein.sequences.v11.5.fa",
		        "enrichment_path": "795830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "795830.protein.info.v11.5.txt",
		        "node_list_path": "795830.cluster.nodes.v11.5.txt",
		        "edge_list_path": "795830.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpLc238Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. LC238 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpLc238Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502852.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502852.protein.info.v11.5.txt",
		        "node_list_path": "1502852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioDechloracetivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio dechloracetivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioDechloracetivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "117209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "117209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "117209.clusters.proteins.v11.5.txt",
		        "sequence_path": "117209.protein.sequences.v11.5.fa",
		        "enrichment_path": "117209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "117209.protein.info.v11.5.txt",
		        "node_list_path": "117209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "117209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomonasLentaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas lenta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasLentaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "980561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "980561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "980561.clusters.proteins.v11.5.txt",
		        "sequence_path": "980561.protein.sequences.v11.5.fa",
		        "enrichment_path": "980561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "980561.protein.info.v11.5.txt",
		        "node_list_path": "980561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "980561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LabeoRohitaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Labeo rohita Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabeoRohitaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84645.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84645.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84645.clusters.proteins.v11.5.txt",
		        "sequence_path": "84645.protein.sequences.v11.5.fa",
		        "enrichment_path": "84645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84645.protein.info.v11.5.txt",
		        "node_list_path": "84645.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84645.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpAc4496(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. AC44/96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpAc4496", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841654.protein.info.v11.5.txt",
		        "node_list_path": "1841654.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBeijerinckii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter beijerinckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBeijerinckii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217648.protein.info.v11.5.txt",
		        "node_list_path": "1217648.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaXishanensisNbrc101358(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia xishanensis NBRC 101358 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaXishanensisNbrc101358", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210101.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210101.protein.info.v11.5.txt",
		        "node_list_path": "1210101.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpNfr03Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpNfr03Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566263.protein.info.v11.5.txt",
		        "node_list_path": "1566263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseolineaSerpensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseolinea serpens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseolineaSerpensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "947013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "947013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "947013.clusters.proteins.v11.5.txt",
		        "sequence_path": "947013.protein.sequences.v11.5.fa",
		        "enrichment_path": "947013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "947013.protein.info.v11.5.txt",
		        "node_list_path": "947013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "947013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KiloniellaMajae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kiloniella majae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KiloniellaMajae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1938558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938558.protein.info.v11.5.txt",
		        "node_list_path": "1938558.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaeCc1513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaeCc1513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1357275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1357275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1357275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1357275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357275.protein.info.v11.5.txt",
		        "node_list_path": "1357275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1357275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaRaraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella rara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaRaraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1676614.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1676614.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1676614.clusters.proteins.v11.5.txt",
		        "sequence_path": "1676614.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676614.protein.info.v11.5.txt",
		        "node_list_path": "1676614.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1676614.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumSubspAnimalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum subsp. animalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumSubspAnimalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "76859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "76859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "76859.clusters.proteins.v11.5.txt",
		        "sequence_path": "76859.protein.sequences.v11.5.fa",
		        "enrichment_path": "76859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76859.protein.info.v11.5.txt",
		        "node_list_path": "76859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "76859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JuglansRegiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Juglans regia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JuglansRegiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "51240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "51240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "51240.clusters.proteins.v11.5.txt",
		        "sequence_path": "51240.protein.sequences.v11.5.fa",
		        "enrichment_path": "51240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51240.protein.info.v11.5.txt",
		        "node_list_path": "51240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "51240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AminicenantesBacteriumScgcAaa252a02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium SCGC AAA252A02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminicenantesBacteriumScgcAaa252a02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1047013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1047013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1047013.protein.info.v11.5.txt",
		        "node_list_path": "1047013.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaAcidivoransNbrc108247(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia acidivorans NBRC 108247 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAcidivoransNbrc108247", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210062.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210062.protein.info.v11.5.txt",
		        "node_list_path": "1210062.protein.complete.v11.5.txt"
		    }
		]
    )()

def HepatoplasmaCrinochetorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hepatoplasma crinochetorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HepatoplasmaCrinochetorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1427984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1427984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1427984.clusters.proteins.v11.5.txt",
		        "sequence_path": "1427984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1427984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1427984.protein.info.v11.5.txt",
		        "node_list_path": "1427984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1427984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumOlb14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumOlb14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617415.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617415.protein.info.v11.5.txt",
		        "node_list_path": "1617415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSpLeaf194(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf194 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpLeaf194", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736297.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736297.protein.info.v11.5.txt",
		        "node_list_path": "1736297.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinomonasAtlantica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasAtlantica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1806668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806668.protein.info.v11.5.txt",
		        "node_list_path": "1806668.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFrigorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium frigoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFrigorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1086011.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1086011.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1086011.clusters.proteins.v11.5.txt",
		        "sequence_path": "1086011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1086011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1086011.protein.info.v11.5.txt",
		        "node_list_path": "1086011.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1086011.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobiusActivus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassobius activus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobiusActivus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1715691.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715691.protein.info.v11.5.txt",
		        "node_list_path": "1715691.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpRoot264(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root264 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpRoot264", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736503.protein.info.v11.5.txt",
		        "node_list_path": "1736503.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioFibrisolvens164Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens 16/4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioFibrisolvens164Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "657324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "657324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "657324.clusters.proteins.v11.5.txt",
		        "sequence_path": "657324.protein.sequences.v11.5.fa",
		        "enrichment_path": "657324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657324.protein.info.v11.5.txt",
		        "node_list_path": "657324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "657324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NautiliaProfundicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nautilia profundicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NautiliaProfundicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "598659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "598659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "598659.clusters.proteins.v11.5.txt",
		        "sequence_path": "598659.protein.sequences.v11.5.fa",
		        "enrichment_path": "598659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "598659.protein.info.v11.5.txt",
		        "node_list_path": "598659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "598659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpP11g3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. P11G3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpP11g3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1699623.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1699623.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1699623.clusters.proteins.v11.5.txt",
		        "sequence_path": "1699623.protein.sequences.v11.5.fa",
		        "enrichment_path": "1699623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1699623.protein.info.v11.5.txt",
		        "node_list_path": "1699623.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1699623.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StegastesPartitusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stegastes partitus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StegastesPartitusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "144197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "144197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "144197.clusters.proteins.v11.5.txt",
		        "sequence_path": "144197.protein.sequences.v11.5.fa",
		        "enrichment_path": "144197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "144197.protein.info.v11.5.txt",
		        "node_list_path": "144197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "144197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NaegleriaGruberiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Naegleria gruberi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NaegleriaGruberiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5762.clusters.proteins.v11.5.txt",
		        "sequence_path": "5762.protein.sequences.v11.5.fa",
		        "enrichment_path": "5762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5762.protein.info.v11.5.txt",
		        "node_list_path": "5762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaCantharicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma cantharicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaCantharicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "362837.protein.sequences.v11.5.fa",
		        "enrichment_path": "362837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362837.protein.info.v11.5.txt",
		        "node_list_path": "362837.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeurosporaTetraspermaFgsc2509Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neurospora tetrasperma FGSC 2509 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeurosporaTetraspermaFgsc2509Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "510952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "510952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "510952.clusters.proteins.v11.5.txt",
		        "sequence_path": "510952.protein.sequences.v11.5.fa",
		        "enrichment_path": "510952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "510952.protein.info.v11.5.txt",
		        "node_list_path": "510952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "510952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumD1873(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum D 1873 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumD1873", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "592027.protein.sequences.v11.5.fa",
		        "enrichment_path": "592027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592027.protein.info.v11.5.txt",
		        "node_list_path": "592027.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusArlettaeCvd059Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus arlettae CVD059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusArlettaeCvd059Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1212545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1212545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1212545.clusters.proteins.v11.5.txt",
		        "sequence_path": "1212545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1212545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1212545.protein.info.v11.5.txt",
		        "node_list_path": "1212545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1212545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychroserpensMesophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens mesophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroserpensMesophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "325473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "325473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "325473.clusters.proteins.v11.5.txt",
		        "sequence_path": "325473.protein.sequences.v11.5.fa",
		        "enrichment_path": "325473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "325473.protein.info.v11.5.txt",
		        "node_list_path": "325473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "325473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassotaleaSpNd16aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassotalea sp. ND16A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassotaleaSpNd16aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1535422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1535422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1535422.clusters.proteins.v11.5.txt",
		        "sequence_path": "1535422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1535422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1535422.protein.info.v11.5.txt",
		        "node_list_path": "1535422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1535422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlexistipesSinusarabiciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flexistipes sinusarabici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlexistipesSinusarabiciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717231.clusters.proteins.v11.5.txt",
		        "sequence_path": "717231.protein.sequences.v11.5.fa",
		        "enrichment_path": "717231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717231.protein.info.v11.5.txt",
		        "node_list_path": "717231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EndosymbiontOfTevnia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Tevnia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndosymbiontOfTevnia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1049564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1049564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1049564.protein.info.v11.5.txt",
		        "node_list_path": "1049564.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyphellophoraEuropaeaCbs101466Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyphellophora europaea CBS 101466 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyphellophoraEuropaeaCbs101466Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220924.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220924.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220924.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220924.protein.info.v11.5.txt",
		        "node_list_path": "1220924.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220924.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FictibacillusSolisalsi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fictibacillus solisalsi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FictibacillusSolisalsi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "459525.protein.sequences.v11.5.fa",
		        "enrichment_path": "459525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "459525.protein.info.v11.5.txt",
		        "node_list_path": "459525.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioThiocyanoxidansArh4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArh4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "713587.clusters.info.v11.0.txt",
		        "cluster_tree_path": "713587.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "713587.clusters.proteins.v11.0.txt",
		        "sequence_path": "713587.protein.sequences.v11.0.fa",
		        "enrichment_path": "713587.protein.enrichment.terms.v11.0.txt",
		        "info_path": "713587.protein.info.v11.0.txt",
		        "node_list_path": "713587.cluster.nodes.v11.0.txt",
		        "edge_list_path": "713587.protein.cluster.v11.0.txt"
		    }
		]
    )()

def HalolaminaRubra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halolamina rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolaminaRubra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380430.protein.info.v11.5.txt",
		        "node_list_path": "1380430.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu032Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU032 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu032Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671650.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671650.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671650.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671650.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671650.protein.info.v11.5.txt",
		        "node_list_path": "1671650.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671650.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HippocampusComesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hippocampus comes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HippocampusComesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "109280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "109280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "109280.clusters.proteins.v11.5.txt",
		        "sequence_path": "109280.protein.sequences.v11.5.fa",
		        "enrichment_path": "109280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109280.protein.info.v11.5.txt",
		        "node_list_path": "109280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "109280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfurococcusKamchatkensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurococcus kamchatkensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurococcusKamchatkensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "490899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "490899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "490899.clusters.proteins.v11.5.txt",
		        "sequence_path": "490899.protein.sequences.v11.5.fa",
		        "enrichment_path": "490899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "490899.protein.info.v11.5.txt",
		        "node_list_path": "490899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "490899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MalasseziaSympodialisAtcc42132Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Malassezia sympodialis ATCC 42132 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalasseziaSympodialisAtcc42132Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230383.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230383.protein.info.v11.5.txt",
		        "node_list_path": "1230383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoflavonifractorCapillosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoflavonifractor capillosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoflavonifractorCapillosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411467.clusters.proteins.v11.5.txt",
		        "sequence_path": "411467.protein.sequences.v11.5.fa",
		        "enrichment_path": "411467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411467.protein.info.v11.5.txt",
		        "node_list_path": "411467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaUdeis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia udeis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaUdeis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232866.protein.info.v11.5.txt",
		        "node_list_path": "1232866.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteusHauseriAtcc700826(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteus hauseri ATCC 700826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteusHauseriAtcc700826", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354271.protein.info.v11.5.txt",
		        "node_list_path": "1354271.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpCl154Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. CL154 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpCl154Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798214.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798214.protein.info.v11.5.txt",
		        "node_list_path": "1798214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaeroarcusBurkinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaeroarcus burkinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeroarcusBurkinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120985.protein.info.v11.5.txt",
		        "node_list_path": "1120985.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumExBugulaNeritinaAb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium (ex Bugula neritina AB1) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumExBugulaNeritinaAb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1868286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1868286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1868286.protein.info.v11.5.txt",
		        "node_list_path": "1868286.protein.complete.v11.5.txt"
		    }
		]
    )()

def CatonellaMorbi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catonella morbi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatonellaMorbi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "592026.protein.sequences.v11.5.fa",
		        "enrichment_path": "592026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592026.protein.info.v11.5.txt",
		        "node_list_path": "592026.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumBangladeshense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium bangladeshense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumBangladeshense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1138189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1138189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1138189.protein.info.v11.5.txt",
		        "node_list_path": "1138189.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpFd1XmdCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. fd1-xmd Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpFd1XmdCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1812480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1812480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1812480.clusters.proteins.v11.5.txt",
		        "sequence_path": "1812480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1812480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1812480.protein.info.v11.5.txt",
		        "node_list_path": "1812480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1812480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpA23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. A23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpA23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1944133.protein.sequences.v11.5.fa",
		        "enrichment_path": "1944133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1944133.protein.info.v11.5.txt",
		        "node_list_path": "1944133.protein.complete.v11.5.txt"
		    }
		]
    )()

def CionaSavignyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ciona savignyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CionaSavignyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "51511.protein.sequences.v11.5.fa",
		        "enrichment_path": "51511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51511.protein.info.v11.5.txt",
		        "node_list_path": "51511.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchizoporaParadoxaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizopora paradoxa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizoporaParadoxaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "27342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "27342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "27342.clusters.proteins.v11.5.txt",
		        "sequence_path": "27342.protein.sequences.v11.5.fa",
		        "enrichment_path": "27342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27342.protein.info.v11.5.txt",
		        "node_list_path": "27342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "27342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedLachnospiraSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Lachnospira sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedLachnospiraSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "446043.clusters.info.v11.5.txt",
		        "cluster_tree_path": "446043.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "446043.clusters.proteins.v11.5.txt",
		        "sequence_path": "446043.protein.sequences.v11.5.fa",
		        "enrichment_path": "446043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446043.protein.info.v11.5.txt",
		        "node_list_path": "446043.cluster.nodes.v11.5.txt",
		        "edge_list_path": "446043.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusFumigatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus fumigatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusFumigatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "746128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "746128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "746128.clusters.proteins.v11.5.txt",
		        "sequence_path": "746128.protein.sequences.v11.5.fa",
		        "enrichment_path": "746128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "746128.protein.info.v11.5.txt",
		        "node_list_path": "746128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "746128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGwe23716(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWE2_37_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGwe23716", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798261.protein.info.v11.5.txt",
		        "node_list_path": "1798261.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3919(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_39_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3919", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802062.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802062.protein.info.v11.5.txt",
		        "node_list_path": "1802062.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobiumChlorochromatiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium chlorochromatii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumChlorochromatiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "340177.clusters.info.v11.5.txt",
		        "cluster_tree_path": "340177.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "340177.clusters.proteins.v11.5.txt",
		        "sequence_path": "340177.protein.sequences.v11.5.fa",
		        "enrichment_path": "340177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340177.protein.info.v11.5.txt",
		        "node_list_path": "340177.cluster.nodes.v11.5.txt",
		        "edge_list_path": "340177.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaScopos(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella scopos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaScopos", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236518.protein.info.v11.5.txt",
		        "node_list_path": "1236518.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumJdfr88Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-88 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumJdfr88Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935149.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935149.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935149.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935149.protein.info.v11.5.txt",
		        "node_list_path": "1935149.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935149.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFirestonebacteriaBacteriumRifoxya2Full408(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Firestonebacteria bacterium RIFOXYA2_FULL_40_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFirestonebacteriaBacteriumRifoxya2Full408", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817859.protein.info.v11.5.txt",
		        "node_list_path": "1817859.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumLactosutensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium lactosutens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumLactosutensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1331060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1331060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1331060.clusters.proteins.v11.5.txt",
		        "sequence_path": "1331060.protein.sequences.v11.5.fa",
		        "enrichment_path": "1331060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1331060.protein.info.v11.5.txt",
		        "node_list_path": "1331060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1331060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychroflexusTropicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychroflexus tropicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroflexusTropicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123035.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123035.protein.info.v11.5.txt",
		        "node_list_path": "1123035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DethiosulfatarculusSandiegensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dethiosulfatarculus sandiegensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DethiosulfatarculusSandiegensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1429043.protein.sequences.v11.5.fa",
		        "enrichment_path": "1429043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1429043.protein.info.v11.5.txt",
		        "node_list_path": "1429043.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpCf125Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. CF125 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpCf125Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855303.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855303.protein.info.v11.5.txt",
		        "node_list_path": "1855303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMspmpm5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MspMPM5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMspmpm5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1155718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1155718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1155718.protein.info.v11.5.txt",
		        "node_list_path": "1155718.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptobacillusHongkongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptobacillus hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptobacillusHongkongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1162717.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1162717.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1162717.clusters.proteins.v11.5.txt",
		        "sequence_path": "1162717.protein.sequences.v11.5.fa",
		        "enrichment_path": "1162717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1162717.protein.info.v11.5.txt",
		        "node_list_path": "1162717.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1162717.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpMsmb0266(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. MSMB0266 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpMsmb0266", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1637837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1637837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1637837.protein.info.v11.5.txt",
		        "node_list_path": "1637837.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarispirochaetaAestuarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marispirochaeta aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarispirochaetaAestuarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1963862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1963862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1963862.protein.info.v11.5.txt",
		        "node_list_path": "1963862.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusEquiSubspZooepidemicusAtcc35246Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus equi subsp. zooepidemicus ATCC 35246 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusEquiSubspZooepidemicusAtcc35246Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1051072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1051072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1051072.clusters.proteins.v11.5.txt",
		        "sequence_path": "1051072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051072.protein.info.v11.5.txt",
		        "node_list_path": "1051072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1051072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumBact19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumBact19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674833.protein.info.v11.5.txt",
		        "node_list_path": "1674833.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121362.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121362.protein.info.v11.5.txt",
		        "node_list_path": "1121362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSubtilisSubspNattoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. natto Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSubtilisSubspNattoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86029.clusters.proteins.v11.5.txt",
		        "sequence_path": "86029.protein.sequences.v11.5.fa",
		        "enrichment_path": "86029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86029.protein.info.v11.5.txt",
		        "node_list_path": "86029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterGossypiicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter gossypiicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterGossypiicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "551995.protein.sequences.v11.5.fa",
		        "enrichment_path": "551995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551995.protein.info.v11.5.txt",
		        "node_list_path": "551995.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusBarophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus barophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusBarophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391623.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391623.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391623.clusters.proteins.v11.5.txt",
		        "sequence_path": "391623.protein.sequences.v11.5.fa",
		        "enrichment_path": "391623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391623.protein.info.v11.5.txt",
		        "node_list_path": "391623.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391623.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KurthiaHuakuiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kurthia huakuii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KurthiaHuakuiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1334046.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1334046.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1334046.clusters.proteins.v11.5.txt",
		        "sequence_path": "1334046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1334046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1334046.protein.info.v11.5.txt",
		        "node_list_path": "1334046.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1334046.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PasteurellaMultocidaSubspMultocidaOh4807(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida subsp. multocida OH4807 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaMultocidaSubspMultocidaOh4807", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304873.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304873.protein.info.v11.5.txt",
		        "node_list_path": "1304873.protein.complete.v11.5.txt"
		    }
		]
    )()

def MorganellaMorganii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Morganella morganii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MorganellaMorganii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1124991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1124991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1124991.protein.info.v11.5.txt",
		        "node_list_path": "1124991.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu024(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu024", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1676160.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676160.protein.info.v11.5.txt",
		        "node_list_path": "1676160.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaceaeBacteriumFsla50209(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeriaceae bacterium FSLA50209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaceaeBacteriumFsla50209", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1497679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1497679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1497679.protein.info.v11.5.txt",
		        "node_list_path": "1497679.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTpA0356Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TP-A0356 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTpA0356Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1359208.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1359208.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1359208.clusters.proteins.v11.5.txt",
		        "sequence_path": "1359208.protein.sequences.v11.5.fa",
		        "enrichment_path": "1359208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1359208.protein.info.v11.5.txt",
		        "node_list_path": "1359208.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1359208.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinomonasHumiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinomonas humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinomonasHumiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1338436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1338436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1338436.clusters.proteins.v11.5.txt",
		        "sequence_path": "1338436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1338436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1338436.protein.info.v11.5.txt",
		        "node_list_path": "1338436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1338436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BalaenopteraAcutorostrataScammoniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Balaenoptera acutorostrata scammoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BalaenopteraAcutorostrataScammoniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "310752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "310752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "310752.clusters.proteins.v11.5.txt",
		        "sequence_path": "310752.protein.sequences.v11.5.fa",
		        "enrichment_path": "310752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "310752.protein.info.v11.5.txt",
		        "node_list_path": "310752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "310752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KurthiaHuakuii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kurthia huakuii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KurthiaHuakuii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1334046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1334046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1334046.protein.info.v11.5.txt",
		        "node_list_path": "1334046.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurovumLithotrophicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum lithotrophicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurovumLithotrophicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "206403.protein.sequences.v11.5.fa",
		        "enrichment_path": "206403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "206403.protein.info.v11.5.txt",
		        "node_list_path": "206403.protein.complete.v11.5.txt"
		    }
		]
    )()

def VaranusKomodoensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Varanus komodoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaranusKomodoensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61221.protein.sequences.v11.5.fa",
		        "enrichment_path": "61221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61221.protein.info.v11.5.txt",
		        "node_list_path": "61221.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1034943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034943.protein.info.v11.5.txt",
		        "node_list_path": "1034943.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaHirsuta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia hirsuta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaHirsuta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121927.protein.info.v11.5.txt",
		        "node_list_path": "1121927.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifoxyb1Full4113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYB1_FULL_41_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyb1Full4113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802540.protein.info.v11.5.txt",
		        "node_list_path": "1802540.protein.complete.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterEpoxidivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter epoxidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterEpoxidivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "361183.protein.sequences.v11.5.fa",
		        "enrichment_path": "361183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "361183.protein.info.v11.5.txt",
		        "node_list_path": "361183.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterBorealisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter borealis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterBorealisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1454007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1454007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1454007.clusters.proteins.v11.5.txt",
		        "sequence_path": "1454007.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454007.protein.info.v11.5.txt",
		        "node_list_path": "1454007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1454007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FluoribacterGormaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fluoribacter gormanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FluoribacterGormaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "464.clusters.info.v11.5.txt",
		        "cluster_tree_path": "464.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "464.clusters.proteins.v11.5.txt",
		        "sequence_path": "464.protein.sequences.v11.5.fa",
		        "enrichment_path": "464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "464.protein.info.v11.5.txt",
		        "node_list_path": "464.cluster.nodes.v11.5.txt",
		        "edge_list_path": "464.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaplochromisBurtoni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haplochromis burtoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaplochromisBurtoni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8153.protein.sequences.v11.5.fa",
		        "enrichment_path": "8153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8153.protein.info.v11.5.txt",
		        "node_list_path": "8153.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalegentibacterEchinorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter echinorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterEchinorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1073325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1073325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1073325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1073325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073325.protein.info.v11.5.txt",
		        "node_list_path": "1073325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1073325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JaminaeaRosea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jaminaea rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JaminaeaRosea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1569628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1569628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1569628.protein.info.v11.5.txt",
		        "node_list_path": "1569628.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerminiimonasArsenicoxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herminiimonas arsenicoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerminiimonasArsenicoxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "204773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "204773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "204773.clusters.proteins.v11.5.txt",
		        "sequence_path": "204773.protein.sequences.v11.5.fa",
		        "enrichment_path": "204773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "204773.protein.info.v11.5.txt",
		        "node_list_path": "204773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "204773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgibacterAlginicilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algibacter alginicilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgibacterAlginicilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736674.protein.info.v11.5.txt",
		        "node_list_path": "1736674.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumGa0077535(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium Ga0077535 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumGa0077535", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752192.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752192.protein.info.v11.5.txt",
		        "node_list_path": "1752192.protein.complete.v11.5.txt"
		    }
		]
    )()

def PontibacillusYanchengensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacillus yanchengensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacillusYanchengensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385514.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385514.protein.info.v11.5.txt",
		        "node_list_path": "1385514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpC(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpC", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "253839.protein.sequences.v11.5.fa",
		        "enrichment_path": "253839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "253839.protein.info.v11.5.txt",
		        "node_list_path": "253839.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4132(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_41_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4132", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797789.protein.info.v11.5.txt",
		        "node_list_path": "1797789.protein.complete.v11.5.txt"
		    }
		]
    )()

def OchrobactrumSpP6bsIiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum sp. P6BS-III Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OchrobactrumSpP6bsIiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1920636.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1920636.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1920636.clusters.proteins.v11.5.txt",
		        "sequence_path": "1920636.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920636.protein.info.v11.5.txt",
		        "node_list_path": "1920636.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1920636.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XylellaFastidiosaPls229(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xylella fastidiosa PLS229 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylellaFastidiosaPls229", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1444770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444770.protein.info.v11.5.txt",
		        "node_list_path": "1444770.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsialesBacteriumExBugulaNeritinaAb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium (ex Bugula neritina AB1) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsialesBacteriumExBugulaNeritinaAb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1868285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1868285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1868285.protein.info.v11.5.txt",
		        "node_list_path": "1868285.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag417(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:417 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag417", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262804.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262804.protein.info.v11.5.txt",
		        "node_list_path": "1262804.protein.complete.v11.5.txt"
		    }
		]
    )()

def DictyoglomusThermophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dictyoglomus thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DictyoglomusThermophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "309799.protein.sequences.v11.5.fa",
		        "enrichment_path": "309799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "309799.protein.info.v11.5.txt",
		        "node_list_path": "309799.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpM334(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. M334 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpM334", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "563038.protein.sequences.v11.5.fa",
		        "enrichment_path": "563038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563038.protein.info.v11.5.txt",
		        "node_list_path": "563038.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelobacterPropionicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter propionicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelobacterPropionicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "338966.protein.sequences.v11.5.fa",
		        "enrichment_path": "338966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "338966.protein.info.v11.5.txt",
		        "node_list_path": "338966.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9515Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9515 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9515Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "167542.clusters.info.v11.5.txt",
		        "cluster_tree_path": "167542.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "167542.clusters.proteins.v11.5.txt",
		        "sequence_path": "167542.protein.sequences.v11.5.fa",
		        "enrichment_path": "167542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167542.protein.info.v11.5.txt",
		        "node_list_path": "167542.cluster.nodes.v11.5.txt",
		        "edge_list_path": "167542.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpSod10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. SOD10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpSod10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1505946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505946.protein.info.v11.5.txt",
		        "node_list_path": "1505946.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactonifactorLongoviformisDsm17459Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactonifactor longoviformis DSM 17459 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactonifactorLongoviformisDsm17459Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122155.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122155.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122155.protein.info.v11.5.txt",
		        "node_list_path": "1122155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudaminobacterManganicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudaminobacter manganicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudaminobacterManganicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1873176.protein.sequences.v11.5.fa",
		        "enrichment_path": "1873176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1873176.protein.info.v11.5.txt",
		        "node_list_path": "1873176.protein.complete.v11.5.txt"
		    }
		]
    )()

def DefluviimonasAlbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Defluviimonas alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DefluviimonasAlbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1335048.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1335048.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1335048.clusters.proteins.v11.5.txt",
		        "sequence_path": "1335048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1335048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1335048.protein.info.v11.5.txt",
		        "node_list_path": "1335048.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1335048.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGa0077526(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077526 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077526", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752199.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752199.protein.info.v11.5.txt",
		        "node_list_path": "1752199.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetalesBacteriumSpiro09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetalesBacteriumSpiro09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674865.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674865.protein.info.v11.5.txt",
		        "node_list_path": "1674865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AurantimonasCoralicida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aurantimonas coralicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AurantimonasCoralicida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "182270.protein.sequences.v11.5.fa",
		        "enrichment_path": "182270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "182270.protein.info.v11.5.txt",
		        "node_list_path": "182270.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurimonasGotlandicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas gotlandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasGotlandicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "929558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "929558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "929558.clusters.proteins.v11.5.txt",
		        "sequence_path": "929558.protein.sequences.v11.5.fa",
		        "enrichment_path": "929558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929558.protein.info.v11.5.txt",
		        "node_list_path": "929558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "929558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeisingeraSpJc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leisingera sp. JC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraSpJc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855282.protein.info.v11.5.txt",
		        "node_list_path": "1855282.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRbg134510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_13_45_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg134510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798370.protein.info.v11.5.txt",
		        "node_list_path": "1798370.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesoflavibacterZeaxanthDsm18436Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanth. DSM18436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "MesoflavibacterZeaxanthDsm18436Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122225.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1122225.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1122225.clusters.proteins.v11.0.txt",
		        "sequence_path": "1122225.protein.sequences.v11.0.fa",
		        "enrichment_path": "1122225.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1122225.protein.info.v11.0.txt",
		        "node_list_path": "1122225.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1122225.protein.cluster.v11.0.txt"
		    }
		]
    )()

def CellulosimicrobiumFunkei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulosimicrobium funkei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulosimicrobiumFunkei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264251.protein.sequences.v11.5.fa",
		        "enrichment_path": "264251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264251.protein.info.v11.5.txt",
		        "node_list_path": "264251.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPacebacteriaBacteriumRifcsphigho201Full4610(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFCSPHIGHO2_01_FULL_46_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifcsphigho201Full4610", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801884.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801884.protein.info.v11.5.txt",
		        "node_list_path": "1801884.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaphaeosphaeriaSporulosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraphaeosphaeria sporulosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaphaeosphaeriaSporulosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1460663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1460663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1460663.clusters.proteins.v11.5.txt",
		        "sequence_path": "1460663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460663.protein.info.v11.5.txt",
		        "node_list_path": "1460663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1460663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumNeoaurumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium neoaurum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumNeoaurumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "700508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "700508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "700508.clusters.proteins.v11.5.txt",
		        "sequence_path": "700508.protein.sequences.v11.5.fa",
		        "enrichment_path": "700508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "700508.protein.info.v11.5.txt",
		        "node_list_path": "700508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "700508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpSfbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. SFB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpSfbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805634.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805634.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805634.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805634.protein.info.v11.5.txt",
		        "node_list_path": "1805634.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805634.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KockovaellaImperataeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kockovaella imperatae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KockovaellaImperataeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4999.clusters.proteins.v11.5.txt",
		        "sequence_path": "4999.protein.sequences.v11.5.fa",
		        "enrichment_path": "4999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4999.protein.info.v11.5.txt",
		        "node_list_path": "4999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusBadiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus badius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusBadiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1455.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1455.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1455.clusters.proteins.v11.5.txt",
		        "sequence_path": "1455.protein.sequences.v11.5.fa",
		        "enrichment_path": "1455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1455.protein.info.v11.5.txt",
		        "node_list_path": "1455.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1455.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenalcaligenesHominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenalcaligenes hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenalcaligenesHominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "643674.protein.sequences.v11.5.fa",
		        "enrichment_path": "643674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "643674.protein.info.v11.5.txt",
		        "node_list_path": "643674.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusDrentensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus drentensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusDrentensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "220684.protein.sequences.v11.5.fa",
		        "enrichment_path": "220684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220684.protein.info.v11.5.txt",
		        "node_list_path": "220684.protein.complete.v11.5.txt"
		    }
		]
    )()

def TerracoccusSp273mftsu31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terracoccus sp. 273MFTsu31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerracoccusSp273mftsu31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1172188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1172188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1172188.clusters.proteins.v11.5.txt",
		        "sequence_path": "1172188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172188.protein.info.v11.5.txt",
		        "node_list_path": "1172188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1172188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTerrybacteriaBacteriumRifcsphigho201Full5815(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPHIGHO2_01_FULL_58_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsphigho201Full5815", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802363.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802363.protein.info.v11.5.txt",
		        "node_list_path": "1802363.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSp770b2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. 770b2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSp770b2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566271.protein.info.v11.5.txt",
		        "node_list_path": "1566271.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpOxb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. OxB-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpOxb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "98228.clusters.info.v11.5.txt",
		        "cluster_tree_path": "98228.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "98228.clusters.proteins.v11.5.txt",
		        "sequence_path": "98228.protein.sequences.v11.5.fa",
		        "enrichment_path": "98228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "98228.protein.info.v11.5.txt",
		        "node_list_path": "98228.cluster.nodes.v11.5.txt",
		        "edge_list_path": "98228.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioFortis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio fortis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioFortis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "212667.protein.sequences.v11.5.fa",
		        "enrichment_path": "212667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "212667.protein.info.v11.5.txt",
		        "node_list_path": "212667.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumArboris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium arboris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumArboris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935557.protein.sequences.v11.5.fa",
		        "enrichment_path": "935557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935557.protein.info.v11.5.txt",
		        "node_list_path": "935557.protein.complete.v11.5.txt"
		    }
		]
    )()

def CercosporaBerteroaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cercospora berteroae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CercosporaBerteroaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "357750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "357750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "357750.clusters.proteins.v11.5.txt",
		        "sequence_path": "357750.protein.sequences.v11.5.fa",
		        "enrichment_path": "357750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357750.protein.info.v11.5.txt",
		        "node_list_path": "357750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "357750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachanceaFermentatiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachancea fermentati Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachanceaFermentatiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4955.clusters.proteins.v11.5.txt",
		        "sequence_path": "4955.protein.sequences.v11.5.fa",
		        "enrichment_path": "4955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4955.protein.info.v11.5.txt",
		        "node_list_path": "4955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoritellaSpPe36(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moritella sp. PE36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoritellaSpPe36", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "58051.protein.sequences.v11.5.fa",
		        "enrichment_path": "58051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58051.protein.info.v11.5.txt",
		        "node_list_path": "58051.protein.complete.v11.5.txt"
		    }
		]
    )()

def KribbellaFlavidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kribbella flavida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KribbellaFlavidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "479435.clusters.info.v11.5.txt",
		        "cluster_tree_path": "479435.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "479435.clusters.proteins.v11.5.txt",
		        "sequence_path": "479435.protein.sequences.v11.5.fa",
		        "enrichment_path": "479435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479435.protein.info.v11.5.txt",
		        "node_list_path": "479435.cluster.nodes.v11.5.txt",
		        "edge_list_path": "479435.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloversatilisThermotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloversatilis thermotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloversatilisThermotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1346290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1346290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1346290.clusters.proteins.v11.5.txt",
		        "sequence_path": "1346290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346290.protein.info.v11.5.txt",
		        "node_list_path": "1346290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1346290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrovirgaGuangxiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microvirga guangxiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaGuangxiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "549386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "549386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "549386.clusters.proteins.v11.5.txt",
		        "sequence_path": "549386.protein.sequences.v11.5.fa",
		        "enrichment_path": "549386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "549386.protein.info.v11.5.txt",
		        "node_list_path": "549386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "549386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GranulicatellaBalaenopterae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Granulicatella balaenopterae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicatellaBalaenopterae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "137733.protein.sequences.v11.5.fa",
		        "enrichment_path": "137733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137733.protein.info.v11.5.txt",
		        "node_list_path": "137733.protein.complete.v11.5.txt"
		    }
		]
    )()

def GillisiaSpHel133143(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gillisia sp. Hel1_33_143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GillisiaSpHel133143", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336796.protein.info.v11.5.txt",
		        "node_list_path": "1336796.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwa25412(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_54_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25412", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797808.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797808.protein.info.v11.5.txt",
		        "node_list_path": "1797808.protein.complete.v11.5.txt"
		    }
		]
    )()

def AciduliprofundumSpMar08339(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aciduliprofundum sp. MAR08339 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AciduliprofundumSpMar08339", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "673860.protein.sequences.v11.5.fa",
		        "enrichment_path": "673860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "673860.protein.info.v11.5.txt",
		        "node_list_path": "673860.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchaaliaOdontolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schaalia odontolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchaaliaOdontolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660.protein.info.v11.5.txt",
		        "node_list_path": "1660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpUrhd0057(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. URHD0057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpUrhd0057", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380389.protein.info.v11.5.txt",
		        "node_list_path": "1380389.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRiesiaSpGbbu(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia sp. GBBU graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRiesiaSpGbbu", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1719125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1719125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1719125.protein.info.v11.5.txt",
		        "node_list_path": "1719125.protein.complete.v11.5.txt"
		    }
		]
    )()

def TannerellaSpOralTaxonHot286Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tannerella sp. oral taxon HOT-286 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TannerellaSpOralTaxonHot286Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "712710.clusters.info.v11.5.txt",
		        "cluster_tree_path": "712710.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "712710.clusters.proteins.v11.5.txt",
		        "sequence_path": "712710.protein.sequences.v11.5.fa",
		        "enrichment_path": "712710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712710.protein.info.v11.5.txt",
		        "node_list_path": "712710.cluster.nodes.v11.5.txt",
		        "edge_list_path": "712710.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisExcentricus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis excentricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisExcentricus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573065.protein.sequences.v11.5.fa",
		        "enrichment_path": "573065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573065.protein.info.v11.5.txt",
		        "node_list_path": "573065.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesHygroscopicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesHygroscopicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1133850.protein.sequences.v11.5.fa",
		        "enrichment_path": "1133850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1133850.protein.info.v11.5.txt",
		        "node_list_path": "1133850.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1450648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450648.protein.info.v11.5.txt",
		        "node_list_path": "1450648.protein.complete.v11.5.txt"
		    }
		]
    )()

def BipolarisSorokinianaNd90pr(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris sorokiniana ND90Pr graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisSorokinianaNd90pr", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665912.protein.sequences.v11.5.fa",
		        "enrichment_path": "665912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665912.protein.info.v11.5.txt",
		        "node_list_path": "665912.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioclavaNitratireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioclava nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaNitratireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1915078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1915078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1915078.clusters.proteins.v11.5.txt",
		        "sequence_path": "1915078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915078.protein.info.v11.5.txt",
		        "node_list_path": "1915078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1915078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCiconiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium ciconiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCiconiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121356.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121356.protein.info.v11.5.txt",
		        "node_list_path": "1121356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporobacterTermitidisDsm10068Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporobacter termitidis DSM 10068 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporobacterTermitidisDsm10068Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123282.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123282.protein.info.v11.5.txt",
		        "node_list_path": "1123282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusPastorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus pastoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusPastorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59919.clusters.proteins.v11.5.txt",
		        "sequence_path": "59919.protein.sequences.v11.5.fa",
		        "enrichment_path": "59919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59919.protein.info.v11.5.txt",
		        "node_list_path": "59919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaAnanatisAj13355(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea ananatis AJ13355 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaAnanatisAj13355", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "932677.protein.sequences.v11.5.fa",
		        "enrichment_path": "932677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932677.protein.info.v11.5.txt",
		        "node_list_path": "932677.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlycomycesSpNrrlb16210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glycomyces sp. NRRLB16210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlycomycesSpNrrlb16210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463821.protein.info.v11.5.txt",
		        "node_list_path": "1463821.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlloscardoviaOmnicolens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alloscardovia omnicolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloscardoviaOmnicolens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120979.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120979.protein.info.v11.5.txt",
		        "node_list_path": "1120979.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGa0074130Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0074130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGa0074130Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752197.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752197.protein.info.v11.5.txt",
		        "node_list_path": "1752197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudohongiellaSpirulinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudohongiella spirulinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudohongiellaSpirulinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1249552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249552.protein.info.v11.5.txt",
		        "node_list_path": "1249552.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpAcn1agCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. ACN1ag Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpAcn1agCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "102891.clusters.info.v11.5.txt",
		        "cluster_tree_path": "102891.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "102891.clusters.proteins.v11.5.txt",
		        "sequence_path": "102891.protein.sequences.v11.5.fa",
		        "enrichment_path": "102891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102891.protein.info.v11.5.txt",
		        "node_list_path": "102891.cluster.nodes.v11.5.txt",
		        "edge_list_path": "102891.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumSgBin4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SG_bin4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumSgBin4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1827381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827381.protein.info.v11.5.txt",
		        "node_list_path": "1827381.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterGudaonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter gudaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterGudaonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "375760.protein.sequences.v11.5.fa",
		        "enrichment_path": "375760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375760.protein.info.v11.5.txt",
		        "node_list_path": "375760.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpOk909(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ok909 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpOk909", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761746.protein.info.v11.5.txt",
		        "node_list_path": "1761746.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaNivara(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryza nivara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaNivara", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4536.protein.sequences.v11.5.fa",
		        "enrichment_path": "4536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4536.protein.info.v11.5.txt",
		        "node_list_path": "4536.protein.complete.v11.5.txt"
		    }
		]
    )()

def GloeocapsaSpPcc73106(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gloeocapsa sp. PCC73106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeocapsaSpPcc73106", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "102232.protein.sequences.v11.5.fa",
		        "enrichment_path": "102232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102232.protein.info.v11.5.txt",
		        "node_list_path": "102232.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSaudimassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter saudimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSaudimassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461584.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461584.protein.info.v11.5.txt",
		        "node_list_path": "1461584.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpMitS9508Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. MIT S9508 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpMitS9508Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801629.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801629.protein.info.v11.5.txt",
		        "node_list_path": "1801629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaGinsengisoliNbrc100965(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengisoli NBRC 100965 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaGinsengisoliNbrc100965", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218078.protein.info.v11.5.txt",
		        "node_list_path": "1218078.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasMaltophiliaK279aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia K279a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasMaltophiliaK279aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "522373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "522373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "522373.clusters.proteins.v11.5.txt",
		        "sequence_path": "522373.protein.sequences.v11.5.fa",
		        "enrichment_path": "522373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "522373.protein.info.v11.5.txt",
		        "node_list_path": "522373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "522373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfobacteriumGeofontis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium geofontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfobacteriumGeofontis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "795359.protein.sequences.v11.5.fa",
		        "enrichment_path": "795359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "795359.protein.info.v11.5.txt",
		        "node_list_path": "795359.protein.complete.v11.5.txt"
		    }
		]
    )()

def GluconobacterOxydansH24Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans H24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterOxydansH24Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1224746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1224746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1224746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1224746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224746.protein.info.v11.5.txt",
		        "node_list_path": "1224746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1224746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho201Full37110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_37_110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full37110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801730.protein.info.v11.5.txt",
		        "node_list_path": "1801730.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSp73145Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. 73-145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSp73145Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895739.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895739.protein.info.v11.5.txt",
		        "node_list_path": "1895739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShimiaHaliotisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shimia haliotis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShimiaHaliotisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280847.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280847.protein.info.v11.5.txt",
		        "node_list_path": "1280847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumLotiR88bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti R88b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumLotiR88bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935548.clusters.proteins.v11.5.txt",
		        "sequence_path": "935548.protein.sequences.v11.5.fa",
		        "enrichment_path": "935548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935548.protein.info.v11.5.txt",
		        "node_list_path": "935548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrospiraPlatensisC1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrospira platensis C1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrospiraPlatensisC1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "459495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "459495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "459495.clusters.proteins.v11.5.txt",
		        "sequence_path": "459495.protein.sequences.v11.5.fa",
		        "enrichment_path": "459495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "459495.protein.info.v11.5.txt",
		        "node_list_path": "459495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "459495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpHb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. HB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpHb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1678678.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1678678.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1678678.clusters.proteins.v11.5.txt",
		        "sequence_path": "1678678.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678678.protein.info.v11.5.txt",
		        "node_list_path": "1678678.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1678678.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrinemaPallidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrinema pallidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrinemaPallidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227495.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227495.protein.info.v11.5.txt",
		        "node_list_path": "1227495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpKhp7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. khp7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpKhp7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761885.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761885.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761885.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761885.protein.info.v11.5.txt",
		        "node_list_path": "1761885.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761885.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacteriumHubeiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium hubeiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacteriumHubeiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1407499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1407499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1407499.protein.info.v11.5.txt",
		        "node_list_path": "1407499.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusNomiusNrrl13137Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus nomius NRRL 13137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusNomiusNrrl13137Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1509407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1509407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1509407.clusters.proteins.v11.5.txt",
		        "sequence_path": "1509407.protein.sequences.v11.5.fa",
		        "enrichment_path": "1509407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1509407.protein.info.v11.5.txt",
		        "node_list_path": "1509407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1509407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EuryarchaeotaArchaeonJdfr21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon JdFR-21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EuryarchaeotaArchaeonJdfr21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935139.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935139.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935139.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935139.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935139.protein.info.v11.5.txt",
		        "node_list_path": "1935139.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935139.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JannaschiaFaecimaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia faecimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaFaecimaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1244108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1244108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1244108.protein.info.v11.5.txt",
		        "node_list_path": "1244108.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusPseudoaviumNbrc100491(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus pseudoavium NBRC 100491 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusPseudoaviumNbrc100491", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218092.protein.info.v11.5.txt",
		        "node_list_path": "1218092.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerolineaeBacteriumCg2305767Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium CG2_30_57_67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaeBacteriumCg2305767Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805003.protein.info.v11.5.txt",
		        "node_list_path": "1805003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusFlavefaciensAe3010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens AE3010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusFlavefaciensAe3010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1384066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1384066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1384066.clusters.proteins.v11.5.txt",
		        "sequence_path": "1384066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384066.protein.info.v11.5.txt",
		        "node_list_path": "1384066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1384066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTaa486Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA486 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTaa486Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298880.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298880.protein.info.v11.5.txt",
		        "node_list_path": "1298880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusCristatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus cristatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusCristatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573508.clusters.proteins.v11.5.txt",
		        "sequence_path": "573508.protein.sequences.v11.5.fa",
		        "enrichment_path": "573508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573508.protein.info.v11.5.txt",
		        "node_list_path": "573508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumIcense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium icense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumIcense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1274631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274631.protein.info.v11.5.txt",
		        "node_list_path": "1274631.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumA2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium A2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumA2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "397290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "397290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "397290.clusters.proteins.v11.5.txt",
		        "sequence_path": "397290.protein.sequences.v11.5.fa",
		        "enrichment_path": "397290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397290.protein.info.v11.5.txt",
		        "node_list_path": "397290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "397290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusOrisPb013t23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oris PB013T23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOrisPb013t23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "908339.protein.sequences.v11.5.fa",
		        "enrichment_path": "908339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908339.protein.info.v11.5.txt",
		        "node_list_path": "908339.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaSalsilacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella salsilacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaSalsilacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "195913.protein.sequences.v11.5.fa",
		        "enrichment_path": "195913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195913.protein.info.v11.5.txt",
		        "node_list_path": "195913.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5050(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_50_50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5050", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798492.protein.info.v11.5.txt",
		        "node_list_path": "1798492.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidiphiliumRubrumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidiphilium rubrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidiphiliumRubrumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "526.clusters.proteins.v11.5.txt",
		        "sequence_path": "526.protein.sequences.v11.5.fa",
		        "enrichment_path": "526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526.protein.info.v11.5.txt",
		        "node_list_path": "526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlochmanniaPennsylvanicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia pennsylvanicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlochmanniaPennsylvanicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "291272.protein.sequences.v11.5.fa",
		        "enrichment_path": "291272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "291272.protein.info.v11.5.txt",
		        "node_list_path": "291272.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalanaerobiumPraevalensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halanaerobium praevalens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaerobiumPraevalensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "572479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "572479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "572479.clusters.proteins.v11.5.txt",
		        "sequence_path": "572479.protein.sequences.v11.5.fa",
		        "enrichment_path": "572479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572479.protein.info.v11.5.txt",
		        "node_list_path": "572479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "572479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674850.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674850.protein.info.v11.5.txt",
		        "node_list_path": "1674850.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesBacteriumUtcpr1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates bacterium UTCPR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesBacteriumUtcpr1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1961107.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961107.protein.info.v11.5.txt",
		        "node_list_path": "1961107.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumCch11D2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium CCH11-D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumCch11D2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1768801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768801.protein.info.v11.5.txt",
		        "node_list_path": "1768801.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSulciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sulci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSulciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888727.clusters.proteins.v11.5.txt",
		        "sequence_path": "888727.protein.sequences.v11.5.fa",
		        "enrichment_path": "888727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888727.protein.info.v11.5.txt",
		        "node_list_path": "888727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium4718Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 47-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium4718Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895926.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895926.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895926.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895926.protein.info.v11.5.txt",
		        "node_list_path": "1895926.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895926.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusFerus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus ferus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusFerus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123303.protein.info.v11.5.txt",
		        "node_list_path": "1123303.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeeuwenhoekiellaBlandensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella blandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeeuwenhoekiellaBlandensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398720.protein.sequences.v11.5.fa",
		        "enrichment_path": "398720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398720.protein.info.v11.5.txt",
		        "node_list_path": "398720.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichophytonRubrumCbs118892(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton rubrum CBS 118892 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichophytonRubrumCbs118892", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "559305.protein.sequences.v11.5.fa",
		        "enrichment_path": "559305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559305.protein.info.v11.5.txt",
		        "node_list_path": "559305.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisSpAc402Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC402 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisSpAc402Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1282361.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1282361.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1282361.clusters.proteins.v11.5.txt",
		        "sequence_path": "1282361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282361.protein.info.v11.5.txt",
		        "node_list_path": "1282361.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1282361.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesFaecis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides faecis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFaecis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1077285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077285.protein.info.v11.5.txt",
		        "node_list_path": "1077285.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichococcusPasteuriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichococcus pasteurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichococcusPasteuriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43064.clusters.proteins.v11.5.txt",
		        "sequence_path": "43064.protein.sequences.v11.5.fa",
		        "enrichment_path": "43064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43064.protein.info.v11.5.txt",
		        "node_list_path": "43064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumRiyadhenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium riyadhense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumRiyadhenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "486698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "486698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "486698.clusters.proteins.v11.5.txt",
		        "sequence_path": "486698.protein.sequences.v11.5.fa",
		        "enrichment_path": "486698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "486698.protein.info.v11.5.txt",
		        "node_list_path": "486698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "486698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AfipiaFelisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Afipia felis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaFelisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883080.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883080.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883080.clusters.proteins.v11.5.txt",
		        "sequence_path": "883080.protein.sequences.v11.5.fa",
		        "enrichment_path": "883080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883080.protein.info.v11.5.txt",
		        "node_list_path": "883080.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883080.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PiscirickettsiaLitoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Piscirickettsia litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiscirickettsiaLitoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1891921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1891921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1891921.clusters.proteins.v11.5.txt",
		        "sequence_path": "1891921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891921.protein.info.v11.5.txt",
		        "node_list_path": "1891921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1891921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusPseudofirmus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus pseudofirmus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPseudofirmus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398511.protein.sequences.v11.5.fa",
		        "enrichment_path": "398511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398511.protein.info.v11.5.txt",
		        "node_list_path": "398511.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucobacterSpUcdThu(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter sp. UCD-THU graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterSpUcdThu", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1292023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292023.protein.info.v11.5.txt",
		        "node_list_path": "1292023.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumMerdaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium merdae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumMerdaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1958780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1958780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1958780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1958780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1958780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1958780.protein.info.v11.5.txt",
		        "node_list_path": "1958780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1958780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LichtheimiaCorymbiferaJmrcFsu9682(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lichtheimia corymbifera JMRC:FSU:9682 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LichtheimiaCorymbiferaJmrcFsu9682", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263082.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263082.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263082.protein.info.v11.5.txt",
		        "node_list_path": "1263082.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaSpLeaf50(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. Leaf50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpLeaf50", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736223.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736223.protein.info.v11.5.txt",
		        "node_list_path": "1736223.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesJaponicusYfs275(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces japonicus yFS275 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesJaponicusYfs275", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "402676.protein.sequences.v11.5.fa",
		        "enrichment_path": "402676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402676.protein.info.v11.5.txt",
		        "node_list_path": "402676.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpF3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. F-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpF3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1840095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1840095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1840095.protein.info.v11.5.txt",
		        "node_list_path": "1840095.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867008Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867008Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1659202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1659202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1659202.clusters.proteins.v11.5.txt",
		        "sequence_path": "1659202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659202.protein.info.v11.5.txt",
		        "node_list_path": "1659202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1659202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSericytochromatiaBacteriumS15bMn24Raac196Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sericytochromatia bacterium S15B-MN24 RAAC_196 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSericytochromatiaBacteriumS15bMn24Raac196Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1919280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1919280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1919280.clusters.proteins.v11.5.txt",
		        "sequence_path": "1919280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1919280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1919280.protein.info.v11.5.txt",
		        "node_list_path": "1919280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1919280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpNfacc26(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. NFACC26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpNfacc26", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566275.protein.info.v11.5.txt",
		        "node_list_path": "1566275.protein.complete.v11.5.txt"
		    }
		]
    )()

def CedeceaNeteri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cedecea neteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CedeceaNeteri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "158822.protein.sequences.v11.5.fa",
		        "enrichment_path": "158822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158822.protein.info.v11.5.txt",
		        "node_list_path": "158822.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSp67h29bp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. 67H29BP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSp67h29bp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "864563.protein.sequences.v11.5.fa",
		        "enrichment_path": "864563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864563.protein.info.v11.5.txt",
		        "node_list_path": "864563.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonasSpT16b2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. T16B2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSpT16b2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280941.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280941.protein.info.v11.5.txt",
		        "node_list_path": "1280941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesFinegoldii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides finegoldii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFinegoldii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "483215.protein.sequences.v11.5.fa",
		        "enrichment_path": "483215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483215.protein.info.v11.5.txt",
		        "node_list_path": "483215.protein.complete.v11.5.txt"
		    }
		]
    )()

def EcheneisNaucrates(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Echeneis naucrates graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EcheneisNaucrates", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "173247.protein.sequences.v11.5.fa",
		        "enrichment_path": "173247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "173247.protein.info.v11.5.txt",
		        "node_list_path": "173247.protein.complete.v11.5.txt"
		    }
		]
    )()

def TolypocladiumOphioglossoidesCbs100239(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tolypocladium ophioglossoides CBS 100239 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolypocladiumOphioglossoidesCbs100239", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163406.protein.info.v11.5.txt",
		        "node_list_path": "1163406.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanothrixThermoacetophilaPt(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanothrix thermoacetophila PT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothrixThermoacetophilaPt", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349307.protein.sequences.v11.5.fa",
		        "enrichment_path": "349307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349307.protein.info.v11.5.txt",
		        "node_list_path": "349307.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpB05(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. B05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpB05", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945859.protein.info.v11.5.txt",
		        "node_list_path": "1945859.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaAnimaloris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria animaloris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaAnimaloris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326522.protein.sequences.v11.5.fa",
		        "enrichment_path": "326522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326522.protein.info.v11.5.txt",
		        "node_list_path": "326522.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucobacterSpPh1cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter sp. PH1c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterSpPh1cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397278.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397278.protein.info.v11.5.txt",
		        "node_list_path": "1397278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychroflexusGondwanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychroflexus gondwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroflexusGondwanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1189619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1189619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1189619.protein.info.v11.5.txt",
		        "node_list_path": "1189619.protein.complete.v11.5.txt"
		    }
		]
    )()

def AchromobacterInsolitusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter insolitus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterInsolitusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "217204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "217204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "217204.clusters.proteins.v11.5.txt",
		        "sequence_path": "217204.protein.sequences.v11.5.fa",
		        "enrichment_path": "217204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "217204.protein.info.v11.5.txt",
		        "node_list_path": "217204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "217204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaDispar(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma dispar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaDispar", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86660.protein.sequences.v11.5.fa",
		        "enrichment_path": "86660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86660.protein.info.v11.5.txt",
		        "node_list_path": "86660.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprobacillusSpCag826Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus sp. CAG:826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprobacillusSpCag826Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262857.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262857.protein.info.v11.5.txt",
		        "node_list_path": "1262857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoniaMobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesonia mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoniaMobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122226.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122226.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122226.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122226.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122226.protein.info.v11.5.txt",
		        "node_list_path": "1122226.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122226.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusTibetensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus tibetensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusTibetensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "336292.protein.sequences.v11.5.fa",
		        "enrichment_path": "336292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336292.protein.info.v11.5.txt",
		        "node_list_path": "336292.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwb13613(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWB1_36_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwb13613", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802174.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802174.protein.info.v11.5.txt",
		        "node_list_path": "1802174.protein.complete.v11.5.txt"
		    }
		]
    )()

def AngiostrongylusCantonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Angiostrongylus cantonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AngiostrongylusCantonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6313.clusters.proteins.v11.5.txt",
		        "sequence_path": "6313.protein.sequences.v11.5.fa",
		        "enrichment_path": "6313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6313.protein.info.v11.5.txt",
		        "node_list_path": "6313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphaeroformaArcticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaeroforma arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaeroformaArcticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "72019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "72019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "72019.clusters.proteins.v11.5.txt",
		        "sequence_path": "72019.protein.sequences.v11.5.fa",
		        "enrichment_path": "72019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72019.protein.info.v11.5.txt",
		        "node_list_path": "72019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "72019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalovivaxAsiaticusJcm14624Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halovivax asiaticus JCM 14624 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalovivaxAsiaticusJcm14624Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227490.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227490.protein.info.v11.5.txt",
		        "node_list_path": "1227490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioFibrisolvensDsm3071Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens DSM 3071 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioFibrisolvensDsm3071Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121131.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121131.protein.info.v11.5.txt",
		        "node_list_path": "1121131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpNTMorphotypeB(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. N.t. morphotype B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpNTMorphotypeB", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "420336.protein.sequences.v11.5.fa",
		        "enrichment_path": "420336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420336.protein.info.v11.5.txt",
		        "node_list_path": "420336.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasHydrophilaAtcc7966(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila ATCC7966 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasHydrophilaAtcc7966", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "380703.protein.sequences.v11.5.fa",
		        "enrichment_path": "380703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380703.protein.info.v11.5.txt",
		        "node_list_path": "380703.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaModicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma modicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaModicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408417.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408417.protein.info.v11.5.txt",
		        "node_list_path": "1408417.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisListeriNbrc13360Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis listeri NBRC 13360 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisListeriNbrc13360Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348637.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348637.protein.info.v11.5.txt",
		        "node_list_path": "1348637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcaceaeBacteriumCm5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium CM5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcaceaeBacteriumCm5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "796940.protein.sequences.v11.5.fa",
		        "enrichment_path": "796940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796940.protein.info.v11.5.txt",
		        "node_list_path": "796940.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalopigerSpIih2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halopiger sp. IIH2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalopigerSpIih2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293047.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293047.protein.info.v11.5.txt",
		        "node_list_path": "1293047.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycesMarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces maris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycesMarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "344747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "344747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "344747.clusters.proteins.v11.5.txt",
		        "sequence_path": "344747.protein.sequences.v11.5.fa",
		        "enrichment_path": "344747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "344747.protein.info.v11.5.txt",
		        "node_list_path": "344747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "344747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusJannaschii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus jannaschii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusJannaschii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243232.protein.sequences.v11.5.fa",
		        "enrichment_path": "243232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243232.protein.info.v11.5.txt",
		        "node_list_path": "243232.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaRwandensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea rwandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaRwandensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1076550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1076550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1076550.clusters.proteins.v11.5.txt",
		        "sequence_path": "1076550.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076550.protein.info.v11.5.txt",
		        "node_list_path": "1076550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1076550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FulvimarinaManganoxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fulvimarina manganoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FulvimarinaManganoxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "937218.protein.sequences.v11.5.fa",
		        "enrichment_path": "937218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937218.protein.info.v11.5.txt",
		        "node_list_path": "937218.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusBarengoltziiG22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus barengoltzii G22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusBarengoltziiG22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235795.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235795.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235795.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235795.protein.info.v11.5.txt",
		        "node_list_path": "1235795.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235795.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWalczuchellaMonophlebidarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Walczuchella monophlebidarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWalczuchellaMonophlebidarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415657.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415657.protein.info.v11.5.txt",
		        "node_list_path": "1415657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KaistiaGranuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kaistia granuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KaistiaGranuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122132.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122132.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122132.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122132.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122132.protein.info.v11.5.txt",
		        "node_list_path": "1122132.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122132.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumKishitaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium kishitanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumKishitaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "318456.clusters.info.v11.5.txt",
		        "cluster_tree_path": "318456.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "318456.clusters.proteins.v11.5.txt",
		        "sequence_path": "318456.protein.sequences.v11.5.fa",
		        "enrichment_path": "318456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318456.protein.info.v11.5.txt",
		        "node_list_path": "318456.cluster.nodes.v11.5.txt",
		        "edge_list_path": "318456.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeoglobusAcetivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geoglobus acetivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeoglobusAcetivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "565033.protein.sequences.v11.5.fa",
		        "enrichment_path": "565033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565033.protein.info.v11.5.txt",
		        "node_list_path": "565033.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaeBacteriumRifcsphigho212Full278Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPHIGHO2_12_FULL_27_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaeBacteriumRifcsphigho212Full278Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797601.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797601.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797601.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797601.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797601.protein.info.v11.5.txt",
		        "node_list_path": "1797601.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797601.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodospirillalesBacterium6911Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium 69-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillalesBacterium6911Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895825.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895825.protein.info.v11.5.txt",
		        "node_list_path": "1895825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BatrachochytriumSalamandrivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Batrachochytrium salamandrivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BatrachochytriumSalamandrivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1357716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357716.protein.info.v11.5.txt",
		        "node_list_path": "1357716.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxCaeni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxCaeni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "343013.protein.sequences.v11.5.fa",
		        "enrichment_path": "343013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "343013.protein.info.v11.5.txt",
		        "node_list_path": "343013.protein.complete.v11.5.txt"
		    }
		]
    )()

def SediminibacteriumSpC3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium sp. C3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacteriumSpC3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267211.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267211.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267211.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267211.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267211.protein.info.v11.5.txt",
		        "node_list_path": "1267211.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267211.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSp6754Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. 67-54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSp6754Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895754.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895754.protein.info.v11.5.txt",
		        "node_list_path": "1895754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrenarchaeotaArchaeon13140cm3535(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_53_5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenarchaeotaArchaeon13140cm3535", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805098.protein.info.v11.5.txt",
		        "node_list_path": "1805098.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110052(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110052 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110052", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1570341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570341.protein.info.v11.5.txt",
		        "node_list_path": "1570341.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumChocolatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium chocolatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumChocolatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84292.clusters.proteins.v11.5.txt",
		        "sequence_path": "84292.protein.sequences.v11.5.fa",
		        "enrichment_path": "84292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84292.protein.info.v11.5.txt",
		        "node_list_path": "84292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioKanaloae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio kanaloae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioKanaloae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1191299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1191299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1191299.protein.info.v11.5.txt",
		        "node_list_path": "1191299.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusHunanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus hunanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusHunanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "578214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "578214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "578214.clusters.proteins.v11.5.txt",
		        "sequence_path": "578214.protein.sequences.v11.5.fa",
		        "enrichment_path": "578214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578214.protein.info.v11.5.txt",
		        "node_list_path": "578214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "578214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DethiosulfatarculusSandiegensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dethiosulfatarculus sandiegensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DethiosulfatarculusSandiegensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1429043.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1429043.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1429043.clusters.proteins.v11.5.txt",
		        "sequence_path": "1429043.protein.sequences.v11.5.fa",
		        "enrichment_path": "1429043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1429043.protein.info.v11.5.txt",
		        "node_list_path": "1429043.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1429043.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrionalesBacteriumGwa2659(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrionales bacterium GWA2_65_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrionalesBacteriumGwa2659", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797915.protein.info.v11.5.txt",
		        "node_list_path": "1797915.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusFicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus ficus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusFicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "317577.protein.sequences.v11.5.fa",
		        "enrichment_path": "317577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317577.protein.info.v11.5.txt",
		        "node_list_path": "317577.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaRupisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga rupis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaRupisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573321.clusters.proteins.v11.5.txt",
		        "sequence_path": "573321.protein.sequences.v11.5.fa",
		        "enrichment_path": "573321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573321.protein.info.v11.5.txt",
		        "node_list_path": "573321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasSpAl212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. AL212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasSpAl212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "153948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "153948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "153948.clusters.proteins.v11.5.txt",
		        "sequence_path": "153948.protein.sequences.v11.5.fa",
		        "enrichment_path": "153948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "153948.protein.info.v11.5.txt",
		        "node_list_path": "153948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "153948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FructobacillusDurionisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fructobacillus durionis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FructobacillusDurionisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "283737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "283737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "283737.clusters.proteins.v11.5.txt",
		        "sequence_path": "283737.protein.sequences.v11.5.fa",
		        "enrichment_path": "283737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283737.protein.info.v11.5.txt",
		        "node_list_path": "283737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "283737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSoil782(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil782 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSoil782", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736410.protein.info.v11.5.txt",
		        "node_list_path": "1736410.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaSubspSalamaeSerovar56Z10ENXStr136973Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. salamae serovar 56:z10:e,n,x str. 1369-73 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaSubspSalamaeSerovar56Z10ENXStr136973Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1243604.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1243604.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1243604.clusters.proteins.v11.5.txt",
		        "sequence_path": "1243604.protein.sequences.v11.5.fa",
		        "enrichment_path": "1243604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1243604.protein.info.v11.5.txt",
		        "node_list_path": "1243604.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1243604.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumHochsteniumAtcc700873(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum hochstenium ATCC 700873 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumHochsteniumAtcc700873", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227481.protein.info.v11.5.txt",
		        "node_list_path": "1227481.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyadobacterSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "659014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "659014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "659014.clusters.proteins.v11.5.txt",
		        "sequence_path": "659014.protein.sequences.v11.5.fa",
		        "enrichment_path": "659014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "659014.protein.info.v11.5.txt",
		        "node_list_path": "659014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "659014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCf046(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. cf046 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCf046", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761803.protein.info.v11.5.txt",
		        "node_list_path": "1761803.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium32Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium32Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235799.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235799.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235799.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235799.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235799.protein.info.v11.5.txt",
		        "node_list_path": "1235799.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235799.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrososphaeraGargensisGa92(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrososphaera gargensis Ga9.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrososphaeraGargensisGa92", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1237085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1237085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1237085.protein.info.v11.5.txt",
		        "node_list_path": "1237085.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteralesBacteriumRifcsphigho202Full62130Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium RIFCSPHIGHO2_02_FULL_62_130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteralesBacteriumRifcsphigho202Full62130Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802014.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802014.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802014.protein.info.v11.5.txt",
		        "node_list_path": "1802014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MillionellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Millionella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MillionellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871023.protein.info.v11.5.txt",
		        "node_list_path": "1871023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusHomiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus homiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusHomiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "364199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "364199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "364199.clusters.proteins.v11.5.txt",
		        "sequence_path": "364199.protein.sequences.v11.5.fa",
		        "enrichment_path": "364199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "364199.protein.info.v11.5.txt",
		        "node_list_path": "364199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "364199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAceticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium aceticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAceticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84022.clusters.proteins.v11.5.txt",
		        "sequence_path": "84022.protein.sequences.v11.5.fa",
		        "enrichment_path": "84022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84022.protein.info.v11.5.txt",
		        "node_list_path": "84022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSp446Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 446 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSp446Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426117.clusters.proteins.v11.5.txt",
		        "sequence_path": "426117.protein.sequences.v11.5.fa",
		        "enrichment_path": "426117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426117.protein.info.v11.5.txt",
		        "node_list_path": "426117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpHixCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. HIX Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpHixCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1759074.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1759074.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1759074.clusters.proteins.v11.5.txt",
		        "sequence_path": "1759074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759074.protein.info.v11.5.txt",
		        "node_list_path": "1759074.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1759074.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag609(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:609 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag609", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262827.protein.info.v11.5.txt",
		        "node_list_path": "1262827.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesOceaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces oceani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesOceaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1075402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1075402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1075402.clusters.proteins.v11.5.txt",
		        "sequence_path": "1075402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1075402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1075402.protein.info.v11.5.txt",
		        "node_list_path": "1075402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1075402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomonasKoyamae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas koyamae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasKoyamae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "702114.protein.sequences.v11.5.fa",
		        "enrichment_path": "702114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702114.protein.info.v11.5.txt",
		        "node_list_path": "702114.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusSanguinicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus sanguinicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusSanguinicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "119206.protein.sequences.v11.5.fa",
		        "enrichment_path": "119206.protein.enrichment.terms.v11.5.txt",
		        "info_path": "119206.protein.info.v11.5.txt",
		        "node_list_path": "119206.protein.complete.v11.5.txt"
		    }
		]
    )()

def FonsecaeaPedrosoiCbs27137Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fonsecaea pedrosoi CBS 271.37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FonsecaeaPedrosoiCbs27137Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1442368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1442368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1442368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1442368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1442368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1442368.protein.info.v11.5.txt",
		        "node_list_path": "1442368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1442368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichophytonInterdigitaleMr816(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton interdigitale MR816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichophytonInterdigitaleMr816", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1215338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215338.protein.info.v11.5.txt",
		        "node_list_path": "1215338.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacteraceaeBacteriumOtszA272Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacteraceae bacterium OTSz_A_272 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacteraceaeBacteriumOtszA272Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1759059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1759059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1759059.clusters.proteins.v11.5.txt",
		        "sequence_path": "1759059.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759059.protein.info.v11.5.txt",
		        "node_list_path": "1759059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1759059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpLs16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. LS16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpLs16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1690248.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690248.protein.info.v11.5.txt",
		        "node_list_path": "1690248.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesBacteriumScgcAaa011L6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates bacterium SCGC AAA011-L6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesBacteriumScgcAaa011L6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "699262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "699262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "699262.clusters.proteins.v11.5.txt",
		        "sequence_path": "699262.protein.sequences.v11.5.fa",
		        "enrichment_path": "699262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "699262.protein.info.v11.5.txt",
		        "node_list_path": "699262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "699262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AminobacterSpRoot100(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aminobacter sp. Root100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminobacterSpRoot100", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736420.protein.info.v11.5.txt",
		        "node_list_path": "1736420.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumGlucuronolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium glucuronolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumGlucuronolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "548477.protein.sequences.v11.5.fa",
		        "enrichment_path": "548477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "548477.protein.info.v11.5.txt",
		        "node_list_path": "548477.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasGuineaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas guineae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasGuineaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "425504.clusters.info.v11.5.txt",
		        "cluster_tree_path": "425504.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "425504.clusters.proteins.v11.5.txt",
		        "sequence_path": "425504.protein.sequences.v11.5.fa",
		        "enrichment_path": "425504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425504.protein.info.v11.5.txt",
		        "node_list_path": "425504.cluster.nodes.v11.5.txt",
		        "edge_list_path": "425504.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythruraGouldiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrura gouldiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythruraGouldiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44316.clusters.proteins.v11.5.txt",
		        "sequence_path": "44316.protein.sequences.v11.5.fa",
		        "enrichment_path": "44316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44316.protein.info.v11.5.txt",
		        "node_list_path": "44316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaBrunensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella brunensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaBrunensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29422.clusters.proteins.v11.5.txt",
		        "sequence_path": "29422.protein.sequences.v11.5.fa",
		        "enrichment_path": "29422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29422.protein.info.v11.5.txt",
		        "node_list_path": "29422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinoplanesDerwentensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes derwentensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesDerwentensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "113562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "113562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "113562.clusters.proteins.v11.5.txt",
		        "sequence_path": "113562.protein.sequences.v11.5.fa",
		        "enrichment_path": "113562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113562.protein.info.v11.5.txt",
		        "node_list_path": "113562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "113562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MalasseziaRestrictaCbs7877(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Malassezia restricta CBS 7877 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalasseziaRestrictaCbs7877", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "425264.protein.sequences.v11.5.fa",
		        "enrichment_path": "425264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425264.protein.info.v11.5.txt",
		        "node_list_path": "425264.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesLuteocolorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces luteocolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesLuteocolorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "285500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "285500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "285500.clusters.proteins.v11.5.txt",
		        "sequence_path": "285500.protein.sequences.v11.5.fa",
		        "enrichment_path": "285500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285500.protein.info.v11.5.txt",
		        "node_list_path": "285500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "285500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumShigense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium shigense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumShigense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "297244.protein.sequences.v11.5.fa",
		        "enrichment_path": "297244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "297244.protein.info.v11.5.txt",
		        "node_list_path": "297244.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsaiaPrunellaeJcm25354Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asaia prunellae JCM 25354 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsaiaPrunellaeJcm25354Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236502.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236502.protein.info.v11.5.txt",
		        "node_list_path": "1236502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteusPenneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteus penneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteusPenneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471881.protein.sequences.v11.5.fa",
		        "enrichment_path": "471881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471881.protein.info.v11.5.txt",
		        "node_list_path": "471881.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChrysiogenesArsenatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chrysiogenes arsenatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChrysiogenesArsenatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118005.clusters.proteins.v11.5.txt",
		        "sequence_path": "118005.protein.sequences.v11.5.fa",
		        "enrichment_path": "118005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118005.protein.info.v11.5.txt",
		        "node_list_path": "118005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumLeprae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium leprae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumLeprae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272631.protein.sequences.v11.5.fa",
		        "enrichment_path": "272631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272631.protein.info.v11.5.txt",
		        "node_list_path": "272631.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonopterusAlbusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monopterus albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonopterusAlbusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43700.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43700.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43700.clusters.proteins.v11.5.txt",
		        "sequence_path": "43700.protein.sequences.v11.5.fa",
		        "enrichment_path": "43700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43700.protein.info.v11.5.txt",
		        "node_list_path": "43700.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43700.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LiberibacterAsiaticusGxpsyCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus gxpsy Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LiberibacterAsiaticusGxpsyCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1174529.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1174529.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1174529.clusters.proteins.v11.5.txt",
		        "sequence_path": "1174529.protein.sequences.v11.5.fa",
		        "enrichment_path": "1174529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1174529.protein.info.v11.5.txt",
		        "node_list_path": "1174529.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1174529.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMethanolicusPb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus methanolicus PB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMethanolicusPb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "997296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "997296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "997296.clusters.proteins.v11.5.txt",
		        "sequence_path": "997296.protein.sequences.v11.5.fa",
		        "enrichment_path": "997296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997296.protein.info.v11.5.txt",
		        "node_list_path": "997296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "997296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesSpCag409Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides sp. CAG:409 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesSpCag409Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262913.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262913.protein.info.v11.5.txt",
		        "node_list_path": "1262913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerticilliumDahliaeVdls17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verticillium dahliae VdLs.17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerticilliumDahliaeVdls17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "498257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "498257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "498257.clusters.proteins.v11.5.txt",
		        "sequence_path": "498257.protein.sequences.v11.5.fa",
		        "enrichment_path": "498257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498257.protein.info.v11.5.txt",
		        "node_list_path": "498257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "498257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumTestaceum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium testaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumTestaceum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "979556.protein.sequences.v11.5.fa",
		        "enrichment_path": "979556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "979556.protein.info.v11.5.txt",
		        "node_list_path": "979556.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "394264.protein.sequences.v11.5.fa",
		        "enrichment_path": "394264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394264.protein.info.v11.5.txt",
		        "node_list_path": "394264.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpChd6aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. CHD6a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpChd6aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1643452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1643452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1643452.clusters.proteins.v11.5.txt",
		        "sequence_path": "1643452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643452.protein.info.v11.5.txt",
		        "node_list_path": "1643452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1643452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlternariaAlternata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alternaria alternata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlternariaAlternata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5599.protein.sequences.v11.5.fa",
		        "enrichment_path": "5599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5599.protein.info.v11.5.txt",
		        "node_list_path": "5599.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterJohnsoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter johnsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterJohnsoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575586.clusters.proteins.v11.5.txt",
		        "sequence_path": "575586.protein.sequences.v11.5.fa",
		        "enrichment_path": "575586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575586.protein.info.v11.5.txt",
		        "node_list_path": "575586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAnthracisSterne(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis Sterne graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAnthracisSterne", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "260799.protein.sequences.v11.5.fa",
		        "enrichment_path": "260799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "260799.protein.info.v11.5.txt",
		        "node_list_path": "260799.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaFermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaFermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "496833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "496833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "496833.clusters.proteins.v11.5.txt",
		        "sequence_path": "496833.protein.sequences.v11.5.fa",
		        "enrichment_path": "496833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "496833.protein.info.v11.5.txt",
		        "node_list_path": "496833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "496833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPropinquum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium propinquum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPropinquum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121367.protein.info.v11.5.txt",
		        "node_list_path": "1121367.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryobacteriumArcticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryobacterium arcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryobacteriumArcticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "670052.protein.sequences.v11.5.fa",
		        "enrichment_path": "670052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670052.protein.info.v11.5.txt",
		        "node_list_path": "670052.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumD5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium D5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumD5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520815.protein.info.v11.5.txt",
		        "node_list_path": "1520815.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMuproteobacteriaBacteriumRbg166534Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_65_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166534Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817760.protein.info.v11.5.txt",
		        "node_list_path": "1817760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasMaltophiliaR5513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia R5513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasMaltophiliaR5513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391008.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391008.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391008.clusters.proteins.v11.5.txt",
		        "sequence_path": "391008.protein.sequences.v11.5.fa",
		        "enrichment_path": "391008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391008.protein.info.v11.5.txt",
		        "node_list_path": "391008.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391008.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumLepraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium leprae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumLepraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272631.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272631.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272631.clusters.proteins.v11.5.txt",
		        "sequence_path": "272631.protein.sequences.v11.5.fa",
		        "enrichment_path": "272631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272631.protein.info.v11.5.txt",
		        "node_list_path": "272631.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272631.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusManasiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus manasiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusManasiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "586413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "586413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "586413.clusters.proteins.v11.5.txt",
		        "sequence_path": "586413.protein.sequences.v11.5.fa",
		        "enrichment_path": "586413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "586413.protein.info.v11.5.txt",
		        "node_list_path": "586413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "586413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SodiomycesAlkalinusF11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sodiomyces alkalinus F11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SodiomycesAlkalinusF11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314773.protein.info.v11.5.txt",
		        "node_list_path": "1314773.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusAsaccharolyticusDsm20463(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus asaccharolyticus DSM 20463 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusAsaccharolyticusDsm20463", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573058.protein.sequences.v11.5.fa",
		        "enrichment_path": "573058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573058.protein.info.v11.5.txt",
		        "node_list_path": "573058.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpDjl10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. djl-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpDjl10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1879023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1879023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1879023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1879023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1879023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1879023.protein.info.v11.5.txt",
		        "node_list_path": "1879023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1879023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobaculumLitoreumDsm18839(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassobaculum litoreum DSM 18839 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobaculumLitoreumDsm18839", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123362.protein.info.v11.5.txt",
		        "node_list_path": "1123362.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19035Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19035 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19035Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1460653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1460653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1460653.clusters.proteins.v11.5.txt",
		        "sequence_path": "1460653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460653.protein.info.v11.5.txt",
		        "node_list_path": "1460653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1460653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CylindrospermumStagnaleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cylindrospermum stagnale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CylindrospermumStagnaleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56107.clusters.proteins.v11.5.txt",
		        "sequence_path": "56107.protein.sequences.v11.5.fa",
		        "enrichment_path": "56107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56107.protein.info.v11.5.txt",
		        "node_list_path": "56107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCrustorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus crustorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCrustorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "392416.protein.sequences.v11.5.fa",
		        "enrichment_path": "392416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392416.protein.info.v11.5.txt",
		        "node_list_path": "392416.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifoxyb1Full4113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYB1_FULL_41_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyb1Full4113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802540.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802540.protein.info.v11.5.txt",
		        "node_list_path": "1802540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerotruncusSpCag390Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. CAG:390 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotruncusSpCag390Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262703.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262703.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262703.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262703.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262703.protein.info.v11.5.txt",
		        "node_list_path": "1262703.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262703.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200251163Sch5372311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-51163_SCH5372311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200251163Sch5372311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834097.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834097.protein.info.v11.5.txt",
		        "node_list_path": "1834097.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioScophthalmiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio scophthalmi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioScophthalmiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "870967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "870967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "870967.clusters.proteins.v11.5.txt",
		        "sequence_path": "870967.protein.sequences.v11.5.fa",
		        "enrichment_path": "870967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "870967.protein.info.v11.5.txt",
		        "node_list_path": "870967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "870967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacteriumWoodii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacterium woodii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacteriumWoodii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "931626.protein.sequences.v11.5.fa",
		        "enrichment_path": "931626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "931626.protein.info.v11.5.txt",
		        "node_list_path": "931626.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumFournierii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium fournierii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumFournierii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852390.protein.info.v11.5.txt",
		        "node_list_path": "1852390.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3812Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_38_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3812Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802061.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802061.protein.info.v11.5.txt",
		        "node_list_path": "1802061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumRussiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium russii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumRussiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278306.protein.info.v11.5.txt",
		        "node_list_path": "1278306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraSojaeStrainP6497(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora sojae strain P6497 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraSojaeStrainP6497", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094619.protein.info.v11.5.txt",
		        "node_list_path": "1094619.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioMexicanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio mexicanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioMexicanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1004326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004326.protein.info.v11.5.txt",
		        "node_list_path": "1004326.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpAt1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. AT1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpAt1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "574934.clusters.info.v11.5.txt",
		        "cluster_tree_path": "574934.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "574934.clusters.proteins.v11.5.txt",
		        "sequence_path": "574934.protein.sequences.v11.5.fa",
		        "enrichment_path": "574934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574934.protein.info.v11.5.txt",
		        "node_list_path": "574934.cluster.nodes.v11.5.txt",
		        "edge_list_path": "574934.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrobacterFreundiiCfnih1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter freundii CFNIH1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterFreundiiCfnih1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1333848.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333848.protein.info.v11.5.txt",
		        "node_list_path": "1333848.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusOdoriferCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus odorifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusOdoriferCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "189426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "189426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "189426.clusters.proteins.v11.5.txt",
		        "sequence_path": "189426.protein.sequences.v11.5.fa",
		        "enrichment_path": "189426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189426.protein.info.v11.5.txt",
		        "node_list_path": "189426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "189426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioBrasiliensisJcm12178Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio brasiliensis JCM 12178 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioBrasiliensisJcm12178Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1294020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1294020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1294020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1294020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294020.protein.info.v11.5.txt",
		        "node_list_path": "1294020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1294020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusAlvei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Paenibacillus alvei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusAlvei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117108.protein.sequences.v11.0.fa",
		        "enrichment_path": "1117108.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1117108.protein.info.v11.0.txt",
		        "node_list_path": "1117108.protein.complete.v11.0.txt"
		    }
		]
    )()

def EquusCaballus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Equus caballus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EquusCaballus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9796.protein.sequences.v11.5.fa",
		        "enrichment_path": "9796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9796.protein.info.v11.5.txt",
		        "node_list_path": "9796.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumMultivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum multivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumMultivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150621.protein.info.v11.5.txt",
		        "node_list_path": "1150621.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf23810(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_38_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf23810", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619084.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619084.protein.info.v11.5.txt",
		        "node_list_path": "1619084.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwe24116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWE2_41_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwe24116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619075.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619075.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619075.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619075.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619075.protein.info.v11.5.txt",
		        "node_list_path": "1619075.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619075.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaDubliniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida dubliniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaDubliniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42374.clusters.proteins.v11.5.txt",
		        "sequence_path": "42374.protein.sequences.v11.5.fa",
		        "enrichment_path": "42374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42374.protein.info.v11.5.txt",
		        "node_list_path": "42374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumPolynesienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium polynesiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPolynesienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1325933.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1325933.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1325933.clusters.proteins.v11.5.txt",
		        "sequence_path": "1325933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325933.protein.info.v11.5.txt",
		        "node_list_path": "1325933.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1325933.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1291743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1291743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1291743.clusters.proteins.v11.5.txt",
		        "sequence_path": "1291743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291743.protein.info.v11.5.txt",
		        "node_list_path": "1291743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1291743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpCf284(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. CF284 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpCf284", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500281.protein.info.v11.5.txt",
		        "node_list_path": "1500281.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMinor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus minor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMinor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123309.protein.info.v11.5.txt",
		        "node_list_path": "1123309.protein.complete.v11.5.txt"
		    }
		]
    )()

def MacellibacteroidesSpHhZsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Macellibacteroides sp. HH-ZS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacellibacteroidesSpHhZsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1857568.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1857568.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1857568.clusters.proteins.v11.5.txt",
		        "sequence_path": "1857568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1857568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1857568.protein.info.v11.5.txt",
		        "node_list_path": "1857568.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1857568.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesJeddahensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces jeddahensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesJeddahensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1716141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1716141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1716141.protein.info.v11.5.txt",
		        "node_list_path": "1716141.protein.complete.v11.5.txt"
		    }
		]
    )()

def PneumocystisJiroveciiSe8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii SE8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PneumocystisJiroveciiSe8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1209962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1209962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1209962.protein.info.v11.5.txt",
		        "node_list_path": "1209962.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelcobacillusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helcobacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelcobacillusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521392.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521392.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521392.clusters.proteins.v11.5.txt",
		        "sequence_path": "521392.protein.sequences.v11.5.fa",
		        "enrichment_path": "521392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521392.protein.info.v11.5.txt",
		        "node_list_path": "521392.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521392.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlycomycesHarbinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glycomyces harbinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlycomycesHarbinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "58114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "58114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "58114.clusters.proteins.v11.5.txt",
		        "sequence_path": "58114.protein.sequences.v11.5.fa",
		        "enrichment_path": "58114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58114.protein.info.v11.5.txt",
		        "node_list_path": "58114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "58114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseomonasRosea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseomonasRosea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "198092.protein.sequences.v11.5.fa",
		        "enrichment_path": "198092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198092.protein.info.v11.5.txt",
		        "node_list_path": "198092.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnabasTestudineus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anabas testudineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabasTestudineus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "64144.protein.sequences.v11.5.fa",
		        "enrichment_path": "64144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64144.protein.info.v11.5.txt",
		        "node_list_path": "64144.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaPecorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pecorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaPecorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "331635.protein.sequences.v11.5.fa",
		        "enrichment_path": "331635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331635.protein.info.v11.5.txt",
		        "node_list_path": "331635.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwc25546Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_55_46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc25546Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797818.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797818.protein.info.v11.5.txt",
		        "node_list_path": "1797818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasSpNm166(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm166 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasSpNm166", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881054.protein.info.v11.5.txt",
		        "node_list_path": "1881054.protein.complete.v11.5.txt"
		    }
		]
    )()

def CephaloticoccusCapnophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cephaloticoccus capnophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CephaloticoccusCapnophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1548208.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1548208.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1548208.clusters.proteins.v11.5.txt",
		        "sequence_path": "1548208.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548208.protein.info.v11.5.txt",
		        "node_list_path": "1548208.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1548208.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag65Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag65Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262994.protein.info.v11.5.txt",
		        "node_list_path": "1262994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaLimicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena limicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaLimicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230457.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230457.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230457.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230457.protein.info.v11.5.txt",
		        "node_list_path": "1230457.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230457.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaLupini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea lupini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaLupini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1036779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036779.protein.info.v11.5.txt",
		        "node_list_path": "1036779.protein.complete.v11.5.txt"
		    }
		]
    )()

def FuchsiellaAlkaliacetigenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fuchsiella alkaliacetigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FuchsiellaAlkaliacetigenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "957042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "957042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "957042.clusters.proteins.v11.5.txt",
		        "sequence_path": "957042.protein.sequences.v11.5.fa",
		        "enrichment_path": "957042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "957042.protein.info.v11.5.txt",
		        "node_list_path": "957042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "957042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusTestis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus testis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusTestis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1622072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622072.protein.info.v11.5.txt",
		        "node_list_path": "1622072.protein.complete.v11.5.txt"
		    }
		]
    )()

def SmittiumMucronatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Smittium mucronatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmittiumMucronatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "133383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "133383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "133383.clusters.proteins.v11.5.txt",
		        "sequence_path": "133383.protein.sequences.v11.5.fa",
		        "enrichment_path": "133383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133383.protein.info.v11.5.txt",
		        "node_list_path": "133383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "133383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasPolarisDsm16579Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas polaris DSM 16579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasPolarisDsm16579Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122206.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122206.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122206.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122206.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122206.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122206.protein.info.v11.5.txt",
		        "node_list_path": "1122206.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122206.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharibacterFloricolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharibacter floricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharibacterFloricolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123227.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123227.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123227.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123227.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123227.protein.info.v11.5.txt",
		        "node_list_path": "1123227.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123227.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaMonticola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia monticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaMonticola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1399968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399968.protein.info.v11.5.txt",
		        "node_list_path": "1399968.protein.complete.v11.5.txt"
		    }
		]
    )()

def RothiaKristinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rothia kristinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RothiaKristinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37923.protein.sequences.v11.5.fa",
		        "enrichment_path": "37923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37923.protein.info.v11.5.txt",
		        "node_list_path": "37923.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc11e11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC11E11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc11e11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1581089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581089.protein.info.v11.5.txt",
		        "node_list_path": "1581089.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhaeobacterSpCect7735Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter sp. CECT 7735 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterSpCect7735Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1715693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1715693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1715693.clusters.proteins.v11.5.txt",
		        "sequence_path": "1715693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715693.protein.info.v11.5.txt",
		        "node_list_path": "1715693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1715693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpRoot112d2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root112D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpRoot112d2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736426.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736426.protein.info.v11.5.txt",
		        "node_list_path": "1736426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrocarboniphagaDaqingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga daqingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrocarboniphagaDaqingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "490188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "490188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "490188.clusters.proteins.v11.5.txt",
		        "sequence_path": "490188.protein.sequences.v11.5.fa",
		        "enrichment_path": "490188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "490188.protein.info.v11.5.txt",
		        "node_list_path": "490188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "490188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacterium13140cm46819Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium 13_1_40CM_4_68_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacterium13140cm46819Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805121.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805121.protein.info.v11.5.txt",
		        "node_list_path": "1805121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumChiriqhuchaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium chiriqhucha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumChiriqhuchaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385984.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385984.protein.info.v11.5.txt",
		        "node_list_path": "1385984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumPh28Bin88(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium PH28_bin88 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumPh28Bin88", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1605376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1605376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1605376.protein.info.v11.5.txt",
		        "node_list_path": "1605376.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumGwa25511Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_55_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumGwa25511Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798421.protein.info.v11.5.txt",
		        "node_list_path": "1798421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacterium3317Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 33-17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacterium3317Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895704.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895704.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895704.protein.info.v11.5.txt",
		        "node_list_path": "1895704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraNoguchiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira noguchii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraNoguchiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28182.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28182.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28182.clusters.proteins.v11.5.txt",
		        "sequence_path": "28182.protein.sequences.v11.5.fa",
		        "enrichment_path": "28182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28182.protein.info.v11.5.txt",
		        "node_list_path": "28182.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28182.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwb1388Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_38_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb1388Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618570.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618570.protein.info.v11.5.txt",
		        "node_list_path": "1618570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumGenavenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium genavense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumGenavenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408452.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408452.protein.info.v11.5.txt",
		        "node_list_path": "1408452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusOnnurineusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus onnurineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusOnnurineusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "523850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "523850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "523850.clusters.proteins.v11.5.txt",
		        "sequence_path": "523850.protein.sequences.v11.5.fa",
		        "enrichment_path": "523850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523850.protein.info.v11.5.txt",
		        "node_list_path": "523850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "523850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasChangbaiensisNbrc104936Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas changbaiensis NBRC 104936 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasChangbaiensisNbrc104936Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219043.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219043.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219043.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219043.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219043.protein.info.v11.5.txt",
		        "node_list_path": "1219043.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219043.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LutibacterMaritimusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lutibacter maritimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutibacterMaritimusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "593133.clusters.info.v11.5.txt",
		        "cluster_tree_path": "593133.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "593133.clusters.proteins.v11.5.txt",
		        "sequence_path": "593133.protein.sequences.v11.5.fa",
		        "enrichment_path": "593133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "593133.protein.info.v11.5.txt",
		        "node_list_path": "593133.cluster.nodes.v11.5.txt",
		        "edge_list_path": "593133.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnsiferAridi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer aridi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferAridi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1708715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1708715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1708715.protein.info.v11.5.txt",
		        "node_list_path": "1708715.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaSpOmz838(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema sp. OMZ838 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSpOmz838", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1539298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1539298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1539298.protein.info.v11.5.txt",
		        "node_list_path": "1539298.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSanfranciscensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sanfranciscensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSanfranciscensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "714313.protein.sequences.v11.5.fa",
		        "enrichment_path": "714313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "714313.protein.info.v11.5.txt",
		        "node_list_path": "714313.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumGaetbulicolaGung47(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium gaetbulicola Gung47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumGaetbulicolaGung47", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658445.protein.sequences.v11.5.fa",
		        "enrichment_path": "658445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658445.protein.info.v11.5.txt",
		        "node_list_path": "658445.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobiumPhaeobacteroidesDsm266(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium phaeobacteroides DSM266 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumPhaeobacteroidesDsm266", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290317.protein.sequences.v11.5.fa",
		        "enrichment_path": "290317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290317.protein.info.v11.5.txt",
		        "node_list_path": "290317.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanolaciniaPaynteri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanolacinia paynteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolaciniaPaynteri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "230356.protein.sequences.v11.5.fa",
		        "enrichment_path": "230356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "230356.protein.info.v11.5.txt",
		        "node_list_path": "230356.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpAc2005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AC2005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpAc2005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280672.protein.info.v11.5.txt",
		        "node_list_path": "1280672.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumYim77505(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium YIM77505 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumYim77505", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1411123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1411123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1411123.protein.info.v11.5.txt",
		        "node_list_path": "1411123.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexusAggregansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexus aggregans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexusAggregansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326427.clusters.proteins.v11.5.txt",
		        "sequence_path": "326427.protein.sequences.v11.5.fa",
		        "enrichment_path": "326427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326427.protein.info.v11.5.txt",
		        "node_list_path": "326427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSzulgaiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium szulgai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSzulgaiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1787.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1787.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1787.clusters.proteins.v11.5.txt",
		        "sequence_path": "1787.protein.sequences.v11.5.fa",
		        "enrichment_path": "1787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1787.protein.info.v11.5.txt",
		        "node_list_path": "1787.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1787.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusWeihenstephanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus weihenstephanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusWeihenstephanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "315730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "315730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "315730.clusters.proteins.v11.5.txt",
		        "sequence_path": "315730.protein.sequences.v11.5.fa",
		        "enrichment_path": "315730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "315730.protein.info.v11.5.txt",
		        "node_list_path": "315730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "315730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsplowo212Full4312Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_12_FULL_43_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo212Full4312Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798692.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798692.protein.info.v11.5.txt",
		        "node_list_path": "1798692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpAle5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. ALE5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpAle5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "748650.clusters.info.v11.5.txt",
		        "cluster_tree_path": "748650.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "748650.clusters.proteins.v11.5.txt",
		        "sequence_path": "748650.protein.sequences.v11.5.fa",
		        "enrichment_path": "748650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748650.protein.info.v11.5.txt",
		        "node_list_path": "748650.cluster.nodes.v11.5.txt",
		        "edge_list_path": "748650.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzorhizobiumDoebereinerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azorhizobium doebereinerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzorhizobiumDoebereinerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1038858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038858.protein.info.v11.5.txt",
		        "node_list_path": "1038858.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaSputigena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga sputigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaSputigena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553177.protein.sequences.v11.5.fa",
		        "enrichment_path": "553177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553177.protein.info.v11.5.txt",
		        "node_list_path": "553177.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumRubi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium rubi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumRubi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28099.protein.sequences.v11.5.fa",
		        "enrichment_path": "28099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28099.protein.info.v11.5.txt",
		        "node_list_path": "28099.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag230(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:230 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag230", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262782.protein.info.v11.5.txt",
		        "node_list_path": "1262782.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumLindaniclasticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium lindaniclasticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumLindaniclasticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1096930.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1096930.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1096930.clusters.proteins.v11.5.txt",
		        "sequence_path": "1096930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1096930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1096930.protein.info.v11.5.txt",
		        "node_list_path": "1096930.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1096930.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumGilvum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium gilvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumGilvum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1130080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1130080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1130080.protein.info.v11.5.txt",
		        "node_list_path": "1130080.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterSpMit115569Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT115569 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSpMit115569Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1548151.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1548151.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1548151.clusters.proteins.v11.5.txt",
		        "sequence_path": "1548151.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548151.protein.info.v11.5.txt",
		        "node_list_path": "1548151.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1548151.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GaleopterusVariegatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Galeopterus variegatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GaleopterusVariegatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "482537.protein.sequences.v11.5.fa",
		        "enrichment_path": "482537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "482537.protein.info.v11.5.txt",
		        "node_list_path": "482537.protein.complete.v11.5.txt"
		    }
		]
    )()

def KnoelliaAerolata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Knoellia aerolata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KnoelliaAerolata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385519.protein.info.v11.5.txt",
		        "node_list_path": "1385519.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerocolumnaAminovalericaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerocolumna aminovalerica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerocolumnaAminovalericaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1527.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1527.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1527.clusters.proteins.v11.5.txt",
		        "sequence_path": "1527.protein.sequences.v11.5.fa",
		        "enrichment_path": "1527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1527.protein.info.v11.5.txt",
		        "node_list_path": "1527.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1527.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacterHeraklionensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter heraklionensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterHeraklionensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "512402.protein.sequences.v11.5.fa",
		        "enrichment_path": "512402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512402.protein.info.v11.5.txt",
		        "node_list_path": "512402.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpIso899Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. Iso899 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpIso899Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1283283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1283283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1283283.clusters.proteins.v11.5.txt",
		        "sequence_path": "1283283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283283.protein.info.v11.5.txt",
		        "node_list_path": "1283283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1283283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlj11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlj11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158760.protein.info.v11.5.txt",
		        "node_list_path": "1158760.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolitaleaCanadensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solitalea canadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolitaleaCanadensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "929556.protein.sequences.v11.5.fa",
		        "enrichment_path": "929556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929556.protein.info.v11.5.txt",
		        "node_list_path": "929556.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSimilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter similis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSimilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420916.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420916.protein.info.v11.5.txt",
		        "node_list_path": "1420916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaTellurisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia telluris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaTellurisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326475.clusters.proteins.v11.5.txt",
		        "sequence_path": "326475.protein.sequences.v11.5.fa",
		        "enrichment_path": "326475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326475.protein.info.v11.5.txt",
		        "node_list_path": "326475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FaecalibacteriumPrausnitziiKle1255(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii KLE1255 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibacteriumPrausnitziiKle1255", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "748224.protein.sequences.v11.5.fa",
		        "enrichment_path": "748224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748224.protein.info.v11.5.txt",
		        "node_list_path": "748224.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpYr216(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. YR216 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpYr216", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882828.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882828.protein.info.v11.5.txt",
		        "node_list_path": "1882828.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumSp64120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. 64-120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumSp64120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895778.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895778.protein.info.v11.5.txt",
		        "node_list_path": "1895778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteimonasMephitisDsm12574Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas mephitis DSM 12574 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteimonasMephitisDsm12574Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122183.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122183.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122183.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122183.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122183.protein.info.v11.5.txt",
		        "node_list_path": "1122183.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122183.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRifcsplowo212Full6621(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO2_12_FULL_66_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212Full6621", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797191.protein.info.v11.5.txt",
		        "node_list_path": "1797191.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumGinsengisoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumGinsengisoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "400772.protein.sequences.v11.5.fa",
		        "enrichment_path": "400772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400772.protein.info.v11.5.txt",
		        "node_list_path": "400772.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassotaleaAgarivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassotalea agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassotaleaAgarivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349064.clusters.proteins.v11.5.txt",
		        "sequence_path": "349064.protein.sequences.v11.5.fa",
		        "enrichment_path": "349064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349064.protein.info.v11.5.txt",
		        "node_list_path": "349064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CardiniumEndosymbiontCbtq1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cardinium endosymbiont cBtQ1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CardiniumEndosymbiontCbtq1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354314.protein.info.v11.5.txt",
		        "node_list_path": "1354314.protein.complete.v11.5.txt"
		    }
		]
    )()

def GabonibacterMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gabonibacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GabonibacterMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720195.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720195.protein.info.v11.5.txt",
		        "node_list_path": "1720195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OkibacteriumFritillariaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Okibacterium fritillariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OkibacteriumFritillariaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "123320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "123320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "123320.clusters.proteins.v11.5.txt",
		        "sequence_path": "123320.protein.sequences.v11.5.fa",
		        "enrichment_path": "123320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "123320.protein.info.v11.5.txt",
		        "node_list_path": "123320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "123320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBoissieri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter boissieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBoissieri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219383.protein.info.v11.5.txt",
		        "node_list_path": "1219383.protein.complete.v11.5.txt"
		    }
		]
    )()

def RachicladosporiumAntarcticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rachicladosporium antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RachicladosporiumAntarcticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1507870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1507870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1507870.clusters.proteins.v11.5.txt",
		        "sequence_path": "1507870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1507870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1507870.protein.info.v11.5.txt",
		        "node_list_path": "1507870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1507870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChelativoransSpJ32Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chelativorans sp. J32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelativoransSpJ32Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935840.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935840.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935840.clusters.proteins.v11.5.txt",
		        "sequence_path": "935840.protein.sequences.v11.5.fa",
		        "enrichment_path": "935840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935840.protein.info.v11.5.txt",
		        "node_list_path": "935840.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935840.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacteriaBacteriumGut307(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacteria bacterium GUT307 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacteriaBacteriumGut307", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1704281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1704281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1704281.protein.info.v11.5.txt",
		        "node_list_path": "1704281.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumLablabiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium lablabi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumLablabiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "722472.clusters.info.v11.5.txt",
		        "cluster_tree_path": "722472.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "722472.clusters.proteins.v11.5.txt",
		        "sequence_path": "722472.protein.sequences.v11.5.fa",
		        "enrichment_path": "722472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "722472.protein.info.v11.5.txt",
		        "node_list_path": "722472.cluster.nodes.v11.5.txt",
		        "edge_list_path": "722472.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CebusCapucinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cebus capucinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CebusCapucinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9516.clusters.proteins.v11.5.txt",
		        "sequence_path": "9516.protein.sequences.v11.5.fa",
		        "enrichment_path": "9516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9516.protein.info.v11.5.txt",
		        "node_list_path": "9516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAcidiscabiesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces acidiscabies Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAcidiscabiesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1116232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1116232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1116232.clusters.proteins.v11.5.txt",
		        "sequence_path": "1116232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116232.protein.info.v11.5.txt",
		        "node_list_path": "1116232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1116232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonadalesBacteriumEhc05(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium EhC05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonadalesBacteriumEhc05", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849171.protein.info.v11.5.txt",
		        "node_list_path": "1849171.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusHalmapalus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus halmapalus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHalmapalus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "79882.protein.sequences.v11.5.fa",
		        "enrichment_path": "79882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79882.protein.info.v11.5.txt",
		        "node_list_path": "79882.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAle14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAle14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158168.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158168.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158168.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158168.protein.info.v11.5.txt",
		        "node_list_path": "1158168.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158168.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTusciae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tusciae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTusciae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "710687.protein.sequences.v11.5.fa",
		        "enrichment_path": "710687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710687.protein.info.v11.5.txt",
		        "node_list_path": "710687.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumGw2011Gwb24517Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_45_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24517Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618388.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618388.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618388.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618388.protein.info.v11.5.txt",
		        "node_list_path": "1618388.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618388.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpOk602Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ok602 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpOk602Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761898.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761898.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761898.protein.info.v11.5.txt",
		        "node_list_path": "1761898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAcidifarinaeDsm19394(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidifarinae DSM 19394 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAcidifarinaeDsm19394", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423715.protein.info.v11.5.txt",
		        "node_list_path": "1423715.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanobacillusIheyensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus iheyensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusIheyensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "221109.clusters.info.v11.5.txt",
		        "cluster_tree_path": "221109.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "221109.clusters.proteins.v11.5.txt",
		        "sequence_path": "221109.protein.sequences.v11.5.fa",
		        "enrichment_path": "221109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221109.protein.info.v11.5.txt",
		        "node_list_path": "221109.cluster.nodes.v11.5.txt",
		        "edge_list_path": "221109.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicolaBatsensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola batsensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaBatsensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "252305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "252305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "252305.clusters.proteins.v11.5.txt",
		        "sequence_path": "252305.protein.sequences.v11.5.fa",
		        "enrichment_path": "252305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "252305.protein.info.v11.5.txt",
		        "node_list_path": "252305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "252305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensF113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens F113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensF113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1114970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114970.protein.info.v11.5.txt",
		        "node_list_path": "1114970.protein.complete.v11.5.txt"
		    }
		]
    )()

def KordiimonasLacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kordiimonas lacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KordiimonasLacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "637679.protein.sequences.v11.5.fa",
		        "enrichment_path": "637679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637679.protein.info.v11.5.txt",
		        "node_list_path": "637679.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasVesicatoria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas vesicatoria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasVesicatoria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "925775.protein.sequences.v11.5.fa",
		        "enrichment_path": "925775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "925775.protein.info.v11.5.txt",
		        "node_list_path": "925775.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSp719Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. 71-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSp719Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895934.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895934.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895934.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895934.protein.info.v11.5.txt",
		        "node_list_path": "1895934.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895934.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaimiriBoliviensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saimiri boliviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaimiriBoliviensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "27679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "27679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "27679.clusters.proteins.v11.5.txt",
		        "sequence_path": "27679.protein.sequences.v11.5.fa",
		        "enrichment_path": "27679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27679.protein.info.v11.5.txt",
		        "node_list_path": "27679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "27679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusTukisamuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus tukisamuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusTukisamuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "168276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "168276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "168276.clusters.proteins.v11.5.txt",
		        "sequence_path": "168276.protein.sequences.v11.5.fa",
		        "enrichment_path": "168276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "168276.protein.info.v11.5.txt",
		        "node_list_path": "168276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "168276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCirculansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus circulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCirculansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397.protein.info.v11.5.txt",
		        "node_list_path": "1397.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpNs7484Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. NS-7484 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpNs7484Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834161.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834161.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834161.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834161.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834161.protein.info.v11.5.txt",
		        "node_list_path": "1834161.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834161.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDesantisbacteriaBacteriumCg2304021(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG2_30_40_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg2304021", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817895.protein.info.v11.5.txt",
		        "node_list_path": "1817895.protein.complete.v11.5.txt"
		    }
		]
    )()

def MannheimiaGranulomatisDsm19156(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia granulomatis DSM 19156 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaGranulomatisDsm19156", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122190.protein.info.v11.5.txt",
		        "node_list_path": "1122190.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusBeddingiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus beddingii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusBeddingiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40578.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40578.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40578.clusters.proteins.v11.5.txt",
		        "sequence_path": "40578.protein.sequences.v11.5.fa",
		        "enrichment_path": "40578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40578.protein.info.v11.5.txt",
		        "node_list_path": "40578.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40578.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasJandaei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas jandaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasJandaei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "650.protein.sequences.v11.5.fa",
		        "enrichment_path": "650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "650.protein.info.v11.5.txt",
		        "node_list_path": "650.protein.complete.v11.5.txt"
		    }
		]
    )()

def KocuriaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kocuria marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "223184.protein.sequences.v11.5.fa",
		        "enrichment_path": "223184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223184.protein.info.v11.5.txt",
		        "node_list_path": "223184.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag465(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:465 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag465", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262811.protein.info.v11.5.txt",
		        "node_list_path": "1262811.protein.complete.v11.5.txt"
		    }
		]
    )()

def PurpureocilliumLilacinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Purpureocillium lilacinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PurpureocilliumLilacinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33203.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33203.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33203.clusters.proteins.v11.5.txt",
		        "sequence_path": "33203.protein.sequences.v11.5.fa",
		        "enrichment_path": "33203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33203.protein.info.v11.5.txt",
		        "node_list_path": "33203.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33203.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TheileriaOrientalisStrainShintoku(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Theileria orientalis strain Shintoku graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheileriaOrientalisStrainShintoku", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "869250.protein.sequences.v11.5.fa",
		        "enrichment_path": "869250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869250.protein.info.v11.5.txt",
		        "node_list_path": "869250.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacterium13120cm3538Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_1_20CM_3_53_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacterium13120cm3538Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803431.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803431.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803431.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803431.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803431.protein.info.v11.5.txt",
		        "node_list_path": "1803431.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803431.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumP6b14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium P6B14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumP6b14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410631.protein.info.v11.5.txt",
		        "node_list_path": "1410631.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalegentibacterSalegens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter salegens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterSalegens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "143223.protein.sequences.v11.5.fa",
		        "enrichment_path": "143223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "143223.protein.info.v11.5.txt",
		        "node_list_path": "143223.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCdtb01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CdTB01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCdtb01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1725411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1725411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1725411.protein.info.v11.5.txt",
		        "node_list_path": "1725411.protein.complete.v11.5.txt"
		    }
		]
    )()

def DokdoniaSp4h375Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dokdonia sp. 4H375 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DokdoniaSp4h375Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983548.clusters.proteins.v11.5.txt",
		        "sequence_path": "983548.protein.sequences.v11.5.fa",
		        "enrichment_path": "983548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983548.protein.info.v11.5.txt",
		        "node_list_path": "983548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaParvula(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella parvula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaParvula", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "479436.protein.sequences.v11.5.fa",
		        "enrichment_path": "479436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479436.protein.info.v11.5.txt",
		        "node_list_path": "479436.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpUrhb0015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. URHB0015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpUrhb0015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380376.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380376.protein.info.v11.5.txt",
		        "node_list_path": "1380376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumOpportunistumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium opportunistum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumOpportunistumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "536019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "536019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "536019.clusters.proteins.v11.5.txt",
		        "sequence_path": "536019.protein.sequences.v11.5.fa",
		        "enrichment_path": "536019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "536019.protein.info.v11.5.txt",
		        "node_list_path": "536019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "536019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpShues1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. SHUES1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpShues1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849383.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849383.protein.info.v11.5.txt",
		        "node_list_path": "1849383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioRuminisCf1bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis CF1b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioRuminisCf1bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280688.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280688.protein.info.v11.5.txt",
		        "node_list_path": "1280688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho212Full4519bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_12_FULL_45_19b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho212Full4519bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802689.protein.info.v11.5.txt",
		        "node_list_path": "1802689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusDelbrueckiiBulgaricusAtcc11842(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii bulgaricus ATCC 11842 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusDelbrueckiiBulgaricusAtcc11842", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "390333.protein.sequences.v11.5.fa",
		        "enrichment_path": "390333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390333.protein.info.v11.5.txt",
		        "node_list_path": "390333.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterPasteuriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter pasteurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterPasteuriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945520.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945520.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945520.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945520.protein.info.v11.5.txt",
		        "node_list_path": "1945520.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945520.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusPimensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus pimensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusPimensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926554.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926554.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926554.clusters.proteins.v11.5.txt",
		        "sequence_path": "926554.protein.sequences.v11.5.fa",
		        "enrichment_path": "926554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926554.protein.info.v11.5.txt",
		        "node_list_path": "926554.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926554.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavonifractorPlautiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavonifractor plautii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavonifractorPlautiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "292800.clusters.info.v11.5.txt",
		        "cluster_tree_path": "292800.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "292800.clusters.proteins.v11.5.txt",
		        "sequence_path": "292800.protein.sequences.v11.5.fa",
		        "enrichment_path": "292800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292800.protein.info.v11.5.txt",
		        "node_list_path": "292800.cluster.nodes.v11.5.txt",
		        "edge_list_path": "292800.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaTrevisanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia trevisanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaTrevisanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122173.protein.info.v11.5.txt",
		        "node_list_path": "1122173.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnicoccusHospitalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignicoccus hospitalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnicoccusHospitalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "453591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "453591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "453591.clusters.proteins.v11.5.txt",
		        "sequence_path": "453591.protein.sequences.v11.5.fa",
		        "enrichment_path": "453591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "453591.protein.info.v11.5.txt",
		        "node_list_path": "453591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "453591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonlabensDokdonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensDokdonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "592029.protein.sequences.v11.5.fa",
		        "enrichment_path": "592029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592029.protein.info.v11.5.txt",
		        "node_list_path": "592029.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlj1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlj1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158144.protein.info.v11.5.txt",
		        "node_list_path": "1158144.protein.complete.v11.5.txt"
		    }
		]
    )()

def GregarinaNiphandrodes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gregarina niphandrodes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GregarinaNiphandrodes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "110365.protein.sequences.v11.5.fa",
		        "enrichment_path": "110365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "110365.protein.info.v11.5.txt",
		        "node_list_path": "110365.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaBrevicatenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia brevicatena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaBrevicatenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206725.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206725.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206725.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206725.protein.info.v11.5.txt",
		        "node_list_path": "1206725.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206725.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseoruber(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseoruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseoruber", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1943.protein.info.v11.5.txt",
		        "node_list_path": "1943.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacillusSpMm3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacillus sp. MM3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacillusSpMm3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1848039.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848039.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848039.protein.info.v11.5.txt",
		        "node_list_path": "1848039.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeeuwenhoekiellaPalythoae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella palythoae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeeuwenhoekiellaPalythoae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573501.protein.sequences.v11.5.fa",
		        "enrichment_path": "573501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573501.protein.info.v11.5.txt",
		        "node_list_path": "573501.protein.complete.v11.5.txt"
		    }
		]
    )()

def AdvenellaMimigardefordensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Advenella mimigardefordensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AdvenellaMimigardefordensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1247726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1247726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1247726.protein.info.v11.5.txt",
		        "node_list_path": "1247726.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoriobacterialesBacteriumDnf00809(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriales bacterium DNF00809 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacterialesBacteriumDnf00809", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1588753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588753.protein.info.v11.5.txt",
		        "node_list_path": "1588753.protein.complete.v11.5.txt"
		    }
		]
    )()

def TsukamurellaPaurometabola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tsukamurella paurometabola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TsukamurellaPaurometabola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521096.protein.sequences.v11.5.fa",
		        "enrichment_path": "521096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521096.protein.info.v11.5.txt",
		        "node_list_path": "521096.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpRs9916Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. RS9916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpRs9916Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "221359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "221359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "221359.clusters.proteins.v11.5.txt",
		        "sequence_path": "221359.protein.sequences.v11.5.fa",
		        "enrichment_path": "221359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221359.protein.info.v11.5.txt",
		        "node_list_path": "221359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "221359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumCg2305367Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_53_67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumCg2305367Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805278.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805278.protein.info.v11.5.txt",
		        "node_list_path": "1805278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaCinaraPseudotaxifoliae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara pseudotaxifoliae) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaCinaraPseudotaxifoliae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655384.protein.sequences.v11.5.fa",
		        "enrichment_path": "655384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655384.protein.info.v11.5.txt",
		        "node_list_path": "655384.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanomicrobiumOkeanokoitesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planomicrobium okeanokoites Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanomicrobiumOkeanokoitesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "244.clusters.proteins.v11.5.txt",
		        "sequence_path": "244.protein.sequences.v11.5.fa",
		        "enrichment_path": "244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244.protein.info.v11.5.txt",
		        "node_list_path": "244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpHk1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. HK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpHk1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1469245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1469245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1469245.clusters.proteins.v11.5.txt",
		        "sequence_path": "1469245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469245.protein.info.v11.5.txt",
		        "node_list_path": "1469245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1469245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeuconostocKimchiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc kimchii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocKimchiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762051.clusters.proteins.v11.5.txt",
		        "sequence_path": "762051.protein.sequences.v11.5.fa",
		        "enrichment_path": "762051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762051.protein.info.v11.5.txt",
		        "node_list_path": "762051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FictibacillusPhosphorivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fictibacillus phosphorivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FictibacillusPhosphorivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1221500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1221500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1221500.protein.info.v11.5.txt",
		        "node_list_path": "1221500.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgromycesSpSoil535Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agromyces sp. Soil535 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesSpSoil535Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736390.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736390.protein.info.v11.5.txt",
		        "node_list_path": "1736390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumClostridioformeAgr2157(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] clostridioforme AGR2157 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumClostridioformeAgr2157", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280695.protein.info.v11.5.txt",
		        "node_list_path": "1280695.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesPlebeiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides plebeius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesPlebeiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "484018.clusters.info.v11.5.txt",
		        "cluster_tree_path": "484018.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "484018.clusters.proteins.v11.5.txt",
		        "sequence_path": "484018.protein.sequences.v11.5.fa",
		        "enrichment_path": "484018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484018.protein.info.v11.5.txt",
		        "node_list_path": "484018.cluster.nodes.v11.5.txt",
		        "edge_list_path": "484018.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusVaccinostercusDsm20634Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus vaccinostercus DSM 20634 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusVaccinostercusDsm20634Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423813.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423813.protein.info.v11.5.txt",
		        "node_list_path": "1423813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusNantensisDsm16982Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nantensis DSM 16982 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusNantensisDsm16982Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423774.protein.info.v11.5.txt",
		        "node_list_path": "1423774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCereusAtcc14579(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cereus ATCC 14579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCereusAtcc14579", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "226900.protein.sequences.v11.5.fa",
		        "enrichment_path": "226900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226900.protein.info.v11.5.txt",
		        "node_list_path": "226900.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasKorlensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas korlensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasKorlensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "463301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "463301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "463301.clusters.proteins.v11.5.txt",
		        "sequence_path": "463301.protein.sequences.v11.5.fa",
		        "enrichment_path": "463301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "463301.protein.info.v11.5.txt",
		        "node_list_path": "463301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "463301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MediterraneaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mediterranea massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MediterraneaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841865.protein.info.v11.5.txt",
		        "node_list_path": "1841865.protein.complete.v11.5.txt"
		    }
		]
    )()

def ManihotEsculenta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Manihot esculenta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ManihotEsculenta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3983.protein.sequences.v11.5.fa",
		        "enrichment_path": "3983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3983.protein.info.v11.5.txt",
		        "node_list_path": "3983.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusEpidermidisRp62a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis RP62A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusEpidermidisRp62a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "176279.protein.sequences.v11.5.fa",
		        "enrichment_path": "176279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "176279.protein.info.v11.5.txt",
		        "node_list_path": "176279.protein.complete.v11.5.txt"
		    }
		]
    )()

def BatrachochytriumDendrobatidisJel423(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis JEL423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BatrachochytriumDendrobatidisJel423", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "403673.protein.sequences.v11.5.fa",
		        "enrichment_path": "403673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "403673.protein.info.v11.5.txt",
		        "node_list_path": "403673.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesCellulosilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides cellulosilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCellulosilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1268240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1268240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1268240.clusters.proteins.v11.5.txt",
		        "sequence_path": "1268240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268240.protein.info.v11.5.txt",
		        "node_list_path": "1268240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1268240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpLpb0140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LPB0140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpLpb0140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1913578.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1913578.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1913578.clusters.proteins.v11.5.txt",
		        "sequence_path": "1913578.protein.sequences.v11.5.fa",
		        "enrichment_path": "1913578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1913578.protein.info.v11.5.txt",
		        "node_list_path": "1913578.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1913578.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillibacterSpCag2416221Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. CAG:241_62_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSpCag2416221Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897012.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897012.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897012.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897012.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897012.protein.info.v11.5.txt",
		        "node_list_path": "1897012.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897012.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumUlcerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium ulcerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumUlcerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "362242.protein.sequences.v11.5.fa",
		        "enrichment_path": "362242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362242.protein.info.v11.5.txt",
		        "node_list_path": "362242.protein.complete.v11.5.txt"
		    }
		]
    )()

def MobilicoccusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mobilicoccus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobilicoccusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1522310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522310.protein.info.v11.5.txt",
		        "node_list_path": "1522310.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelobacterPropionicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter propionicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelobacterPropionicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "338966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "338966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "338966.clusters.proteins.v11.5.txt",
		        "sequence_path": "338966.protein.sequences.v11.5.fa",
		        "enrichment_path": "338966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "338966.protein.info.v11.5.txt",
		        "node_list_path": "338966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "338966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PleurotusOstreatusPc15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pleurotus ostreatus PC15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PleurotusOstreatusPc15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1137138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1137138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1137138.clusters.proteins.v11.5.txt",
		        "sequence_path": "1137138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137138.protein.info.v11.5.txt",
		        "node_list_path": "1137138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1137138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3523(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_35_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3523", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798274.protein.info.v11.5.txt",
		        "node_list_path": "1798274.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAbyssalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus abyssalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAbyssalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1221450.protein.sequences.v11.5.fa",
		        "enrichment_path": "1221450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1221450.protein.info.v11.5.txt",
		        "node_list_path": "1221450.protein.complete.v11.5.txt"
		    }
		]
    )()

def MerdibacterMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Merdibacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MerdibacterMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871030.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871030.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871030.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871030.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871030.protein.info.v11.5.txt",
		        "node_list_path": "1871030.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871030.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedOscillibacterSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Oscillibacter sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedOscillibacterSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "876091.protein.sequences.v11.5.fa",
		        "enrichment_path": "876091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "876091.protein.info.v11.5.txt",
		        "node_list_path": "876091.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag343Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:343 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag343Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262796.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262796.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262796.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262796.protein.info.v11.5.txt",
		        "node_list_path": "1262796.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262796.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumHimb5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumHimb5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "859653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "859653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "859653.clusters.proteins.v11.5.txt",
		        "sequence_path": "859653.protein.sequences.v11.5.fa",
		        "enrichment_path": "859653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "859653.protein.info.v11.5.txt",
		        "node_list_path": "859653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "859653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCitroniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium citroniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCitroniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742733.protein.sequences.v11.5.fa",
		        "enrichment_path": "742733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742733.protein.info.v11.5.txt",
		        "node_list_path": "742733.protein.complete.v11.5.txt"
		    }
		]
    )()

def CallipeplaSquamataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Callipepla squamata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CallipeplaSquamataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9009.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9009.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9009.clusters.proteins.v11.5.txt",
		        "sequence_path": "9009.protein.sequences.v11.5.fa",
		        "enrichment_path": "9009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9009.protein.info.v11.5.txt",
		        "node_list_path": "9009.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9009.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KiloniellaLitopenaei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kiloniella litopenaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KiloniellaLitopenaei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1549748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1549748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1549748.protein.info.v11.5.txt",
		        "node_list_path": "1549748.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag356Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:356 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag356Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262800.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262800.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262800.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262800.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262800.protein.info.v11.5.txt",
		        "node_list_path": "1262800.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262800.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumSb2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium SB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumSb2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1689867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1689867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1689867.protein.info.v11.5.txt",
		        "node_list_path": "1689867.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaOvisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella ovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaOvisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29433.clusters.proteins.v11.5.txt",
		        "sequence_path": "29433.protein.sequences.v11.5.fa",
		        "enrichment_path": "29433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29433.protein.info.v11.5.txt",
		        "node_list_path": "29433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1934996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934996.protein.info.v11.5.txt",
		        "node_list_path": "1934996.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavisolibacterGinsengisoliDsm18119(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavisolibacter ginsengisoli DSM 18119 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavisolibacterGinsengisoliDsm18119", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121884.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121884.protein.info.v11.5.txt",
		        "node_list_path": "1121884.protein.complete.v11.5.txt"
		    }
		]
    )()

def RunellaSlithyformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Runella slithyformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RunellaSlithyformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "761193.protein.sequences.v11.5.fa",
		        "enrichment_path": "761193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "761193.protein.info.v11.5.txt",
		        "node_list_path": "761193.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetrapisisporaBlattae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora blattae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrapisisporaBlattae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071379.protein.info.v11.5.txt",
		        "node_list_path": "1071379.protein.complete.v11.5.txt"
		    }
		]
    )()

def HistoplasmaCapsulatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HistoplasmaCapsulatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5037.protein.sequences.v11.5.fa",
		        "enrichment_path": "5037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5037.protein.info.v11.5.txt",
		        "node_list_path": "5037.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrenophoraTriticirepentisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora triticirepentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrenophoraTriticirepentisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45151.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45151.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45151.clusters.proteins.v11.5.txt",
		        "sequence_path": "45151.protein.sequences.v11.5.fa",
		        "enrichment_path": "45151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45151.protein.info.v11.5.txt",
		        "node_list_path": "45151.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45151.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsplowo202Full519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_02_FULL_51_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo202Full519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802410.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802410.protein.info.v11.5.txt",
		        "node_list_path": "1802410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaSainthelensi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella sainthelensi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaSainthelensi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408445.protein.info.v11.5.txt",
		        "node_list_path": "1408445.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasJinjuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas jinjuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasJinjuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "198616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "198616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "198616.clusters.proteins.v11.5.txt",
		        "sequence_path": "198616.protein.sequences.v11.5.fa",
		        "enrichment_path": "198616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198616.protein.info.v11.5.txt",
		        "node_list_path": "198616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "198616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag299(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag299", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262792.protein.info.v11.5.txt",
		        "node_list_path": "1262792.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterSpUrha0019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter sp. URHA0019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterSpUrha0019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298861.protein.info.v11.5.txt",
		        "node_list_path": "1298861.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusAureusSubspAureusNctc8325Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus aureus subsp. aureus NCTC 8325 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusAureusSubspAureusNctc8325Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93061.clusters.proteins.v11.5.txt",
		        "sequence_path": "93061.protein.sequences.v11.5.fa",
		        "enrichment_path": "93061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93061.protein.info.v11.5.txt",
		        "node_list_path": "93061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwe23928(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_39_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwe23928", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797333.protein.info.v11.5.txt",
		        "node_list_path": "1797333.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full4317bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_43_17b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full4317bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802216.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802216.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802216.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802216.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802216.protein.info.v11.5.txt",
		        "node_list_path": "1802216.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802216.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NevskiaRamosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nevskia ramosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NevskiaRamosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122603.protein.info.v11.5.txt",
		        "node_list_path": "1122603.protein.complete.v11.5.txt"
		    }
		]
    )()

def TessaracoccusFlavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus flavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusFlavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1610493.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1610493.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1610493.clusters.proteins.v11.5.txt",
		        "sequence_path": "1610493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1610493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1610493.protein.info.v11.5.txt",
		        "node_list_path": "1610493.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1610493.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusSenegalensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusSenegalensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1936063.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1936063.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1936063.clusters.proteins.v11.5.txt",
		        "sequence_path": "1936063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1936063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1936063.protein.info.v11.5.txt",
		        "node_list_path": "1936063.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1936063.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MelampsoraLaricipopulina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Melampsora laricipopulina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MelampsoraLaricipopulina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "203908.protein.sequences.v11.5.fa",
		        "enrichment_path": "203908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203908.protein.info.v11.5.txt",
		        "node_list_path": "203908.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumKroppenstedtiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium kroppenstedtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumKroppenstedtiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "645127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "645127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "645127.clusters.proteins.v11.5.txt",
		        "sequence_path": "645127.protein.sequences.v11.5.fa",
		        "enrichment_path": "645127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645127.protein.info.v11.5.txt",
		        "node_list_path": "645127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "645127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesColeocanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces coleocanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesColeocanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525245.protein.sequences.v11.5.fa",
		        "enrichment_path": "525245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525245.protein.info.v11.5.txt",
		        "node_list_path": "525245.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonasTerrigenaNbrc13299Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas terrigena NBRC 13299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasTerrigenaNbrc13299Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219032.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219032.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219032.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219032.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219032.protein.info.v11.5.txt",
		        "node_list_path": "1219032.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219032.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumGwa25343Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_53_43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa25343Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801841.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801841.protein.info.v11.5.txt",
		        "node_list_path": "1801841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraYanagawaeSerovarSaopauloStrSaoPauloAtcc700523Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira yanagawae serovar Saopaulo str. Sao Paulo ATCC 700523 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraYanagawaeSerovarSaopauloStrSaoPauloAtcc700523Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1249483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1249483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1249483.clusters.proteins.v11.5.txt",
		        "sequence_path": "1249483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249483.protein.info.v11.5.txt",
		        "node_list_path": "1249483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1249483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SanguibacterKeddieii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter keddieii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SanguibacterKeddieii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "446469.protein.sequences.v11.5.fa",
		        "enrichment_path": "446469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446469.protein.info.v11.5.txt",
		        "node_list_path": "446469.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacteriumRifcsplowo202Full7356(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium RIFCSPLOWO2_02_FULL_73_56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacteriumRifcsplowo202Full7356", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802107.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802107.protein.info.v11.5.txt",
		        "node_list_path": "1802107.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4186Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_41_86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4186Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817821.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817821.protein.info.v11.5.txt",
		        "node_list_path": "1817821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchaaliaOdontolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schaalia odontolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchaaliaOdontolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660.protein.info.v11.5.txt",
		        "node_list_path": "1660.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusProfundusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus profundus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusProfundusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "572546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "572546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "572546.clusters.proteins.v11.5.txt",
		        "sequence_path": "572546.protein.sequences.v11.5.fa",
		        "enrichment_path": "572546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572546.protein.info.v11.5.txt",
		        "node_list_path": "572546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "572546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfuribacillusStibiiarsenatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfuribacillus stibiiarsenatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuribacillusStibiiarsenatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1390249.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1390249.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1390249.clusters.proteins.v11.5.txt",
		        "sequence_path": "1390249.protein.sequences.v11.5.fa",
		        "enrichment_path": "1390249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1390249.protein.info.v11.5.txt",
		        "node_list_path": "1390249.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1390249.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacillusReuszeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus reuszeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusReuszeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "54915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "54915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "54915.clusters.proteins.v11.5.txt",
		        "sequence_path": "54915.protein.sequences.v11.5.fa",
		        "enrichment_path": "54915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54915.protein.info.v11.5.txt",
		        "node_list_path": "54915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "54915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VanderwaltozymaPolysporaDsm70294Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vanderwaltozyma polyspora DSM 70294 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VanderwaltozymaPolysporaDsm70294Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "436907.clusters.info.v11.5.txt",
		        "cluster_tree_path": "436907.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "436907.clusters.proteins.v11.5.txt",
		        "sequence_path": "436907.protein.sequences.v11.5.fa",
		        "enrichment_path": "436907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436907.protein.info.v11.5.txt",
		        "node_list_path": "436907.cluster.nodes.v11.5.txt",
		        "edge_list_path": "436907.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpNc2002(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. NC2002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpNc2002", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410610.protein.info.v11.5.txt",
		        "node_list_path": "1410610.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSanguinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSanguinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122925.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122925.protein.info.v11.5.txt",
		        "node_list_path": "1122925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpC150Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. C150 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpC150Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "435842.clusters.info.v11.5.txt",
		        "cluster_tree_path": "435842.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "435842.clusters.proteins.v11.5.txt",
		        "sequence_path": "435842.protein.sequences.v11.5.fa",
		        "enrichment_path": "435842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435842.protein.info.v11.5.txt",
		        "node_list_path": "435842.cluster.nodes.v11.5.txt",
		        "edge_list_path": "435842.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumXerosisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium xerosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumXerosisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1725.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1725.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1725.clusters.proteins.v11.5.txt",
		        "sequence_path": "1725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1725.protein.info.v11.5.txt",
		        "node_list_path": "1725.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1725.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumMarseillense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium marseillense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumMarseillense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "701042.protein.sequences.v11.5.fa",
		        "enrichment_path": "701042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "701042.protein.info.v11.5.txt",
		        "node_list_path": "701042.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsphigho202Full3919Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_02_FULL_39_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho202Full3919Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802746.protein.info.v11.5.txt",
		        "node_list_path": "1802746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacterium5419(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 54-19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacterium5419", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895928.protein.info.v11.5.txt",
		        "node_list_path": "1895928.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumBoenickei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium boenickei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumBoenickei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "146017.protein.sequences.v11.5.fa",
		        "enrichment_path": "146017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146017.protein.info.v11.5.txt",
		        "node_list_path": "146017.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumJaponicumUsda6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum USDA6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumJaponicumUsda6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1037409.protein.sequences.v11.5.fa",
		        "enrichment_path": "1037409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1037409.protein.info.v11.5.txt",
		        "node_list_path": "1037409.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerrimonasFuttsuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas futtsuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrimonasFuttsuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121878.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121878.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121878.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121878.protein.info.v11.5.txt",
		        "node_list_path": "1121878.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121878.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisBenzoatilytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis benzoatilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisBenzoatilytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089544.protein.info.v11.5.txt",
		        "node_list_path": "1089544.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerinicoccusMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serinicoccus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerinicoccusMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123251.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123251.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123251.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123251.protein.info.v11.5.txt",
		        "node_list_path": "1123251.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123251.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaPneumophilaSubspFraseri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila subsp. fraseri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaPneumophilaSubspFraseri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "91892.protein.sequences.v11.5.fa",
		        "enrichment_path": "91892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91892.protein.info.v11.5.txt",
		        "node_list_path": "91892.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonasGranuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas granuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasGranuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223521.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223521.protein.info.v11.5.txt",
		        "node_list_path": "1223521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBifidumNcimb41171(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum NCIMB41171 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBifidumNcimb41171", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398513.protein.sequences.v11.5.fa",
		        "enrichment_path": "398513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398513.protein.info.v11.5.txt",
		        "node_list_path": "398513.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifoxya1Full4114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFOXYA1_FULL_41_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifoxya1Full4114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797737.protein.info.v11.5.txt",
		        "node_list_path": "1797737.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumPutridalgicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium putridalgicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumPutridalgicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426703.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426703.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426703.clusters.proteins.v11.5.txt",
		        "sequence_path": "426703.protein.sequences.v11.5.fa",
		        "enrichment_path": "426703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426703.protein.info.v11.5.txt",
		        "node_list_path": "426703.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426703.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpNml980116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML98-0116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpNml980116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "702967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "702967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "702967.clusters.proteins.v11.5.txt",
		        "sequence_path": "702967.protein.sequences.v11.5.fa",
		        "enrichment_path": "702967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702967.protein.info.v11.5.txt",
		        "node_list_path": "702967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "702967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusContaminans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus contaminans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusContaminans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120971.protein.info.v11.5.txt",
		        "node_list_path": "1120971.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusAlliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus allii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAlliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1847728.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1847728.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1847728.clusters.proteins.v11.5.txt",
		        "sequence_path": "1847728.protein.sequences.v11.5.fa",
		        "enrichment_path": "1847728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1847728.protein.info.v11.5.txt",
		        "node_list_path": "1847728.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1847728.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FormosaAgariphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Formosa agariphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaAgariphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1347342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1347342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1347342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1347342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347342.protein.info.v11.5.txt",
		        "node_list_path": "1347342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1347342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumCaliforniensisDsm19288(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum californiensis DSM 19288 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumCaliforniensisDsm19288", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227465.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227465.protein.info.v11.5.txt",
		        "node_list_path": "1227465.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonJgiOtu1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon JGI OTU-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonJgiOtu1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1378080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1378080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1378080.protein.info.v11.5.txt",
		        "node_list_path": "1378080.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpAcc21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. ACC21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpAcc21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1161413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1161413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1161413.clusters.proteins.v11.5.txt",
		        "sequence_path": "1161413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1161413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1161413.protein.info.v11.5.txt",
		        "node_list_path": "1161413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1161413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BelliellaBalticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Belliella baltica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BelliellaBalticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "866536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "866536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "866536.clusters.proteins.v11.5.txt",
		        "sequence_path": "866536.protein.sequences.v11.5.fa",
		        "enrichment_path": "866536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866536.protein.info.v11.5.txt",
		        "node_list_path": "866536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "866536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DiaphorobacterSpJ551Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Diaphorobacter sp. J5-51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiaphorobacterSpJ551Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "680496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "680496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "680496.clusters.proteins.v11.5.txt",
		        "sequence_path": "680496.protein.sequences.v11.5.fa",
		        "enrichment_path": "680496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "680496.protein.info.v11.5.txt",
		        "node_list_path": "680496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "680496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaproniaCoronataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capronia coronata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaproniaCoronataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43229.clusters.proteins.v11.5.txt",
		        "sequence_path": "43229.protein.sequences.v11.5.fa",
		        "enrichment_path": "43229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43229.protein.info.v11.5.txt",
		        "node_list_path": "43229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalotaleaAlkalilenta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halotalea alkalilenta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalotaleaAlkalilenta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "376489.protein.sequences.v11.5.fa",
		        "enrichment_path": "376489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376489.protein.info.v11.5.txt",
		        "node_list_path": "376489.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "415425.protein.sequences.v11.5.fa",
		        "enrichment_path": "415425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "415425.protein.info.v11.5.txt",
		        "node_list_path": "415425.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpEs333Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ES3-33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpEs333Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1628833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1628833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1628833.clusters.proteins.v11.5.txt",
		        "sequence_path": "1628833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628833.protein.info.v11.5.txt",
		        "node_list_path": "1628833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1628833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaProductaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia producta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaProductaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33035.clusters.proteins.v11.5.txt",
		        "sequence_path": "33035.protein.sequences.v11.5.fa",
		        "enrichment_path": "33035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33035.protein.info.v11.5.txt",
		        "node_list_path": "33035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeuconostocaceaeBacteriumR53105Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostocaceae bacterium R-53105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocaceaeBacteriumR53105Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855370.protein.info.v11.5.txt",
		        "node_list_path": "1855370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaCtu(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ctu graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaCtu", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "261317.protein.sequences.v11.0.fa",
		        "enrichment_path": "261317.protein.enrichment.terms.v11.0.txt",
		        "info_path": "261317.protein.info.v11.0.txt",
		        "node_list_path": "261317.protein.complete.v11.0.txt"
		    }
		]
    )()

def ParacoccusSanguinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSanguinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1545044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545044.protein.info.v11.5.txt",
		        "node_list_path": "1545044.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasFimi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas fimi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasFimi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "590998.protein.sequences.v11.5.fa",
		        "enrichment_path": "590998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "590998.protein.info.v11.5.txt",
		        "node_list_path": "590998.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChytriomycesConfervaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chytriomyces confervae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChytriomycesConfervaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246404.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246404.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246404.clusters.proteins.v11.5.txt",
		        "sequence_path": "246404.protein.sequences.v11.5.fa",
		        "enrichment_path": "246404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246404.protein.info.v11.5.txt",
		        "node_list_path": "246404.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246404.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HistoplasmaCapsulatumG186ar(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum G186AR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HistoplasmaCapsulatumG186ar", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "447093.protein.sequences.v11.5.fa",
		        "enrichment_path": "447093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "447093.protein.info.v11.5.txt",
		        "node_list_path": "447093.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHlucca08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCA08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHlucca08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1666913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666913.protein.info.v11.5.txt",
		        "node_list_path": "1666913.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSenmaizukeiDsm21775Nbrc103853Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus senmaizukei DSM 21775 NBRC 103853 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSenmaizukeiDsm21775Nbrc103853Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423803.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423803.protein.info.v11.5.txt",
		        "node_list_path": "1423803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrococcusCarbonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrococcus carbonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrococcusCarbonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "684552.clusters.info.v11.5.txt",
		        "cluster_tree_path": "684552.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "684552.clusters.proteins.v11.5.txt",
		        "sequence_path": "684552.protein.sequences.v11.5.fa",
		        "enrichment_path": "684552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "684552.protein.info.v11.5.txt",
		        "node_list_path": "684552.cluster.nodes.v11.5.txt",
		        "edge_list_path": "684552.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermobifidaHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermobifida halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobifidaHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "483545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "483545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "483545.clusters.proteins.v11.5.txt",
		        "sequence_path": "483545.protein.sequences.v11.5.fa",
		        "enrichment_path": "483545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483545.protein.info.v11.5.txt",
		        "node_list_path": "483545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "483545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BotryotiniaCalthaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Botryotinia calthae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotryotiniaCalthaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "38488.clusters.info.v11.5.txt",
		        "cluster_tree_path": "38488.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "38488.clusters.proteins.v11.5.txt",
		        "sequence_path": "38488.protein.sequences.v11.5.fa",
		        "enrichment_path": "38488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38488.protein.info.v11.5.txt",
		        "node_list_path": "38488.cluster.nodes.v11.5.txt",
		        "edge_list_path": "38488.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MnemiopsisLeidyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mnemiopsis leidyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MnemiopsisLeidyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "27923.clusters.info.v11.5.txt",
		        "cluster_tree_path": "27923.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "27923.clusters.proteins.v11.5.txt",
		        "sequence_path": "27923.protein.sequences.v11.5.fa",
		        "enrichment_path": "27923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27923.protein.info.v11.5.txt",
		        "node_list_path": "27923.cluster.nodes.v11.5.txt",
		        "edge_list_path": "27923.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AggregatibacterSpOralTaxon458StrW10330Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter sp. oral taxon 458 str. W10330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterSpOralTaxon458StrW10330Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321772.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321772.protein.info.v11.5.txt",
		        "node_list_path": "1321772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusDeserti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus deserti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusDeserti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546414.protein.sequences.v11.5.fa",
		        "enrichment_path": "546414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546414.protein.info.v11.5.txt",
		        "node_list_path": "546414.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpPamc26642Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. PAMC 26642 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpPamc26642Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1792307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1792307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1792307.clusters.proteins.v11.5.txt",
		        "sequence_path": "1792307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792307.protein.info.v11.5.txt",
		        "node_list_path": "1792307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1792307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BalneolaSpEhc07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Balneola sp. EhC07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BalneolaSpEhc07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849360.protein.info.v11.5.txt",
		        "node_list_path": "1849360.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasAsturiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas asturiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAsturiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1190415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1190415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1190415.protein.info.v11.5.txt",
		        "node_list_path": "1190415.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumRbg166413(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_16_64_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumRbg166413", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797200.protein.info.v11.5.txt",
		        "node_list_path": "1797200.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumCg1023572Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG1_02_35_72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumCg1023572Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805158.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805158.protein.info.v11.5.txt",
		        "node_list_path": "1805158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CroceicoccusPelagiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Croceicoccus pelagius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CroceicoccusPelagiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703341.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703341.protein.info.v11.5.txt",
		        "node_list_path": "1703341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaloceraCorneaHhb12733(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Calocera cornea HHB12733 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloceraCorneaHhb12733", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1353952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353952.protein.info.v11.5.txt",
		        "node_list_path": "1353952.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeofamiliaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neofamilia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeofamiliaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1673724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1673724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1673724.clusters.proteins.v11.5.txt",
		        "sequence_path": "1673724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673724.protein.info.v11.5.txt",
		        "node_list_path": "1673724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1673724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OryziasMelastigma(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryzias melastigma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryziasMelastigma", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "30732.protein.sequences.v11.5.fa",
		        "enrichment_path": "30732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30732.protein.info.v11.5.txt",
		        "node_list_path": "30732.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpH2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. H2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpH2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658612.clusters.proteins.v11.5.txt",
		        "sequence_path": "658612.protein.sequences.v11.5.fa",
		        "enrichment_path": "658612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658612.protein.info.v11.5.txt",
		        "node_list_path": "658612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpAe3009(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpAe3009", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280666.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280666.protein.info.v11.5.txt",
		        "node_list_path": "1280666.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpCag988(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. CAG:988 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpCag988", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262708.protein.info.v11.5.txt",
		        "node_list_path": "1262708.protein.complete.v11.5.txt"
		    }
		]
    )()

def PneumocystisJiroveciiRu7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii RU7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PneumocystisJiroveciiRu7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408657.protein.info.v11.5.txt",
		        "node_list_path": "1408657.protein.complete.v11.5.txt"
		    }
		]
    )()

def MillerozymaFarinosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Millerozyma farinosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MillerozymaFarinosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4920.clusters.proteins.v11.5.txt",
		        "sequence_path": "4920.protein.sequences.v11.5.fa",
		        "enrichment_path": "4920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4920.protein.info.v11.5.txt",
		        "node_list_path": "4920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho2024118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_41_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho2024118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801746.protein.info.v11.5.txt",
		        "node_list_path": "1801746.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaceaeBacteriumPmp191fCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium PMP191F Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaceaeBacteriumPmp191fCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1691979.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1691979.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1691979.clusters.proteins.v11.5.txt",
		        "sequence_path": "1691979.protein.sequences.v11.5.fa",
		        "enrichment_path": "1691979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1691979.protein.info.v11.5.txt",
		        "node_list_path": "1691979.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1691979.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucispirillumSchaedleri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucispirillum schaedleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucispirillumSchaedleri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379858.protein.info.v11.5.txt",
		        "node_list_path": "1379858.protein.complete.v11.5.txt"
		    }
		]
    )()

def FangiaHongkongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fangia hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FangiaHongkongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089439.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089439.protein.info.v11.5.txt",
		        "node_list_path": "1089439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyronemaOmphalodesCbs100304(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyronema omphalodes CBS 100304 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyronemaOmphalodesCbs100304", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1076935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076935.protein.info.v11.5.txt",
		        "node_list_path": "1076935.protein.complete.v11.5.txt"
		    }
		]
    )()

def KamptonemaFormosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kamptonema formosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KamptonemaFormosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "402777.protein.sequences.v11.5.fa",
		        "enrichment_path": "402777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402777.protein.info.v11.5.txt",
		        "node_list_path": "402777.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalieaSalexigens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haliea salexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalieaSalexigens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121937.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121937.protein.info.v11.5.txt",
		        "node_list_path": "1121937.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSanguinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSanguinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121020.protein.info.v11.5.txt",
		        "node_list_path": "1121020.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807736.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807736.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807736.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807736.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807736.protein.info.v11.5.txt",
		        "node_list_path": "1807736.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807736.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CytophagaFermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cytophaga fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CytophagaFermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "869213.protein.sequences.v11.5.fa",
		        "enrichment_path": "869213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869213.protein.info.v11.5.txt",
		        "node_list_path": "869213.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBrisouii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter brisouii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBrisouii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217652.protein.info.v11.5.txt",
		        "node_list_path": "1217652.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSeniorisDsm24302Jcm17472(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus senioris DSM 24302 JCM 17472 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSeniorisDsm24302Jcm17472", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423802.protein.info.v11.5.txt",
		        "node_list_path": "1423802.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaucisalibacillusGlobulusDsm18846(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paucisalibacillus globulus DSM 18846 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaucisalibacillusGlobulusDsm18846", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122940.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122940.protein.info.v11.5.txt",
		        "node_list_path": "1122940.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumChaponenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium chaponense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumChaponenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "713588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "713588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "713588.clusters.proteins.v11.5.txt",
		        "sequence_path": "713588.protein.sequences.v11.5.fa",
		        "enrichment_path": "713588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713588.protein.info.v11.5.txt",
		        "node_list_path": "713588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "713588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaIntermedia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella intermedia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaIntermedia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28131.protein.sequences.v11.5.fa",
		        "enrichment_path": "28131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28131.protein.info.v11.5.txt",
		        "node_list_path": "28131.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasDaejeonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas daejeonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasDaejeonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "659018.clusters.info.v11.5.txt",
		        "cluster_tree_path": "659018.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "659018.clusters.proteins.v11.5.txt",
		        "sequence_path": "659018.protein.sequences.v11.5.fa",
		        "enrichment_path": "659018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "659018.protein.info.v11.5.txt",
		        "node_list_path": "659018.cluster.nodes.v11.5.txt",
		        "edge_list_path": "659018.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSaphenum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium saphenum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSaphenum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "592031.protein.sequences.v11.5.fa",
		        "enrichment_path": "592031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592031.protein.info.v11.5.txt",
		        "node_list_path": "592031.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusEquicursorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus equicursoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusEquicursorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293597.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293597.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293597.protein.info.v11.5.txt",
		        "node_list_path": "1293597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YarrowiaLipolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yarrowia lipolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YarrowiaLipolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4952.protein.sequences.v11.5.fa",
		        "enrichment_path": "4952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4952.protein.info.v11.5.txt",
		        "node_list_path": "4952.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaDentasiniJcm15908Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella dentasini JCM 15908 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaDentasiniJcm15908Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236509.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236509.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236509.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236509.protein.info.v11.5.txt",
		        "node_list_path": "1236509.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236509.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthromitusSpSfbratyit(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBratYit graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthromitusSpSfbratyit", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041504.protein.info.v11.5.txt",
		        "node_list_path": "1041504.protein.complete.v11.5.txt"
		    }
		]
    )()

def CercosporaZeina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cercospora zeina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CercosporaZeina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "348901.protein.sequences.v11.5.fa",
		        "enrichment_path": "348901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "348901.protein.info.v11.5.txt",
		        "node_list_path": "348901.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAureofaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aureofaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAureofaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1894.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1894.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1894.clusters.proteins.v11.5.txt",
		        "sequence_path": "1894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1894.protein.info.v11.5.txt",
		        "node_list_path": "1894.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1894.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesAlbimanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles albimanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesAlbimanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7167.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7167.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7167.clusters.proteins.v11.5.txt",
		        "sequence_path": "7167.protein.sequences.v11.5.fa",
		        "enrichment_path": "7167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7167.protein.info.v11.5.txt",
		        "node_list_path": "7167.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7167.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumSpRoot344(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root344 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumSpRoot344", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736521.protein.info.v11.5.txt",
		        "node_list_path": "1736521.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanobacillusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "946235.clusters.info.v11.5.txt",
		        "cluster_tree_path": "946235.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "946235.clusters.proteins.v11.5.txt",
		        "sequence_path": "946235.protein.sequences.v11.5.fa",
		        "enrichment_path": "946235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946235.protein.info.v11.5.txt",
		        "node_list_path": "946235.cluster.nodes.v11.5.txt",
		        "edge_list_path": "946235.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusHumi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHumi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "263474.protein.sequences.v11.5.fa",
		        "enrichment_path": "263474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263474.protein.info.v11.5.txt",
		        "node_list_path": "263474.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSp6021061333Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 6021061333 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSp6021061333Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816690.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816690.protein.info.v11.5.txt",
		        "node_list_path": "1816690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusArciformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus arciformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusArciformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "482827.protein.sequences.v11.5.fa",
		        "enrichment_path": "482827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "482827.protein.info.v11.5.txt",
		        "node_list_path": "482827.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermomonasHydrothermalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermomonas hydrothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermomonasHydrothermalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "213588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "213588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "213588.clusters.proteins.v11.5.txt",
		        "sequence_path": "213588.protein.sequences.v11.5.fa",
		        "enrichment_path": "213588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "213588.protein.info.v11.5.txt",
		        "node_list_path": "213588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "213588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GallionellalesBacteriumRifcsplowo212Full5922(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallionellales bacterium RIFCSPLOWO2_12_FULL_59_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallionellalesBacteriumRifcsplowo212Full5922", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798257.protein.info.v11.5.txt",
		        "node_list_path": "1798257.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisSpAc466Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC466 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisSpAc466Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1282362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1282362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1282362.clusters.proteins.v11.5.txt",
		        "sequence_path": "1282362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282362.protein.info.v11.5.txt",
		        "node_list_path": "1282362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1282362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpAp12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AP12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpAp12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144305.protein.info.v11.5.txt",
		        "node_list_path": "1144305.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesUrogenitalisDsm15434(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis DSM15434 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesUrogenitalisDsm15434", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525246.protein.sequences.v11.5.fa",
		        "enrichment_path": "525246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525246.protein.info.v11.5.txt",
		        "node_list_path": "525246.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaSpF0314Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. F0314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSpF0314Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641149.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641149.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641149.clusters.proteins.v11.5.txt",
		        "sequence_path": "641149.protein.sequences.v11.5.fa",
		        "enrichment_path": "641149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641149.protein.info.v11.5.txt",
		        "node_list_path": "641149.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641149.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquaspirillumSerpensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquaspirillum serpens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquaspirillumSerpensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121004.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121004.protein.info.v11.5.txt",
		        "node_list_path": "1121004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterKivui(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter kivui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterKivui", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2325.protein.sequences.v11.5.fa",
		        "enrichment_path": "2325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2325.protein.info.v11.5.txt",
		        "node_list_path": "2325.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusFaecimaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus faecimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusFaecimaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "686796.protein.sequences.v11.5.fa",
		        "enrichment_path": "686796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686796.protein.info.v11.5.txt",
		        "node_list_path": "686796.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaMelanogaster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila melanogaster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaMelanogaster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7227.protein.sequences.v11.5.fa",
		        "enrichment_path": "7227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7227.protein.info.v11.5.txt",
		        "node_list_path": "7227.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonasSp22ii122f38Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. 22II122F38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSp22ii122f38Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280948.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280948.protein.info.v11.5.txt",
		        "node_list_path": "1280948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusSilesiacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus silesiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSilesiacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "332949.clusters.info.v11.5.txt",
		        "cluster_tree_path": "332949.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "332949.clusters.proteins.v11.5.txt",
		        "sequence_path": "332949.protein.sequences.v11.5.fa",
		        "enrichment_path": "332949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332949.protein.info.v11.5.txt",
		        "node_list_path": "332949.cluster.nodes.v11.5.txt",
		        "edge_list_path": "332949.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterMustelaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter mustelae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterMustelaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679897.clusters.proteins.v11.5.txt",
		        "sequence_path": "679897.protein.sequences.v11.5.fa",
		        "enrichment_path": "679897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679897.protein.info.v11.5.txt",
		        "node_list_path": "679897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc04h06(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC04H06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc04h06", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1581050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581050.protein.info.v11.5.txt",
		        "node_list_path": "1581050.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCgr1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CGR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCgr1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1696072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1696072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1696072.protein.info.v11.5.txt",
		        "node_list_path": "1696072.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaSpMtp4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina sp. MTP4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaSpMtp4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434100.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434100.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434100.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434100.protein.info.v11.5.txt",
		        "node_list_path": "1434100.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434100.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumGwa24915Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWA2_49_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumGwa24915Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797384.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797384.protein.info.v11.5.txt",
		        "node_list_path": "1797384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterPhenylpyruvicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter phenylpyruvicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterPhenylpyruvicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123034.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123034.protein.info.v11.5.txt",
		        "node_list_path": "1123034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4470Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4470 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4470Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977881.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977881.protein.info.v11.5.txt",
		        "node_list_path": "1977881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterCupressiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter cupressi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterCupressiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1045773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1045773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1045773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1045773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045773.protein.info.v11.5.txt",
		        "node_list_path": "1045773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1045773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpYr375(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. yr375 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpYr375", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761906.protein.info.v11.5.txt",
		        "node_list_path": "1761906.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxya2Full4753(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2_FULL_47_53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2Full4753", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797959.protein.info.v11.5.txt",
		        "node_list_path": "1797959.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioParahaemolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio parahaemolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioParahaemolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "223926.protein.sequences.v11.5.fa",
		        "enrichment_path": "223926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223926.protein.info.v11.5.txt",
		        "node_list_path": "223926.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalonatronumSaccharophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halonatronum saccharophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalonatronumSaccharophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926692.clusters.proteins.v11.5.txt",
		        "sequence_path": "926692.protein.sequences.v11.5.fa",
		        "enrichment_path": "926692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926692.protein.info.v11.5.txt",
		        "node_list_path": "926692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag492Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:492 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag492Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262813.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262813.protein.info.v11.5.txt",
		        "node_list_path": "1262813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusUrinalisFb127cna2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus urinalis FB127CNA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusUrinalisFb127cna2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883168.protein.sequences.v11.5.fa",
		        "enrichment_path": "883168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883168.protein.info.v11.5.txt",
		        "node_list_path": "883168.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfipiaSpRoot123d2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. Root123D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaSpRoot123d2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736436.protein.info.v11.5.txt",
		        "node_list_path": "1736436.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumSpRoot700(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. Root700 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumSpRoot700", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736591.protein.info.v11.5.txt",
		        "node_list_path": "1736591.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterCapsici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter capsici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterCapsici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "435897.protein.sequences.v11.5.fa",
		        "enrichment_path": "435897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435897.protein.info.v11.5.txt",
		        "node_list_path": "435897.protein.complete.v11.5.txt"
		    }
		]
    )()

def WenxiniaSaemankumensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wenxinia saemankumensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WenxiniaSaemankumensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1447782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1447782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1447782.protein.info.v11.5.txt",
		        "node_list_path": "1447782.protein.complete.v11.5.txt"
		    }
		]
    )()

def AncylostomaCeylanicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ancylostoma ceylanicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AncylostomaCeylanicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53326.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53326.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53326.clusters.proteins.v11.5.txt",
		        "sequence_path": "53326.protein.sequences.v11.5.fa",
		        "enrichment_path": "53326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53326.protein.info.v11.5.txt",
		        "node_list_path": "53326.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53326.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollinsellaSpMs5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collinsella sp. MS5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaSpMs5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499681.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499681.protein.info.v11.5.txt",
		        "node_list_path": "1499681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumSpLeaf291Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Leaf291 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumSpLeaf291Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736325.protein.info.v11.5.txt",
		        "node_list_path": "1736325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusHomiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus homiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusHomiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "364199.protein.sequences.v11.5.fa",
		        "enrichment_path": "364199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "364199.protein.info.v11.5.txt",
		        "node_list_path": "364199.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacteriumJilantaienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium jilantaiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacteriumJilantaienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "355548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "355548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "355548.clusters.proteins.v11.5.txt",
		        "sequence_path": "355548.protein.sequences.v11.5.fa",
		        "enrichment_path": "355548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "355548.protein.info.v11.5.txt",
		        "node_list_path": "355548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "355548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaribacterForsetii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter forsetii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterForsetii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392498.protein.info.v11.5.txt",
		        "node_list_path": "1392498.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumSpMaddingleyCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium sp. Maddingley Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumSpMaddingleyCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220534.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220534.protein.info.v11.5.txt",
		        "node_list_path": "1220534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4422Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_44_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4422Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802697.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802697.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802697.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802697.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802697.protein.info.v11.5.txt",
		        "node_list_path": "1802697.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802697.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpSd21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SD21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpSd21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "161528.protein.sequences.v11.5.fa",
		        "enrichment_path": "161528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161528.protein.info.v11.5.txt",
		        "node_list_path": "161528.protein.complete.v11.5.txt"
		    }
		]
    )()

def HistoplasmaCapsulatumNam1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum NAm1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HistoplasmaCapsulatumNam1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "339724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "339724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "339724.clusters.proteins.v11.5.txt",
		        "sequence_path": "339724.protein.sequences.v11.5.fa",
		        "enrichment_path": "339724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "339724.protein.info.v11.5.txt",
		        "node_list_path": "339724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "339724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSenegalensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSenegalensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033732.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033732.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033732.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033732.protein.info.v11.5.txt",
		        "node_list_path": "1033732.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033732.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacterium4415Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 44-15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacterium4415Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895837.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895837.protein.info.v11.5.txt",
		        "node_list_path": "1895837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JatrophihabitansEndophyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jatrophihabitans endophyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JatrophihabitansEndophyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206085.protein.info.v11.5.txt",
		        "node_list_path": "1206085.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquiflexumBalticumDsm16537Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquiflexum balticum DSM 16537 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquiflexumBalticumDsm16537Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "758820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "758820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "758820.clusters.proteins.v11.5.txt",
		        "sequence_path": "758820.protein.sequences.v11.5.fa",
		        "enrichment_path": "758820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758820.protein.info.v11.5.txt",
		        "node_list_path": "758820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "758820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaAmicalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia amicalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaAmicalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1386969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1386969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1386969.protein.info.v11.5.txt",
		        "node_list_path": "1386969.protein.complete.v11.5.txt"
		    }
		]
    )()

def SkermaniaPiniformisNbrc15059Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Skermania piniformis NBRC 15059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SkermaniaPiniformisNbrc15059Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223536.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223536.protein.info.v11.5.txt",
		        "node_list_path": "1223536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpMrs7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. MRS7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpMrs7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1268622.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268622.protein.info.v11.5.txt",
		        "node_list_path": "1268622.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaSp52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea sp. 52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaSp52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235798.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235798.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235798.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235798.protein.info.v11.5.txt",
		        "node_list_path": "1235798.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235798.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KazachstaniaNaganishii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania naganishii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KazachstaniaNaganishii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "588726.protein.sequences.v11.5.fa",
		        "enrichment_path": "588726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588726.protein.info.v11.5.txt",
		        "node_list_path": "588726.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeonGw2011Ar5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return archaeon GW2011_AR5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeonGw2011Ar5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1579367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1579367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1579367.clusters.proteins.v11.5.txt",
		        "sequence_path": "1579367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579367.protein.info.v11.5.txt",
		        "node_list_path": "1579367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1579367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200250816Sch5313054BCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-50816_SCH5313054-b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200250816Sch5313054BCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834092.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834092.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834092.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834092.protein.info.v11.5.txt",
		        "node_list_path": "1834092.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834092.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusDenitrificansPd1222Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus denitrificans PD1222 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusDenitrificansPd1222Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "318586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "318586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "318586.clusters.proteins.v11.5.txt",
		        "sequence_path": "318586.protein.sequences.v11.5.fa",
		        "enrichment_path": "318586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318586.protein.info.v11.5.txt",
		        "node_list_path": "318586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "318586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExophialaAquamarinaCbs119918(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exophiala aquamarina CBS 119918 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaAquamarinaCbs119918", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1182545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182545.protein.info.v11.5.txt",
		        "node_list_path": "1182545.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaParkeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia parkeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaParkeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1313294.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1313294.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1313294.clusters.proteins.v11.5.txt",
		        "sequence_path": "1313294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313294.protein.info.v11.5.txt",
		        "node_list_path": "1313294.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1313294.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpBiomig1n(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BIOMIG1N graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpBiomig1n", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1763882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1763882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1763882.protein.info.v11.5.txt",
		        "node_list_path": "1763882.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanicolaBatsensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola batsensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaBatsensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "252305.protein.sequences.v11.5.fa",
		        "enrichment_path": "252305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "252305.protein.info.v11.5.txt",
		        "node_list_path": "252305.protein.complete.v11.5.txt"
		    }
		]
    )()

def CuculusCanorus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cuculus canorus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CuculusCanorus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "55661.protein.sequences.v11.5.fa",
		        "enrichment_path": "55661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55661.protein.info.v11.5.txt",
		        "node_list_path": "55661.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat28573(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-28573 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat28573", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720554.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720554.protein.info.v11.5.txt",
		        "node_list_path": "1720554.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifoxya12Full3519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYA12_FULL_35_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxya12Full3519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801646.protein.info.v11.5.txt",
		        "node_list_path": "1801646.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumTetaniE88Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tetani E88 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTetaniE88Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "212717.clusters.info.v11.5.txt",
		        "cluster_tree_path": "212717.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "212717.clusters.proteins.v11.5.txt",
		        "sequence_path": "212717.protein.sequences.v11.5.fa",
		        "enrichment_path": "212717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "212717.protein.info.v11.5.txt",
		        "node_list_path": "212717.cluster.nodes.v11.5.txt",
		        "edge_list_path": "212717.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpRoot157Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root157 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpRoot157Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736477.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736477.protein.info.v11.5.txt",
		        "node_list_path": "1736477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpIhbb10380(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. IHBB 10380 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpIhbb10380", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566358.protein.info.v11.5.txt",
		        "node_list_path": "1566358.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusLacrimalisDsm7455(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus lacrimalis DSM 7455 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusLacrimalisDsm7455", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122949.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122949.protein.info.v11.5.txt",
		        "node_list_path": "1122949.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRbg166620Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_66_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRbg166620Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797479.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797479.protein.info.v11.5.txt",
		        "node_list_path": "1797479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnanasComosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ananas comosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnanasComosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4615.clusters.proteins.v11.5.txt",
		        "sequence_path": "4615.protein.sequences.v11.5.fa",
		        "enrichment_path": "4615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4615.protein.info.v11.5.txt",
		        "node_list_path": "4615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumFormosenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium formosense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumFormosenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "236814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "236814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "236814.clusters.proteins.v11.5.txt",
		        "sequence_path": "236814.protein.sequences.v11.5.fa",
		        "enrichment_path": "236814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "236814.protein.info.v11.5.txt",
		        "node_list_path": "236814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "236814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumSpYr522Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. YR522 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumSpYr522Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144342.protein.info.v11.5.txt",
		        "node_list_path": "1144342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OryzaGlaberrimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza glaberrima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaGlaberrimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4538.clusters.proteins.v11.5.txt",
		        "sequence_path": "4538.protein.sequences.v11.5.fa",
		        "enrichment_path": "4538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4538.protein.info.v11.5.txt",
		        "node_list_path": "4538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAljtCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAljtCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158146.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158146.protein.info.v11.5.txt",
		        "node_list_path": "1158146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpM26Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. M26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpM26Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1762962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1762962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1762962.clusters.proteins.v11.5.txt",
		        "sequence_path": "1762962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1762962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1762962.protein.info.v11.5.txt",
		        "node_list_path": "1762962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1762962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiorhodococcusDrewsii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiorhodococcus drewsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiorhodococcusDrewsii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765913.protein.sequences.v11.5.fa",
		        "enrichment_path": "765913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765913.protein.info.v11.5.txt",
		        "node_list_path": "765913.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyclobacteriumAmurskyense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacterium amurskyense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyclobacteriumAmurskyense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "320787.protein.sequences.v11.5.fa",
		        "enrichment_path": "320787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "320787.protein.info.v11.5.txt",
		        "node_list_path": "320787.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMethylopumilusTuricensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methylopumilus turicensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethylopumilusTuricensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1581680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1581680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1581680.clusters.proteins.v11.5.txt",
		        "sequence_path": "1581680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581680.protein.info.v11.5.txt",
		        "node_list_path": "1581680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1581680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacteriumSpDl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium sp. DL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacteriumSpDl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "751944.protein.sequences.v11.5.fa",
		        "enrichment_path": "751944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "751944.protein.info.v11.5.txt",
		        "node_list_path": "751944.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfospiraJoergensenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfospira joergensenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfospiraJoergensenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265505.protein.info.v11.5.txt",
		        "node_list_path": "1265505.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrenneriaSpEnid312(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brenneria sp. EniD312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrenneriaSpEnid312", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "598467.protein.sequences.v11.5.fa",
		        "enrichment_path": "598467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "598467.protein.info.v11.5.txt",
		        "node_list_path": "598467.protein.complete.v11.5.txt"
		    }
		]
    )()

def FelisCatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Felis catus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FelisCatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9685.clusters.proteins.v11.5.txt",
		        "sequence_path": "9685.protein.sequences.v11.5.fa",
		        "enrichment_path": "9685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9685.protein.info.v11.5.txt",
		        "node_list_path": "9685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KnoelliaSinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Knoellia sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KnoelliaSinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385520.protein.info.v11.5.txt",
		        "node_list_path": "1385520.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpF0418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpF0418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "904294.clusters.info.v11.5.txt",
		        "cluster_tree_path": "904294.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "904294.clusters.proteins.v11.5.txt",
		        "sequence_path": "904294.protein.sequences.v11.5.fa",
		        "enrichment_path": "904294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904294.protein.info.v11.5.txt",
		        "node_list_path": "904294.cluster.nodes.v11.5.txt",
		        "edge_list_path": "904294.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromatiaceaeBacterium2141tStbd0c01a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chromatiaceae bacterium 2141T.STBD.0c.01a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromatiaceaeBacterium2141tStbd0c01a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1978339.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978339.protein.info.v11.5.txt",
		        "node_list_path": "1978339.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifoxyd1Full4023(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD1_FULL_40_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd1Full4023", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798705.protein.info.v11.5.txt",
		        "node_list_path": "1798705.protein.complete.v11.5.txt"
		    }
		]
    )()

def PustulibacteriumMarinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pustulibacterium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PustulibacteriumMarinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1224947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1224947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1224947.clusters.proteins.v11.5.txt",
		        "sequence_path": "1224947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224947.protein.info.v11.5.txt",
		        "node_list_path": "1224947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1224947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylosinusSpPw1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylosinus sp. PW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylosinusSpPw1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "107636.clusters.info.v11.5.txt",
		        "cluster_tree_path": "107636.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "107636.clusters.proteins.v11.5.txt",
		        "sequence_path": "107636.protein.sequences.v11.5.fa",
		        "enrichment_path": "107636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "107636.protein.info.v11.5.txt",
		        "node_list_path": "107636.cluster.nodes.v11.5.txt",
		        "edge_list_path": "107636.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4127Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4127Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802662.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802662.protein.info.v11.5.txt",
		        "node_list_path": "1802662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TardiphagaRobiniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tardiphaga robiniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TardiphagaRobiniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "943830.protein.sequences.v11.5.fa",
		        "enrichment_path": "943830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "943830.protein.info.v11.5.txt",
		        "node_list_path": "943830.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAlboflavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces alboflavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAlboflavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67267.protein.sequences.v11.5.fa",
		        "enrichment_path": "67267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67267.protein.info.v11.5.txt",
		        "node_list_path": "67267.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesPyogenesDsm20611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides pyogenes DSM20611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesPyogenesDsm20611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121100.protein.info.v11.5.txt",
		        "node_list_path": "1121100.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyclobacteriaceaeBacteriumAk24(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacteriaceae bacterium AK24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyclobacteriaceaeBacteriumAk24", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288963.protein.info.v11.5.txt",
		        "node_list_path": "1288963.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusCaldoxylosilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus caldoxylosilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusCaldoxylosilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1234664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234664.protein.info.v11.5.txt",
		        "node_list_path": "1234664.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumStBin12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium ST_bin12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumStBin12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1978760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978760.protein.info.v11.5.txt",
		        "node_list_path": "1978760.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpiroformeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium spiroforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpiroformeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "428126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "428126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "428126.clusters.proteins.v11.5.txt",
		        "sequence_path": "428126.protein.sequences.v11.5.fa",
		        "enrichment_path": "428126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428126.protein.info.v11.5.txt",
		        "node_list_path": "428126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "428126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "198620.protein.sequences.v11.5.fa",
		        "enrichment_path": "198620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198620.protein.info.v11.5.txt",
		        "node_list_path": "198620.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4323(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_43_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4323", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817822.protein.info.v11.5.txt",
		        "node_list_path": "1817822.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParasporobacteriumPaucivoransDsm15970(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parasporobacterium paucivorans DSM 15970 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParasporobacteriumPaucivoransDsm15970", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122934.protein.info.v11.5.txt",
		        "node_list_path": "1122934.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwa23217(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_32_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwa23217", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797316.protein.info.v11.5.txt",
		        "node_list_path": "1797316.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycesBrasiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycesBrasiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "756272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "756272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "756272.clusters.proteins.v11.5.txt",
		        "sequence_path": "756272.protein.sequences.v11.5.fa",
		        "enrichment_path": "756272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "756272.protein.info.v11.5.txt",
		        "node_list_path": "756272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "756272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodotorulaSpJg1b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula sp. JG-1b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodotorulaSpJg1b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1305733.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305733.protein.info.v11.5.txt",
		        "node_list_path": "1305733.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpMc2013(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MC2013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpMc2013", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280686.protein.info.v11.5.txt",
		        "node_list_path": "1280686.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFlevenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium flevense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFlevenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983.clusters.proteins.v11.5.txt",
		        "sequence_path": "983.protein.sequences.v11.5.fa",
		        "enrichment_path": "983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983.protein.info.v11.5.txt",
		        "node_list_path": "983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "265726.protein.sequences.v11.5.fa",
		        "enrichment_path": "265726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265726.protein.info.v11.5.txt",
		        "node_list_path": "265726.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumMangrovi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium mangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumMangrovi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348253.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348253.protein.info.v11.5.txt",
		        "node_list_path": "1348253.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpU41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. U41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpU41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849032.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849032.protein.info.v11.5.txt",
		        "node_list_path": "1849032.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumGw2011Gwa25212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium GW2011_GWA2_52_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumGw2011Gwa25212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618671.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618671.protein.info.v11.5.txt",
		        "node_list_path": "1618671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpF0295Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0295 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpF0295Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "619693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "619693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "619693.clusters.proteins.v11.5.txt",
		        "sequence_path": "619693.protein.sequences.v11.5.fa",
		        "enrichment_path": "619693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "619693.protein.info.v11.5.txt",
		        "node_list_path": "619693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "619693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaSp6418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea sp. 64-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaSp6418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895806.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895806.protein.info.v11.5.txt",
		        "node_list_path": "1895806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAlcalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus alcalophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAlcalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218173.protein.info.v11.5.txt",
		        "node_list_path": "1218173.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumRifoxyb1Full4712(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFOXYB1_FULL_47_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifoxyb1Full4712", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797264.protein.info.v11.5.txt",
		        "node_list_path": "1797264.protein.complete.v11.5.txt"
		    }
		]
    )()

def OchrobactrumPseudogrignonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum pseudogrignonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OchrobactrumPseudogrignonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "419475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "419475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "419475.clusters.proteins.v11.5.txt",
		        "sequence_path": "419475.protein.sequences.v11.5.fa",
		        "enrichment_path": "419475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419475.protein.info.v11.5.txt",
		        "node_list_path": "419475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "419475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolirubrobacterSpUrhd0082Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solirubrobacter sp. URHD0082 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolirubrobacterSpUrhd0082Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298857.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298857.protein.info.v11.5.txt",
		        "node_list_path": "1298857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1176165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1176165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1176165.clusters.proteins.v11.5.txt",
		        "sequence_path": "1176165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1176165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1176165.protein.info.v11.5.txt",
		        "node_list_path": "1176165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1176165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrobacterSpNb311a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrobacter sp. Nb-311A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrobacterSpNb311a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314253.protein.sequences.v11.5.fa",
		        "enrichment_path": "314253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314253.protein.info.v11.5.txt",
		        "node_list_path": "314253.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusLentus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lentus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusLentus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1179226.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179226.protein.info.v11.5.txt",
		        "node_list_path": "1179226.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaSubspDiarizonae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. diarizonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaSubspDiarizonae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59204.protein.sequences.v11.5.fa",
		        "enrichment_path": "59204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59204.protein.info.v11.5.txt",
		        "node_list_path": "59204.protein.complete.v11.5.txt"
		    }
		]
    )()

def EremotheciumGossypii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium gossypii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremotheciumGossypii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33169.protein.sequences.v11.5.fa",
		        "enrichment_path": "33169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33169.protein.info.v11.5.txt",
		        "node_list_path": "33169.protein.complete.v11.5.txt"
		    }
		]
    )()

def SmithellaSpM82(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Smithella sp. M82 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmithellaSpM82", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1678137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678137.protein.info.v11.5.txt",
		        "node_list_path": "1678137.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full4512(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_45_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full4512", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798288.protein.info.v11.5.txt",
		        "node_list_path": "1798288.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "637971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "637971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "637971.clusters.proteins.v11.5.txt",
		        "sequence_path": "637971.protein.sequences.v11.5.fa",
		        "enrichment_path": "637971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637971.protein.info.v11.5.txt",
		        "node_list_path": "637971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "637971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusGlacialis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus glacialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusGlacialis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "494026.protein.sequences.v11.5.fa",
		        "enrichment_path": "494026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "494026.protein.info.v11.5.txt",
		        "node_list_path": "494026.protein.complete.v11.5.txt"
		    }
		]
    )()

def GiardiaIntestinalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Giardia intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GiardiaIntestinalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5741.protein.sequences.v11.5.fa",
		        "enrichment_path": "5741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5741.protein.info.v11.5.txt",
		        "node_list_path": "5741.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumJdfr80Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr80Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935110.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935110.protein.info.v11.5.txt",
		        "node_list_path": "1935110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldisericumExile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldisericum exile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldisericumExile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "511051.protein.sequences.v11.5.fa",
		        "enrichment_path": "511051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511051.protein.info.v11.5.txt",
		        "node_list_path": "511051.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacteriaceaeBacteriumStrainCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium strain Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacteriaceaeBacteriumStrainCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "693444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "693444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "693444.clusters.proteins.v11.5.txt",
		        "sequence_path": "693444.protein.sequences.v11.5.fa",
		        "enrichment_path": "693444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693444.protein.info.v11.5.txt",
		        "node_list_path": "693444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "693444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumCrassostreaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium crassostreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumCrassostreaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1763534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1763534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1763534.clusters.proteins.v11.5.txt",
		        "sequence_path": "1763534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1763534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1763534.protein.info.v11.5.txt",
		        "node_list_path": "1763534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1763534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasBalearicaDsm6083Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas balearica DSM 6083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBalearicaDsm6083Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123016.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123016.protein.info.v11.5.txt",
		        "node_list_path": "1123016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotignumBalticumDsm7044Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotignum balticum DSM 7044 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotignumBalticumDsm7044Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304886.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304886.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304886.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304886.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304886.protein.info.v11.5.txt",
		        "node_list_path": "1304886.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304886.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PneumocystisMurinaB123(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis murina B123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PneumocystisMurinaB123", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1069680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069680.protein.info.v11.5.txt",
		        "node_list_path": "1069680.protein.complete.v11.5.txt"
		    }
		]
    )()

def DonghicolaXiamenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Donghicola xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DonghicolaXiamenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121479.protein.info.v11.5.txt",
		        "node_list_path": "1121479.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumMethylpentosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium methylpentosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumMethylpentosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "537013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "537013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "537013.clusters.proteins.v11.5.txt",
		        "sequence_path": "537013.protein.sequences.v11.5.fa",
		        "enrichment_path": "537013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537013.protein.info.v11.5.txt",
		        "node_list_path": "537013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "537013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharibacterSpAm169Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharibacter sp. AM169 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharibacterSpAm169Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1343158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1343158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1343158.clusters.proteins.v11.5.txt",
		        "sequence_path": "1343158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1343158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1343158.protein.info.v11.5.txt",
		        "node_list_path": "1343158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1343158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusPyogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pyogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPyogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314.protein.info.v11.5.txt",
		        "node_list_path": "1314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanibaculumNanhaiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanibaculum nanhaiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanibaculumNanhaiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1909734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1909734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1909734.protein.info.v11.5.txt",
		        "node_list_path": "1909734.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPantholopis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pantholopis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPantholopis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811193.protein.info.v11.5.txt",
		        "node_list_path": "1811193.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusViridansLl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus viridans LL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusViridansLl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1175629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1175629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1175629.clusters.proteins.v11.5.txt",
		        "sequence_path": "1175629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1175629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1175629.protein.info.v11.5.txt",
		        "node_list_path": "1175629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1175629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LabrenziaSpOb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Labrenzia sp. OB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrenziaSpOb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1561204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1561204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1561204.clusters.proteins.v11.5.txt",
		        "sequence_path": "1561204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561204.protein.info.v11.5.txt",
		        "node_list_path": "1561204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1561204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaHermsii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia hermsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaHermsii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314723.protein.sequences.v11.5.fa",
		        "enrichment_path": "314723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314723.protein.info.v11.5.txt",
		        "node_list_path": "314723.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocCarnosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc carnosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocCarnosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229758.protein.info.v11.5.txt",
		        "node_list_path": "1229758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsphigho212Full429(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_12_FULL_42_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho212Full429", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802511.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802511.protein.info.v11.5.txt",
		        "node_list_path": "1802511.protein.complete.v11.5.txt"
		    }
		]
    )()

def FaecalicatenaContortaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalicatena contorta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalicatenaContortaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39482.clusters.proteins.v11.5.txt",
		        "sequence_path": "39482.protein.sequences.v11.5.fa",
		        "enrichment_path": "39482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39482.protein.info.v11.5.txt",
		        "node_list_path": "39482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaSaoudiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella saoudiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaSaoudiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1750561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1750561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1750561.clusters.proteins.v11.5.txt",
		        "sequence_path": "1750561.protein.sequences.v11.5.fa",
		        "enrichment_path": "1750561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1750561.protein.info.v11.5.txt",
		        "node_list_path": "1750561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1750561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusWulumuqiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus wulumuqiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusWulumuqiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1567107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1567107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1567107.clusters.proteins.v11.5.txt",
		        "sequence_path": "1567107.protein.sequences.v11.5.fa",
		        "enrichment_path": "1567107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1567107.protein.info.v11.5.txt",
		        "node_list_path": "1567107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1567107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProsthecochlorisSpHl130Gsb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prosthecochloris sp. HL-130-GSB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProsthecochlorisSpHl130Gsb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1974213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1974213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1974213.protein.info.v11.5.txt",
		        "node_list_path": "1974213.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraPectinoschiza(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospira pectinoschiza graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraPectinoschiza", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28052.protein.sequences.v11.5.fa",
		        "enrichment_path": "28052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28052.protein.info.v11.5.txt",
		        "node_list_path": "28052.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrassicaOleraceaVarOleracea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brassica oleracea var. oleracea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrassicaOleraceaVarOleracea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "109376.protein.sequences.v11.5.fa",
		        "enrichment_path": "109376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109376.protein.info.v11.5.txt",
		        "node_list_path": "109376.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobacterGummiphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobacter gummiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobacterGummiphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "946333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "946333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "946333.clusters.proteins.v11.5.txt",
		        "sequence_path": "946333.protein.sequences.v11.5.fa",
		        "enrichment_path": "946333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946333.protein.info.v11.5.txt",
		        "node_list_path": "946333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "946333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumCg1023112Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_31_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg1023112Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805280.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805280.protein.info.v11.5.txt",
		        "node_list_path": "1805280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterPasteurii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter pasteurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterPasteurii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945520.protein.info.v11.5.txt",
		        "node_list_path": "1945520.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHimb55(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HIMB55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHimb55", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "745014.protein.sequences.v11.5.fa",
		        "enrichment_path": "745014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745014.protein.info.v11.5.txt",
		        "node_list_path": "745014.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpDd11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpDd11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777879.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777879.protein.info.v11.5.txt",
		        "node_list_path": "1777879.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasSpMitacek01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Mitacek01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasSpMitacek01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1732019.protein.sequences.v11.5.fa",
		        "enrichment_path": "1732019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1732019.protein.info.v11.5.txt",
		        "node_list_path": "1732019.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerendipitaVermiferaMaff305830Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serendipita vermifera MAFF 305830 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerendipitaVermiferaMaff305830Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "933852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "933852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "933852.clusters.proteins.v11.5.txt",
		        "sequence_path": "933852.protein.sequences.v11.5.fa",
		        "enrichment_path": "933852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933852.protein.info.v11.5.txt",
		        "node_list_path": "933852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "933852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaSpNCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella sp. N Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaSpNCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1746199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1746199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1746199.clusters.proteins.v11.5.txt",
		        "sequence_path": "1746199.protein.sequences.v11.5.fa",
		        "enrichment_path": "1746199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1746199.protein.info.v11.5.txt",
		        "node_list_path": "1746199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1746199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrahymenaThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrahymena thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrahymenaThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5911.clusters.proteins.v11.5.txt",
		        "sequence_path": "5911.protein.sequences.v11.5.fa",
		        "enrichment_path": "5911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5911.protein.info.v11.5.txt",
		        "node_list_path": "5911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaHospita(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia hospita graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaHospita", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "169430.protein.sequences.v11.5.fa",
		        "enrichment_path": "169430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "169430.protein.info.v11.5.txt",
		        "node_list_path": "169430.protein.complete.v11.5.txt"
		    }
		]
    )()

def GranulicoccusPhenolivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Granulicoccus phenolivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicoccusPhenolivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121933.protein.info.v11.5.txt",
		        "node_list_path": "1121933.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaproniaEpimycesCbs60696Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capronia epimyces CBS 606.96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaproniaEpimycesCbs60696Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1182542.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1182542.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1182542.clusters.proteins.v11.5.txt",
		        "sequence_path": "1182542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182542.protein.info.v11.5.txt",
		        "node_list_path": "1182542.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1182542.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MedicagoTruncatulaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Medicago truncatula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MedicagoTruncatulaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3880.clusters.proteins.v11.5.txt",
		        "sequence_path": "3880.protein.sequences.v11.5.fa",
		        "enrichment_path": "3880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3880.protein.info.v11.5.txt",
		        "node_list_path": "3880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OligoflexusTunisiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oligoflexus tunisiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OligoflexusTunisiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "708132.protein.sequences.v11.5.fa",
		        "enrichment_path": "708132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "708132.protein.info.v11.5.txt",
		        "node_list_path": "708132.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaProteobacteriumL13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return beta proteobacterium L13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaProteobacteriumL13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229489.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229489.protein.info.v11.5.txt",
		        "node_list_path": "1229489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioVersutusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio versutus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioVersutusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "106634.clusters.info.v11.5.txt",
		        "cluster_tree_path": "106634.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "106634.clusters.proteins.v11.5.txt",
		        "sequence_path": "106634.protein.sequences.v11.5.fa",
		        "enrichment_path": "106634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106634.protein.info.v11.5.txt",
		        "node_list_path": "106634.cluster.nodes.v11.5.txt",
		        "edge_list_path": "106634.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1450648.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1450648.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1450648.clusters.proteins.v11.5.txt",
		        "sequence_path": "1450648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450648.protein.info.v11.5.txt",
		        "node_list_path": "1450648.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1450648.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NosemaBombycisCq1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nosema bombycis CQ1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NosemaBombycisCq1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "578461.protein.sequences.v11.5.fa",
		        "enrichment_path": "578461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578461.protein.info.v11.5.txt",
		        "node_list_path": "578461.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMycoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mycoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMycoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1405.clusters.proteins.v11.5.txt",
		        "sequence_path": "1405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1405.protein.info.v11.5.txt",
		        "node_list_path": "1405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalanaerobiumKushneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halanaerobium kushneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaerobiumKushneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56779.clusters.proteins.v11.5.txt",
		        "sequence_path": "56779.protein.sequences.v11.5.fa",
		        "enrichment_path": "56779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56779.protein.info.v11.5.txt",
		        "node_list_path": "56779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumFunditumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium funditum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumFunditumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449337.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449337.protein.info.v11.5.txt",
		        "node_list_path": "1449337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaViridescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella viridescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaViridescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629.protein.info.v11.5.txt",
		        "node_list_path": "1629.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfurobacteriumSpTc51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurobacterium sp. TC51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurobacteriumSpTc51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158318.protein.info.v11.5.txt",
		        "node_list_path": "1158318.protein.complete.v11.5.txt"
		    }
		]
    )()

def CordycepsMilitarisCm01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps militaris CM01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CordycepsMilitarisCm01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983644.protein.sequences.v11.5.fa",
		        "enrichment_path": "983644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983644.protein.info.v11.5.txt",
		        "node_list_path": "983644.protein.complete.v11.5.txt"
		    }
		]
    )()

def UlvibacterLitoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ulvibacter litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UlvibacterLitoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "227084.protein.sequences.v11.5.fa",
		        "enrichment_path": "227084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227084.protein.info.v11.5.txt",
		        "node_list_path": "227084.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumRifcsphigho212Full4510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RIFCSPHIGHO2_12_FULL_45_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRifcsphigho212Full4510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802603.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802603.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802603.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802603.protein.info.v11.5.txt",
		        "node_list_path": "1802603.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802603.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifcsphigho202Full3936(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPHIGHO2_02_FULL_39_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifcsphigho202Full3936", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797942.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797942.protein.info.v11.5.txt",
		        "node_list_path": "1797942.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorellaVariabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorella variabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorellaVariabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "554065.protein.sequences.v11.5.fa",
		        "enrichment_path": "554065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "554065.protein.info.v11.5.txt",
		        "node_list_path": "554065.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesGambiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles gambiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesGambiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7165.protein.sequences.v11.5.fa",
		        "enrichment_path": "7165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7165.protein.info.v11.5.txt",
		        "node_list_path": "7165.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumSpSpongeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium sp. sponge Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumSpSpongeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1775432.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1775432.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1775432.clusters.proteins.v11.5.txt",
		        "sequence_path": "1775432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775432.protein.info.v11.5.txt",
		        "node_list_path": "1775432.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1775432.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeobacterItalicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter italicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterItalicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "481446.clusters.info.v11.5.txt",
		        "cluster_tree_path": "481446.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "481446.clusters.proteins.v11.5.txt",
		        "sequence_path": "481446.protein.sequences.v11.5.fa",
		        "enrichment_path": "481446.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481446.protein.info.v11.5.txt",
		        "node_list_path": "481446.cluster.nodes.v11.5.txt",
		        "edge_list_path": "481446.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorObsidiansisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor obsidiansis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorObsidiansisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "608506.clusters.info.v11.5.txt",
		        "cluster_tree_path": "608506.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "608506.clusters.proteins.v11.5.txt",
		        "sequence_path": "608506.protein.sequences.v11.5.fa",
		        "enrichment_path": "608506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "608506.protein.info.v11.5.txt",
		        "node_list_path": "608506.cluster.nodes.v11.5.txt",
		        "edge_list_path": "608506.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ApisMellifera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Apis mellifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApisMellifera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7460.protein.sequences.v11.5.fa",
		        "enrichment_path": "7460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7460.protein.info.v11.5.txt",
		        "node_list_path": "7460.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegasphaeraCerevisiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera cerevisiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraCerevisiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39029.protein.sequences.v11.5.fa",
		        "enrichment_path": "39029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39029.protein.info.v11.5.txt",
		        "node_list_path": "39029.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "882083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "882083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "882083.clusters.proteins.v11.5.txt",
		        "sequence_path": "882083.protein.sequences.v11.5.fa",
		        "enrichment_path": "882083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882083.protein.info.v11.5.txt",
		        "node_list_path": "882083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "882083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumAquidurense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium aquidurense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumAquidurense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "362413.protein.sequences.v11.5.fa",
		        "enrichment_path": "362413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362413.protein.info.v11.5.txt",
		        "node_list_path": "362413.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumPhragmitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium phragmitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumPhragmitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "739143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "739143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "739143.clusters.proteins.v11.5.txt",
		        "sequence_path": "739143.protein.sequences.v11.5.fa",
		        "enrichment_path": "739143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "739143.protein.info.v11.5.txt",
		        "node_list_path": "739143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "739143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelosinusFermentansJbw45Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus fermentans JBW45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelosinusFermentansJbw45Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1192197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1192197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1192197.clusters.proteins.v11.5.txt",
		        "sequence_path": "1192197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192197.protein.info.v11.5.txt",
		        "node_list_path": "1192197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1192197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ModestobacterMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Modestobacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ModestobacterMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "477641.protein.sequences.v11.5.fa",
		        "enrichment_path": "477641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477641.protein.info.v11.5.txt",
		        "node_list_path": "477641.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusPiscium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus piscium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusPiscium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1364.protein.info.v11.5.txt",
		        "node_list_path": "1364.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumRbg164519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RBG_16_45_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumRbg164519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817747.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817747.protein.info.v11.5.txt",
		        "node_list_path": "1817747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusHomeothermusArabinoxylanisolvens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Homeothermus arabinoxylanisolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHomeothermusArabinoxylanisolvens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2005518.protein.sequences.v11.5.fa",
		        "enrichment_path": "2005518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2005518.protein.info.v11.5.txt",
		        "node_list_path": "2005518.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfolobusSpJcm16833(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus sp. JCM 16833 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusSpJcm16833", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1294262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294262.protein.info.v11.5.txt",
		        "node_list_path": "1294262.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoregulaBooneiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoregula boonei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoregulaBooneiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "456442.clusters.info.v11.5.txt",
		        "cluster_tree_path": "456442.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "456442.clusters.proteins.v11.5.txt",
		        "sequence_path": "456442.protein.sequences.v11.5.fa",
		        "enrichment_path": "456442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "456442.protein.info.v11.5.txt",
		        "node_list_path": "456442.cluster.nodes.v11.5.txt",
		        "edge_list_path": "456442.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusBathoardescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus bathoardescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusBathoardescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1301915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1301915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1301915.protein.info.v11.5.txt",
		        "node_list_path": "1301915.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumLepromatosis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium lepromatosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumLepromatosis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "480418.protein.sequences.v11.5.fa",
		        "enrichment_path": "480418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "480418.protein.info.v11.5.txt",
		        "node_list_path": "480418.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConidiobolusCoronatusNrrl28638Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Conidiobolus coronatus NRRL 28638 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConidiobolusCoronatusNrrl28638Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "796925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "796925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "796925.clusters.proteins.v11.5.txt",
		        "sequence_path": "796925.protein.sequences.v11.5.fa",
		        "enrichment_path": "796925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796925.protein.info.v11.5.txt",
		        "node_list_path": "796925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "796925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumGwf24416(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_44_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumGwf24416", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798571.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798571.protein.info.v11.5.txt",
		        "node_list_path": "1798571.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumLinens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium linens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumLinens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321955.protein.sequences.v11.5.fa",
		        "enrichment_path": "321955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321955.protein.info.v11.5.txt",
		        "node_list_path": "321955.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesHimastatinicusAtcc53653Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces himastatinicus ATCC 53653 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesHimastatinicusAtcc53653Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "457427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "457427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "457427.clusters.proteins.v11.5.txt",
		        "sequence_path": "457427.protein.sequences.v11.5.fa",
		        "enrichment_path": "457427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457427.protein.info.v11.5.txt",
		        "node_list_path": "457427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "457427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterNeustonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter neustonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterNeustonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1112.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112.protein.info.v11.5.txt",
		        "node_list_path": "1112.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrobacterSuccinogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter succinogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSuccinogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59374.clusters.proteins.v11.5.txt",
		        "sequence_path": "59374.protein.sequences.v11.5.fa",
		        "enrichment_path": "59374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59374.protein.info.v11.5.txt",
		        "node_list_path": "59374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusCapitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus capitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusCapitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "435838.protein.sequences.v11.5.fa",
		        "enrichment_path": "435838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435838.protein.info.v11.5.txt",
		        "node_list_path": "435838.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaCherrii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella cherrii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaCherrii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28084.protein.sequences.v11.5.fa",
		        "enrichment_path": "28084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28084.protein.info.v11.5.txt",
		        "node_list_path": "28084.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnaportheOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnaporthe oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnaportheOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "318829.clusters.info.v11.5.txt",
		        "cluster_tree_path": "318829.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "318829.clusters.proteins.v11.5.txt",
		        "sequence_path": "318829.protein.sequences.v11.5.fa",
		        "enrichment_path": "318829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318829.protein.info.v11.5.txt",
		        "node_list_path": "318829.cluster.nodes.v11.5.txt",
		        "edge_list_path": "318829.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumCellulosolvens6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens 6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumCellulosolvens6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "633697.protein.sequences.v11.5.fa",
		        "enrichment_path": "633697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633697.protein.info.v11.5.txt",
		        "node_list_path": "633697.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIs3022Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-3022 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIs3022Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1772277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1772277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1772277.clusters.proteins.v11.5.txt",
		        "sequence_path": "1772277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772277.protein.info.v11.5.txt",
		        "node_list_path": "1772277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1772277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PiscibacillusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Piscibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiscibacillusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "571933.protein.sequences.v11.5.fa",
		        "enrichment_path": "571933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571933.protein.info.v11.5.txt",
		        "node_list_path": "571933.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1023751Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_37_51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023751Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805303.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805303.protein.info.v11.5.txt",
		        "node_list_path": "1805303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DoreaFormicigeneransAtcc27755(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dorea formicigenerans ATCC27755 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaFormicigeneransAtcc27755", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411461.protein.sequences.v11.5.fa",
		        "enrichment_path": "411461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411461.protein.info.v11.5.txt",
		        "node_list_path": "411461.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaCrocinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia crocina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaCrocinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "429728.clusters.info.v11.5.txt",
		        "cluster_tree_path": "429728.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "429728.clusters.proteins.v11.5.txt",
		        "sequence_path": "429728.protein.sequences.v11.5.fa",
		        "enrichment_path": "429728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "429728.protein.info.v11.5.txt",
		        "node_list_path": "429728.cluster.nodes.v11.5.txt",
		        "edge_list_path": "429728.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwe23121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWE2_31_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwe23121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619073.protein.info.v11.5.txt",
		        "node_list_path": "1619073.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidiphiliumCryptum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidiphilium cryptum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidiphiliumCryptum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349163.protein.sequences.v11.5.fa",
		        "enrichment_path": "349163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349163.protein.info.v11.5.txt",
		        "node_list_path": "349163.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasAntarcticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas antarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAntarcticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "219572.clusters.info.v11.5.txt",
		        "cluster_tree_path": "219572.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "219572.clusters.proteins.v11.5.txt",
		        "sequence_path": "219572.protein.sequences.v11.5.fa",
		        "enrichment_path": "219572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "219572.protein.info.v11.5.txt",
		        "node_list_path": "219572.cluster.nodes.v11.5.txt",
		        "edge_list_path": "219572.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalipaludibacillusAurantiacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salipaludibacillus aurantiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalipaludibacillusAurantiacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1601833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1601833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1601833.clusters.proteins.v11.5.txt",
		        "sequence_path": "1601833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1601833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1601833.protein.info.v11.5.txt",
		        "node_list_path": "1601833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1601833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CallithrixJacchus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Callithrix jacchus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CallithrixJacchus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9483.protein.sequences.v11.5.fa",
		        "enrichment_path": "9483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9483.protein.info.v11.5.txt",
		        "node_list_path": "9483.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospirillalesBacteriumUrhd0088(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium URHD0088 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillalesBacteriumUrhd0088", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380394.protein.info.v11.5.txt",
		        "node_list_path": "1380394.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpHmp27(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. HMP27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpHmp27", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1487921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1487921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1487921.protein.info.v11.5.txt",
		        "node_list_path": "1487921.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsplowo201Full4724(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_01_FULL_47_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo201Full4724", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802401.protein.info.v11.5.txt",
		        "node_list_path": "1802401.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5424Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5424Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798515.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798515.protein.info.v11.5.txt",
		        "node_list_path": "1798515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarlitoSyrichtaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carlito syrichta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarlitoSyrichtaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1868482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1868482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1868482.clusters.proteins.v11.5.txt",
		        "sequence_path": "1868482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1868482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1868482.protein.info.v11.5.txt",
		        "node_list_path": "1868482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1868482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpR372017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. R37(2017) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpR372017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1981685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1981685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1981685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1981685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1981685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1981685.protein.info.v11.5.txt",
		        "node_list_path": "1981685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1981685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoflavibacterZeaxanthinifaciensDsm18436Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanthinifaciens DSM 18436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoflavibacterZeaxanthinifaciensDsm18436Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122225.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122225.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122225.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122225.protein.info.v11.5.txt",
		        "node_list_path": "1122225.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122225.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumCg1023735(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium CG1_02_37_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumCg1023735", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805220.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805220.protein.info.v11.5.txt",
		        "node_list_path": "1805220.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaChinhatensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia chinhatensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaChinhatensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "429727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "429727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "429727.clusters.proteins.v11.5.txt",
		        "sequence_path": "429727.protein.sequences.v11.5.fa",
		        "enrichment_path": "429727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "429727.protein.info.v11.5.txt",
		        "node_list_path": "429727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "429727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFlexibilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas flexibilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFlexibilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "706570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "706570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "706570.clusters.proteins.v11.5.txt",
		        "sequence_path": "706570.protein.sequences.v11.5.fa",
		        "enrichment_path": "706570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706570.protein.info.v11.5.txt",
		        "node_list_path": "706570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "706570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSalivarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus salivarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSalivarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304.protein.info.v11.5.txt",
		        "node_list_path": "1304.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpArr65(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. ARR65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpArr65", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1040989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1040989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1040989.protein.info.v11.5.txt",
		        "node_list_path": "1040989.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteusPenneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteus penneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteusPenneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471881.clusters.proteins.v11.5.txt",
		        "sequence_path": "471881.protein.sequences.v11.5.fa",
		        "enrichment_path": "471881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471881.protein.info.v11.5.txt",
		        "node_list_path": "471881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HathewayaProteolyticaDsm3090(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hathewaya proteolytica DSM 3090 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HathewayaProteolyticaDsm3090", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121331.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121331.protein.info.v11.5.txt",
		        "node_list_path": "1121331.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnr698(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNR698 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnr698", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206101.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206101.protein.info.v11.5.txt",
		        "node_list_path": "1206101.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacteriumBakiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacterium bakii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacteriumBakiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52689.clusters.proteins.v11.5.txt",
		        "sequence_path": "52689.protein.sequences.v11.5.fa",
		        "enrichment_path": "52689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52689.protein.info.v11.5.txt",
		        "node_list_path": "52689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EctothiorhodospiraMagnaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ectothiorhodospira magna Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctothiorhodospiraMagnaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "867345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "867345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "867345.clusters.proteins.v11.5.txt",
		        "sequence_path": "867345.protein.sequences.v11.5.fa",
		        "enrichment_path": "867345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867345.protein.info.v11.5.txt",
		        "node_list_path": "867345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "867345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SuccinatimonasHippei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Succinatimonas hippei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuccinatimonasHippei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762983.protein.sequences.v11.5.fa",
		        "enrichment_path": "762983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762983.protein.info.v11.5.txt",
		        "node_list_path": "762983.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSp117(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. 117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSp117", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125973.protein.info.v11.5.txt",
		        "node_list_path": "1125973.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaAtypicaKonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella atypica KON Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaAtypicaKonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1128111.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1128111.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1128111.clusters.proteins.v11.5.txt",
		        "sequence_path": "1128111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128111.protein.info.v11.5.txt",
		        "node_list_path": "1128111.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1128111.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitratireductorIndicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitratireductor indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratireductorIndicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231190.protein.info.v11.5.txt",
		        "node_list_path": "1231190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasCampaniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas campaniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasCampaniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "213554.clusters.info.v11.5.txt",
		        "cluster_tree_path": "213554.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "213554.clusters.proteins.v11.5.txt",
		        "sequence_path": "213554.protein.sequences.v11.5.fa",
		        "enrichment_path": "213554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "213554.protein.info.v11.5.txt",
		        "node_list_path": "213554.cluster.nodes.v11.5.txt",
		        "edge_list_path": "213554.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumMathurenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium mathurense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumMathurenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "428990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "428990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "428990.clusters.proteins.v11.5.txt",
		        "sequence_path": "428990.protein.sequences.v11.5.fa",
		        "enrichment_path": "428990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428990.protein.info.v11.5.txt",
		        "node_list_path": "428990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "428990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TersicoccusPhoenicisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tersicoccus phoenicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TersicoccusPhoenicisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "554083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "554083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "554083.clusters.proteins.v11.5.txt",
		        "sequence_path": "554083.protein.sequences.v11.5.fa",
		        "enrichment_path": "554083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "554083.protein.info.v11.5.txt",
		        "node_list_path": "554083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "554083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasWeihenstephanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas weihenstephanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasWeihenstephanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1608994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608994.protein.info.v11.5.txt",
		        "node_list_path": "1608994.protein.complete.v11.5.txt"
		    }
		]
    )()

def PanicumHalliiVarHallii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Panicum hallii var. hallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PanicumHalliiVarHallii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1504633.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504633.protein.info.v11.5.txt",
		        "node_list_path": "1504633.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf22910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_29_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf22910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797340.protein.info.v11.5.txt",
		        "node_list_path": "1797340.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusDevrieseiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus devriesei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDevrieseiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123300.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123300.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123300.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123300.protein.info.v11.5.txt",
		        "node_list_path": "1123300.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123300.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumVaginaeDsm15829Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium vaginae DSM15829 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumVaginaeDsm15829Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525256.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525256.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525256.clusters.proteins.v11.5.txt",
		        "sequence_path": "525256.protein.sequences.v11.5.fa",
		        "enrichment_path": "525256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525256.protein.info.v11.5.txt",
		        "node_list_path": "525256.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525256.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomonasSpFbcd(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas sp. FBCd graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomonasSpFbcd", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158292.protein.info.v11.5.txt",
		        "node_list_path": "1158292.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioclavaSp13d2w2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. 13D2W2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaSp13d2w2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1317124.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1317124.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1317124.clusters.proteins.v11.5.txt",
		        "sequence_path": "1317124.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317124.protein.info.v11.5.txt",
		        "node_list_path": "1317124.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1317124.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CentipedaPeriodontii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Centipeda periodontii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CentipedaPeriodontii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888060.protein.sequences.v11.5.fa",
		        "enrichment_path": "888060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888060.protein.info.v11.5.txt",
		        "node_list_path": "888060.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpC8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. C8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpC8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1667357.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1667357.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1667357.clusters.proteins.v11.5.txt",
		        "sequence_path": "1667357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1667357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1667357.protein.info.v11.5.txt",
		        "node_list_path": "1667357.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1667357.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusVersutusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus versutus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusVersutusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34007.clusters.proteins.v11.5.txt",
		        "sequence_path": "34007.protein.sequences.v11.5.fa",
		        "enrichment_path": "34007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34007.protein.info.v11.5.txt",
		        "node_list_path": "34007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaNautarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella nautarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaNautarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45070.protein.sequences.v11.5.fa",
		        "enrichment_path": "45070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45070.protein.info.v11.5.txt",
		        "node_list_path": "45070.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlleyaMarilimosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olleya marilimosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlleyaMarilimosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1353276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353276.protein.info.v11.5.txt",
		        "node_list_path": "1353276.protein.complete.v11.5.txt"
		    }
		]
    )()

def SediminibacillusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacillusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926277.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926277.protein.info.v11.5.txt",
		        "node_list_path": "1926277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TepidibacterThalassicusDsm15285Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tepidibacter thalassicus DSM 15285 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidibacterThalassicusDsm15285Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123350.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123350.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123350.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123350.protein.info.v11.5.txt",
		        "node_list_path": "1123350.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123350.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotorhabdusLuminescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photorhabdus luminescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotorhabdusLuminescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243265.clusters.proteins.v11.5.txt",
		        "sequence_path": "243265.protein.sequences.v11.5.fa",
		        "enrichment_path": "243265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243265.protein.info.v11.5.txt",
		        "node_list_path": "243265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterAsymbioticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter asymbioticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterAsymbioticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "576611.protein.sequences.v11.5.fa",
		        "enrichment_path": "576611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "576611.protein.info.v11.5.txt",
		        "node_list_path": "576611.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpFobrc9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. FOBRC9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpFobrc9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936573.protein.sequences.v11.5.fa",
		        "enrichment_path": "936573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936573.protein.info.v11.5.txt",
		        "node_list_path": "936573.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachyspiraHampsonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira hampsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraHampsonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1289135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1289135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1289135.protein.info.v11.5.txt",
		        "node_list_path": "1289135.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpPamc21119(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. PAMC21119 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpPamc21119", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1112209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112209.protein.info.v11.5.txt",
		        "node_list_path": "1112209.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterAscendens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter ascendens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterAscendens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "481146.protein.sequences.v11.5.fa",
		        "enrichment_path": "481146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481146.protein.info.v11.5.txt",
		        "node_list_path": "481146.protein.complete.v11.5.txt"
		    }
		]
    )()

def TersicoccusPhoenicis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tersicoccus phoenicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TersicoccusPhoenicis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "554083.protein.sequences.v11.5.fa",
		        "enrichment_path": "554083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "554083.protein.info.v11.5.txt",
		        "node_list_path": "554083.protein.complete.v11.5.txt"
		    }
		]
    )()

def PoeciliaFormosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Poecilia formosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PoeciliaFormosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "48698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "48698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "48698.clusters.proteins.v11.5.txt",
		        "sequence_path": "48698.protein.sequences.v11.5.fa",
		        "enrichment_path": "48698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48698.protein.info.v11.5.txt",
		        "node_list_path": "48698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "48698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpTb67Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. TB67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpTb67Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1055815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1055815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1055815.clusters.proteins.v11.5.txt",
		        "sequence_path": "1055815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1055815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1055815.protein.info.v11.5.txt",
		        "node_list_path": "1055815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1055815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumErythreum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium erythreum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumErythreum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2041.protein.sequences.v11.5.fa",
		        "enrichment_path": "2041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2041.protein.info.v11.5.txt",
		        "node_list_path": "2041.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusLocisalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus locisalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusLocisalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "305507.protein.sequences.v11.5.fa",
		        "enrichment_path": "305507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "305507.protein.info.v11.5.txt",
		        "node_list_path": "305507.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacterium5246(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium 52_46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacterium5246", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897040.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897040.protein.info.v11.5.txt",
		        "node_list_path": "1897040.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterAceti1023(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter aceti 1023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterAceti1023", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1457393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1457393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1457393.protein.info.v11.5.txt",
		        "node_list_path": "1457393.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaSp428Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea sp. 42_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaSp428Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896999.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896999.protein.info.v11.5.txt",
		        "node_list_path": "1896999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermosyntrophaLipolyticaDsm11003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermosyntropha lipolytica DSM 11003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosyntrophaLipolyticaDsm11003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123382.protein.info.v11.5.txt",
		        "node_list_path": "1123382.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacaedibacterAcanthamoebae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracaedibacter acanthamoebae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacaedibacterAcanthamoebae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "91604.protein.sequences.v11.5.fa",
		        "enrichment_path": "91604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91604.protein.info.v11.5.txt",
		        "node_list_path": "91604.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumDg741Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_74_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumDg741Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703765.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703765.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703765.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703765.protein.info.v11.5.txt",
		        "node_list_path": "1703765.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703765.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OstreococcusTauriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ostreococcus tauri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OstreococcusTauriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "70448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "70448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "70448.clusters.proteins.v11.5.txt",
		        "sequence_path": "70448.protein.sequences.v11.5.fa",
		        "enrichment_path": "70448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "70448.protein.info.v11.5.txt",
		        "node_list_path": "70448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "70448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674845.protein.info.v11.5.txt",
		        "node_list_path": "1674845.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichodermaAtrovirideCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma atroviride Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaAtrovirideCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "63577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "63577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "63577.clusters.proteins.v11.5.txt",
		        "sequence_path": "63577.protein.sequences.v11.5.fa",
		        "enrichment_path": "63577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63577.protein.info.v11.5.txt",
		        "node_list_path": "63577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "63577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaSpLrs4154(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. LRS4.154 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaSpLrs4154", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1962155.protein.sequences.v11.5.fa",
		        "enrichment_path": "1962155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1962155.protein.info.v11.5.txt",
		        "node_list_path": "1962155.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusVerrucosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus verrucosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusVerrucosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "342668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "342668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "342668.clusters.proteins.v11.5.txt",
		        "sequence_path": "342668.protein.sequences.v11.5.fa",
		        "enrichment_path": "342668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342668.protein.info.v11.5.txt",
		        "node_list_path": "342668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "342668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesProvencensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces provencensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesProvencensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720198.protein.info.v11.5.txt",
		        "node_list_path": "1720198.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5421bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPLOWO2_01_FULL_54_21b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5421bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797245.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797245.protein.info.v11.5.txt",
		        "node_list_path": "1797245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoheibacterSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moheibacter sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoheibacterSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434700.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434700.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434700.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434700.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434700.protein.info.v11.5.txt",
		        "node_list_path": "1434700.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434700.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalegentibacterSpT436(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter sp. T436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterSpT436", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729720.protein.info.v11.5.txt",
		        "node_list_path": "1729720.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaplasmaPhagocytophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma phagocytophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaplasmaPhagocytophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "212042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "212042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "212042.clusters.proteins.v11.5.txt",
		        "sequence_path": "212042.protein.sequences.v11.5.fa",
		        "enrichment_path": "212042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "212042.protein.info.v11.5.txt",
		        "node_list_path": "212042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "212042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSuncheonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium suncheonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSuncheonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121899.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121899.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121899.protein.info.v11.5.txt",
		        "node_list_path": "1121899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobellusClavatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobellus clavatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobellusClavatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "660517.protein.sequences.v11.5.fa",
		        "enrichment_path": "660517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660517.protein.info.v11.5.txt",
		        "node_list_path": "660517.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaCalifornicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma californicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaCalifornicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2113.protein.sequences.v11.5.fa",
		        "enrichment_path": "2113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2113.protein.info.v11.5.txt",
		        "node_list_path": "2113.protein.complete.v11.5.txt"
		    }
		]
    )()

def JeotgalibacillusAlimentarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalibacillus alimentarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalibacillusAlimentarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "135826.protein.sequences.v11.5.fa",
		        "enrichment_path": "135826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "135826.protein.info.v11.5.txt",
		        "node_list_path": "135826.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanktothricoidesSpSr001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planktothricoides sp. SR001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktothricoidesSpSr001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1705388.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1705388.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1705388.clusters.proteins.v11.5.txt",
		        "sequence_path": "1705388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705388.protein.info.v11.5.txt",
		        "node_list_path": "1705388.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1705388.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumRubensWisconsin541255Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium rubens Wisconsin 54-1255 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumRubensWisconsin541255Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "500485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "500485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "500485.clusters.proteins.v11.5.txt",
		        "sequence_path": "500485.protein.sequences.v11.5.fa",
		        "enrichment_path": "500485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500485.protein.info.v11.5.txt",
		        "node_list_path": "500485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "500485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TamlanaSedimentorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tamlana sedimentorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TamlanaSedimentorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1435349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1435349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1435349.protein.info.v11.5.txt",
		        "node_list_path": "1435349.protein.complete.v11.5.txt"
		    }
		]
    )()

def MinicystisRoseaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Minicystis rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MinicystisRoseaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888845.clusters.proteins.v11.5.txt",
		        "sequence_path": "888845.protein.sequences.v11.5.fa",
		        "enrichment_path": "888845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888845.protein.info.v11.5.txt",
		        "node_list_path": "888845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpCfcc11742Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. CFCC 11742 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpCfcc11742Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1775560.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1775560.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1775560.clusters.proteins.v11.5.txt",
		        "sequence_path": "1775560.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775560.protein.info.v11.5.txt",
		        "node_list_path": "1775560.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1775560.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AromatoleumToluclasticumAtcc700605(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aromatoleum toluclasticum ATCC 700605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AromatoleumToluclasticumAtcc700605", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1261621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261621.protein.info.v11.5.txt",
		        "node_list_path": "1261621.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpMi1205Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. MI1205 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpMi1205Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "407020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "407020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "407020.clusters.proteins.v11.5.txt",
		        "sequence_path": "407020.protein.sequences.v11.5.fa",
		        "enrichment_path": "407020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "407020.protein.info.v11.5.txt",
		        "node_list_path": "407020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "407020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KwoniellaDejecticolaCbs10117(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella dejecticola CBS 10117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KwoniellaDejecticolaCbs10117", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1296121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296121.protein.info.v11.5.txt",
		        "node_list_path": "1296121.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloteneraSpRifcsplowo202Full4514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera sp. RIFCSPLOWO2_02_FULL_45_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraSpRifcsplowo202Full4514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801615.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801615.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801615.protein.info.v11.5.txt",
		        "node_list_path": "1801615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophilusSpOh31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. OH31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusSpOh31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1387312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387312.protein.info.v11.5.txt",
		        "node_list_path": "1387312.protein.complete.v11.5.txt"
		    }
		]
    )()

def TropilaelapsMercedesae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tropilaelaps mercedesae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TropilaelapsMercedesae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "418985.protein.sequences.v11.5.fa",
		        "enrichment_path": "418985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "418985.protein.info.v11.5.txt",
		        "node_list_path": "418985.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusTigurinus1366(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus tigurinus 1366 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusTigurinus1366", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1282665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282665.protein.info.v11.5.txt",
		        "node_list_path": "1282665.protein.complete.v11.5.txt"
		    }
		]
    )()

def FolsomiaCandidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Folsomia candida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FolsomiaCandidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "158441.clusters.info.v11.5.txt",
		        "cluster_tree_path": "158441.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "158441.clusters.proteins.v11.5.txt",
		        "sequence_path": "158441.protein.sequences.v11.5.fa",
		        "enrichment_path": "158441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158441.protein.info.v11.5.txt",
		        "node_list_path": "158441.cluster.nodes.v11.5.txt",
		        "edge_list_path": "158441.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidimicrobiaceaeBacteriumRaap2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidimicrobiaceae bacterium RAAP-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidimicrobiaceaeBacteriumRaap2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736654.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736654.protein.info.v11.5.txt",
		        "node_list_path": "1736654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusDuerdeniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus duerdenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusDuerdeniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "862517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "862517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "862517.clusters.proteins.v11.5.txt",
		        "sequence_path": "862517.protein.sequences.v11.5.fa",
		        "enrichment_path": "862517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862517.protein.info.v11.5.txt",
		        "node_list_path": "862517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "862517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterHaemolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter haemolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterHaemolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1331660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1331660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1331660.clusters.proteins.v11.5.txt",
		        "sequence_path": "1331660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1331660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1331660.protein.info.v11.5.txt",
		        "node_list_path": "1331660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1331660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GigasporaRoseaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gigaspora rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GigasporaRoseaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44941.clusters.proteins.v11.5.txt",
		        "sequence_path": "44941.protein.sequences.v11.5.fa",
		        "enrichment_path": "44941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44941.protein.info.v11.5.txt",
		        "node_list_path": "44941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetallosphaeraYellowstonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metallosphaera yellowstonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetallosphaeraYellowstonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "671065.protein.sequences.v11.5.fa",
		        "enrichment_path": "671065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "671065.protein.info.v11.5.txt",
		        "node_list_path": "671065.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpMf4836Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. MF4836 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpMf4836Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1960827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1960827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1960827.clusters.proteins.v11.5.txt",
		        "sequence_path": "1960827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1960827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1960827.protein.info.v11.5.txt",
		        "node_list_path": "1960827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1960827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusRattiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus ratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusRattiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "150033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "150033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "150033.clusters.proteins.v11.5.txt",
		        "sequence_path": "150033.protein.sequences.v11.5.fa",
		        "enrichment_path": "150033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150033.protein.info.v11.5.txt",
		        "node_list_path": "150033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "150033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpF52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. F52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpF52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1202532.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1202532.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1202532.clusters.proteins.v11.5.txt",
		        "sequence_path": "1202532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202532.protein.info.v11.5.txt",
		        "node_list_path": "1202532.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1202532.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_49_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798396.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798396.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798396.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798396.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798396.protein.info.v11.5.txt",
		        "node_list_path": "1798396.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798396.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacterium13140cm6619(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 13_1_40CM_66_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacterium13140cm6619", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805081.protein.info.v11.5.txt",
		        "node_list_path": "1805081.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaDrozanskiiLlap1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella drozanskii LLAP-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaDrozanskiiLlap1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1212489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1212489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1212489.protein.info.v11.5.txt",
		        "node_list_path": "1212489.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPneumoniaeR6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae R6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPneumoniaeR6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "171101.protein.sequences.v11.5.fa",
		        "enrichment_path": "171101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "171101.protein.info.v11.5.txt",
		        "node_list_path": "171101.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmoSalarCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmo salar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmoSalarCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8030.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8030.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8030.clusters.proteins.v11.5.txt",
		        "sequence_path": "8030.protein.sequences.v11.5.fa",
		        "enrichment_path": "8030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8030.protein.info.v11.5.txt",
		        "node_list_path": "8030.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8030.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCb02923Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB02923 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCb02923Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1718985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1718985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1718985.clusters.proteins.v11.5.txt",
		        "sequence_path": "1718985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1718985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1718985.protein.info.v11.5.txt",
		        "node_list_path": "1718985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1718985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpUrhd0069Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. URHD0069 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpUrhd0069Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380355.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380355.protein.info.v11.5.txt",
		        "node_list_path": "1380355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumGrantiiDsm8605(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium grantii DSM 8605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumGrantiiDsm8605", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121316.protein.info.v11.5.txt",
		        "node_list_path": "1121316.protein.complete.v11.5.txt"
		    }
		]
    )()

def SuricataSuricatta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Suricata suricatta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuricataSuricatta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37032.protein.sequences.v11.5.fa",
		        "enrichment_path": "37032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37032.protein.info.v11.5.txt",
		        "node_list_path": "37032.protein.complete.v11.5.txt"
		    }
		]
    )()

def SorghumBicolorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sorghum bicolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SorghumBicolorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4558.clusters.proteins.v11.5.txt",
		        "sequence_path": "4558.protein.sequences.v11.5.fa",
		        "enrichment_path": "4558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4558.protein.info.v11.5.txt",
		        "node_list_path": "4558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterSegnisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter segnis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSegnisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "509190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "509190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "509190.clusters.proteins.v11.5.txt",
		        "sequence_path": "509190.protein.sequences.v11.5.fa",
		        "enrichment_path": "509190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "509190.protein.info.v11.5.txt",
		        "node_list_path": "509190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "509190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPelagiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pelagia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPelagiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1323663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1323663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1323663.clusters.proteins.v11.5.txt",
		        "sequence_path": "1323663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1323663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1323663.protein.info.v11.5.txt",
		        "node_list_path": "1323663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1323663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumDentiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium dentium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumDentiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "401473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "401473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "401473.clusters.proteins.v11.5.txt",
		        "sequence_path": "401473.protein.sequences.v11.5.fa",
		        "enrichment_path": "401473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "401473.protein.info.v11.5.txt",
		        "node_list_path": "401473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "401473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfitobacteriumDichloroeliminansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium dichloroeliminans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitobacteriumDichloroeliminansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "871963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "871963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "871963.clusters.proteins.v11.5.txt",
		        "sequence_path": "871963.protein.sequences.v11.5.fa",
		        "enrichment_path": "871963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871963.protein.info.v11.5.txt",
		        "node_list_path": "871963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "871963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisSaalfeldensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis saalfeldensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisSaalfeldensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "394193.protein.sequences.v11.5.fa",
		        "enrichment_path": "394193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394193.protein.info.v11.5.txt",
		        "node_list_path": "394193.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifoxyd12Full6137(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFOXYD12_FULL_61_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifoxyd12Full6137", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798308.protein.info.v11.5.txt",
		        "node_list_path": "1798308.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionNc10BacteriumCsp15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division NC10 bacterium CSP1-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionNc10BacteriumCsp15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1640516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640516.protein.info.v11.5.txt",
		        "node_list_path": "1640516.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterNitrofigilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter nitrofigilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterNitrofigilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "572480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "572480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "572480.clusters.proteins.v11.5.txt",
		        "sequence_path": "572480.protein.sequences.v11.5.fa",
		        "enrichment_path": "572480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572480.protein.info.v11.5.txt",
		        "node_list_path": "572480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "572480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfobiumNarugenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfobium narugense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfobiumNarugenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "747365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "747365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "747365.clusters.proteins.v11.5.txt",
		        "sequence_path": "747365.protein.sequences.v11.5.fa",
		        "enrichment_path": "747365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747365.protein.info.v11.5.txt",
		        "node_list_path": "747365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "747365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SeriolaLalandiDorsalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Seriola lalandi dorsalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SeriolaLalandiDorsalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841481.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841481.protein.info.v11.5.txt",
		        "node_list_path": "1841481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumAntarcticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumAntarcticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "416450.clusters.info.v11.5.txt",
		        "cluster_tree_path": "416450.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "416450.clusters.proteins.v11.5.txt",
		        "sequence_path": "416450.protein.sequences.v11.5.fa",
		        "enrichment_path": "416450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416450.protein.info.v11.5.txt",
		        "node_list_path": "416450.cluster.nodes.v11.5.txt",
		        "edge_list_path": "416450.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifoxyb2Full4511(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYB2_FULL_45_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyb2Full4511", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802421.protein.info.v11.5.txt",
		        "node_list_path": "1802421.protein.complete.v11.5.txt"
		    }
		]
    )()

def WoodsholeaMaritimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Woodsholea maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WoodsholeaMaritimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123503.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123503.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123503.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123503.protein.info.v11.5.txt",
		        "node_list_path": "1123503.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123503.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumColicanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium colicanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumColicanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999411.clusters.proteins.v11.5.txt",
		        "sequence_path": "999411.protein.sequences.v11.5.fa",
		        "enrichment_path": "999411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999411.protein.info.v11.5.txt",
		        "node_list_path": "999411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubellimicrobiumThermophilumDsm16684(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubellimicrobium thermophilum DSM 16684 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubellimicrobiumThermophilumDsm16684", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123069.protein.info.v11.5.txt",
		        "node_list_path": "1123069.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumCatenulatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium catenulatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumCatenulatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "566552.protein.sequences.v11.5.fa",
		        "enrichment_path": "566552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "566552.protein.info.v11.5.txt",
		        "node_list_path": "566552.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSp7sr1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. 7SR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSp7sr1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881017.protein.info.v11.5.txt",
		        "node_list_path": "1881017.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermincolaPotens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermincola potens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermincolaPotens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "635013.protein.sequences.v11.5.fa",
		        "enrichment_path": "635013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "635013.protein.info.v11.5.txt",
		        "node_list_path": "635013.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumScadc123(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium SCADC1_2_3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumScadc123", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1487582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1487582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1487582.protein.info.v11.5.txt",
		        "node_list_path": "1487582.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionCpr2BacteriumGw2011Gwc23910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR2 bacterium GW2011_GWC2_39_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionCpr2BacteriumGw2011Gwc23910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618345.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618345.protein.info.v11.5.txt",
		        "node_list_path": "1618345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldimonasTaiwanensisNbrc104434(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldimonas taiwanensis NBRC 104434 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldimonasTaiwanensisNbrc104434", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349753.protein.info.v11.5.txt",
		        "node_list_path": "1349753.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpEur3121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. EUR3 1.2.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpEur3121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1305734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1305734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1305734.clusters.proteins.v11.5.txt",
		        "sequence_path": "1305734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305734.protein.info.v11.5.txt",
		        "node_list_path": "1305734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1305734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophusAciditrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophus aciditrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophusAciditrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56780.protein.sequences.v11.5.fa",
		        "enrichment_path": "56780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56780.protein.info.v11.5.txt",
		        "node_list_path": "56780.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumRoseumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium roseum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumRoseumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84029.clusters.proteins.v11.5.txt",
		        "sequence_path": "84029.protein.sequences.v11.5.fa",
		        "enrichment_path": "84029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84029.protein.info.v11.5.txt",
		        "node_list_path": "84029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacteriaceaeBacteriumStrain(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium strain graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacteriaceaeBacteriumStrain", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "693444.protein.sequences.v11.5.fa",
		        "enrichment_path": "693444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693444.protein.info.v11.5.txt",
		        "node_list_path": "693444.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoplasmatalesArchaeonSg8523Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon SG8-52-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmatalesArchaeonSg8523Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803818.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803818.protein.info.v11.5.txt",
		        "node_list_path": "1803818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporomusaMalonicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporomusa malonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporomusaMalonicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "112901.clusters.info.v11.5.txt",
		        "cluster_tree_path": "112901.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "112901.clusters.proteins.v11.5.txt",
		        "sequence_path": "112901.protein.sequences.v11.5.fa",
		        "enrichment_path": "112901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112901.protein.info.v11.5.txt",
		        "node_list_path": "112901.cluster.nodes.v11.5.txt",
		        "edge_list_path": "112901.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumCg2306627(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CG2_30_66_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumCg2306627", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805127.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805127.protein.info.v11.5.txt",
		        "node_list_path": "1805127.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCollagenovoransDsm3089(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium collagenovorans DSM 3089 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCollagenovoransDsm3089", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121306.protein.info.v11.5.txt",
		        "node_list_path": "1121306.protein.complete.v11.5.txt"
		    }
		]
    )()

def OidiodendronMaiusZnCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oidiodendron maius Zn Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OidiodendronMaiusZnCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "913774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "913774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "913774.clusters.proteins.v11.5.txt",
		        "sequence_path": "913774.protein.sequences.v11.5.fa",
		        "enrichment_path": "913774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913774.protein.info.v11.5.txt",
		        "node_list_path": "913774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "913774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlbugoCandidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Albugo candida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlbugoCandidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "65357.clusters.info.v11.5.txt",
		        "cluster_tree_path": "65357.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "65357.clusters.proteins.v11.5.txt",
		        "sequence_path": "65357.protein.sequences.v11.5.fa",
		        "enrichment_path": "65357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65357.protein.info.v11.5.txt",
		        "node_list_path": "65357.cluster.nodes.v11.5.txt",
		        "edge_list_path": "65357.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusChinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus chinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusChinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525640.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525640.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525640.clusters.proteins.v11.5.txt",
		        "sequence_path": "525640.protein.sequences.v11.5.fa",
		        "enrichment_path": "525640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525640.protein.info.v11.5.txt",
		        "node_list_path": "525640.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525640.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacterium5246Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium 52_46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacterium5246Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897040.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897040.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897040.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897040.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897040.protein.info.v11.5.txt",
		        "node_list_path": "1897040.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897040.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CylindrobasidiumTorrendiiFp15055Ss10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cylindrobasidium torrendii FP15055 ss-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CylindrobasidiumTorrendiiFp15055Ss10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314674.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314674.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314674.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314674.protein.info.v11.5.txt",
		        "node_list_path": "1314674.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314674.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusLacustrisStrTousCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus lacustris str. Tous Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusLacustrisStrTousCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1910958.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1910958.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1910958.clusters.proteins.v11.5.txt",
		        "sequence_path": "1910958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1910958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1910958.protein.info.v11.5.txt",
		        "node_list_path": "1910958.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1910958.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpRitPiE(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. RIT-PI-e graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpRitPiE", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1681197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1681197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1681197.protein.info.v11.5.txt",
		        "node_list_path": "1681197.protein.complete.v11.5.txt"
		    }
		]
    )()

def AhrensiaSpR2a130Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ahrensia sp. R2A130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AhrensiaSpR2a130Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "744979.clusters.info.v11.5.txt",
		        "cluster_tree_path": "744979.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "744979.clusters.proteins.v11.5.txt",
		        "sequence_path": "744979.protein.sequences.v11.5.fa",
		        "enrichment_path": "744979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "744979.protein.info.v11.5.txt",
		        "node_list_path": "744979.cluster.nodes.v11.5.txt",
		        "edge_list_path": "744979.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GracilariopsisChordaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gracilariopsis chorda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilariopsisChordaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "448386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "448386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "448386.clusters.proteins.v11.5.txt",
		        "sequence_path": "448386.protein.sequences.v11.5.fa",
		        "enrichment_path": "448386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "448386.protein.info.v11.5.txt",
		        "node_list_path": "448386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "448386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121362.protein.info.v11.5.txt",
		        "node_list_path": "1121362.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumIranicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium iranicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumIranicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "912594.protein.sequences.v11.5.fa",
		        "enrichment_path": "912594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "912594.protein.info.v11.5.txt",
		        "node_list_path": "912594.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterSubantarcticusLmg24377Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter subantarcticus LMG 24377 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSubantarcticusLmg24377Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1388752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1388752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1388752.clusters.proteins.v11.5.txt",
		        "sequence_path": "1388752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1388752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1388752.protein.info.v11.5.txt",
		        "node_list_path": "1388752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1388752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321775.protein.info.v11.5.txt",
		        "node_list_path": "1321775.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensF113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens F113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensF113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1114970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1114970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1114970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1114970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114970.protein.info.v11.5.txt",
		        "node_list_path": "1114970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1114970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusZymaeDsm19395Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus zymae DSM 19395 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusZymaeDsm19395Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423817.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423817.protein.info.v11.5.txt",
		        "node_list_path": "1423817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasJeotgali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasJeotgali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1238190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238190.protein.info.v11.5.txt",
		        "node_list_path": "1238190.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaJinanensisNbrc108249Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia jinanensis NBRC 108249 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaJinanensisNbrc108249Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210082.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210082.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210082.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210082.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210082.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210082.protein.info.v11.5.txt",
		        "node_list_path": "1210082.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210082.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmazonaCollariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amazona collaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmazonaCollariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "241587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "241587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "241587.clusters.proteins.v11.5.txt",
		        "sequence_path": "241587.protein.sequences.v11.5.fa",
		        "enrichment_path": "241587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "241587.protein.info.v11.5.txt",
		        "node_list_path": "241587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "241587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpHu2014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. HU2014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpHu2014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1664275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1664275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1664275.protein.info.v11.5.txt",
		        "node_list_path": "1664275.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMusc14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MUSC 14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMusc14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1354889.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1354889.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1354889.clusters.proteins.v11.5.txt",
		        "sequence_path": "1354889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354889.protein.info.v11.5.txt",
		        "node_list_path": "1354889.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1354889.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasRubraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasRubraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1117318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1117318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1117318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117318.protein.info.v11.5.txt",
		        "node_list_path": "1117318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1117318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlatysternonMegacephalum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Platysternon megacephalum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlatysternonMegacephalum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "55544.protein.sequences.v11.5.fa",
		        "enrichment_path": "55544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55544.protein.info.v11.5.txt",
		        "node_list_path": "55544.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110057(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110057", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1570346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570346.protein.info.v11.5.txt",
		        "node_list_path": "1570346.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat28573Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-28573 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat28573Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720554.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720554.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720554.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720554.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720554.protein.info.v11.5.txt",
		        "node_list_path": "1720554.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720554.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylocystisBryophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylocystis bryophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocystisBryophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655015.protein.sequences.v11.5.fa",
		        "enrichment_path": "655015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655015.protein.info.v11.5.txt",
		        "node_list_path": "655015.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSelenitireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium selenitireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSelenitireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336235.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336235.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336235.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336235.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336235.protein.info.v11.5.txt",
		        "node_list_path": "1336235.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336235.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisLatens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis latens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisLatens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1503980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1503980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1503980.protein.info.v11.5.txt",
		        "node_list_path": "1503980.protein.complete.v11.5.txt"
		    }
		]
    )()

def KurthiaSpDielmo(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kurthia sp. Dielmo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KurthiaSpDielmo", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033738.protein.info.v11.5.txt",
		        "node_list_path": "1033738.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanothrixSoehngeniiGp6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanothrix soehngenii GP6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothrixSoehngeniiGp6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "990316.protein.sequences.v11.5.fa",
		        "enrichment_path": "990316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990316.protein.info.v11.5.txt",
		        "node_list_path": "990316.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusSpYim77409(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus sp. YIM77409 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusSpYim77409", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449080.protein.info.v11.5.txt",
		        "node_list_path": "1449080.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaFlocculareAtcc27399Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma flocculare ATCC 27399 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaFlocculareAtcc27399Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743971.clusters.proteins.v11.5.txt",
		        "sequence_path": "743971.protein.sequences.v11.5.fa",
		        "enrichment_path": "743971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743971.protein.info.v11.5.txt",
		        "node_list_path": "743971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp141(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 141 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp141", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120797.protein.info.v11.5.txt",
		        "node_list_path": "1120797.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomassariellaVexata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomassariella vexata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomassariellaVexata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1141098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141098.protein.info.v11.5.txt",
		        "node_list_path": "1141098.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseivirgaSeohaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseivirga seohaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivirgaSeohaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1914963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1914963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1914963.protein.info.v11.5.txt",
		        "node_list_path": "1914963.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodolunaLacicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodoluna lacicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodolunaLacicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "529884.protein.sequences.v11.5.fa",
		        "enrichment_path": "529884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529884.protein.info.v11.5.txt",
		        "node_list_path": "529884.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumRbg19ftCombo6530Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_19FT_COMBO_65_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg19ftCombo6530Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797277.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797277.protein.info.v11.5.txt",
		        "node_list_path": "1797277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinitogaSp1155Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinitoga sp. 1155 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinitogaSp1155Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1428448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1428448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1428448.clusters.proteins.v11.5.txt",
		        "sequence_path": "1428448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1428448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1428448.protein.info.v11.5.txt",
		        "node_list_path": "1428448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1428448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaMimosarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia mimosarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaMimosarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1038869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1038869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1038869.clusters.proteins.v11.5.txt",
		        "sequence_path": "1038869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038869.protein.info.v11.5.txt",
		        "node_list_path": "1038869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1038869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpUnccl28(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UNCCL28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpUnccl28", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502752.protein.info.v11.5.txt",
		        "node_list_path": "1502752.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterJuniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter junii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterJuniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40215.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40215.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40215.clusters.proteins.v11.5.txt",
		        "sequence_path": "40215.protein.sequences.v11.5.fa",
		        "enrichment_path": "40215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40215.protein.info.v11.5.txt",
		        "node_list_path": "40215.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40215.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteralesBacteriumY4i(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium Y4I graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteralesBacteriumY4i", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "439496.protein.sequences.v11.5.fa",
		        "enrichment_path": "439496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439496.protein.info.v11.5.txt",
		        "node_list_path": "439496.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumGwf25010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_50_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumGwf25010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801959.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801959.protein.info.v11.5.txt",
		        "node_list_path": "1801959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusDictyosporus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus dictyosporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusDictyosporus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523247.protein.info.v11.5.txt",
		        "node_list_path": "1523247.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZimmermannellaAlbaNbrc15616Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Zimmermannella] alba NBRC 15616 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZimmermannellaAlbaNbrc15616Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349786.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349786.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349786.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349786.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349786.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349786.protein.info.v11.5.txt",
		        "node_list_path": "1349786.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349786.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PediococcusStilesii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus stilesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusStilesii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "331679.protein.sequences.v11.5.fa",
		        "enrichment_path": "331679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331679.protein.info.v11.5.txt",
		        "node_list_path": "331679.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobaculumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobaculumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "202789.protein.sequences.v11.5.fa",
		        "enrichment_path": "202789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202789.protein.info.v11.5.txt",
		        "node_list_path": "202789.protein.complete.v11.5.txt"
		    }
		]
    )()

def GayadomonasJoobiniegeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gayadomonas joobiniege Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GayadomonasJoobiniegeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1046714.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1046714.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1046714.clusters.proteins.v11.5.txt",
		        "sequence_path": "1046714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046714.protein.info.v11.5.txt",
		        "node_list_path": "1046714.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1046714.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeisingeraSpAngM7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leisingera sp. ANG-M7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraSpAngM7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577902.protein.info.v11.5.txt",
		        "node_list_path": "1577902.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavihumibacterPetaseusNbrc106054Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavihumibacter petaseus NBRC 106054 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavihumibacterPetaseusNbrc106054Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220578.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220578.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220578.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220578.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220578.protein.info.v11.5.txt",
		        "node_list_path": "1220578.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220578.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumGa0077544Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium Ga0077544 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumGa0077544Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752206.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752206.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752206.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752206.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752206.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752206.protein.info.v11.5.txt",
		        "node_list_path": "1752206.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752206.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumCfCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium CF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumCfCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1400053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1400053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1400053.clusters.proteins.v11.5.txt",
		        "sequence_path": "1400053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400053.protein.info.v11.5.txt",
		        "node_list_path": "1400053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1400053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WilliamsiaSp1138(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Williamsia sp. 1138 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WilliamsiaSp1138", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1903117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903117.protein.info.v11.5.txt",
		        "node_list_path": "1903117.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteribacillusBidgolensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteribacillus bidgolensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteribacillusBidgolensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930129.protein.sequences.v11.5.fa",
		        "enrichment_path": "930129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930129.protein.info.v11.5.txt",
		        "node_list_path": "930129.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0386Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0386 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0386Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762963.clusters.proteins.v11.5.txt",
		        "sequence_path": "762963.protein.sequences.v11.5.fa",
		        "enrichment_path": "762963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762963.protein.info.v11.5.txt",
		        "node_list_path": "762963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloterricolaOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloterricola oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloterricolaOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1495050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1495050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1495050.clusters.proteins.v11.5.txt",
		        "sequence_path": "1495050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495050.protein.info.v11.5.txt",
		        "node_list_path": "1495050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1495050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpA37Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. A37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpA37Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945864.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945864.protein.info.v11.5.txt",
		        "node_list_path": "1945864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MacacaMulattaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Macaca mulatta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacacaMulattaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9544.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9544.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9544.clusters.proteins.v11.5.txt",
		        "sequence_path": "9544.protein.sequences.v11.5.fa",
		        "enrichment_path": "9544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9544.protein.info.v11.5.txt",
		        "node_list_path": "9544.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9544.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "946235.protein.sequences.v11.5.fa",
		        "enrichment_path": "946235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946235.protein.info.v11.5.txt",
		        "node_list_path": "946235.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGa0077523(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077523 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077523", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752198.protein.info.v11.5.txt",
		        "node_list_path": "1752198.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusXiangfangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus xiangfangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusXiangfangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "942150.protein.sequences.v11.5.fa",
		        "enrichment_path": "942150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "942150.protein.info.v11.5.txt",
		        "node_list_path": "942150.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumDolichumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium dolichum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumDolichumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "428127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "428127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "428127.clusters.proteins.v11.5.txt",
		        "sequence_path": "428127.protein.sequences.v11.5.fa",
		        "enrichment_path": "428127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428127.protein.info.v11.5.txt",
		        "node_list_path": "428127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "428127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusPseudalcaliphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus pseudalcaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPseudalcaliphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "79884.protein.sequences.v11.5.fa",
		        "enrichment_path": "79884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79884.protein.info.v11.5.txt",
		        "node_list_path": "79884.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumPavilionensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium pavilionensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumPavilionensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1345023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1345023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1345023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1345023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1345023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1345023.protein.info.v11.5.txt",
		        "node_list_path": "1345023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1345023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrovirgulaAerodenitrificansDsm15089(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microvirgula aerodenitrificans DSM 15089 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgulaAerodenitrificansDsm15089", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122240.protein.info.v11.5.txt",
		        "node_list_path": "1122240.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCf335(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CF335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCf335", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500279.protein.info.v11.5.txt",
		        "node_list_path": "1500279.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraMultiparaLb2003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospira multipara LB2003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraMultiparaLb2003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410661.protein.info.v11.5.txt",
		        "node_list_path": "1410661.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedSup05ClusterBacteriumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured SUP05 cluster bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedSup05ClusterBacteriumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655186.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655186.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655186.clusters.proteins.v11.5.txt",
		        "sequence_path": "655186.protein.sequences.v11.5.fa",
		        "enrichment_path": "655186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655186.protein.info.v11.5.txt",
		        "node_list_path": "655186.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655186.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusCarbonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus carbonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusCarbonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "105422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "105422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "105422.clusters.proteins.v11.5.txt",
		        "sequence_path": "105422.protein.sequences.v11.5.fa",
		        "enrichment_path": "105422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105422.protein.info.v11.5.txt",
		        "node_list_path": "105422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "105422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermocrispumMunicipaleDsm44069Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermocrispum municipale DSM 44069 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocrispumMunicipaleDsm44069Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111737.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111737.protein.info.v11.5.txt",
		        "node_list_path": "1111737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophomonasZehnderiOl4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas zehnderi OL-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophomonasZehnderiOl4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "690567.protein.sequences.v11.5.fa",
		        "enrichment_path": "690567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690567.protein.info.v11.5.txt",
		        "node_list_path": "690567.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarivirgaTractuosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marivirga tractuosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivirgaTractuosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "643867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "643867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "643867.clusters.proteins.v11.5.txt",
		        "sequence_path": "643867.protein.sequences.v11.5.fa",
		        "enrichment_path": "643867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "643867.protein.info.v11.5.txt",
		        "node_list_path": "643867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "643867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumIndolisDsm755Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] indolis DSM 755 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumIndolisDsm755Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304881.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304881.protein.info.v11.5.txt",
		        "node_list_path": "1304881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumExtorquensAm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium extorquens AM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumExtorquensAm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272630.protein.sequences.v11.5.fa",
		        "enrichment_path": "272630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272630.protein.info.v11.5.txt",
		        "node_list_path": "272630.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf525Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF525 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf525Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463861.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463861.protein.info.v11.5.txt",
		        "node_list_path": "1463861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiothrixEikelboomiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix eikelboomii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiothrixEikelboomiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "92487.clusters.info.v11.5.txt",
		        "cluster_tree_path": "92487.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "92487.clusters.proteins.v11.5.txt",
		        "sequence_path": "92487.protein.sequences.v11.5.fa",
		        "enrichment_path": "92487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92487.protein.info.v11.5.txt",
		        "node_list_path": "92487.cluster.nodes.v11.5.txt",
		        "edge_list_path": "92487.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusHareiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus harei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusHareiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "908338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "908338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "908338.clusters.proteins.v11.5.txt",
		        "sequence_path": "908338.protein.sequences.v11.5.fa",
		        "enrichment_path": "908338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908338.protein.info.v11.5.txt",
		        "node_list_path": "908338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "908338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpP6b1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. P6B1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpP6b1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410613.protein.info.v11.5.txt",
		        "node_list_path": "1410613.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumSpHmsc063g07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium sp. HMSC063G07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumSpHmsc063g07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739261.protein.info.v11.5.txt",
		        "node_list_path": "1739261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBolteaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium bolteae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBolteaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411902.clusters.proteins.v11.5.txt",
		        "sequence_path": "411902.protein.sequences.v11.5.fa",
		        "enrichment_path": "411902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411902.protein.info.v11.5.txt",
		        "node_list_path": "411902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalmoTruttaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmo trutta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmoTruttaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8032.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8032.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8032.clusters.proteins.v11.5.txt",
		        "sequence_path": "8032.protein.sequences.v11.5.fa",
		        "enrichment_path": "8032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8032.protein.info.v11.5.txt",
		        "node_list_path": "8032.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8032.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrusClementinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrus clementina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrusClementinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "85681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "85681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "85681.clusters.proteins.v11.5.txt",
		        "sequence_path": "85681.protein.sequences.v11.5.fa",
		        "enrichment_path": "85681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85681.protein.info.v11.5.txt",
		        "node_list_path": "85681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "85681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PriciaAntarctica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pricia antarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PriciaAntarctica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641691.protein.sequences.v11.5.fa",
		        "enrichment_path": "641691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641691.protein.info.v11.5.txt",
		        "node_list_path": "641691.protein.complete.v11.5.txt"
		    }
		]
    )()

def MitsuokellaSpW9106Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mitsuokella sp. W9106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MitsuokellaSpW9106Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321781.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321781.protein.info.v11.5.txt",
		        "node_list_path": "1321781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpHmica12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. HmicA12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpHmica12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1156844.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156844.protein.info.v11.5.txt",
		        "node_list_path": "1156844.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusPsychrosaccharolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus psychrosaccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPsychrosaccharolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1174504.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1174504.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1174504.clusters.proteins.v11.5.txt",
		        "sequence_path": "1174504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1174504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1174504.protein.info.v11.5.txt",
		        "node_list_path": "1174504.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1174504.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpHel13349Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel13349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpHel13349Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336803.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336803.protein.info.v11.5.txt",
		        "node_list_path": "1336803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemetriaTerragena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demetria terragena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemetriaTerragena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121385.protein.info.v11.5.txt",
		        "node_list_path": "1121385.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterSpT28Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter sp. T28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterSpT28Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1836467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1836467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1836467.clusters.proteins.v11.5.txt",
		        "sequence_path": "1836467.protein.sequences.v11.5.fa",
		        "enrichment_path": "1836467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1836467.protein.info.v11.5.txt",
		        "node_list_path": "1836467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1836467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaMaculosaOt289Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella maculosa OT 289 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMaculosaOt289Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999422.clusters.proteins.v11.5.txt",
		        "sequence_path": "999422.protein.sequences.v11.5.fa",
		        "enrichment_path": "999422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999422.protein.info.v11.5.txt",
		        "node_list_path": "999422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaceaeBacteriumHun156Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotellaceae bacterium HUN156 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaceaeBacteriumHun156Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520830.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520830.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520830.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520830.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520830.protein.info.v11.5.txt",
		        "node_list_path": "1520830.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520830.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrnithinimicrobiumSpCnj824(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ornithinimicrobium sp. CNJ-824 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithinimicrobiumSpCnj824", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1904966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904966.protein.info.v11.5.txt",
		        "node_list_path": "1904966.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho212Full4422b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_12_FULL_44_22b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho212Full4422b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801763.protein.info.v11.5.txt",
		        "node_list_path": "1801763.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusObesiensisPh10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus obesiensis ph10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusObesiensisPh10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118056.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118056.protein.info.v11.5.txt",
		        "node_list_path": "1118056.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumVulpinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium vulpinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumVulpinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29845.protein.sequences.v11.5.fa",
		        "enrichment_path": "29845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29845.protein.info.v11.5.txt",
		        "node_list_path": "29845.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporolactobacillusLaevolacticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus laevolacticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolactobacillusLaevolacticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1395513.protein.sequences.v11.5.fa",
		        "enrichment_path": "1395513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1395513.protein.info.v11.5.txt",
		        "node_list_path": "1395513.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrialbaSpSsl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrialba sp. SSL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaSpSsl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1869245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1869245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1869245.protein.info.v11.5.txt",
		        "node_list_path": "1869245.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumHaemolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium haemolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumHaemolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "394935.protein.sequences.v11.5.fa",
		        "enrichment_path": "394935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394935.protein.info.v11.5.txt",
		        "node_list_path": "394935.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumA2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium A2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumA2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "397290.protein.sequences.v11.5.fa",
		        "enrichment_path": "397290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397290.protein.info.v11.5.txt",
		        "node_list_path": "397290.protein.complete.v11.5.txt"
		    }
		]
    )()

def BerkelbacteriaBacteriumGw2011Gwa2359Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011_GWA2_35_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BerkelbacteriaBacteriumGw2011Gwa2359Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618333.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618333.protein.info.v11.5.txt",
		        "node_list_path": "1618333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAsiaticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium asiaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAsiaticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265310.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265310.protein.info.v11.5.txt",
		        "node_list_path": "1265310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaCrassostreae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga crassostreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaCrassostreae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1763535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1763535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1763535.protein.info.v11.5.txt",
		        "node_list_path": "1763535.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinisporaPacificaDsm45544Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45544 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisporaPacificaDsm45544Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999543.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999543.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999543.clusters.proteins.v11.5.txt",
		        "sequence_path": "999543.protein.sequences.v11.5.fa",
		        "enrichment_path": "999543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999543.protein.info.v11.5.txt",
		        "node_list_path": "999543.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999543.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaVagans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea vagans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaVagans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "712898.protein.sequences.v11.5.fa",
		        "enrichment_path": "712898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712898.protein.info.v11.5.txt",
		        "node_list_path": "712898.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloceanibacterSuperfactus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloceanibacter superfactus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloceanibacterSuperfactus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1774969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1774969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1774969.protein.info.v11.5.txt",
		        "node_list_path": "1774969.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusSpOlCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. OL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusSpOlCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1888891.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1888891.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1888891.clusters.proteins.v11.5.txt",
		        "sequence_path": "1888891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1888891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1888891.protein.info.v11.5.txt",
		        "node_list_path": "1888891.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1888891.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumObuense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium obuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumObuense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807.protein.info.v11.5.txt",
		        "node_list_path": "1807.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitreimonasSalinaria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citreimonas salinaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitreimonasSalinaria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321339.protein.sequences.v11.5.fa",
		        "enrichment_path": "321339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321339.protein.info.v11.5.txt",
		        "node_list_path": "321339.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRifoxyc1Full3779Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYC1_FULL_37_79 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyc1Full3779Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797395.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797395.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797395.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797395.protein.info.v11.5.txt",
		        "node_list_path": "1797395.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797395.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermotogaCaldifontisAzm44c09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga caldifontis AZM44c09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaCaldifontisAzm44c09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408159.protein.info.v11.5.txt",
		        "node_list_path": "1408159.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThamnocephalisSphaerosporaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thamnocephalis sphaerospora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThamnocephalisSphaerosporaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "78915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "78915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "78915.clusters.proteins.v11.5.txt",
		        "sequence_path": "78915.protein.sequences.v11.5.fa",
		        "enrichment_path": "78915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78915.protein.info.v11.5.txt",
		        "node_list_path": "78915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "78915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumBica17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BICA1-7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumBica17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1531961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1531961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1531961.clusters.proteins.v11.5.txt",
		        "sequence_path": "1531961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1531961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1531961.protein.info.v11.5.txt",
		        "node_list_path": "1531961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1531961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobulbaceaeBacteriumDb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbaceae bacterium DB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbaceaeBacteriumDb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1920419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920419.protein.info.v11.5.txt",
		        "node_list_path": "1920419.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifcsplowo212Full599(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO2_12_FULL_59_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo212Full599", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797952.protein.info.v11.5.txt",
		        "node_list_path": "1797952.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpUrha0020Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. URHA0020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpUrha0020Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380392.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380392.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380392.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380392.protein.info.v11.5.txt",
		        "node_list_path": "1380392.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380392.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumGwa25525(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_55_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumGwa25525", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798422.protein.info.v11.5.txt",
		        "node_list_path": "1798422.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1025068Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_50_68 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1025068Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805312.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805312.protein.info.v11.5.txt",
		        "node_list_path": "1805312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NanohaloarchaeaArchaeonB1Br10U2g1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon B1-Br10_U2g1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NanohaloarchaeaArchaeonB1Br10U2g1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729453.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729453.protein.info.v11.5.txt",
		        "node_list_path": "1729453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterSyzygii9h2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter syzygii 9H-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterSyzygii9h2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231343.protein.info.v11.5.txt",
		        "node_list_path": "1231343.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeptunicoccusSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neptunicoccus sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptunicoccusSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1892596.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892596.protein.info.v11.5.txt",
		        "node_list_path": "1892596.protein.complete.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpScgC07wgaEpuloa2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. SCG-C07WGA-EpuloA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpScgC07wgaEpuloa2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1712378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1712378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1712378.protein.info.v11.5.txt",
		        "node_list_path": "1712378.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc055a01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC055A01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc055a01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1715083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1715083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1715083.clusters.proteins.v11.5.txt",
		        "sequence_path": "1715083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715083.protein.info.v11.5.txt",
		        "node_list_path": "1715083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1715083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterPylori26695Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori 26695 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterPylori26695Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "85962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "85962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "85962.clusters.proteins.v11.5.txt",
		        "sequence_path": "85962.protein.sequences.v11.5.fa",
		        "enrichment_path": "85962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85962.protein.info.v11.5.txt",
		        "node_list_path": "85962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "85962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobacillusCyri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacillus cyri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobacillusCyri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "571932.protein.sequences.v11.5.fa",
		        "enrichment_path": "571932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571932.protein.info.v11.5.txt",
		        "node_list_path": "571932.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf104Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf104 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf104Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736254.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736254.protein.info.v11.5.txt",
		        "node_list_path": "1736254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwb25519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWB2_55_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwb25519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797814.protein.info.v11.5.txt",
		        "node_list_path": "1797814.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpMrmr6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MRMR6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpMrmr6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1928617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1928617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1928617.protein.info.v11.5.txt",
		        "node_list_path": "1928617.protein.complete.v11.5.txt"
		    }
		]
    )()

def DictyosteliumPurpureumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dictyostelium purpureum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DictyosteliumPurpureumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5786.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5786.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5786.clusters.proteins.v11.5.txt",
		        "sequence_path": "5786.protein.sequences.v11.5.fa",
		        "enrichment_path": "5786.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5786.protein.info.v11.5.txt",
		        "node_list_path": "5786.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5786.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DialisterMicroaerophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dialister microaerophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterMicroaerophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "910314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "910314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "910314.clusters.proteins.v11.5.txt",
		        "sequence_path": "910314.protein.sequences.v11.5.fa",
		        "enrichment_path": "910314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "910314.protein.info.v11.5.txt",
		        "node_list_path": "910314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "910314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpKh2c16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. KH2C16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpKh2c16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855325.protein.info.v11.5.txt",
		        "node_list_path": "1855325.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhormidesmisPriestleyiBc1401(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi BC1401 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhormidesmisPriestleyiBc1401", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1850361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850361.protein.info.v11.5.txt",
		        "node_list_path": "1850361.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaCaballeronisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia caballeronis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaCaballeronisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "416943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "416943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "416943.clusters.proteins.v11.5.txt",
		        "sequence_path": "416943.protein.sequences.v11.5.fa",
		        "enrichment_path": "416943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416943.protein.info.v11.5.txt",
		        "node_list_path": "416943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "416943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloceanibacterMethanicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloceanibacter methanicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloceanibacterMethanicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1774968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1774968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1774968.clusters.proteins.v11.5.txt",
		        "sequence_path": "1774968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1774968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1774968.protein.info.v11.5.txt",
		        "node_list_path": "1774968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1774968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HandroanthusImpetiginosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Handroanthus impetiginosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HandroanthusImpetiginosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "429701.protein.sequences.v11.5.fa",
		        "enrichment_path": "429701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "429701.protein.info.v11.5.txt",
		        "node_list_path": "429701.protein.complete.v11.5.txt"
		    }
		]
    )()

def KlebsiellaPneumoniaeSubspOzaenaeNbrc105683Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. ozaenae NBRC 105683 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaPneumoniaeSubspOzaenaeNbrc105683Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218098.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218098.protein.info.v11.5.txt",
		        "node_list_path": "1218098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KribbellaCatacumbaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kribbella catacumbae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KribbellaCatacumbaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122138.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122138.protein.info.v11.5.txt",
		        "node_list_path": "1122138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumRhizosphaeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumRhizosphaeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "346179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "346179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "346179.clusters.proteins.v11.5.txt",
		        "sequence_path": "346179.protein.sequences.v11.5.fa",
		        "enrichment_path": "346179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "346179.protein.info.v11.5.txt",
		        "node_list_path": "346179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "346179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpF0091(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0091 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpF0091", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227276.protein.info.v11.5.txt",
		        "node_list_path": "1227276.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickenellaMellea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickenella mellea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickenellaMellea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "50990.protein.sequences.v11.5.fa",
		        "enrichment_path": "50990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50990.protein.info.v11.5.txt",
		        "node_list_path": "50990.protein.complete.v11.5.txt"
		    }
		]
    )()

def HippeaJasoniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hippea jasoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HippeaJasoniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "944479.protein.sequences.v11.5.fa",
		        "enrichment_path": "944479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944479.protein.info.v11.5.txt",
		        "node_list_path": "944479.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4126(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4126", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802661.protein.info.v11.5.txt",
		        "node_list_path": "1802661.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAnimalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium animalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAnimalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "552531.clusters.info.v11.5.txt",
		        "cluster_tree_path": "552531.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "552531.clusters.proteins.v11.5.txt",
		        "sequence_path": "552531.protein.sequences.v11.5.fa",
		        "enrichment_path": "552531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "552531.protein.info.v11.5.txt",
		        "node_list_path": "552531.cluster.nodes.v11.5.txt",
		        "edge_list_path": "552531.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag227(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:227 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag227", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263010.protein.info.v11.5.txt",
		        "node_list_path": "1263010.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaMycoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma mycoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaMycoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272632.protein.sequences.v11.5.fa",
		        "enrichment_path": "272632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272632.protein.info.v11.5.txt",
		        "node_list_path": "272632.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastococcusSpDsm46838Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 46838 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusSpDsm46838Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798228.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798228.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798228.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798228.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798228.protein.info.v11.5.txt",
		        "node_list_path": "1798228.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798228.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZetaproteobacteriaBacteriumCg1024923Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_49_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaproteobacteriaBacteriumCg1024923Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805426.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805426.protein.info.v11.5.txt",
		        "node_list_path": "1805426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhyllobacteriumSpYr620Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. YR620 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhyllobacteriumSpYr620Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881066.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881066.protein.info.v11.5.txt",
		        "node_list_path": "1881066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumSetenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium setense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumSetenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "431269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "431269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "431269.clusters.proteins.v11.5.txt",
		        "sequence_path": "431269.protein.sequences.v11.5.fa",
		        "enrichment_path": "431269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431269.protein.info.v11.5.txt",
		        "node_list_path": "431269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "431269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiaBacteriumTcs56(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiaBacteriumTcs56", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1781247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1781247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1781247.protein.info.v11.5.txt",
		        "node_list_path": "1781247.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpFcs006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FCS006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpFcs006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280684.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280684.protein.info.v11.5.txt",
		        "node_list_path": "1280684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumBaderiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium baderi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumBaderiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1332080.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1332080.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1332080.clusters.proteins.v11.5.txt",
		        "sequence_path": "1332080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1332080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1332080.protein.info.v11.5.txt",
		        "node_list_path": "1332080.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1332080.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErinaceusEuropaeus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erinaceus europaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErinaceusEuropaeus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9365.protein.sequences.v11.5.fa",
		        "enrichment_path": "9365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9365.protein.info.v11.5.txt",
		        "node_list_path": "9365.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnoanaerobaculumSpMsx33Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum sp. MSX33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoanaerobaculumSpMsx33Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936596.clusters.proteins.v11.5.txt",
		        "sequence_path": "936596.protein.sequences.v11.5.fa",
		        "enrichment_path": "936596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936596.protein.info.v11.5.txt",
		        "node_list_path": "936596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesPombe972hCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces pombe 972h- Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesPombe972hCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "284812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "284812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "284812.clusters.proteins.v11.5.txt",
		        "sequence_path": "284812.protein.sequences.v11.5.fa",
		        "enrichment_path": "284812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284812.protein.info.v11.5.txt",
		        "node_list_path": "284812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "284812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeuconostocaceaeBacteriumR53105(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostocaceae bacterium R-53105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocaceaeBacteriumR53105", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855370.protein.info.v11.5.txt",
		        "node_list_path": "1855370.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpB7740(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. B7740 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpB7740", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1564114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1564114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1564114.protein.info.v11.5.txt",
		        "node_list_path": "1564114.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorothrixHollandicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorothrix hollandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorothrixHollandicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "317619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "317619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "317619.clusters.proteins.v11.5.txt",
		        "sequence_path": "317619.protein.sequences.v11.5.fa",
		        "enrichment_path": "317619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317619.protein.info.v11.5.txt",
		        "node_list_path": "317619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "317619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulosimicrobiumCellulans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulosimicrobium cellulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulosimicrobiumCellulans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935839.protein.sequences.v11.5.fa",
		        "enrichment_path": "935839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935839.protein.info.v11.5.txt",
		        "node_list_path": "935839.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChaetomiumGlobosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium globosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChaetomiumGlobosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "38033.protein.sequences.v11.5.fa",
		        "enrichment_path": "38033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38033.protein.info.v11.5.txt",
		        "node_list_path": "38033.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHtcc5015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC5015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc5015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391615.protein.sequences.v11.0.fa",
		        "enrichment_path": "391615.protein.enrichment.terms.v11.0.txt",
		        "info_path": "391615.protein.info.v11.0.txt",
		        "node_list_path": "391615.protein.complete.v11.0.txt"
		    }
		]
    )()

def StreptomycesSpNrrlS1022Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL S-1022 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlS1022Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463880.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463880.protein.info.v11.5.txt",
		        "node_list_path": "1463880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SistotremastrumNiveocremeumHhb9708Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sistotremastrum niveocremeum HHB9708 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SistotremastrumNiveocremeumHhb9708Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314777.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314777.protein.info.v11.5.txt",
		        "node_list_path": "1314777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRu3701Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. ru370.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRu3701Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761809.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761809.protein.info.v11.5.txt",
		        "node_list_path": "1761809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OryzaRufipogon(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryza rufipogon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaRufipogon", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4529.protein.sequences.v11.5.fa",
		        "enrichment_path": "4529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4529.protein.info.v11.5.txt",
		        "node_list_path": "4529.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumCelatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium celatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumCelatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28045.protein.sequences.v11.5.fa",
		        "enrichment_path": "28045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28045.protein.info.v11.5.txt",
		        "node_list_path": "28045.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaWaksmanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella waksmanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaWaksmanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336233.protein.info.v11.5.txt",
		        "node_list_path": "1336233.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSp3910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 39-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSp3910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895745.protein.info.v11.5.txt",
		        "node_list_path": "1895745.protein.complete.v11.5.txt"
		    }
		]
    )()

def CottopercaGobioCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cottoperca gobio Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CottopercaGobioCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56716.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56716.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56716.clusters.proteins.v11.5.txt",
		        "sequence_path": "56716.protein.sequences.v11.5.fa",
		        "enrichment_path": "56716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56716.protein.info.v11.5.txt",
		        "node_list_path": "56716.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56716.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasCatoniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas catoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasCatoniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1127696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127696.protein.info.v11.5.txt",
		        "node_list_path": "1127696.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsplowo212Full3610Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO2_12_FULL_36_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo212Full3610Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802630.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802630.protein.info.v11.5.txt",
		        "node_list_path": "1802630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DickeyaDadantiiEch586Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii Ech586 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaDadantiiEch586Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "590409.clusters.info.v11.5.txt",
		        "cluster_tree_path": "590409.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "590409.clusters.proteins.v11.5.txt",
		        "sequence_path": "590409.protein.sequences.v11.5.fa",
		        "enrichment_path": "590409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "590409.protein.info.v11.5.txt",
		        "node_list_path": "590409.cluster.nodes.v11.5.txt",
		        "edge_list_path": "590409.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumFreii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium freii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumFreii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "48697.protein.sequences.v11.5.fa",
		        "enrichment_path": "48697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48697.protein.info.v11.5.txt",
		        "node_list_path": "48697.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAidingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus aidingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAidingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121085.protein.info.v11.5.txt",
		        "node_list_path": "1121085.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumGasigenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium gasigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumGasigenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "94869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "94869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "94869.clusters.proteins.v11.5.txt",
		        "sequence_path": "94869.protein.sequences.v11.5.fa",
		        "enrichment_path": "94869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94869.protein.info.v11.5.txt",
		        "node_list_path": "94869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "94869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PestalotiopsisFici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pestalotiopsis fici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PestalotiopsisFici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "393283.protein.sequences.v11.5.fa",
		        "enrichment_path": "393283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393283.protein.info.v11.5.txt",
		        "node_list_path": "393283.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumKa00344(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KA00344 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumKa00344", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1497954.protein.sequences.v11.5.fa",
		        "enrichment_path": "1497954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1497954.protein.info.v11.5.txt",
		        "node_list_path": "1497954.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPseudogenitaliumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pseudogenitalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPseudogenitaliumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525264.clusters.proteins.v11.5.txt",
		        "sequence_path": "525264.protein.sequences.v11.5.fa",
		        "enrichment_path": "525264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525264.protein.info.v11.5.txt",
		        "node_list_path": "525264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobulbaceaeBacteriumBrhC16aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbaceae bacterium BRH_c16a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbaceaeBacteriumBrhC16aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629713.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629713.protein.info.v11.5.txt",
		        "node_list_path": "1629713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NevskiaSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nevskia soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NevskiaSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122604.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122604.protein.info.v11.5.txt",
		        "node_list_path": "1122604.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusJorgensenbacteriaBacteriumGwa15412(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GWA1_54_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGwa15412", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798468.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798468.protein.info.v11.5.txt",
		        "node_list_path": "1798468.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSp20bn(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. 20BN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSp20bn", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499686.protein.info.v11.5.txt",
		        "node_list_path": "1499686.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpT32(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. T32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpT32", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776083.protein.info.v11.5.txt",
		        "node_list_path": "1776083.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPolymyxaE681Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa E681 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPolymyxaE681Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349520.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349520.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349520.clusters.proteins.v11.5.txt",
		        "sequence_path": "349520.protein.sequences.v11.5.fa",
		        "enrichment_path": "349520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349520.protein.info.v11.5.txt",
		        "node_list_path": "349520.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349520.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusPentosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pentosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPentosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1136177.protein.sequences.v11.5.fa",
		        "enrichment_path": "1136177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1136177.protein.info.v11.5.txt",
		        "node_list_path": "1136177.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag485Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:485 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag485Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262927.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262927.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262927.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262927.protein.info.v11.5.txt",
		        "node_list_path": "1262927.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262927.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiohalorhabdusDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiohalorhabdus denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiohalorhabdusDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "381306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "381306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "381306.clusters.proteins.v11.5.txt",
		        "sequence_path": "381306.protein.sequences.v11.5.fa",
		        "enrichment_path": "381306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381306.protein.info.v11.5.txt",
		        "node_list_path": "381306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "381306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumAquaticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium aquaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumAquaticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "270351.protein.sequences.v11.5.fa",
		        "enrichment_path": "270351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "270351.protein.info.v11.5.txt",
		        "node_list_path": "270351.protein.complete.v11.5.txt"
		    }
		]
    )()

def BipolarisMaydisC5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris maydis C5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisMaydisC5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "701091.clusters.info.v11.5.txt",
		        "cluster_tree_path": "701091.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "701091.clusters.proteins.v11.5.txt",
		        "sequence_path": "701091.protein.sequences.v11.5.fa",
		        "enrichment_path": "701091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "701091.protein.info.v11.5.txt",
		        "node_list_path": "701091.cluster.nodes.v11.5.txt",
		        "edge_list_path": "701091.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BosIndicusXBosTaurus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bos indicus x Bos taurus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BosIndicusXBosTaurus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "30522.protein.sequences.v11.5.fa",
		        "enrichment_path": "30522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30522.protein.info.v11.5.txt",
		        "node_list_path": "30522.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerrimonasKyonanensisDsm18153(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas kyonanensis DSM 18153 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrimonasKyonanensisDsm18153", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121879.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121879.protein.info.v11.5.txt",
		        "node_list_path": "1121879.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastomycesSilverae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces silverae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomycesSilverae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2060906.protein.sequences.v11.5.fa",
		        "enrichment_path": "2060906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2060906.protein.info.v11.5.txt",
		        "node_list_path": "2060906.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTsri0107(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TSRI0107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTsri0107", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703942.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703942.protein.info.v11.5.txt",
		        "node_list_path": "1703942.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusJostii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus jostii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusJostii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "101510.protein.sequences.v11.5.fa",
		        "enrichment_path": "101510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101510.protein.info.v11.5.txt",
		        "node_list_path": "101510.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraMadurae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura madurae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraMadurae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1394178.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394178.protein.info.v11.5.txt",
		        "node_list_path": "1394178.protein.complete.v11.5.txt"
		    }
		]
    )()

def HanseniasporaUvarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hanseniaspora uvarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HanseniasporaUvarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29833.protein.sequences.v11.5.fa",
		        "enrichment_path": "29833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29833.protein.info.v11.5.txt",
		        "node_list_path": "29833.protein.complete.v11.5.txt"
		    }
		]
    )()

def BerkelbacteriaBacteriumGw2011Gwa13910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011_GWA1_39_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BerkelbacteriaBacteriumGw2011Gwa13910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618332.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618332.protein.info.v11.5.txt",
		        "node_list_path": "1618332.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpRuh2624Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. RUH2624 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpRuh2624Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575564.clusters.proteins.v11.5.txt",
		        "sequence_path": "575564.protein.sequences.v11.5.fa",
		        "enrichment_path": "575564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575564.protein.info.v11.5.txt",
		        "node_list_path": "575564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VulcanisaetaThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vulcanisaeta thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulcanisaetaThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "867917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "867917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "867917.clusters.proteins.v11.5.txt",
		        "sequence_path": "867917.protein.sequences.v11.5.fa",
		        "enrichment_path": "867917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867917.protein.info.v11.5.txt",
		        "node_list_path": "867917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "867917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HistoplasmaCapsulatumH88Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum H88 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HistoplasmaCapsulatumH88Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "544711.clusters.info.v11.5.txt",
		        "cluster_tree_path": "544711.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "544711.clusters.proteins.v11.5.txt",
		        "sequence_path": "544711.protein.sequences.v11.5.fa",
		        "enrichment_path": "544711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "544711.protein.info.v11.5.txt",
		        "node_list_path": "544711.cluster.nodes.v11.5.txt",
		        "edge_list_path": "544711.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PersephonellaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Persephonella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PersephonellaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "123214.protein.sequences.v11.5.fa",
		        "enrichment_path": "123214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "123214.protein.info.v11.5.txt",
		        "node_list_path": "123214.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusReticulitermitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus reticulitermitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusReticulitermitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "856736.clusters.info.v11.5.txt",
		        "cluster_tree_path": "856736.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "856736.clusters.proteins.v11.5.txt",
		        "sequence_path": "856736.protein.sequences.v11.5.fa",
		        "enrichment_path": "856736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "856736.protein.info.v11.5.txt",
		        "node_list_path": "856736.cluster.nodes.v11.5.txt",
		        "edge_list_path": "856736.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerotignumNeopropionicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerotignum neopropionicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotignumNeopropionicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36847.clusters.proteins.v11.5.txt",
		        "sequence_path": "36847.protein.sequences.v11.5.fa",
		        "enrichment_path": "36847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36847.protein.info.v11.5.txt",
		        "node_list_path": "36847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerribacillusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terribacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerribacillusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "361279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "361279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "361279.clusters.proteins.v11.5.txt",
		        "sequence_path": "361279.protein.sequences.v11.5.fa",
		        "enrichment_path": "361279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "361279.protein.info.v11.5.txt",
		        "node_list_path": "361279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "361279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaNamucuonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia namucuonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaNamucuonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035707.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035707.protein.info.v11.5.txt",
		        "node_list_path": "1035707.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMarinisedimentorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus marinisedimentorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMarinisedimentorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1821260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1821260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1821260.clusters.proteins.v11.5.txt",
		        "sequence_path": "1821260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1821260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1821260.protein.info.v11.5.txt",
		        "node_list_path": "1821260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1821260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HeterosteliumAlbumPn500(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Heterostelium album PN500 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeterosteliumAlbumPn500", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "670386.protein.sequences.v11.5.fa",
		        "enrichment_path": "670386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670386.protein.info.v11.5.txt",
		        "node_list_path": "670386.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumFlavescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumFlavescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776.protein.info.v11.5.txt",
		        "node_list_path": "1776.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusPauculusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus pauculus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusPauculusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "82633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "82633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "82633.clusters.proteins.v11.5.txt",
		        "sequence_path": "82633.protein.sequences.v11.5.fa",
		        "enrichment_path": "82633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82633.protein.info.v11.5.txt",
		        "node_list_path": "82633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "82633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylocystisParvusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylocystis parvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocystisParvusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1134912.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1134912.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1134912.clusters.proteins.v11.5.txt",
		        "sequence_path": "1134912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134912.protein.info.v11.5.txt",
		        "node_list_path": "1134912.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1134912.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumFerrireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumFerrireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1833852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1833852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1833852.clusters.proteins.v11.5.txt",
		        "sequence_path": "1833852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1833852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1833852.protein.info.v11.5.txt",
		        "node_list_path": "1833852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1833852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OleiagrimonasSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oleiagrimonas soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OleiagrimonasSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1543381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1543381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1543381.protein.info.v11.5.txt",
		        "node_list_path": "1543381.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerticilliumDahliaeVdls17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verticillium dahliae VdLs.17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerticilliumDahliaeVdls17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "498257.protein.sequences.v11.5.fa",
		        "enrichment_path": "498257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498257.protein.info.v11.5.txt",
		        "node_list_path": "498257.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpCag318(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. CAG:318 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpCag318", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262761.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262761.protein.info.v11.5.txt",
		        "node_list_path": "1262761.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaitoellaComplicataNrrlY17804Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saitoella complicata NRRL Y-17804 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaitoellaComplicataNrrlY17804Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "698492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "698492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "698492.clusters.proteins.v11.5.txt",
		        "sequence_path": "698492.protein.sequences.v11.5.fa",
		        "enrichment_path": "698492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698492.protein.info.v11.5.txt",
		        "node_list_path": "698492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "698492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaFlavescensSk114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria flavescens SK114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaFlavescensSk114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596320.clusters.proteins.v11.5.txt",
		        "sequence_path": "596320.protein.sequences.v11.5.fa",
		        "enrichment_path": "596320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596320.protein.info.v11.5.txt",
		        "node_list_path": "596320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsCamponotiRufipedisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps camponoti-rufipedis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsCamponotiRufipedisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2004952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2004952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2004952.clusters.proteins.v11.5.txt",
		        "sequence_path": "2004952.protein.sequences.v11.5.fa",
		        "enrichment_path": "2004952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2004952.protein.info.v11.5.txt",
		        "node_list_path": "2004952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2004952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSpBf4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. BF4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSpBf4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1473546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1473546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1473546.clusters.proteins.v11.5.txt",
		        "sequence_path": "1473546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1473546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1473546.protein.info.v11.5.txt",
		        "node_list_path": "1473546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1473546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesGordoniiMs1Dsm23371Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides gordonii MS-1 DSM 23371 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesGordoniiMs1Dsm23371Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203610.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203610.protein.info.v11.5.txt",
		        "node_list_path": "1203610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu053(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU053 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu053", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671652.protein.info.v11.5.txt",
		        "node_list_path": "1671652.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasJandaeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas jandaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasJandaeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "650.clusters.info.v11.5.txt",
		        "cluster_tree_path": "650.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "650.clusters.proteins.v11.5.txt",
		        "sequence_path": "650.protein.sequences.v11.5.fa",
		        "enrichment_path": "650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "650.protein.info.v11.5.txt",
		        "node_list_path": "650.cluster.nodes.v11.5.txt",
		        "edge_list_path": "650.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumExtorquensAm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium extorquens AM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumExtorquensAm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272630.clusters.proteins.v11.5.txt",
		        "sequence_path": "272630.protein.sequences.v11.5.fa",
		        "enrichment_path": "272630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272630.protein.info.v11.5.txt",
		        "node_list_path": "272630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DactylosporangiumAurantiacum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dactylosporangium aurantiacum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DactylosporangiumAurantiacum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35754.protein.sequences.v11.5.fa",
		        "enrichment_path": "35754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35754.protein.info.v11.5.txt",
		        "node_list_path": "35754.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasAntarctica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas antarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAntarctica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "219572.protein.sequences.v11.5.fa",
		        "enrichment_path": "219572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "219572.protein.info.v11.5.txt",
		        "node_list_path": "219572.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusLugdunensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusLugdunensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28035.clusters.proteins.v11.5.txt",
		        "sequence_path": "28035.protein.sequences.v11.5.fa",
		        "enrichment_path": "28035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28035.protein.info.v11.5.txt",
		        "node_list_path": "28035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseospirillumParvumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseospirillum parvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseospirillumParvumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83401.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83401.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83401.clusters.proteins.v11.5.txt",
		        "sequence_path": "83401.protein.sequences.v11.5.fa",
		        "enrichment_path": "83401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83401.protein.info.v11.5.txt",
		        "node_list_path": "83401.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83401.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKefiranofaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kefiranofaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKefiranofaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033837.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033837.protein.info.v11.5.txt",
		        "node_list_path": "1033837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SediminibacillusAlbus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacillus albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacillusAlbus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "407036.protein.sequences.v11.5.fa",
		        "enrichment_path": "407036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "407036.protein.info.v11.5.txt",
		        "node_list_path": "407036.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag508(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:508 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag508", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262815.protein.info.v11.5.txt",
		        "node_list_path": "1262815.protein.complete.v11.5.txt"
		    }
		]
    )()

def LaetiporusSulphureus9353Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Laetiporus sulphureus 93-53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LaetiporusSulphureus9353Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314785.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314785.protein.info.v11.5.txt",
		        "node_list_path": "1314785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaAurantiacaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaAurantiacaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "676200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "676200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "676200.clusters.proteins.v11.5.txt",
		        "sequence_path": "676200.protein.sequences.v11.5.fa",
		        "enrichment_path": "676200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "676200.protein.info.v11.5.txt",
		        "node_list_path": "676200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "676200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzotobacterVinelandii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azotobacter vinelandii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzotobacterVinelandii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "322710.protein.sequences.v11.5.fa",
		        "enrichment_path": "322710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "322710.protein.info.v11.5.txt",
		        "node_list_path": "322710.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinispirillumAlkaliphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinispirillum alkaliphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinispirillumAlkaliphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1008392.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1008392.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1008392.clusters.proteins.v11.5.txt",
		        "sequence_path": "1008392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1008392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1008392.protein.info.v11.5.txt",
		        "node_list_path": "1008392.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1008392.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3810(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_02_FULL_38_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3810", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802074.protein.info.v11.5.txt",
		        "node_list_path": "1802074.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisDassonvilleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis dassonvillei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisDassonvilleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "446468.clusters.info.v11.5.txt",
		        "cluster_tree_path": "446468.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "446468.clusters.proteins.v11.5.txt",
		        "sequence_path": "446468.protein.sequences.v11.5.fa",
		        "enrichment_path": "446468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446468.protein.info.v11.5.txt",
		        "node_list_path": "446468.cluster.nodes.v11.5.txt",
		        "edge_list_path": "446468.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudorhodobacterWandonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodobacter wandonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodobacterWandonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120568.protein.info.v11.5.txt",
		        "node_list_path": "1120568.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg19ftCombo5516(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_19FT_COMBO_55_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg19ftCombo5516", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797669.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797669.protein.info.v11.5.txt",
		        "node_list_path": "1797669.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusEisenbacteriaBacteriumRbg167146(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Eisenbacteria bacterium RBG_16_71_46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusEisenbacteriaBacteriumRbg167146", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817856.protein.info.v11.5.txt",
		        "node_list_path": "1817856.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaLoihica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella loihica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaLoihica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "323850.protein.sequences.v11.5.fa",
		        "enrichment_path": "323850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323850.protein.info.v11.5.txt",
		        "node_list_path": "323850.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusDevrieseiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus devriesei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusDevrieseiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "319970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "319970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "319970.clusters.proteins.v11.5.txt",
		        "sequence_path": "319970.protein.sequences.v11.5.fa",
		        "enrichment_path": "319970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319970.protein.info.v11.5.txt",
		        "node_list_path": "319970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "319970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollimonasArenae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collimonas arenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollimonasArenae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "279058.protein.sequences.v11.5.fa",
		        "enrichment_path": "279058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279058.protein.info.v11.5.txt",
		        "node_list_path": "279058.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc28b08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC28B08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc28b08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1581066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1581066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1581066.clusters.proteins.v11.5.txt",
		        "sequence_path": "1581066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581066.protein.info.v11.5.txt",
		        "node_list_path": "1581066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1581066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlsenellaProvencensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella provencensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaProvencensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852386.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852386.protein.info.v11.5.txt",
		        "node_list_path": "1852386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FranconibacterHelveticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Franconibacter helveticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FranconibacterHelveticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "357240.protein.sequences.v11.5.fa",
		        "enrichment_path": "357240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357240.protein.info.v11.5.txt",
		        "node_list_path": "357240.protein.complete.v11.5.txt"
		    }
		]
    )()

def NanoarchaeumEquitansKin4MCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nanoarchaeum equitans Kin4-M Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NanoarchaeumEquitansKin4MCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "228908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "228908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "228908.clusters.proteins.v11.5.txt",
		        "sequence_path": "228908.protein.sequences.v11.5.fa",
		        "enrichment_path": "228908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228908.protein.info.v11.5.txt",
		        "node_list_path": "228908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "228908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrialbaSpSsl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialba sp. SSL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaSpSsl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1869245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1869245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1869245.clusters.proteins.v11.5.txt",
		        "sequence_path": "1869245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1869245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1869245.protein.info.v11.5.txt",
		        "node_list_path": "1869245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1869245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermanaerothrixDaxensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermanaerothrix daxensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermanaerothrixDaxensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "869279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "869279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "869279.clusters.proteins.v11.5.txt",
		        "sequence_path": "869279.protein.sequences.v11.5.fa",
		        "enrichment_path": "869279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869279.protein.info.v11.5.txt",
		        "node_list_path": "869279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "869279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpWcd2001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. WCD2001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpWcd2001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280681.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280681.protein.info.v11.5.txt",
		        "node_list_path": "1280681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionSr1BacteriumRaac1Sr11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division SR1 bacterium RAAC1_SR1_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionSr1BacteriumRaac1Sr11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1394709.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394709.protein.info.v11.5.txt",
		        "node_list_path": "1394709.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinisphaeraHydrothermalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinisphaera hydrothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisphaeraHydrothermalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304275.protein.info.v11.5.txt",
		        "node_list_path": "1304275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaAmbifaria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia ambifaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaAmbifaria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "339670.protein.sequences.v11.5.fa",
		        "enrichment_path": "339670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "339670.protein.info.v11.5.txt",
		        "node_list_path": "339670.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteroidesImmunogenumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacteroides immunogenum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteroidesImmunogenumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83262.clusters.proteins.v11.5.txt",
		        "sequence_path": "83262.protein.sequences.v11.5.fa",
		        "enrichment_path": "83262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83262.protein.info.v11.5.txt",
		        "node_list_path": "83262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ManacusVitellinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Manacus vitellinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ManacusVitellinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "328815.protein.sequences.v11.5.fa",
		        "enrichment_path": "328815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "328815.protein.info.v11.5.txt",
		        "node_list_path": "328815.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpP4b1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. P4B1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpP4b1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1119533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1119533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1119533.clusters.proteins.v11.5.txt",
		        "sequence_path": "1119533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1119533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1119533.protein.info.v11.5.txt",
		        "node_list_path": "1119533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1119533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiocystisViolascens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiocystis violascens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiocystisViolascens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765911.protein.sequences.v11.5.fa",
		        "enrichment_path": "765911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765911.protein.info.v11.5.txt",
		        "node_list_path": "765911.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCelatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium celatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCelatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "545697.protein.sequences.v11.5.fa",
		        "enrichment_path": "545697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545697.protein.info.v11.5.txt",
		        "node_list_path": "545697.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasDokdonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasDokdonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "344882.protein.sequences.v11.5.fa",
		        "enrichment_path": "344882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "344882.protein.info.v11.5.txt",
		        "node_list_path": "344882.protein.complete.v11.5.txt"
		    }
		]
    )()

def DialisterSpCag357Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dialister sp. CAG:357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterSpCag357Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262869.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262869.protein.info.v11.5.txt",
		        "node_list_path": "1262869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb245a519a13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_519A13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb245a519a13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1471509.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1471509.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1471509.clusters.proteins.v11.5.txt",
		        "sequence_path": "1471509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471509.protein.info.v11.5.txt",
		        "node_list_path": "1471509.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1471509.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwa24010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_40_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa24010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619037.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619037.protein.info.v11.5.txt",
		        "node_list_path": "1619037.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisRubida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis rubida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisRubida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "112413.protein.sequences.v11.5.fa",
		        "enrichment_path": "112413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112413.protein.info.v11.5.txt",
		        "node_list_path": "112413.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifoxya2Full4719(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYA2_FULL_47_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxya2Full4719", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797994.protein.info.v11.5.txt",
		        "node_list_path": "1797994.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAlaskensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio alaskensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAlaskensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "207559.protein.sequences.v11.5.fa",
		        "enrichment_path": "207559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "207559.protein.info.v11.5.txt",
		        "node_list_path": "207559.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumF0540Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium F0540 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumF0540Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321778.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321778.protein.info.v11.5.txt",
		        "node_list_path": "1321778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc14514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_45_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc14514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618915.protein.info.v11.5.txt",
		        "node_list_path": "1618915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinoplanesSpSe50110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes sp. SE50110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesSpSe50110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "134676.protein.sequences.v11.5.fa",
		        "enrichment_path": "134676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134676.protein.info.v11.5.txt",
		        "node_list_path": "134676.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasAveniformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas aveniformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasAveniformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121123.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121123.protein.info.v11.5.txt",
		        "node_list_path": "1121123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumBrhC4b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRH_c4b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumBrhC4b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629717.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629717.protein.info.v11.5.txt",
		        "node_list_path": "1629717.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumAntarcticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumAntarcticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266748.protein.sequences.v11.5.fa",
		        "enrichment_path": "266748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266748.protein.info.v11.5.txt",
		        "node_list_path": "266748.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRoot53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRoot53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736553.protein.info.v11.5.txt",
		        "node_list_path": "1736553.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf23548(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_35_48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf23548", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797343.protein.info.v11.5.txt",
		        "node_list_path": "1797343.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusInfantisNrrlB14911(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus infantis NRRL B-14911 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusInfantisNrrlB14911", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1367477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1367477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1367477.protein.info.v11.5.txt",
		        "node_list_path": "1367477.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesToyocaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces toyocaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesToyocaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "55952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "55952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "55952.clusters.proteins.v11.5.txt",
		        "sequence_path": "55952.protein.sequences.v11.5.fa",
		        "enrichment_path": "55952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55952.protein.info.v11.5.txt",
		        "node_list_path": "55952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "55952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpRc3b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Rc3b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpRc3b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855322.protein.info.v11.5.txt",
		        "node_list_path": "1855322.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifoxyb1Full4324(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYB1_FULL_43_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyb1Full4324", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802640.protein.info.v11.5.txt",
		        "node_list_path": "1802640.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpLeaf159Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf159 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpLeaf159Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736279.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736279.protein.info.v11.5.txt",
		        "node_list_path": "1736279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpAle5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. ALE5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpAle5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "748650.protein.sequences.v11.5.fa",
		        "enrichment_path": "748650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748650.protein.info.v11.5.txt",
		        "node_list_path": "748650.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosospiraMultiformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira multiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraMultiformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "323848.protein.sequences.v11.5.fa",
		        "enrichment_path": "323848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323848.protein.info.v11.5.txt",
		        "node_list_path": "323848.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27445(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27445 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27445", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1679166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679166.protein.info.v11.5.txt",
		        "node_list_path": "1679166.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumPerfringensAtcc13124(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium perfringens ATCC13124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPerfringensAtcc13124", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "195103.protein.sequences.v11.5.fa",
		        "enrichment_path": "195103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195103.protein.info.v11.5.txt",
		        "node_list_path": "195103.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaCremea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora cremea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaCremea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "709881.protein.sequences.v11.5.fa",
		        "enrichment_path": "709881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709881.protein.info.v11.5.txt",
		        "node_list_path": "709881.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaFiliformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga filiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaFiliformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "104663.protein.sequences.v11.5.fa",
		        "enrichment_path": "104663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104663.protein.info.v11.5.txt",
		        "node_list_path": "104663.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollinsellaSp4847faaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collinsella sp. 4847FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaSp4847faaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742722.clusters.proteins.v11.5.txt",
		        "sequence_path": "742722.protein.sequences.v11.5.fa",
		        "enrichment_path": "742722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742722.protein.info.v11.5.txt",
		        "node_list_path": "742722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaSp2HT1a6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina sp. 2.H.T.1A.6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaSp2HT1a6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1483599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1483599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1483599.protein.info.v11.5.txt",
		        "node_list_path": "1483599.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinithermusHydrothermalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinithermus hydrothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinithermusHydrothermalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "869210.protein.sequences.v11.5.fa",
		        "enrichment_path": "869210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869210.protein.info.v11.5.txt",
		        "node_list_path": "869210.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumVe20213Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumVe20213Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232443.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232443.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232443.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232443.protein.info.v11.5.txt",
		        "node_list_path": "1232443.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232443.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyripristisMurdjanCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myripristis murdjan Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyripristisMurdjanCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "586833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "586833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "586833.clusters.proteins.v11.5.txt",
		        "sequence_path": "586833.protein.sequences.v11.5.fa",
		        "enrichment_path": "586833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "586833.protein.info.v11.5.txt",
		        "node_list_path": "586833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "586833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AscodesmisNigricans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ascodesmis nigricans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AscodesmisNigricans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "341454.protein.sequences.v11.5.fa",
		        "enrichment_path": "341454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "341454.protein.info.v11.5.txt",
		        "node_list_path": "341454.protein.complete.v11.5.txt"
		    }
		]
    )()

def PvcGroupBacteriumExBugulaNeritinaAb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return PVC group bacterium (ex Bugula neritina AB1) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PvcGroupBacteriumExBugulaNeritinaAb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1868283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1868283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1868283.protein.info.v11.5.txt",
		        "node_list_path": "1868283.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseburiaHominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseburia hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaHominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585394.clusters.proteins.v11.5.txt",
		        "sequence_path": "585394.protein.sequences.v11.5.fa",
		        "enrichment_path": "585394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585394.protein.info.v11.5.txt",
		        "node_list_path": "585394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaPrimitiaZas2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema primitia ZAS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPrimitiaZas2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "545694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "545694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "545694.clusters.proteins.v11.5.txt",
		        "sequence_path": "545694.protein.sequences.v11.5.fa",
		        "enrichment_path": "545694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545694.protein.info.v11.5.txt",
		        "node_list_path": "545694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "545694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumBaderi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium baderi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumBaderi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1332080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1332080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1332080.protein.info.v11.5.txt",
		        "node_list_path": "1332080.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodovulumSpEs010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. ES.010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovulumSpEs010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882821.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882821.protein.info.v11.5.txt",
		        "node_list_path": "1882821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonasConfluentis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas confluentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasConfluentis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1656094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1656094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1656094.protein.info.v11.5.txt",
		        "node_list_path": "1656094.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterSanguineus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter sanguineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterSanguineus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "198312.protein.sequences.v11.5.fa",
		        "enrichment_path": "198312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198312.protein.info.v11.5.txt",
		        "node_list_path": "198312.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "405671.protein.sequences.v11.5.fa",
		        "enrichment_path": "405671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405671.protein.info.v11.5.txt",
		        "node_list_path": "405671.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaPsychrophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaPsychrophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "728005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "728005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "728005.clusters.proteins.v11.5.txt",
		        "sequence_path": "728005.protein.sequences.v11.5.fa",
		        "enrichment_path": "728005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "728005.protein.info.v11.5.txt",
		        "node_list_path": "728005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "728005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbiconiuxSpYr403(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbiconiux sp. YR403 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbiconiuxSpYr403", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500280.protein.info.v11.5.txt",
		        "node_list_path": "1500280.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumHylemonae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium hylemonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumHylemonae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553973.protein.sequences.v11.5.fa",
		        "enrichment_path": "553973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553973.protein.info.v11.5.txt",
		        "node_list_path": "553973.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseburiaInulinivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseburia inulinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaInulinivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "622312.protein.sequences.v11.5.fa",
		        "enrichment_path": "622312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "622312.protein.info.v11.5.txt",
		        "node_list_path": "622312.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpTrpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. TRP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpTrpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "412597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "412597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "412597.clusters.proteins.v11.5.txt",
		        "sequence_path": "412597.protein.sequences.v11.5.fa",
		        "enrichment_path": "412597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "412597.protein.info.v11.5.txt",
		        "node_list_path": "412597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "412597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumSpF0209(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. F0209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumSpF0209", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321773.protein.info.v11.5.txt",
		        "node_list_path": "1321773.protein.complete.v11.5.txt"
		    }
		]
    )()

def DialisterSpCag486Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dialister sp. CAG:486 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterSpCag486Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262870.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262870.protein.info.v11.5.txt",
		        "node_list_path": "1262870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlbimonasDonghaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Albimonas donghaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlbimonasDonghaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "356660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "356660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "356660.clusters.proteins.v11.5.txt",
		        "sequence_path": "356660.protein.sequences.v11.5.fa",
		        "enrichment_path": "356660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "356660.protein.info.v11.5.txt",
		        "node_list_path": "356660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "356660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumGw2011Gwf24219(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWF2_42_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwf24219", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618659.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618659.protein.info.v11.5.txt",
		        "node_list_path": "1618659.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb1388Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_38_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb1388Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618864.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618864.protein.info.v11.5.txt",
		        "node_list_path": "1618864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaXyliCtcb07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia xyli CTCB07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaXyliCtcb07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "281090.protein.sequences.v11.5.fa",
		        "enrichment_path": "281090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "281090.protein.info.v11.5.txt",
		        "node_list_path": "281090.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpCg912(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. CG912 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpCg912", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1504672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504672.protein.info.v11.5.txt",
		        "node_list_path": "1504672.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPacearchaeotaArchaeonRbg133326(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacearchaeota archaeon RBG_13_33_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacearchaeotaArchaeonRbg133326", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801880.protein.info.v11.5.txt",
		        "node_list_path": "1801880.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag755Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:755 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag755Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262935.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262935.protein.info.v11.5.txt",
		        "node_list_path": "1262935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpMarseilleP2426Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. Marseille-P2426 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpMarseilleP2426Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816686.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816686.protein.info.v11.5.txt",
		        "node_list_path": "1816686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpFh2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FH2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpFh2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674291.protein.info.v11.5.txt",
		        "node_list_path": "1674291.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpAw25m09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. AW25M09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpAw25m09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1268303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1268303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1268303.clusters.proteins.v11.5.txt",
		        "sequence_path": "1268303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268303.protein.info.v11.5.txt",
		        "node_list_path": "1268303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1268303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeothermobacterSpEprMCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geothermobacter sp. EPR-M Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeothermobacterSpEprMCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1969733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1969733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1969733.clusters.proteins.v11.5.txt",
		        "sequence_path": "1969733.protein.sequences.v11.5.fa",
		        "enrichment_path": "1969733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1969733.protein.info.v11.5.txt",
		        "node_list_path": "1969733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1969733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumBact13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumBact13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674827.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674827.protein.info.v11.5.txt",
		        "node_list_path": "1674827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumL18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium L18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumL18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229486.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229486.protein.info.v11.5.txt",
		        "node_list_path": "1229486.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumPaucimobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium paucimobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumPaucimobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1346330.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1346330.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1346330.clusters.proteins.v11.5.txt",
		        "sequence_path": "1346330.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346330.protein.info.v11.5.txt",
		        "node_list_path": "1346330.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1346330.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSpAtcc39149(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora sp. ATCC39149 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSpAtcc39149", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "219305.protein.sequences.v11.5.fa",
		        "enrichment_path": "219305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "219305.protein.info.v11.5.txt",
		        "node_list_path": "219305.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusMarisflaviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius marisflavi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusMarisflaviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1054996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1054996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1054996.clusters.proteins.v11.5.txt",
		        "sequence_path": "1054996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1054996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1054996.protein.info.v11.5.txt",
		        "node_list_path": "1054996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1054996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1755099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1755099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1755099.protein.info.v11.5.txt",
		        "node_list_path": "1755099.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusObscurus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus obscurus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusObscurus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "526225.protein.sequences.v11.5.fa",
		        "enrichment_path": "526225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526225.protein.info.v11.5.txt",
		        "node_list_path": "526225.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaeromycesRobustusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaeromyces robustus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeromycesRobustusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1754192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1754192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1754192.clusters.proteins.v11.5.txt",
		        "sequence_path": "1754192.protein.sequences.v11.5.fa",
		        "enrichment_path": "1754192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1754192.protein.info.v11.5.txt",
		        "node_list_path": "1754192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1754192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusAquaticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus aquaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusAquaticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "498848.protein.sequences.v11.5.fa",
		        "enrichment_path": "498848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498848.protein.info.v11.5.txt",
		        "node_list_path": "498848.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4327(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_01_FULL_43_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4327", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802735.protein.info.v11.5.txt",
		        "node_list_path": "1802735.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumGwa23526Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium GWA2_35_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumGwa23526Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798013.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798013.protein.info.v11.5.txt",
		        "node_list_path": "1798013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterGerneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter gerneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterGerneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "202952.protein.sequences.v11.5.fa",
		        "enrichment_path": "202952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202952.protein.info.v11.5.txt",
		        "node_list_path": "202952.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumEnclenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium enclense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumEnclenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "993073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "993073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "993073.clusters.proteins.v11.5.txt",
		        "sequence_path": "993073.protein.sequences.v11.5.fa",
		        "enrichment_path": "993073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "993073.protein.info.v11.5.txt",
		        "node_list_path": "993073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "993073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpFcs006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FCS006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpFcs006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280684.protein.info.v11.5.txt",
		        "node_list_path": "1280684.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumGwa2528Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium GWA2_52_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumGwa2528Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801817.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801817.protein.info.v11.5.txt",
		        "node_list_path": "1801817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusHeilongjiangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus heilongjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHeilongjiangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1074467.protein.sequences.v11.5.fa",
		        "enrichment_path": "1074467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1074467.protein.info.v11.5.txt",
		        "node_list_path": "1074467.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSp157mfCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. 157MF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSp157mfCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798222.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798222.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798222.protein.info.v11.5.txt",
		        "node_list_path": "1798222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcusMaripaludisS2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis S2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusMaripaludisS2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "267377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "267377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "267377.clusters.proteins.v11.5.txt",
		        "sequence_path": "267377.protein.sequences.v11.5.fa",
		        "enrichment_path": "267377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267377.protein.info.v11.5.txt",
		        "node_list_path": "267377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "267377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumSpMe1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. ME-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumSpMe1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1639348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1639348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1639348.clusters.proteins.v11.5.txt",
		        "sequence_path": "1639348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1639348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1639348.protein.info.v11.5.txt",
		        "node_list_path": "1639348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1639348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumOlb10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumOlb10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617421.protein.info.v11.5.txt",
		        "node_list_path": "1617421.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesNodosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces nodosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesNodosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40318.protein.sequences.v11.5.fa",
		        "enrichment_path": "40318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40318.protein.info.v11.5.txt",
		        "node_list_path": "40318.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusFlavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus flavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusFlavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5059.clusters.proteins.v11.5.txt",
		        "sequence_path": "5059.protein.sequences.v11.5.fa",
		        "enrichment_path": "5059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5059.protein.info.v11.5.txt",
		        "node_list_path": "5059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidiaBacteriumGa0077558(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidia bacterium Ga0077558 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidiaBacteriumGa0077558", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752194.protein.info.v11.5.txt",
		        "node_list_path": "1752194.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSpNrrlB16802(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora sp. NRRL B-16802 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSpNrrlB16802", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415541.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415541.protein.info.v11.5.txt",
		        "node_list_path": "1415541.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusVireti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus vireti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusVireti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131730.protein.info.v11.5.txt",
		        "node_list_path": "1131730.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisAlkaliphilaYim80379Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis alkaliphila YIM 80379 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisAlkaliphilaYim80379Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246461.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246461.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246461.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246461.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246461.protein.info.v11.5.txt",
		        "node_list_path": "1246461.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246461.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag451Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:451 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag451Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262809.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262809.protein.info.v11.5.txt",
		        "node_list_path": "1262809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaBoryana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya boryana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaBoryana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272134.protein.sequences.v11.5.fa",
		        "enrichment_path": "272134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272134.protein.info.v11.5.txt",
		        "node_list_path": "272134.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaceaeBacteriumDtu059Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaceaeBacteriumDtu059Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671644.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671644.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671644.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671644.protein.info.v11.5.txt",
		        "node_list_path": "1671644.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671644.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpBms12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BMS12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpBms12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1796033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1796033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1796033.clusters.proteins.v11.5.txt",
		        "sequence_path": "1796033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796033.protein.info.v11.5.txt",
		        "node_list_path": "1796033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1796033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwa25713(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_57_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25713", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797811.protein.info.v11.5.txt",
		        "node_list_path": "1797811.protein.complete.v11.5.txt"
		    }
		]
    )()

def TurneriellaParvaDsm21527(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Turneriella parva DSM 21527 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TurneriellaParvaDsm21527", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "869212.protein.sequences.v11.5.fa",
		        "enrichment_path": "869212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869212.protein.info.v11.5.txt",
		        "node_list_path": "869212.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZhouiaAmylolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zhouia amylolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZhouiaAmylolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1286632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286632.protein.info.v11.5.txt",
		        "node_list_path": "1286632.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylothermaceaeBacteriaB42(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylothermaceae bacteria B42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylothermaceaeBacteriaB42", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798802.protein.info.v11.5.txt",
		        "node_list_path": "1798802.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelosinusFermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelosinusFermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122947.protein.info.v11.5.txt",
		        "node_list_path": "1122947.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeoalkalibacterSubterraneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geoalkalibacter subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeoalkalibacterSubterraneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "483547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "483547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "483547.clusters.proteins.v11.5.txt",
		        "sequence_path": "483547.protein.sequences.v11.5.fa",
		        "enrichment_path": "483547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483547.protein.info.v11.5.txt",
		        "node_list_path": "483547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "483547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaNeofelifaecis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia neofelifaecis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaNeofelifaecis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644548.protein.sequences.v11.5.fa",
		        "enrichment_path": "644548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644548.protein.info.v11.5.txt",
		        "node_list_path": "644548.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRbg165712(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RBG_16_57_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRbg165712", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798266.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798266.protein.info.v11.5.txt",
		        "node_list_path": "1798266.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaBirtlesiiIbs325(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella birtlesii IBS 325 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaBirtlesiiIbs325", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095900.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095900.protein.info.v11.5.txt",
		        "node_list_path": "1095900.protein.complete.v11.5.txt"
		    }
		]
    )()

def YooniaLitoreaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yoonia litorea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YooniaLitoreaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123755.protein.info.v11.5.txt",
		        "node_list_path": "1123755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusSpLeaf326(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. Leaf326 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusSpLeaf326", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736338.protein.info.v11.5.txt",
		        "node_list_path": "1736338.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasEchinoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas echinoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasEchinoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1112212.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112212.protein.info.v11.5.txt",
		        "node_list_path": "1112212.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaCoriaceae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia coriaceae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaCoriaceae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1313292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313292.protein.info.v11.5.txt",
		        "node_list_path": "1313292.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterPragensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter pragensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterPragensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1806892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1806892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1806892.clusters.proteins.v11.5.txt",
		        "sequence_path": "1806892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806892.protein.info.v11.5.txt",
		        "node_list_path": "1806892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1806892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaSpAs16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. AS16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaSpAs16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936589.protein.sequences.v11.5.fa",
		        "enrichment_path": "936589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936589.protein.info.v11.5.txt",
		        "node_list_path": "936589.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4513Fw928Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4513 (FW-928) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4513Fw928Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420907.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420907.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420907.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420907.protein.info.v11.5.txt",
		        "node_list_path": "1420907.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420907.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaTannerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella tannerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaTannerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "626522.protein.sequences.v11.5.fa",
		        "enrichment_path": "626522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626522.protein.info.v11.5.txt",
		        "node_list_path": "626522.protein.complete.v11.5.txt"
		    }
		]
    )()

def SnodgrassellaAlvi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Snodgrassella alvi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SnodgrassellaAlvi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196083.protein.info.v11.5.txt",
		        "node_list_path": "1196083.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusCaliditerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus caliditerrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusCaliditerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1330700.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1330700.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1330700.clusters.proteins.v11.5.txt",
		        "sequence_path": "1330700.protein.sequences.v11.5.fa",
		        "enrichment_path": "1330700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1330700.protein.info.v11.5.txt",
		        "node_list_path": "1330700.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1330700.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichinellaSpT6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichinella sp. T6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaSpT6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "92179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "92179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "92179.clusters.proteins.v11.5.txt",
		        "sequence_path": "92179.protein.sequences.v11.5.fa",
		        "enrichment_path": "92179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92179.protein.info.v11.5.txt",
		        "node_list_path": "92179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "92179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusGorillaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gorillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGorillaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1450649.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1450649.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1450649.clusters.proteins.v11.5.txt",
		        "sequence_path": "1450649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450649.protein.info.v11.5.txt",
		        "node_list_path": "1450649.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1450649.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasCommunis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas communis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasCommunis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44574.protein.sequences.v11.5.fa",
		        "enrichment_path": "44574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44574.protein.info.v11.5.txt",
		        "node_list_path": "44574.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhyllobacteriumSpOv277Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. OV277 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhyllobacteriumSpOv277Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882772.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882772.protein.info.v11.5.txt",
		        "node_list_path": "1882772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasBrassicacearumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas brassicacearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBrassicacearumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930166.clusters.proteins.v11.5.txt",
		        "sequence_path": "930166.protein.sequences.v11.5.fa",
		        "enrichment_path": "930166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930166.protein.info.v11.5.txt",
		        "node_list_path": "930166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSuccinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus succinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSuccinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61015.protein.sequences.v11.5.fa",
		        "enrichment_path": "61015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61015.protein.info.v11.5.txt",
		        "node_list_path": "61015.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClohesyomycesAquaticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clohesyomyces aquaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClohesyomycesAquaticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231657.protein.info.v11.5.txt",
		        "node_list_path": "1231657.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMicrarchaeotaArchaeonCg1024740(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_47_40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1024740", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805247.protein.info.v11.5.txt",
		        "node_list_path": "1805247.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp32146(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3214.6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp32146", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882757.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882757.protein.info.v11.5.txt",
		        "node_list_path": "1882757.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumRufumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rufum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumRufumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "318424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "318424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "318424.clusters.proteins.v11.5.txt",
		        "sequence_path": "318424.protein.sequences.v11.5.fa",
		        "enrichment_path": "318424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318424.protein.info.v11.5.txt",
		        "node_list_path": "318424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "318424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinoplanesSubtropicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes subtropicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesSubtropicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "543632.protein.sequences.v11.5.fa",
		        "enrichment_path": "543632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543632.protein.info.v11.5.txt",
		        "node_list_path": "543632.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumGwf1657Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium GWF1_65_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumGwf1657Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802013.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802013.protein.info.v11.5.txt",
		        "node_list_path": "1802013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxSpNbrc102024Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. NBRC 102024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxSpNbrc102024Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1113895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1113895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1113895.clusters.proteins.v11.5.txt",
		        "sequence_path": "1113895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1113895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1113895.protein.info.v11.5.txt",
		        "node_list_path": "1113895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1113895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumLongipesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium longipes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumLongipesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "694270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "694270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "694270.clusters.proteins.v11.5.txt",
		        "sequence_path": "694270.protein.sequences.v11.5.fa",
		        "enrichment_path": "694270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694270.protein.info.v11.5.txt",
		        "node_list_path": "694270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "694270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4999Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4999 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4999Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977882.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977882.protein.info.v11.5.txt",
		        "node_list_path": "1977882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf208(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf208 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf208", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735679.protein.info.v11.5.txt",
		        "node_list_path": "1735679.protein.complete.v11.5.txt"
		    }
		]
    )()

def BombyxMori(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bombyx mori graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BombyxMori", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7091.protein.sequences.v11.5.fa",
		        "enrichment_path": "7091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7091.protein.info.v11.5.txt",
		        "node_list_path": "7091.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesertifilumSpIppasB1220Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desertifilum sp. IPPAS B-1220 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesertifilumSpIppasB1220Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1781255.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1781255.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1781255.clusters.proteins.v11.5.txt",
		        "sequence_path": "1781255.protein.sequences.v11.5.fa",
		        "enrichment_path": "1781255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1781255.protein.info.v11.5.txt",
		        "node_list_path": "1781255.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1781255.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumNigerienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium nigeriense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumNigerienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805470.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805470.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805470.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805470.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805470.protein.info.v11.5.txt",
		        "node_list_path": "1805470.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805470.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifoxyb1Full4614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFOXYB1_FULL_46_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifoxyb1Full4614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798531.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798531.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798531.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798531.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798531.protein.info.v11.5.txt",
		        "node_list_path": "1798531.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798531.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DomibacillusAminovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus aminovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusAminovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29332.clusters.proteins.v11.5.txt",
		        "sequence_path": "29332.protein.sequences.v11.5.fa",
		        "enrichment_path": "29332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29332.protein.info.v11.5.txt",
		        "node_list_path": "29332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpGfaj1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. GFAJ1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpGfaj1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118153.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118153.protein.info.v11.5.txt",
		        "node_list_path": "1118153.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocFallaxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc fallax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocFallaxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "907931.clusters.info.v11.5.txt",
		        "cluster_tree_path": "907931.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "907931.clusters.proteins.v11.5.txt",
		        "sequence_path": "907931.protein.sequences.v11.5.fa",
		        "enrichment_path": "907931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "907931.protein.info.v11.5.txt",
		        "node_list_path": "907931.cluster.nodes.v11.5.txt",
		        "edge_list_path": "907931.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TuberMagnatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tuber magnatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuberMagnatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42249.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42249.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42249.clusters.proteins.v11.5.txt",
		        "sequence_path": "42249.protein.sequences.v11.5.fa",
		        "enrichment_path": "42249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42249.protein.info.v11.5.txt",
		        "node_list_path": "42249.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42249.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhinolophusFerrumequinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhinolophus ferrumequinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhinolophusFerrumequinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59479.clusters.proteins.v11.5.txt",
		        "sequence_path": "59479.protein.sequences.v11.5.fa",
		        "enrichment_path": "59479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59479.protein.info.v11.5.txt",
		        "node_list_path": "59479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomicronemaHongdechlorisC2206Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomicronema hongdechloris C2206 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomicronemaHongdechlorisC2206Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1641165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1641165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1641165.clusters.proteins.v11.5.txt",
		        "sequence_path": "1641165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1641165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1641165.protein.info.v11.5.txt",
		        "node_list_path": "1641165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1641165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag30730263Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:307_30_263 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag30730263Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896987.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896987.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896987.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896987.protein.info.v11.5.txt",
		        "node_list_path": "1896987.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896987.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumFioriniaePj7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum fioriniae PJ7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumFioriniaePj7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1445577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1445577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1445577.clusters.proteins.v11.5.txt",
		        "sequence_path": "1445577.protein.sequences.v11.5.fa",
		        "enrichment_path": "1445577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1445577.protein.info.v11.5.txt",
		        "node_list_path": "1445577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1445577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpMku1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. MKU1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpMku1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1745182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1745182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1745182.protein.info.v11.5.txt",
		        "node_list_path": "1745182.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrinemaSalaciaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrinema salaciae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrinemaSalaciaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1186196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1186196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1186196.clusters.proteins.v11.5.txt",
		        "sequence_path": "1186196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1186196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1186196.protein.info.v11.5.txt",
		        "node_list_path": "1186196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1186196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ApteryxHaastiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Apteryx haastii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApteryxHaastiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8823.clusters.proteins.v11.5.txt",
		        "sequence_path": "8823.protein.sequences.v11.5.fa",
		        "enrichment_path": "8823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8823.protein.info.v11.5.txt",
		        "node_list_path": "8823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaPseudotuberculosisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia pseudotuberculosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaPseudotuberculosisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "633.clusters.proteins.v11.5.txt",
		        "sequence_path": "633.protein.sequences.v11.5.fa",
		        "enrichment_path": "633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633.protein.info.v11.5.txt",
		        "node_list_path": "633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AngelakisellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Angelakisella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AngelakisellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871018.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871018.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871018.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871018.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871018.protein.info.v11.5.txt",
		        "node_list_path": "1871018.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871018.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporolactobacillusLaevolacticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus laevolacticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolactobacillusLaevolacticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1395513.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1395513.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1395513.clusters.proteins.v11.5.txt",
		        "sequence_path": "1395513.protein.sequences.v11.5.fa",
		        "enrichment_path": "1395513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1395513.protein.info.v11.5.txt",
		        "node_list_path": "1395513.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1395513.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaSainthelensiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella sainthelensi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaSainthelensiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408445.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408445.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408445.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408445.protein.info.v11.5.txt",
		        "node_list_path": "1408445.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408445.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumAStrAtcc3502Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum A str. ATCC 3502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumAStrAtcc3502Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "413999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "413999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "413999.clusters.proteins.v11.5.txt",
		        "sequence_path": "413999.protein.sequences.v11.5.fa",
		        "enrichment_path": "413999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "413999.protein.info.v11.5.txt",
		        "node_list_path": "413999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "413999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCloacimonetesBacterium457255Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Cloacimonetes bacterium 4572_55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCloacimonetesBacterium457255Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1971726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1971726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1971726.clusters.proteins.v11.5.txt",
		        "sequence_path": "1971726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971726.protein.info.v11.5.txt",
		        "node_list_path": "1971726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1971726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MonoraphidiumNeglectum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monoraphidium neglectum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonoraphidiumNeglectum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "145388.protein.sequences.v11.5.fa",
		        "enrichment_path": "145388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "145388.protein.info.v11.5.txt",
		        "node_list_path": "145388.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccidioidesLutziiPb01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides lutzii Pb01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccidioidesLutziiPb01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "502779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "502779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "502779.clusters.proteins.v11.5.txt",
		        "sequence_path": "502779.protein.sequences.v11.5.fa",
		        "enrichment_path": "502779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502779.protein.info.v11.5.txt",
		        "node_list_path": "502779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "502779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpPamc25486(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. PAMC 25486 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpPamc25486", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1494608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1494608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1494608.protein.info.v11.5.txt",
		        "node_list_path": "1494608.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumF0431(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium F0431 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumF0431", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "861454.protein.sequences.v11.5.fa",
		        "enrichment_path": "861454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861454.protein.info.v11.5.txt",
		        "node_list_path": "861454.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloteneraMobilis13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera mobilis 13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraMobilis13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1132855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1132855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1132855.clusters.proteins.v11.5.txt",
		        "sequence_path": "1132855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1132855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1132855.protein.info.v11.5.txt",
		        "node_list_path": "1132855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1132855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaElaeis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia elaeis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaElaeis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1770058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1770058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1770058.protein.info.v11.5.txt",
		        "node_list_path": "1770058.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyotisBrandtiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myotis brandtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyotisBrandtiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "109478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "109478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "109478.clusters.proteins.v11.5.txt",
		        "sequence_path": "109478.protein.sequences.v11.5.fa",
		        "enrichment_path": "109478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109478.protein.info.v11.5.txt",
		        "node_list_path": "109478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "109478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PuniceicoccalesBacteriumVerruco01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Puniceicoccales bacterium Verruco_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PuniceicoccalesBacteriumVerruco01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674912.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674912.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674912.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674912.protein.info.v11.5.txt",
		        "node_list_path": "1674912.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674912.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumDtu014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumDtu014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671636.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671636.protein.info.v11.5.txt",
		        "node_list_path": "1671636.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaOrisF0302(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris F0302 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOrisF0302", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649760.protein.sequences.v11.5.fa",
		        "enrichment_path": "649760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649760.protein.info.v11.5.txt",
		        "node_list_path": "649760.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumGwc23612Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWC2_36_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumGwc23612Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798427.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798427.protein.info.v11.5.txt",
		        "node_list_path": "1798427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SediminibacillusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacillusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926277.protein.info.v11.5.txt",
		        "node_list_path": "1926277.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYonathbacteriaBacteriumRifcsphigho201Full5110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPHIGHO2_01_FULL_51_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsphigho201Full5110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802723.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802723.protein.info.v11.5.txt",
		        "node_list_path": "1802723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBeijerinckiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium beijerinckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBeijerinckiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290402.clusters.proteins.v11.5.txt",
		        "sequence_path": "290402.protein.sequences.v11.5.fa",
		        "enrichment_path": "290402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290402.protein.info.v11.5.txt",
		        "node_list_path": "290402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PericoniaMacrospinosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Periconia macrospinosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PericoniaMacrospinosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "97972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "97972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "97972.clusters.proteins.v11.5.txt",
		        "sequence_path": "97972.protein.sequences.v11.5.fa",
		        "enrichment_path": "97972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97972.protein.info.v11.5.txt",
		        "node_list_path": "97972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "97972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SparassisCrispaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sparassis crispa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SparassisCrispaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "139825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "139825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "139825.clusters.proteins.v11.5.txt",
		        "sequence_path": "139825.protein.sequences.v11.5.fa",
		        "enrichment_path": "139825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "139825.protein.info.v11.5.txt",
		        "node_list_path": "139825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "139825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaProteobacteriumMl8F1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return delta proteobacterium ML8_F1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaProteobacteriumMl8F1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1775671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775671.protein.info.v11.5.txt",
		        "node_list_path": "1775671.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcanobacteriumSpS3pf19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcanobacterium sp. S3PF19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcanobacteriumSpS3pf19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219585.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219585.protein.info.v11.5.txt",
		        "node_list_path": "1219585.protein.complete.v11.5.txt"
		    }
		]
    )()

def NonomuraeaCoxensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea coxensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaCoxensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122611.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122611.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122611.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122611.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122611.protein.info.v11.5.txt",
		        "node_list_path": "1122611.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122611.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeiothermusRufus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus rufus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusRufus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "604331.protein.sequences.v11.5.fa",
		        "enrichment_path": "604331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "604331.protein.info.v11.5.txt",
		        "node_list_path": "604331.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4246Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4246 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4246Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420902.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420902.protein.info.v11.5.txt",
		        "node_list_path": "1420902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RodentibacterHeidelbergensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter heidelbergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterHeidelbergensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1908258.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1908258.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1908258.clusters.proteins.v11.5.txt",
		        "sequence_path": "1908258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908258.protein.info.v11.5.txt",
		        "node_list_path": "1908258.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1908258.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSp88aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 88A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSp88aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131813.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131813.protein.info.v11.5.txt",
		        "node_list_path": "1131813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpIP16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. I-P16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpIP16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1156433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1156433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1156433.clusters.proteins.v11.5.txt",
		        "sequence_path": "1156433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156433.protein.info.v11.5.txt",
		        "node_list_path": "1156433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1156433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapsasporaOwczarzakiAtcc30864(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capsaspora owczarzaki ATCC 30864 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsasporaOwczarzakiAtcc30864", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "595528.protein.sequences.v11.5.fa",
		        "enrichment_path": "595528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595528.protein.info.v11.5.txt",
		        "node_list_path": "595528.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPanipatensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas panipatensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPanipatensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "428992.protein.sequences.v11.5.fa",
		        "enrichment_path": "428992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428992.protein.info.v11.5.txt",
		        "node_list_path": "428992.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterQingfengensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter qingfengensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterQingfengensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262585.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262585.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262585.protein.info.v11.5.txt",
		        "node_list_path": "1262585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiopsisBaichengensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis baichengensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisBaichengensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236902.protein.info.v11.5.txt",
		        "node_list_path": "1236902.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumMongoliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium mongoliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumMongoliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437603.protein.info.v11.5.txt",
		        "node_list_path": "1437603.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumBohemicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium bohemicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumBohemicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56425.protein.sequences.v11.5.fa",
		        "enrichment_path": "56425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56425.protein.info.v11.5.txt",
		        "node_list_path": "56425.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpDsm4029Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. DSM 4029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpDsm4029Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882754.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882754.protein.info.v11.5.txt",
		        "node_list_path": "1882754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumScgcAaa027G08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium SCGC AAA027-G08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumScgcAaa027G08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "938698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "938698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "938698.clusters.proteins.v11.5.txt",
		        "sequence_path": "938698.protein.sequences.v11.5.fa",
		        "enrichment_path": "938698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938698.protein.info.v11.5.txt",
		        "node_list_path": "938698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "938698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychromonasAquimarinaAtccBaa1526(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas aquimarina ATCC BAA-1526 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychromonasAquimarinaAtccBaa1526", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278312.protein.info.v11.5.txt",
		        "node_list_path": "1278312.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpGd7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. GD7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpGd7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232427.protein.info.v11.5.txt",
		        "node_list_path": "1232427.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesRubrolavendulaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces rubrolavendulae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRubrolavendulaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "285473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "285473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "285473.clusters.proteins.v11.5.txt",
		        "sequence_path": "285473.protein.sequences.v11.5.fa",
		        "enrichment_path": "285473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285473.protein.info.v11.5.txt",
		        "node_list_path": "285473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "285473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CronobacterSakazakii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter sakazakii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CronobacterSakazakii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28141.protein.sequences.v11.5.fa",
		        "enrichment_path": "28141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28141.protein.info.v11.5.txt",
		        "node_list_path": "28141.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasTaeanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas taeanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasTaeanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1395571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1395571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1395571.clusters.proteins.v11.5.txt",
		        "sequence_path": "1395571.protein.sequences.v11.5.fa",
		        "enrichment_path": "1395571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1395571.protein.info.v11.5.txt",
		        "node_list_path": "1395571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1395571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioSpMd2005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. MD2005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioSpMd2005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410616.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410616.protein.info.v11.5.txt",
		        "node_list_path": "1410616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumSublineola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum sublineola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumSublineola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173701.protein.info.v11.5.txt",
		        "node_list_path": "1173701.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifoxyd12Full5624Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12_FULL_56_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12Full5624Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797905.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797905.protein.info.v11.5.txt",
		        "node_list_path": "1797905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasMaltophiliaPml168(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia PML168 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasMaltophiliaPml168", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118235.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118235.protein.info.v11.5.txt",
		        "node_list_path": "1118235.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpTab87Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. TAB 87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpTab87Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729581.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729581.protein.info.v11.5.txt",
		        "node_list_path": "1729581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OchrobactrumAnthropiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum anthropi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OchrobactrumAnthropiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "439375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "439375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "439375.clusters.proteins.v11.5.txt",
		        "sequence_path": "439375.protein.sequences.v11.5.fa",
		        "enrichment_path": "439375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439375.protein.info.v11.5.txt",
		        "node_list_path": "439375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "439375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacteriumDehalogenansDsm11527(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacterium dehalogenans DSM 11527 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacteriumDehalogenansDsm11527", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1068975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1068975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1068975.protein.info.v11.5.txt",
		        "node_list_path": "1068975.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrincolaSpAD6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrincola sp. A-D6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrincolaSpAD6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1545442.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545442.protein.info.v11.5.txt",
		        "node_list_path": "1545442.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaeromyxobacterDehalogenansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaeromyxobacter dehalogenans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeromyxobacterDehalogenansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290397.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290397.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290397.clusters.proteins.v11.5.txt",
		        "sequence_path": "290397.protein.sequences.v11.5.fa",
		        "enrichment_path": "290397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290397.protein.info.v11.5.txt",
		        "node_list_path": "290397.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290397.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PediococcusCellicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus cellicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusCellicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "319652.protein.sequences.v11.5.fa",
		        "enrichment_path": "319652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319652.protein.info.v11.5.txt",
		        "node_list_path": "319652.protein.complete.v11.5.txt"
		    }
		]
    )()

def LatesCalcariferCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lates calcarifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LatesCalcariferCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8187.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8187.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8187.clusters.proteins.v11.5.txt",
		        "sequence_path": "8187.protein.sequences.v11.5.fa",
		        "enrichment_path": "8187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8187.protein.info.v11.5.txt",
		        "node_list_path": "8187.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8187.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LobosporangiumTransversale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lobosporangium transversale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LobosporangiumTransversale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "64571.protein.sequences.v11.5.fa",
		        "enrichment_path": "64571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64571.protein.info.v11.5.txt",
		        "node_list_path": "64571.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaTerricolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia terricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaTerricolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "169427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "169427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "169427.clusters.proteins.v11.5.txt",
		        "sequence_path": "169427.protein.sequences.v11.5.fa",
		        "enrichment_path": "169427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "169427.protein.info.v11.5.txt",
		        "node_list_path": "169427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "169427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalococcusSalifodinaeDsm8989(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halococcus salifodinae DSM 8989 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusSalifodinaeDsm8989", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227456.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227456.protein.info.v11.5.txt",
		        "node_list_path": "1227456.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaBiviaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bivia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBiviaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28125.clusters.proteins.v11.5.txt",
		        "sequence_path": "28125.protein.sequences.v11.5.fa",
		        "enrichment_path": "28125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28125.protein.info.v11.5.txt",
		        "node_list_path": "28125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFjat27812(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FJAT-27812 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFjat27812", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1684143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1684143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1684143.protein.info.v11.5.txt",
		        "node_list_path": "1684143.protein.complete.v11.5.txt"
		    }
		]
    )()

def FodinicurvataFenggangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fodinicurvata fenggangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FodinicurvataFenggangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "570967.protein.sequences.v11.5.fa",
		        "enrichment_path": "570967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570967.protein.info.v11.5.txt",
		        "node_list_path": "570967.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichormusSpNmc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichormus sp. NMC-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichormusSpNmc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1853259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1853259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1853259.protein.info.v11.5.txt",
		        "node_list_path": "1853259.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSp3524zxx(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 3524ZXX graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSp3524zxx", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1545915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545915.protein.info.v11.5.txt",
		        "node_list_path": "1545915.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo202Full6726(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_02_FULL_67_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202Full6726", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797492.protein.info.v11.5.txt",
		        "node_list_path": "1797492.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumIndolisDsm755(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] indolis DSM 755 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumIndolisDsm755", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304881.protein.info.v11.5.txt",
		        "node_list_path": "1304881.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaBellii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia bellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaBellii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33990.protein.sequences.v11.5.fa",
		        "enrichment_path": "33990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33990.protein.info.v11.5.txt",
		        "node_list_path": "33990.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucobacterChironomi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter chironomi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterChironomi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122175.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122175.protein.info.v11.5.txt",
		        "node_list_path": "1122175.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerrimonasBalearicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas balearica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrimonasBalearicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "550540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "550540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "550540.clusters.proteins.v11.5.txt",
		        "sequence_path": "550540.protein.sequences.v11.5.fa",
		        "enrichment_path": "550540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "550540.protein.info.v11.5.txt",
		        "node_list_path": "550540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "550540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3317(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_33_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3317", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801764.protein.info.v11.5.txt",
		        "node_list_path": "1801764.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonasAdhaerens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas adhaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasAdhaerens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280949.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280949.protein.info.v11.5.txt",
		        "node_list_path": "1280949.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaSpAtcc39006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. ATCC39006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpAtcc39006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "104623.protein.sequences.v11.5.fa",
		        "enrichment_path": "104623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104623.protein.info.v11.5.txt",
		        "node_list_path": "104623.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhlebiaCentrifugaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phlebia centrifuga Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhlebiaCentrifugaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "98765.clusters.info.v11.5.txt",
		        "cluster_tree_path": "98765.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "98765.clusters.proteins.v11.5.txt",
		        "sequence_path": "98765.protein.sequences.v11.5.fa",
		        "enrichment_path": "98765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "98765.protein.info.v11.5.txt",
		        "node_list_path": "98765.cluster.nodes.v11.5.txt",
		        "edge_list_path": "98765.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KwoniellaMangroviensisCbs10435Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella mangroviensis CBS 10435 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KwoniellaMangroviensisCbs10435Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1331196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1331196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1331196.clusters.proteins.v11.5.txt",
		        "sequence_path": "1331196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1331196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1331196.protein.info.v11.5.txt",
		        "node_list_path": "1331196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1331196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParapedobacterKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parapedobacter koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParapedobacterKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "332977.clusters.info.v11.5.txt",
		        "cluster_tree_path": "332977.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "332977.clusters.proteins.v11.5.txt",
		        "sequence_path": "332977.protein.sequences.v11.5.fa",
		        "enrichment_path": "332977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332977.protein.info.v11.5.txt",
		        "node_list_path": "332977.cluster.nodes.v11.5.txt",
		        "edge_list_path": "332977.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusRaoultii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus raoultii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusRaoultii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776387.protein.info.v11.5.txt",
		        "node_list_path": "1776387.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSp6113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 61-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSp6113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895780.protein.info.v11.5.txt",
		        "node_list_path": "1895780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasMaltophiliaK279a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia K279a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasMaltophiliaK279a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "522373.protein.sequences.v11.5.fa",
		        "enrichment_path": "522373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "522373.protein.info.v11.5.txt",
		        "node_list_path": "522373.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacaBarguzinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobaca barguzinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacaBarguzinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "441209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "441209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "441209.clusters.proteins.v11.5.txt",
		        "sequence_path": "441209.protein.sequences.v11.5.fa",
		        "enrichment_path": "441209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441209.protein.info.v11.5.txt",
		        "node_list_path": "441209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "441209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesMegasporusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces megasporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesMegasporusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44060.clusters.proteins.v11.5.txt",
		        "sequence_path": "44060.protein.sequences.v11.5.fa",
		        "enrichment_path": "44060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44060.protein.info.v11.5.txt",
		        "node_list_path": "44060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaSeriolae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia seriolae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSeriolae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37332.protein.sequences.v11.5.fa",
		        "enrichment_path": "37332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37332.protein.info.v11.5.txt",
		        "node_list_path": "37332.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasPhyllosphaeraeFa2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas phyllosphaerae FA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasPhyllosphaeraeFa2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1090319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1090319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1090319.protein.info.v11.5.txt",
		        "node_list_path": "1090319.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpCl95Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. cl95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpCl95Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761761.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761761.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761761.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761761.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761761.protein.info.v11.5.txt",
		        "node_list_path": "1761761.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761761.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAlgidusDsm15638Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus algidus DSM 15638 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAlgidusDsm15638Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423719.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423719.protein.info.v11.5.txt",
		        "node_list_path": "1423719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusOpacusB4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus opacus B4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusOpacusB4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "632772.protein.sequences.v11.5.fa",
		        "enrichment_path": "632772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632772.protein.info.v11.5.txt",
		        "node_list_path": "632772.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumGa0077528Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium Ga0077528 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumGa0077528Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752212.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752212.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752212.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752212.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752212.protein.info.v11.5.txt",
		        "node_list_path": "1752212.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752212.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumFortuitum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium fortuitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumFortuitum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1766.protein.info.v11.5.txt",
		        "node_list_path": "1766.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaAbortusLlgCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia abortus LLG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaAbortusLlgCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1003238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1003238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1003238.clusters.proteins.v11.5.txt",
		        "sequence_path": "1003238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1003238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1003238.protein.info.v11.5.txt",
		        "node_list_path": "1003238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1003238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChrysemysPictaBellii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chrysemys picta bellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChrysemysPictaBellii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8478.protein.sequences.v11.5.fa",
		        "enrichment_path": "8478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8478.protein.info.v11.5.txt",
		        "node_list_path": "8478.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_44_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797535.protein.info.v11.5.txt",
		        "node_list_path": "1797535.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnsiferGlycinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer glycinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferGlycinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1472378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1472378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1472378.protein.info.v11.5.txt",
		        "node_list_path": "1472378.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrococcusSpMarseilleP2731Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrococcus sp. Marseille-P2731 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrococcusSpMarseilleP2731Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841862.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841862.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841862.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841862.protein.info.v11.5.txt",
		        "node_list_path": "1841862.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841862.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKomeilibacteriaBacteriumRifcsplowo202Full4811Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_02_FULL_48_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo202Full4811Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798553.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798553.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798553.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798553.protein.info.v11.5.txt",
		        "node_list_path": "1798553.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798553.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNealsonbacteriaBacteriumRbg134211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RBG_13_42_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRbg134211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801663.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801663.protein.info.v11.5.txt",
		        "node_list_path": "1801663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SediminibacteriumGinsengisoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacteriumGinsengisoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "413434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "413434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "413434.clusters.proteins.v11.5.txt",
		        "sequence_path": "413434.protein.sequences.v11.5.fa",
		        "enrichment_path": "413434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "413434.protein.info.v11.5.txt",
		        "node_list_path": "413434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "413434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioPalustris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio palustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioPalustris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1918946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918946.protein.info.v11.5.txt",
		        "node_list_path": "1918946.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpOk665Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. OK665 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpOk665Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500305.protein.info.v11.5.txt",
		        "node_list_path": "1500305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodosporidiumToruloides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodosporidium toruloides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodosporidiumToruloides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5286.protein.sequences.v11.5.fa",
		        "enrichment_path": "5286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5286.protein.info.v11.5.txt",
		        "node_list_path": "5286.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenericutesBacteriumGwd23827Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWD2_38_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenericutesBacteriumGwd23827Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802348.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802348.protein.info.v11.5.txt",
		        "node_list_path": "1802348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFf3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FF3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFf3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1347368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1347368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1347368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1347368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347368.protein.info.v11.5.txt",
		        "node_list_path": "1347368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1347368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27986Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27986 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27986Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1743146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1743146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1743146.clusters.proteins.v11.5.txt",
		        "sequence_path": "1743146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743146.protein.info.v11.5.txt",
		        "node_list_path": "1743146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1743146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeropyrumPernixCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeropyrum pernix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeropyrumPernixCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272557.clusters.proteins.v11.5.txt",
		        "sequence_path": "272557.protein.sequences.v11.5.fa",
		        "enrichment_path": "272557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272557.protein.info.v11.5.txt",
		        "node_list_path": "272557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaDilworthii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia dilworthii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaDilworthii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "948106.protein.sequences.v11.5.fa",
		        "enrichment_path": "948106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "948106.protein.info.v11.5.txt",
		        "node_list_path": "948106.protein.complete.v11.5.txt"
		    }
		]
    )()

def TepidimonasTaiwanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tepidimonas taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidimonasTaiwanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "307486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "307486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "307486.clusters.proteins.v11.5.txt",
		        "sequence_path": "307486.protein.sequences.v11.5.fa",
		        "enrichment_path": "307486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "307486.protein.info.v11.5.txt",
		        "node_list_path": "307486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "307486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4921(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_01_FULL_49_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4921", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802135.protein.info.v11.5.txt",
		        "node_list_path": "1802135.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPsychrophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPsychrophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211112.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211112.protein.info.v11.5.txt",
		        "node_list_path": "1211112.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpGfb01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. GFB01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpGfb01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1662190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662190.protein.info.v11.5.txt",
		        "node_list_path": "1662190.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolyangiumBrachysporum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Polyangium] brachysporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolyangiumBrachysporum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "413882.protein.sequences.v11.5.fa",
		        "enrichment_path": "413882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "413882.protein.info.v11.5.txt",
		        "node_list_path": "413882.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaSocranskiiVpidr56br1116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema socranskii VPIDR56BR1116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSocranskiiVpidr56br1116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125725.protein.info.v11.5.txt",
		        "node_list_path": "1125725.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasCangingivalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas cangingivalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasCangingivalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36874.clusters.proteins.v11.5.txt",
		        "sequence_path": "36874.protein.sequences.v11.5.fa",
		        "enrichment_path": "36874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36874.protein.info.v11.5.txt",
		        "node_list_path": "36874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaProteobacteriumCb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return beta proteobacterium CB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaProteobacteriumCb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "543913.protein.sequences.v11.5.fa",
		        "enrichment_path": "543913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543913.protein.info.v11.5.txt",
		        "node_list_path": "543913.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSp9120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. 9120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSp9120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500897.protein.info.v11.5.txt",
		        "node_list_path": "1500897.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeothrixFermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geothrix fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeothrixFermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121920.protein.info.v11.5.txt",
		        "node_list_path": "1121920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrcinusOrcaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Orcinus orca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrcinusOrcaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9733.clusters.proteins.v11.5.txt",
		        "sequence_path": "9733.protein.sequences.v11.5.fa",
		        "enrichment_path": "9733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9733.protein.info.v11.5.txt",
		        "node_list_path": "9733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSoliNbrc102451Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus soli NBRC 102451 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSoliNbrc102451Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348630.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348630.protein.info.v11.5.txt",
		        "node_list_path": "1348630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionSr1BacteriumRaac1Sr11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division SR1 bacterium RAAC1_SR1_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionSr1BacteriumRaac1Sr11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1394709.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1394709.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1394709.clusters.proteins.v11.5.txt",
		        "sequence_path": "1394709.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394709.protein.info.v11.5.txt",
		        "node_list_path": "1394709.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1394709.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenimonasSpSl110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caenimonas sp. SL110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenimonasSpSl110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1450524.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1450524.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1450524.clusters.proteins.v11.5.txt",
		        "sequence_path": "1450524.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450524.protein.info.v11.5.txt",
		        "node_list_path": "1450524.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1450524.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CadophoraSpDse1049(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cadophora sp. DSE1049 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CadophoraSpDse1049", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1485229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1485229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1485229.protein.info.v11.5.txt",
		        "node_list_path": "1485229.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpKnhs205Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs205 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpKnhs205Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449050.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449050.protein.info.v11.5.txt",
		        "node_list_path": "1449050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DissulfuribacterThermophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dissulfuribacter thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DissulfuribacterThermophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1156395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156395.protein.info.v11.5.txt",
		        "node_list_path": "1156395.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4112Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_41_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4112Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802138.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802138.protein.info.v11.5.txt",
		        "node_list_path": "1802138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfamplusMagnetovallimortisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfamplus magnetovallimortis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfamplusMagnetovallimortisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246637.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246637.protein.info.v11.5.txt",
		        "node_list_path": "1246637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPilosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pilosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPilosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121366.protein.info.v11.5.txt",
		        "node_list_path": "1121366.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasCichorii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas cichorii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCichorii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1441629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1441629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1441629.protein.info.v11.5.txt",
		        "node_list_path": "1441629.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpCfcc11742(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. CFCC 11742 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpCfcc11742", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1775560.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775560.protein.info.v11.5.txt",
		        "node_list_path": "1775560.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacterSulfurreducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter sulfurreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterSulfurreducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243231.protein.sequences.v11.5.fa",
		        "enrichment_path": "243231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243231.protein.info.v11.5.txt",
		        "node_list_path": "243231.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAdlerbacteriaBacteriumGw2011Gwb1547(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium GW2011_GWB1_54_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumGw2011Gwb1547", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618607.protein.info.v11.5.txt",
		        "node_list_path": "1618607.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxyb2Full5012(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2_FULL_50_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2Full5012", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797969.protein.info.v11.5.txt",
		        "node_list_path": "1797969.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoalloteichusHymeniacidonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoalloteichus hymeniacidonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoalloteichusHymeniacidonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "340345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "340345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "340345.clusters.proteins.v11.5.txt",
		        "sequence_path": "340345.protein.sequences.v11.5.fa",
		        "enrichment_path": "340345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340345.protein.info.v11.5.txt",
		        "node_list_path": "340345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "340345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlysiellaCrassa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alysiella crassa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlysiellaCrassa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120980.protein.info.v11.5.txt",
		        "node_list_path": "1120980.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpTnhr37bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. TNHR37B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpTnhr37bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1775956.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1775956.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1775956.clusters.proteins.v11.5.txt",
		        "sequence_path": "1775956.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775956.protein.info.v11.5.txt",
		        "node_list_path": "1775956.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1775956.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpXbb1001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. XBB1001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpXbb1001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280682.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280682.protein.info.v11.5.txt",
		        "node_list_path": "1280682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LabrenziaSpDg1229(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Labrenzia sp. DG1229 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrenziaSpDg1229", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "681847.protein.sequences.v11.5.fa",
		        "enrichment_path": "681847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "681847.protein.info.v11.5.txt",
		        "node_list_path": "681847.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusFloricolaDsm23037Jcm16512(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus floricola DSM 23037 JCM 16512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFloricolaDsm23037Jcm16512", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423744.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423744.protein.info.v11.5.txt",
		        "node_list_path": "1423744.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterArcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterArcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "561365.protein.sequences.v11.5.fa",
		        "enrichment_path": "561365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561365.protein.info.v11.5.txt",
		        "node_list_path": "561365.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusPrevotiiAcs065vcol13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus prevotii ACS065VCol13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusPrevotiiAcs065vcol13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "879305.protein.sequences.v11.5.fa",
		        "enrichment_path": "879305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879305.protein.info.v11.5.txt",
		        "node_list_path": "879305.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhormidiumSpOscrCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phormidium sp. OSCR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhormidiumSpOscrCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1666905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1666905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1666905.clusters.proteins.v11.5.txt",
		        "sequence_path": "1666905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666905.protein.info.v11.5.txt",
		        "node_list_path": "1666905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1666905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AerococcusSanguinicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus sanguinicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusSanguinicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "119206.clusters.info.v11.5.txt",
		        "cluster_tree_path": "119206.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "119206.clusters.proteins.v11.5.txt",
		        "sequence_path": "119206.protein.sequences.v11.5.fa",
		        "enrichment_path": "119206.protein.enrichment.terms.v11.5.txt",
		        "info_path": "119206.protein.info.v11.5.txt",
		        "node_list_path": "119206.cluster.nodes.v11.5.txt",
		        "edge_list_path": "119206.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterGyllenbergii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter gyllenbergii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterGyllenbergii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217658.protein.info.v11.5.txt",
		        "node_list_path": "1217658.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemmataSpShPl17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmata sp. SH-PL17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmataSpShPl17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1630693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1630693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1630693.clusters.proteins.v11.5.txt",
		        "sequence_path": "1630693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1630693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1630693.protein.info.v11.5.txt",
		        "node_list_path": "1630693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1630693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpJpy347Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. JPY347 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpJpy347Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "667632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "667632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "667632.clusters.proteins.v11.5.txt",
		        "sequence_path": "667632.protein.sequences.v11.5.fa",
		        "enrichment_path": "667632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667632.protein.info.v11.5.txt",
		        "node_list_path": "667632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "667632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerasakiispiraPapahanaumokuakeensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terasakiispira papahanaumokuakeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerasakiispiraPapahanaumokuakeensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "197479.protein.sequences.v11.5.fa",
		        "enrichment_path": "197479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "197479.protein.info.v11.5.txt",
		        "node_list_path": "197479.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaeBacteriumGwa25015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium GWA2_50_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaeBacteriumGwa25015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797595.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797595.protein.info.v11.5.txt",
		        "node_list_path": "1797595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EremotheciumSinecaudum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium sinecaudum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremotheciumSinecaudum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45286.protein.sequences.v11.5.fa",
		        "enrichment_path": "45286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45286.protein.info.v11.5.txt",
		        "node_list_path": "45286.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusAlbus8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus albus 8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusAlbus8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246199.clusters.proteins.v11.5.txt",
		        "sequence_path": "246199.protein.sequences.v11.5.fa",
		        "enrichment_path": "246199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246199.protein.info.v11.5.txt",
		        "node_list_path": "246199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioNigripulchritudo(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio nigripulchritudo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioNigripulchritudo", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1238450.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238450.protein.info.v11.5.txt",
		        "node_list_path": "1238450.protein.complete.v11.5.txt"
		    }
		]
    )()

def TessaracoccusBendigoensisDsm12906(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus bendigoensis DSM 12906 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusBendigoensisDsm12906", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123357.protein.info.v11.5.txt",
		        "node_list_path": "1123357.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpCf384Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. CF384 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpCf384Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884382.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884382.protein.info.v11.5.txt",
		        "node_list_path": "1884382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaRuminicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella ruminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaRuminicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264731.clusters.proteins.v11.5.txt",
		        "sequence_path": "264731.protein.sequences.v11.5.fa",
		        "enrichment_path": "264731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264731.protein.info.v11.5.txt",
		        "node_list_path": "264731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaConjunctivae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma conjunctivae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaConjunctivae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45361.protein.sequences.v11.5.fa",
		        "enrichment_path": "45361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45361.protein.info.v11.5.txt",
		        "node_list_path": "45361.protein.complete.v11.5.txt"
		    }
		]
    )()

def EdwardsiellaIctaluri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Edwardsiella ictaluri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EdwardsiellaIctaluri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67780.protein.sequences.v11.5.fa",
		        "enrichment_path": "67780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67780.protein.info.v11.5.txt",
		        "node_list_path": "67780.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusOralisSk255Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis SK255 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOralisSk255Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005704.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005704.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005704.protein.info.v11.5.txt",
		        "node_list_path": "1005704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaXiamenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaXiamenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "740709.clusters.info.v11.5.txt",
		        "cluster_tree_path": "740709.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "740709.clusters.proteins.v11.5.txt",
		        "sequence_path": "740709.protein.sequences.v11.5.fa",
		        "enrichment_path": "740709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "740709.protein.info.v11.5.txt",
		        "node_list_path": "740709.cluster.nodes.v11.5.txt",
		        "edge_list_path": "740709.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumUc511d2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-1D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumUc511d2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1697780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1697780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1697780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1697780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1697780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1697780.protein.info.v11.5.txt",
		        "node_list_path": "1697780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1697780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusPakistanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus pakistanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusPakistanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "759811.protein.sequences.v11.5.fa",
		        "enrichment_path": "759811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759811.protein.info.v11.5.txt",
		        "node_list_path": "759811.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaSubspHoutenaeStrAtccBaa1581Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. houtenae str. ATCC BAA-1581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaSubspHoutenaeStrAtccBaa1581Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "523831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "523831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "523831.clusters.proteins.v11.5.txt",
		        "sequence_path": "523831.protein.sequences.v11.5.fa",
		        "enrichment_path": "523831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523831.protein.info.v11.5.txt",
		        "node_list_path": "523831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "523831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpS6262(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. S6-262 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpS6262", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1166340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166340.protein.info.v11.5.txt",
		        "node_list_path": "1166340.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterKookii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter kookii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterKookii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1226327.protein.sequences.v11.5.fa",
		        "enrichment_path": "1226327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1226327.protein.info.v11.5.txt",
		        "node_list_path": "1226327.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassilibacteroidesVaginae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilibacteroides vaginae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassilibacteroidesVaginae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1673718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673718.protein.info.v11.5.txt",
		        "node_list_path": "1673718.protein.complete.v11.5.txt"
		    }
		]
    )()

def TessaracoccusAquimarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus aquimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusAquimarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1332264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1332264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1332264.clusters.proteins.v11.5.txt",
		        "sequence_path": "1332264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1332264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1332264.protein.info.v11.5.txt",
		        "node_list_path": "1332264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1332264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasAtlanticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasAtlanticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1806668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1806668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1806668.clusters.proteins.v11.5.txt",
		        "sequence_path": "1806668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806668.protein.info.v11.5.txt",
		        "node_list_path": "1806668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1806668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPseudotuberculosisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pseudotuberculosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPseudotuberculosisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1719.clusters.proteins.v11.5.txt",
		        "sequence_path": "1719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1719.protein.info.v11.5.txt",
		        "node_list_path": "1719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumGallicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium gallicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumGallicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "561180.protein.sequences.v11.5.fa",
		        "enrichment_path": "561180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561180.protein.info.v11.5.txt",
		        "node_list_path": "561180.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSyntrophoarchaeumCaldarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Syntrophoarchaeum caldarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSyntrophoarchaeumCaldarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1838285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1838285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1838285.protein.info.v11.5.txt",
		        "node_list_path": "1838285.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesDenticolensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces denticolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesDenticolensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52767.clusters.proteins.v11.5.txt",
		        "sequence_path": "52767.protein.sequences.v11.5.fa",
		        "enrichment_path": "52767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52767.protein.info.v11.5.txt",
		        "node_list_path": "52767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavigranumRuoffiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavigranum ruoffiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavigranumRuoffiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "89093.protein.sequences.v11.5.fa",
		        "enrichment_path": "89093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89093.protein.info.v11.5.txt",
		        "node_list_path": "89093.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusPseudintermediusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus pseudintermedius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusPseudintermediusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "984892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "984892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "984892.clusters.proteins.v11.5.txt",
		        "sequence_path": "984892.protein.sequences.v11.5.fa",
		        "enrichment_path": "984892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "984892.protein.info.v11.5.txt",
		        "node_list_path": "984892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "984892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TessaracoccusAquimaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus aquimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusAquimaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1332264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1332264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1332264.protein.info.v11.5.txt",
		        "node_list_path": "1332264.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusPantherisDsm15945Jcm12539Nbrc106106Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pantheris DSM 15945 JCM 12539 NBRC 106106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPantherisDsm15945Jcm12539Nbrc106106Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423783.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423783.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423783.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423783.protein.info.v11.5.txt",
		        "node_list_path": "1423783.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423783.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf38Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf38Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736217.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736217.protein.info.v11.5.txt",
		        "node_list_path": "1736217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphibacillusJilinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amphibacillus jilinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphibacillusJilinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "562743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "562743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "562743.clusters.proteins.v11.5.txt",
		        "sequence_path": "562743.protein.sequences.v11.5.fa",
		        "enrichment_path": "562743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562743.protein.info.v11.5.txt",
		        "node_list_path": "562743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "562743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptosporidiumMurisRn66Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporidium muris RN66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptosporidiumMurisRn66Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "441375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "441375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "441375.clusters.proteins.v11.5.txt",
		        "sequence_path": "441375.protein.sequences.v11.5.fa",
		        "enrichment_path": "441375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441375.protein.info.v11.5.txt",
		        "node_list_path": "441375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "441375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeomicrobiumSpJcm19037Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM19037 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeomicrobiumSpJcm19037Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1460634.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1460634.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1460634.clusters.proteins.v11.5.txt",
		        "sequence_path": "1460634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460634.protein.info.v11.5.txt",
		        "node_list_path": "1460634.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1460634.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusKakegawensisNbrc103104Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus kakegawensis NBRC 103104 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusKakegawensisNbrc103104Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220571.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220571.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220571.protein.info.v11.5.txt",
		        "node_list_path": "1220571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaSpH1n(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. H1n graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpH1n", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397284.protein.info.v11.5.txt",
		        "node_list_path": "1397284.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChristensenellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Christensenella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChristensenellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805714.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805714.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805714.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805714.protein.info.v11.5.txt",
		        "node_list_path": "1805714.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805714.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacillusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926286.protein.info.v11.5.txt",
		        "node_list_path": "1926286.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpCzUamCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. CZ-UAM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpCzUamCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1933868.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1933868.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1933868.clusters.proteins.v11.5.txt",
		        "sequence_path": "1933868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933868.protein.info.v11.5.txt",
		        "node_list_path": "1933868.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1933868.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaCsv86(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida CSV86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaCsv86", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005395.protein.info.v11.5.txt",
		        "node_list_path": "1005395.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpLeaf69Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf69 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpLeaf69Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736232.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736232.protein.info.v11.5.txt",
		        "node_list_path": "1736232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExophialaXenobioticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exophiala xenobiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaXenobioticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "348802.clusters.info.v11.5.txt",
		        "cluster_tree_path": "348802.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "348802.clusters.proteins.v11.5.txt",
		        "sequence_path": "348802.protein.sequences.v11.5.fa",
		        "enrichment_path": "348802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "348802.protein.info.v11.5.txt",
		        "node_list_path": "348802.cluster.nodes.v11.5.txt",
		        "edge_list_path": "348802.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusJaponicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusJaponicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53341.clusters.proteins.v11.5.txt",
		        "sequence_path": "53341.protein.sequences.v11.5.fa",
		        "enrichment_path": "53341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53341.protein.info.v11.5.txt",
		        "node_list_path": "53341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacterCurvatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacter curvatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacterCurvatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121396.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121396.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121396.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121396.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121396.protein.info.v11.5.txt",
		        "node_list_path": "1121396.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121396.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmmonifexDegensiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ammonifex degensii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmmonifexDegensiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "429009.clusters.info.v11.5.txt",
		        "cluster_tree_path": "429009.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "429009.clusters.proteins.v11.5.txt",
		        "sequence_path": "429009.protein.sequences.v11.5.fa",
		        "enrichment_path": "429009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "429009.protein.info.v11.5.txt",
		        "node_list_path": "429009.cluster.nodes.v11.5.txt",
		        "edge_list_path": "429009.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DiplodiaCorticola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Diplodia corticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiplodiaCorticola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "236234.protein.sequences.v11.5.fa",
		        "enrichment_path": "236234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "236234.protein.info.v11.5.txt",
		        "node_list_path": "236234.protein.complete.v11.5.txt"
		    }
		]
    )()

def SuccinivibrioDextrinosolvens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Succinivibrio dextrinosolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuccinivibrioDextrinosolvens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410676.protein.info.v11.5.txt",
		        "node_list_path": "1410676.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScardoviaInopinataJcm12537Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scardovia inopinata JCM 12537 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScardoviaInopinataJcm12537Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150468.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150468.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150468.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150468.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150468.protein.info.v11.5.txt",
		        "node_list_path": "1150468.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150468.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusSanaruensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus sanaruensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusSanaruensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1727163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1727163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1727163.clusters.proteins.v11.5.txt",
		        "sequence_path": "1727163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1727163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1727163.protein.info.v11.5.txt",
		        "node_list_path": "1727163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1727163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263001.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263001.protein.info.v11.5.txt",
		        "node_list_path": "1263001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaOrisC735(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris C735 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOrisC735", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "563008.protein.sequences.v11.5.fa",
		        "enrichment_path": "563008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563008.protein.info.v11.5.txt",
		        "node_list_path": "563008.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusKimbladiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kimbladii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKimbladiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218506.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218506.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218506.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218506.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218506.protein.info.v11.5.txt",
		        "node_list_path": "1218506.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218506.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAtrophaeusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus atrophaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAtrophaeusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "720555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "720555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "720555.clusters.proteins.v11.5.txt",
		        "sequence_path": "720555.protein.sequences.v11.5.fa",
		        "enrichment_path": "720555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "720555.protein.info.v11.5.txt",
		        "node_list_path": "720555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "720555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrococcusJejuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrococcus jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrococcusJejuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "399736.protein.sequences.v11.5.fa",
		        "enrichment_path": "399736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399736.protein.info.v11.5.txt",
		        "node_list_path": "399736.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpMrs1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. MRS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpMrs1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1451261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1451261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1451261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1451261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1451261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1451261.protein.info.v11.5.txt",
		        "node_list_path": "1451261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1451261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpRoot418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. Root418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpRoot418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736532.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736532.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736532.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736532.protein.info.v11.5.txt",
		        "node_list_path": "1736532.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736532.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorocebusSabaeusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorocebus sabaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorocebusSabaeusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "60711.clusters.info.v11.5.txt",
		        "cluster_tree_path": "60711.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "60711.clusters.proteins.v11.5.txt",
		        "sequence_path": "60711.protein.sequences.v11.5.fa",
		        "enrichment_path": "60711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60711.protein.info.v11.5.txt",
		        "node_list_path": "60711.cluster.nodes.v11.5.txt",
		        "edge_list_path": "60711.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FulvimarinaManganoxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fulvimarina manganoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FulvimarinaManganoxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "937218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "937218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "937218.clusters.proteins.v11.5.txt",
		        "sequence_path": "937218.protein.sequences.v11.5.fa",
		        "enrichment_path": "937218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937218.protein.info.v11.5.txt",
		        "node_list_path": "937218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "937218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpMedpeSwcel(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. MedPE-SWcel graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpMedpeSwcel", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1860086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860086.protein.info.v11.5.txt",
		        "node_list_path": "1860086.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaFalsenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella falsenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaFalsenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122983.protein.info.v11.5.txt",
		        "node_list_path": "1122983.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full4515Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_45_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full4515Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798649.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798649.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798649.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798649.protein.info.v11.5.txt",
		        "node_list_path": "1798649.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798649.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwb13912(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13912", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618574.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618574.protein.info.v11.5.txt",
		        "node_list_path": "1618574.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf24387Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_43_87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf24387Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619086.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619086.protein.info.v11.5.txt",
		        "node_list_path": "1619086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanoculleusSpSdb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus sp. SDB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusSpSdb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735326.protein.info.v11.5.txt",
		        "node_list_path": "1735326.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSp6378Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 63-78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSp6378Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895859.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895859.protein.info.v11.5.txt",
		        "node_list_path": "1895859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpU5lCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. U5L Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpU5lCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596152.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596152.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596152.clusters.proteins.v11.5.txt",
		        "sequence_path": "596152.protein.sequences.v11.5.fa",
		        "enrichment_path": "596152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596152.protein.info.v11.5.txt",
		        "node_list_path": "596152.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596152.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucorCircinelloidesFLusitanicusCbs27749Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. lusitanicus CBS 277.49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucorCircinelloidesFLusitanicusCbs27749Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "747725.clusters.info.v11.5.txt",
		        "cluster_tree_path": "747725.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "747725.clusters.proteins.v11.5.txt",
		        "sequence_path": "747725.protein.sequences.v11.5.fa",
		        "enrichment_path": "747725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747725.protein.info.v11.5.txt",
		        "node_list_path": "747725.cluster.nodes.v11.5.txt",
		        "edge_list_path": "747725.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PoeciliaReticulataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Poecilia reticulata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PoeciliaReticulataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8081.clusters.proteins.v11.5.txt",
		        "sequence_path": "8081.protein.sequences.v11.5.fa",
		        "enrichment_path": "8081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8081.protein.info.v11.5.txt",
		        "node_list_path": "8081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonasMacleodiiDeep(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Deep graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasMacleodiiDeep", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314275.protein.sequences.v11.5.fa",
		        "enrichment_path": "314275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314275.protein.info.v11.5.txt",
		        "node_list_path": "314275.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylomonasSp11bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas sp. 11b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasSp11bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1168169.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1168169.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1168169.clusters.proteins.v11.5.txt",
		        "sequence_path": "1168169.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168169.protein.info.v11.5.txt",
		        "node_list_path": "1168169.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1168169.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophusSpGwc25631Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophus sp. GWC2_56_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophusSpGwc25631Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802291.protein.info.v11.5.txt",
		        "node_list_path": "1802291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsplowo201Full5314(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO2_01_FULL_53_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201Full5314", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802628.protein.info.v11.5.txt",
		        "node_list_path": "1802628.protein.complete.v11.5.txt"
		    }
		]
    )()

def DimargarisCristalligena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dimargaris cristalligena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DimargarisCristalligena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "215637.protein.sequences.v11.5.fa",
		        "enrichment_path": "215637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215637.protein.info.v11.5.txt",
		        "node_list_path": "215637.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaPersicinaNbrc102418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia persicina NBRC 102418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaPersicinaNbrc102418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219360.protein.info.v11.5.txt",
		        "node_list_path": "1219360.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnt372Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT372 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnt372Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1169154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1169154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1169154.clusters.proteins.v11.5.txt",
		        "sequence_path": "1169154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169154.protein.info.v11.5.txt",
		        "node_list_path": "1169154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1169154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CribrihabitansMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cribrihabitans marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CribrihabitansMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227549.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227549.protein.info.v11.5.txt",
		        "node_list_path": "1227549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumRifcsphigho201Full5025(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium RIFCSPHIGHO2_01_FULL_50_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumRifcsphigho201Full5025", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817722.protein.info.v11.5.txt",
		        "node_list_path": "1817722.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsterYellows(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aster yellows graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsterYellows", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "322098.protein.sequences.v11.5.fa",
		        "enrichment_path": "322098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "322098.protein.info.v11.5.txt",
		        "node_list_path": "322098.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfipiaSpP5210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. P5210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaSpP5210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1429916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1429916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1429916.clusters.proteins.v11.5.txt",
		        "sequence_path": "1429916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1429916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1429916.protein.info.v11.5.txt",
		        "node_list_path": "1429916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1429916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwa25134(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_51_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwa25134", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797921.protein.info.v11.5.txt",
		        "node_list_path": "1797921.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkaliphilusTransvaalensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkaliphilus transvaalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkaliphilusTransvaalensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408422.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408422.protein.info.v11.5.txt",
		        "node_list_path": "1408422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SiccationiduransArizonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Siccationidurans arizonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SiccationiduransArizonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227077.protein.info.v11.5.txt",
		        "node_list_path": "1227077.protein.complete.v11.5.txt"
		    }
		]
    )()

def FalsirhodobacterSpAlg1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Falsirhodobacter sp. alg1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FalsirhodobacterSpAlg1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1472418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1472418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1472418.clusters.proteins.v11.5.txt",
		        "sequence_path": "1472418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1472418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1472418.protein.info.v11.5.txt",
		        "node_list_path": "1472418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1472418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4519Fw2642(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4519 (FW-2642) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4519Fw2642", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420914.protein.info.v11.5.txt",
		        "node_list_path": "1420914.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag341Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:341 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag341Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263019.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263019.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263019.protein.info.v11.5.txt",
		        "node_list_path": "1263019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachanceaThermotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachancea thermotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachanceaThermotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "381046.protein.sequences.v11.5.fa",
		        "enrichment_path": "381046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381046.protein.info.v11.5.txt",
		        "node_list_path": "381046.protein.complete.v11.5.txt"
		    }
		]
    )()

def KingellaNegevensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kingella negevensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KingellaNegevensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1522312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522312.protein.info.v11.5.txt",
		        "node_list_path": "1522312.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerminiimonasSpCnCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herminiimonas sp. CN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerminiimonasSpCnCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349818.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349818.protein.info.v11.5.txt",
		        "node_list_path": "1349818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinivibrioSiamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio siamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivibrioSiamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "414286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "414286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "414286.clusters.proteins.v11.5.txt",
		        "sequence_path": "414286.protein.sequences.v11.5.fa",
		        "enrichment_path": "414286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "414286.protein.info.v11.5.txt",
		        "node_list_path": "414286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "414286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusVeblenbacteriaBacteriumRifoxyc2Full4211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Veblenbacteria bacterium RIFOXYC2_FULL_42_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusVeblenbacteriaBacteriumRifoxyc2Full4211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802428.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802428.protein.info.v11.5.txt",
		        "node_list_path": "1802428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumJdfr77Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr77Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935107.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935107.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935107.protein.info.v11.5.txt",
		        "node_list_path": "1935107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeurosporaCrassaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neurospora crassa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeurosporaCrassaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5141.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5141.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5141.clusters.proteins.v11.5.txt",
		        "sequence_path": "5141.protein.sequences.v11.5.fa",
		        "enrichment_path": "5141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5141.protein.info.v11.5.txt",
		        "node_list_path": "5141.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5141.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HarpegnathosSaltatorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Harpegnathos saltator Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HarpegnathosSaltatorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "610380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "610380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "610380.clusters.proteins.v11.5.txt",
		        "sequence_path": "610380.protein.sequences.v11.5.fa",
		        "enrichment_path": "610380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "610380.protein.info.v11.5.txt",
		        "node_list_path": "610380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "610380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaGb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida GB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaGb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "76869.protein.sequences.v11.5.fa",
		        "enrichment_path": "76869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76869.protein.info.v11.5.txt",
		        "node_list_path": "76869.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDri13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DRI13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDri13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449126.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449126.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449126.protein.info.v11.5.txt",
		        "node_list_path": "1449126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpLappah95Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. LaPpAH95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpLappah95Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157632.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157632.protein.info.v11.5.txt",
		        "node_list_path": "1157632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736213.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736213.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736213.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736213.protein.info.v11.5.txt",
		        "node_list_path": "1736213.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736213.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterDokdonensisDsw74Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter dokdonensis DSW-74 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterDokdonensisDsw74Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1300349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1300349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1300349.clusters.proteins.v11.5.txt",
		        "sequence_path": "1300349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300349.protein.info.v11.5.txt",
		        "node_list_path": "1300349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1300349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMicrogenomatusAuricolaScgcAaa011E14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Microgenomatus auricola SCGC AAA011-E14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMicrogenomatusAuricolaScgcAaa011E14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1047003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1047003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1047003.protein.info.v11.5.txt",
		        "node_list_path": "1047003.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpEdens01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Edens01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpEdens01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1732020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1732020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1732020.protein.info.v11.5.txt",
		        "node_list_path": "1732020.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizoctoniaSolaniAg1Ib(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizoctonia solani AG-1 IB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizoctoniaSolaniAg1Ib", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1108050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1108050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1108050.protein.info.v11.5.txt",
		        "node_list_path": "1108050.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesBungoensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces bungoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesBungoensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "285568.protein.sequences.v11.5.fa",
		        "enrichment_path": "285568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285568.protein.info.v11.5.txt",
		        "node_list_path": "285568.protein.complete.v11.5.txt"
		    }
		]
    )()

def EpilithonimonasLactisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas lactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpilithonimonasLactisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "421072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "421072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "421072.clusters.proteins.v11.5.txt",
		        "sequence_path": "421072.protein.sequences.v11.5.fa",
		        "enrichment_path": "421072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "421072.protein.info.v11.5.txt",
		        "node_list_path": "421072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "421072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTerasakiellaMagneticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terasakiella magnetica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTerasakiellaMagneticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1867952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1867952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1867952.clusters.proteins.v11.5.txt",
		        "sequence_path": "1867952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1867952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1867952.protein.info.v11.5.txt",
		        "node_list_path": "1867952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1867952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusCorynebacterioides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus corynebacterioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusCorynebacterioides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53972.protein.sequences.v11.5.fa",
		        "enrichment_path": "53972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53972.protein.info.v11.5.txt",
		        "node_list_path": "53972.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquamicrobiumAerolatumDsm21857(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquamicrobium aerolatum DSM 21857 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquamicrobiumAerolatumDsm21857", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121003.protein.info.v11.5.txt",
		        "node_list_path": "1121003.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaAurisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Candida] auris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaAurisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "498019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "498019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "498019.clusters.proteins.v11.5.txt",
		        "sequence_path": "498019.protein.sequences.v11.5.fa",
		        "enrichment_path": "498019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498019.protein.info.v11.5.txt",
		        "node_list_path": "498019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "498019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquabacteriumSpNj1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquabacterium sp. NJ1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquabacteriumSpNj1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1538295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1538295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1538295.protein.info.v11.5.txt",
		        "node_list_path": "1538295.protein.complete.v11.5.txt"
		    }
		]
    )()

def OctadecabacterTemperatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Octadecabacter temperatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OctadecabacterTemperatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1458307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1458307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1458307.clusters.proteins.v11.5.txt",
		        "sequence_path": "1458307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458307.protein.info.v11.5.txt",
		        "node_list_path": "1458307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1458307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrenophoraTeres(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora teres graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrenophoraTeres", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53485.protein.sequences.v11.5.fa",
		        "enrichment_path": "53485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53485.protein.info.v11.5.txt",
		        "node_list_path": "53485.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaSpFb8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella sp. FB8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaSpFb8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1159870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1159870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1159870.clusters.proteins.v11.5.txt",
		        "sequence_path": "1159870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159870.protein.info.v11.5.txt",
		        "node_list_path": "1159870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1159870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HahellaChejuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hahella chejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HahellaChejuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349521.protein.sequences.v11.5.fa",
		        "enrichment_path": "349521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349521.protein.info.v11.5.txt",
		        "node_list_path": "349521.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesVirginiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces virginiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesVirginiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1961.clusters.proteins.v11.5.txt",
		        "sequence_path": "1961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961.protein.info.v11.5.txt",
		        "node_list_path": "1961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanibacterCorallicolaNbrc107790Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janibacter corallicola NBRC 107790 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterCorallicolaNbrc107790Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216969.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216969.protein.info.v11.5.txt",
		        "node_list_path": "1216969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GluconobacterRoseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterRoseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "586239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "586239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "586239.clusters.proteins.v11.5.txt",
		        "sequence_path": "586239.protein.sequences.v11.5.fa",
		        "enrichment_path": "586239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "586239.protein.info.v11.5.txt",
		        "node_list_path": "586239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "586239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumChimaera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium chimaera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumChimaera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "222805.protein.sequences.v11.5.fa",
		        "enrichment_path": "222805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "222805.protein.info.v11.5.txt",
		        "node_list_path": "222805.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterSpMit016242(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT 01-6242 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSpMit016242", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "222136.protein.sequences.v11.5.fa",
		        "enrichment_path": "222136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "222136.protein.info.v11.5.txt",
		        "node_list_path": "222136.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavihumibacterSpZg627(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavihumibacter sp. ZG627 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavihumibacterSpZg627", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463156.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463156.protein.info.v11.5.txt",
		        "node_list_path": "1463156.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumAidingenseJcm13560(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum aidingense JCM 13560 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumAidingenseJcm13560", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230454.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230454.protein.info.v11.5.txt",
		        "node_list_path": "1230454.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaPutidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema putidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPutidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "221027.clusters.info.v11.5.txt",
		        "cluster_tree_path": "221027.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "221027.clusters.proteins.v11.5.txt",
		        "sequence_path": "221027.protein.sequences.v11.5.fa",
		        "enrichment_path": "221027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221027.protein.info.v11.5.txt",
		        "node_list_path": "221027.cluster.nodes.v11.5.txt",
		        "edge_list_path": "221027.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsphigho202Full5223Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_52_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full5223Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802274.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802274.protein.info.v11.5.txt",
		        "node_list_path": "1802274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusOralisAtcc35037Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis ATCC35037 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOralisAtcc35037Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655813.clusters.proteins.v11.5.txt",
		        "sequence_path": "655813.protein.sequences.v11.5.fa",
		        "enrichment_path": "655813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655813.protein.info.v11.5.txt",
		        "node_list_path": "655813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaBuccalisDnf00985Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccalis DNF00985 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBuccalisDnf00985Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1401078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1401078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1401078.clusters.proteins.v11.5.txt",
		        "sequence_path": "1401078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401078.protein.info.v11.5.txt",
		        "node_list_path": "1401078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1401078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioTubiashii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio tubiashii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioTubiashii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1051646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051646.protein.info.v11.5.txt",
		        "node_list_path": "1051646.protein.complete.v11.5.txt"
		    }
		]
    )()

def RahnellaAquatilisHx2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rahnella aquatilis HX2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RahnellaAquatilisHx2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1151116.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151116.protein.info.v11.5.txt",
		        "node_list_path": "1151116.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumStanieri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium stanieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumStanieri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1042375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042375.protein.info.v11.5.txt",
		        "node_list_path": "1042375.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterRoseosalivariusDsm11622Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter roseosalivarius DSM 11622 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterRoseosalivariusDsm11622Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "645990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "645990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "645990.clusters.proteins.v11.5.txt",
		        "sequence_path": "645990.protein.sequences.v11.5.fa",
		        "enrichment_path": "645990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645990.protein.info.v11.5.txt",
		        "node_list_path": "645990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "645990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacillusCapsulatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus capsulatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusCapsulatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120931.protein.info.v11.5.txt",
		        "node_list_path": "1120931.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusFrigens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus frigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusFrigens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121380.protein.info.v11.5.txt",
		        "node_list_path": "1121380.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfallasArcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfallas arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfallasArcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "341036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "341036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "341036.clusters.proteins.v11.5.txt",
		        "sequence_path": "341036.protein.sequences.v11.5.fa",
		        "enrichment_path": "341036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "341036.protein.info.v11.5.txt",
		        "node_list_path": "341036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "341036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaVarigenaUsdaarsusmarc1296(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia varigena USDAARSUSMARC1296 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaVarigenaUsdaarsusmarc1296", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1433287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1433287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1433287.protein.info.v11.5.txt",
		        "node_list_path": "1433287.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenuibacillusMultivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenuibacillus multivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenuibacillusMultivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "237069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "237069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "237069.clusters.proteins.v11.5.txt",
		        "sequence_path": "237069.protein.sequences.v11.5.fa",
		        "enrichment_path": "237069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237069.protein.info.v11.5.txt",
		        "node_list_path": "237069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "237069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaArizonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia arizonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaArizonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1141647.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1141647.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1141647.clusters.proteins.v11.5.txt",
		        "sequence_path": "1141647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141647.protein.info.v11.5.txt",
		        "node_list_path": "1141647.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1141647.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpOk281(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. OK281 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpOk281", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881067.protein.info.v11.5.txt",
		        "node_list_path": "1881067.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeovibrioSpL21acebesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geovibrio sp. L21AceBES Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeovibrioSpL21acebesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304888.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304888.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304888.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304888.protein.info.v11.5.txt",
		        "node_list_path": "1304888.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304888.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NicotianaTomentosiformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nicotiana tomentosiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NicotianaTomentosiformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4098.clusters.proteins.v11.5.txt",
		        "sequence_path": "4098.protein.sequences.v11.5.fa",
		        "enrichment_path": "4098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4098.protein.info.v11.5.txt",
		        "node_list_path": "4098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptotermesSecundus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptotermes secundus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptotermesSecundus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "105785.protein.sequences.v11.5.fa",
		        "enrichment_path": "105785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105785.protein.info.v11.5.txt",
		        "node_list_path": "105785.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumBarnesii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum barnesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumBarnesii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "760154.protein.sequences.v11.5.fa",
		        "enrichment_path": "760154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "760154.protein.info.v11.5.txt",
		        "node_list_path": "760154.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusSclerotiicarbonariusCbs121057Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sclerotiicarbonarius CBS 121057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusSclerotiicarbonariusCbs121057Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1448318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1448318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1448318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1448318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448318.protein.info.v11.5.txt",
		        "node_list_path": "1448318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1448318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FluoribacterDumoffiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fluoribacter dumoffii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FluoribacterDumoffiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094715.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094715.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094715.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094715.protein.info.v11.5.txt",
		        "node_list_path": "1094715.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094715.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGhanaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces ghanaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGhanaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "566461.clusters.info.v11.5.txt",
		        "cluster_tree_path": "566461.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "566461.clusters.proteins.v11.5.txt",
		        "sequence_path": "566461.protein.sequences.v11.5.fa",
		        "enrichment_path": "566461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "566461.protein.info.v11.5.txt",
		        "node_list_path": "566461.cluster.nodes.v11.5.txt",
		        "edge_list_path": "566461.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HistoplasmaCapsulatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HistoplasmaCapsulatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5037.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5037.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5037.clusters.proteins.v11.5.txt",
		        "sequence_path": "5037.protein.sequences.v11.5.fa",
		        "enrichment_path": "5037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5037.protein.info.v11.5.txt",
		        "node_list_path": "5037.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5037.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulosilyticumRuminicolaJcm14822Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulosilyticum ruminicola JCM 14822 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulosilyticumRuminicolaJcm14822Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1294025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1294025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1294025.clusters.proteins.v11.5.txt",
		        "sequence_path": "1294025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294025.protein.info.v11.5.txt",
		        "node_list_path": "1294025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1294025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldanaerobacterSubterraneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldanaerobacter subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldanaerobacterSubterraneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "273068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "273068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "273068.clusters.proteins.v11.5.txt",
		        "sequence_path": "273068.protein.sequences.v11.5.fa",
		        "enrichment_path": "273068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273068.protein.info.v11.5.txt",
		        "node_list_path": "273068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "273068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpHmsc065f10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. HMSC065F10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpHmsc065f10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739394.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739394.protein.info.v11.5.txt",
		        "node_list_path": "1739394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumBrachyCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium brachy Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumBrachyCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321814.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321814.protein.info.v11.5.txt",
		        "node_list_path": "1321814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParvimonasSpKa00067Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parvimonas sp. KA00067 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvimonasSpKa00067Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1588755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1588755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1588755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1588755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588755.protein.info.v11.5.txt",
		        "node_list_path": "1588755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1588755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisXylanicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis xylanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisXylanicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "589385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "589385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "589385.clusters.proteins.v11.5.txt",
		        "sequence_path": "589385.protein.sequences.v11.5.fa",
		        "enrichment_path": "589385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "589385.protein.info.v11.5.txt",
		        "node_list_path": "589385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "589385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisElegans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis elegans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisElegans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6239.protein.sequences.v11.5.fa",
		        "enrichment_path": "6239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6239.protein.info.v11.5.txt",
		        "node_list_path": "6239.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSasangenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sasangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSasangenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121896.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121896.protein.info.v11.5.txt",
		        "node_list_path": "1121896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpOxb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. OxB-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpOxb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "98228.protein.sequences.v11.5.fa",
		        "enrichment_path": "98228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "98228.protein.info.v11.5.txt",
		        "node_list_path": "98228.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterPineti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter pineti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterPineti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1391627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391627.protein.info.v11.5.txt",
		        "node_list_path": "1391627.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesMutabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces mutabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesMutabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67332.clusters.proteins.v11.5.txt",
		        "sequence_path": "67332.protein.sequences.v11.5.fa",
		        "enrichment_path": "67332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67332.protein.info.v11.5.txt",
		        "node_list_path": "67332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidithiobacillusThiooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus thiooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithiobacillusThiooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "637390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "637390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "637390.clusters.proteins.v11.5.txt",
		        "sequence_path": "637390.protein.sequences.v11.5.fa",
		        "enrichment_path": "637390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637390.protein.info.v11.5.txt",
		        "node_list_path": "637390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "637390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlexilineaFlocculi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flexilinea flocculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlexilineaFlocculi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1678840.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678840.protein.info.v11.5.txt",
		        "node_list_path": "1678840.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylocystisSpSb2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylocystis sp. SB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocystisSpSb2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743836.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743836.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743836.clusters.proteins.v11.5.txt",
		        "sequence_path": "743836.protein.sequences.v11.5.fa",
		        "enrichment_path": "743836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743836.protein.info.v11.5.txt",
		        "node_list_path": "743836.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743836.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxValerianellaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax valerianellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxValerianellaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "187868.clusters.info.v11.5.txt",
		        "cluster_tree_path": "187868.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "187868.clusters.proteins.v11.5.txt",
		        "sequence_path": "187868.protein.sequences.v11.5.fa",
		        "enrichment_path": "187868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "187868.protein.info.v11.5.txt",
		        "node_list_path": "187868.cluster.nodes.v11.5.txt",
		        "edge_list_path": "187868.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPachastrellaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pachastrellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPachastrellaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "254161.clusters.info.v11.5.txt",
		        "cluster_tree_path": "254161.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "254161.clusters.proteins.v11.5.txt",
		        "sequence_path": "254161.protein.sequences.v11.5.fa",
		        "enrichment_path": "254161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "254161.protein.info.v11.5.txt",
		        "node_list_path": "254161.cluster.nodes.v11.5.txt",
		        "edge_list_path": "254161.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaHelicoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma helicoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaHelicoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216938.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216938.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216938.clusters.proteins.v11.5.txt",
		        "sequence_path": "216938.protein.sequences.v11.5.fa",
		        "enrichment_path": "216938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216938.protein.info.v11.5.txt",
		        "node_list_path": "216938.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216938.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalodesulfovibrioMarinisediminisDsm17456(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halodesulfovibrio marinisediminis DSM 17456 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalodesulfovibrioMarinisediminisDsm17456", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121457.protein.info.v11.5.txt",
		        "node_list_path": "1121457.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsphigho202Full4416Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO2_02_FULL_44_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho202Full4416Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797862.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797862.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797862.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797862.protein.info.v11.5.txt",
		        "node_list_path": "1797862.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797862.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaRubidaea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia rubidaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaRubidaea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61652.protein.sequences.v11.5.fa",
		        "enrichment_path": "61652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61652.protein.info.v11.5.txt",
		        "node_list_path": "61652.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychroserpensDamuponensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens damuponensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroserpensDamuponensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "943936.protein.sequences.v11.5.fa",
		        "enrichment_path": "943936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "943936.protein.info.v11.5.txt",
		        "node_list_path": "943936.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeonGw2011Ar5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return archaeon GW2011_AR5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeonGw2011Ar5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1579367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579367.protein.info.v11.5.txt",
		        "node_list_path": "1579367.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasPanacihumiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas panacihumi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasPanacihumiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "676599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "676599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "676599.clusters.proteins.v11.5.txt",
		        "sequence_path": "676599.protein.sequences.v11.5.fa",
		        "enrichment_path": "676599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "676599.protein.info.v11.5.txt",
		        "node_list_path": "676599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "676599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisSpAc460(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC460 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisSpAc460", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1282360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282360.protein.info.v11.5.txt",
		        "node_list_path": "1282360.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasVranovensisDsm16006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas vranovensis DSM 16006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasVranovensisDsm16006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1292031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292031.protein.info.v11.5.txt",
		        "node_list_path": "1292031.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichurisTrichiuraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichuris trichiura Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichurisTrichiuraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36087.clusters.proteins.v11.5.txt",
		        "sequence_path": "36087.protein.sequences.v11.5.fa",
		        "enrichment_path": "36087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36087.protein.info.v11.5.txt",
		        "node_list_path": "36087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhasianusColchicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phasianus colchicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhasianusColchicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9054.protein.sequences.v11.5.fa",
		        "enrichment_path": "9054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9054.protein.info.v11.5.txt",
		        "node_list_path": "9054.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnr698Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNR698 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnr698Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206101.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206101.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206101.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206101.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206101.protein.info.v11.5.txt",
		        "node_list_path": "1206101.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206101.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobacterArenaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacter arenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobacterArenaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123360.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123360.protein.info.v11.5.txt",
		        "node_list_path": "1123360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaPallidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora pallida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaPallidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "145854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "145854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "145854.clusters.proteins.v11.5.txt",
		        "sequence_path": "145854.protein.sequences.v11.5.fa",
		        "enrichment_path": "145854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "145854.protein.info.v11.5.txt",
		        "node_list_path": "145854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "145854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SorangiumCellulosumSoCe56Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sorangium cellulosum So ce56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SorangiumCellulosumSoCe56Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "448385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "448385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "448385.clusters.proteins.v11.5.txt",
		        "sequence_path": "448385.protein.sequences.v11.5.fa",
		        "enrichment_path": "448385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "448385.protein.info.v11.5.txt",
		        "node_list_path": "448385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "448385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterSpEp1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. EP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSpEp1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1665555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1665555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1665555.protein.info.v11.5.txt",
		        "node_list_path": "1665555.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusVietnamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus vietnamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusVietnamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351656.protein.sequences.v11.5.fa",
		        "enrichment_path": "351656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351656.protein.info.v11.5.txt",
		        "node_list_path": "351656.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasParafulva(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas parafulva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasParafulva", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1215114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215114.protein.info.v11.5.txt",
		        "node_list_path": "1215114.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinokineosporaInagensisDsm44258(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora inagensis DSM 44258 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinokineosporaInagensisDsm44258", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120935.protein.info.v11.5.txt",
		        "node_list_path": "1120935.protein.complete.v11.5.txt"
		    }
		]
    )()

def WinogradskyellaSpJ142(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Winogradskyella sp. J14-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinogradskyellaSpJ142", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1936080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1936080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1936080.protein.info.v11.5.txt",
		        "node_list_path": "1936080.protein.complete.v11.5.txt"
		    }
		]
    )()

def KlebsiellaPneumoniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaPneumoniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573.protein.sequences.v11.5.fa",
		        "enrichment_path": "573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573.protein.info.v11.5.txt",
		        "node_list_path": "573.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioAlginolyticus40b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus 40B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioAlginolyticus40b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "674977.protein.sequences.v11.5.fa",
		        "enrichment_path": "674977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "674977.protein.info.v11.5.txt",
		        "node_list_path": "674977.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophusAciditrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophus aciditrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophusAciditrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56780.clusters.proteins.v11.5.txt",
		        "sequence_path": "56780.protein.sequences.v11.5.fa",
		        "enrichment_path": "56780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56780.protein.info.v11.5.txt",
		        "node_list_path": "56780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonadaceaeBacteriumH1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonadaceaeBacteriumH1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1458427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458427.protein.info.v11.5.txt",
		        "node_list_path": "1458427.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumMethylpentosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium methylpentosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumMethylpentosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "537013.protein.sequences.v11.5.fa",
		        "enrichment_path": "537013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537013.protein.info.v11.5.txt",
		        "node_list_path": "537013.protein.complete.v11.5.txt"
		    }
		]
    )()

def KordiimonasGwangyangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kordiimonas gwangyangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KordiimonasGwangyangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122137.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122137.protein.info.v11.5.txt",
		        "node_list_path": "1122137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumPapyrosolvensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium papyrosolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPapyrosolvensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "588581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "588581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "588581.clusters.proteins.v11.5.txt",
		        "sequence_path": "588581.protein.sequences.v11.5.fa",
		        "enrichment_path": "588581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588581.protein.info.v11.5.txt",
		        "node_list_path": "588581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "588581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BryobacterAggregatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bryobacter aggregatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BryobacterAggregatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1340493.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1340493.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1340493.clusters.proteins.v11.5.txt",
		        "sequence_path": "1340493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1340493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1340493.protein.info.v11.5.txt",
		        "node_list_path": "1340493.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1340493.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArmillariaGallicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Armillaria gallica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmillariaGallicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47427.clusters.proteins.v11.5.txt",
		        "sequence_path": "47427.protein.sequences.v11.5.fa",
		        "enrichment_path": "47427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47427.protein.info.v11.5.txt",
		        "node_list_path": "47427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PiromycesSpE2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Piromyces sp. E2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiromycesSpE2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "73868.protein.sequences.v11.5.fa",
		        "enrichment_path": "73868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "73868.protein.info.v11.5.txt",
		        "node_list_path": "73868.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillibacterSpCag2416221(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. CAG:241_62_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSpCag2416221", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897012.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897012.protein.info.v11.5.txt",
		        "node_list_path": "1897012.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaSpOralTaxon212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. oral taxon 212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaSpOralTaxon212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "712357.protein.sequences.v11.5.fa",
		        "enrichment_path": "712357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712357.protein.info.v11.5.txt",
		        "node_list_path": "712357.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpKc8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. KC8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpKc8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1030157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1030157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1030157.clusters.proteins.v11.5.txt",
		        "sequence_path": "1030157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1030157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1030157.protein.info.v11.5.txt",
		        "node_list_path": "1030157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1030157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpOrs3324Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpOrs3324Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "408180.clusters.info.v11.5.txt",
		        "cluster_tree_path": "408180.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "408180.clusters.proteins.v11.5.txt",
		        "sequence_path": "408180.protein.sequences.v11.5.fa",
		        "enrichment_path": "408180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408180.protein.info.v11.5.txt",
		        "node_list_path": "408180.cluster.nodes.v11.5.txt",
		        "edge_list_path": "408180.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumKocuriiJcm14978(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum kocurii JCM 14978 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumKocuriiJcm14978", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230456.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230456.protein.info.v11.5.txt",
		        "node_list_path": "1230456.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioHungateiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio hungatei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioHungateiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "185008.clusters.info.v11.5.txt",
		        "cluster_tree_path": "185008.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "185008.clusters.proteins.v11.5.txt",
		        "sequence_path": "185008.protein.sequences.v11.5.fa",
		        "enrichment_path": "185008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "185008.protein.info.v11.5.txt",
		        "node_list_path": "185008.cluster.nodes.v11.5.txt",
		        "edge_list_path": "185008.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumCg2306842Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium CG2_30_68_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumCg2306842Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805051.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805051.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805051.protein.info.v11.5.txt",
		        "node_list_path": "1805051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumMediterraneenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium mediterraneense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumMediterraneenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805472.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805472.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805472.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805472.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805472.protein.info.v11.5.txt",
		        "node_list_path": "1805472.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805472.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpRoot655(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root655 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpRoot655", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736578.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736578.protein.info.v11.5.txt",
		        "node_list_path": "1736578.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaPurisNbrc108233Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia puris NBRC 108233 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaPurisNbrc108233Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210090.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210090.protein.info.v11.5.txt",
		        "node_list_path": "1210090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaSpRac05Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. RAC05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpRac05Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1842539.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1842539.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1842539.clusters.proteins.v11.5.txt",
		        "sequence_path": "1842539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842539.protein.info.v11.5.txt",
		        "node_list_path": "1842539.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1842539.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EhrlichiaRuminantium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia ruminantium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EhrlichiaRuminantium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "254945.protein.sequences.v11.5.fa",
		        "enrichment_path": "254945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "254945.protein.info.v11.5.txt",
		        "node_list_path": "254945.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiohalocapsaSpMl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiohalocapsa sp. ML1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiohalocapsaSpMl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1431688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1431688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1431688.protein.info.v11.5.txt",
		        "node_list_path": "1431688.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpUrha0032(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. URHA0032 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpUrha0032", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380388.protein.info.v11.5.txt",
		        "node_list_path": "1380388.protein.complete.v11.5.txt"
		    }
		]
    )()

def OctadecabacterAntarcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Octadecabacter antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OctadecabacterAntarcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391626.clusters.proteins.v11.5.txt",
		        "sequence_path": "391626.protein.sequences.v11.5.fa",
		        "enrichment_path": "391626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391626.protein.info.v11.5.txt",
		        "node_list_path": "391626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfuromusaKysingiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromusa kysingii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromusaKysingiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37625.clusters.proteins.v11.5.txt",
		        "sequence_path": "37625.protein.sequences.v11.5.fa",
		        "enrichment_path": "37625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37625.protein.info.v11.5.txt",
		        "node_list_path": "37625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidihalobacterProsperus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidihalobacter prosperus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidihalobacterProsperus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "160660.protein.sequences.v11.5.fa",
		        "enrichment_path": "160660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "160660.protein.info.v11.5.txt",
		        "node_list_path": "160660.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFischerbacteriaBacteriumRbg13378Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fischerbacteria bacterium RBG_13_37_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFischerbacteriaBacteriumRbg13378Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817863.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817863.protein.info.v11.5.txt",
		        "node_list_path": "1817863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferSpQ7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer sp. Q7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferSpQ7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1785091.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1785091.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1785091.clusters.proteins.v11.5.txt",
		        "sequence_path": "1785091.protein.sequences.v11.5.fa",
		        "enrichment_path": "1785091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1785091.protein.info.v11.5.txt",
		        "node_list_path": "1785091.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1785091.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalopenitusMalekzadehiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halopenitus malekzadehii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalopenitusMalekzadehiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267564.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267564.protein.info.v11.5.txt",
		        "node_list_path": "1267564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaAcidivoransNbrc108247Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia acidivorans NBRC 108247 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAcidivoransNbrc108247Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210062.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210062.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210062.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210062.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210062.protein.info.v11.5.txt",
		        "node_list_path": "1210062.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210062.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusEiseniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus eiseniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusEiseniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762947.clusters.proteins.v11.5.txt",
		        "sequence_path": "762947.protein.sequences.v11.5.fa",
		        "enrichment_path": "762947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762947.protein.info.v11.5.txt",
		        "node_list_path": "762947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpL1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. L1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpL1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1134413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134413.protein.info.v11.5.txt",
		        "node_list_path": "1134413.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCochlearium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cochlearium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCochlearium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1494.protein.info.v11.5.txt",
		        "node_list_path": "1494.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasVancouverensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas vancouverensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasVancouverensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "95300.protein.sequences.v11.5.fa",
		        "enrichment_path": "95300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "95300.protein.info.v11.5.txt",
		        "node_list_path": "95300.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaVinsoniiSubspArupensisOk94513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella vinsonii subsp. arupensis OK-94-513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaVinsoniiSubspArupensisOk94513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094562.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094562.protein.info.v11.5.txt",
		        "node_list_path": "1094562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermotogaMaritima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaMaritima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243274.protein.sequences.v11.5.fa",
		        "enrichment_path": "243274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243274.protein.info.v11.5.txt",
		        "node_list_path": "243274.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSlackiiAtcc49928Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces slackii ATCC 49928 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSlackiiAtcc49928Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278298.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278298.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278298.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278298.protein.info.v11.5.txt",
		        "node_list_path": "1278298.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278298.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeolectaIrregularisDah3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neolecta irregularis DAH-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeolectaIrregularisDah3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1198029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198029.protein.info.v11.5.txt",
		        "node_list_path": "1198029.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLloydbacteriaBacteriumRifcsplowo201Full5020(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPLOWO2_01_FULL_50_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsplowo201Full5020", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798665.protein.info.v11.5.txt",
		        "node_list_path": "1798665.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaSpTm1040(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. TM1040 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaSpTm1040", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "292414.protein.sequences.v11.5.fa",
		        "enrichment_path": "292414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292414.protein.info.v11.5.txt",
		        "node_list_path": "292414.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalipigerMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salipiger marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalipigerMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "555512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "555512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "555512.clusters.proteins.v11.5.txt",
		        "sequence_path": "555512.protein.sequences.v11.5.fa",
		        "enrichment_path": "555512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555512.protein.info.v11.5.txt",
		        "node_list_path": "555512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "555512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpongiibacterMarinusDsm19753Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spongiibacter marinus DSM 19753 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpongiibacterMarinusDsm19753Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122224.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122224.protein.info.v11.5.txt",
		        "node_list_path": "1122224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudorhodoferaxSpLeaf265(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf265 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodoferaxSpLeaf265", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736315.protein.info.v11.5.txt",
		        "node_list_path": "1736315.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumScgcAaa044D11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA044-D11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumScgcAaa044D11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "938518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "938518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "938518.clusters.proteins.v11.5.txt",
		        "sequence_path": "938518.protein.sequences.v11.5.fa",
		        "enrichment_path": "938518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938518.protein.info.v11.5.txt",
		        "node_list_path": "938518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "938518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfuromonadalesBacteriumGwc26120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromonadales bacterium GWC2_61_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromonadalesBacteriumGwc26120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797916.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797916.protein.info.v11.5.txt",
		        "node_list_path": "1797916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaMucosaAtcc25996(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria mucosa ATCC25996 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaMucosaAtcc25996", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546266.protein.sequences.v11.5.fa",
		        "enrichment_path": "546266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546266.protein.info.v11.5.txt",
		        "node_list_path": "546266.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixibacteriaBacterium448495Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium 4484_95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixibacteriaBacterium448495Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1970781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1970781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1970781.clusters.proteins.v11.5.txt",
		        "sequence_path": "1970781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970781.protein.info.v11.5.txt",
		        "node_list_path": "1970781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1970781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalisediminibacteriumHaloalkalitoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salisediminibacterium haloalkalitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalisediminibacteriumHaloalkalitoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1464123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1464123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1464123.clusters.proteins.v11.5.txt",
		        "sequence_path": "1464123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1464123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1464123.protein.info.v11.5.txt",
		        "node_list_path": "1464123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1464123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OpitutaceaeBacteriumTav5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TAV5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpitutaceaeBacteriumTav5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "794903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "794903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "794903.clusters.proteins.v11.5.txt",
		        "sequence_path": "794903.protein.sequences.v11.5.fa",
		        "enrichment_path": "794903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "794903.protein.info.v11.5.txt",
		        "node_list_path": "794903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "794903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraMicroaerophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira microaerophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraMicroaerophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "406020.protein.sequences.v11.5.fa",
		        "enrichment_path": "406020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406020.protein.info.v11.5.txt",
		        "node_list_path": "406020.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpMb2021Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MB2021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpMb2021Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408303.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408303.protein.info.v11.5.txt",
		        "node_list_path": "1408303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaIniecta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia iniecta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaIniecta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1560201.protein.sequences.v11.5.fa",
		        "enrichment_path": "1560201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1560201.protein.info.v11.5.txt",
		        "node_list_path": "1560201.protein.complete.v11.5.txt"
		    }
		]
    )()

def MacleayaCordataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Macleaya cordata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacleayaCordataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56857.clusters.proteins.v11.5.txt",
		        "sequence_path": "56857.protein.sequences.v11.5.fa",
		        "enrichment_path": "56857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56857.protein.info.v11.5.txt",
		        "node_list_path": "56857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanospirillumMultiglobuliferum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum multiglobuliferum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanospirillumMultiglobuliferum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "64969.protein.sequences.v11.5.fa",
		        "enrichment_path": "64969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64969.protein.info.v11.5.txt",
		        "node_list_path": "64969.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRedseaS12B4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium REDSEA-S12_B4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRedseaS12B4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811664.protein.info.v11.5.txt",
		        "node_list_path": "1811664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumHigginsianumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum higginsianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumHigginsianumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "80884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "80884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "80884.clusters.proteins.v11.5.txt",
		        "sequence_path": "80884.protein.sequences.v11.5.fa",
		        "enrichment_path": "80884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80884.protein.info.v11.5.txt",
		        "node_list_path": "80884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "80884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProcaviaCapensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Procavia capensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProcaviaCapensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9813.protein.sequences.v11.5.fa",
		        "enrichment_path": "9813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9813.protein.info.v11.5.txt",
		        "node_list_path": "9813.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtopobacterPhocaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobacter phocae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobacterPhocaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336234.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336234.protein.info.v11.5.txt",
		        "node_list_path": "1336234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaThermophilaDsm6578Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta thermophila DSM 6578 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaThermophilaDsm6578Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "869211.clusters.info.v11.5.txt",
		        "cluster_tree_path": "869211.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "869211.clusters.proteins.v11.5.txt",
		        "sequence_path": "869211.protein.sequences.v11.5.fa",
		        "enrichment_path": "869211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869211.protein.info.v11.5.txt",
		        "node_list_path": "869211.cluster.nodes.v11.5.txt",
		        "edge_list_path": "869211.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRoot1433d1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root1433D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRoot1433d1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736463.protein.info.v11.5.txt",
		        "node_list_path": "1736463.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasSpNm58Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasSpNm58Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "200126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "200126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "200126.clusters.proteins.v11.5.txt",
		        "sequence_path": "200126.protein.sequences.v11.5.fa",
		        "enrichment_path": "200126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200126.protein.info.v11.5.txt",
		        "node_list_path": "200126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "200126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminobacterAmylophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminobacter amylophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminobacterAmylophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "867.clusters.proteins.v11.5.txt",
		        "sequence_path": "867.protein.sequences.v11.5.fa",
		        "enrichment_path": "867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867.protein.info.v11.5.txt",
		        "node_list_path": "867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpAa23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. AA23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpAa23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1854058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1854058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1854058.protein.info.v11.5.txt",
		        "node_list_path": "1854058.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermomonasFusca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermomonas fusca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermomonasFusca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123377.protein.info.v11.5.txt",
		        "node_list_path": "1123377.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfifellaPfennigiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Afifella pfennigii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfifellaPfennigiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120956.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120956.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120956.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120956.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120956.protein.info.v11.5.txt",
		        "node_list_path": "1120956.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120956.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudohongiellaActicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudohongiella acticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudohongiellaActicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1524254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1524254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1524254.protein.info.v11.5.txt",
		        "node_list_path": "1524254.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpNml130628(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML130628 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpNml130628", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906333.protein.info.v11.5.txt",
		        "node_list_path": "1906333.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerrovumSpJa12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferrovum sp. JA12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrovumSpJa12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1356299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1356299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1356299.protein.info.v11.5.txt",
		        "node_list_path": "1356299.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElysiaChloroticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elysia chlorotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElysiaChloroticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "188477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "188477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "188477.clusters.proteins.v11.5.txt",
		        "sequence_path": "188477.protein.sequences.v11.5.fa",
		        "enrichment_path": "188477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188477.protein.info.v11.5.txt",
		        "node_list_path": "188477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "188477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaSpBmg536(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. BMG5.36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpBmg536", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834512.protein.info.v11.5.txt",
		        "node_list_path": "1834512.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesBacteriumScgcAaa011B20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates bacterium SCGC AAA011-B20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesBacteriumScgcAaa011B20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1104610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1104610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1104610.clusters.proteins.v11.5.txt",
		        "sequence_path": "1104610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104610.protein.info.v11.5.txt",
		        "node_list_path": "1104610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1104610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumDecipiensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium decipiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumDecipiensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1430326.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1430326.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1430326.clusters.proteins.v11.5.txt",
		        "sequence_path": "1430326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1430326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1430326.protein.info.v11.5.txt",
		        "node_list_path": "1430326.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1430326.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudophaeobacterArcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudophaeobacter arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudophaeobacterArcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999550.protein.sequences.v11.5.fa",
		        "enrichment_path": "999550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999550.protein.info.v11.5.txt",
		        "node_list_path": "999550.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumParvumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium parvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumParvumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "796945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "796945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "796945.clusters.proteins.v11.5.txt",
		        "sequence_path": "796945.protein.sequences.v11.5.fa",
		        "enrichment_path": "796945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796945.protein.info.v11.5.txt",
		        "node_list_path": "796945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "796945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterCuticularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter cuticularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterCuticularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47311.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47311.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47311.clusters.proteins.v11.5.txt",
		        "sequence_path": "47311.protein.sequences.v11.5.fa",
		        "enrichment_path": "47311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47311.protein.info.v11.5.txt",
		        "node_list_path": "47311.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47311.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesOlindensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces olindensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesOlindensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "358823.protein.sequences.v11.5.fa",
		        "enrichment_path": "358823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "358823.protein.info.v11.5.txt",
		        "node_list_path": "358823.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocGasicomitatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gasicomitatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocGasicomitatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762550.protein.sequences.v11.5.fa",
		        "enrichment_path": "762550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762550.protein.info.v11.5.txt",
		        "node_list_path": "762550.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumContaminans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium contaminans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumContaminans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423959.protein.info.v11.5.txt",
		        "node_list_path": "1423959.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpFukuswis1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. FUKUSWIS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpFukuswis1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379701.protein.info.v11.5.txt",
		        "node_list_path": "1379701.protein.complete.v11.5.txt"
		    }
		]
    )()

def BosTaurus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bos taurus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BosTaurus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9913.protein.sequences.v11.5.fa",
		        "enrichment_path": "9913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9913.protein.info.v11.5.txt",
		        "node_list_path": "9913.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaArcticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaArcticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1470200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1470200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1470200.clusters.proteins.v11.5.txt",
		        "sequence_path": "1470200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470200.protein.info.v11.5.txt",
		        "node_list_path": "1470200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1470200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaRubidaeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia rubidaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaRubidaeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61652.clusters.proteins.v11.5.txt",
		        "sequence_path": "61652.protein.sequences.v11.5.fa",
		        "enrichment_path": "61652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61652.protein.info.v11.5.txt",
		        "node_list_path": "61652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifoxyc2Full4719Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYC2_FULL_47_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyc2Full4719Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802424.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802424.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802424.protein.info.v11.5.txt",
		        "node_list_path": "1802424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioPiezophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio piezophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioPiezophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1322246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1322246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1322246.clusters.proteins.v11.5.txt",
		        "sequence_path": "1322246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1322246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1322246.protein.info.v11.5.txt",
		        "node_list_path": "1322246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1322246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EhrlichiaMinasensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia minasensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EhrlichiaMinasensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1242993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1242993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1242993.clusters.proteins.v11.5.txt",
		        "sequence_path": "1242993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1242993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1242993.protein.info.v11.5.txt",
		        "node_list_path": "1242993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1242993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BabelaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Babela massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BabelaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "673862.clusters.info.v11.5.txt",
		        "cluster_tree_path": "673862.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "673862.clusters.proteins.v11.5.txt",
		        "sequence_path": "673862.protein.sequences.v11.5.fa",
		        "enrichment_path": "673862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "673862.protein.info.v11.5.txt",
		        "node_list_path": "673862.cluster.nodes.v11.5.txt",
		        "edge_list_path": "673862.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaPhilomiragiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella philomiragia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaPhilomiragiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "484022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "484022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "484022.clusters.proteins.v11.5.txt",
		        "sequence_path": "484022.protein.sequences.v11.5.fa",
		        "enrichment_path": "484022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484022.protein.info.v11.5.txt",
		        "node_list_path": "484022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "484022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaSpDc12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. DC12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpDc12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "683315.protein.sequences.v11.5.fa",
		        "enrichment_path": "683315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683315.protein.info.v11.5.txt",
		        "node_list_path": "683315.protein.complete.v11.5.txt"
		    }
		]
    )()

def TerribacillusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terribacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerribacillusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "361279.protein.sequences.v11.5.fa",
		        "enrichment_path": "361279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "361279.protein.info.v11.5.txt",
		        "node_list_path": "361279.protein.complete.v11.5.txt"
		    }
		]
    )()

def KocuriaPolaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kocuria polaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaPolaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "136273.protein.sequences.v11.5.fa",
		        "enrichment_path": "136273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "136273.protein.info.v11.5.txt",
		        "node_list_path": "136273.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumSpOl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. OL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumSpOl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1504822.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1504822.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1504822.clusters.proteins.v11.0.txt",
		        "sequence_path": "1504822.protein.sequences.v11.0.fa",
		        "enrichment_path": "1504822.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1504822.protein.info.v11.0.txt",
		        "node_list_path": "1504822.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1504822.protein.cluster.v11.0.txt"
		    }
		]
    )()

def DesulfovibrioDesulfuricansNd132Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans ND132 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioDesulfuricansNd132Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641491.clusters.proteins.v11.5.txt",
		        "sequence_path": "641491.protein.sequences.v11.5.fa",
		        "enrichment_path": "641491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641491.protein.info.v11.5.txt",
		        "node_list_path": "641491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolirubrobacterSoliDsm22325Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solirubrobacter soli DSM 22325 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolirubrobacterSoliDsm22325Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123262.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123262.protein.info.v11.5.txt",
		        "node_list_path": "1123262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinivibrioSocompensisS10b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio socompensis S10B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivibrioSocompensisS10b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "868280.protein.sequences.v11.5.fa",
		        "enrichment_path": "868280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "868280.protein.info.v11.5.txt",
		        "node_list_path": "868280.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumUmmariense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium ummariense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumUmmariense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1346791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346791.protein.info.v11.5.txt",
		        "node_list_path": "1346791.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumPentaromativoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium pentaromativorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumPentaromativoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1088721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1088721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1088721.clusters.proteins.v11.5.txt",
		        "sequence_path": "1088721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1088721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1088721.protein.info.v11.5.txt",
		        "node_list_path": "1088721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1088721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KocuriaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kocuria marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "223184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "223184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "223184.clusters.proteins.v11.5.txt",
		        "sequence_path": "223184.protein.sequences.v11.5.fa",
		        "enrichment_path": "223184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223184.protein.info.v11.5.txt",
		        "node_list_path": "223184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "223184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyadobacterSpLeaf189Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter sp. Leaf189 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterSpLeaf189Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736295.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736295.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736295.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736295.protein.info.v11.5.txt",
		        "node_list_path": "1736295.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736295.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifoxyb12Full507Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFOXYB12_FULL_50_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifoxyb12Full507Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801835.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801835.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801835.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801835.protein.info.v11.5.txt",
		        "node_list_path": "1801835.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801835.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumElkaniiWsm2783(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii WSM2783 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumElkaniiWsm2783", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1038860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038860.protein.info.v11.5.txt",
		        "node_list_path": "1038860.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesNasicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces nasicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesNasicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "208480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "208480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "208480.clusters.proteins.v11.5.txt",
		        "sequence_path": "208480.protein.sequences.v11.5.fa",
		        "enrichment_path": "208480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208480.protein.info.v11.5.txt",
		        "node_list_path": "208480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "208480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VaribaculumCambriense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum cambriense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaribaculumCambriense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "184870.protein.sequences.v11.5.fa",
		        "enrichment_path": "184870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "184870.protein.info.v11.5.txt",
		        "node_list_path": "184870.protein.complete.v11.5.txt"
		    }
		]
    )()

def LipotesVexilliferCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lipotes vexillifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LipotesVexilliferCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118797.clusters.proteins.v11.5.txt",
		        "sequence_path": "118797.protein.sequences.v11.5.fa",
		        "enrichment_path": "118797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118797.protein.info.v11.5.txt",
		        "node_list_path": "118797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterUrativoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter urativorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterUrativoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45610.clusters.proteins.v11.5.txt",
		        "sequence_path": "45610.protein.sequences.v11.5.fa",
		        "enrichment_path": "45610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45610.protein.info.v11.5.txt",
		        "node_list_path": "45610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpWy10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. WY10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpWy10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1920667.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1920667.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1920667.clusters.proteins.v11.5.txt",
		        "sequence_path": "1920667.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920667.protein.info.v11.5.txt",
		        "node_list_path": "1920667.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1920667.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumPaxllaeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium paxllaeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumPaxllaeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "190148.clusters.info.v11.5.txt",
		        "cluster_tree_path": "190148.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "190148.clusters.proteins.v11.5.txt",
		        "sequence_path": "190148.protein.sequences.v11.5.fa",
		        "enrichment_path": "190148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190148.protein.info.v11.5.txt",
		        "node_list_path": "190148.cluster.nodes.v11.5.txt",
		        "edge_list_path": "190148.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaMultiformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella multiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMultiformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888743.clusters.proteins.v11.5.txt",
		        "sequence_path": "888743.protein.sequences.v11.5.fa",
		        "enrichment_path": "888743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888743.protein.info.v11.5.txt",
		        "node_list_path": "888743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaSpKtr9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sp. KTR9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSpKtr9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "337191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "337191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "337191.clusters.proteins.v11.5.txt",
		        "sequence_path": "337191.protein.sequences.v11.5.fa",
		        "enrichment_path": "337191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "337191.protein.info.v11.5.txt",
		        "node_list_path": "337191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "337191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DokdoniaSp4h375(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dokdonia sp. 4H375 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DokdoniaSp4h375", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983548.protein.sequences.v11.5.fa",
		        "enrichment_path": "983548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983548.protein.info.v11.5.txt",
		        "node_list_path": "983548.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag180Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:180 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag180Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262882.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262882.protein.info.v11.5.txt",
		        "node_list_path": "1262882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeclerciaAdecarboxylataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leclercia adecarboxylata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeclerciaAdecarboxylataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "911008.clusters.info.v11.5.txt",
		        "cluster_tree_path": "911008.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "911008.clusters.proteins.v11.5.txt",
		        "sequence_path": "911008.protein.sequences.v11.5.fa",
		        "enrichment_path": "911008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "911008.protein.info.v11.5.txt",
		        "node_list_path": "911008.cluster.nodes.v11.5.txt",
		        "edge_list_path": "911008.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCollagenovoransDsm3089Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium collagenovorans DSM 3089 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCollagenovoransDsm3089Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121306.protein.info.v11.5.txt",
		        "node_list_path": "1121306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusBuchneriNrrlb30929Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri NRRLB30929 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBuchneriNrrlb30929Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "511437.clusters.info.v11.5.txt",
		        "cluster_tree_path": "511437.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "511437.clusters.proteins.v11.5.txt",
		        "sequence_path": "511437.protein.sequences.v11.5.fa",
		        "enrichment_path": "511437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511437.protein.info.v11.5.txt",
		        "node_list_path": "511437.cluster.nodes.v11.5.txt",
		        "edge_list_path": "511437.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpYr558Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. YR558 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpYr558Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881044.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881044.protein.info.v11.5.txt",
		        "node_list_path": "1881044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulophagaFucicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga fucicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaFucicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "76595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "76595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "76595.clusters.proteins.v11.5.txt",
		        "sequence_path": "76595.protein.sequences.v11.5.fa",
		        "enrichment_path": "76595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76595.protein.info.v11.5.txt",
		        "node_list_path": "76595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "76595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5013Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_50_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5013Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798661.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798661.protein.info.v11.5.txt",
		        "node_list_path": "1798661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifcsplowo212Full6540(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO2_12_FULL_65_40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo212Full6540", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797569.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797569.protein.info.v11.5.txt",
		        "node_list_path": "1797569.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemmatimonasSpAp64Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonas sp. AP64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonasSpAp64Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379270.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379270.protein.info.v11.5.txt",
		        "node_list_path": "1379270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpOlb3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. OLB3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpOlb3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617410.protein.info.v11.5.txt",
		        "node_list_path": "1617410.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesAcidifaciensJcm10556Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides acidifaciens JCM 10556 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesAcidifaciensJcm10556Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235814.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235814.protein.info.v11.5.txt",
		        "node_list_path": "1235814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaCantharicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma cantharicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaCantharicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "362837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "362837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "362837.clusters.proteins.v11.5.txt",
		        "sequence_path": "362837.protein.sequences.v11.5.fa",
		        "enrichment_path": "362837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362837.protein.info.v11.5.txt",
		        "node_list_path": "362837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "362837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMucidolensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mucidolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMucidolensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46679.clusters.proteins.v11.5.txt",
		        "sequence_path": "46679.protein.sequences.v11.5.fa",
		        "enrichment_path": "46679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46679.protein.info.v11.5.txt",
		        "node_list_path": "46679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CobetiaSpUcd24cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cobetia sp. UCD-24C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CobetiaSpUcd24cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1716176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1716176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1716176.clusters.proteins.v11.5.txt",
		        "sequence_path": "1716176.protein.sequences.v11.5.fa",
		        "enrichment_path": "1716176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1716176.protein.info.v11.5.txt",
		        "node_list_path": "1716176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1716176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnolisCarolinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anolis carolinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnolisCarolinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28377.clusters.proteins.v11.5.txt",
		        "sequence_path": "28377.protein.sequences.v11.5.fa",
		        "enrichment_path": "28377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28377.protein.info.v11.5.txt",
		        "node_list_path": "28377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaTakedensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia takedensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaTakedensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206735.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206735.protein.info.v11.5.txt",
		        "node_list_path": "1206735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DolichospermumCircinaleAwqc131c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dolichospermum circinale AWQC131C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DolichospermumCircinaleAwqc131c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398007.protein.sequences.v11.5.fa",
		        "enrichment_path": "398007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398007.protein.info.v11.5.txt",
		        "node_list_path": "398007.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumHydrogeniformansDsm21757Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium hydrogeniformans DSM 21757 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumHydrogeniformansDsm21757Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121319.protein.info.v11.5.txt",
		        "node_list_path": "1121319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaSpR43(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. R43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpR43", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "269536.protein.sequences.v11.5.fa",
		        "enrichment_path": "269536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269536.protein.info.v11.5.txt",
		        "node_list_path": "269536.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumPasteurianumBc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum BC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPasteurianumBc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86416.clusters.proteins.v11.5.txt",
		        "sequence_path": "86416.protein.sequences.v11.5.fa",
		        "enrichment_path": "86416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86416.protein.info.v11.5.txt",
		        "node_list_path": "86416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumBrhC8aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRH_c8a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumBrhC8aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629715.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629715.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629715.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629715.protein.info.v11.5.txt",
		        "node_list_path": "1629715.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629715.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptonemaIllini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptonema illini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptonemaIllini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "183.protein.sequences.v11.5.fa",
		        "enrichment_path": "183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "183.protein.info.v11.5.txt",
		        "node_list_path": "183.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusEquorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus equorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusEquorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1159488.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1159488.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1159488.clusters.proteins.v11.5.txt",
		        "sequence_path": "1159488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159488.protein.info.v11.5.txt",
		        "node_list_path": "1159488.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1159488.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpCip102129Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP102129 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpCip102129Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144664.protein.info.v11.5.txt",
		        "node_list_path": "1144664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusFlavithermusAk1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus AK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusFlavithermusAk1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1297581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297581.protein.info.v11.5.txt",
		        "node_list_path": "1297581.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrifoliumPratense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trifolium pratense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrifoliumPratense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "57577.protein.sequences.v11.5.fa",
		        "enrichment_path": "57577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "57577.protein.info.v11.5.txt",
		        "node_list_path": "57577.protein.complete.v11.5.txt"
		    }
		]
    )()

def AllofustisSeminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Allofustis seminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllofustisSeminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120978.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120978.protein.info.v11.5.txt",
		        "node_list_path": "1120978.protein.complete.v11.5.txt"
		    }
		]
    )()

def PonticaulisKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ponticaulis koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PonticaulisKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "551789.clusters.info.v11.5.txt",
		        "cluster_tree_path": "551789.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "551789.clusters.proteins.v11.5.txt",
		        "sequence_path": "551789.protein.sequences.v11.5.fa",
		        "enrichment_path": "551789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551789.protein.info.v11.5.txt",
		        "node_list_path": "551789.cluster.nodes.v11.5.txt",
		        "edge_list_path": "551789.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumGwf24151(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_41_51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumGwf24151", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801957.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801957.protein.info.v11.5.txt",
		        "node_list_path": "1801957.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensSbw25(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens SBW25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensSbw25", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216595.protein.sequences.v11.5.fa",
		        "enrichment_path": "216595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216595.protein.info.v11.5.txt",
		        "node_list_path": "216595.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSphaericusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sphaericus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSphaericusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1421.protein.info.v11.5.txt",
		        "node_list_path": "1421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FomitiporiaMediterranea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fomitiporia mediterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FomitiporiaMediterranea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "208960.protein.sequences.v11.5.fa",
		        "enrichment_path": "208960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208960.protein.info.v11.5.txt",
		        "node_list_path": "208960.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpFw510T8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. FW510-T8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpFw510T8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1524463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1524463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1524463.clusters.proteins.v11.5.txt",
		        "sequence_path": "1524463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1524463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1524463.protein.info.v11.5.txt",
		        "node_list_path": "1524463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1524463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaAps(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola APS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaAps", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "107806.protein.sequences.v11.5.fa",
		        "enrichment_path": "107806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "107806.protein.info.v11.5.txt",
		        "node_list_path": "107806.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArenibacterNanhaiticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenibacter nanhaiticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenibacterNanhaiticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "558155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "558155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "558155.clusters.proteins.v11.5.txt",
		        "sequence_path": "558155.protein.sequences.v11.5.fa",
		        "enrichment_path": "558155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558155.protein.info.v11.5.txt",
		        "node_list_path": "558155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "558155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizopusDelemarRa99880Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus delemar RA 99-880 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopusDelemarRa99880Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246409.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246409.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246409.clusters.proteins.v11.5.txt",
		        "sequence_path": "246409.protein.sequences.v11.5.fa",
		        "enrichment_path": "246409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246409.protein.info.v11.5.txt",
		        "node_list_path": "246409.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246409.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MuricaudaZhangzhouensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Muricauda zhangzhouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuricaudaZhangzhouensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1073328.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073328.protein.info.v11.5.txt",
		        "node_list_path": "1073328.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE1214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E1214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE1214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834123.protein.info.v11.5.txt",
		        "node_list_path": "1834123.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAlkalitolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio alkalitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAlkalitolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121439.protein.info.v11.5.txt",
		        "node_list_path": "1121439.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphaerochaetaGlobosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaerochaeta globosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerochaetaGlobosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "158189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "158189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "158189.clusters.proteins.v11.5.txt",
		        "sequence_path": "158189.protein.sequences.v11.5.fa",
		        "enrichment_path": "158189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158189.protein.info.v11.5.txt",
		        "node_list_path": "158189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "158189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesXiamenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesXiamenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "408015.protein.sequences.v11.5.fa",
		        "enrichment_path": "408015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408015.protein.info.v11.5.txt",
		        "node_list_path": "408015.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusGraminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus graminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusGraminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "189425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "189425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "189425.clusters.proteins.v11.5.txt",
		        "sequence_path": "189425.protein.sequences.v11.5.fa",
		        "enrichment_path": "189425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189425.protein.info.v11.5.txt",
		        "node_list_path": "189425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "189425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EncephalitozoonCuniculiGbM1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Encephalitozoon cuniculi GB-M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EncephalitozoonCuniculiGbM1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "284813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "284813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "284813.clusters.proteins.v11.5.txt",
		        "sequence_path": "284813.protein.sequences.v11.5.fa",
		        "enrichment_path": "284813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284813.protein.info.v11.5.txt",
		        "node_list_path": "284813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "284813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TolypothrixSpPcc7601(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tolypothrix sp. PCC 7601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolypothrixSpPcc7601", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188.protein.info.v11.5.txt",
		        "node_list_path": "1188.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermosiphoMelanesiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermosipho melanesiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosiphoMelanesiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391009.protein.sequences.v11.5.fa",
		        "enrichment_path": "391009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391009.protein.info.v11.5.txt",
		        "node_list_path": "391009.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpLeaf151Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf151 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpLeaf151Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736276.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736276.protein.info.v11.5.txt",
		        "node_list_path": "1736276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NosemaCeranaeBrl01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nosema ceranae BRL01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NosemaCeranaeBrl01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "578460.protein.sequences.v11.5.fa",
		        "enrichment_path": "578460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578460.protein.info.v11.5.txt",
		        "node_list_path": "578460.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaviaPorcellus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cavia porcellus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaviaPorcellus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10141.protein.sequences.v11.5.fa",
		        "enrichment_path": "10141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10141.protein.info.v11.5.txt",
		        "node_list_path": "10141.protein.complete.v11.5.txt"
		    }
		]
    )()

def SlackiaPiriformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Slackia piriformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SlackiaPiriformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742818.clusters.proteins.v11.5.txt",
		        "sequence_path": "742818.protein.sequences.v11.5.fa",
		        "enrichment_path": "742818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742818.protein.info.v11.5.txt",
		        "node_list_path": "742818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaPedisStrTA4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema pedis str. T A4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPedisStrTA4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1291379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291379.protein.info.v11.5.txt",
		        "node_list_path": "1291379.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisSpCnr923(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. CNR-923 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisSpCnr923", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1904965.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904965.protein.info.v11.5.txt",
		        "node_list_path": "1904965.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellvibrioJaponicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioJaponicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "498211.protein.sequences.v11.5.fa",
		        "enrichment_path": "498211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498211.protein.info.v11.5.txt",
		        "node_list_path": "498211.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeiothermusRuberCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusRuberCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "504728.clusters.info.v11.5.txt",
		        "cluster_tree_path": "504728.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "504728.clusters.proteins.v11.5.txt",
		        "sequence_path": "504728.protein.sequences.v11.5.fa",
		        "enrichment_path": "504728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504728.protein.info.v11.5.txt",
		        "node_list_path": "504728.cluster.nodes.v11.5.txt",
		        "edge_list_path": "504728.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpEb01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. EB01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpEb01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1347086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1347086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1347086.clusters.proteins.v11.5.txt",
		        "sequence_path": "1347086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347086.protein.info.v11.5.txt",
		        "node_list_path": "1347086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1347086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyceliophthoraThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myceliophthora thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyceliophthoraThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "78579.clusters.info.v11.5.txt",
		        "cluster_tree_path": "78579.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "78579.clusters.proteins.v11.5.txt",
		        "sequence_path": "78579.protein.sequences.v11.5.fa",
		        "enrichment_path": "78579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78579.protein.info.v11.5.txt",
		        "node_list_path": "78579.cluster.nodes.v11.5.txt",
		        "edge_list_path": "78579.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesFluxusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fluxus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFluxusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "763034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "763034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "763034.clusters.proteins.v11.5.txt",
		        "sequence_path": "763034.protein.sequences.v11.5.fa",
		        "enrichment_path": "763034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "763034.protein.info.v11.5.txt",
		        "node_list_path": "763034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "763034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpNele67Bin005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nele67-Bin005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpNele67Bin005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1764963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1764963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1764963.protein.info.v11.5.txt",
		        "node_list_path": "1764963.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaceaeBacteriumMarseilleP2826Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotellaceae bacterium Marseille-P2826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaceaeBacteriumMarseilleP2826Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852368.protein.info.v11.5.txt",
		        "node_list_path": "1852368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpEpa45Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. EPa45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpEpa45Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1545728.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1545728.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1545728.clusters.proteins.v11.5.txt",
		        "sequence_path": "1545728.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545728.protein.info.v11.5.txt",
		        "node_list_path": "1545728.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1545728.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesNiveus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces niveus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesNiveus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1352941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1352941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1352941.protein.info.v11.5.txt",
		        "node_list_path": "1352941.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTuberculosisVariantBovisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTuberculosisVariantBovisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1765.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1765.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1765.clusters.proteins.v11.5.txt",
		        "sequence_path": "1765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765.protein.info.v11.5.txt",
		        "node_list_path": "1765.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1765.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85201450255Sch5639931Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852014-50255_SCH5639931 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85201450255Sch5639931Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834112.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834112.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834112.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834112.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834112.protein.info.v11.5.txt",
		        "node_list_path": "1834112.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834112.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4720Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_47_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4720Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802335.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802335.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802335.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802335.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802335.protein.info.v11.5.txt",
		        "node_list_path": "1802335.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802335.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AequorivitaViscosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aequorivita viscosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AequorivitaViscosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "797419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "797419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "797419.clusters.proteins.v11.5.txt",
		        "sequence_path": "797419.protein.sequences.v11.5.fa",
		        "enrichment_path": "797419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797419.protein.info.v11.5.txt",
		        "node_list_path": "797419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "797419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag581Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag581Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262890.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262890.protein.info.v11.5.txt",
		        "node_list_path": "1262890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsanoaIshikariensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asanoa ishikariensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsanoaIshikariensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "137265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "137265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "137265.clusters.proteins.v11.5.txt",
		        "sequence_path": "137265.protein.sequences.v11.5.fa",
		        "enrichment_path": "137265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137265.protein.info.v11.5.txt",
		        "node_list_path": "137265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "137265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumLimosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium limosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumLimosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "903814.protein.sequences.v11.5.fa",
		        "enrichment_path": "903814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903814.protein.info.v11.5.txt",
		        "node_list_path": "903814.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionimicrobiumLymphophilumAcs093VSch5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionimicrobium lymphophilum ACS-093-V-SCH5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionimicrobiumLymphophilumAcs093VSch5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883161.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883161.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883161.clusters.proteins.v11.5.txt",
		        "sequence_path": "883161.protein.sequences.v11.5.fa",
		        "enrichment_path": "883161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883161.protein.info.v11.5.txt",
		        "node_list_path": "883161.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883161.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeonGw2011Ar18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return archaeon GW2011_AR18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeonGw2011Ar18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1579376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579376.protein.info.v11.5.txt",
		        "node_list_path": "1579376.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesHongkongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesHongkongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "178339.clusters.info.v11.5.txt",
		        "cluster_tree_path": "178339.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "178339.clusters.proteins.v11.5.txt",
		        "sequence_path": "178339.protein.sequences.v11.5.fa",
		        "enrichment_path": "178339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178339.protein.info.v11.5.txt",
		        "node_list_path": "178339.cluster.nodes.v11.5.txt",
		        "edge_list_path": "178339.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumGallinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumGallinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "78344.clusters.info.v11.5.txt",
		        "cluster_tree_path": "78344.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "78344.clusters.proteins.v11.5.txt",
		        "sequence_path": "78344.protein.sequences.v11.5.fa",
		        "enrichment_path": "78344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78344.protein.info.v11.5.txt",
		        "node_list_path": "78344.cluster.nodes.v11.5.txt",
		        "edge_list_path": "78344.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTa06Bacterium32111Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TA06 bacterium 32_111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTa06Bacterium32111Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635278.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635278.protein.info.v11.5.txt",
		        "node_list_path": "1635278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumPhox21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium Phox-21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumPhox21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1918507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918507.protein.info.v11.5.txt",
		        "node_list_path": "1918507.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumCauenseR2a7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium cauense R2A-7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumCauenseR2a7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1341154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1341154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1341154.clusters.proteins.v11.5.txt",
		        "sequence_path": "1341154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341154.protein.info.v11.5.txt",
		        "node_list_path": "1341154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1341154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalopigerSalifodinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halopiger salifodinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalopigerSalifodinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1202768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1202768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1202768.clusters.proteins.v11.5.txt",
		        "sequence_path": "1202768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202768.protein.info.v11.5.txt",
		        "node_list_path": "1202768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1202768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumMalaysienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium malaysiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumMalaysienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348853.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348853.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348853.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348853.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348853.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348853.protein.info.v11.5.txt",
		        "node_list_path": "1348853.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348853.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSpCag831Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:831 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpCag831Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262698.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262698.protein.info.v11.5.txt",
		        "node_list_path": "1262698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumOxysporumFSpCubenseRace4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. cubense race 4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumOxysporumFSpCubenseRace4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229665.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229665.protein.info.v11.5.txt",
		        "node_list_path": "1229665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacteraceaeBacterium4572123Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium 4572_123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteraceaeBacterium4572123Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1971629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1971629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1971629.clusters.proteins.v11.5.txt",
		        "sequence_path": "1971629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971629.protein.info.v11.5.txt",
		        "node_list_path": "1971629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1971629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpeciesTree(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "species.tree.v11.5", **kwargs
) -> Graph:
    """Return SpeciesTree graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "species.tree.v11.5"
        Version to retrieve	
		The available versions are:
			- species.tree.v11.0
			- species.tree.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpeciesTree", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			create_species_tree_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "tree_path": "species.tree.v11.5.txt",
		        "tree_metadata_path": "species.v11.5.txt",
		        "node_list_path": "species.tree.v11.5.nodes.tsv",
		        "edge_list_path": "species.tree.v11.5.edges.tsv"
		    }
		]
    )()

def TetrasphaeraSpSoil756(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera sp. Soil756 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrasphaeraSpSoil756", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736399.protein.info.v11.5.txt",
		        "node_list_path": "1736399.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumResistensNbrc103078Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium resistens NBRC 103078 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumResistensNbrc103078Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223505.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223505.protein.info.v11.5.txt",
		        "node_list_path": "1223505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpStF2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ST-F2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpStF2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1490484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1490484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1490484.clusters.proteins.v11.5.txt",
		        "sequence_path": "1490484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1490484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1490484.protein.info.v11.5.txt",
		        "node_list_path": "1490484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1490484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacteriumHubeienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium hubeiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacteriumHubeienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1407499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1407499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1407499.clusters.proteins.v11.5.txt",
		        "sequence_path": "1407499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1407499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1407499.protein.info.v11.5.txt",
		        "node_list_path": "1407499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1407499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychroflexusTorquisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychroflexus torquis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroflexusTorquisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313595.clusters.proteins.v11.5.txt",
		        "sequence_path": "313595.protein.sequences.v11.5.fa",
		        "enrichment_path": "313595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313595.protein.info.v11.5.txt",
		        "node_list_path": "313595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharopolysporaRectivirgulaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharopolyspora rectivirgula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharopolysporaRectivirgulaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28042.clusters.proteins.v11.5.txt",
		        "sequence_path": "28042.protein.sequences.v11.5.fa",
		        "enrichment_path": "28042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28042.protein.info.v11.5.txt",
		        "node_list_path": "28042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FimbriimonasGinsengisoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fimbriimonas ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FimbriimonasGinsengisoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "661478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "661478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "661478.clusters.proteins.v11.5.txt",
		        "sequence_path": "661478.protein.sequences.v11.5.fa",
		        "enrichment_path": "661478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "661478.protein.info.v11.5.txt",
		        "node_list_path": "661478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "661478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BaumanniaCicadellinicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Baumannia cicadellinicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BaumanniaCicadellinicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "186490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "186490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "186490.clusters.proteins.v11.5.txt",
		        "sequence_path": "186490.protein.sequences.v11.5.fa",
		        "enrichment_path": "186490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "186490.protein.info.v11.5.txt",
		        "node_list_path": "186490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "186490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BotryotiniaNarcissicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Botryotinia narcissicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotryotiniaNarcissicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "278944.protein.sequences.v11.5.fa",
		        "enrichment_path": "278944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278944.protein.info.v11.5.txt",
		        "node_list_path": "278944.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaSubflavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria subflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSubflavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546268.clusters.proteins.v11.5.txt",
		        "sequence_path": "546268.protein.sequences.v11.5.fa",
		        "enrichment_path": "546268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546268.protein.info.v11.5.txt",
		        "node_list_path": "546268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaViolacea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella violacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaViolacea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "637905.protein.sequences.v11.5.fa",
		        "enrichment_path": "637905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637905.protein.info.v11.5.txt",
		        "node_list_path": "637905.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusKullabergensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kullabergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKullabergensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218493.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218493.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218493.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218493.protein.info.v11.5.txt",
		        "node_list_path": "1218493.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218493.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AllisonellaHistaminiformansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Allisonella histaminiformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllisonellaHistaminiformansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "209880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "209880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "209880.clusters.proteins.v11.5.txt",
		        "sequence_path": "209880.protein.sequences.v11.5.fa",
		        "enrichment_path": "209880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "209880.protein.info.v11.5.txt",
		        "node_list_path": "209880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "209880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpYr519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpYr519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500259.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500259.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500259.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500259.protein.info.v11.5.txt",
		        "node_list_path": "1500259.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500259.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4716(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_47_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4716", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798690.protein.info.v11.5.txt",
		        "node_list_path": "1798690.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprobacillusSp291Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus sp. 291 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprobacillusSp291Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469596.clusters.proteins.v11.5.txt",
		        "sequence_path": "469596.protein.sequences.v11.5.fa",
		        "enrichment_path": "469596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469596.protein.info.v11.5.txt",
		        "node_list_path": "469596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MangrovibacterSpMfb070Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mangrovibacter sp. MFB070 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MangrovibacterSpMfb070Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1224318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1224318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1224318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1224318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224318.protein.info.v11.5.txt",
		        "node_list_path": "1224318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1224318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusViretiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus vireti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusViretiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131730.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131730.protein.info.v11.5.txt",
		        "node_list_path": "1131730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychroserpensDamuponensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens damuponensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroserpensDamuponensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "943936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "943936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "943936.clusters.proteins.v11.5.txt",
		        "sequence_path": "943936.protein.sequences.v11.5.fa",
		        "enrichment_path": "943936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "943936.protein.info.v11.5.txt",
		        "node_list_path": "943936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "943936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteimonasSpJm171(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas sp. JM171 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteimonasSpJm171", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896164.protein.info.v11.5.txt",
		        "node_list_path": "1896164.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu013Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu013Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671648.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671648.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671648.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671648.protein.info.v11.5.txt",
		        "node_list_path": "1671648.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671648.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumUterequiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium uterequi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumUterequiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1072256.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1072256.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1072256.clusters.proteins.v11.5.txt",
		        "sequence_path": "1072256.protein.sequences.v11.5.fa",
		        "enrichment_path": "1072256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1072256.protein.info.v11.5.txt",
		        "node_list_path": "1072256.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1072256.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyellaJaponicaDsm16301(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyella japonica DSM 16301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaJaponicaDsm16301", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1440762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1440762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1440762.protein.info.v11.5.txt",
		        "node_list_path": "1440762.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpWg21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. WG21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpWg21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229487.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229487.protein.info.v11.5.txt",
		        "node_list_path": "1229487.protein.complete.v11.5.txt"
		    }
		]
    )()

def GolovinomycesMagnicellulatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Golovinomyces magnicellulatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GolovinomycesMagnicellulatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "62714.clusters.info.v11.5.txt",
		        "cluster_tree_path": "62714.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "62714.clusters.proteins.v11.5.txt",
		        "sequence_path": "62714.protein.sequences.v11.5.fa",
		        "enrichment_path": "62714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62714.protein.info.v11.5.txt",
		        "node_list_path": "62714.cluster.nodes.v11.5.txt",
		        "edge_list_path": "62714.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactococcusChungangensisCau28Dsm22330Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus chungangensis CAU 28 DSM 22330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusChungangensisCau28Dsm22330Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122154.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122154.protein.info.v11.5.txt",
		        "node_list_path": "1122154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacillusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacillusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385510.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385510.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385510.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385510.protein.info.v11.5.txt",
		        "node_list_path": "1385510.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385510.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag822Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:822 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag822Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263032.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263032.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263032.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263032.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263032.protein.info.v11.5.txt",
		        "node_list_path": "1263032.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263032.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAdp1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ADP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAdp1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "62977.protein.sequences.v11.5.fa",
		        "enrichment_path": "62977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62977.protein.info.v11.5.txt",
		        "node_list_path": "62977.protein.complete.v11.5.txt"
		    }
		]
    )()

def VesicomyosociusOkutanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vesicomyosocius okutanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VesicomyosociusOkutanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "412965.protein.sequences.v11.5.fa",
		        "enrichment_path": "412965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "412965.protein.info.v11.5.txt",
		        "node_list_path": "412965.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosospiraSpNsp1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraSpNsp1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "136547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "136547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "136547.clusters.proteins.v11.5.txt",
		        "sequence_path": "136547.protein.sequences.v11.5.fa",
		        "enrichment_path": "136547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "136547.protein.info.v11.5.txt",
		        "node_list_path": "136547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "136547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerostipesSp992aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerostipes sp. 992a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerostipesSp992aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1261637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1261637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1261637.clusters.proteins.v11.5.txt",
		        "sequence_path": "1261637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261637.protein.info.v11.5.txt",
		        "node_list_path": "1261637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1261637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumRbg19ftCombo5817Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_19FT_COMBO_58_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg19ftCombo5817Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797275.protein.info.v11.5.txt",
		        "node_list_path": "1797275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaAnanatisLmg20103Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea ananatis LMG20103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaAnanatisLmg20103Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "706191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "706191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "706191.clusters.proteins.v11.5.txt",
		        "sequence_path": "706191.protein.sequences.v11.5.fa",
		        "enrichment_path": "706191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706191.protein.info.v11.5.txt",
		        "node_list_path": "706191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "706191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpGa1285Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1285 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpGa1285Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1772282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1772282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1772282.clusters.proteins.v11.5.txt",
		        "sequence_path": "1772282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772282.protein.info.v11.5.txt",
		        "node_list_path": "1772282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1772282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanktothrixSpPcc11201(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planktothrix sp. PCC 11201 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktothrixSpPcc11201", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729650.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729650.protein.info.v11.5.txt",
		        "node_list_path": "1729650.protein.complete.v11.5.txt"
		    }
		]
    )()

def GossypiumHirsutumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gossypium hirsutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GossypiumHirsutumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3635.clusters.proteins.v11.5.txt",
		        "sequence_path": "3635.protein.sequences.v11.5.fa",
		        "enrichment_path": "3635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3635.protein.info.v11.5.txt",
		        "node_list_path": "3635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMandelii36mfcvi11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mandelii 36MFCvi11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMandelii36mfcvi11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1151127.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151127.protein.info.v11.5.txt",
		        "node_list_path": "1151127.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls1777(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS1777 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls1777", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463887.protein.info.v11.5.txt",
		        "node_list_path": "1463887.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzospirillumLipoferum4b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum lipoferum 4B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumLipoferum4b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "862719.protein.sequences.v11.5.fa",
		        "enrichment_path": "862719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862719.protein.info.v11.5.txt",
		        "node_list_path": "862719.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpIbvss1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. IBVSS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpIbvss1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1985171.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1985171.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1985171.clusters.proteins.v11.5.txt",
		        "sequence_path": "1985171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1985171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1985171.protein.info.v11.5.txt",
		        "node_list_path": "1985171.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1985171.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesXylophagusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces xylophagus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesXylophagusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "285514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "285514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "285514.clusters.proteins.v11.5.txt",
		        "sequence_path": "285514.protein.sequences.v11.5.fa",
		        "enrichment_path": "285514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285514.protein.info.v11.5.txt",
		        "node_list_path": "285514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "285514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloarculaMarismortuiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula marismortui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaMarismortuiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272569.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272569.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272569.clusters.proteins.v11.5.txt",
		        "sequence_path": "272569.protein.sequences.v11.5.fa",
		        "enrichment_path": "272569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272569.protein.info.v11.5.txt",
		        "node_list_path": "272569.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272569.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OxalobacterFormigenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OxalobacterFormigenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "847.clusters.proteins.v11.5.txt",
		        "sequence_path": "847.protein.sequences.v11.5.fa",
		        "enrichment_path": "847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "847.protein.info.v11.5.txt",
		        "node_list_path": "847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenimonasSpScn70307Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas sp. SCN 70-307 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenimonasSpScn70307Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660089.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660089.protein.info.v11.5.txt",
		        "node_list_path": "1660089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CordycepsMilitarisCm01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps militaris CM01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CordycepsMilitarisCm01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983644.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983644.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983644.clusters.proteins.v11.5.txt",
		        "sequence_path": "983644.protein.sequences.v11.5.fa",
		        "enrichment_path": "983644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983644.protein.info.v11.5.txt",
		        "node_list_path": "983644.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983644.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full4210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_42_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full4210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798285.protein.info.v11.5.txt",
		        "node_list_path": "1798285.protein.complete.v11.5.txt"
		    }
		]
    )()

def TateyamariaOmphaliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tateyamaria omphalii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TateyamariaOmphaliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "299262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "299262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "299262.clusters.proteins.v11.5.txt",
		        "sequence_path": "299262.protein.sequences.v11.5.fa",
		        "enrichment_path": "299262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299262.protein.info.v11.5.txt",
		        "node_list_path": "299262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "299262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MonosporascusSpCrb92Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. CRB-9-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSpCrb92Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2211643.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2211643.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2211643.clusters.proteins.v11.5.txt",
		        "sequence_path": "2211643.protein.sequences.v11.5.fa",
		        "enrichment_path": "2211643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2211643.protein.info.v11.5.txt",
		        "node_list_path": "2211643.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2211643.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphaerochaetaCoccoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaerochaeta coccoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerochaetaCoccoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "760011.clusters.info.v11.5.txt",
		        "cluster_tree_path": "760011.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "760011.clusters.proteins.v11.5.txt",
		        "sequence_path": "760011.protein.sequences.v11.5.fa",
		        "enrichment_path": "760011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "760011.protein.info.v11.5.txt",
		        "node_list_path": "760011.cluster.nodes.v11.5.txt",
		        "edge_list_path": "760011.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaPekkaneniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia pekkanenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaPekkaneniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288385.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288385.protein.info.v11.5.txt",
		        "node_list_path": "1288385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycetaceaeBacteriumMp11305Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomycetaceae bacterium MP113-05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycetaceaeBacteriumMp11305Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380770.protein.info.v11.5.txt",
		        "node_list_path": "1380770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RouxiellaBadensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rouxiella badensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RouxiellaBadensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1646377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1646377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1646377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1646377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1646377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1646377.protein.info.v11.5.txt",
		        "node_list_path": "1646377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1646377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrnithinibacillusCaliforniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ornithinibacillus californiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithinibacillusCaliforniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "161536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "161536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "161536.clusters.proteins.v11.5.txt",
		        "sequence_path": "161536.protein.sequences.v11.5.fa",
		        "enrichment_path": "161536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161536.protein.info.v11.5.txt",
		        "node_list_path": "161536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "161536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusChagannorensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus chagannorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusChagannorensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121087.protein.info.v11.5.txt",
		        "node_list_path": "1121087.protein.complete.v11.5.txt"
		    }
		]
    )()

def PanTroglodytesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pan troglodytes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PanTroglodytesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9598.clusters.proteins.v11.5.txt",
		        "sequence_path": "9598.protein.sequences.v11.5.fa",
		        "enrichment_path": "9598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9598.protein.info.v11.5.txt",
		        "node_list_path": "9598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumMangenotiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium mangenotii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumMangenotiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408823.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408823.protein.info.v11.5.txt",
		        "node_list_path": "1408823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioHungatei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio hungatei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioHungatei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "185008.protein.sequences.v11.5.fa",
		        "enrichment_path": "185008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "185008.protein.info.v11.5.txt",
		        "node_list_path": "185008.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumSpRoot472d3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root472D3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumSpRoot472d3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736540.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736540.protein.info.v11.5.txt",
		        "node_list_path": "1736540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusibacterSp3d3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusibacter sp. 3D3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusibacterSp3d3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1048380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048380.protein.info.v11.5.txt",
		        "node_list_path": "1048380.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharophagusDegradansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharophagus degradans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharophagusDegradansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "203122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "203122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "203122.clusters.proteins.v11.5.txt",
		        "sequence_path": "203122.protein.sequences.v11.5.fa",
		        "enrichment_path": "203122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203122.protein.info.v11.5.txt",
		        "node_list_path": "203122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "203122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasNitrosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas nitrosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasNitrosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52442.protein.sequences.v11.5.fa",
		        "enrichment_path": "52442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52442.protein.info.v11.5.txt",
		        "node_list_path": "52442.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseibacteriumElongatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseibacterium elongatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseibacteriumElongatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1294273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1294273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1294273.clusters.proteins.v11.5.txt",
		        "sequence_path": "1294273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294273.protein.info.v11.5.txt",
		        "node_list_path": "1294273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1294273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteimonasHuabeiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas huabeiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteimonasHuabeiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1442599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1442599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1442599.protein.info.v11.5.txt",
		        "node_list_path": "1442599.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAlboflavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces alboflavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAlboflavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67267.clusters.proteins.v11.5.txt",
		        "sequence_path": "67267.protein.sequences.v11.5.fa",
		        "enrichment_path": "67267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67267.protein.info.v11.5.txt",
		        "node_list_path": "67267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HippeaJasoniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hippea jasoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HippeaJasoniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "944479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "944479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "944479.clusters.proteins.v11.5.txt",
		        "sequence_path": "944479.protein.sequences.v11.5.fa",
		        "enrichment_path": "944479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944479.protein.info.v11.5.txt",
		        "node_list_path": "944479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "944479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg165418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_54_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg165418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797648.protein.info.v11.5.txt",
		        "node_list_path": "1797648.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaPestisCo92(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia pestis CO92 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaPestisCo92", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "214092.protein.sequences.v11.5.fa",
		        "enrichment_path": "214092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "214092.protein.info.v11.5.txt",
		        "node_list_path": "214092.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusBovienii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus bovienii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusBovienii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "406818.protein.sequences.v11.5.fa",
		        "enrichment_path": "406818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406818.protein.info.v11.5.txt",
		        "node_list_path": "406818.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumGwf25010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_50_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumGwf25010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801959.protein.info.v11.5.txt",
		        "node_list_path": "1801959.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentibacillusJuripiscariusJcm12147(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus juripiscarius JCM 12147 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentibacillusJuripiscariusJcm12147", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293599.protein.info.v11.5.txt",
		        "node_list_path": "1293599.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprobacillusSp8254bfaa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus sp. 8_2_54BFAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprobacillusSp8254bfaa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469597.protein.sequences.v11.5.fa",
		        "enrichment_path": "469597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469597.protein.info.v11.5.txt",
		        "node_list_path": "469597.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriAtcc14405(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri ATCC14405 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriAtcc14405", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32042.protein.sequences.v11.5.fa",
		        "enrichment_path": "32042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32042.protein.info.v11.5.txt",
		        "node_list_path": "32042.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumSpScn6119(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. SCN 61-19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumSpScn6119", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660088.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660088.protein.info.v11.5.txt",
		        "node_list_path": "1660088.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeadbetterellaByssophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leadbetterella byssophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeadbetterellaByssophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649349.clusters.proteins.v11.5.txt",
		        "sequence_path": "649349.protein.sequences.v11.5.fa",
		        "enrichment_path": "649349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649349.protein.info.v11.5.txt",
		        "node_list_path": "649349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93059.protein.sequences.v11.5.fa",
		        "enrichment_path": "93059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93059.protein.info.v11.5.txt",
		        "node_list_path": "93059.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaBuccalisAtcc35310(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccalis ATCC35310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBuccalisAtcc35310", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679190.protein.sequences.v11.5.fa",
		        "enrichment_path": "679190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679190.protein.info.v11.5.txt",
		        "node_list_path": "679190.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalimicrobiumSpMj3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salimicrobium sp. MJ3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalimicrobiumSpMj3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230341.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230341.protein.info.v11.5.txt",
		        "node_list_path": "1230341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DinoroseobacterShibaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dinoroseobacter shibae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DinoroseobacterShibaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398580.clusters.proteins.v11.5.txt",
		        "sequence_path": "398580.protein.sequences.v11.5.fa",
		        "enrichment_path": "398580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398580.protein.info.v11.5.txt",
		        "node_list_path": "398580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho212Full6025(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_12_FULL_60_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho212Full6025", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802399.protein.info.v11.5.txt",
		        "node_list_path": "1802399.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumSibiricumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sibiricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumSibiricumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262543.clusters.info.v11.5.txt",
		        "cluster_tree_path": "262543.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "262543.clusters.proteins.v11.5.txt",
		        "sequence_path": "262543.protein.sequences.v11.5.fa",
		        "enrichment_path": "262543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262543.protein.info.v11.5.txt",
		        "node_list_path": "262543.cluster.nodes.v11.5.txt",
		        "edge_list_path": "262543.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumManausenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium manausense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumManausenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "989370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "989370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "989370.clusters.proteins.v11.5.txt",
		        "sequence_path": "989370.protein.sequences.v11.5.fa",
		        "enrichment_path": "989370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "989370.protein.info.v11.5.txt",
		        "node_list_path": "989370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "989370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumSpAt1bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. AT1b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumSpAt1bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "360911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "360911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "360911.clusters.proteins.v11.5.txt",
		        "sequence_path": "360911.protein.sequences.v11.5.fa",
		        "enrichment_path": "360911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360911.protein.info.v11.5.txt",
		        "node_list_path": "360911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "360911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicolaSpMh3r31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinicola sp. MH3R3-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicolaSpMh3r31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1928762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1928762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1928762.protein.info.v11.5.txt",
		        "node_list_path": "1928762.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusColwellbacteriaBacteriumRifcsplowo202Full4511(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_02_FULL_45_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo202Full4511", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797692.protein.info.v11.5.txt",
		        "node_list_path": "1797692.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporisoriumScitamineum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporisorium scitamineum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporisoriumScitamineum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "49012.protein.sequences.v11.5.fa",
		        "enrichment_path": "49012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "49012.protein.info.v11.5.txt",
		        "node_list_path": "49012.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumGasigenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium gasigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumGasigenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "94869.protein.sequences.v11.5.fa",
		        "enrichment_path": "94869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94869.protein.info.v11.5.txt",
		        "node_list_path": "94869.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaPipientisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia pipientis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaPipientisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "955.clusters.proteins.v11.5.txt",
		        "sequence_path": "955.protein.sequences.v11.5.fa",
		        "enrichment_path": "955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "955.protein.info.v11.5.txt",
		        "node_list_path": "955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTuberculosisVariantAfricanum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant africanum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTuberculosisVariantAfricanum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33894.protein.sequences.v11.5.fa",
		        "enrichment_path": "33894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33894.protein.info.v11.5.txt",
		        "node_list_path": "33894.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaSpAngS4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. ANG-S4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaSpAngS4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577904.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577904.protein.info.v11.5.txt",
		        "node_list_path": "1577904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChthonomonasCalidirosea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chthonomonas calidirosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChthonomonasCalidirosea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1303518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1303518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1303518.protein.info.v11.5.txt",
		        "node_list_path": "1303518.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSecaliphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus secaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSecaliphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "396268.protein.sequences.v11.5.fa",
		        "enrichment_path": "396268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396268.protein.info.v11.5.txt",
		        "node_list_path": "396268.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinarimonasRosea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinarimonas rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinarimonasRosea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123229.protein.info.v11.5.txt",
		        "node_list_path": "1123229.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoduganellaViolaceinigraDsm15887Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoduganella violaceinigra DSM 15887 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoduganellaViolaceinigraDsm15887Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121480.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121480.protein.info.v11.5.txt",
		        "node_list_path": "1121480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4112(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4112", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801774.protein.info.v11.5.txt",
		        "node_list_path": "1801774.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumSpVcm10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium sp. VCM10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumSpVcm10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1381751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1381751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1381751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1381751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381751.protein.info.v11.5.txt",
		        "node_list_path": "1381751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1381751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KomagataellaPastorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataella pastoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataellaPastorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4922.clusters.proteins.v11.5.txt",
		        "sequence_path": "4922.protein.sequences.v11.5.fa",
		        "enrichment_path": "4922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4922.protein.info.v11.5.txt",
		        "node_list_path": "4922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusSaliphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus saliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSaliphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "405559.clusters.info.v11.5.txt",
		        "cluster_tree_path": "405559.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "405559.clusters.proteins.v11.5.txt",
		        "sequence_path": "405559.protein.sequences.v11.5.fa",
		        "enrichment_path": "405559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405559.protein.info.v11.5.txt",
		        "node_list_path": "405559.cluster.nodes.v11.5.txt",
		        "edge_list_path": "405559.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaAmicalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia amicalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaAmicalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1386969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1386969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1386969.clusters.proteins.v11.5.txt",
		        "sequence_path": "1386969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1386969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1386969.protein.info.v11.5.txt",
		        "node_list_path": "1386969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1386969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpA3h3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. A3H3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpA3h3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1346287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1346287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1346287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1346287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346287.protein.info.v11.5.txt",
		        "node_list_path": "1346287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1346287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusPettenkoferi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus pettenkoferi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusPettenkoferi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "904314.protein.sequences.v11.5.fa",
		        "enrichment_path": "904314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904314.protein.info.v11.5.txt",
		        "node_list_path": "904314.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterExcellensHl55(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter excellens HL-55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterExcellensHl55", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1305731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305731.protein.info.v11.5.txt",
		        "node_list_path": "1305731.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseiflexusCastenholzii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseiflexus castenholzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseiflexusCastenholzii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "383372.protein.sequences.v11.5.fa",
		        "enrichment_path": "383372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "383372.protein.info.v11.5.txt",
		        "node_list_path": "383372.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseicitreumAntarcticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseicitreum antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseicitreumAntarcticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "564137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "564137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "564137.clusters.proteins.v11.5.txt",
		        "sequence_path": "564137.protein.sequences.v11.5.fa",
		        "enrichment_path": "564137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "564137.protein.info.v11.5.txt",
		        "node_list_path": "564137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "564137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusFordii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus fordii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusFordii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121090.protein.info.v11.5.txt",
		        "node_list_path": "1121090.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaPallidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema pallidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPallidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243276.clusters.proteins.v11.5.txt",
		        "sequence_path": "243276.protein.sequences.v11.5.fa",
		        "enrichment_path": "243276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243276.protein.info.v11.5.txt",
		        "node_list_path": "243276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumSenegalenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium senegalense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumSenegalenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1796.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1796.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1796.clusters.proteins.v11.5.txt",
		        "sequence_path": "1796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796.protein.info.v11.5.txt",
		        "node_list_path": "1796.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1796.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloglobulusMorosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloglobulus morosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloglobulusMorosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1116472.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116472.protein.info.v11.5.txt",
		        "node_list_path": "1116472.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9201(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9201 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9201", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93057.protein.sequences.v11.5.fa",
		        "enrichment_path": "93057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93057.protein.info.v11.5.txt",
		        "node_list_path": "93057.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfoplanesFormicivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfoplanes formicivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfoplanesFormicivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1592317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1592317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1592317.protein.info.v11.5.txt",
		        "node_list_path": "1592317.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumSpMar2009124Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. MAR_2009_124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumSpMar2009124Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1250059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1250059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1250059.clusters.proteins.v11.5.txt",
		        "sequence_path": "1250059.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250059.protein.info.v11.5.txt",
		        "node_list_path": "1250059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1250059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE3198Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E3198 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE3198Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834143.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834143.protein.info.v11.5.txt",
		        "node_list_path": "1834143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumCg2303616Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium CG2_30_36_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumCg2303616Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805221.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805221.protein.info.v11.5.txt",
		        "node_list_path": "1805221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFraserbacteriaBacteriumRbg16559Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fraserbacteria bacterium RBG_16_55_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFraserbacteriaBacteriumRbg16559Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817864.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817864.protein.info.v11.5.txt",
		        "node_list_path": "1817864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SedimenticolaSelenatireducensDsm17993Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sedimenticola selenatireducens DSM 17993 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SedimenticolaSelenatireducensDsm17993Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111735.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111735.protein.info.v11.5.txt",
		        "node_list_path": "1111735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeorickettsiaRisticiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neorickettsia risticii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorickettsiaRisticiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "434131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "434131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "434131.clusters.proteins.v11.5.txt",
		        "sequence_path": "434131.protein.sequences.v11.5.fa",
		        "enrichment_path": "434131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "434131.protein.info.v11.5.txt",
		        "node_list_path": "434131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "434131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanotheceSpCcy0110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. CCY0110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanotheceSpCcy0110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391612.protein.sequences.v11.5.fa",
		        "enrichment_path": "391612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391612.protein.info.v11.5.txt",
		        "node_list_path": "391612.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpYab3001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. YAB3001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpYab3001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520812.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520812.protein.info.v11.5.txt",
		        "node_list_path": "1520812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaGallinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaGallinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29557.protein.sequences.v11.5.fa",
		        "enrichment_path": "29557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29557.protein.info.v11.5.txt",
		        "node_list_path": "29557.protein.complete.v11.5.txt"
		    }
		]
    )()

def TolumonasAuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tolumonas auensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolumonasAuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "595494.clusters.info.v11.5.txt",
		        "cluster_tree_path": "595494.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "595494.clusters.proteins.v11.5.txt",
		        "sequence_path": "595494.protein.sequences.v11.5.fa",
		        "enrichment_path": "595494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595494.protein.info.v11.5.txt",
		        "node_list_path": "595494.cluster.nodes.v11.5.txt",
		        "edge_list_path": "595494.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesReticulotermitisJcm10512(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides reticulotermitis JCM 10512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesReticulotermitisJcm10512", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1445607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1445607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1445607.protein.info.v11.5.txt",
		        "node_list_path": "1445607.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumAminophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium aminophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAminophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121296.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121296.protein.info.v11.5.txt",
		        "node_list_path": "1121296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BergeyellaZoohelcum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bergeyella zoohelcum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BergeyellaZoohelcum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883096.protein.sequences.v11.5.fa",
		        "enrichment_path": "883096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883096.protein.info.v11.5.txt",
		        "node_list_path": "883096.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldivirgaMaquilingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldivirga maquilingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldivirgaMaquilingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "397948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "397948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "397948.clusters.proteins.v11.5.txt",
		        "sequence_path": "397948.protein.sequences.v11.5.fa",
		        "enrichment_path": "397948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397948.protein.info.v11.5.txt",
		        "node_list_path": "397948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "397948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryobacteriumRoopkundenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryobacterium roopkundense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryobacteriumRoopkundenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1001240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1001240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1001240.clusters.proteins.v11.5.txt",
		        "sequence_path": "1001240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001240.protein.info.v11.5.txt",
		        "node_list_path": "1001240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1001240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MacropusEugenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Macropus eugenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacropusEugenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9315.protein.sequences.v11.5.fa",
		        "enrichment_path": "9315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9315.protein.info.v11.5.txt",
		        "node_list_path": "9315.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSpVpap30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. VPAP30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpVpap30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1647102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1647102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1647102.clusters.proteins.v11.5.txt",
		        "sequence_path": "1647102.protein.sequences.v11.5.fa",
		        "enrichment_path": "1647102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1647102.protein.info.v11.5.txt",
		        "node_list_path": "1647102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1647102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterSpMhB5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. MH-B5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterSpMhB5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1172626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172626.protein.info.v11.5.txt",
		        "node_list_path": "1172626.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSpBma(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. BMA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpBma", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1663685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1663685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1663685.protein.info.v11.5.txt",
		        "node_list_path": "1663685.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixibacteriaBacteriumSm23733(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_73_3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm23733", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703427.protein.info.v11.5.txt",
		        "node_list_path": "1703427.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeptunomonasQingdaonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neptunomonas qingdaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptunomonasQingdaonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1045558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1045558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1045558.clusters.proteins.v11.5.txt",
		        "sequence_path": "1045558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045558.protein.info.v11.5.txt",
		        "node_list_path": "1045558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1045558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaSp119(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. 1.19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSp119", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1925589.protein.sequences.v11.5.fa",
		        "enrichment_path": "1925589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1925589.protein.info.v11.5.txt",
		        "node_list_path": "1925589.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumAntarcticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumAntarcticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1087448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1087448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1087448.clusters.proteins.v11.5.txt",
		        "sequence_path": "1087448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1087448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1087448.protein.info.v11.5.txt",
		        "node_list_path": "1087448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1087448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5236(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_52_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5236", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798510.protein.info.v11.5.txt",
		        "node_list_path": "1798510.protein.complete.v11.5.txt"
		    }
		]
    )()

def DiplodiaCorticolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Diplodia corticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiplodiaCorticolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "236234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "236234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "236234.clusters.proteins.v11.5.txt",
		        "sequence_path": "236234.protein.sequences.v11.5.fa",
		        "enrichment_path": "236234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "236234.protein.info.v11.5.txt",
		        "node_list_path": "236234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "236234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OoceraeaBiroi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ooceraea biroi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OoceraeaBiroi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2015173.protein.sequences.v11.5.fa",
		        "enrichment_path": "2015173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2015173.protein.info.v11.5.txt",
		        "node_list_path": "2015173.protein.complete.v11.5.txt"
		    }
		]
    )()

def LabrusBergylta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Labrus bergylta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrusBergylta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56723.protein.sequences.v11.5.fa",
		        "enrichment_path": "56723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56723.protein.info.v11.5.txt",
		        "node_list_path": "56723.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoculleusSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1550566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550566.protein.info.v11.5.txt",
		        "node_list_path": "1550566.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAmmoniagenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium ammoniagenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAmmoniagenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649754.clusters.proteins.v11.5.txt",
		        "sequence_path": "649754.protein.sequences.v11.5.fa",
		        "enrichment_path": "649754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649754.protein.info.v11.5.txt",
		        "node_list_path": "649754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_40_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801773.protein.info.v11.5.txt",
		        "node_list_path": "1801773.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseivivaxHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93684.clusters.proteins.v11.5.txt",
		        "sequence_path": "93684.protein.sequences.v11.5.fa",
		        "enrichment_path": "93684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93684.protein.info.v11.5.txt",
		        "node_list_path": "93684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRedseaS39B2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. REDSEA-S39_B2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRedseaS39B2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811558.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811558.protein.info.v11.5.txt",
		        "node_list_path": "1811558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMutansGs5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mutans GS5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMutansGs5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1198676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1198676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1198676.clusters.proteins.v11.5.txt",
		        "sequence_path": "1198676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198676.protein.info.v11.5.txt",
		        "node_list_path": "1198676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1198676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFjat27812Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FJAT-27812 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFjat27812Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1684143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1684143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1684143.clusters.proteins.v11.5.txt",
		        "sequence_path": "1684143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1684143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1684143.protein.info.v11.5.txt",
		        "node_list_path": "1684143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1684143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag724(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:724 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag724", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262966.protein.info.v11.5.txt",
		        "node_list_path": "1262966.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumMedpeSwsndG1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium MedPE-SWsnd-G1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumMedpeSwsndG1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1860094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1860094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1860094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1860094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860094.protein.info.v11.5.txt",
		        "node_list_path": "1860094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1860094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full4414(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_44_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full4414", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802525.protein.info.v11.5.txt",
		        "node_list_path": "1802525.protein.complete.v11.5.txt"
		    }
		]
    )()

def PasteurellaMultocidaSubspMultocidaStrPm70Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida subsp. multocida str. Pm70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaMultocidaSubspMultocidaStrPm70Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272843.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272843.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272843.clusters.proteins.v11.5.txt",
		        "sequence_path": "272843.protein.sequences.v11.5.fa",
		        "enrichment_path": "272843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272843.protein.info.v11.5.txt",
		        "node_list_path": "272843.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272843.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanothermobacterWolfeii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter wolfeii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermobacterWolfeii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "145261.protein.sequences.v11.5.fa",
		        "enrichment_path": "145261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "145261.protein.info.v11.5.txt",
		        "node_list_path": "145261.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusAquimarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus aquimarinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusAquimarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "237018.protein.sequences.v11.5.fa",
		        "enrichment_path": "237018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237018.protein.info.v11.5.txt",
		        "node_list_path": "237018.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpCf385(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. CF385 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpCf385", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881042.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881042.protein.info.v11.5.txt",
		        "node_list_path": "1881042.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumAngstadtii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium angstadtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumAngstadtii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "558151.protein.sequences.v11.5.fa",
		        "enrichment_path": "558151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558151.protein.info.v11.5.txt",
		        "node_list_path": "558151.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetradesmusObliquus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetradesmus obliquus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetradesmusObliquus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3088.protein.sequences.v11.5.fa",
		        "enrichment_path": "3088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3088.protein.info.v11.5.txt",
		        "node_list_path": "3088.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaSpKtr9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sp. KTR9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSpKtr9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "337191.protein.sequences.v11.5.fa",
		        "enrichment_path": "337191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "337191.protein.info.v11.5.txt",
		        "node_list_path": "337191.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraTerpstraeSerovarHualinStrLt1133Atcc700639(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira terpstrae serovar Hualin str. LT 11-33 ATCC 700639 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraTerpstraeSerovarHualinStrLt1133Atcc700639", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1257025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1257025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1257025.protein.info.v11.5.txt",
		        "node_list_path": "1257025.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarum248Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum 248 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarum248Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936136.clusters.info.v11.0.txt",
		        "cluster_tree_path": "936136.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "936136.clusters.proteins.v11.0.txt",
		        "sequence_path": "936136.protein.sequences.v11.0.fa",
		        "enrichment_path": "936136.protein.enrichment.terms.v11.0.txt",
		        "info_path": "936136.protein.info.v11.0.txt",
		        "node_list_path": "936136.cluster.nodes.v11.0.txt",
		        "edge_list_path": "936136.protein.cluster.v11.0.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4655(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4655 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4655", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977878.protein.info.v11.5.txt",
		        "node_list_path": "1977878.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrososphaeraGargensisGa92Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrososphaera gargensis Ga9.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrososphaeraGargensisGa92Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1237085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1237085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1237085.clusters.proteins.v11.5.txt",
		        "sequence_path": "1237085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1237085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1237085.protein.info.v11.5.txt",
		        "node_list_path": "1237085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1237085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho201Full4010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_40_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798593.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798593.protein.info.v11.5.txt",
		        "node_list_path": "1798593.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusBeddingii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus beddingii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusBeddingii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40578.protein.sequences.v11.5.fa",
		        "enrichment_path": "40578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40578.protein.info.v11.5.txt",
		        "node_list_path": "40578.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusPallensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus pallens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusPallensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158607.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158607.protein.info.v11.5.txt",
		        "node_list_path": "1158607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaminicellaSporogenesDsm14501(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caminicella sporogenes DSM 14501 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaminicellaSporogenesDsm14501", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121266.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121266.protein.info.v11.5.txt",
		        "node_list_path": "1121266.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpAcam123Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. ACAM123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpAcam123Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1189620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1189620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1189620.clusters.proteins.v11.5.txt",
		        "sequence_path": "1189620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1189620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1189620.protein.info.v11.5.txt",
		        "node_list_path": "1189620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1189620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801775.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801775.protein.info.v11.5.txt",
		        "node_list_path": "1801775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumCdBkt12695Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum CD BKT12695 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumCdBkt12695Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1443125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1443125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1443125.clusters.proteins.v11.5.txt",
		        "sequence_path": "1443125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443125.protein.info.v11.5.txt",
		        "node_list_path": "1443125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1443125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeminocystisSpNies3708(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geminocystis sp. NIES-3708 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeminocystisSpNies3708", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1615909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1615909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1615909.protein.info.v11.5.txt",
		        "node_list_path": "1615909.protein.complete.v11.5.txt"
		    }
		]
    )()

def EntamoebaHistolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Entamoeba histolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EntamoebaHistolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5759.clusters.proteins.v11.5.txt",
		        "sequence_path": "5759.protein.sequences.v11.5.fa",
		        "enrichment_path": "5759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5759.protein.info.v11.5.txt",
		        "node_list_path": "5759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelomonasSpRoot662Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root662 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelomonasSpRoot662Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736580.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736580.protein.info.v11.5.txt",
		        "node_list_path": "1736580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomicrobiumBuryatense5g(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomicrobium buryatense 5G graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomicrobiumBuryatense5g", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675511.protein.sequences.v11.5.fa",
		        "enrichment_path": "675511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675511.protein.info.v11.5.txt",
		        "node_list_path": "675511.protein.complete.v11.5.txt"
		    }
		]
    )()

def TilletiopsisWashingtonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tilletiopsis washingtonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TilletiopsisWashingtonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "58919.protein.sequences.v11.5.fa",
		        "enrichment_path": "58919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58919.protein.info.v11.5.txt",
		        "node_list_path": "58919.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioVersutus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio versutus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioVersutus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "106634.protein.sequences.v11.5.fa",
		        "enrichment_path": "106634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106634.protein.info.v11.5.txt",
		        "node_list_path": "106634.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesOnderdonkiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes onderdonkii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesOnderdonkiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203611.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203611.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203611.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203611.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203611.protein.info.v11.5.txt",
		        "node_list_path": "1203611.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203611.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaAnthophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea anthophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaAnthophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "470931.protein.sequences.v11.5.fa",
		        "enrichment_path": "470931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "470931.protein.info.v11.5.txt",
		        "node_list_path": "470931.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosphaeraStadtmanaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosphaera stadtmanae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosphaeraStadtmanaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "339860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "339860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "339860.clusters.proteins.v11.5.txt",
		        "sequence_path": "339860.protein.sequences.v11.5.fa",
		        "enrichment_path": "339860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "339860.protein.info.v11.5.txt",
		        "node_list_path": "339860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "339860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpIbvhs1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. IBVHS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpIbvhs1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1985169.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1985169.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1985169.clusters.proteins.v11.5.txt",
		        "sequence_path": "1985169.protein.sequences.v11.5.fa",
		        "enrichment_path": "1985169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1985169.protein.info.v11.5.txt",
		        "node_list_path": "1985169.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1985169.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeofilumRubicundumJcm15548Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geofilum rubicundum JCM 15548 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeofilumRubicundumJcm15548Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236989.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236989.protein.info.v11.5.txt",
		        "node_list_path": "1236989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudospirillumJaponicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudospirillum japonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudospirillumJaponicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "64971.protein.sequences.v11.5.fa",
		        "enrichment_path": "64971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64971.protein.info.v11.5.txt",
		        "node_list_path": "64971.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumTropici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium tropici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumTropici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "698761.protein.sequences.v11.5.fa",
		        "enrichment_path": "698761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698761.protein.info.v11.5.txt",
		        "node_list_path": "698761.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacteraceaeBacteriumGomA1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacteraceae bacterium GOM-A1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacteraceaeBacteriumGomA1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1696173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1696173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1696173.protein.info.v11.5.txt",
		        "node_list_path": "1696173.protein.complete.v11.5.txt"
		    }
		]
    )()

def FodinicurvataSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fodinicurvata sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FodinicurvataSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "570952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "570952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "570952.clusters.proteins.v11.5.txt",
		        "sequence_path": "570952.protein.sequences.v11.5.fa",
		        "enrichment_path": "570952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570952.protein.info.v11.5.txt",
		        "node_list_path": "570952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "570952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAcidicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus acidicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAcidicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "209389.clusters.info.v11.5.txt",
		        "cluster_tree_path": "209389.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "209389.clusters.proteins.v11.5.txt",
		        "sequence_path": "209389.protein.sequences.v11.5.fa",
		        "enrichment_path": "209389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "209389.protein.info.v11.5.txt",
		        "node_list_path": "209389.cluster.nodes.v11.5.txt",
		        "edge_list_path": "209389.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoleophilumAlbum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoleophilum album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoleophilumAlbum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29539.protein.sequences.v11.5.fa",
		        "enrichment_path": "29539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29539.protein.info.v11.5.txt",
		        "node_list_path": "29539.protein.complete.v11.5.txt"
		    }
		]
    )()

def GranulicellaTundricola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Granulicella tundricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicellaTundricola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1198114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198114.protein.info.v11.5.txt",
		        "node_list_path": "1198114.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusVogelbacteriaBacteriumRifoxyb1Full4216Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYB1_FULL_42_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyb1Full4216Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802436.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802436.protein.info.v11.5.txt",
		        "node_list_path": "1802436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusInfantisSk1076(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis SK1076 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusInfantisSk1076", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005705.protein.info.v11.5.txt",
		        "node_list_path": "1005705.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedRuminococcusSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Ruminococcus sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedRuminococcusSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "165186.protein.sequences.v11.5.fa",
		        "enrichment_path": "165186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "165186.protein.info.v11.5.txt",
		        "node_list_path": "165186.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaSechellia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila sechellia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaSechellia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7238.protein.sequences.v11.5.fa",
		        "enrichment_path": "7238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7238.protein.info.v11.5.txt",
		        "node_list_path": "7238.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusPseudintermediusHku1003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus pseudintermedius HKU10-03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusPseudintermediusHku1003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "937773.protein.sequences.v11.5.fa",
		        "enrichment_path": "937773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937773.protein.info.v11.5.txt",
		        "node_list_path": "937773.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoplanesFriuliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes friuliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesFriuliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246995.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246995.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246995.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246995.protein.info.v11.5.txt",
		        "node_list_path": "1246995.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246995.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasCorrugata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas corrugata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCorrugata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1316927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1316927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1316927.protein.info.v11.5.txt",
		        "node_list_path": "1316927.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusGigeriorumDsm23908Crbip2485(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gigeriorum DSM 23908 CRBIP 24.85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGigeriorumDsm23908Crbip2485", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423751.protein.info.v11.5.txt",
		        "node_list_path": "1423751.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinokineosporaBangkokensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora bangkokensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinokineosporaBangkokensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193682.protein.info.v11.5.txt",
		        "node_list_path": "1193682.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaedibacterSp3749(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caedibacter sp. 37-49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaedibacterSp3749", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895735.protein.info.v11.5.txt",
		        "node_list_path": "1895735.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonopterusAlbus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monopterus albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonopterusAlbus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43700.protein.sequences.v11.5.fa",
		        "enrichment_path": "43700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43700.protein.info.v11.5.txt",
		        "node_list_path": "43700.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseofilumReptotaeniumAo1ACluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseofilum reptotaenium AO1-A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseofilumReptotaeniumAo1ACluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1925591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1925591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1925591.clusters.proteins.v11.5.txt",
		        "sequence_path": "1925591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1925591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1925591.protein.info.v11.5.txt",
		        "node_list_path": "1925591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1925591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumMicromati(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium micromati graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumMicromati", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "229205.protein.sequences.v11.5.fa",
		        "enrichment_path": "229205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229205.protein.info.v11.5.txt",
		        "node_list_path": "229205.protein.complete.v11.5.txt"
		    }
		]
    )()

def NosemaCeranaeBrl01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nosema ceranae BRL01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NosemaCeranaeBrl01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "578460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "578460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "578460.clusters.proteins.v11.5.txt",
		        "sequence_path": "578460.protein.sequences.v11.5.fa",
		        "enrichment_path": "578460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578460.protein.info.v11.5.txt",
		        "node_list_path": "578460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "578460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureimonasAltamirensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas altamirensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasAltamirensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "370622.clusters.info.v11.5.txt",
		        "cluster_tree_path": "370622.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "370622.clusters.proteins.v11.5.txt",
		        "sequence_path": "370622.protein.sequences.v11.5.fa",
		        "enrichment_path": "370622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "370622.protein.info.v11.5.txt",
		        "node_list_path": "370622.cluster.nodes.v11.5.txt",
		        "edge_list_path": "370622.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyclobacteriumMarinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacterium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyclobacteriumMarinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "880070.clusters.info.v11.5.txt",
		        "cluster_tree_path": "880070.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "880070.clusters.proteins.v11.5.txt",
		        "sequence_path": "880070.protein.sequences.v11.5.fa",
		        "enrichment_path": "880070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880070.protein.info.v11.5.txt",
		        "node_list_path": "880070.cluster.nodes.v11.5.txt",
		        "edge_list_path": "880070.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumScgcAaa300K03(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium SCGC AAA300-K03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumScgcAaa300K03", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "939909.protein.sequences.v11.5.fa",
		        "enrichment_path": "939909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939909.protein.info.v11.5.txt",
		        "node_list_path": "939909.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerpentinomonasMccroryiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serpentinomonas mccroryi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerpentinomonasMccroryiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1458426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1458426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1458426.clusters.proteins.v11.5.txt",
		        "sequence_path": "1458426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458426.protein.info.v11.5.txt",
		        "node_list_path": "1458426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1458426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDadabacteriaBacteriumCsp12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dadabacteria bacterium CSP1-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDadabacteriaBacteriumCsp12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1640508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1640508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1640508.clusters.proteins.v11.5.txt",
		        "sequence_path": "1640508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640508.protein.info.v11.5.txt",
		        "node_list_path": "1640508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1640508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMassilioanorexiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus massilioanorexius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMassilioanorexiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211814.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211814.protein.info.v11.5.txt",
		        "node_list_path": "1211814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAfermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium afermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAfermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "38286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "38286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "38286.clusters.proteins.v11.5.txt",
		        "sequence_path": "38286.protein.sequences.v11.5.fa",
		        "enrichment_path": "38286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38286.protein.info.v11.5.txt",
		        "node_list_path": "38286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "38286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrnithorhynchusAnatinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ornithorhynchus anatinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithorhynchusAnatinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9258.protein.sequences.v11.5.fa",
		        "enrichment_path": "9258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9258.protein.info.v11.5.txt",
		        "node_list_path": "9258.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaKandleriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella kandleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaKandleriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1616.clusters.proteins.v11.5.txt",
		        "sequence_path": "1616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1616.protein.info.v11.5.txt",
		        "node_list_path": "1616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LoktanellaVestfoldensisSka53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella vestfoldensis SKA53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaVestfoldensisSka53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314232.clusters.proteins.v11.5.txt",
		        "sequence_path": "314232.protein.sequences.v11.5.fa",
		        "enrichment_path": "314232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314232.protein.info.v11.5.txt",
		        "node_list_path": "314232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaSpL21rpuld2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta sp. L21RPulD2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaSpL21rpuld2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1307761.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307761.protein.info.v11.5.txt",
		        "node_list_path": "1307761.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaCynodegmiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga cynodegmi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaCynodegmiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926551.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926551.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926551.clusters.proteins.v11.5.txt",
		        "sequence_path": "926551.protein.sequences.v11.5.fa",
		        "enrichment_path": "926551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926551.protein.info.v11.5.txt",
		        "node_list_path": "926551.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926551.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpNd1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. ND1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpNd1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658518.protein.info.v11.5.txt",
		        "node_list_path": "1658518.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterGottschalkiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter gottschalkii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterGottschalkiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "190974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "190974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "190974.clusters.proteins.v11.5.txt",
		        "sequence_path": "190974.protein.sequences.v11.5.fa",
		        "enrichment_path": "190974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190974.protein.info.v11.5.txt",
		        "node_list_path": "190974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "190974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PiriformosporaIndicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Piriformospora indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiriformosporaIndicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "65672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "65672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "65672.clusters.proteins.v11.5.txt",
		        "sequence_path": "65672.protein.sequences.v11.5.fa",
		        "enrichment_path": "65672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65672.protein.info.v11.5.txt",
		        "node_list_path": "65672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "65672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4999(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4999 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4999", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977882.protein.info.v11.5.txt",
		        "node_list_path": "1977882.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumGw2011Gwa24314Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA2_43_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa24314Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618443.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618443.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618443.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618443.protein.info.v11.5.txt",
		        "node_list_path": "1618443.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618443.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaMedium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema medium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaMedium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125700.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125700.protein.info.v11.5.txt",
		        "node_list_path": "1125700.protein.complete.v11.5.txt"
		    }
		]
    )()

def RubrivivaxSpScn71131(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubrivivax sp. SCN 71-131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrivivaxSpScn71131", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660138.protein.info.v11.5.txt",
		        "node_list_path": "1660138.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095767.protein.info.v11.5.txt",
		        "node_list_path": "1095767.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesPurpureus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces purpureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPurpureus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1054860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1054860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1054860.protein.info.v11.5.txt",
		        "node_list_path": "1054860.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfolobalesArchaeonAcd1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobales archaeon Acd1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobalesArchaeonAcd1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1294123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1294123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1294123.clusters.proteins.v11.5.txt",
		        "sequence_path": "1294123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294123.protein.info.v11.5.txt",
		        "node_list_path": "1294123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1294123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNcu2d2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NCu2D-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNcu2d2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1608473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1608473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1608473.clusters.proteins.v11.5.txt",
		        "sequence_path": "1608473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608473.protein.info.v11.5.txt",
		        "node_list_path": "1608473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1608473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlaciecolaPallidulaDsm14239Acam615(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola pallidula DSM 14239 ACAM 615 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaPallidulaDsm14239Acam615", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121922.protein.info.v11.5.txt",
		        "node_list_path": "1121922.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaGariniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia garinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaGariniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290434.clusters.proteins.v11.5.txt",
		        "sequence_path": "290434.protein.sequences.v11.5.fa",
		        "enrichment_path": "290434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290434.protein.info.v11.5.txt",
		        "node_list_path": "290434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyripristisMurdjan(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myripristis murdjan graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyripristisMurdjan", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "586833.protein.sequences.v11.5.fa",
		        "enrichment_path": "586833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "586833.protein.info.v11.5.txt",
		        "node_list_path": "586833.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaOralisHga0225Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oralis HGA0225 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOralisHga0225Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203550.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203550.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203550.protein.info.v11.5.txt",
		        "node_list_path": "1203550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusBvHnlc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus bv. HNLC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusBvHnlc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041938.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041938.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041938.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041938.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041938.protein.info.v11.5.txt",
		        "node_list_path": "1041938.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041938.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EuryarchaeotaArchaeonRbg135723Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_13_57_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EuryarchaeotaArchaeonRbg135723Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797977.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797977.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797977.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797977.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797977.protein.info.v11.5.txt",
		        "node_list_path": "1797977.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797977.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSoil763(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil763 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSoil763", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736402.protein.info.v11.5.txt",
		        "node_list_path": "1736402.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemmatimonadetesBacterium13220cm2657Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium 13_2_20CM_2_65_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonadetesBacterium13220cm2657Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805202.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805202.protein.info.v11.5.txt",
		        "node_list_path": "1805202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRbg136816Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RBG_13_68_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRbg136816Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797171.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797171.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797171.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797171.protein.info.v11.5.txt",
		        "node_list_path": "1797171.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797171.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychromonasSpCnpt3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas sp. CNPT3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychromonasSpCnpt3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314282.protein.sequences.v11.5.fa",
		        "enrichment_path": "314282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314282.protein.info.v11.5.txt",
		        "node_list_path": "314282.protein.complete.v11.5.txt"
		    }
		]
    )()

def CebusCapucinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cebus capucinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CebusCapucinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9516.protein.sequences.v11.5.fa",
		        "enrichment_path": "9516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9516.protein.info.v11.5.txt",
		        "node_list_path": "9516.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosopumilusMaritimusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus maritimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopumilusMaritimusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "436308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "436308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "436308.clusters.proteins.v11.5.txt",
		        "sequence_path": "436308.protein.sequences.v11.5.fa",
		        "enrichment_path": "436308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436308.protein.info.v11.5.txt",
		        "node_list_path": "436308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "436308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpCc6Yy74(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CC6-YY-74 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpCc6Yy74", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930532.protein.info.v11.5.txt",
		        "node_list_path": "1930532.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaMonocytogenesEgdeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria monocytogenes EGDe Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaMonocytogenesEgdeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "169963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "169963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "169963.clusters.proteins.v11.5.txt",
		        "sequence_path": "169963.protein.sequences.v11.5.fa",
		        "enrichment_path": "169963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "169963.protein.info.v11.5.txt",
		        "node_list_path": "169963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "169963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoriobacteriaceaeBacteriumChkci002Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium CHKCI002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacteriaceaeBacteriumChkci002Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1780377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1780377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1780377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1780377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780377.protein.info.v11.5.txt",
		        "node_list_path": "1780377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1780377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCdtb01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CdTB01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCdtb01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1725411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1725411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1725411.clusters.proteins.v11.5.txt",
		        "sequence_path": "1725411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1725411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1725411.protein.info.v11.5.txt",
		        "node_list_path": "1725411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1725411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaOnionYellowsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma onion yellows Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaOnionYellowsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262768.clusters.info.v11.0.txt",
		        "cluster_tree_path": "262768.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "262768.clusters.proteins.v11.0.txt",
		        "sequence_path": "262768.protein.sequences.v11.0.fa",
		        "enrichment_path": "262768.protein.enrichment.terms.v11.0.txt",
		        "info_path": "262768.protein.info.v11.0.txt",
		        "node_list_path": "262768.cluster.nodes.v11.0.txt",
		        "edge_list_path": "262768.protein.cluster.v11.0.txt"
		    }
		]
    )()

def SecondaryEndosymbiontOfHeteropsyllaCubanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Heteropsylla cubana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SecondaryEndosymbiontOfHeteropsyllaCubanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "134287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "134287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "134287.clusters.proteins.v11.5.txt",
		        "sequence_path": "134287.protein.sequences.v11.5.fa",
		        "enrichment_path": "134287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134287.protein.info.v11.5.txt",
		        "node_list_path": "134287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "134287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraMultiparaLb2003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospira multipara LB2003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraMultiparaLb2003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410661.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410661.protein.info.v11.5.txt",
		        "node_list_path": "1410661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaSpCulexCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Culex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaSpCulexCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "570417.clusters.info.v11.0.txt",
		        "cluster_tree_path": "570417.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "570417.clusters.proteins.v11.0.txt",
		        "sequence_path": "570417.protein.sequences.v11.0.fa",
		        "enrichment_path": "570417.protein.enrichment.terms.v11.0.txt",
		        "info_path": "570417.protein.info.v11.0.txt",
		        "node_list_path": "570417.cluster.nodes.v11.0.txt",
		        "edge_list_path": "570417.protein.cluster.v11.0.txt"
		    }
		]
    )()

def SphingomonasSpScn6718(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SCN 67-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpScn6718", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660141.protein.info.v11.5.txt",
		        "node_list_path": "1660141.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusJeojiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus jeojiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusJeojiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "436229.protein.sequences.v11.5.fa",
		        "enrichment_path": "436229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436229.protein.info.v11.5.txt",
		        "node_list_path": "436229.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesFinegoldii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes finegoldii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesFinegoldii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679935.protein.sequences.v11.5.fa",
		        "enrichment_path": "679935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679935.protein.info.v11.5.txt",
		        "node_list_path": "679935.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusNematophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus nematophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusNematophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "406817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "406817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "406817.clusters.proteins.v11.5.txt",
		        "sequence_path": "406817.protein.sequences.v11.5.fa",
		        "enrichment_path": "406817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406817.protein.info.v11.5.txt",
		        "node_list_path": "406817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "406817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinosporangiumSpNrrlb3428(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinosporangium sp. NRRLB3428 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinosporangiumSpNrrlb3428", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463820.protein.info.v11.5.txt",
		        "node_list_path": "1463820.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolirubrobacteralesBacteriumUrhd0059Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solirubrobacterales bacterium URHD0059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolirubrobacteralesBacteriumUrhd0059Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380390.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380390.protein.info.v11.5.txt",
		        "node_list_path": "1380390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumCanariense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium canariense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumCanariense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "255045.protein.sequences.v11.5.fa",
		        "enrichment_path": "255045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "255045.protein.info.v11.5.txt",
		        "node_list_path": "255045.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumAcamd5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium acAMD5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumAcamd5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1504319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1504319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1504319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1504319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504319.protein.info.v11.5.txt",
		        "node_list_path": "1504319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1504319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag780(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:780 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag780", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262839.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262839.protein.info.v11.5.txt",
		        "node_list_path": "1262839.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusMalefermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus malefermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMalefermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122149.protein.info.v11.5.txt",
		        "node_list_path": "1122149.protein.complete.v11.5.txt"
		    }
		]
    )()

def KurthiaSpDielmoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kurthia sp. Dielmo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KurthiaSpDielmoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033738.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033738.protein.info.v11.5.txt",
		        "node_list_path": "1033738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasKorlensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas korlensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasKorlensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "463301.protein.sequences.v11.5.fa",
		        "enrichment_path": "463301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "463301.protein.info.v11.5.txt",
		        "node_list_path": "463301.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho212Full4219(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_12_FULL_42_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho212Full4219", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801762.protein.info.v11.5.txt",
		        "node_list_path": "1801762.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag43Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag43Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262805.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262805.protein.info.v11.5.txt",
		        "node_list_path": "1262805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumSolitum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium solitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumSolitum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "60172.protein.sequences.v11.5.fa",
		        "enrichment_path": "60172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60172.protein.info.v11.5.txt",
		        "node_list_path": "60172.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumArthrosphaerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium arthrosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumArthrosphaerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "651561.protein.sequences.v11.5.fa",
		        "enrichment_path": "651561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "651561.protein.info.v11.5.txt",
		        "node_list_path": "651561.protein.complete.v11.5.txt"
		    }
		]
    )()

def PichiaMembranifaciensNrrlY2026Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pichia membranifaciens NRRL Y-2026 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PichiaMembranifaciensNrrlY2026Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "763406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "763406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "763406.clusters.proteins.v11.5.txt",
		        "sequence_path": "763406.protein.sequences.v11.5.fa",
		        "enrichment_path": "763406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "763406.protein.info.v11.5.txt",
		        "node_list_path": "763406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "763406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusBuchneriCd034(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri CD034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBuchneriCd034", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071400.protein.info.v11.5.txt",
		        "node_list_path": "1071400.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumFioriniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum fioriniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumFioriniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "710243.protein.sequences.v11.5.fa",
		        "enrichment_path": "710243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710243.protein.info.v11.5.txt",
		        "node_list_path": "710243.protein.complete.v11.5.txt"
		    }
		]
    )()

def NakamurellaPanacisegetis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nakamurella panacisegetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NakamurellaPanacisegetis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1090615.protein.sequences.v11.5.fa",
		        "enrichment_path": "1090615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1090615.protein.info.v11.5.txt",
		        "node_list_path": "1090615.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpWsm3626(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. WSM3626 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpWsm3626", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1040987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1040987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1040987.protein.info.v11.5.txt",
		        "node_list_path": "1040987.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumGenitaliumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium genitalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumGenitaliumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585529.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585529.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585529.clusters.proteins.v11.5.txt",
		        "sequence_path": "585529.protein.sequences.v11.5.fa",
		        "enrichment_path": "585529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585529.protein.info.v11.5.txt",
		        "node_list_path": "585529.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585529.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobiusVermicularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobius vermicularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobiusVermicularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "51028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "51028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "51028.clusters.proteins.v11.5.txt",
		        "sequence_path": "51028.protein.sequences.v11.5.fa",
		        "enrichment_path": "51028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51028.protein.info.v11.5.txt",
		        "node_list_path": "51028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "51028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumPapyrosolvens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium papyrosolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPapyrosolvens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "588581.protein.sequences.v11.5.fa",
		        "enrichment_path": "588581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588581.protein.info.v11.5.txt",
		        "node_list_path": "588581.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErysipelothrixRhusiopathiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysipelothrix rhusiopathiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelothrixRhusiopathiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "650150.clusters.info.v11.5.txt",
		        "cluster_tree_path": "650150.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "650150.clusters.proteins.v11.5.txt",
		        "sequence_path": "650150.protein.sequences.v11.5.fa",
		        "enrichment_path": "650150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "650150.protein.info.v11.5.txt",
		        "node_list_path": "650150.cluster.nodes.v11.5.txt",
		        "edge_list_path": "650150.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivivaxIsoporaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax isoporae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxIsoporaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449351.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449351.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449351.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449351.protein.info.v11.5.txt",
		        "node_list_path": "1449351.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449351.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpLfm046(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. LFM046 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpLfm046", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1608357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608357.protein.info.v11.5.txt",
		        "node_list_path": "1608357.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasMendocinaEgdaq5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina EGDAQ5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMendocinaEgdaq5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1390370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1390370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1390370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1390370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1390370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1390370.protein.info.v11.5.txt",
		        "node_list_path": "1390370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1390370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaEntomophagaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia entomophaga Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaEntomophagaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935293.clusters.proteins.v11.5.txt",
		        "sequence_path": "935293.protein.sequences.v11.5.fa",
		        "enrichment_path": "935293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935293.protein.info.v11.5.txt",
		        "node_list_path": "935293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SilicibacterSpTrichch4b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Silicibacter sp. TrichCH4B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SilicibacterSpTrichch4b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644076.protein.sequences.v11.5.fa",
		        "enrichment_path": "644076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644076.protein.info.v11.5.txt",
		        "node_list_path": "644076.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaAlbicansSc5314Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida albicans SC5314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaAlbicansSc5314Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "237561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "237561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "237561.clusters.proteins.v11.5.txt",
		        "sequence_path": "237561.protein.sequences.v11.5.fa",
		        "enrichment_path": "237561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237561.protein.info.v11.5.txt",
		        "node_list_path": "237561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "237561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpBsc265Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. BSC265 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpBsc265Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1549812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1549812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1549812.clusters.proteins.v11.5.txt",
		        "sequence_path": "1549812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1549812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1549812.protein.info.v11.5.txt",
		        "node_list_path": "1549812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1549812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SorangiumCellulosumSoCe56(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sorangium cellulosum So ce56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SorangiumCellulosumSoCe56", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "448385.protein.sequences.v11.5.fa",
		        "enrichment_path": "448385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "448385.protein.info.v11.5.txt",
		        "node_list_path": "448385.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwa25412Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_54_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25412Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797808.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797808.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797808.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797808.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797808.protein.info.v11.5.txt",
		        "node_list_path": "1797808.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797808.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusAnginosusC238(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus C238 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAnginosusC238", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "862971.protein.sequences.v11.5.fa",
		        "enrichment_path": "862971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862971.protein.info.v11.5.txt",
		        "node_list_path": "862971.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBohemicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter bohemicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBohemicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217715.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217715.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217715.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217715.protein.info.v11.5.txt",
		        "node_list_path": "1217715.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217715.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200251163Sch5372311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-51163_SCH5372311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200251163Sch5372311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834097.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834097.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834097.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834097.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834097.protein.info.v11.5.txt",
		        "node_list_path": "1834097.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834097.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1848.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1848.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1848.clusters.proteins.v11.5.txt",
		        "sequence_path": "1848.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848.protein.info.v11.5.txt",
		        "node_list_path": "1848.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1848.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaMegapolitana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia megapolitana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaMegapolitana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "420953.protein.sequences.v11.5.fa",
		        "enrichment_path": "420953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420953.protein.info.v11.5.txt",
		        "node_list_path": "420953.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpAr710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. AR7-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpAr710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1891970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1891970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1891970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1891970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891970.protein.info.v11.5.txt",
		        "node_list_path": "1891970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1891970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesVitaminophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces vitaminophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesVitaminophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123322.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123322.protein.info.v11.5.txt",
		        "node_list_path": "1123322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KytococcusSedentarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kytococcus sedentarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KytococcusSedentarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "478801.protein.sequences.v11.5.fa",
		        "enrichment_path": "478801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "478801.protein.info.v11.5.txt",
		        "node_list_path": "478801.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpB6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. B6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpB6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1295626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1295626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1295626.clusters.proteins.v11.5.txt",
		        "sequence_path": "1295626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1295626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1295626.protein.info.v11.5.txt",
		        "node_list_path": "1295626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1295626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpMp1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. MP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpMp1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1458357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458357.protein.info.v11.5.txt",
		        "node_list_path": "1458357.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpMb200(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. MB200 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpMb200", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "648885.protein.sequences.v11.5.fa",
		        "enrichment_path": "648885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "648885.protein.info.v11.5.txt",
		        "node_list_path": "648885.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldimonasManganoxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldimonas manganoxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldimonasManganoxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265502.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265502.protein.info.v11.5.txt",
		        "node_list_path": "1265502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcaceaeBacteriumW5053(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium W5053 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcaceaeBacteriumW5053", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321784.protein.info.v11.5.txt",
		        "node_list_path": "1321784.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumRbg19ftCombo4210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RBG_19FT_COMBO_42_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumRbg19ftCombo4210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797359.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797359.protein.info.v11.5.txt",
		        "node_list_path": "1797359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifoxyb12Full507(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFOXYB12_FULL_50_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifoxyb12Full507", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801835.protein.info.v11.5.txt",
		        "node_list_path": "1801835.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIs1496(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1496 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIs1496", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1772284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772284.protein.info.v11.5.txt",
		        "node_list_path": "1772284.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusFarraginisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus farraginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusFarraginisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "254757.clusters.info.v11.5.txt",
		        "cluster_tree_path": "254757.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "254757.clusters.proteins.v11.5.txt",
		        "sequence_path": "254757.protein.sequences.v11.5.fa",
		        "enrichment_path": "254757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "254757.protein.info.v11.5.txt",
		        "node_list_path": "254757.cluster.nodes.v11.5.txt",
		        "edge_list_path": "254757.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyphaciaMurisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syphacia muris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyphaciaMurisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "451379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "451379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "451379.clusters.proteins.v11.5.txt",
		        "sequence_path": "451379.protein.sequences.v11.5.fa",
		        "enrichment_path": "451379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "451379.protein.info.v11.5.txt",
		        "node_list_path": "451379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "451379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraParasiticaInra310(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora parasitica INRA-310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraParasiticaInra310", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "761204.protein.sequences.v11.5.fa",
		        "enrichment_path": "761204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "761204.protein.info.v11.5.txt",
		        "node_list_path": "761204.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPasteurianusAtcc43144Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pasteurianus ATCC 43144 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPasteurianusAtcc43144Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "981540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "981540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "981540.clusters.proteins.v11.5.txt",
		        "sequence_path": "981540.protein.sequences.v11.5.fa",
		        "enrichment_path": "981540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981540.protein.info.v11.5.txt",
		        "node_list_path": "981540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "981540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RomboutsiaSpMt17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Romboutsia sp. MT17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RomboutsiaSpMt17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720299.protein.info.v11.5.txt",
		        "node_list_path": "1720299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPectinilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus pectinilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPectinilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "512399.protein.sequences.v11.5.fa",
		        "enrichment_path": "512399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512399.protein.info.v11.5.txt",
		        "node_list_path": "512399.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteribacillusIranensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteribacillus iranensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteribacillusIranensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930128.clusters.proteins.v11.5.txt",
		        "sequence_path": "930128.protein.sequences.v11.5.fa",
		        "enrichment_path": "930128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930128.protein.info.v11.5.txt",
		        "node_list_path": "930128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ValsaMaliVarPyriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Valsa mali var. pyri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ValsaMaliVarPyriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "694573.clusters.info.v11.5.txt",
		        "cluster_tree_path": "694573.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "694573.clusters.proteins.v11.5.txt",
		        "sequence_path": "694573.protein.sequences.v11.5.fa",
		        "enrichment_path": "694573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694573.protein.info.v11.5.txt",
		        "node_list_path": "694573.cluster.nodes.v11.5.txt",
		        "edge_list_path": "694573.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumThermocisternum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum thermocisternum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumThermocisternum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121430.protein.info.v11.5.txt",
		        "node_list_path": "1121430.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpLkl04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. LKL04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpLkl04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "912630.protein.sequences.v11.5.fa",
		        "enrichment_path": "912630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "912630.protein.info.v11.5.txt",
		        "node_list_path": "912630.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoritellaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moritella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoritellaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1202962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202962.protein.info.v11.5.txt",
		        "node_list_path": "1202962.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterFulvus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter fulvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterFulvus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163408.protein.info.v11.5.txt",
		        "node_list_path": "1163408.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmodiumCynomolgi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium cynomolgi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumCynomolgi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5827.protein.sequences.v11.5.fa",
		        "enrichment_path": "5827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5827.protein.info.v11.5.txt",
		        "node_list_path": "5827.protein.complete.v11.5.txt"
		    }
		]
    )()

def AchromobacterXylosoxidansNbrc15126Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans NBRC15126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterXylosoxidansNbrc15126Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216976.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216976.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216976.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216976.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216976.protein.info.v11.5.txt",
		        "node_list_path": "1216976.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216976.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlobicatellaSulfidifaciensDsm15739(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Globicatella sulfidifaciens DSM 15739 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlobicatellaSulfidifaciensDsm15739", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121925.protein.info.v11.5.txt",
		        "node_list_path": "1121925.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpP11g3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. P11G3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpP11g3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1699623.protein.sequences.v11.5.fa",
		        "enrichment_path": "1699623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1699623.protein.info.v11.5.txt",
		        "node_list_path": "1699623.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumCaspAlpha6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium casp-alpha6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumCaspAlpha6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1656909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1656909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1656909.protein.info.v11.5.txt",
		        "node_list_path": "1656909.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacillusTrivialisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacillus trivialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacillusTrivialisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798.protein.info.v11.5.txt",
		        "node_list_path": "1798.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionKazanBacteriumRifcsplowo201Full4813Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RIFCSPLOWO2_01_FULL_48_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionKazanBacteriumRifcsplowo201Full4813Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798539.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798539.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798539.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798539.protein.info.v11.5.txt",
		        "node_list_path": "1798539.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798539.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZetaproteobacteriaBacteriumCg1025345Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_53_45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaproteobacteriaBacteriumCg1025345Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805427.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805427.protein.info.v11.5.txt",
		        "node_list_path": "1805427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchleiferiaThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schleiferia thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchleiferiaThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1453500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1453500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1453500.clusters.proteins.v11.5.txt",
		        "sequence_path": "1453500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453500.protein.info.v11.5.txt",
		        "node_list_path": "1453500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1453500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DehalococcoidesSpJdfr56(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides sp. JdFR-56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalococcoidesSpJdfr56", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935049.protein.info.v11.5.txt",
		        "node_list_path": "1935049.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgromycesSpSoil535(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agromyces sp. Soil535 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesSpSoil535", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736390.protein.info.v11.5.txt",
		        "node_list_path": "1736390.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexusSpY3961Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexus sp. Y3961 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexusSpY3961Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "867845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "867845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "867845.clusters.proteins.v11.5.txt",
		        "sequence_path": "867845.protein.sequences.v11.5.fa",
		        "enrichment_path": "867845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867845.protein.info.v11.5.txt",
		        "node_list_path": "867845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "867845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumJeotgali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumJeotgali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "545534.protein.sequences.v11.5.fa",
		        "enrichment_path": "545534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545534.protein.info.v11.5.txt",
		        "node_list_path": "545534.protein.complete.v11.5.txt"
		    }
		]
    )()

def CrenotaleaThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crenotalea thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenotaleaThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1393122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1393122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1393122.protein.info.v11.5.txt",
		        "node_list_path": "1393122.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsphigho202Full4513bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_02_FULL_45_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho202Full4513bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802117.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802117.protein.info.v11.5.txt",
		        "node_list_path": "1802117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ReinekeaBlandensisMed297Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Reinekea blandensis MED297 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ReinekeaBlandensisMed297Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314283.clusters.proteins.v11.5.txt",
		        "sequence_path": "314283.protein.sequences.v11.5.fa",
		        "enrichment_path": "314283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314283.protein.info.v11.5.txt",
		        "node_list_path": "314283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoccidioidesImmitisRmscc2394(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis RMSCC 2394 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesImmitisRmscc2394", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "404692.protein.sequences.v11.5.fa",
		        "enrichment_path": "404692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "404692.protein.info.v11.5.txt",
		        "node_list_path": "404692.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytophthoraKernoviae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora kernoviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraKernoviae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "325452.protein.sequences.v11.5.fa",
		        "enrichment_path": "325452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "325452.protein.info.v11.5.txt",
		        "node_list_path": "325452.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaOrisF0302Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris F0302 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOrisF0302Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649760.clusters.proteins.v11.5.txt",
		        "sequence_path": "649760.protein.sequences.v11.5.fa",
		        "enrichment_path": "649760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649760.protein.info.v11.5.txt",
		        "node_list_path": "649760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodoferaxFerrireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodoferax ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodoferaxFerrireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "338969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "338969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "338969.clusters.proteins.v11.5.txt",
		        "sequence_path": "338969.protein.sequences.v11.5.fa",
		        "enrichment_path": "338969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "338969.protein.info.v11.5.txt",
		        "node_list_path": "338969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "338969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterJeongneungensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter jeongneungensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterJeongneungensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "947309.protein.sequences.v11.5.fa",
		        "enrichment_path": "947309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "947309.protein.info.v11.5.txt",
		        "node_list_path": "947309.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpTc228(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. tc2-28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpTc228", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761888.protein.info.v11.5.txt",
		        "node_list_path": "1761888.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyadobacterAlkalitoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter alkalitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterAlkalitoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121481.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121481.protein.info.v11.5.txt",
		        "node_list_path": "1121481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobaculumGomorrenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobaculum gomorrense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobaculumGomorrenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43928.clusters.proteins.v11.5.txt",
		        "sequence_path": "43928.protein.sequences.v11.5.fa",
		        "enrichment_path": "43928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43928.protein.info.v11.5.txt",
		        "node_list_path": "43928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiocystisViolascensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiocystis violascens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiocystisViolascensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765911.clusters.proteins.v11.5.txt",
		        "sequence_path": "765911.protein.sequences.v11.5.fa",
		        "enrichment_path": "765911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765911.protein.info.v11.5.txt",
		        "node_list_path": "765911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4218Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4218 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4218Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977880.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977880.protein.info.v11.5.txt",
		        "node_list_path": "1977880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumFujikuroiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium fujikuroi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumFujikuroiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5127.clusters.proteins.v11.5.txt",
		        "sequence_path": "5127.protein.sequences.v11.5.fa",
		        "enrichment_path": "5127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5127.protein.info.v11.5.txt",
		        "node_list_path": "5127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfovibrioYellowstoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio yellowstonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfovibrioYellowstoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "289376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "289376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "289376.clusters.proteins.v11.5.txt",
		        "sequence_path": "289376.protein.sequences.v11.5.fa",
		        "enrichment_path": "289376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "289376.protein.info.v11.5.txt",
		        "node_list_path": "289376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "289376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpKk4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. KK4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpKk4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855729.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855729.protein.info.v11.5.txt",
		        "node_list_path": "1855729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaAkari(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia akari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaAkari", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "293614.protein.sequences.v11.5.fa",
		        "enrichment_path": "293614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "293614.protein.info.v11.5.txt",
		        "node_list_path": "293614.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaQuinlivanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella quinlivanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaQuinlivanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45073.protein.sequences.v11.5.fa",
		        "enrichment_path": "45073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45073.protein.info.v11.5.txt",
		        "node_list_path": "45073.protein.complete.v11.5.txt"
		    }
		]
    )()

def StoquefichusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stoquefichus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StoquefichusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211844.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211844.protein.info.v11.5.txt",
		        "node_list_path": "1211844.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasWittichii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas wittichii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasWittichii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "392499.protein.sequences.v11.5.fa",
		        "enrichment_path": "392499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392499.protein.info.v11.5.txt",
		        "node_list_path": "392499.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaSpTm1040Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. TM1040 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaSpTm1040Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "292414.clusters.info.v11.5.txt",
		        "cluster_tree_path": "292414.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "292414.clusters.proteins.v11.5.txt",
		        "sequence_path": "292414.protein.sequences.v11.5.fa",
		        "enrichment_path": "292414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292414.protein.info.v11.5.txt",
		        "node_list_path": "292414.cluster.nodes.v11.5.txt",
		        "edge_list_path": "292414.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSp54146Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. 54_146 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSp54146Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635257.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635257.protein.info.v11.5.txt",
		        "node_list_path": "1635257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseatelesDepolymeransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseateles depolymerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseatelesDepolymeransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "76731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "76731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "76731.clusters.proteins.v11.5.txt",
		        "sequence_path": "76731.protein.sequences.v11.5.fa",
		        "enrichment_path": "76731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76731.protein.info.v11.5.txt",
		        "node_list_path": "76731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "76731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaSpMarseilleP3201tCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia sp. Marseille-P3201T Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaSpMarseilleP3201tCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907659.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907659.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907659.protein.info.v11.5.txt",
		        "node_list_path": "1907659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnsiferAdhaerensOv14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer adhaerens OV14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferAdhaerensOv14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1416753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1416753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1416753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1416753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416753.protein.info.v11.5.txt",
		        "node_list_path": "1416753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1416753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OdyssellaThessalonicensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Odyssella thessalonicensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OdyssellaThessalonicensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "985867.protein.sequences.v11.5.fa",
		        "enrichment_path": "985867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985867.protein.info.v11.5.txt",
		        "node_list_path": "985867.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilimonasTropicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gracilimonas tropica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilimonasTropicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121930.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121930.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121930.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121930.protein.info.v11.5.txt",
		        "node_list_path": "1121930.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121930.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumKnowlesi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium knowlesi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumKnowlesi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5850.protein.sequences.v11.5.fa",
		        "enrichment_path": "5850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5850.protein.info.v11.5.txt",
		        "node_list_path": "5850.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg165411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_54_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797842.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797842.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797842.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797842.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797842.protein.info.v11.5.txt",
		        "node_list_path": "1797842.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797842.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMmg1121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MMG1121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMmg1121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415544.protein.info.v11.5.txt",
		        "node_list_path": "1415544.protein.complete.v11.5.txt"
		    }
		]
    )()

def OctodonDegusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Octodon degus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OctodonDegusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10160.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10160.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10160.clusters.proteins.v11.5.txt",
		        "sequence_path": "10160.protein.sequences.v11.5.fa",
		        "enrichment_path": "10160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10160.protein.info.v11.5.txt",
		        "node_list_path": "10160.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10160.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacillusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "866895.protein.sequences.v11.5.fa",
		        "enrichment_path": "866895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866895.protein.info.v11.5.txt",
		        "node_list_path": "866895.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisExcentricusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis excentricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisExcentricusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573065.clusters.proteins.v11.5.txt",
		        "sequence_path": "573065.protein.sequences.v11.5.fa",
		        "enrichment_path": "573065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573065.protein.info.v11.5.txt",
		        "node_list_path": "573065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1294143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1294143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1294143.clusters.proteins.v11.5.txt",
		        "sequence_path": "1294143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294143.protein.info.v11.5.txt",
		        "node_list_path": "1294143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1294143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaCoubleaeNbrc108252Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia coubleae NBRC 108252 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaCoubleaeNbrc108252Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210069.protein.info.v11.5.txt",
		        "node_list_path": "1210069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhormidiumAmbiguumIamM71(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phormidium ambiguum IAM M-71 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhormidiumAmbiguumIamM71", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "454136.protein.sequences.v11.5.fa",
		        "enrichment_path": "454136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454136.protein.info.v11.5.txt",
		        "node_list_path": "454136.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterSpHeli7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter sp. HelI7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterSpHeli7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1249997.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249997.protein.info.v11.5.txt",
		        "node_list_path": "1249997.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaShimofusensisNbrc100134(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia shimofusensis NBRC 100134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaShimofusensisNbrc100134", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210087.protein.info.v11.5.txt",
		        "node_list_path": "1210087.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpCip642Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP 64.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpCip642Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217694.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217694.protein.info.v11.5.txt",
		        "node_list_path": "1217694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpAap83Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpAap83Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523425.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523425.protein.info.v11.5.txt",
		        "node_list_path": "1523425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSp369Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 36-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSp369Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895905.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895905.protein.info.v11.5.txt",
		        "node_list_path": "1895905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg165611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_56_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg165611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797649.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797649.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797649.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797649.protein.info.v11.5.txt",
		        "node_list_path": "1797649.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797649.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1659195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659195.protein.info.v11.5.txt",
		        "node_list_path": "1659195.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterIndicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterIndicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1341679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1341679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1341679.clusters.proteins.v11.5.txt",
		        "sequence_path": "1341679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341679.protein.info.v11.5.txt",
		        "node_list_path": "1341679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1341679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslr50345(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR50345 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslr50345", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1536770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536770.protein.info.v11.5.txt",
		        "node_list_path": "1536770.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkanindigesIllinoisensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkanindiges illinoisensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkanindigesIllinoisensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120977.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120977.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120977.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120977.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120977.protein.info.v11.5.txt",
		        "node_list_path": "1120977.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120977.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodotorulaSpCcfee5036Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula sp. CCFEE 5036 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodotorulaSpCcfee5036Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1965284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1965284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1965284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1965284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1965284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1965284.protein.info.v11.5.txt",
		        "node_list_path": "1965284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1965284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobaculumUrinale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum urinale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobaculumUrinale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120933.protein.info.v11.5.txt",
		        "node_list_path": "1120933.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpLeaf183Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. Leaf183 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpLeaf183Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736291.protein.info.v11.5.txt",
		        "node_list_path": "1736291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgreiaSpLeaf210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agreia sp. Leaf210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgreiaSpLeaf210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735682.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735682.protein.info.v11.5.txt",
		        "node_list_path": "1735682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SkermanellaStibiiresistensSb22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Skermanella stibiiresistens SB22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SkermanellaStibiiresistensSb22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385369.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385369.protein.info.v11.5.txt",
		        "node_list_path": "1385369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTaa204Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA204 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTaa204Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1289387.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1289387.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1289387.clusters.proteins.v11.5.txt",
		        "sequence_path": "1289387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1289387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1289387.protein.info.v11.5.txt",
		        "node_list_path": "1289387.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1289387.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFukatsuiaSymbiotica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fukatsuia symbiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFukatsuiaSymbiotica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1878942.protein.sequences.v11.5.fa",
		        "enrichment_path": "1878942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1878942.protein.info.v11.5.txt",
		        "node_list_path": "1878942.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumGwa25525Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_55_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumGwa25525Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798422.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798422.protein.info.v11.5.txt",
		        "node_list_path": "1798422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumKluyveri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium kluyveri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumKluyveri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "431943.protein.sequences.v11.5.fa",
		        "enrichment_path": "431943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431943.protein.info.v11.5.txt",
		        "node_list_path": "431943.protein.complete.v11.5.txt"
		    }
		]
    )()

def DactylellinaHaptotylaCbs20050Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dactylellina haptotyla CBS 200.50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DactylellinaHaptotylaCbs20050Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1284197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1284197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1284197.clusters.proteins.v11.5.txt",
		        "sequence_path": "1284197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284197.protein.info.v11.5.txt",
		        "node_list_path": "1284197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1284197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CloacimonasAcidaminovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cloacimonas acidaminovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CloacimonasAcidaminovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "459349.protein.sequences.v11.5.fa",
		        "enrichment_path": "459349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "459349.protein.info.v11.5.txt",
		        "node_list_path": "459349.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag631(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:631 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag631", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262996.protein.info.v11.5.txt",
		        "node_list_path": "1262996.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaSpHyo08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina sp. HYO08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaSpHyo08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1759557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1759557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1759557.clusters.proteins.v11.5.txt",
		        "sequence_path": "1759557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759557.protein.info.v11.5.txt",
		        "node_list_path": "1759557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1759557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterPontiacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter pontiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterPontiacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "60137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "60137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "60137.clusters.proteins.v11.5.txt",
		        "sequence_path": "60137.protein.sequences.v11.5.fa",
		        "enrichment_path": "60137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60137.protein.info.v11.5.txt",
		        "node_list_path": "60137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "60137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumPerfringensStr13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium perfringens str. 13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPerfringensStr13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "195102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "195102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "195102.clusters.proteins.v11.5.txt",
		        "sequence_path": "195102.protein.sequences.v11.5.fa",
		        "enrichment_path": "195102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195102.protein.info.v11.5.txt",
		        "node_list_path": "195102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "195102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpAtcc29733Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ATCC29733 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpAtcc29733Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1507.clusters.proteins.v11.5.txt",
		        "sequence_path": "1507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1507.protein.info.v11.5.txt",
		        "node_list_path": "1507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VavraiaCulicisSubspFloridensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vavraia culicis subsp. floridensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VavraiaCulicisSubspFloridensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "948595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "948595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "948595.clusters.proteins.v11.5.txt",
		        "sequence_path": "948595.protein.sequences.v11.5.fa",
		        "enrichment_path": "948595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "948595.protein.info.v11.5.txt",
		        "node_list_path": "948595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "948595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusEndobugulaSertulaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Endobugula sertula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusEndobugulaSertulaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "62101.clusters.info.v11.5.txt",
		        "cluster_tree_path": "62101.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "62101.clusters.proteins.v11.5.txt",
		        "sequence_path": "62101.protein.sequences.v11.5.fa",
		        "enrichment_path": "62101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62101.protein.info.v11.5.txt",
		        "node_list_path": "62101.cluster.nodes.v11.5.txt",
		        "edge_list_path": "62101.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FacklamiaSourekii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Facklamia sourekii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FacklamiaSourekii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408438.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408438.protein.info.v11.5.txt",
		        "node_list_path": "1408438.protein.complete.v11.5.txt"
		    }
		]
    )()

def HeliobacteriumModesticaldumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Heliobacterium modesticaldum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeliobacteriumModesticaldumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "498761.clusters.info.v11.5.txt",
		        "cluster_tree_path": "498761.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "498761.clusters.proteins.v11.5.txt",
		        "sequence_path": "498761.protein.sequences.v11.5.fa",
		        "enrichment_path": "498761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498761.protein.info.v11.5.txt",
		        "node_list_path": "498761.cluster.nodes.v11.5.txt",
		        "edge_list_path": "498761.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa2439b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_43_9b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa2439b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618828.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618828.protein.info.v11.5.txt",
		        "node_list_path": "1618828.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpNk3a76Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. NK3A76 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpNk3a76Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "877411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "877411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "877411.clusters.proteins.v11.5.txt",
		        "sequence_path": "877411.protein.sequences.v11.5.fa",
		        "enrichment_path": "877411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877411.protein.info.v11.5.txt",
		        "node_list_path": "877411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "877411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaVermiculataNbrc100427(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia vermiculata NBRC 100427 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaVermiculataNbrc100427", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210096.protein.info.v11.5.txt",
		        "node_list_path": "1210096.protein.complete.v11.5.txt"
		    }
		]
    )()

def TemnothoraxLongispinosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Temnothorax longispinosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TemnothoraxLongispinosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "300112.protein.sequences.v11.5.fa",
		        "enrichment_path": "300112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "300112.protein.info.v11.5.txt",
		        "node_list_path": "300112.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag841Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:841 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag841Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262894.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262894.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262894.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262894.protein.info.v11.5.txt",
		        "node_list_path": "1262894.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262894.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasOceanitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas oceanitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasOceanitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280953.protein.info.v11.5.txt",
		        "node_list_path": "1280953.protein.complete.v11.5.txt"
		    }
		]
    )()

def OerskoviaEnterophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oerskovia enterophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OerskoviaEnterophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43678.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43678.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43678.clusters.proteins.v11.5.txt",
		        "sequence_path": "43678.protein.sequences.v11.5.fa",
		        "enrichment_path": "43678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43678.protein.info.v11.5.txt",
		        "node_list_path": "43678.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43678.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusBeveridgei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus beveridgei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusBeveridgei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "632773.protein.sequences.v11.5.fa",
		        "enrichment_path": "632773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632773.protein.info.v11.5.txt",
		        "node_list_path": "632773.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesFlavovariabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavovariabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesFlavovariabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "284031.protein.sequences.v11.5.fa",
		        "enrichment_path": "284031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284031.protein.info.v11.5.txt",
		        "node_list_path": "284031.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesPutredinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes putredinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesPutredinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445970.protein.sequences.v11.5.fa",
		        "enrichment_path": "445970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445970.protein.info.v11.5.txt",
		        "node_list_path": "445970.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterSpAap82(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. AAP82 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterSpAap82", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1248917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1248917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1248917.protein.info.v11.5.txt",
		        "node_list_path": "1248917.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpSgBin2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. SG-bin2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpSgBin2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1827377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1827377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1827377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1827377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827377.protein.info.v11.5.txt",
		        "node_list_path": "1827377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1827377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisSpAc402(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC402 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisSpAc402", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1282361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282361.protein.info.v11.5.txt",
		        "node_list_path": "1282361.protein.complete.v11.5.txt"
		    }
		]
    )()

def StrongyloidesVenezuelensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Strongyloides venezuelensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrongyloidesVenezuelensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "75913.protein.sequences.v11.5.fa",
		        "enrichment_path": "75913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75913.protein.info.v11.5.txt",
		        "node_list_path": "75913.protein.complete.v11.5.txt"
		    }
		]
    )()

def ViridibacillusArenosi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Viridibacillus arenosi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ViridibacillusArenosi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227360.protein.info.v11.5.txt",
		        "node_list_path": "1227360.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaChukchiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia chukchiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaChukchiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641665.protein.sequences.v11.5.fa",
		        "enrichment_path": "641665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641665.protein.info.v11.5.txt",
		        "node_list_path": "641665.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpUasws1009Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. UASWS1009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpUasws1009Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566387.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566387.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566387.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566387.protein.info.v11.5.txt",
		        "node_list_path": "1566387.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566387.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCarsonellaRuddiiPcIsolateNhvCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii PC isolate NHV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCarsonellaRuddiiPcIsolateNhvCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1202540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1202540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1202540.clusters.proteins.v11.5.txt",
		        "sequence_path": "1202540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202540.protein.info.v11.5.txt",
		        "node_list_path": "1202540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1202540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusParauberisKctc11537Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parauberis KCTC11537 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusParauberisKctc11537Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936154.clusters.proteins.v11.5.txt",
		        "sequence_path": "936154.protein.sequences.v11.5.fa",
		        "enrichment_path": "936154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936154.protein.info.v11.5.txt",
		        "node_list_path": "936154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusBrevisAtcc367(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus brevis ATCC367 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBrevisAtcc367", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "387344.protein.sequences.v11.5.fa",
		        "enrichment_path": "387344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "387344.protein.info.v11.5.txt",
		        "node_list_path": "387344.protein.complete.v11.5.txt"
		    }
		]
    )()

def FabibacterPacificusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fabibacter pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FabibacterPacificusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267423.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267423.protein.info.v11.5.txt",
		        "node_list_path": "1267423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaMollaretii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia mollaretii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaMollaretii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33060.protein.sequences.v11.5.fa",
		        "enrichment_path": "33060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33060.protein.info.v11.5.txt",
		        "node_list_path": "33060.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChaetomiumThermophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChaetomiumThermophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "209285.protein.sequences.v11.5.fa",
		        "enrichment_path": "209285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "209285.protein.info.v11.5.txt",
		        "node_list_path": "209285.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusFumigatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus fumigatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusFumigatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "746128.protein.sequences.v11.5.fa",
		        "enrichment_path": "746128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "746128.protein.info.v11.5.txt",
		        "node_list_path": "746128.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesRuminicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces ruminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesRuminicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "332524.protein.sequences.v11.5.fa",
		        "enrichment_path": "332524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332524.protein.info.v11.5.txt",
		        "node_list_path": "332524.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSymbiosumWal14163Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium symbiosum WAL14163 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSymbiosumWal14163Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742740.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742740.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742740.clusters.proteins.v11.5.txt",
		        "sequence_path": "742740.protein.sequences.v11.5.fa",
		        "enrichment_path": "742740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742740.protein.info.v11.5.txt",
		        "node_list_path": "742740.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742740.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifoxya2Full4528Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFOXYA2_FULL_45_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifoxya2Full4528Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802713.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802713.protein.info.v11.5.txt",
		        "node_list_path": "1802713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5329Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_53_29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5329Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798480.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798480.protein.info.v11.5.txt",
		        "node_list_path": "1798480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioTritonius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio tritonius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioTritonius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1435069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1435069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1435069.protein.info.v11.5.txt",
		        "node_list_path": "1435069.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslH70326(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSL H7-0326 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslH70326", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1921144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921144.protein.info.v11.5.txt",
		        "node_list_path": "1921144.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonCaspThauma1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon casp-thauma1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonCaspThauma1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1661711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661711.protein.info.v11.5.txt",
		        "node_list_path": "1661711.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumPelagiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium pelagium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumPelagiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426702.clusters.proteins.v11.5.txt",
		        "sequence_path": "426702.protein.sequences.v11.5.fa",
		        "enrichment_path": "426702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426702.protein.info.v11.5.txt",
		        "node_list_path": "426702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LunatimonasLonarensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lunatimonas lonarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LunatimonasLonarensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232681.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232681.protein.info.v11.5.txt",
		        "node_list_path": "1232681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasVasicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas vasicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasVasicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56459.protein.sequences.v11.5.fa",
		        "enrichment_path": "56459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56459.protein.info.v11.5.txt",
		        "node_list_path": "56459.protein.complete.v11.5.txt"
		    }
		]
    )()

def EikenellaSpNml96A049(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eikenella sp. NML96-A-049 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EikenellaSpNml96A049", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1809061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1809061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1809061.protein.info.v11.5.txt",
		        "node_list_path": "1809061.protein.complete.v11.5.txt"
		    }
		]
    )()

def FluoribacterBozemanae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fluoribacter bozemanae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FluoribacterBozemanae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "447.protein.sequences.v11.5.fa",
		        "enrichment_path": "447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "447.protein.info.v11.5.txt",
		        "node_list_path": "447.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumPseudolongumGlobosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum globosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumPseudolongumGlobosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690.protein.info.v11.5.txt",
		        "node_list_path": "1690.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColobusAngolensisPalliatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colobus angolensis palliatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColobusAngolensisPalliatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "336983.protein.sequences.v11.5.fa",
		        "enrichment_path": "336983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336983.protein.info.v11.5.txt",
		        "node_list_path": "336983.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpJcm9796Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 9796 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpJcm9796Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298602.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298602.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298602.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298602.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298602.protein.info.v11.5.txt",
		        "node_list_path": "1298602.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298602.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachyspiraIntermedia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira intermedia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraIntermedia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1045858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045858.protein.info.v11.5.txt",
		        "node_list_path": "1045858.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaTimonensis4401737(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella timonensis 4401737 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaTimonensis4401737", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122992.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122992.protein.info.v11.5.txt",
		        "node_list_path": "1122992.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulosimicrobiumCellulansJ1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulosimicrobium cellulans J1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulosimicrobiumCellulansJ1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "903523.clusters.info.v11.5.txt",
		        "cluster_tree_path": "903523.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "903523.clusters.proteins.v11.5.txt",
		        "sequence_path": "903523.protein.sequences.v11.5.fa",
		        "enrichment_path": "903523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903523.protein.info.v11.5.txt",
		        "node_list_path": "903523.cluster.nodes.v11.5.txt",
		        "edge_list_path": "903523.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetarhiziumAcridumCqma102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium acridum CQMa 102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetarhiziumAcridumCqma102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655827.clusters.proteins.v11.5.txt",
		        "sequence_path": "655827.protein.sequences.v11.5.fa",
		        "enrichment_path": "655827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655827.protein.info.v11.5.txt",
		        "node_list_path": "655827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpMcba15008(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpMcba15008", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1898736.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898736.protein.info.v11.5.txt",
		        "node_list_path": "1898736.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsplowo212Full5011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO2_12_FULL_50_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo212Full5011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801834.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801834.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801834.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801834.protein.info.v11.5.txt",
		        "node_list_path": "1801834.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801834.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpRs9916(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. RS9916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpRs9916", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "221359.protein.sequences.v11.5.fa",
		        "enrichment_path": "221359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221359.protein.info.v11.5.txt",
		        "node_list_path": "221359.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSlbn53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SLBN-53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSlbn53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1570328.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570328.protein.info.v11.5.txt",
		        "node_list_path": "1570328.protein.complete.v11.5.txt"
		    }
		]
    )()

def CatenovulumAgarivoransYm01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catenovulum agarivorans YM01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenovulumAgarivoransYm01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "659495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "659495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "659495.clusters.proteins.v11.5.txt",
		        "sequence_path": "659495.protein.sequences.v11.5.fa",
		        "enrichment_path": "659495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "659495.protein.info.v11.5.txt",
		        "node_list_path": "659495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "659495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpLeaf404(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf404 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpLeaf404", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736366.protein.info.v11.5.txt",
		        "node_list_path": "1736366.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospinaSpAb629b18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospina sp. AB629B18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospinaSpAb629b18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131269.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131269.protein.info.v11.5.txt",
		        "node_list_path": "1131269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureimonasSpAu12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpAu12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1638161.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1638161.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1638161.clusters.proteins.v11.5.txt",
		        "sequence_path": "1638161.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638161.protein.info.v11.5.txt",
		        "node_list_path": "1638161.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1638161.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesIntestinalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesIntestinalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471870.clusters.proteins.v11.5.txt",
		        "sequence_path": "471870.protein.sequences.v11.5.fa",
		        "enrichment_path": "471870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471870.protein.info.v11.5.txt",
		        "node_list_path": "471870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterOryzifermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter oryzifermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterOryzifermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1633874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1633874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1633874.protein.info.v11.5.txt",
		        "node_list_path": "1633874.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasCrevioricanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas crevioricanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasCrevioricanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "393921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "393921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "393921.clusters.proteins.v11.5.txt",
		        "sequence_path": "393921.protein.sequences.v11.5.fa",
		        "enrichment_path": "393921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393921.protein.info.v11.5.txt",
		        "node_list_path": "393921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "393921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaShakespearei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella shakespearei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaShakespearei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122169.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122169.protein.info.v11.5.txt",
		        "node_list_path": "1122169.protein.complete.v11.5.txt"
		    }
		]
    )()

def NippostrongylusBrasiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nippostrongylus brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NippostrongylusBrasiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "27835.protein.sequences.v11.5.fa",
		        "enrichment_path": "27835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27835.protein.info.v11.5.txt",
		        "node_list_path": "27835.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesUrinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesUrinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1689268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1689268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1689268.clusters.proteins.v11.5.txt",
		        "sequence_path": "1689268.protein.sequences.v11.5.fa",
		        "enrichment_path": "1689268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1689268.protein.info.v11.5.txt",
		        "node_list_path": "1689268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1689268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColwelliaAestuarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaAestuarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "329993.protein.sequences.v11.5.fa",
		        "enrichment_path": "329993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "329993.protein.info.v11.5.txt",
		        "node_list_path": "329993.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichodermaAtrovirideImi206040Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma atroviride IMI 206040 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaAtrovirideImi206040Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "452589.clusters.info.v11.5.txt",
		        "cluster_tree_path": "452589.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "452589.clusters.proteins.v11.5.txt",
		        "sequence_path": "452589.protein.sequences.v11.5.fa",
		        "enrichment_path": "452589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452589.protein.info.v11.5.txt",
		        "node_list_path": "452589.cluster.nodes.v11.5.txt",
		        "edge_list_path": "452589.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag1219Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag1219Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262772.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262772.protein.info.v11.5.txt",
		        "node_list_path": "1262772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanomicrobiumOkeanokoites(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planomicrobium okeanokoites graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanomicrobiumOkeanokoites", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "244.protein.sequences.v11.5.fa",
		        "enrichment_path": "244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244.protein.info.v11.5.txt",
		        "node_list_path": "244.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaprolegniaDiclinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saprolegnia diclina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaprolegniaDiclinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "112098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "112098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "112098.clusters.proteins.v11.5.txt",
		        "sequence_path": "112098.protein.sequences.v11.5.fa",
		        "enrichment_path": "112098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112098.protein.info.v11.5.txt",
		        "node_list_path": "112098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "112098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpNd1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. ND1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpNd1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658518.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658518.protein.info.v11.5.txt",
		        "node_list_path": "1658518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSp157mf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. 157MF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSp157mf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798222.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798222.protein.info.v11.5.txt",
		        "node_list_path": "1798222.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisValliformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis valliformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisValliformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246448.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246448.protein.info.v11.5.txt",
		        "node_list_path": "1246448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParastrongyloidesTrichosuri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parastrongyloides trichosuri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParastrongyloidesTrichosuri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "131310.protein.sequences.v11.5.fa",
		        "enrichment_path": "131310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "131310.protein.info.v11.5.txt",
		        "node_list_path": "131310.protein.complete.v11.5.txt"
		    }
		]
    )()

def AneurinibacillusMigulanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aneurinibacillus migulanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AneurinibacillusMigulanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47500.clusters.proteins.v11.5.txt",
		        "sequence_path": "47500.protein.sequences.v11.5.fa",
		        "enrichment_path": "47500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47500.protein.info.v11.5.txt",
		        "node_list_path": "47500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlsenellaScatoligenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella scatoligenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaScatoligenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1299998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1299998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1299998.protein.info.v11.5.txt",
		        "node_list_path": "1299998.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoactinomycesSpAs95Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. AS95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoactinomycesSpAs95Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811386.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811386.protein.info.v11.5.txt",
		        "node_list_path": "1811386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpCag877Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:877 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpCag877Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262907.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262907.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262907.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262907.protein.info.v11.5.txt",
		        "node_list_path": "1262907.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262907.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusLoiseleuriae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus loiseleuriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLoiseleuriae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1679170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679170.protein.info.v11.5.txt",
		        "node_list_path": "1679170.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaSpScgcAb629i23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota sp. SCGC AB629I23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaSpScgcAb629i23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131266.protein.sequences.v11.0.fa",
		        "enrichment_path": "1131266.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1131266.protein.info.v11.0.txt",
		        "node_list_path": "1131266.protein.complete.v11.0.txt"
		    }
		]
    )()

def ParacoccusSp228Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. 228 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSp228Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1192054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1192054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1192054.clusters.proteins.v11.5.txt",
		        "sequence_path": "1192054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192054.protein.info.v11.5.txt",
		        "node_list_path": "1192054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1192054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaPattaloongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora pattaloongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaPattaloongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "405436.protein.sequences.v11.5.fa",
		        "enrichment_path": "405436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405436.protein.info.v11.5.txt",
		        "node_list_path": "405436.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumUndicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium undicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumUndicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1370122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1370122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1370122.clusters.proteins.v11.5.txt",
		        "sequence_path": "1370122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1370122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1370122.protein.info.v11.5.txt",
		        "node_list_path": "1370122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1370122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterAfricanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter africanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterAfricanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "151894.clusters.info.v11.5.txt",
		        "cluster_tree_path": "151894.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "151894.clusters.proteins.v11.5.txt",
		        "sequence_path": "151894.protein.sequences.v11.5.fa",
		        "enrichment_path": "151894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "151894.protein.info.v11.5.txt",
		        "node_list_path": "151894.cluster.nodes.v11.5.txt",
		        "edge_list_path": "151894.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudolabrysSpRoot1462Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudolabrys sp. Root1462 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudolabrysSpRoot1462Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736466.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736466.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736466.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736466.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736466.protein.info.v11.5.txt",
		        "node_list_path": "1736466.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736466.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMycetoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium mycetoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMycetoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "38302.protein.sequences.v11.5.fa",
		        "enrichment_path": "38302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38302.protein.info.v11.5.txt",
		        "node_list_path": "38302.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerpulaLacrymansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serpula lacrymans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerpulaLacrymansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "85982.clusters.info.v11.5.txt",
		        "cluster_tree_path": "85982.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "85982.clusters.proteins.v11.5.txt",
		        "sequence_path": "85982.protein.sequences.v11.5.fa",
		        "enrichment_path": "85982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85982.protein.info.v11.5.txt",
		        "node_list_path": "85982.cluster.nodes.v11.5.txt",
		        "edge_list_path": "85982.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhynchosporiumCommune(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhynchosporium commune graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhynchosporiumCommune", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "914237.protein.sequences.v11.5.fa",
		        "enrichment_path": "914237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "914237.protein.info.v11.5.txt",
		        "node_list_path": "914237.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobaculumLimnaeum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobaculum limnaeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobaculumLimnaeum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "274537.protein.sequences.v11.5.fa",
		        "enrichment_path": "274537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "274537.protein.info.v11.5.txt",
		        "node_list_path": "274537.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumScgcAaa076P09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA076-P09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumScgcAaa076P09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1007118.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1007118.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1007118.clusters.proteins.v11.5.txt",
		        "sequence_path": "1007118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007118.protein.info.v11.5.txt",
		        "node_list_path": "1007118.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1007118.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterNamhicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter namhicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterNamhicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "645517.protein.sequences.v11.5.fa",
		        "enrichment_path": "645517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645517.protein.info.v11.5.txt",
		        "node_list_path": "645517.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsphigho202Full3917Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_02_FULL_39_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho202Full3917Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797539.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797539.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797539.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797539.protein.info.v11.5.txt",
		        "node_list_path": "1797539.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797539.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGullanellaEndobia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gullanella endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGullanellaEndobia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1070130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1070130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1070130.protein.info.v11.5.txt",
		        "node_list_path": "1070130.protein.complete.v11.5.txt"
		    }
		]
    )()

def WinkiaNeuiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Winkia neuii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinkiaNeuiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33007.clusters.proteins.v11.5.txt",
		        "sequence_path": "33007.protein.sequences.v11.5.fa",
		        "enrichment_path": "33007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33007.protein.info.v11.5.txt",
		        "node_list_path": "33007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BeduiniMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Beduini massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeduiniMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1585974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1585974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1585974.clusters.proteins.v11.5.txt",
		        "sequence_path": "1585974.protein.sequences.v11.5.fa",
		        "enrichment_path": "1585974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1585974.protein.info.v11.5.txt",
		        "node_list_path": "1585974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1585974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkaliflexusImshenetskii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkaliflexus imshenetskii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkaliflexusImshenetskii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "927658.protein.sequences.v11.5.fa",
		        "enrichment_path": "927658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927658.protein.info.v11.5.txt",
		        "node_list_path": "927658.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifoxyd12Full5516Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12_FULL_55_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12Full5516Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797904.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797904.protein.info.v11.5.txt",
		        "node_list_path": "1797904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSp54146(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. 54_146 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSp54146", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635257.protein.info.v11.5.txt",
		        "node_list_path": "1635257.protein.complete.v11.5.txt"
		    }
		]
    )()

def RalstoniaSpMd27Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. MD27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSpMd27Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1676617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1676617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1676617.clusters.proteins.v11.5.txt",
		        "sequence_path": "1676617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676617.protein.info.v11.5.txt",
		        "node_list_path": "1676617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1676617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSinesaloumensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sinesaloumensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSinesaloumensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926280.protein.info.v11.5.txt",
		        "node_list_path": "1926280.protein.complete.v11.5.txt"
		    }
		]
    )()

def JiangellaAlkaliphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jiangella alkaliphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JiangellaAlkaliphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "419479.protein.sequences.v11.5.fa",
		        "enrichment_path": "419479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419479.protein.info.v11.5.txt",
		        "node_list_path": "419479.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrolobusFumariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrolobus fumarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrolobusFumariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "694429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "694429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "694429.clusters.proteins.v11.5.txt",
		        "sequence_path": "694429.protein.sequences.v11.5.fa",
		        "enrichment_path": "694429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694429.protein.info.v11.5.txt",
		        "node_list_path": "694429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "694429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzospirillumThiophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum thiophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumThiophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "528244.protein.sequences.v11.5.fa",
		        "enrichment_path": "528244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "528244.protein.info.v11.5.txt",
		        "node_list_path": "528244.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaSpP37Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina sp. P37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaSpP37Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930546.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930546.protein.info.v11.5.txt",
		        "node_list_path": "1930546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumGossipiicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium gossipiicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumGossipiicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582675.clusters.proteins.v11.5.txt",
		        "sequence_path": "582675.protein.sequences.v11.5.fa",
		        "enrichment_path": "582675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582675.protein.info.v11.5.txt",
		        "node_list_path": "582675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudacidovoraxSpRu35eCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudacidovorax sp. RU35E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudacidovoraxSpRu35eCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907403.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907403.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907403.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907403.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907403.protein.info.v11.5.txt",
		        "node_list_path": "1907403.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907403.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BizioniaParagorgiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bizionia paragorgiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BizioniaParagorgiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "283786.protein.sequences.v11.5.fa",
		        "enrichment_path": "283786.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283786.protein.info.v11.5.txt",
		        "node_list_path": "283786.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasBenzenivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas benzenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBenzenivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "556533.protein.sequences.v11.5.fa",
		        "enrichment_path": "556533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556533.protein.info.v11.5.txt",
		        "node_list_path": "556533.protein.complete.v11.5.txt"
		    }
		]
    )()

def SkermanellaStibiiresistensSb22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Skermanella stibiiresistens SB22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SkermanellaStibiiresistensSb22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385369.protein.info.v11.5.txt",
		        "node_list_path": "1385369.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhaeobacterSpCect7735(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter sp. CECT 7735 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterSpCect7735", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1715693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715693.protein.info.v11.5.txt",
		        "node_list_path": "1715693.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCelerecrescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] celerecrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCelerecrescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29354.clusters.proteins.v11.5.txt",
		        "sequence_path": "29354.protein.sequences.v11.5.fa",
		        "enrichment_path": "29354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29354.protein.info.v11.5.txt",
		        "node_list_path": "29354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsphigho202Full4528(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO2_02_FULL_45_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202Full4528", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801819.protein.info.v11.5.txt",
		        "node_list_path": "1801819.protein.complete.v11.5.txt"
		    }
		]
    )()

def LiberibacterSolanacearumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter solanacearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LiberibacterSolanacearumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658172.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658172.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658172.clusters.proteins.v11.5.txt",
		        "sequence_path": "658172.protein.sequences.v11.5.fa",
		        "enrichment_path": "658172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658172.protein.info.v11.5.txt",
		        "node_list_path": "658172.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658172.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPhytoplasmaAurantifoliaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma aurantifolia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPhytoplasmaAurantifoliaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "180978.clusters.info.v11.5.txt",
		        "cluster_tree_path": "180978.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "180978.clusters.proteins.v11.5.txt",
		        "sequence_path": "180978.protein.sequences.v11.5.fa",
		        "enrichment_path": "180978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180978.protein.info.v11.5.txt",
		        "node_list_path": "180978.cluster.nodes.v11.5.txt",
		        "edge_list_path": "180978.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlenkiaSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klenkia soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlenkiaSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1052260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1052260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1052260.protein.info.v11.5.txt",
		        "node_list_path": "1052260.protein.complete.v11.5.txt"
		    }
		]
    )()

def DaldiniaSpEc12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Daldinia sp. EC12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DaldiniaSpEc12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1001832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001832.protein.info.v11.5.txt",
		        "node_list_path": "1001832.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesQinglanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces qinglanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesQinglanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "943816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "943816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "943816.clusters.proteins.v11.5.txt",
		        "sequence_path": "943816.protein.sequences.v11.5.fa",
		        "enrichment_path": "943816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "943816.protein.info.v11.5.txt",
		        "node_list_path": "943816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "943816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubrimonasCliftonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubrimonas cliftonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrimonasCliftonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "89524.clusters.info.v11.5.txt",
		        "cluster_tree_path": "89524.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "89524.clusters.proteins.v11.5.txt",
		        "sequence_path": "89524.protein.sequences.v11.5.fa",
		        "enrichment_path": "89524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89524.protein.info.v11.5.txt",
		        "node_list_path": "89524.cluster.nodes.v11.5.txt",
		        "edge_list_path": "89524.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusEpidermidisAtcc12228Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis ATCC12228 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusEpidermidisAtcc12228Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "176280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "176280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "176280.clusters.proteins.v11.5.txt",
		        "sequence_path": "176280.protein.sequences.v11.5.fa",
		        "enrichment_path": "176280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "176280.protein.info.v11.5.txt",
		        "node_list_path": "176280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "176280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasMediterraneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas mediterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasMediterraneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717774.clusters.proteins.v11.5.txt",
		        "sequence_path": "717774.protein.sequences.v11.5.fa",
		        "enrichment_path": "717774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717774.protein.info.v11.5.txt",
		        "node_list_path": "717774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifoxyd2Full5815(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFOXYD2_FULL_58_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifoxyd2Full5815", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801943.protein.info.v11.5.txt",
		        "node_list_path": "1801943.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumMs0243c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium MS024-3C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumMs0243c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "487797.protein.sequences.v11.5.fa",
		        "enrichment_path": "487797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487797.protein.info.v11.5.txt",
		        "node_list_path": "487797.protein.complete.v11.5.txt"
		    }
		]
    )()

def EptatretusBurgeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eptatretus burgeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EptatretusBurgeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7764.protein.sequences.v11.5.fa",
		        "enrichment_path": "7764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7764.protein.info.v11.5.txt",
		        "node_list_path": "7764.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpW7784(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. W7784 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpW7784", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227272.protein.info.v11.5.txt",
		        "node_list_path": "1227272.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinopolymorphaSingaporensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinopolymorpha singaporensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolymorphaSingaporensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "117157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "117157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "117157.clusters.proteins.v11.5.txt",
		        "sequence_path": "117157.protein.sequences.v11.5.fa",
		        "enrichment_path": "117157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "117157.protein.info.v11.5.txt",
		        "node_list_path": "117157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "117157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full4013bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full4013bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802041.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802041.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802041.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802041.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802041.protein.info.v11.5.txt",
		        "node_list_path": "1802041.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802041.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AminomonasPaucivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aminomonas paucivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminomonasPaucivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "584708.protein.sequences.v11.5.fa",
		        "enrichment_path": "584708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "584708.protein.info.v11.5.txt",
		        "node_list_path": "584708.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPulmonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma pulmonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPulmonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272635.clusters.proteins.v11.5.txt",
		        "sequence_path": "272635.protein.sequences.v11.5.fa",
		        "enrichment_path": "272635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272635.protein.info.v11.5.txt",
		        "node_list_path": "272635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacillusSpWch70Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. WCH70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusSpWch70Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471223.clusters.proteins.v11.5.txt",
		        "sequence_path": "471223.protein.sequences.v11.5.fa",
		        "enrichment_path": "471223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471223.protein.info.v11.5.txt",
		        "node_list_path": "471223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HeliothisVirescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Heliothis virescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeliothisVirescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7102.protein.sequences.v11.5.fa",
		        "enrichment_path": "7102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7102.protein.info.v11.5.txt",
		        "node_list_path": "7102.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpMrs1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. MRS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpMrs1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1451261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1451261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1451261.protein.info.v11.5.txt",
		        "node_list_path": "1451261.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaSpUcdKl20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia sp. UCD-KL20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaSpUcdKl20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1917165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1917165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1917165.clusters.proteins.v11.5.txt",
		        "sequence_path": "1917165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917165.protein.info.v11.5.txt",
		        "node_list_path": "1917165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1917165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodoferaxFermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodoferax fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodoferaxFermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28066.clusters.proteins.v11.5.txt",
		        "sequence_path": "28066.protein.sequences.v11.5.fa",
		        "enrichment_path": "28066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28066.protein.info.v11.5.txt",
		        "node_list_path": "28066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaGrenadensisNbrc108939Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia grenadensis NBRC 108939 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaGrenadensisNbrc108939Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223546.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223546.protein.info.v11.5.txt",
		        "node_list_path": "1223546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacterSpLpb0142Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter sp. LPB0142 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterSpLpb0142Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1850250.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1850250.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1850250.clusters.proteins.v11.5.txt",
		        "sequence_path": "1850250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850250.protein.info.v11.5.txt",
		        "node_list_path": "1850250.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1850250.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudorhodobacterAquimarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodobacter aquimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodobacterAquimarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "687412.clusters.info.v11.5.txt",
		        "cluster_tree_path": "687412.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "687412.clusters.proteins.v11.5.txt",
		        "sequence_path": "687412.protein.sequences.v11.5.fa",
		        "enrichment_path": "687412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "687412.protein.info.v11.5.txt",
		        "node_list_path": "687412.cluster.nodes.v11.5.txt",
		        "edge_list_path": "687412.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolirubrobacterSoliDsm22325(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solirubrobacter soli DSM 22325 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolirubrobacterSoliDsm22325", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123262.protein.info.v11.5.txt",
		        "node_list_path": "1123262.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosarchaeumLimniumSfb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosarchaeum limnium SFB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosarchaeumLimniumSfb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "886738.protein.sequences.v11.5.fa",
		        "enrichment_path": "886738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "886738.protein.info.v11.5.txt",
		        "node_list_path": "886738.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophagaSulfidovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga sulfidovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaSulfidovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45496.clusters.proteins.v11.5.txt",
		        "sequence_path": "45496.protein.sequences.v11.5.fa",
		        "enrichment_path": "45496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45496.protein.info.v11.5.txt",
		        "node_list_path": "45496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerrabacterSpSoil810Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terrabacter sp. Soil810 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrabacterSpSoil810Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736418.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736418.protein.info.v11.5.txt",
		        "node_list_path": "1736418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenisporosarcinaSpHgh0030Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenisporosarcina sp. HGH0030 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenisporosarcinaSpHgh0030Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1078085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1078085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1078085.clusters.proteins.v11.5.txt",
		        "sequence_path": "1078085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078085.protein.info.v11.5.txt",
		        "node_list_path": "1078085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1078085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusHydrogenalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus hydrogenalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusHydrogenalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "561177.clusters.info.v11.5.txt",
		        "cluster_tree_path": "561177.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "561177.clusters.proteins.v11.5.txt",
		        "sequence_path": "561177.protein.sequences.v11.5.fa",
		        "enrichment_path": "561177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561177.protein.info.v11.5.txt",
		        "node_list_path": "561177.cluster.nodes.v11.5.txt",
		        "edge_list_path": "561177.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls337Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS337 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls337Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463900.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463900.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463900.protein.info.v11.5.txt",
		        "node_list_path": "1463900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TuberMelanosporumMel28(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tuber melanosporum Mel28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuberMelanosporumMel28", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "656061.protein.sequences.v11.5.fa",
		        "enrichment_path": "656061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656061.protein.info.v11.5.txt",
		        "node_list_path": "656061.protein.complete.v11.5.txt"
		    }
		]
    )()

def OpisthorchisFelineus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Opisthorchis felineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpisthorchisFelineus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "147828.protein.sequences.v11.5.fa",
		        "enrichment_path": "147828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "147828.protein.info.v11.5.txt",
		        "node_list_path": "147828.protein.complete.v11.5.txt"
		    }
		]
    )()

def MurdochiellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Murdochiella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MurdochiellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1673723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1673723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1673723.clusters.proteins.v11.5.txt",
		        "sequence_path": "1673723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673723.protein.info.v11.5.txt",
		        "node_list_path": "1673723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1673723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyxococcusXanthus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus xanthus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcusXanthus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246197.protein.sequences.v11.5.fa",
		        "enrichment_path": "246197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246197.protein.info.v11.5.txt",
		        "node_list_path": "246197.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusParasiticusSu1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus parasiticus SU-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusParasiticusSu1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1403190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403190.protein.info.v11.5.txt",
		        "node_list_path": "1403190.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisPotens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis potens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisPotens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "570268.protein.sequences.v11.5.fa",
		        "enrichment_path": "570268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570268.protein.info.v11.5.txt",
		        "node_list_path": "570268.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillatorialesCyanobacterium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillatorialesCyanobacterium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "864702.protein.sequences.v11.5.fa",
		        "enrichment_path": "864702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864702.protein.info.v11.5.txt",
		        "node_list_path": "864702.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSp123mfchir2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 123MFChir2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp123mfchir2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1169144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1169144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1169144.clusters.proteins.v11.5.txt",
		        "sequence_path": "1169144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169144.protein.info.v11.5.txt",
		        "node_list_path": "1169144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1169144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasHaloplanktisTac125Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis TAC125 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasHaloplanktisTac125Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326442.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326442.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326442.clusters.proteins.v11.5.txt",
		        "sequence_path": "326442.protein.sequences.v11.5.fa",
		        "enrichment_path": "326442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326442.protein.info.v11.5.txt",
		        "node_list_path": "326442.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326442.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinoplanesSubtropicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes subtropicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesSubtropicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "543632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "543632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "543632.clusters.proteins.v11.5.txt",
		        "sequence_path": "543632.protein.sequences.v11.5.fa",
		        "enrichment_path": "543632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543632.protein.info.v11.5.txt",
		        "node_list_path": "543632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "543632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinihabitansFlavidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinihabitans flavidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinihabitansFlavidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "569882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "569882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "569882.clusters.proteins.v11.5.txt",
		        "sequence_path": "569882.protein.sequences.v11.5.fa",
		        "enrichment_path": "569882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "569882.protein.info.v11.5.txt",
		        "node_list_path": "569882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "569882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasGulaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gulae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasGulaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "111105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "111105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "111105.clusters.proteins.v11.5.txt",
		        "sequence_path": "111105.protein.sequences.v11.5.fa",
		        "enrichment_path": "111105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "111105.protein.info.v11.5.txt",
		        "node_list_path": "111105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "111105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTpA0875(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TP-A0875 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTpA0875", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "552354.protein.sequences.v11.5.fa",
		        "enrichment_path": "552354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "552354.protein.info.v11.5.txt",
		        "node_list_path": "552354.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpOv219(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. OV219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpOv219", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884377.protein.info.v11.5.txt",
		        "node_list_path": "1884377.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlb24720Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLB24720 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlb24720Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1476876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1476876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1476876.clusters.proteins.v11.5.txt",
		        "sequence_path": "1476876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1476876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1476876.protein.info.v11.5.txt",
		        "node_list_path": "1476876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1476876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaSpCag257Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia sp. CAG:257 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaSpCag257Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262756.protein.info.v11.5.txt",
		        "node_list_path": "1262756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusCanintestini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus canintestini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusCanintestini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "317010.protein.sequences.v11.5.fa",
		        "enrichment_path": "317010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317010.protein.info.v11.5.txt",
		        "node_list_path": "317010.protein.complete.v11.5.txt"
		    }
		]
    )()

def LongilineaArvoryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Longilinea arvoryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LongilineaArvoryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "360412.clusters.info.v11.5.txt",
		        "cluster_tree_path": "360412.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "360412.clusters.proteins.v11.5.txt",
		        "sequence_path": "360412.protein.sequences.v11.5.fa",
		        "enrichment_path": "360412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360412.protein.info.v11.5.txt",
		        "node_list_path": "360412.cluster.nodes.v11.5.txt",
		        "edge_list_path": "360412.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpSoil774(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil774 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpSoil774", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736408.protein.info.v11.5.txt",
		        "node_list_path": "1736408.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaArthritidisNbrc100137(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia arthritidis NBRC 100137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaArthritidisNbrc100137", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210067.protein.info.v11.5.txt",
		        "node_list_path": "1210067.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusVaginalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusVaginalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423814.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423814.protein.info.v11.5.txt",
		        "node_list_path": "1423814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollinsellaStercoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collinsella stercoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaStercoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445975.protein.sequences.v11.5.fa",
		        "enrichment_path": "445975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445975.protein.info.v11.5.txt",
		        "node_list_path": "445975.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGilvosporeus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces gilvosporeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGilvosporeus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553510.protein.sequences.v11.5.fa",
		        "enrichment_path": "553510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553510.protein.info.v11.5.txt",
		        "node_list_path": "553510.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumSpRac06(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. RAC06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumSpRac06", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1842536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842536.protein.info.v11.5.txt",
		        "node_list_path": "1842536.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesGenomosp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales genomosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesGenomosp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "699246.protein.sequences.v11.5.fa",
		        "enrichment_path": "699246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "699246.protein.info.v11.5.txt",
		        "node_list_path": "699246.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKapabacteriaThiocyanatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kapabacteria thiocyanatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKapabacteriaThiocyanatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895771.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895771.protein.info.v11.5.txt",
		        "node_list_path": "1895771.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosospiraSpApg3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. APG3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraSpApg3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288494.protein.info.v11.5.txt",
		        "node_list_path": "1288494.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumSpMar2009124(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. MAR_2009_124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumSpMar2009124", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1250059.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250059.protein.info.v11.5.txt",
		        "node_list_path": "1250059.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlautiaWexlerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blautia wexlerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaWexlerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121115.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121115.protein.info.v11.5.txt",
		        "node_list_path": "1121115.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacteriumCg1024416Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_44_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024416Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805287.protein.info.v11.5.txt",
		        "node_list_path": "1805287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCaldiarchaeumSubterraneumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Caldiarchaeum subterraneum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCaldiarchaeumSubterraneumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "311458.clusters.info.v11.5.txt",
		        "cluster_tree_path": "311458.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "311458.clusters.proteins.v11.5.txt",
		        "sequence_path": "311458.protein.sequences.v11.5.fa",
		        "enrichment_path": "311458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311458.protein.info.v11.5.txt",
		        "node_list_path": "311458.cluster.nodes.v11.5.txt",
		        "edge_list_path": "311458.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwb26322(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWB2_63_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwb26322", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797929.protein.info.v11.5.txt",
		        "node_list_path": "1797929.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioRuberDsm16370Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ruber DSM 16370 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioRuberDsm16370Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123498.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123498.protein.info.v11.5.txt",
		        "node_list_path": "1123498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FructobacillusTropaeoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fructobacillus tropaeoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FructobacillusTropaeoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "709323.protein.sequences.v11.5.fa",
		        "enrichment_path": "709323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709323.protein.info.v11.5.txt",
		        "node_list_path": "709323.protein.complete.v11.5.txt"
		    }
		]
    )()

def PersephonellaSpIf05l8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Persephonella sp. IF05L8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PersephonellaSpIf05l8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158338.protein.info.v11.5.txt",
		        "node_list_path": "1158338.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumRbg16399b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_39_9b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg16399b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802595.protein.info.v11.5.txt",
		        "node_list_path": "1802595.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAquaticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium aquaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAquaticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1927124.protein.sequences.v11.5.fa",
		        "enrichment_path": "1927124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1927124.protein.info.v11.5.txt",
		        "node_list_path": "1927124.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSp135mfcol51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 135MFCol51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSp135mfcol51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158050.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158050.protein.info.v11.5.txt",
		        "node_list_path": "1158050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatonellaMorbiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catonella morbi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatonellaMorbiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "592026.clusters.info.v11.5.txt",
		        "cluster_tree_path": "592026.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "592026.clusters.proteins.v11.5.txt",
		        "sequence_path": "592026.protein.sequences.v11.5.fa",
		        "enrichment_path": "592026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592026.protein.info.v11.5.txt",
		        "node_list_path": "592026.cluster.nodes.v11.5.txt",
		        "edge_list_path": "592026.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TannerellaForsythia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tannerella forsythia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TannerellaForsythia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "203275.protein.sequences.v11.5.fa",
		        "enrichment_path": "203275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203275.protein.info.v11.5.txt",
		        "node_list_path": "203275.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumMongolense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium mongolense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumMongolense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1079460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1079460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1079460.protein.info.v11.5.txt",
		        "node_list_path": "1079460.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusGinsengihumi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus ginsengihumi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGinsengihumi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "363870.protein.sequences.v11.5.fa",
		        "enrichment_path": "363870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "363870.protein.info.v11.5.txt",
		        "node_list_path": "363870.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaWestfalicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia westfalica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaWestfalicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "158898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "158898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "158898.clusters.proteins.v11.5.txt",
		        "sequence_path": "158898.protein.sequences.v11.5.fa",
		        "enrichment_path": "158898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158898.protein.info.v11.5.txt",
		        "node_list_path": "158898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "158898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag524Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:524 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag524Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262817.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262817.protein.info.v11.5.txt",
		        "node_list_path": "1262817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaSpTu14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma sp. TU-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaSpTu14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1898044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898044.protein.info.v11.5.txt",
		        "node_list_path": "1898044.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusSpWch70(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. WCH70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusSpWch70", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471223.protein.sequences.v11.5.fa",
		        "enrichment_path": "471223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471223.protein.info.v11.5.txt",
		        "node_list_path": "471223.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg2304418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_44_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805318.protein.info.v11.5.txt",
		        "node_list_path": "1805318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSaudimassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas saudimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSaudimassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461581.protein.info.v11.5.txt",
		        "node_list_path": "1461581.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnatzschineriaLarvaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignatzschineria larvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnatzschineriaLarvaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111732.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111732.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111732.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111732.protein.info.v11.5.txt",
		        "node_list_path": "1111732.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111732.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumMa2020Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MA2020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumMa2020Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408323.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408323.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408323.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408323.protein.info.v11.5.txt",
		        "node_list_path": "1408323.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408323.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaFaecigallinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea faecigallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaFaecigallinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "656179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "656179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "656179.clusters.proteins.v11.5.txt",
		        "sequence_path": "656179.protein.sequences.v11.5.fa",
		        "enrichment_path": "656179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656179.protein.info.v11.5.txt",
		        "node_list_path": "656179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "656179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasCitreaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas citrea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasCitreaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1117314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1117314.clusters.proteins.v11.5.txt",
		        "sequence_path": "1117314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117314.protein.info.v11.5.txt",
		        "node_list_path": "1117314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1117314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanohalobiumEvestigatumZ7303Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanohalobium evestigatum Z-7303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanohalobiumEvestigatumZ7303Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644295.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644295.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644295.clusters.proteins.v11.5.txt",
		        "sequence_path": "644295.protein.sequences.v11.5.fa",
		        "enrichment_path": "644295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644295.protein.info.v11.5.txt",
		        "node_list_path": "644295.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644295.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpUnc438cl73tsus30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. UNC438CL73TsuS30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpUnc438cl73tsus30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1340434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1340434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1340434.protein.info.v11.5.txt",
		        "node_list_path": "1340434.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetivibrioCellulolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetivibrio cellulolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetivibrioCellulolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "509191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "509191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "509191.clusters.proteins.v11.5.txt",
		        "sequence_path": "509191.protein.sequences.v11.5.fa",
		        "enrichment_path": "509191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "509191.protein.info.v11.5.txt",
		        "node_list_path": "509191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "509191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzospirillumBrasilense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum brasilense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumBrasilense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "192.protein.sequences.v11.5.fa",
		        "enrichment_path": "192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192.protein.info.v11.5.txt",
		        "node_list_path": "192.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPutrefaciensMput9231(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens Mput9231 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPutrefaciensMput9231", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1292033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292033.protein.info.v11.5.txt",
		        "node_list_path": "1292033.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumGwa26437(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GWA2_64_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumGwa26437", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797549.protein.info.v11.5.txt",
		        "node_list_path": "1797549.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumOrchidophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum orchidophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumOrchidophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1209926.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1209926.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1209926.clusters.proteins.v11.5.txt",
		        "sequence_path": "1209926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1209926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1209926.protein.info.v11.5.txt",
		        "node_list_path": "1209926.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1209926.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusSpRlCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. RL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusSpRlCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1489678.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1489678.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1489678.clusters.proteins.v11.5.txt",
		        "sequence_path": "1489678.protein.sequences.v11.5.fa",
		        "enrichment_path": "1489678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1489678.protein.info.v11.5.txt",
		        "node_list_path": "1489678.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1489678.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumBarkeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium barkeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumBarkeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1528.protein.info.v11.5.txt",
		        "node_list_path": "1528.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeminocystisHerdmaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geminocystis herdmanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeminocystisHerdmaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "113355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "113355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "113355.clusters.proteins.v11.5.txt",
		        "sequence_path": "113355.protein.sequences.v11.5.fa",
		        "enrichment_path": "113355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113355.protein.info.v11.5.txt",
		        "node_list_path": "113355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "113355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaParapsilosisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida parapsilosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaParapsilosisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5480.clusters.proteins.v11.5.txt",
		        "sequence_path": "5480.protein.sequences.v11.5.fa",
		        "enrichment_path": "5480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5480.protein.info.v11.5.txt",
		        "node_list_path": "5480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesBikiniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces bikiniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesBikiniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896.protein.info.v11.5.txt",
		        "node_list_path": "1896.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpUrha0032Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. URHA0032 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpUrha0032Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380388.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380388.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380388.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380388.protein.info.v11.5.txt",
		        "node_list_path": "1380388.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380388.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophomonasSpDtu019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas sp. DTU019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophomonasSpDtu019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671630.protein.info.v11.5.txt",
		        "node_list_path": "1671630.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumFrankenforstenseDsm45800(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium frankenforstense DSM 45800 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumFrankenforstenseDsm45800", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437875.protein.info.v11.5.txt",
		        "node_list_path": "1437875.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusFumarioliNbrc102428(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus fumarioli NBRC 102428 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusFumarioliNbrc102428", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314754.protein.info.v11.5.txt",
		        "node_list_path": "1314754.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisBalhimycina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis balhimycina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisBalhimycina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089545.protein.info.v11.5.txt",
		        "node_list_path": "1089545.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSputiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sputi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSputiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111729.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111729.protein.info.v11.5.txt",
		        "node_list_path": "1111729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBereziniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter bereziniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBereziniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "106648.clusters.info.v11.5.txt",
		        "cluster_tree_path": "106648.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "106648.clusters.proteins.v11.5.txt",
		        "sequence_path": "106648.protein.sequences.v11.5.fa",
		        "enrichment_path": "106648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106648.protein.info.v11.5.txt",
		        "node_list_path": "106648.cluster.nodes.v11.5.txt",
		        "edge_list_path": "106648.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesViridosporusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces viridosporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesViridosporusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665577.clusters.proteins.v11.5.txt",
		        "sequence_path": "665577.protein.sequences.v11.5.fa",
		        "enrichment_path": "665577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665577.protein.info.v11.5.txt",
		        "node_list_path": "665577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg167214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_72_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg167214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797663.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797663.protein.info.v11.5.txt",
		        "node_list_path": "1797663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusAs9601Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus AS9601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusAs9601Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "146891.clusters.info.v11.5.txt",
		        "cluster_tree_path": "146891.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "146891.clusters.proteins.v11.5.txt",
		        "sequence_path": "146891.protein.sequences.v11.5.fa",
		        "enrichment_path": "146891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146891.protein.info.v11.5.txt",
		        "node_list_path": "146891.cluster.nodes.v11.5.txt",
		        "edge_list_path": "146891.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumStellenboschenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium stellenboschense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumStellenboschenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762211.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762211.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762211.clusters.proteins.v11.5.txt",
		        "sequence_path": "762211.protein.sequences.v11.5.fa",
		        "enrichment_path": "762211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762211.protein.info.v11.5.txt",
		        "node_list_path": "762211.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762211.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPoribacteriaBacteriumWga3gCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Poribacteria bacterium WGA-3G Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPoribacteriaBacteriumWga3gCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1104566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1104566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1104566.clusters.proteins.v11.5.txt",
		        "sequence_path": "1104566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104566.protein.info.v11.5.txt",
		        "node_list_path": "1104566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1104566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusAnginosusDora7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus DORA7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAnginosusDora7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1403946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403946.protein.info.v11.5.txt",
		        "node_list_path": "1403946.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusNasuensisJcm17158Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nasuensis JCM 17158 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusNasuensisJcm17158Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1291734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1291734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1291734.clusters.proteins.v11.5.txt",
		        "sequence_path": "1291734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291734.protein.info.v11.5.txt",
		        "node_list_path": "1291734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1291734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full4424b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_44_24b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full4424b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802526.protein.info.v11.5.txt",
		        "node_list_path": "1802526.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaShahii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella shahii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaShahii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122991.protein.info.v11.5.txt",
		        "node_list_path": "1122991.protein.complete.v11.5.txt"
		    }
		]
    )()

def SimonsiellaMuelleri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Simonsiella muelleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SimonsiellaMuelleri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641147.protein.sequences.v11.5.fa",
		        "enrichment_path": "641147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641147.protein.info.v11.5.txt",
		        "node_list_path": "641147.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag354(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:354 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag354", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262799.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262799.protein.info.v11.5.txt",
		        "node_list_path": "1262799.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseomonasMucosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas mucosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseomonasMucosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "207340.protein.sequences.v11.5.fa",
		        "enrichment_path": "207340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "207340.protein.info.v11.5.txt",
		        "node_list_path": "207340.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumVarium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium varium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumVarium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469618.protein.sequences.v11.5.fa",
		        "enrichment_path": "469618.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469618.protein.info.v11.5.txt",
		        "node_list_path": "469618.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusVulcaniusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus vulcanius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusVulcaniusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "579137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "579137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "579137.clusters.proteins.v11.5.txt",
		        "sequence_path": "579137.protein.sequences.v11.5.fa",
		        "enrichment_path": "579137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579137.protein.info.v11.5.txt",
		        "node_list_path": "579137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "579137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CladophialophoraCarrioniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora carrionii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CladophialophoraCarrioniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86049.clusters.proteins.v11.5.txt",
		        "sequence_path": "86049.protein.sequences.v11.5.fa",
		        "enrichment_path": "86049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86049.protein.info.v11.5.txt",
		        "node_list_path": "86049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumSpMs4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. MS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumSpMs4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120746.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1120746.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1120746.clusters.proteins.v11.0.txt",
		        "sequence_path": "1120746.protein.sequences.v11.0.fa",
		        "enrichment_path": "1120746.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1120746.protein.info.v11.0.txt",
		        "node_list_path": "1120746.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1120746.protein.cluster.v11.0.txt"
		    }
		]
    )()

def BrevundimonasAbyssalisTar001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas abyssalis TAR-001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasAbyssalisTar001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1391729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1391729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1391729.clusters.proteins.v11.5.txt",
		        "sequence_path": "1391729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391729.protein.info.v11.5.txt",
		        "node_list_path": "1391729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1391729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKuenenbacteriaBacteriumRifcsphigho202Full3913Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium RIFCSPHIGHO2_02_FULL_39_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumRifcsphigho202Full3913Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798561.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798561.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798561.protein.info.v11.5.txt",
		        "node_list_path": "1798561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusWeihaiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus weihaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusWeihaiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1547283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1547283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1547283.clusters.proteins.v11.5.txt",
		        "sequence_path": "1547283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1547283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1547283.protein.info.v11.5.txt",
		        "node_list_path": "1547283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1547283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlligatorMississippiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alligator mississippiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlligatorMississippiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8496.protein.sequences.v11.5.fa",
		        "enrichment_path": "8496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8496.protein.info.v11.5.txt",
		        "node_list_path": "8496.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaLacustrisZ7289(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina lacustris Z-7289 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaLacustrisZ7289", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434111.protein.info.v11.5.txt",
		        "node_list_path": "1434111.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolytolypaHystricisUamh7299Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polytolypa hystricis UAMH7299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolytolypaHystricisUamh7299Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1447883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1447883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1447883.clusters.proteins.v11.5.txt",
		        "sequence_path": "1447883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1447883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1447883.protein.info.v11.5.txt",
		        "node_list_path": "1447883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1447883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OchrobactrumIntermediumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum intermedium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OchrobactrumIntermediumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "94625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "94625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "94625.clusters.proteins.v11.5.txt",
		        "sequence_path": "94625.protein.sequences.v11.5.fa",
		        "enrichment_path": "94625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94625.protein.info.v11.5.txt",
		        "node_list_path": "94625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "94625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaObeumA2162Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia obeum A2-162 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaObeumA2162Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "657314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "657314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "657314.clusters.proteins.v11.5.txt",
		        "sequence_path": "657314.protein.sequences.v11.5.fa",
		        "enrichment_path": "657314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657314.protein.info.v11.5.txt",
		        "node_list_path": "657314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "657314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium1456faa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 1456FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium1456faa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658655.protein.sequences.v11.5.fa",
		        "enrichment_path": "658655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658655.protein.info.v11.5.txt",
		        "node_list_path": "658655.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaSpF0356(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella sp. F0356 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaSpF0356", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "661087.protein.sequences.v11.5.fa",
		        "enrichment_path": "661087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "661087.protein.info.v11.5.txt",
		        "node_list_path": "661087.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSobrinusDsm20742Atcc33478(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sobrinus DSM 20742 ATCC 33478 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSobrinusDsm20742Atcc33478", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123317.protein.info.v11.5.txt",
		        "node_list_path": "1123317.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuminiphilusSyltensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luminiphilus syltensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuminiphilusSyltensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "565045.protein.sequences.v11.5.fa",
		        "enrichment_path": "565045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565045.protein.info.v11.5.txt",
		        "node_list_path": "565045.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpVer3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. Ver3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpVer3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "466088.protein.sequences.v11.5.fa",
		        "enrichment_path": "466088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "466088.protein.info.v11.5.txt",
		        "node_list_path": "466088.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusAlkeniferCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus alkenifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusAlkeniferCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "65735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "65735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "65735.clusters.proteins.v11.5.txt",
		        "sequence_path": "65735.protein.sequences.v11.5.fa",
		        "enrichment_path": "65735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65735.protein.info.v11.5.txt",
		        "node_list_path": "65735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "65735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium4572128(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 4572_128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium4572128", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1971633.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971633.protein.info.v11.5.txt",
		        "node_list_path": "1971633.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmatimonadetesBacteriumOlb18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium OLB18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmatimonadetesBacteriumOlb18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617424.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617424.protein.info.v11.5.txt",
		        "node_list_path": "1617424.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesLydicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces lydicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesLydicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47763.clusters.proteins.v11.5.txt",
		        "sequence_path": "47763.protein.sequences.v11.5.fa",
		        "enrichment_path": "47763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47763.protein.info.v11.5.txt",
		        "node_list_path": "47763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosarchaeumKoreenseMy1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosarchaeum koreense MY1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosarchaeumKoreenseMy1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1001994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001994.protein.info.v11.5.txt",
		        "node_list_path": "1001994.protein.complete.v11.5.txt"
		    }
		]
    )()

def UlvibacterSpLpb0005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ulvibacter sp. LPB0005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UlvibacterSpLpb0005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1763537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1763537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1763537.protein.info.v11.5.txt",
		        "node_list_path": "1763537.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerminiimonasArsenitoxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herminiimonas arsenitoxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerminiimonasArsenitoxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1809410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1809410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1809410.clusters.proteins.v11.5.txt",
		        "sequence_path": "1809410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1809410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1809410.protein.info.v11.5.txt",
		        "node_list_path": "1809410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1809410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAnguillisepticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas anguilliseptica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAnguillisepticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53406.clusters.proteins.v11.5.txt",
		        "sequence_path": "53406.protein.sequences.v11.5.fa",
		        "enrichment_path": "53406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53406.protein.info.v11.5.txt",
		        "node_list_path": "53406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrusUnshiuCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrus unshiu Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrusUnshiuCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "55188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "55188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "55188.clusters.proteins.v11.5.txt",
		        "sequence_path": "55188.protein.sequences.v11.5.fa",
		        "enrichment_path": "55188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55188.protein.info.v11.5.txt",
		        "node_list_path": "55188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "55188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraInadaiSerovarLymeStr10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira inadai serovar Lyme str. 10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraInadaiSerovarLymeStr10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1049790.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1049790.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1049790.clusters.proteins.v11.5.txt",
		        "sequence_path": "1049790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1049790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1049790.protein.info.v11.5.txt",
		        "node_list_path": "1049790.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1049790.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusAcidocaldariusTc41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius Tc41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusAcidocaldariusTc41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1048834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048834.protein.info.v11.5.txt",
		        "node_list_path": "1048834.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumLimigenitum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium limigenitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumLimigenitum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1612149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1612149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1612149.protein.info.v11.5.txt",
		        "node_list_path": "1612149.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeisingeraSpAngM7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leisingera sp. ANG-M7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraSpAngM7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577902.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577902.protein.info.v11.5.txt",
		        "node_list_path": "1577902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumPseudosasicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium pseudosasicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumPseudosasicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582667.protein.sequences.v11.5.fa",
		        "enrichment_path": "582667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582667.protein.info.v11.5.txt",
		        "node_list_path": "582667.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusGp2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus GP2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusGp2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59925.clusters.proteins.v11.5.txt",
		        "sequence_path": "59925.protein.sequences.v11.5.fa",
		        "enrichment_path": "59925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59925.protein.info.v11.5.txt",
		        "node_list_path": "59925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_51_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798508.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798508.protein.info.v11.5.txt",
		        "node_list_path": "1798508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurimonasSpGwf2378Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. GWF2_37_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasSpGwf2378Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802250.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802250.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802250.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802250.protein.info.v11.5.txt",
		        "node_list_path": "1802250.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802250.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumFlavigenumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium flavigenum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumFlavigenumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "254877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "254877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "254877.clusters.proteins.v11.5.txt",
		        "sequence_path": "254877.protein.sequences.v11.5.fa",
		        "enrichment_path": "254877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "254877.protein.info.v11.5.txt",
		        "node_list_path": "254877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "254877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusTukisamuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus tukisamuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusTukisamuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "168276.protein.sequences.v11.5.fa",
		        "enrichment_path": "168276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "168276.protein.info.v11.5.txt",
		        "node_list_path": "168276.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumJaponicumIn8p8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum in8p8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumJaponicumIn8p8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304878.protein.info.v11.5.txt",
		        "node_list_path": "1304878.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelcococcusSueciensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helcococcus sueciensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelcococcusSueciensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121947.protein.info.v11.5.txt",
		        "node_list_path": "1121947.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpCot290Oh3588Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT-290 OH3588 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpCot290Oh3588Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1515617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1515617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1515617.clusters.proteins.v11.5.txt",
		        "sequence_path": "1515617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1515617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1515617.protein.info.v11.5.txt",
		        "node_list_path": "1515617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1515617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpYr710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. YR710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpYr710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882773.protein.info.v11.5.txt",
		        "node_list_path": "1882773.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachyspiraMurdochiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira murdochii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraMurdochiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "526224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "526224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "526224.clusters.proteins.v11.5.txt",
		        "sequence_path": "526224.protein.sequences.v11.5.fa",
		        "enrichment_path": "526224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526224.protein.info.v11.5.txt",
		        "node_list_path": "526224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "526224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolicicoccusSubflavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolicicoccus subflavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolicicoccusSubflavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "443218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "443218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "443218.clusters.proteins.v11.5.txt",
		        "sequence_path": "443218.protein.sequences.v11.5.fa",
		        "enrichment_path": "443218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443218.protein.info.v11.5.txt",
		        "node_list_path": "443218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "443218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumGa0077543Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium Ga0077543 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumGa0077543Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752205.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752205.protein.info.v11.5.txt",
		        "node_list_path": "1752205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4825Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_48_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4825Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802765.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802765.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802765.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802765.protein.info.v11.5.txt",
		        "node_list_path": "1802765.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802765.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichobilharziaRegentiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichobilharzia regenti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichobilharziaRegentiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "157069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "157069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "157069.clusters.proteins.v11.5.txt",
		        "sequence_path": "157069.protein.sequences.v11.5.fa",
		        "enrichment_path": "157069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157069.protein.info.v11.5.txt",
		        "node_list_path": "157069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "157069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumLuteum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium luteum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumLuteum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33881.protein.sequences.v11.5.fa",
		        "enrichment_path": "33881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33881.protein.info.v11.5.txt",
		        "node_list_path": "33881.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusPhoenicisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus phoenicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusPhoenicisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1476583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1476583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1476583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1476583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1476583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1476583.protein.info.v11.5.txt",
		        "node_list_path": "1476583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1476583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterDelicatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter delicatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterDelicatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "218672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "218672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "218672.clusters.proteins.v11.5.txt",
		        "sequence_path": "218672.protein.sequences.v11.5.fa",
		        "enrichment_path": "218672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218672.protein.info.v11.5.txt",
		        "node_list_path": "218672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "218672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlaciecolaMesophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola mesophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaMesophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1128912.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1128912.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1128912.clusters.proteins.v11.5.txt",
		        "sequence_path": "1128912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128912.protein.info.v11.5.txt",
		        "node_list_path": "1128912.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1128912.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusTerreus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus terreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusTerreus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33178.protein.sequences.v11.5.fa",
		        "enrichment_path": "33178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33178.protein.info.v11.5.txt",
		        "node_list_path": "33178.protein.complete.v11.5.txt"
		    }
		]
    )()

def NautiliaProfundicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nautilia profundicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NautiliaProfundicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "598659.protein.sequences.v11.5.fa",
		        "enrichment_path": "598659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "598659.protein.info.v11.5.txt",
		        "node_list_path": "598659.protein.complete.v11.5.txt"
		    }
		]
    )()

def GuillardiaThetaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Guillardia theta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GuillardiaThetaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "55529.clusters.info.v11.5.txt",
		        "cluster_tree_path": "55529.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "55529.clusters.proteins.v11.5.txt",
		        "sequence_path": "55529.protein.sequences.v11.5.fa",
		        "enrichment_path": "55529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55529.protein.info.v11.5.txt",
		        "node_list_path": "55529.cluster.nodes.v11.5.txt",
		        "edge_list_path": "55529.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonasSpRw2a1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. RW2A1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasSpRw2a1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1917158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917158.protein.info.v11.5.txt",
		        "node_list_path": "1917158.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureimonasSpLeaf324(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpLeaf324", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736336.protein.info.v11.5.txt",
		        "node_list_path": "1736336.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacterCrescentusOr37Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter crescentus OR37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterCrescentusOr37Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1292034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1292034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1292034.clusters.proteins.v11.5.txt",
		        "sequence_path": "1292034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292034.protein.info.v11.5.txt",
		        "node_list_path": "1292034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1292034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophilusSp1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusSp1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1112273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112273.protein.info.v11.5.txt",
		        "node_list_path": "1112273.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaeMaculicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae maculicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaeMaculicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "629265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "629265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "629265.clusters.proteins.v11.5.txt",
		        "sequence_path": "629265.protein.sequences.v11.5.fa",
		        "enrichment_path": "629265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "629265.protein.info.v11.5.txt",
		        "node_list_path": "629265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "629265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwe23121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWE2_31_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwe23121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619073.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619073.protein.info.v11.5.txt",
		        "node_list_path": "1619073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasAquatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasAquatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "558964.protein.sequences.v11.5.fa",
		        "enrichment_path": "558964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558964.protein.info.v11.5.txt",
		        "node_list_path": "558964.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalitaleaSaponilacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalitalea saponilacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalitaleaSaponilacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "889453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "889453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "889453.clusters.proteins.v11.5.txt",
		        "sequence_path": "889453.protein.sequences.v11.5.fa",
		        "enrichment_path": "889453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "889453.protein.info.v11.5.txt",
		        "node_list_path": "889453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "889453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumAcidifaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acidifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumAcidifaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122994.protein.info.v11.5.txt",
		        "node_list_path": "1122994.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPutrefaciensMput9231Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens Mput9231 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPutrefaciensMput9231Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1292033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1292033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1292033.clusters.proteins.v11.5.txt",
		        "sequence_path": "1292033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292033.protein.info.v11.5.txt",
		        "node_list_path": "1292033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1292033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaLongibrachiatumAtcc18648(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma longibrachiatum ATCC 18648 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaLongibrachiatumAtcc18648", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983965.protein.sequences.v11.5.fa",
		        "enrichment_path": "983965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983965.protein.info.v11.5.txt",
		        "node_list_path": "983965.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriSdmlacCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri SDMLAC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriSdmlacCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1109445.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1109445.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1109445.clusters.proteins.v11.5.txt",
		        "sequence_path": "1109445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1109445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1109445.protein.info.v11.5.txt",
		        "node_list_path": "1109445.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1109445.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4422Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_44_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4422Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802669.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802669.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802669.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802669.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802669.protein.info.v11.5.txt",
		        "node_list_path": "1802669.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802669.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHtcc5015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC5015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHtcc5015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391615.clusters.proteins.v11.5.txt",
		        "sequence_path": "391615.protein.sequences.v11.5.fa",
		        "enrichment_path": "391615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391615.protein.info.v11.5.txt",
		        "node_list_path": "391615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcanthocheilonemaViteae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acanthocheilonema viteae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcanthocheilonemaViteae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6277.protein.sequences.v11.5.fa",
		        "enrichment_path": "6277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6277.protein.info.v11.5.txt",
		        "node_list_path": "6277.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioRhizosphaeraeDsm18581Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio rhizosphaerae DSM 18581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioRhizosphaeraeDsm18581Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123497.protein.info.v11.5.txt",
		        "node_list_path": "1123497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaAmmonioxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia ammonioxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaAmmonioxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "260086.protein.sequences.v11.5.fa",
		        "enrichment_path": "260086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "260086.protein.info.v11.5.txt",
		        "node_list_path": "260086.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBreve(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium breve graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBreve", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326426.protein.sequences.v11.5.fa",
		        "enrichment_path": "326426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326426.protein.info.v11.5.txt",
		        "node_list_path": "326426.protein.complete.v11.5.txt"
		    }
		]
    )()

def FriedmanniomycesSimplex(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Friedmanniomyces simplex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FriedmanniomycesSimplex", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "329884.protein.sequences.v11.5.fa",
		        "enrichment_path": "329884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "329884.protein.info.v11.5.txt",
		        "node_list_path": "329884.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaJogaejeotgaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella jogaejeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaJogaejeotgaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1631871.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1631871.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1631871.clusters.proteins.v11.5.txt",
		        "sequence_path": "1631871.protein.sequences.v11.5.fa",
		        "enrichment_path": "1631871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1631871.protein.info.v11.5.txt",
		        "node_list_path": "1631871.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1631871.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpPrwf1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. PRwf1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpPrwf1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349106.protein.sequences.v11.5.fa",
		        "enrichment_path": "349106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349106.protein.info.v11.5.txt",
		        "node_list_path": "349106.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735676.protein.info.v11.5.txt",
		        "node_list_path": "1735676.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho201Full6320Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_01_FULL_63_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho201Full6320Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802385.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802385.protein.info.v11.5.txt",
		        "node_list_path": "1802385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AccumulibacterSpBa93Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Accumulibacter sp. BA93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AccumulibacterSpBa93Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1454004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1454004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1454004.clusters.proteins.v11.5.txt",
		        "sequence_path": "1454004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454004.protein.info.v11.5.txt",
		        "node_list_path": "1454004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1454004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulforudisAudaxviatorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulforudis audaxviator Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulforudisAudaxviatorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "477974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "477974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "477974.clusters.proteins.v11.5.txt",
		        "sequence_path": "477974.protein.sequences.v11.5.fa",
		        "enrichment_path": "477974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477974.protein.info.v11.5.txt",
		        "node_list_path": "477974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "477974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumMathurense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium mathurense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumMathurense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "428990.protein.sequences.v11.5.fa",
		        "enrichment_path": "428990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428990.protein.info.v11.5.txt",
		        "node_list_path": "428990.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaSpErvv1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia sp. ErVv1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaSpErvv1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1603299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1603299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1603299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1603299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603299.protein.info.v11.5.txt",
		        "node_list_path": "1603299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1603299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaKrabiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora krabiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaKrabiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "307121.protein.sequences.v11.5.fa",
		        "enrichment_path": "307121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "307121.protein.info.v11.5.txt",
		        "node_list_path": "307121.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichodermaAtrovirideImi206040(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma atroviride IMI 206040 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaAtrovirideImi206040", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "452589.protein.sequences.v11.5.fa",
		        "enrichment_path": "452589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452589.protein.info.v11.5.txt",
		        "node_list_path": "452589.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyclobacteriumMarinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacterium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyclobacteriumMarinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "880070.protein.sequences.v11.5.fa",
		        "enrichment_path": "880070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880070.protein.info.v11.5.txt",
		        "node_list_path": "880070.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidimicrobiiaBacteriumRedseaS09B7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium REDSEA-S09_B7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidimicrobiiaBacteriumRedseaS09B7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811597.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811597.protein.info.v11.5.txt",
		        "node_list_path": "1811597.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusJorgensenbacteriaBacteriumGwa15412Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GWA1_54_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGwa15412Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798468.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798468.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798468.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798468.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798468.protein.info.v11.5.txt",
		        "node_list_path": "1798468.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798468.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumHigginsianum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum higginsianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumHigginsianum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "80884.protein.sequences.v11.5.fa",
		        "enrichment_path": "80884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80884.protein.info.v11.5.txt",
		        "node_list_path": "80884.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseivivaxLentusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax lentus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxLentusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "633194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "633194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "633194.clusters.proteins.v11.5.txt",
		        "sequence_path": "633194.protein.sequences.v11.5.fa",
		        "enrichment_path": "633194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633194.protein.info.v11.5.txt",
		        "node_list_path": "633194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "633194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchizoporaParadoxa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schizopora paradoxa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizoporaParadoxa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "27342.protein.sequences.v11.5.fa",
		        "enrichment_path": "27342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27342.protein.info.v11.5.txt",
		        "node_list_path": "27342.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full398(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_39_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full398", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797533.protein.info.v11.5.txt",
		        "node_list_path": "1797533.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusLactisIl1403(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus lactis Il1403 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusLactisIl1403", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272623.protein.sequences.v11.5.fa",
		        "enrichment_path": "272623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272623.protein.info.v11.5.txt",
		        "node_list_path": "272623.protein.complete.v11.5.txt"
		    }
		]
    )()

def RheinheimeraSpKl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera sp. KL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraSpKl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635005.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635005.protein.info.v11.5.txt",
		        "node_list_path": "1635005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasRuminantiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasRuminantiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "971.clusters.proteins.v11.5.txt",
		        "sequence_path": "971.protein.sequences.v11.5.fa",
		        "enrichment_path": "971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "971.protein.info.v11.5.txt",
		        "node_list_path": "971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpecialis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces specialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpecialis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "498367.protein.sequences.v11.5.fa",
		        "enrichment_path": "498367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498367.protein.info.v11.5.txt",
		        "node_list_path": "498367.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalothiobacillusSpLs2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halothiobacillus sp. LS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalothiobacillusSpLs2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1860122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860122.protein.info.v11.5.txt",
		        "node_list_path": "1860122.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusGraminisDsm20719(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus graminis DSM 20719 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGraminisDsm20719", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423752.protein.info.v11.5.txt",
		        "node_list_path": "1423752.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRhodolunaPlanktonica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rhodoluna planktonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRhodolunaPlanktonica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "535712.protein.sequences.v11.5.fa",
		        "enrichment_path": "535712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "535712.protein.info.v11.5.txt",
		        "node_list_path": "535712.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfatitaleaSpBrhC12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfatitalea sp. BRH_c12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfatitaleaSpBrhC12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629708.protein.info.v11.5.txt",
		        "node_list_path": "1629708.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaConspicuaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea conspicua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaConspicuaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "472705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "472705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "472705.clusters.proteins.v11.5.txt",
		        "sequence_path": "472705.protein.sequences.v11.5.fa",
		        "enrichment_path": "472705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472705.protein.info.v11.5.txt",
		        "node_list_path": "472705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "472705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalsuginibacillusKocurii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salsuginibacillus kocurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalsuginibacillusKocurii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123239.protein.info.v11.5.txt",
		        "node_list_path": "1123239.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraChibensisNbrc106107(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura chibensis NBRC 106107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraChibensisNbrc106107", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220554.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220554.protein.info.v11.5.txt",
		        "node_list_path": "1220554.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAureusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAureusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "193461.clusters.info.v11.5.txt",
		        "cluster_tree_path": "193461.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "193461.clusters.proteins.v11.5.txt",
		        "sequence_path": "193461.protein.sequences.v11.5.fa",
		        "enrichment_path": "193461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "193461.protein.info.v11.5.txt",
		        "node_list_path": "193461.cluster.nodes.v11.5.txt",
		        "edge_list_path": "193461.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesCaecimurisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides caecimuris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCaecimurisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1796613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1796613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1796613.clusters.proteins.v11.5.txt",
		        "sequence_path": "1796613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796613.protein.info.v11.5.txt",
		        "node_list_path": "1796613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1796613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaprevotellaXylaniphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraprevotella xylaniphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaprevotellaXylaniphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762982.protein.sequences.v11.5.fa",
		        "enrichment_path": "762982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762982.protein.info.v11.5.txt",
		        "node_list_path": "762982.protein.complete.v11.5.txt"
		    }
		]
    )()

def DictyosteliumPurpureum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dictyostelium purpureum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DictyosteliumPurpureum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5786.protein.sequences.v11.5.fa",
		        "enrichment_path": "5786.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5786.protein.info.v11.5.txt",
		        "node_list_path": "5786.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentzeaWaywayandensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentzea waywayandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentzeaWaywayandensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84724.clusters.proteins.v11.5.txt",
		        "sequence_path": "84724.protein.sequences.v11.5.fa",
		        "enrichment_path": "84724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84724.protein.info.v11.5.txt",
		        "node_list_path": "84724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetschnikowiaBicuspidataVarBicuspidataNrrlYb4993(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metschnikowia bicuspidata var. bicuspidata NRRL YB-4993 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetschnikowiaBicuspidataVarBicuspidataNrrlYb4993", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "869754.protein.sequences.v11.5.fa",
		        "enrichment_path": "869754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869754.protein.info.v11.5.txt",
		        "node_list_path": "869754.protein.complete.v11.5.txt"
		    }
		]
    )()

def LaccariaBicolorS238nH82(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Laccaria bicolor S238N-H82 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LaccariaBicolorS238nH82", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "486041.protein.sequences.v11.5.fa",
		        "enrichment_path": "486041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "486041.protein.info.v11.5.txt",
		        "node_list_path": "486041.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioMimicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio mimicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioMimicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675806.protein.sequences.v11.5.fa",
		        "enrichment_path": "675806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675806.protein.info.v11.5.txt",
		        "node_list_path": "675806.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryomycesMinteri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryomyces minteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryomycesMinteri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "331657.protein.sequences.v11.5.fa",
		        "enrichment_path": "331657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331657.protein.info.v11.5.txt",
		        "node_list_path": "331657.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfolobusIslandicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus islandicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusIslandicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930945.protein.sequences.v11.5.fa",
		        "enrichment_path": "930945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930945.protein.info.v11.5.txt",
		        "node_list_path": "930945.protein.complete.v11.5.txt"
		    }
		]
    )()

def TepidibacterFormicigenesDsm15518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tepidibacter formicigenes DSM 15518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidibacterFormicigenesDsm15518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123349.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123349.protein.info.v11.5.txt",
		        "node_list_path": "1123349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusDoucetiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus doucetiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusDoucetiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351671.protein.sequences.v11.5.fa",
		        "enrichment_path": "351671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351671.protein.info.v11.5.txt",
		        "node_list_path": "351671.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAld1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALD1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAld1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158150.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158150.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158150.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158150.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158150.protein.info.v11.5.txt",
		        "node_list_path": "1158150.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158150.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasOryzaePxo99a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae PXO99A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasOryzaePxo99a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "360094.protein.sequences.v11.5.fa",
		        "enrichment_path": "360094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360094.protein.info.v11.5.txt",
		        "node_list_path": "360094.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpC03(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpC03", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945858.protein.info.v11.5.txt",
		        "node_list_path": "1945858.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasChromatireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas chromatireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasChromatireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "507626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "507626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "507626.clusters.proteins.v11.5.txt",
		        "sequence_path": "507626.protein.sequences.v11.5.fa",
		        "enrichment_path": "507626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "507626.protein.info.v11.5.txt",
		        "node_list_path": "507626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "507626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaSubspArizonaeSerovar62Z4Z23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. arizonae serovar 62:z4,z23:- Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaSubspArizonaeSerovar62Z4Z23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "41514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "41514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "41514.clusters.proteins.v11.5.txt",
		        "sequence_path": "41514.protein.sequences.v11.5.fa",
		        "enrichment_path": "41514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41514.protein.info.v11.5.txt",
		        "node_list_path": "41514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "41514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasSpNm33Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasSpNm33Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "133724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "133724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "133724.clusters.proteins.v11.5.txt",
		        "sequence_path": "133724.protein.sequences.v11.5.fa",
		        "enrichment_path": "133724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133724.protein.info.v11.5.txt",
		        "node_list_path": "133724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "133724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpStflb209Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. StFLB209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpStflb209Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1028989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1028989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1028989.clusters.proteins.v11.5.txt",
		        "sequence_path": "1028989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028989.protein.info.v11.5.txt",
		        "node_list_path": "1028989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1028989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisBiprosthecum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis biprosthecum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisBiprosthecum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "715226.protein.sequences.v11.5.fa",
		        "enrichment_path": "715226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "715226.protein.info.v11.5.txt",
		        "node_list_path": "715226.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpXpd2006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. XPD2006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpXpd2006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280668.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280668.protein.info.v11.5.txt",
		        "node_list_path": "1280668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCollinoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus collinoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCollinoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33960.clusters.proteins.v11.5.txt",
		        "sequence_path": "33960.protein.sequences.v11.5.fa",
		        "enrichment_path": "33960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33960.protein.info.v11.5.txt",
		        "node_list_path": "33960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaueraSpMz1tCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. MZ1T Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraSpMz1tCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "85643.clusters.info.v11.5.txt",
		        "cluster_tree_path": "85643.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "85643.clusters.proteins.v11.5.txt",
		        "sequence_path": "85643.protein.sequences.v11.5.fa",
		        "enrichment_path": "85643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85643.protein.info.v11.5.txt",
		        "node_list_path": "85643.cluster.nodes.v11.5.txt",
		        "edge_list_path": "85643.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusOeniDsm19972Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oeni DSM 19972 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOeniDsm19972Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423777.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423777.protein.info.v11.5.txt",
		        "node_list_path": "1423777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaloceraViscosaTufc12733(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Calocera viscosa TUFC12733 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloceraViscosaTufc12733", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1330018.protein.sequences.v11.5.fa",
		        "enrichment_path": "1330018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1330018.protein.info.v11.5.txt",
		        "node_list_path": "1330018.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpHel185(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel185 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpHel185", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1250005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250005.protein.info.v11.5.txt",
		        "node_list_path": "1250005.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiUmn026(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli UMN026 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiUmn026", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585056.protein.sequences.v11.5.fa",
		        "enrichment_path": "585056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585056.protein.info.v11.5.txt",
		        "node_list_path": "585056.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSaudimassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus saudimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSaudimassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461583.protein.info.v11.5.txt",
		        "node_list_path": "1461583.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumCg2303331(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium CG2_30_33_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumCg2303331", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805033.protein.info.v11.5.txt",
		        "node_list_path": "1805033.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumRbg135518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_13_55_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumRbg135518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797197.protein.info.v11.5.txt",
		        "node_list_path": "1797197.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaSpCag317Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea sp. CAG:317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaSpCag317Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262873.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262873.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262873.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262873.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262873.protein.info.v11.5.txt",
		        "node_list_path": "1262873.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262873.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaWenyoniiStrMassachusettsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma wenyonii str. Massachusetts Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaWenyoniiStrMassachusettsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1197325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1197325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1197325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1197325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197325.protein.info.v11.5.txt",
		        "node_list_path": "1197325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1197325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaMiyunensisNbrc108239(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia miyunensis NBRC 108239 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaMiyunensisNbrc108239", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210084.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210084.protein.info.v11.5.txt",
		        "node_list_path": "1210084.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsplowo201Full4211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO2_01_FULL_42_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201Full4211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802627.protein.info.v11.5.txt",
		        "node_list_path": "1802627.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemellaSpOralTaxon928(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemella sp. oral taxon 928 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaSpOralTaxon928", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1785995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1785995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1785995.protein.info.v11.5.txt",
		        "node_list_path": "1785995.protein.complete.v11.5.txt"
		    }
		]
    )()

def DaldiniaSpEc12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Daldinia sp. EC12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DaldiniaSpEc12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1001832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1001832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1001832.clusters.proteins.v11.5.txt",
		        "sequence_path": "1001832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001832.protein.info.v11.5.txt",
		        "node_list_path": "1001832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1001832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgromycesFlavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agromyces flavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesFlavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "589382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "589382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "589382.clusters.proteins.v11.5.txt",
		        "sequence_path": "589382.protein.sequences.v11.5.fa",
		        "enrichment_path": "589382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "589382.protein.info.v11.5.txt",
		        "node_list_path": "589382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "589382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DysgonomonasGadeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas gadei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasGadeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742766.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742766.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742766.clusters.proteins.v11.5.txt",
		        "sequence_path": "742766.protein.sequences.v11.5.fa",
		        "enrichment_path": "742766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742766.protein.info.v11.5.txt",
		        "node_list_path": "742766.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742766.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkelbacteriaBacteriumCg2304320(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium CG2_30_43_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumCg2304320", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805038.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805038.protein.info.v11.5.txt",
		        "node_list_path": "1805038.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophusGentianaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophus gentianae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophusGentianaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43775.clusters.proteins.v11.5.txt",
		        "sequence_path": "43775.protein.sequences.v11.5.fa",
		        "enrichment_path": "43775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43775.protein.info.v11.5.txt",
		        "node_list_path": "43775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCamporealensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium camporealensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCamporealensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "161896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "161896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "161896.clusters.proteins.v11.5.txt",
		        "sequence_path": "161896.protein.sequences.v11.5.fa",
		        "enrichment_path": "161896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161896.protein.info.v11.5.txt",
		        "node_list_path": "161896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "161896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpPm2P129(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. PM2-P1-29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpPm2P129", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "403776.protein.sequences.v11.5.fa",
		        "enrichment_path": "403776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "403776.protein.info.v11.5.txt",
		        "node_list_path": "403776.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobaculumSpF0552Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum sp. F0552 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobaculumSpF0552Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227261.protein.info.v11.5.txt",
		        "node_list_path": "1227261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFluviicolaRiflensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fluviicola riflensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFluviicolaRiflensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798018.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798018.protein.info.v11.5.txt",
		        "node_list_path": "1798018.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingorhabdusSpM41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingorhabdus sp. M41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingorhabdusSpM41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1806885.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1806885.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1806885.clusters.proteins.v11.5.txt",
		        "sequence_path": "1806885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806885.protein.info.v11.5.txt",
		        "node_list_path": "1806885.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1806885.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaAmaraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia amarae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaAmaraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1075090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1075090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1075090.clusters.proteins.v11.5.txt",
		        "sequence_path": "1075090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1075090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1075090.protein.info.v11.5.txt",
		        "node_list_path": "1075090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1075090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaBuccalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia buccalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaBuccalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "523794.clusters.info.v11.5.txt",
		        "cluster_tree_path": "523794.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "523794.clusters.proteins.v11.5.txt",
		        "sequence_path": "523794.protein.sequences.v11.5.fa",
		        "enrichment_path": "523794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523794.protein.info.v11.5.txt",
		        "node_list_path": "523794.cluster.nodes.v11.5.txt",
		        "edge_list_path": "523794.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesHygroscopicusSubspHygroscopicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus subsp. hygroscopicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesHygroscopicusSubspHygroscopicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68042.clusters.proteins.v11.5.txt",
		        "sequence_path": "68042.protein.sequences.v11.5.fa",
		        "enrichment_path": "68042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68042.protein.info.v11.5.txt",
		        "node_list_path": "68042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureimonasPhyllosphaerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas phyllosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasPhyllosphaerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1166078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166078.protein.info.v11.5.txt",
		        "node_list_path": "1166078.protein.complete.v11.5.txt"
		    }
		]
    )()

def DaphniaMagna(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Daphnia magna graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DaphniaMagna", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35525.protein.sequences.v11.5.fa",
		        "enrichment_path": "35525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35525.protein.info.v11.5.txt",
		        "node_list_path": "35525.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpUrhe0023Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. URHE0023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpUrhe0023Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380354.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380354.protein.info.v11.5.txt",
		        "node_list_path": "1380354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumCg104632Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium CG10_46_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumCg104632Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1911907.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1911907.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1911907.clusters.proteins.v11.5.txt",
		        "sequence_path": "1911907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1911907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1911907.protein.info.v11.5.txt",
		        "node_list_path": "1911907.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1911907.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpW2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. W2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpW2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203261.protein.info.v11.5.txt",
		        "node_list_path": "1203261.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumFreiburgense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium freiburgense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumFreiburgense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121360.protein.info.v11.5.txt",
		        "node_list_path": "1121360.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwa26924(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_69_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwa26924", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797927.protein.info.v11.5.txt",
		        "node_list_path": "1797927.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumHalophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum halophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumHalophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "413816.protein.sequences.v11.5.fa",
		        "enrichment_path": "413816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "413816.protein.info.v11.5.txt",
		        "node_list_path": "413816.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenimonasThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenimonas thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenimonasThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "223786.protein.sequences.v11.5.fa",
		        "enrichment_path": "223786.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223786.protein.info.v11.5.txt",
		        "node_list_path": "223786.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeodermatophilaceaeBacteriumUrhb0062(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHB0062 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilaceaeBacteriumUrhb0062", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380353.protein.info.v11.5.txt",
		        "node_list_path": "1380353.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodonellumPsychrophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodonellum psychrophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodonellumPsychrophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123057.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123057.protein.info.v11.5.txt",
		        "node_list_path": "1123057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusLentulusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus lentulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusLentulusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "293939.clusters.info.v11.5.txt",
		        "cluster_tree_path": "293939.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "293939.clusters.proteins.v11.5.txt",
		        "sequence_path": "293939.protein.sequences.v11.5.fa",
		        "enrichment_path": "293939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "293939.protein.info.v11.5.txt",
		        "node_list_path": "293939.cluster.nodes.v11.5.txt",
		        "edge_list_path": "293939.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaOrthopsilosisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida orthopsilosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaOrthopsilosisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "273371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "273371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "273371.clusters.proteins.v11.5.txt",
		        "sequence_path": "273371.protein.sequences.v11.5.fa",
		        "enrichment_path": "273371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273371.protein.info.v11.5.txt",
		        "node_list_path": "273371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "273371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhycomycesBlakesleeanusNrrl1555Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phycomyces blakesleeanus NRRL 1555(-) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycomycesBlakesleeanusNrrl1555Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "763407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "763407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "763407.clusters.proteins.v11.5.txt",
		        "sequence_path": "763407.protein.sequences.v11.5.fa",
		        "enrichment_path": "763407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "763407.protein.info.v11.5.txt",
		        "node_list_path": "763407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "763407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSteyniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter steynii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSteyniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "430522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "430522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "430522.clusters.proteins.v11.5.txt",
		        "sequence_path": "430522.protein.sequences.v11.5.fa",
		        "enrichment_path": "430522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "430522.protein.info.v11.5.txt",
		        "node_list_path": "430522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "430522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldibacillusDebilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldibacillus debilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldibacillusDebilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "301148.clusters.info.v11.5.txt",
		        "cluster_tree_path": "301148.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "301148.clusters.proteins.v11.5.txt",
		        "sequence_path": "301148.protein.sequences.v11.5.fa",
		        "enrichment_path": "301148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "301148.protein.info.v11.5.txt",
		        "node_list_path": "301148.cluster.nodes.v11.5.txt",
		        "edge_list_path": "301148.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyorhinisSk76(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis SK76 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyorhinisSk76", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118964.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118964.protein.info.v11.5.txt",
		        "node_list_path": "1118964.protein.complete.v11.5.txt"
		    }
		]
    )()

def NegativicoccusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Negativicoccus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NegativicoccusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1702287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1702287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1702287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1702287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1702287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1702287.protein.info.v11.5.txt",
		        "node_list_path": "1702287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1702287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusDendritiformisC454(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus dendritiformis C454 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusDendritiformisC454", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131935.protein.info.v11.5.txt",
		        "node_list_path": "1131935.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag709(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:709 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag709", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262748.protein.info.v11.5.txt",
		        "node_list_path": "1262748.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterCryohalolentisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter cryohalolentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterCryohalolentisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "335284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "335284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "335284.clusters.proteins.v11.5.txt",
		        "sequence_path": "335284.protein.sequences.v11.5.fa",
		        "enrichment_path": "335284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335284.protein.info.v11.5.txt",
		        "node_list_path": "335284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "335284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycetalesBacterium457213(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 4572_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetalesBacterium457213", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1971638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971638.protein.info.v11.5.txt",
		        "node_list_path": "1971638.protein.complete.v11.5.txt"
		    }
		]
    )()

def NaumovozymaDairenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma dairenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NaumovozymaDairenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "27289.clusters.info.v11.5.txt",
		        "cluster_tree_path": "27289.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "27289.clusters.proteins.v11.5.txt",
		        "sequence_path": "27289.protein.sequences.v11.5.fa",
		        "enrichment_path": "27289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27289.protein.info.v11.5.txt",
		        "node_list_path": "27289.cluster.nodes.v11.5.txt",
		        "edge_list_path": "27289.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9215Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9215 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9215Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93060.clusters.proteins.v11.5.txt",
		        "sequence_path": "93060.protein.sequences.v11.5.fa",
		        "enrichment_path": "93060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93060.protein.info.v11.5.txt",
		        "node_list_path": "93060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusNeutrinimicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus neutrinimicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusNeutrinimicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "105420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "105420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "105420.clusters.proteins.v11.5.txt",
		        "sequence_path": "105420.protein.sequences.v11.5.fa",
		        "enrichment_path": "105420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105420.protein.info.v11.5.txt",
		        "node_list_path": "105420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "105420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomonasBhubaneswarensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas bhubaneswarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomonasBhubaneswarensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "339866.protein.sequences.v11.5.fa",
		        "enrichment_path": "339866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "339866.protein.info.v11.5.txt",
		        "node_list_path": "339866.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaLongicatena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dorea longicatena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaLongicatena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "88431.protein.sequences.v11.5.fa",
		        "enrichment_path": "88431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "88431.protein.info.v11.5.txt",
		        "node_list_path": "88431.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpLc2012Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. lc2012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpLc2012Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761886.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761886.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761886.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761886.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761886.protein.info.v11.5.txt",
		        "node_list_path": "1761886.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761886.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DokdonellaKoreensisDs123Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dokdonella koreensis DS-123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DokdonellaKoreensisDs123Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1300342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1300342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1300342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1300342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300342.protein.info.v11.5.txt",
		        "node_list_path": "1300342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1300342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSoliNbrc106424(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax soli NBRC 106424 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSoliNbrc106424", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321611.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321611.protein.info.v11.5.txt",
		        "node_list_path": "1321611.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovispirillumItersonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novispirillum itersonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovispirillumItersonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1279038.protein.sequences.v11.5.fa",
		        "enrichment_path": "1279038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1279038.protein.info.v11.5.txt",
		        "node_list_path": "1279038.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScheffersomycesStipitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scheffersomyces stipitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScheffersomycesStipitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4924.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4924.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4924.clusters.proteins.v11.5.txt",
		        "sequence_path": "4924.protein.sequences.v11.5.fa",
		        "enrichment_path": "4924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4924.protein.info.v11.5.txt",
		        "node_list_path": "4924.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4924.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaFeeleii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella feeleii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaFeeleii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "453.protein.sequences.v11.5.fa",
		        "enrichment_path": "453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "453.protein.info.v11.5.txt",
		        "node_list_path": "453.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusXylanilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus xylanilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusXylanilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582475.clusters.proteins.v11.5.txt",
		        "sequence_path": "582475.protein.sequences.v11.5.fa",
		        "enrichment_path": "582475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582475.protein.info.v11.5.txt",
		        "node_list_path": "582475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionKsb1Bacterium448487Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division KSB1 bacterium 4484_87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionKsb1Bacterium448487Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1970772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1970772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1970772.clusters.proteins.v11.5.txt",
		        "sequence_path": "1970772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970772.protein.info.v11.5.txt",
		        "node_list_path": "1970772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1970772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurovumSpAr(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum sp. AR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurovumSpAr", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1165841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1165841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1165841.protein.info.v11.5.txt",
		        "node_list_path": "1165841.protein.complete.v11.5.txt"
		    }
		]
    )()

def GadusMorhua(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gadus morhua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GadusMorhua", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8049.protein.sequences.v11.5.fa",
		        "enrichment_path": "8049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8049.protein.info.v11.5.txt",
		        "node_list_path": "8049.protein.complete.v11.5.txt"
		    }
		]
    )()

def WinogradskyellaSpRha55(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Winogradskyella sp. RHA_55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinogradskyellaSpRha55", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1249933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249933.protein.info.v11.5.txt",
		        "node_list_path": "1249933.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSyntrophoarchaeumButanivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Syntrophoarchaeum butanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSyntrophoarchaeumButanivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1839936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1839936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1839936.protein.info.v11.5.txt",
		        "node_list_path": "1839936.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSubvibrioidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas subvibrioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSubvibrioidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "633149.clusters.info.v11.5.txt",
		        "cluster_tree_path": "633149.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "633149.clusters.proteins.v11.5.txt",
		        "sequence_path": "633149.protein.sequences.v11.5.fa",
		        "enrichment_path": "633149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633149.protein.info.v11.5.txt",
		        "node_list_path": "633149.cluster.nodes.v11.5.txt",
		        "edge_list_path": "633149.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanolobusProfundiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus profundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolobusProfundiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "487685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "487685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "487685.clusters.proteins.v11.5.txt",
		        "sequence_path": "487685.protein.sequences.v11.5.fa",
		        "enrichment_path": "487685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487685.protein.info.v11.5.txt",
		        "node_list_path": "487685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "487685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseobacterSpAzwk3b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. AzwK3b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterSpAzwk3b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351016.protein.sequences.v11.5.fa",
		        "enrichment_path": "351016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351016.protein.info.v11.5.txt",
		        "node_list_path": "351016.protein.complete.v11.5.txt"
		    }
		]
    )()

def SteccherinumOchraceumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Steccherinum ochraceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SteccherinumOchraceumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "92696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "92696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "92696.clusters.proteins.v11.5.txt",
		        "sequence_path": "92696.protein.sequences.v11.5.fa",
		        "enrichment_path": "92696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92696.protein.info.v11.5.txt",
		        "node_list_path": "92696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "92696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp141Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 141 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp141Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120797.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120797.protein.info.v11.5.txt",
		        "node_list_path": "1120797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaSpUcdKl21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. UCD-KL21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSpUcdKl21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1917164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917164.protein.info.v11.5.txt",
		        "node_list_path": "1917164.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpermophilusDauricus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spermophilus dauricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpermophilusDauricus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "99837.protein.sequences.v11.5.fa",
		        "enrichment_path": "99837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "99837.protein.info.v11.5.txt",
		        "node_list_path": "99837.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpNk2b42(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. NK2B42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpNk2b42", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "689781.protein.sequences.v11.5.fa",
		        "enrichment_path": "689781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "689781.protein.info.v11.5.txt",
		        "node_list_path": "689781.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacterium13220cm6814Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium 13_2_20CM_68_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacterium13220cm6814Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803496.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803496.protein.info.v11.5.txt",
		        "node_list_path": "1803496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpAdetyCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. AdeTY Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpAdetyCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1391647.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1391647.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1391647.clusters.proteins.v11.5.txt",
		        "sequence_path": "1391647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391647.protein.info.v11.5.txt",
		        "node_list_path": "1391647.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1391647.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumAestuariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumAestuariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1638982.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1638982.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1638982.clusters.proteins.v11.5.txt",
		        "sequence_path": "1638982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638982.protein.info.v11.5.txt",
		        "node_list_path": "1638982.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1638982.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AerococcusUrinaehominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus urinaehominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusUrinaehominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "128944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "128944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "128944.clusters.proteins.v11.5.txt",
		        "sequence_path": "128944.protein.sequences.v11.5.fa",
		        "enrichment_path": "128944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "128944.protein.info.v11.5.txt",
		        "node_list_path": "128944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "128944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MitsuariaChitosanitabidaAtccBaa476Nbrc102408(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mitsuaria chitosanitabida ATCC BAA-476 NBRC 102408 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MitsuariaChitosanitabidaAtccBaa476Nbrc102408", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336246.protein.info.v11.5.txt",
		        "node_list_path": "1336246.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporanaerobacterAcetigenesDsm13106(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporanaerobacter acetigenes DSM 13106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporanaerobacterAcetigenesDsm13106", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123281.protein.info.v11.5.txt",
		        "node_list_path": "1123281.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMicrarchaeotaArchaeonCg1026051(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_60_51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1026051", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805252.protein.info.v11.5.txt",
		        "node_list_path": "1805252.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusRhinitidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus rhinitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusRhinitidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "875454.protein.sequences.v11.5.fa",
		        "enrichment_path": "875454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "875454.protein.info.v11.5.txt",
		        "node_list_path": "875454.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoplasmatalesArchaeonIPlasmaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon I-plasma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmatalesArchaeonIPlasmaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "667138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "667138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "667138.clusters.proteins.v11.5.txt",
		        "sequence_path": "667138.protein.sequences.v11.5.fa",
		        "enrichment_path": "667138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667138.protein.info.v11.5.txt",
		        "node_list_path": "667138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "667138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumThermoresistibileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium thermoresistibile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumThermoresistibileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797.protein.info.v11.5.txt",
		        "node_list_path": "1797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JoostellaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Joostella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JoostellaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926559.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926559.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926559.clusters.proteins.v11.5.txt",
		        "sequence_path": "926559.protein.sequences.v11.5.fa",
		        "enrichment_path": "926559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926559.protein.info.v11.5.txt",
		        "node_list_path": "926559.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926559.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacterVibrioformisDsm8776Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacter vibrioformis DSM 8776 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacterVibrioformisDsm8776Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121398.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121398.protein.info.v11.5.txt",
		        "node_list_path": "1121398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwf13135(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWF1_31_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwf13135", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618600.protein.info.v11.5.txt",
		        "node_list_path": "1618600.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryptosporidiumMuris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporidium muris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptosporidiumMuris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5808.protein.sequences.v11.5.fa",
		        "enrichment_path": "5808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5808.protein.info.v11.5.txt",
		        "node_list_path": "5808.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacteraceaeBacteriumGwc25520(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_55_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacteraceaeBacteriumGwc25520", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798317.protein.info.v11.5.txt",
		        "node_list_path": "1798317.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErysipelotrichaceaeBacteriumMtc7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium MTC7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelotrichaceaeBacteriumMtc7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1768196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768196.protein.info.v11.5.txt",
		        "node_list_path": "1768196.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacterium13220cm6619Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 13_2_20CM_66_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacterium13220cm6619Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805166.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805166.protein.info.v11.5.txt",
		        "node_list_path": "1805166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophobacterFumaroxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophobacter fumaroxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophobacterFumaroxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "335543.protein.sequences.v11.5.fa",
		        "enrichment_path": "335543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335543.protein.info.v11.5.txt",
		        "node_list_path": "335543.protein.complete.v11.5.txt"
		    }
		]
    )()

def MelghirimycesThermohalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Melghirimyces thermohalophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MelghirimycesThermohalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236220.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236220.protein.info.v11.5.txt",
		        "node_list_path": "1236220.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusSpBab2008Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus sp. BAB2008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusSpBab2008Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246484.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246484.protein.info.v11.5.txt",
		        "node_list_path": "1246484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho202Full4213(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_02_FULL_42_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho202Full4213", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798271.protein.info.v11.5.txt",
		        "node_list_path": "1798271.protein.complete.v11.5.txt"
		    }
		]
    )()

def StappiaStellulataDsm5886(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stappia stellulata DSM 5886 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StappiaStellulataDsm5886", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123294.protein.info.v11.5.txt",
		        "node_list_path": "1123294.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusResistens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus resistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusResistens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1750590.protein.sequences.v11.5.fa",
		        "enrichment_path": "1750590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1750590.protein.info.v11.5.txt",
		        "node_list_path": "1750590.protein.complete.v11.5.txt"
		    }
		]
    )()

def PandoraeaSpSd62(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea sp. SD62 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaSpSd62", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1286093.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286093.protein.info.v11.5.txt",
		        "node_list_path": "1286093.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSaudimassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus saudimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSaudimassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461583.protein.info.v11.5.txt",
		        "node_list_path": "1461583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumJaponicumUsda124Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum USDA124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumJaponicumUsda124Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1038862.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1038862.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1038862.clusters.proteins.v11.5.txt",
		        "sequence_path": "1038862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038862.protein.info.v11.5.txt",
		        "node_list_path": "1038862.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1038862.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaTimonensisCris5cb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella timonensis CRIS5CB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaTimonensisCris5cb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679189.protein.sequences.v11.5.fa",
		        "enrichment_path": "679189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679189.protein.info.v11.5.txt",
		        "node_list_path": "679189.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDelongbacteriaBacteriumGwf24014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Delongbacteria bacterium GWF2_40_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDelongbacteriaBacteriumGwf24014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817817.protein.info.v11.5.txt",
		        "node_list_path": "1817817.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasNasdaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas nasdae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasNasdaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "172043.clusters.info.v11.5.txt",
		        "cluster_tree_path": "172043.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "172043.clusters.proteins.v11.5.txt",
		        "sequence_path": "172043.protein.sequences.v11.5.fa",
		        "enrichment_path": "172043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "172043.protein.info.v11.5.txt",
		        "node_list_path": "172043.cluster.nodes.v11.5.txt",
		        "edge_list_path": "172043.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubritaleaSqualenifaciensDsm18772Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubritalea squalenifaciens DSM 18772 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubritaleaSqualenifaciensDsm18772Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123071.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123071.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123071.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123071.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123071.protein.info.v11.5.txt",
		        "node_list_path": "1123071.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123071.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumExpansum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium expansum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumExpansum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "27334.protein.sequences.v11.5.fa",
		        "enrichment_path": "27334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27334.protein.info.v11.5.txt",
		        "node_list_path": "27334.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpB6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. B6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpB6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1295626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1295626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1295626.protein.info.v11.5.txt",
		        "node_list_path": "1295626.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpCg2304434Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. CG2_30_44_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpCg2304434Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805397.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805397.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805397.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805397.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805397.protein.info.v11.5.txt",
		        "node_list_path": "1805397.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805397.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyadobacterPsychrophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter psychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterPsychrophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "651661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "651661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "651661.clusters.proteins.v11.5.txt",
		        "sequence_path": "651661.protein.sequences.v11.5.fa",
		        "enrichment_path": "651661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "651661.protein.info.v11.5.txt",
		        "node_list_path": "651661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "651661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumPhlei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium phlei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumPhlei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150599.protein.info.v11.5.txt",
		        "node_list_path": "1150599.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhaeodactylumTricornutumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeodactylum tricornutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeodactylumTricornutumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2850.clusters.proteins.v11.5.txt",
		        "sequence_path": "2850.protein.sequences.v11.5.fa",
		        "enrichment_path": "2850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2850.protein.info.v11.5.txt",
		        "node_list_path": "2850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaHispanicaCriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia hispanica CRI Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaHispanicaCriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1417229.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1417229.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1417229.clusters.proteins.v11.5.txt",
		        "sequence_path": "1417229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1417229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1417229.protein.info.v11.5.txt",
		        "node_list_path": "1417229.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1417229.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeotrichumCandidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geotrichum candidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeotrichumCandidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173061.protein.info.v11.5.txt",
		        "node_list_path": "1173061.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallibacteriumGenomospCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallibacteriumGenomospCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "155515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "155515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "155515.clusters.proteins.v11.5.txt",
		        "sequence_path": "155515.protein.sequences.v11.5.fa",
		        "enrichment_path": "155515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "155515.protein.info.v11.5.txt",
		        "node_list_path": "155515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "155515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenimonasMalthae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas malthae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenimonasMalthae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1384054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384054.protein.info.v11.5.txt",
		        "node_list_path": "1384054.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "108003.protein.sequences.v11.5.fa",
		        "enrichment_path": "108003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "108003.protein.info.v11.5.txt",
		        "node_list_path": "108003.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgromycesSpCf514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agromyces sp. CF514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesSpCf514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881031.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881031.protein.info.v11.5.txt",
		        "node_list_path": "1881031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SutterellaSpCag521(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sutterella sp. CAG:521 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SutterellaSpCag521", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262977.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262977.protein.info.v11.5.txt",
		        "node_list_path": "1262977.protein.complete.v11.5.txt"
		    }
		]
    )()

def RodentolepisNana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rodentolepis nana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentolepisNana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "102285.protein.sequences.v11.5.fa",
		        "enrichment_path": "102285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102285.protein.info.v11.5.txt",
		        "node_list_path": "102285.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesSpZor0009(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. ZOR0009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpZor0009", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1339253.protein.sequences.v11.5.fa",
		        "enrichment_path": "1339253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1339253.protein.info.v11.5.txt",
		        "node_list_path": "1339253.protein.complete.v11.5.txt"
		    }
		]
    )()

def StanieriaCyanosphaeraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stanieria cyanosphaera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StanieriaCyanosphaeraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "111780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "111780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "111780.clusters.proteins.v11.5.txt",
		        "sequence_path": "111780.protein.sequences.v11.5.fa",
		        "enrichment_path": "111780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "111780.protein.info.v11.5.txt",
		        "node_list_path": "111780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "111780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaNonliquefaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella nonliquefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaNonliquefaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "478.protein.sequences.v11.5.fa",
		        "enrichment_path": "478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "478.protein.info.v11.5.txt",
		        "node_list_path": "478.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag460Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:460 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag460Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263024.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263024.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263024.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263024.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263024.protein.info.v11.5.txt",
		        "node_list_path": "1263024.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263024.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSinduriensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sinduriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSinduriensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1384057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1384057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1384057.clusters.proteins.v11.5.txt",
		        "sequence_path": "1384057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384057.protein.info.v11.5.txt",
		        "node_list_path": "1384057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1384057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusMucilaginosus3016(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus mucilaginosus 3016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusMucilaginosus3016", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1116391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116391.protein.info.v11.5.txt",
		        "node_list_path": "1116391.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusConstellatusPharyngisC1050Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus constellatus pharyngis C1050 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusConstellatusPharyngisC1050Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "862969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "862969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "862969.clusters.proteins.v11.5.txt",
		        "sequence_path": "862969.protein.sequences.v11.5.fa",
		        "enrichment_path": "862969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862969.protein.info.v11.5.txt",
		        "node_list_path": "862969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "862969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusTerrigenaDsm22685(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus terrigena DSM 22685 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusTerrigenaDsm22685", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120967.protein.info.v11.5.txt",
		        "node_list_path": "1120967.protein.complete.v11.5.txt"
		    }
		]
    )()

def FervidobacteriumIslandicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium islandicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidobacteriumIslandicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2423.clusters.proteins.v11.5.txt",
		        "sequence_path": "2423.protein.sequences.v11.5.fa",
		        "enrichment_path": "2423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2423.protein.info.v11.5.txt",
		        "node_list_path": "2423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpR1200b2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. R1200B2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpR1200b2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1509405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1509405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1509405.protein.info.v11.5.txt",
		        "node_list_path": "1509405.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumTetaniE88(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tetani E88 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTetaniE88", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "212717.protein.sequences.v11.5.fa",
		        "enrichment_path": "212717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "212717.protein.info.v11.5.txt",
		        "node_list_path": "212717.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpEc33Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ec33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpEc33Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "189753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "189753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "189753.clusters.proteins.v11.5.txt",
		        "sequence_path": "189753.protein.sequences.v11.5.fa",
		        "enrichment_path": "189753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189753.protein.info.v11.5.txt",
		        "node_list_path": "189753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "189753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterPsychrotoleransDsm18569Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter psychrotolerans DSM 18569 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterPsychrotoleransDsm18569Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121959.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121959.protein.info.v11.5.txt",
		        "node_list_path": "1121959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterMucosalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter mucosalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterMucosalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "202.protein.sequences.v11.5.fa",
		        "enrichment_path": "202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202.protein.info.v11.5.txt",
		        "node_list_path": "202.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSphenisciDsm44792(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sphenisci DSM 44792 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSphenisciDsm44792", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437874.protein.info.v11.5.txt",
		        "node_list_path": "1437874.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerohalosphaeraLusitana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerohalosphaera lusitana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerohalosphaeraLusitana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1936003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1936003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1936003.protein.info.v11.5.txt",
		        "node_list_path": "1936003.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpQssc122bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. QSSC1-22B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpQssc122bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1860125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1860125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1860125.clusters.proteins.v11.5.txt",
		        "sequence_path": "1860125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860125.protein.info.v11.5.txt",
		        "node_list_path": "1860125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1860125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeucothrixMucor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucothrix mucor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucothrixMucor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "998674.protein.sequences.v11.5.fa",
		        "enrichment_path": "998674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "998674.protein.info.v11.5.txt",
		        "node_list_path": "998674.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlycomycesSpNrrlb16210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glycomyces sp. NRRLB16210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlycomycesSpNrrlb16210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463821.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463821.protein.info.v11.5.txt",
		        "node_list_path": "1463821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphiprionOcellaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amphiprion ocellaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphiprionOcellaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "80972.protein.sequences.v11.5.fa",
		        "enrichment_path": "80972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80972.protein.info.v11.5.txt",
		        "node_list_path": "80972.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegasphaeraSpUpii135eCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. UPII135E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraSpUpii135eCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1000569.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1000569.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1000569.clusters.proteins.v11.5.txt",
		        "sequence_path": "1000569.protein.sequences.v11.5.fa",
		        "enrichment_path": "1000569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1000569.protein.info.v11.5.txt",
		        "node_list_path": "1000569.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1000569.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwc14311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWC1_43_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwc14311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618520.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618520.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618520.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618520.protein.info.v11.5.txt",
		        "node_list_path": "1618520.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618520.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilaceaeBacteriumUrha0031Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHA0031 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilaceaeBacteriumUrha0031Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380393.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380393.protein.info.v11.5.txt",
		        "node_list_path": "1380393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterShowaeCc57cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter showae CC57C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterShowaeCc57cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1073353.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1073353.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1073353.clusters.proteins.v11.5.txt",
		        "sequence_path": "1073353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073353.protein.info.v11.5.txt",
		        "node_list_path": "1073353.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1073353.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaLoihiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina loihiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaLoihiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "283942.protein.sequences.v11.5.fa",
		        "enrichment_path": "283942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283942.protein.info.v11.5.txt",
		        "node_list_path": "283942.protein.complete.v11.5.txt"
		    }
		]
    )()

def FaecalibacteriumPrausnitziiA2165(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii A2165 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibacteriumPrausnitziiA2165", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411483.protein.sequences.v11.5.fa",
		        "enrichment_path": "411483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411483.protein.info.v11.5.txt",
		        "node_list_path": "411483.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanothermobacterThermautotrophicusStrDeltaH(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter thermautotrophicus str. Delta H graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermobacterThermautotrophicusStrDeltaH", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "187420.protein.sequences.v11.5.fa",
		        "enrichment_path": "187420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "187420.protein.info.v11.5.txt",
		        "node_list_path": "187420.protein.complete.v11.5.txt"
		    }
		]
    )()

def EmergomycesPasteurianusEp9510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Emergomyces pasteurianus Ep9510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmergomycesPasteurianusEp9510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1447872.protein.sequences.v11.5.fa",
		        "enrichment_path": "1447872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1447872.protein.info.v11.5.txt",
		        "node_list_path": "1447872.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusSzentirmaiiDsm16338(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus szentirmaii DSM 16338 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusSzentirmaiiDsm16338", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1427518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1427518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1427518.protein.info.v11.5.txt",
		        "node_list_path": "1427518.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifoxyc2Full3612Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYC2_FULL_36_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyc2Full3612Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798002.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798002.protein.info.v11.5.txt",
		        "node_list_path": "1798002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OstreococcusLucimarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ostreococcus lucimarinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OstreococcusLucimarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "242159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "242159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "242159.clusters.proteins.v11.5.txt",
		        "sequence_path": "242159.protein.sequences.v11.5.fa",
		        "enrichment_path": "242159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "242159.protein.info.v11.5.txt",
		        "node_list_path": "242159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "242159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalimicrobiumAerophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalimicrobium aerophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalimicrobiumAerophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717772.clusters.proteins.v11.5.txt",
		        "sequence_path": "717772.protein.sequences.v11.5.fa",
		        "enrichment_path": "717772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717772.protein.info.v11.5.txt",
		        "node_list_path": "717772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PectobacteriumAtrosepticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium atrosepticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumAtrosepticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "218491.protein.sequences.v11.5.fa",
		        "enrichment_path": "218491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218491.protein.info.v11.5.txt",
		        "node_list_path": "218491.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaAkariCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia akari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaAkariCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "293614.clusters.info.v11.5.txt",
		        "cluster_tree_path": "293614.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "293614.clusters.proteins.v11.5.txt",
		        "sequence_path": "293614.protein.sequences.v11.5.fa",
		        "enrichment_path": "293614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "293614.protein.info.v11.5.txt",
		        "node_list_path": "293614.cluster.nodes.v11.5.txt",
		        "edge_list_path": "293614.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumGwc27318Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWC2_73_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumGwc27318Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797616.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797616.protein.info.v11.5.txt",
		        "node_list_path": "1797616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr35(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr35", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1934992.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934992.protein.info.v11.5.txt",
		        "node_list_path": "1934992.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1750560.protein.sequences.v11.5.fa",
		        "enrichment_path": "1750560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1750560.protein.info.v11.5.txt",
		        "node_list_path": "1750560.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxXenomutans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax xenomutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxXenomutans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094342.protein.info.v11.5.txt",
		        "node_list_path": "1094342.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCcmMd2014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CCM_MD2014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCcmMd2014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1561022.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561022.protein.info.v11.5.txt",
		        "node_list_path": "1561022.protein.complete.v11.5.txt"
		    }
		]
    )()

def CedeceaNeteriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cedecea neteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CedeceaNeteriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "158822.clusters.info.v11.5.txt",
		        "cluster_tree_path": "158822.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "158822.clusters.proteins.v11.5.txt",
		        "sequence_path": "158822.protein.sequences.v11.5.fa",
		        "enrichment_path": "158822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158822.protein.info.v11.5.txt",
		        "node_list_path": "158822.cluster.nodes.v11.5.txt",
		        "edge_list_path": "158822.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AfipiaSp6413(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. 64-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaSp6413", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895701.protein.info.v11.5.txt",
		        "node_list_path": "1895701.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifoxya1Full4011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYA1_FULL_40_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxya1Full4011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802631.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802631.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802631.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802631.protein.info.v11.5.txt",
		        "node_list_path": "1802631.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802631.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpBv3p1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. BV3P1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpBv3p1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111130.protein.info.v11.5.txt",
		        "node_list_path": "1111130.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaAldovaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia aldovae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaAldovaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "527002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "527002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "527002.clusters.proteins.v11.5.txt",
		        "sequence_path": "527002.protein.sequences.v11.5.fa",
		        "enrichment_path": "527002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "527002.protein.info.v11.5.txt",
		        "node_list_path": "527002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "527002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumRbg136414Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_13_64_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg136414Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797271.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797271.protein.info.v11.5.txt",
		        "node_list_path": "1797271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioSpNor37(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. NOR37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioSpNor37", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798168.protein.info.v11.5.txt",
		        "node_list_path": "1798168.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioAzureus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio azureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioAzureus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219077.protein.info.v11.5.txt",
		        "node_list_path": "1219077.protein.complete.v11.5.txt"
		    }
		]
    )()

def KwoniellaBestiolaeCbs10118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella bestiolae CBS 10118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KwoniellaBestiolaeCbs10118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1296100.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1296100.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1296100.clusters.proteins.v11.5.txt",
		        "sequence_path": "1296100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296100.protein.info.v11.5.txt",
		        "node_list_path": "1296100.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1296100.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubrobacterXylanophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubrobacter xylanophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrobacterXylanophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266117.clusters.proteins.v11.5.txt",
		        "sequence_path": "266117.protein.sequences.v11.5.fa",
		        "enrichment_path": "266117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266117.protein.info.v11.5.txt",
		        "node_list_path": "266117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumLp2aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium LP2A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumLp2aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "478741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "478741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "478741.clusters.proteins.v11.5.txt",
		        "sequence_path": "478741.protein.sequences.v11.5.fa",
		        "enrichment_path": "478741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "478741.protein.info.v11.5.txt",
		        "node_list_path": "478741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "478741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizoctoniaSolaniAg1IaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizoctonia solani AG-1 IA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizoctoniaSolaniAg1IaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983506.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983506.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983506.clusters.proteins.v11.5.txt",
		        "sequence_path": "983506.protein.sequences.v11.5.fa",
		        "enrichment_path": "983506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983506.protein.info.v11.5.txt",
		        "node_list_path": "983506.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983506.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NannizziaGypseaCbs118893(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nannizzia gypsea CBS 118893 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NannizziaGypseaCbs118893", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "535722.protein.sequences.v11.5.fa",
		        "enrichment_path": "535722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "535722.protein.info.v11.5.txt",
		        "node_list_path": "535722.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRoot166Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root166 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRoot166Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736478.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736478.protein.info.v11.5.txt",
		        "node_list_path": "1736478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfocurvusVexinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfocurvus vexinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfocurvusVexinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121406.protein.info.v11.5.txt",
		        "node_list_path": "1121406.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumMongolienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium mongoliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumMongolienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437603.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437603.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437603.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437603.protein.info.v11.5.txt",
		        "node_list_path": "1437603.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437603.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaPneumophilaSubspPasculleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila subsp. pascullei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaPneumophilaSubspPasculleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "91890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "91890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "91890.clusters.proteins.v11.5.txt",
		        "sequence_path": "91890.protein.sequences.v11.5.fa",
		        "enrichment_path": "91890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91890.protein.info.v11.5.txt",
		        "node_list_path": "91890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "91890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2034155.protein.sequences.v11.5.fa",
		        "enrichment_path": "2034155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2034155.protein.info.v11.5.txt",
		        "node_list_path": "2034155.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfolunaSpongiiphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfoluna spongiiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfolunaSpongiiphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "419481.protein.sequences.v11.5.fa",
		        "enrichment_path": "419481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419481.protein.info.v11.5.txt",
		        "node_list_path": "419481.protein.complete.v11.5.txt"
		    }
		]
    )()

def DuganellaSpCf402(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. CF402 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpCf402", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855289.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855289.protein.info.v11.5.txt",
		        "node_list_path": "1855289.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentzeaAlbidocapillataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentzea albidocapillata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentzeaAlbidocapillataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40571.clusters.proteins.v11.5.txt",
		        "sequence_path": "40571.protein.sequences.v11.5.fa",
		        "enrichment_path": "40571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40571.protein.info.v11.5.txt",
		        "node_list_path": "40571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NadsoniaFulvescensVarElongataDsm6958(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nadsonia fulvescens var. elongata DSM 6958 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NadsoniaFulvescensVarElongataDsm6958", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "857566.protein.sequences.v11.5.fa",
		        "enrichment_path": "857566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857566.protein.info.v11.5.txt",
		        "node_list_path": "857566.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf24914(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_49_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf24914", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797354.protein.info.v11.5.txt",
		        "node_list_path": "1797354.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusThorarchaeotaArchaeonSmtz145Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thorarchaeota archaeon SMTZ1-45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThorarchaeotaArchaeonSmtz145Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1706444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1706444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1706444.clusters.proteins.v11.5.txt",
		        "sequence_path": "1706444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1706444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1706444.protein.info.v11.5.txt",
		        "node_list_path": "1706444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1706444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ReichenbachiellaAgariperforans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Reichenbachiella agariperforans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ReichenbachiellaAgariperforans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "156994.protein.sequences.v11.5.fa",
		        "enrichment_path": "156994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156994.protein.info.v11.5.txt",
		        "node_list_path": "156994.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpJha19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. JHA19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpJha19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577588.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577588.protein.info.v11.5.txt",
		        "node_list_path": "1577588.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegamonasHypermegale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megamonas hypermegale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegamonasHypermegale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122216.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122216.protein.info.v11.5.txt",
		        "node_list_path": "1122216.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShimiaHaliotis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shimia haliotis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShimiaHaliotis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280847.protein.info.v11.5.txt",
		        "node_list_path": "1280847.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full5114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_51_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full5114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798683.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798683.protein.info.v11.5.txt",
		        "node_list_path": "1798683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ScytonemaHofmanniiPcc7110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scytonema hofmannii PCC 7110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScytonemaHofmanniiPcc7110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "128403.clusters.info.v11.5.txt",
		        "cluster_tree_path": "128403.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "128403.clusters.proteins.v11.5.txt",
		        "sequence_path": "128403.protein.sequences.v11.5.fa",
		        "enrichment_path": "128403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "128403.protein.info.v11.5.txt",
		        "node_list_path": "128403.cluster.nodes.v11.5.txt",
		        "edge_list_path": "128403.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusDidelphisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus didelphis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDidelphisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123301.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123301.protein.info.v11.5.txt",
		        "node_list_path": "1123301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudocercosporaEumusaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudocercospora eumusae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudocercosporaEumusaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "321146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "321146.clusters.proteins.v11.5.txt",
		        "sequence_path": "321146.protein.sequences.v11.5.fa",
		        "enrichment_path": "321146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321146.protein.info.v11.5.txt",
		        "node_list_path": "321146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "321146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChristensenellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Christensenella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChristensenellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805714.protein.info.v11.5.txt",
		        "node_list_path": "1805714.protein.complete.v11.5.txt"
		    }
		]
    )()

def MacrostomumLignano(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Macrostomum lignano graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacrostomumLignano", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "282301.protein.sequences.v11.5.fa",
		        "enrichment_path": "282301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "282301.protein.info.v11.5.txt",
		        "node_list_path": "282301.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalohastaLitchfieldiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halohasta litchfieldiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalohastaLitchfieldiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1073996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073996.protein.info.v11.5.txt",
		        "node_list_path": "1073996.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumScgcAaa076P13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA076-P13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumScgcAaa076P13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1007119.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1007119.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1007119.clusters.proteins.v11.5.txt",
		        "sequence_path": "1007119.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007119.protein.info.v11.5.txt",
		        "node_list_path": "1007119.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1007119.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RutstroemiaSpNjr2017aWrk4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rutstroemia sp. NJR-2017a WRK4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RutstroemiaSpNjr2017aWrk4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2070412.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2070412.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2070412.clusters.proteins.v11.5.txt",
		        "sequence_path": "2070412.protein.sequences.v11.5.fa",
		        "enrichment_path": "2070412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2070412.protein.info.v11.5.txt",
		        "node_list_path": "2070412.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2070412.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusTigurinusAz3aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus tigurinus AZ3a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusTigurinusAz3aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1282664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1282664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1282664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1282664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282664.protein.info.v11.5.txt",
		        "node_list_path": "1282664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1282664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OgataeaParapolymorphaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ogataea parapolymorpha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OgataeaParapolymorphaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005962.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005962.protein.info.v11.5.txt",
		        "node_list_path": "1005962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumParafortuitumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium parafortuitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumParafortuitumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39692.clusters.proteins.v11.5.txt",
		        "sequence_path": "39692.protein.sequences.v11.5.fa",
		        "enrichment_path": "39692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39692.protein.info.v11.5.txt",
		        "node_list_path": "39692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPseudoalcaligenesAd6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes AD6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPseudoalcaligenesAd6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1453503.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1453503.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1453503.clusters.proteins.v11.5.txt",
		        "sequence_path": "1453503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453503.protein.info.v11.5.txt",
		        "node_list_path": "1453503.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1453503.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_35_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801748.protein.info.v11.5.txt",
		        "node_list_path": "1801748.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumNodulansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium nodulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumNodulansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "460265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "460265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "460265.clusters.proteins.v11.5.txt",
		        "sequence_path": "460265.protein.sequences.v11.5.fa",
		        "enrichment_path": "460265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "460265.protein.info.v11.5.txt",
		        "node_list_path": "460265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "460265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumDtu014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumDtu014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671636.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671636.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671636.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671636.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671636.protein.info.v11.5.txt",
		        "node_list_path": "1671636.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671636.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacaBermudensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibaca bermudensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacaBermudensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314265.clusters.proteins.v11.5.txt",
		        "sequence_path": "314265.protein.sequences.v11.5.fa",
		        "enrichment_path": "314265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314265.protein.info.v11.5.txt",
		        "node_list_path": "314265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfohalobiumRetbaense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfohalobium retbaense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfohalobiumRetbaense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "485915.protein.sequences.v11.5.fa",
		        "enrichment_path": "485915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485915.protein.info.v11.5.txt",
		        "node_list_path": "485915.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagnetobacteriumCasensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magnetobacterium casensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagnetobacteriumCasensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1455061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1455061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1455061.clusters.proteins.v11.5.txt",
		        "sequence_path": "1455061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1455061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1455061.protein.info.v11.5.txt",
		        "node_list_path": "1455061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1455061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicaulisSpHtcc2633(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. HTCC2633 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicaulisSpHtcc2633", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314254.protein.sequences.v11.5.fa",
		        "enrichment_path": "314254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314254.protein.info.v11.5.txt",
		        "node_list_path": "314254.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusNigerCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus niger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusNigerCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5061.clusters.proteins.v11.5.txt",
		        "sequence_path": "5061.protein.sequences.v11.5.fa",
		        "enrichment_path": "5061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5061.protein.info.v11.5.txt",
		        "node_list_path": "5061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerotruncusColihominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerotruncus colihominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotruncusColihominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445972.clusters.proteins.v11.5.txt",
		        "sequence_path": "445972.protein.sequences.v11.5.fa",
		        "enrichment_path": "445972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445972.protein.info.v11.5.txt",
		        "node_list_path": "445972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusDelbrueckiiBulgaricus2038(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii bulgaricus 2038 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusDelbrueckiiBulgaricus2038", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "353496.protein.sequences.v11.5.fa",
		        "enrichment_path": "353496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "353496.protein.info.v11.5.txt",
		        "node_list_path": "353496.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterHeilmanniiAsb14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter heilmannii ASB1.4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterHeilmanniiAsb14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216962.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216962.protein.info.v11.5.txt",
		        "node_list_path": "1216962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusGuaymasensisDsm11113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus guaymasensis DSM 11113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusGuaymasensisDsm11113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1432656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1432656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1432656.clusters.proteins.v11.5.txt",
		        "sequence_path": "1432656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432656.protein.info.v11.5.txt",
		        "node_list_path": "1432656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1432656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesScabrisporusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces scabrisporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesScabrisporusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123320.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123320.protein.info.v11.5.txt",
		        "node_list_path": "1123320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasBivalviumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas bivalvium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasBivalviumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "440079.clusters.info.v11.5.txt",
		        "cluster_tree_path": "440079.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "440079.clusters.proteins.v11.5.txt",
		        "sequence_path": "440079.protein.sequences.v11.5.fa",
		        "enrichment_path": "440079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "440079.protein.info.v11.5.txt",
		        "node_list_path": "440079.cluster.nodes.v11.5.txt",
		        "edge_list_path": "440079.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAlaskensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio alaskensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAlaskensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "207559.clusters.info.v11.5.txt",
		        "cluster_tree_path": "207559.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "207559.clusters.proteins.v11.5.txt",
		        "sequence_path": "207559.protein.sequences.v11.5.fa",
		        "enrichment_path": "207559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "207559.protein.info.v11.5.txt",
		        "node_list_path": "207559.cluster.nodes.v11.5.txt",
		        "edge_list_path": "207559.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumCg1024134Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium CG1_02_41_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumCg1024134Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805239.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805239.protein.info.v11.5.txt",
		        "node_list_path": "1805239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumCaliforniensisDsm19288Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum californiensis DSM 19288 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumCaliforniensisDsm19288Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227465.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227465.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227465.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227465.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227465.protein.info.v11.5.txt",
		        "node_list_path": "1227465.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227465.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph809(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH809 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph809", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217713.protein.info.v11.5.txt",
		        "node_list_path": "1217713.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusBorealisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus borealis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusBorealisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "160799.clusters.info.v11.5.txt",
		        "cluster_tree_path": "160799.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "160799.clusters.proteins.v11.5.txt",
		        "sequence_path": "160799.protein.sequences.v11.5.fa",
		        "enrichment_path": "160799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "160799.protein.info.v11.5.txt",
		        "node_list_path": "160799.cluster.nodes.v11.5.txt",
		        "edge_list_path": "160799.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpongiibacterMarinusDsm19753(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spongiibacter marinus DSM 19753 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpongiibacterMarinusDsm19753", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122224.protein.info.v11.5.txt",
		        "node_list_path": "1122224.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division ZIXI Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379698.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379698.protein.info.v11.5.txt",
		        "node_list_path": "1379698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumParaenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium paraense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumParaenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "767916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "767916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "767916.clusters.proteins.v11.5.txt",
		        "sequence_path": "767916.protein.sequences.v11.5.fa",
		        "enrichment_path": "767916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767916.protein.info.v11.5.txt",
		        "node_list_path": "767916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "767916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAlligatorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma alligatoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAlligatorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "747682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "747682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "747682.clusters.proteins.v11.5.txt",
		        "sequence_path": "747682.protein.sequences.v11.5.fa",
		        "enrichment_path": "747682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747682.protein.info.v11.5.txt",
		        "node_list_path": "747682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "747682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcoidesMethylutensMm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanococcoides methylutens MM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcoidesMethylutensMm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434104.protein.info.v11.5.txt",
		        "node_list_path": "1434104.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumMedicae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium medicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumMedicae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "366394.protein.sequences.v11.5.fa",
		        "enrichment_path": "366394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366394.protein.info.v11.5.txt",
		        "node_list_path": "366394.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusClausii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus clausii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusClausii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66692.protein.sequences.v11.5.fa",
		        "enrichment_path": "66692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66692.protein.info.v11.5.txt",
		        "node_list_path": "66692.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidaminococcusTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidaminococcus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminococcusTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871002.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871002.protein.info.v11.5.txt",
		        "node_list_path": "1871002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRbg164113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_41_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802484.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802484.protein.info.v11.5.txt",
		        "node_list_path": "1802484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WenyingzhuangiaFucanilytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wenyingzhuangia fucanilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WenyingzhuangiaFucanilytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1790137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1790137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1790137.protein.info.v11.5.txt",
		        "node_list_path": "1790137.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusHalodurans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus halodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHalodurans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272558.protein.sequences.v11.5.fa",
		        "enrichment_path": "272558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272558.protein.info.v11.5.txt",
		        "node_list_path": "272558.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSchekmanbacteriaBacteriumRifcsplowo212Full3815Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Schekmanbacteria bacterium RIFCSPLOWO2_12_FULL_38_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSchekmanbacteriaBacteriumRifcsplowo212Full3815Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817883.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817883.protein.info.v11.5.txt",
		        "node_list_path": "1817883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetakosakoniaMassiliensisJc163(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metakosakonia massiliensis JC163 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetakosakoniaMassiliensisJc163", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095768.protein.info.v11.5.txt",
		        "node_list_path": "1095768.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat29937Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-29937 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat29937Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720553.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720553.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720553.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720553.protein.info.v11.5.txt",
		        "node_list_path": "1720553.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720553.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSpRoot436Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. Root436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpRoot436Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736537.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736537.protein.info.v11.5.txt",
		        "node_list_path": "1736537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpSlbn35(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. SLBN-35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpSlbn35", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "512030.protein.sequences.v11.5.fa",
		        "enrichment_path": "512030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512030.protein.info.v11.5.txt",
		        "node_list_path": "512030.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTerrybacteriaBacteriumRifcsplowo2024220(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPLOWO2_02_42_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsplowo2024220", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802370.protein.info.v11.5.txt",
		        "node_list_path": "1802370.protein.complete.v11.5.txt"
		    }
		]
    )()

def AdhaeribacterAquaticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Adhaeribacter aquaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AdhaeribacterAquaticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926549.clusters.proteins.v11.5.txt",
		        "sequence_path": "926549.protein.sequences.v11.5.fa",
		        "enrichment_path": "926549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926549.protein.info.v11.5.txt",
		        "node_list_path": "926549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolineaTardivitalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptolinea tardivitalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolineaTardivitalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "229920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "229920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "229920.clusters.proteins.v11.5.txt",
		        "sequence_path": "229920.protein.sequences.v11.5.fa",
		        "enrichment_path": "229920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229920.protein.info.v11.5.txt",
		        "node_list_path": "229920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "229920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf23810Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_38_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf23810Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619084.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619084.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619084.protein.info.v11.5.txt",
		        "node_list_path": "1619084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacterialesBacteriumUtchb2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteriales bacterium UTCHB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacterialesBacteriumUtchb2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1961105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961105.protein.info.v11.5.txt",
		        "node_list_path": "1961105.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaSpT9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichinella sp. T9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaSpT9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "181606.protein.sequences.v11.5.fa",
		        "enrichment_path": "181606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "181606.protein.info.v11.5.txt",
		        "node_list_path": "181606.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaePvTagetis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae pv. tagetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaePvTagetis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "129140.protein.sequences.v11.5.fa",
		        "enrichment_path": "129140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "129140.protein.info.v11.5.txt",
		        "node_list_path": "129140.protein.complete.v11.5.txt"
		    }
		]
    )()

def RubrobacterAplysinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubrobacter aplysinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrobacterAplysinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "909625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "909625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "909625.clusters.proteins.v11.5.txt",
		        "sequence_path": "909625.protein.sequences.v11.5.fa",
		        "enrichment_path": "909625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "909625.protein.info.v11.5.txt",
		        "node_list_path": "909625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "909625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpZor0019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. ZOR0019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpZor0019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1339233.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1339233.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1339233.clusters.proteins.v11.5.txt",
		        "sequence_path": "1339233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1339233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1339233.protein.info.v11.5.txt",
		        "node_list_path": "1339233.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1339233.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo212Full6423Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_12_FULL_64_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212Full6423Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797499.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797499.protein.info.v11.5.txt",
		        "node_list_path": "1797499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacillusGenomosp3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus genomosp. 3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusGenomosp3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1921421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921421.protein.info.v11.5.txt",
		        "node_list_path": "1921421.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu087Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU087 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu087Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1676158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1676158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1676158.clusters.proteins.v11.5.txt",
		        "sequence_path": "1676158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676158.protein.info.v11.5.txt",
		        "node_list_path": "1676158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1676158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudochrobactrumSpB5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudochrobactrum sp. B5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudochrobactrumSpB5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1289478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1289478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1289478.protein.info.v11.5.txt",
		        "node_list_path": "1289478.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpPamc26628Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. PAMC 26628 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpPamc26628Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1484118.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1484118.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1484118.clusters.proteins.v11.5.txt",
		        "sequence_path": "1484118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484118.protein.info.v11.5.txt",
		        "node_list_path": "1484118.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1484118.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolirubrumPuertoriconensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solirubrum puertoriconensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolirubrumPuertoriconensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1751427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1751427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1751427.protein.info.v11.5.txt",
		        "node_list_path": "1751427.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSpZym1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. ZYM-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSpZym1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1681184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1681184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1681184.protein.info.v11.5.txt",
		        "node_list_path": "1681184.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGr1643Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium GR16-43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGr1643Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1904640.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1904640.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1904640.clusters.proteins.v11.5.txt",
		        "sequence_path": "1904640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904640.protein.info.v11.5.txt",
		        "node_list_path": "1904640.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1904640.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinisporaPacificaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinispora pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisporaPacificaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1136417.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1136417.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1136417.clusters.proteins.v11.5.txt",
		        "sequence_path": "1136417.protein.sequences.v11.5.fa",
		        "enrichment_path": "1136417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1136417.protein.info.v11.5.txt",
		        "node_list_path": "1136417.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1136417.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusHirae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus hirae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusHirae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "768486.protein.sequences.v11.5.fa",
		        "enrichment_path": "768486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768486.protein.info.v11.5.txt",
		        "node_list_path": "768486.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaCenocepaciaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia cenocepacia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaCenocepaciaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216591.clusters.proteins.v11.5.txt",
		        "sequence_path": "216591.protein.sequences.v11.5.fa",
		        "enrichment_path": "216591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216591.protein.info.v11.5.txt",
		        "node_list_path": "216591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasCedrina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas cedrina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCedrina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "651740.protein.sequences.v11.5.fa",
		        "enrichment_path": "651740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "651740.protein.info.v11.5.txt",
		        "node_list_path": "651740.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpL21syrabCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. L21SyrAB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpL21syrabCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1307759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1307759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1307759.clusters.proteins.v11.5.txt",
		        "sequence_path": "1307759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307759.protein.info.v11.5.txt",
		        "node_list_path": "1307759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1307759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PicrophilusTorridus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Picrophilus torridus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PicrophilusTorridus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "263820.protein.sequences.v11.5.fa",
		        "enrichment_path": "263820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263820.protein.info.v11.5.txt",
		        "node_list_path": "263820.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpMrMd2014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MR_MD2014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpMrMd2014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1561023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1561023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1561023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1561023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561023.protein.info.v11.5.txt",
		        "node_list_path": "1561023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1561023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaAlsatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella alsatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaAlsatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094551.protein.info.v11.5.txt",
		        "node_list_path": "1094551.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumGw2011Gwe24535Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_45_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24535Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618993.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618993.protein.info.v11.5.txt",
		        "node_list_path": "1618993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpBc26Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. BC26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpBc26Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881032.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881032.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881032.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881032.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881032.protein.info.v11.5.txt",
		        "node_list_path": "1881032.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881032.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionisporaSp2237(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionispora sp. 2/2-37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionisporaSp2237", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1677858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1677858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1677858.protein.info.v11.5.txt",
		        "node_list_path": "1677858.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxCaeniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxCaeniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "343013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "343013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "343013.clusters.proteins.v11.5.txt",
		        "sequence_path": "343013.protein.sequences.v11.5.fa",
		        "enrichment_path": "343013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "343013.protein.info.v11.5.txt",
		        "node_list_path": "343013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "343013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaGlebae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia glebae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaGlebae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777143.protein.info.v11.5.txt",
		        "node_list_path": "1777143.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacillusEquuliSubspEquuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus equuli subsp. equuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusEquuliSubspEquuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "202947.protein.sequences.v11.5.fa",
		        "enrichment_path": "202947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202947.protein.info.v11.5.txt",
		        "node_list_path": "202947.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpUnc305mfcol52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. UNC305MFCol52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpUnc305mfcol52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449076.protein.info.v11.5.txt",
		        "node_list_path": "1449076.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterSpR4368(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter sp. R4368 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterSpR4368", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1166130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166130.protein.info.v11.5.txt",
		        "node_list_path": "1166130.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesBacteriumOlb22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates bacterium OLB22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesBacteriumOlb22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617428.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617428.protein.info.v11.5.txt",
		        "node_list_path": "1617428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumOlb11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumOlb11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617422.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617422.protein.info.v11.5.txt",
		        "node_list_path": "1617422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SebaldellaTermitidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sebaldella termitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SebaldellaTermitidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "526218.protein.sequences.v11.5.fa",
		        "enrichment_path": "526218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526218.protein.info.v11.5.txt",
		        "node_list_path": "526218.protein.complete.v11.5.txt"
		    }
		]
    )()

def MusPahari(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mus pahari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusPahari", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10093.protein.sequences.v11.5.fa",
		        "enrichment_path": "10093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10093.protein.info.v11.5.txt",
		        "node_list_path": "10093.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeF0167Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae F0167 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeF0167Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575593.clusters.proteins.v11.5.txt",
		        "sequence_path": "575593.protein.sequences.v11.5.fa",
		        "enrichment_path": "575593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575593.protein.info.v11.5.txt",
		        "node_list_path": "575593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSpLc5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. LC5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpLc5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502724.protein.info.v11.5.txt",
		        "node_list_path": "1502724.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumGw2011Gwb24212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_42_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618386.protein.info.v11.5.txt",
		        "node_list_path": "1618386.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusArsenophonusTriatominarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arsenophonus triatominarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusArsenophonusTriatominarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "57911.protein.sequences.v11.5.fa",
		        "enrichment_path": "57911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "57911.protein.info.v11.5.txt",
		        "node_list_path": "57911.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp12747610Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1274761.0 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp12747610Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834077.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834077.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834077.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834077.protein.info.v11.5.txt",
		        "node_list_path": "1834077.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834077.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSpSg55(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. SG55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSpSg55", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500270.protein.info.v11.5.txt",
		        "node_list_path": "1500270.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumRifcsplowo212Full4010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPLOWO2_12_FULL_40_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsplowo212Full4010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817745.protein.info.v11.5.txt",
		        "node_list_path": "1817745.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumFallaxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium fallax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumFallaxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1533.clusters.proteins.v11.5.txt",
		        "sequence_path": "1533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1533.protein.info.v11.5.txt",
		        "node_list_path": "1533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaLaidlawii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma laidlawii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaLaidlawii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "441768.protein.sequences.v11.5.fa",
		        "enrichment_path": "441768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441768.protein.info.v11.5.txt",
		        "node_list_path": "441768.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusConcavusDsm17758(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus concavus DSM 17758 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusConcavusDsm17758", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423735.protein.info.v11.5.txt",
		        "node_list_path": "1423735.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpCip562Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP56.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpCip562Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144672.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144672.protein.info.v11.5.txt",
		        "node_list_path": "1144672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMutansGs5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mutans GS5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMutansGs5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1198676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198676.protein.info.v11.5.txt",
		        "node_list_path": "1198676.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterAlpinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter alpinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterAlpinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "656366.clusters.info.v11.5.txt",
		        "cluster_tree_path": "656366.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "656366.clusters.proteins.v11.5.txt",
		        "sequence_path": "656366.protein.sequences.v11.5.fa",
		        "enrichment_path": "656366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656366.protein.info.v11.5.txt",
		        "node_list_path": "656366.cluster.nodes.v11.5.txt",
		        "edge_list_path": "656366.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalolaminaPelagicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halolamina pelagica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolaminaPelagicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "699431.clusters.info.v11.5.txt",
		        "cluster_tree_path": "699431.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "699431.clusters.proteins.v11.5.txt",
		        "sequence_path": "699431.protein.sequences.v11.5.fa",
		        "enrichment_path": "699431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "699431.protein.info.v11.5.txt",
		        "node_list_path": "699431.cluster.nodes.v11.5.txt",
		        "edge_list_path": "699431.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumWg36(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium WG36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumWg36", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229485.protein.sequences.v11.0.fa",
		        "enrichment_path": "1229485.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1229485.protein.info.v11.0.txt",
		        "node_list_path": "1229485.protein.complete.v11.0.txt"
		    }
		]
    )()

def KiloniellaLitopenaeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kiloniella litopenaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KiloniellaLitopenaeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1549748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1549748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1549748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1549748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1549748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1549748.protein.info.v11.5.txt",
		        "node_list_path": "1549748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1549748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslr7277(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR7277 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslr7277", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227352.protein.info.v11.5.txt",
		        "node_list_path": "1227352.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumJdfr78Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr78Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935108.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935108.protein.info.v11.5.txt",
		        "node_list_path": "1935108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaMaltosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida maltosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaMaltosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5479.clusters.proteins.v11.5.txt",
		        "sequence_path": "5479.protein.sequences.v11.5.fa",
		        "enrichment_path": "5479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5479.protein.info.v11.5.txt",
		        "node_list_path": "5479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusChisholmbacteriaBacteriumRifcsplowo201Full5028Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPLOWO2_01_FULL_50_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsplowo201Full5028Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797594.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797594.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797594.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797594.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797594.protein.info.v11.5.txt",
		        "node_list_path": "1797594.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797594.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellalesBacteriumRifcsphigho212Full3714Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionellales bacterium RIFCSPHIGHO2_12_FULL_37_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellalesBacteriumRifcsphigho212Full3714Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798568.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798568.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798568.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798568.protein.info.v11.5.txt",
		        "node_list_path": "1798568.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798568.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusDextrinicusDsm20335(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus dextrinicus DSM 20335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusDextrinicusDsm20335", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423738.protein.info.v11.5.txt",
		        "node_list_path": "1423738.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBeckwithbacteriaBacteriumRbg13429Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium RBG_13_42_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumRbg13429Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797457.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797457.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797457.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797457.protein.info.v11.5.txt",
		        "node_list_path": "1797457.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797457.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermotogaSp2812bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga sp. 2812B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaSp2812bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157948.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157948.protein.info.v11.5.txt",
		        "node_list_path": "1157948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CladophialophoraYegresiiCbs114405(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora yegresii CBS 114405 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CladophialophoraYegresiiCbs114405", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1182544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182544.protein.info.v11.5.txt",
		        "node_list_path": "1182544.protein.complete.v11.5.txt"
		    }
		]
    )()

def EctothiorhodospiraMobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ectothiorhodospira mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctothiorhodospiraMobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "195064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "195064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "195064.clusters.proteins.v11.5.txt",
		        "sequence_path": "195064.protein.sequences.v11.5.fa",
		        "enrichment_path": "195064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195064.protein.info.v11.5.txt",
		        "node_list_path": "195064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "195064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterQingfengensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter qingfengensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterQingfengensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262585.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262585.protein.info.v11.5.txt",
		        "node_list_path": "1262585.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumIriomotenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium iriomotense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumIriomotenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1536641.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1536641.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1536641.clusters.proteins.v11.5.txt",
		        "sequence_path": "1536641.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536641.protein.info.v11.5.txt",
		        "node_list_path": "1536641.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1536641.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprinopsisCinereaOkayama7130(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprinopsis cinerea okayama7#130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprinopsisCinereaOkayama7130", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "240176.protein.sequences.v11.5.fa",
		        "enrichment_path": "240176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240176.protein.info.v11.5.txt",
		        "node_list_path": "240176.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaSpCetp13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema sp. CETP13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSpCetp13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1908540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1908540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1908540.clusters.proteins.v11.5.txt",
		        "sequence_path": "1908540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908540.protein.info.v11.5.txt",
		        "node_list_path": "1908540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1908540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaedimonasVaricaedensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caedimonas varicaedens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaedimonasVaricaedensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629334.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629334.protein.info.v11.5.txt",
		        "node_list_path": "1629334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnoanaerobaculumSpObrc55(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum sp. OBRC5-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoanaerobaculumSpObrc55", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936595.protein.sequences.v11.5.fa",
		        "enrichment_path": "936595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936595.protein.info.v11.5.txt",
		        "node_list_path": "936595.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKomeilibacteriaBacteriumRifcsplowo201Full5215Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_01_FULL_52_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo201Full5215Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798551.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798551.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798551.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798551.protein.info.v11.5.txt",
		        "node_list_path": "1798551.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798551.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaPickettii12jCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia pickettii 12J Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaPickettii12jCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "402626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "402626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "402626.clusters.proteins.v11.5.txt",
		        "sequence_path": "402626.protein.sequences.v11.5.fa",
		        "enrichment_path": "402626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402626.protein.info.v11.5.txt",
		        "node_list_path": "402626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "402626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpCcgeLa001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. CCGE-LA001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpCcgeLa001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223566.protein.info.v11.5.txt",
		        "node_list_path": "1223566.protein.complete.v11.5.txt"
		    }
		]
    )()

def JonesiaDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jonesia denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JonesiaDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471856.clusters.proteins.v11.5.txt",
		        "sequence_path": "471856.protein.sequences.v11.5.fa",
		        "enrichment_path": "471856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471856.protein.info.v11.5.txt",
		        "node_list_path": "471856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsplowo212Full4630(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPLOWO2_12_FULL_46_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212Full4630", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801867.protein.info.v11.5.txt",
		        "node_list_path": "1801867.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeliponaQuadrifasciata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Melipona quadrifasciata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeliponaQuadrifasciata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "166423.protein.sequences.v11.5.fa",
		        "enrichment_path": "166423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "166423.protein.info.v11.5.txt",
		        "node_list_path": "166423.protein.complete.v11.5.txt"
		    }
		]
    )()

def MacacaFascicularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Macaca fascicularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacacaFascicularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9541.protein.sequences.v11.5.fa",
		        "enrichment_path": "9541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9541.protein.info.v11.5.txt",
		        "node_list_path": "9541.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusOshimaiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus oshimai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusOshimaiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "751945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "751945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "751945.clusters.proteins.v11.5.txt",
		        "sequence_path": "751945.protein.sequences.v11.5.fa",
		        "enrichment_path": "751945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "751945.protein.info.v11.5.txt",
		        "node_list_path": "751945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "751945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachyspiraHyodysenteriaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira hyodysenteriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraHyodysenteriaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "565034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "565034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "565034.clusters.proteins.v11.5.txt",
		        "sequence_path": "565034.protein.sequences.v11.5.fa",
		        "enrichment_path": "565034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565034.protein.info.v11.5.txt",
		        "node_list_path": "565034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "565034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslr70331Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70331 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslr70331Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1536773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1536773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1536773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1536773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536773.protein.info.v11.5.txt",
		        "node_list_path": "1536773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1536773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PediococcusPentosaceusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus pentosaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusPentosaceusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "278197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "278197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "278197.clusters.proteins.v11.5.txt",
		        "sequence_path": "278197.protein.sequences.v11.5.fa",
		        "enrichment_path": "278197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278197.protein.info.v11.5.txt",
		        "node_list_path": "278197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "278197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumLitorale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium litorale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumLitorale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "758802.protein.sequences.v11.5.fa",
		        "enrichment_path": "758802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758802.protein.info.v11.5.txt",
		        "node_list_path": "758802.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusSpKgw1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus sp. KGW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusSpKgw1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1793726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1793726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1793726.protein.info.v11.5.txt",
		        "node_list_path": "1793726.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumGw2011Gwa1418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011_GWA1_41_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011Gwa1418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619103.protein.info.v11.5.txt",
		        "node_list_path": "1619103.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasMoraviensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas moraviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMoraviensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1395516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1395516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1395516.clusters.proteins.v11.5.txt",
		        "sequence_path": "1395516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1395516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1395516.protein.info.v11.5.txt",
		        "node_list_path": "1395516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1395516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColeofasciculusChthonoplastes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coleofasciculus chthonoplastes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColeofasciculusChthonoplastes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118168.protein.sequences.v11.5.fa",
		        "enrichment_path": "118168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118168.protein.info.v11.5.txt",
		        "node_list_path": "118168.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacillusGlycogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacillus glycogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacillusGlycogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236959.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236959.protein.info.v11.5.txt",
		        "node_list_path": "1236959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumCg10247685Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_47_685 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg10247685Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805282.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805282.protein.info.v11.5.txt",
		        "node_list_path": "1805282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HadesarchaeaArchaeonYnp45(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hadesarchaea archaeon YNP_45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HadesarchaeaArchaeonYnp45", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776334.protein.info.v11.5.txt",
		        "node_list_path": "1776334.protein.complete.v11.5.txt"
		    }
		]
    )()

def MortierellaElongataAg77Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mortierella elongata AG-77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MortierellaElongataAg77Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314771.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314771.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314771.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314771.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314771.protein.info.v11.5.txt",
		        "node_list_path": "1314771.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314771.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifoxyc2Full398Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYC2_FULL_39_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyc2Full398Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798702.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798702.protein.info.v11.5.txt",
		        "node_list_path": "1798702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterMedellinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter medellinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterMedellinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634177.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634177.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634177.clusters.proteins.v11.5.txt",
		        "sequence_path": "634177.protein.sequences.v11.5.fa",
		        "enrichment_path": "634177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634177.protein.info.v11.5.txt",
		        "node_list_path": "634177.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634177.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTa06Bacterium32111(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TA06 bacterium 32_111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTa06Bacterium32111", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635278.protein.info.v11.5.txt",
		        "node_list_path": "1635278.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerticilliumAlfalfaeVams102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verticillium alfalfae VaMs.102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerticilliumAlfalfaeVams102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "526221.protein.sequences.v11.5.fa",
		        "enrichment_path": "526221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526221.protein.info.v11.5.txt",
		        "node_list_path": "526221.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusOrisF0423Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oris F0423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOrisF0423Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "944562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "944562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "944562.clusters.proteins.v11.5.txt",
		        "sequence_path": "944562.protein.sequences.v11.5.fa",
		        "enrichment_path": "944562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944562.protein.info.v11.5.txt",
		        "node_list_path": "944562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "944562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitromicrobiumSpJl477(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citromicrobium sp. JL477 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitromicrobiumSpJl477", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1634516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1634516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1634516.protein.info.v11.5.txt",
		        "node_list_path": "1634516.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeosynechococcusSphagnicolaSy1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neosynechococcus sphagnicola sy1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeosynechococcusSphagnicolaSy1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1497020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1497020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1497020.protein.info.v11.5.txt",
		        "node_list_path": "1497020.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcaromycesIngoldiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acaromyces ingoldii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcaromycesIngoldiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "215250.clusters.info.v11.5.txt",
		        "cluster_tree_path": "215250.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "215250.clusters.proteins.v11.5.txt",
		        "sequence_path": "215250.protein.sequences.v11.5.fa",
		        "enrichment_path": "215250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215250.protein.info.v11.5.txt",
		        "node_list_path": "215250.cluster.nodes.v11.5.txt",
		        "edge_list_path": "215250.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalisaetaLongaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salisaeta longa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalisaetaLongaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089550.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089550.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089550.protein.info.v11.5.txt",
		        "node_list_path": "1089550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpScn6821(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. SCN 68-21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpScn6821", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660154.protein.info.v11.5.txt",
		        "node_list_path": "1660154.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumCg23050142(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium CG2_30_50_142 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumCg23050142", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803498.protein.info.v11.5.txt",
		        "node_list_path": "1803498.protein.complete.v11.5.txt"
		    }
		]
    )()

def LechevalieriaFradiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lechevalieria fradiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LechevalieriaFradiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "200378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "200378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "200378.clusters.proteins.v11.5.txt",
		        "sequence_path": "200378.protein.sequences.v11.5.fa",
		        "enrichment_path": "200378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200378.protein.info.v11.5.txt",
		        "node_list_path": "200378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "200378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PapilioMachaonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Papilio machaon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PapilioMachaonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "76193.clusters.info.v11.5.txt",
		        "cluster_tree_path": "76193.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "76193.clusters.proteins.v11.5.txt",
		        "sequence_path": "76193.protein.sequences.v11.5.fa",
		        "enrichment_path": "76193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76193.protein.info.v11.5.txt",
		        "node_list_path": "76193.cluster.nodes.v11.5.txt",
		        "edge_list_path": "76193.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFf4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FF4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFf4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1347369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1347369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1347369.clusters.proteins.v11.5.txt",
		        "sequence_path": "1347369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347369.protein.info.v11.5.txt",
		        "node_list_path": "1347369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1347369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg164923(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_49_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg164923", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797840.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797840.protein.info.v11.5.txt",
		        "node_list_path": "1797840.protein.complete.v11.5.txt"
		    }
		]
    )()

def MalusDomesticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Malus domestica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalusDomesticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3750.clusters.proteins.v11.5.txt",
		        "sequence_path": "3750.protein.sequences.v11.5.fa",
		        "enrichment_path": "3750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3750.protein.info.v11.5.txt",
		        "node_list_path": "3750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp2714Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 27_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp2714Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896979.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896979.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896979.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896979.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896979.protein.info.v11.5.txt",
		        "node_list_path": "1896979.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896979.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GramellaSalexigens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gramella salexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaSalexigens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1913577.protein.sequences.v11.5.fa",
		        "enrichment_path": "1913577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1913577.protein.info.v11.5.txt",
		        "node_list_path": "1913577.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusCapraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus caprae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusCapraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525378.clusters.proteins.v11.5.txt",
		        "sequence_path": "525378.protein.sequences.v11.5.fa",
		        "enrichment_path": "525378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525378.protein.info.v11.5.txt",
		        "node_list_path": "525378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHtcc2150Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HTCC2150 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHtcc2150Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "388401.clusters.info.v11.5.txt",
		        "cluster_tree_path": "388401.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "388401.clusters.proteins.v11.5.txt",
		        "sequence_path": "388401.protein.sequences.v11.5.fa",
		        "enrichment_path": "388401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388401.protein.info.v11.5.txt",
		        "node_list_path": "388401.cluster.nodes.v11.5.txt",
		        "edge_list_path": "388401.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpUnc378mf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. UNC378MF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpUnc378mf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502748.protein.info.v11.5.txt",
		        "node_list_path": "1502748.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlB1140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL B-1140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlB1140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415549.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415549.protein.info.v11.5.txt",
		        "node_list_path": "1415549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhascolarctobacteriumSpCag207(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phascolarctobacterium sp. CAG207 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhascolarctobacteriumSpCag207", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262914.protein.info.v11.5.txt",
		        "node_list_path": "1262914.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5517Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_55_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5517Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798496.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798496.protein.info.v11.5.txt",
		        "node_list_path": "1798496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CloacibacteriumNormanense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cloacibacterium normanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CloacibacteriumNormanense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "237258.protein.sequences.v11.5.fa",
		        "enrichment_path": "237258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237258.protein.info.v11.5.txt",
		        "node_list_path": "237258.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizophagusClarusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus clarus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizophagusClarusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "94130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "94130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "94130.clusters.proteins.v11.5.txt",
		        "sequence_path": "94130.protein.sequences.v11.5.fa",
		        "enrichment_path": "94130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94130.protein.info.v11.5.txt",
		        "node_list_path": "94130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "94130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumMangroviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium mangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumMangroviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348253.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348253.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348253.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348253.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348253.protein.info.v11.5.txt",
		        "node_list_path": "1348253.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348253.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AerococcusViridans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus viridans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusViridans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1377.protein.info.v11.5.txt",
		        "node_list_path": "1377.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterMillerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter millerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterMillerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "230361.protein.sequences.v11.5.fa",
		        "enrichment_path": "230361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "230361.protein.info.v11.5.txt",
		        "node_list_path": "230361.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasMohniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mohnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMohniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "395600.clusters.info.v11.5.txt",
		        "cluster_tree_path": "395600.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "395600.clusters.proteins.v11.5.txt",
		        "sequence_path": "395600.protein.sequences.v11.5.fa",
		        "enrichment_path": "395600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395600.protein.info.v11.5.txt",
		        "node_list_path": "395600.cluster.nodes.v11.5.txt",
		        "edge_list_path": "395600.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyceliophthoraThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myceliophthora thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyceliophthoraThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "78579.protein.sequences.v11.5.fa",
		        "enrichment_path": "78579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78579.protein.info.v11.5.txt",
		        "node_list_path": "78579.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzoarcusSpKh32c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azoarcus sp. KH32C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzoarcusSpKh32c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "748247.protein.sequences.v11.5.fa",
		        "enrichment_path": "748247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748247.protein.info.v11.5.txt",
		        "node_list_path": "748247.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusSpDsm45219Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus sp. DSM 45219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusSpDsm45219Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881103.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881103.protein.info.v11.5.txt",
		        "node_list_path": "1881103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterSpLpb0137(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. LPB0137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSpLpb0137", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1850254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850254.protein.info.v11.5.txt",
		        "node_list_path": "1850254.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaceaeBacteriumKa00182Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonellaceae bacterium KA00182 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaceaeBacteriumKa00182Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1588748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1588748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1588748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1588748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588748.protein.info.v11.5.txt",
		        "node_list_path": "1588748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1588748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DinothrombiumTinctorium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dinothrombium tinctorium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DinothrombiumTinctorium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1965070.protein.sequences.v11.5.fa",
		        "enrichment_path": "1965070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1965070.protein.info.v11.5.txt",
		        "node_list_path": "1965070.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHydrogenedentesBacteriumCg1024214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrogenedentes bacterium CG1_02_42_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHydrogenedentesBacteriumCg1024214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805216.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805216.protein.info.v11.5.txt",
		        "node_list_path": "1805216.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg166432(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_64_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg166432", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797658.protein.info.v11.5.txt",
		        "node_list_path": "1797658.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFryxellicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium fryxellicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFryxellicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "249352.protein.sequences.v11.5.fa",
		        "enrichment_path": "249352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "249352.protein.info.v11.5.txt",
		        "node_list_path": "249352.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumVirideCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium viride Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumVirideCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121344.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121344.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121344.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121344.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121344.protein.info.v11.5.txt",
		        "node_list_path": "1121344.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121344.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JeotgalibacillusAlimentariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalibacillus alimentarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalibacillusAlimentariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "135826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "135826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "135826.clusters.proteins.v11.5.txt",
		        "sequence_path": "135826.protein.sequences.v11.5.fa",
		        "enrichment_path": "135826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "135826.protein.info.v11.5.txt",
		        "node_list_path": "135826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "135826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusRiograndensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus riograndensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusRiograndensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "483937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "483937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "483937.clusters.proteins.v11.5.txt",
		        "sequence_path": "483937.protein.sequences.v11.5.fa",
		        "enrichment_path": "483937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483937.protein.info.v11.5.txt",
		        "node_list_path": "483937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "483937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpRoot630Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. Root630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpRoot630Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736574.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736574.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736574.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736574.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736574.protein.info.v11.5.txt",
		        "node_list_path": "1736574.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736574.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumMobile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium mobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumMobile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449342.protein.info.v11.5.txt",
		        "node_list_path": "1449342.protein.complete.v11.5.txt"
		    }
		]
    )()

def SutterellaWadsworthensis2159bfaa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis 2159BFAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SutterellaWadsworthensis2159bfaa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742823.protein.sequences.v11.5.fa",
		        "enrichment_path": "742823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742823.protein.info.v11.5.txt",
		        "node_list_path": "742823.protein.complete.v11.5.txt"
		    }
		]
    )()

def PogonaVitticepsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pogona vitticeps Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PogonaVitticepsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "103695.clusters.info.v11.5.txt",
		        "cluster_tree_path": "103695.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "103695.clusters.proteins.v11.5.txt",
		        "sequence_path": "103695.protein.sequences.v11.5.fa",
		        "enrichment_path": "103695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103695.protein.info.v11.5.txt",
		        "node_list_path": "103695.cluster.nodes.v11.5.txt",
		        "edge_list_path": "103695.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCamelliaeDsm22697Jcm13995(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus camelliae DSM 22697 JCM 13995 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCamelliaeDsm22697Jcm13995", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423730.protein.info.v11.5.txt",
		        "node_list_path": "1423730.protein.complete.v11.5.txt"
		    }
		]
    )()

def SiccationiduransArizonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Siccationidurans arizonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SiccationiduransArizonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227077.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227077.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227077.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227077.protein.info.v11.5.txt",
		        "node_list_path": "1227077.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227077.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSpCag514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpCag514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262696.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262696.protein.info.v11.5.txt",
		        "node_list_path": "1262696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EquusAsinusAsinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Equus asinus asinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EquusAsinusAsinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83772.clusters.proteins.v11.5.txt",
		        "sequence_path": "83772.protein.sequences.v11.5.fa",
		        "enrichment_path": "83772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83772.protein.info.v11.5.txt",
		        "node_list_path": "83772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasElongata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas elongata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasElongata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "768066.protein.sequences.v11.5.fa",
		        "enrichment_path": "768066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768066.protein.info.v11.5.txt",
		        "node_list_path": "768066.protein.complete.v11.5.txt"
		    }
		]
    )()

def SenegalimassiliaAnaerobia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Senegalimassilia anaerobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SenegalimassiliaAnaerobia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1034345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034345.protein.info.v11.5.txt",
		        "node_list_path": "1034345.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumBdw918(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium BDW918 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumBdw918", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1168065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168065.protein.info.v11.5.txt",
		        "node_list_path": "1168065.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "260554.protein.sequences.v11.5.fa",
		        "enrichment_path": "260554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "260554.protein.info.v11.5.txt",
		        "node_list_path": "260554.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumCaspAlpha2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium casp-alpha2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumCaspAlpha2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1655503.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1655503.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1655503.clusters.proteins.v11.5.txt",
		        "sequence_path": "1655503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655503.protein.info.v11.5.txt",
		        "node_list_path": "1655503.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1655503.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PediococcusPentosaceus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus pentosaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusPentosaceus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "278197.protein.sequences.v11.5.fa",
		        "enrichment_path": "278197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278197.protein.info.v11.5.txt",
		        "node_list_path": "278197.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsplowo212Full5124(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPLOWO2_12_FULL_51_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212Full5124", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801869.protein.info.v11.5.txt",
		        "node_list_path": "1801869.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumVerticillioides7600Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium verticillioides 7600 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumVerticillioides7600Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "334819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "334819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "334819.clusters.proteins.v11.5.txt",
		        "sequence_path": "334819.protein.sequences.v11.5.fa",
		        "enrichment_path": "334819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334819.protein.info.v11.5.txt",
		        "node_list_path": "334819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "334819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumRifoxya2Full3321(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYA2_FULL_33_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxya2Full3321", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801902.protein.info.v11.5.txt",
		        "node_list_path": "1801902.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterLutiphocaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter lutiphocae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterLutiphocaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123033.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123033.protein.info.v11.5.txt",
		        "node_list_path": "1123033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaThiooxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea thiooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaThiooxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445709.protein.sequences.v11.5.fa",
		        "enrichment_path": "445709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445709.protein.info.v11.5.txt",
		        "node_list_path": "445709.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaSp1andimar09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella sp. 1ANDIMAR09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaSp1andimar09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1700845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1700845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1700845.protein.info.v11.5.txt",
		        "node_list_path": "1700845.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaAviumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia avium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaAviumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229831.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229831.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229831.protein.info.v11.5.txt",
		        "node_list_path": "1229831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermobacillusComposti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermobacillus composti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobacillusComposti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717605.protein.sequences.v11.5.fa",
		        "enrichment_path": "717605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717605.protein.info.v11.5.txt",
		        "node_list_path": "717605.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaTrachomatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia trachomatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaTrachomatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "813.clusters.proteins.v11.5.txt",
		        "sequence_path": "813.protein.sequences.v11.5.fa",
		        "enrichment_path": "813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "813.protein.info.v11.5.txt",
		        "node_list_path": "813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumNoncentrifugens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium noncentrifugens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumNoncentrifugens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1128970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128970.protein.info.v11.5.txt",
		        "node_list_path": "1128970.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaPorciDsm25326Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella porci DSM 25326 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaPorciDsm25326Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573983.clusters.proteins.v11.5.txt",
		        "sequence_path": "573983.protein.sequences.v11.5.fa",
		        "enrichment_path": "573983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573983.protein.info.v11.5.txt",
		        "node_list_path": "573983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccoglossusKowalevskiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccoglossus kowalevskii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccoglossusKowalevskiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10224.clusters.proteins.v11.5.txt",
		        "sequence_path": "10224.protein.sequences.v11.5.fa",
		        "enrichment_path": "10224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10224.protein.info.v11.5.txt",
		        "node_list_path": "10224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BotrytisCinereaT4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Botrytis cinerea T4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotrytisCinereaT4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999810.protein.sequences.v11.5.fa",
		        "enrichment_path": "999810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999810.protein.info.v11.5.txt",
		        "node_list_path": "999810.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanomethylicusOleusabulumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomethylicus oleusabulum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanomethylicusOleusabulumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1867260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1867260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1867260.clusters.proteins.v11.5.txt",
		        "sequence_path": "1867260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1867260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1867260.protein.info.v11.5.txt",
		        "node_list_path": "1867260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1867260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChamaesiphonMinutusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chamaesiphon minutus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChamaesiphonMinutusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173020.protein.info.v11.5.txt",
		        "node_list_path": "1173020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AedesAlbopictusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aedes albopictus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AedesAlbopictusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7160.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7160.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7160.clusters.proteins.v11.5.txt",
		        "sequence_path": "7160.protein.sequences.v11.5.fa",
		        "enrichment_path": "7160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7160.protein.info.v11.5.txt",
		        "node_list_path": "7160.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7160.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CutibacteriumAcnesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cutibacterium acnes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CutibacteriumAcnesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1747.clusters.proteins.v11.5.txt",
		        "sequence_path": "1747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1747.protein.info.v11.5.txt",
		        "node_list_path": "1747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PunicaGranatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Punica granatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PunicaGranatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "22663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "22663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "22663.clusters.proteins.v11.5.txt",
		        "sequence_path": "22663.protein.sequences.v11.5.fa",
		        "enrichment_path": "22663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "22663.protein.info.v11.5.txt",
		        "node_list_path": "22663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "22663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollimonasPratensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collimonas pratensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollimonasPratensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "279113.protein.sequences.v11.5.fa",
		        "enrichment_path": "279113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279113.protein.info.v11.5.txt",
		        "node_list_path": "279113.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpBp7605Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. Bp7605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpBp7605Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1740163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1740163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1740163.clusters.proteins.v11.5.txt",
		        "sequence_path": "1740163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1740163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1740163.protein.info.v11.5.txt",
		        "node_list_path": "1740163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1740163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusSpBica19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. BICA1-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusSpBica19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1531958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1531958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1531958.protein.info.v11.5.txt",
		        "node_list_path": "1531958.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferAggregansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer aggregans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferAggregansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1769779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1769779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1769779.clusters.proteins.v11.5.txt",
		        "sequence_path": "1769779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1769779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1769779.protein.info.v11.5.txt",
		        "node_list_path": "1769779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1769779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSpR2019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. R2019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpR2019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1270196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1270196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1270196.protein.info.v11.5.txt",
		        "node_list_path": "1270196.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegamonasRupellensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megamonas rupellensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegamonasRupellensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122217.protein.info.v11.5.txt",
		        "node_list_path": "1122217.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelodiscusSinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelodiscus sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelodiscusSinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13735.protein.sequences.v11.5.fa",
		        "enrichment_path": "13735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13735.protein.info.v11.5.txt",
		        "node_list_path": "13735.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpSoil522(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil522 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpSoil522", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736388.protein.info.v11.5.txt",
		        "node_list_path": "1736388.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumProfundum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium profundum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumProfundum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1714300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714300.protein.info.v11.5.txt",
		        "node_list_path": "1714300.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumRbg135114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_13_51_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumRbg135114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802193.protein.info.v11.5.txt",
		        "node_list_path": "1802193.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyclobacteriaceaeBacteriumAk24Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacteriaceae bacterium AK24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyclobacteriaceaeBacteriumAk24Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288963.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288963.protein.info.v11.5.txt",
		        "node_list_path": "1288963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpPml113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. PML113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpPml113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1899350.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1899350.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1899350.clusters.proteins.v11.5.txt",
		        "sequence_path": "1899350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1899350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1899350.protein.info.v11.5.txt",
		        "node_list_path": "1899350.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1899350.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSpBa94Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. BA-94 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSpBa94Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1454005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1454005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1454005.clusters.proteins.v11.5.txt",
		        "sequence_path": "1454005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454005.protein.info.v11.5.txt",
		        "node_list_path": "1454005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1454005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifoxyd2Full3512(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYD2_FULL_35_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyd2Full3512", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801812.protein.info.v11.5.txt",
		        "node_list_path": "1801812.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBifidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBifidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1681.clusters.proteins.v11.5.txt",
		        "sequence_path": "1681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1681.protein.info.v11.5.txt",
		        "node_list_path": "1681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGlobisporusC1027Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces globisporus C-1027 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGlobisporusC1027Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1172567.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1172567.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1172567.clusters.proteins.v11.5.txt",
		        "sequence_path": "1172567.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172567.protein.info.v11.5.txt",
		        "node_list_path": "1172567.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1172567.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PediococcusAcidilacticiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus acidilactici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusAcidilacticiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1254.clusters.proteins.v11.5.txt",
		        "sequence_path": "1254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1254.protein.info.v11.5.txt",
		        "node_list_path": "1254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwb16080(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWB1_60_80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwb16080", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802177.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802177.protein.info.v11.5.txt",
		        "node_list_path": "1802177.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSpMarseilleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. Marseille Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSpMarseilleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "375286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "375286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "375286.clusters.proteins.v11.5.txt",
		        "sequence_path": "375286.protein.sequences.v11.5.fa",
		        "enrichment_path": "375286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375286.protein.info.v11.5.txt",
		        "node_list_path": "375286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "375286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807755.protein.info.v11.5.txt",
		        "node_list_path": "1807755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VirgibacillusSalinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus salinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusSalinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553311.protein.sequences.v11.5.fa",
		        "enrichment_path": "553311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553311.protein.info.v11.5.txt",
		        "node_list_path": "553311.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpJa33abCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. JA33Ab Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpJa33abCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "321327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "321327.clusters.proteins.v11.5.txt",
		        "sequence_path": "321327.protein.sequences.v11.5.fa",
		        "enrichment_path": "321327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321327.protein.info.v11.5.txt",
		        "node_list_path": "321327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "321327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriellaXinjiangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriella xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriellaXinjiangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "684065.protein.sequences.v11.5.fa",
		        "enrichment_path": "684065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "684065.protein.info.v11.5.txt",
		        "node_list_path": "684065.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumSg824Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium SG8_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumSg824Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703768.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703768.protein.info.v11.5.txt",
		        "node_list_path": "1703768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot482(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root482 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot482", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736543.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736543.protein.info.v11.5.txt",
		        "node_list_path": "1736543.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBacteroidesPeriocalifornicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus [Bacteroides] periocalifornicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBacteroidesPeriocalifornicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1702214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1702214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1702214.clusters.proteins.v11.5.txt",
		        "sequence_path": "1702214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1702214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1702214.protein.info.v11.5.txt",
		        "node_list_path": "1702214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1702214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PisolithusMicrocarpus441(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pisolithus microcarpus 441 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PisolithusMicrocarpus441", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765257.protein.sequences.v11.5.fa",
		        "enrichment_path": "765257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765257.protein.info.v11.5.txt",
		        "node_list_path": "765257.protein.complete.v11.5.txt"
		    }
		]
    )()

def NesterenkoniaSpPf2b19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. PF2B19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesterenkoniaSpPf2b19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881858.protein.info.v11.5.txt",
		        "node_list_path": "1881858.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpMb2005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MB2005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpMb2005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280678.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280678.protein.info.v11.5.txt",
		        "node_list_path": "1280678.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFrigoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium frigoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFrigoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1086011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1086011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1086011.protein.info.v11.5.txt",
		        "node_list_path": "1086011.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerosporobacterMobilisDsm15930(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerosporobacter mobilis DSM 15930 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerosporobacterMobilisDsm15930", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120996.protein.info.v11.5.txt",
		        "node_list_path": "1120996.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClavibacterMichiganensisNcppb382Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis NCPPB382 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavibacterMichiganensisNcppb382Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "443906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "443906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "443906.clusters.proteins.v11.5.txt",
		        "sequence_path": "443906.protein.sequences.v11.5.fa",
		        "enrichment_path": "443906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443906.protein.info.v11.5.txt",
		        "node_list_path": "443906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "443906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAcidophilusNcfm(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus NCFM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAcidophilusNcfm", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272621.protein.sequences.v11.5.fa",
		        "enrichment_path": "272621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272621.protein.info.v11.5.txt",
		        "node_list_path": "272621.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAquimarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus aquimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAquimarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "189382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "189382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "189382.clusters.proteins.v11.5.txt",
		        "sequence_path": "189382.protein.sequences.v11.5.fa",
		        "enrichment_path": "189382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189382.protein.info.v11.5.txt",
		        "node_list_path": "189382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "189382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpVcb2006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. VCB2006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpVcb2006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280679.protein.info.v11.5.txt",
		        "node_list_path": "1280679.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynchytriumMicrobalum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synchytrium microbalum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynchytriumMicrobalum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1806994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806994.protein.info.v11.5.txt",
		        "node_list_path": "1806994.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumSb2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium SB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumSb2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1689867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1689867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1689867.clusters.proteins.v11.5.txt",
		        "sequence_path": "1689867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1689867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1689867.protein.info.v11.5.txt",
		        "node_list_path": "1689867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1689867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YamadazymaTenuisAtcc10573Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yamadazyma tenuis ATCC 10573 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YamadazymaTenuisAtcc10573Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "590646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "590646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "590646.clusters.proteins.v11.5.txt",
		        "sequence_path": "590646.protein.sequences.v11.5.fa",
		        "enrichment_path": "590646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "590646.protein.info.v11.5.txt",
		        "node_list_path": "590646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "590646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NectriaHaematococca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nectria haematococca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NectriaHaematococca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "140110.protein.sequences.v11.5.fa",
		        "enrichment_path": "140110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "140110.protein.info.v11.5.txt",
		        "node_list_path": "140110.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaclostridiumBifermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraclostridium bifermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaclostridiumBifermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1490.protein.info.v11.5.txt",
		        "node_list_path": "1490.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanibacterMelonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janibacter melonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterMelonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "262209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "262209.clusters.proteins.v11.5.txt",
		        "sequence_path": "262209.protein.sequences.v11.5.fa",
		        "enrichment_path": "262209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262209.protein.info.v11.5.txt",
		        "node_list_path": "262209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "262209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpBolea5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. BoleA5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpBolea5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157637.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157637.protein.info.v11.5.txt",
		        "node_list_path": "1157637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusObesiensisPh10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus obesiensis ph10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusObesiensisPh10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118056.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118056.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118056.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118056.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118056.protein.info.v11.5.txt",
		        "node_list_path": "1118056.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118056.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumM181Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium M181 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumM181Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235792.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235792.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235792.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235792.protein.info.v11.5.txt",
		        "node_list_path": "1235792.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235792.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeurosporaCrassa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neurospora crassa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeurosporaCrassa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5141.protein.sequences.v11.5.fa",
		        "enrichment_path": "5141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5141.protein.info.v11.5.txt",
		        "node_list_path": "5141.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArenibacterAlgicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arenibacter algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenibacterAlgicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "616991.protein.sequences.v11.5.fa",
		        "enrichment_path": "616991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "616991.protein.info.v11.5.txt",
		        "node_list_path": "616991.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusLitoralisDsm5473(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus litoralis DSM 5473 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusLitoralisDsm5473", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "523849.protein.sequences.v11.5.fa",
		        "enrichment_path": "523849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523849.protein.info.v11.5.txt",
		        "node_list_path": "523849.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalipaludibacillusAgaradhaerensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salipaludibacillus agaradhaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalipaludibacillusAgaradhaerensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "76935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "76935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "76935.clusters.proteins.v11.5.txt",
		        "sequence_path": "76935.protein.sequences.v11.5.fa",
		        "enrichment_path": "76935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76935.protein.info.v11.5.txt",
		        "node_list_path": "76935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "76935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinokineosporaSpEg49(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora sp. EG49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinokineosporaSpEg49", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "909613.protein.sequences.v11.5.fa",
		        "enrichment_path": "909613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "909613.protein.info.v11.5.txt",
		        "node_list_path": "909613.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgreiaPratensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agreia pratensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgreiaPratensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "150121.protein.sequences.v11.5.fa",
		        "enrichment_path": "150121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150121.protein.info.v11.5.txt",
		        "node_list_path": "150121.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasJatrophaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas jatrophae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasJatrophaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1166337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1166337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1166337.clusters.proteins.v11.5.txt",
		        "sequence_path": "1166337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166337.protein.info.v11.5.txt",
		        "node_list_path": "1166337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1166337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KazachstaniaNaganishiiCbs8797(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania naganishii CBS 8797 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KazachstaniaNaganishiiCbs8797", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071383.protein.info.v11.5.txt",
		        "node_list_path": "1071383.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionKazanBacteriumRbg13509(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RBG_13_50_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionKazanBacteriumRbg13509", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798535.protein.info.v11.5.txt",
		        "node_list_path": "1798535.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwa2407b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA2_40_7b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa2407b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618563.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618563.protein.info.v11.5.txt",
		        "node_list_path": "1618563.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkanindigesIllinoisensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkanindiges illinoisensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkanindigesIllinoisensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120977.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120977.protein.info.v11.5.txt",
		        "node_list_path": "1120977.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprinopsisCinereaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprinopsis cinerea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprinopsisCinereaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5346.clusters.proteins.v11.5.txt",
		        "sequence_path": "5346.protein.sequences.v11.5.fa",
		        "enrichment_path": "5346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5346.protein.info.v11.5.txt",
		        "node_list_path": "5346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaMagna(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella magna graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaMagna", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123489.protein.info.v11.5.txt",
		        "node_list_path": "1123489.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumU91i(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium U9-1i graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumU91i", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1605283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1605283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1605283.protein.info.v11.5.txt",
		        "node_list_path": "1605283.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumGwf1327Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium GWF1_32_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumGwf1327Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798014.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798014.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798014.protein.info.v11.5.txt",
		        "node_list_path": "1798014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobiBacteriumOlb7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobi bacterium OLB7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiBacteriumOlb7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619898.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619898.protein.info.v11.5.txt",
		        "node_list_path": "1619898.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarmoricolaScoriae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marmoricola scoriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarmoricolaScoriae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "642780.protein.sequences.v11.5.fa",
		        "enrichment_path": "642780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "642780.protein.info.v11.5.txt",
		        "node_list_path": "642780.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumImmobileAtcc35973(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium immobile (ATCC 35973) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumImmobileAtcc35973", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "31967.protein.sequences.v11.5.fa",
		        "enrichment_path": "31967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31967.protein.info.v11.5.txt",
		        "node_list_path": "31967.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag138(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:138 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag138", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262775.protein.info.v11.5.txt",
		        "node_list_path": "1262775.protein.complete.v11.5.txt"
		    }
		]
    )()

def RomboutsiaTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Romboutsia timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RomboutsiaTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776391.protein.info.v11.5.txt",
		        "node_list_path": "1776391.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchwartziaSuccinivoransDsm10502(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schwartzia succinivorans DSM 10502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchwartziaSuccinivoransDsm10502", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123243.protein.info.v11.5.txt",
		        "node_list_path": "1123243.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpYr477Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR477 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpYr477Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500295.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500295.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500295.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500295.protein.info.v11.5.txt",
		        "node_list_path": "1500295.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500295.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAlni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces alni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAlni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "380248.protein.sequences.v11.5.fa",
		        "enrichment_path": "380248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380248.protein.info.v11.5.txt",
		        "node_list_path": "380248.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiK12Mg1655(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 MG1655 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiK12Mg1655", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "511145.protein.sequences.v11.0.fa",
		        "enrichment_path": "511145.protein.enrichment.terms.v11.0.txt",
		        "info_path": "511145.protein.info.v11.0.txt",
		        "node_list_path": "511145.protein.complete.v11.0.txt"
		    }
		]
    )()

def SalimicrobiumFlavidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salimicrobium flavidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalimicrobiumFlavidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "570947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "570947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "570947.clusters.proteins.v11.5.txt",
		        "sequence_path": "570947.protein.sequences.v11.5.fa",
		        "enrichment_path": "570947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570947.protein.info.v11.5.txt",
		        "node_list_path": "570947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "570947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurihydrogenibiumSpYo3aop1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium sp. YO3AOP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurihydrogenibiumSpYo3aop1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "436114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "436114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "436114.clusters.proteins.v11.5.txt",
		        "sequence_path": "436114.protein.sequences.v11.5.fa",
		        "enrichment_path": "436114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436114.protein.info.v11.5.txt",
		        "node_list_path": "436114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "436114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpRoot1471Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root1471 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpRoot1471Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736469.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736469.protein.info.v11.5.txt",
		        "node_list_path": "1736469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DomibacillusMangrovi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus mangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusMangrovi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1714354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714354.protein.info.v11.5.txt",
		        "node_list_path": "1714354.protein.complete.v11.5.txt"
		    }
		]
    )()

def PatulibacterAmericanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Patulibacter americanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PatulibacterAmericanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122939.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122939.protein.info.v11.5.txt",
		        "node_list_path": "1122939.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumPyruvativorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium pyruvativorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumPyruvativorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "155865.protein.sequences.v11.5.fa",
		        "enrichment_path": "155865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "155865.protein.info.v11.5.txt",
		        "node_list_path": "155865.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumCg1025453Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium CG1_02_54_53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumCg1025453Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805323.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805323.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805323.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805323.protein.info.v11.5.txt",
		        "node_list_path": "1805323.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805323.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptococcusDepauperatusCbs7841Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus depauperatus CBS 7841 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptococcusDepauperatusCbs7841Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1295531.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1295531.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1295531.clusters.proteins.v11.5.txt",
		        "sequence_path": "1295531.protein.sequences.v11.5.fa",
		        "enrichment_path": "1295531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1295531.protein.info.v11.5.txt",
		        "node_list_path": "1295531.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1295531.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAbyssalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces abyssalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAbyssalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "933944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "933944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "933944.clusters.proteins.v11.5.txt",
		        "sequence_path": "933944.protein.sequences.v11.5.fa",
		        "enrichment_path": "933944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933944.protein.info.v11.5.txt",
		        "node_list_path": "933944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "933944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphacelomaMurrayae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphaceloma murrayae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphacelomaMurrayae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2082308.protein.sequences.v11.5.fa",
		        "enrichment_path": "2082308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2082308.protein.info.v11.5.txt",
		        "node_list_path": "2082308.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaAmblyommatisStrGat30vCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia amblyommatis str. GAT-30V Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaAmblyommatisStrGat30vCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1105111.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1105111.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1105111.clusters.proteins.v11.5.txt",
		        "sequence_path": "1105111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1105111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1105111.protein.info.v11.5.txt",
		        "node_list_path": "1105111.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1105111.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesVarsoviensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces varsoviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesVarsoviensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67373.clusters.proteins.v11.5.txt",
		        "sequence_path": "67373.protein.sequences.v11.5.fa",
		        "enrichment_path": "67373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67373.protein.info.v11.5.txt",
		        "node_list_path": "67373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaAsteroidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia asteroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAsteroidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1110697.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1110697.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1110697.clusters.proteins.v11.5.txt",
		        "sequence_path": "1110697.protein.sequences.v11.5.fa",
		        "enrichment_path": "1110697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1110697.protein.info.v11.5.txt",
		        "node_list_path": "1110697.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1110697.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AuriculariaDelicataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Auricularia delicata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AuriculariaDelicataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "160860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "160860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "160860.clusters.proteins.v11.5.txt",
		        "sequence_path": "160860.protein.sequences.v11.5.fa",
		        "enrichment_path": "160860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "160860.protein.info.v11.5.txt",
		        "node_list_path": "160860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "160860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcusVannielii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus vannielii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusVannielii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "406327.protein.sequences.v11.5.fa",
		        "enrichment_path": "406327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406327.protein.info.v11.5.txt",
		        "node_list_path": "406327.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuberMagnatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tuber magnatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuberMagnatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42249.protein.sequences.v11.5.fa",
		        "enrichment_path": "42249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42249.protein.info.v11.5.txt",
		        "node_list_path": "42249.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpD20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. D20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpD20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585543.protein.sequences.v11.5.fa",
		        "enrichment_path": "585543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585543.protein.info.v11.5.txt",
		        "node_list_path": "585543.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpSm22m07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. SM22M-07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpSm22m07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520813.protein.info.v11.5.txt",
		        "node_list_path": "1520813.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureimonasJatrophae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas jatrophae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasJatrophae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1166073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166073.protein.info.v11.5.txt",
		        "node_list_path": "1166073.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwc2459(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWC2_45_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwc2459", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618589.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618589.protein.info.v11.5.txt",
		        "node_list_path": "1618589.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCaseinilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus caseinilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCaseinilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1503961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1503961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1503961.protein.info.v11.5.txt",
		        "node_list_path": "1503961.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "347256.protein.sequences.v11.5.fa",
		        "enrichment_path": "347256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "347256.protein.info.v11.5.txt",
		        "node_list_path": "347256.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSuwonensis111(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis 111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSuwonensis111", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743721.protein.sequences.v11.5.fa",
		        "enrichment_path": "743721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743721.protein.info.v11.5.txt",
		        "node_list_path": "743721.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsphigho202Full4711(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_47_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full4711", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802270.protein.info.v11.5.txt",
		        "node_list_path": "1802270.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrialbaHulunbeirensisJcm10989(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrialba hulunbeirensis JCM 10989 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaHulunbeirensisJcm10989", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227493.protein.info.v11.5.txt",
		        "node_list_path": "1227493.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSelenatarsenatisSf1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus selenatarsenatis SF-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSelenatarsenatisSf1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321606.protein.info.v11.5.txt",
		        "node_list_path": "1321606.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumScgcAaa536N21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA536-N21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumScgcAaa536N21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1009711.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1009711.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1009711.clusters.proteins.v11.5.txt",
		        "sequence_path": "1009711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009711.protein.info.v11.5.txt",
		        "node_list_path": "1009711.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1009711.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KluyveraAscorbata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kluyvera ascorbata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KluyveraAscorbata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1006000.protein.sequences.v11.5.fa",
		        "enrichment_path": "1006000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1006000.protein.info.v11.5.txt",
		        "node_list_path": "1006000.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusSclerotiicarbonariusCbs121057(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sclerotiicarbonarius CBS 121057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusSclerotiicarbonariusCbs121057", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1448318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448318.protein.info.v11.5.txt",
		        "node_list_path": "1448318.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSubtilisSubspNatto(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. natto graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSubtilisSubspNatto", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86029.protein.sequences.v11.5.fa",
		        "enrichment_path": "86029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86029.protein.info.v11.5.txt",
		        "node_list_path": "86029.protein.complete.v11.5.txt"
		    }
		]
    )()

def RappaportIsraeli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rappaport israeli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RappaportIsraeli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1839807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1839807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1839807.protein.info.v11.5.txt",
		        "node_list_path": "1839807.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastococcusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211815.protein.info.v11.5.txt",
		        "node_list_path": "1211815.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmphilophusCitrinellus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amphilophus citrinellus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphilophusCitrinellus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61819.protein.sequences.v11.5.fa",
		        "enrichment_path": "61819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61819.protein.info.v11.5.txt",
		        "node_list_path": "61819.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylibiumSpCf468Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylibium sp. CF468 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylibiumSpCf468Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500262.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500262.protein.info.v11.5.txt",
		        "node_list_path": "1500262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarssoninaBrunneaFSpMultigermtubiMbM1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marssonina brunnea f. sp. multigermtubi MB_m1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarssoninaBrunneaFSpMultigermtubiMbM1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1072389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1072389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1072389.protein.info.v11.5.txt",
		        "node_list_path": "1072389.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAkibaiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus akibai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAkibaiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236973.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236973.protein.info.v11.5.txt",
		        "node_list_path": "1236973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAlkalitelluris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus alkalitelluris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAlkalitelluris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "304268.protein.sequences.v11.5.fa",
		        "enrichment_path": "304268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "304268.protein.info.v11.5.txt",
		        "node_list_path": "304268.protein.complete.v11.5.txt"
		    }
		]
    )()

def SodalisLikeEndosymbiontOfProechinophthirusFluctus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sodalis-like endosymbiont of Proechinophthirus fluctus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SodalisLikeEndosymbiontOfProechinophthirusFluctus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1462730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462730.protein.info.v11.5.txt",
		        "node_list_path": "1462730.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho201Full4012(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_40_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full4012", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801737.protein.info.v11.5.txt",
		        "node_list_path": "1801737.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumOxysporumFSpCubenseRace4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. cubense race 4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumOxysporumFSpCubenseRace4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229665.protein.info.v11.5.txt",
		        "node_list_path": "1229665.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterMediterraneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter mediterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterMediterraneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83219.protein.sequences.v11.5.fa",
		        "enrichment_path": "83219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83219.protein.info.v11.5.txt",
		        "node_list_path": "83219.protein.complete.v11.5.txt"
		    }
		]
    )()

def CulturomicaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Culturomica massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CulturomicaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841857.protein.info.v11.5.txt",
		        "node_list_path": "1841857.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitratireductorPacificusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitratireductor pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratireductorPacificusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391937.clusters.proteins.v11.5.txt",
		        "sequence_path": "391937.protein.sequences.v11.5.fa",
		        "enrichment_path": "391937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391937.protein.info.v11.5.txt",
		        "node_list_path": "391937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlumeriaGraminisFSpHordeiDh14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blumeria graminis f. sp. hordei DH14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlumeriaGraminisFSpHordeiDh14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546991.clusters.proteins.v11.5.txt",
		        "sequence_path": "546991.protein.sequences.v11.5.fa",
		        "enrichment_path": "546991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546991.protein.info.v11.5.txt",
		        "node_list_path": "546991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerfeziaBoudieriAtccMya4762Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terfezia boudieri ATCC MYA-4762 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerfeziaBoudieriAtccMya4762Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1051890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1051890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1051890.clusters.proteins.v11.5.txt",
		        "sequence_path": "1051890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051890.protein.info.v11.5.txt",
		        "node_list_path": "1051890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1051890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeeuwenhoekiellaMarinoflavaDsm3653Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella marinoflava DSM 3653 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeeuwenhoekiellaMarinoflavaDsm3653Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122159.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122159.protein.info.v11.5.txt",
		        "node_list_path": "1122159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWs6BacteriumOlb21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium OLB21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWs6BacteriumOlb21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617427.protein.info.v11.5.txt",
		        "node_list_path": "1617427.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudovibrioStylochiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio stylochi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioStylochiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807766.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807766.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807766.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807766.protein.info.v11.5.txt",
		        "node_list_path": "1807766.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807766.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag382(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:382 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag382", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262957.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262957.protein.info.v11.5.txt",
		        "node_list_path": "1262957.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpKordi100(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpKordi100", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280380.protein.info.v11.5.txt",
		        "node_list_path": "1280380.protein.complete.v11.5.txt"
		    }
		]
    )()

def FloricoccusTropicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Floricoccus tropicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FloricoccusTropicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1859473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1859473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1859473.clusters.proteins.v11.5.txt",
		        "sequence_path": "1859473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1859473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1859473.protein.info.v11.5.txt",
		        "node_list_path": "1859473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1859473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinitogaHydrogenitoleransDsm16785(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinitoga hydrogenitolerans DSM 16785 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinitogaHydrogenitoleransDsm16785", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122195.protein.info.v11.5.txt",
		        "node_list_path": "1122195.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumVe20214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumVe20214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232452.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232452.protein.info.v11.5.txt",
		        "node_list_path": "1232452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerosceptrumFracticalcis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerosceptrum fracticalcis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerosceptrumFracticalcis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1712410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1712410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1712410.protein.info.v11.5.txt",
		        "node_list_path": "1712410.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRifoxyc1Full3779(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYC1_FULL_37_79 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyc1Full3779", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797395.protein.info.v11.5.txt",
		        "node_list_path": "1797395.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSpF0131(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. F0131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSpF0131", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575609.protein.sequences.v11.5.fa",
		        "enrichment_path": "575609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575609.protein.info.v11.5.txt",
		        "node_list_path": "575609.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelcococcusKunzii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helcococcus kunzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelcococcusKunzii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883114.protein.sequences.v11.5.fa",
		        "enrichment_path": "883114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883114.protein.info.v11.5.txt",
		        "node_list_path": "883114.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinilactibacillusPsychrotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinilactibacillus psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinilactibacillusPsychrotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "191770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "191770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "191770.clusters.proteins.v11.5.txt",
		        "sequence_path": "191770.protein.sequences.v11.5.fa",
		        "enrichment_path": "191770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "191770.protein.info.v11.5.txt",
		        "node_list_path": "191770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "191770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasGuineae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas guineae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasGuineae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "425504.protein.sequences.v11.5.fa",
		        "enrichment_path": "425504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425504.protein.info.v11.5.txt",
		        "node_list_path": "425504.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumSg847(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium SG8_47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumSg847", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703406.protein.info.v11.5.txt",
		        "node_list_path": "1703406.protein.complete.v11.5.txt"
		    }
		]
    )()

def AttaColombica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atta colombica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AttaColombica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "520822.protein.sequences.v11.5.fa",
		        "enrichment_path": "520822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "520822.protein.info.v11.5.txt",
		        "node_list_path": "520822.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpN54Mgs139Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. N54.MGS-139 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpN54Mgs139Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1637509.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1637509.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1637509.clusters.proteins.v11.5.txt",
		        "sequence_path": "1637509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1637509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1637509.protein.info.v11.5.txt",
		        "node_list_path": "1637509.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1637509.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaMaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytoplasma mali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaMaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37692.clusters.proteins.v11.5.txt",
		        "sequence_path": "37692.protein.sequences.v11.5.fa",
		        "enrichment_path": "37692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37692.protein.info.v11.5.txt",
		        "node_list_path": "37692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGlobisporusC1027(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces globisporus C-1027 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGlobisporusC1027", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1172567.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172567.protein.info.v11.5.txt",
		        "node_list_path": "1172567.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterNyackensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter nyackensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterNyackensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "475255.clusters.info.v11.5.txt",
		        "cluster_tree_path": "475255.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "475255.clusters.proteins.v11.5.txt",
		        "sequence_path": "475255.protein.sequences.v11.5.fa",
		        "enrichment_path": "475255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "475255.protein.info.v11.5.txt",
		        "node_list_path": "475255.cluster.nodes.v11.5.txt",
		        "edge_list_path": "475255.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudaestuariivitaAtlanticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudaestuariivita atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudaestuariivitaAtlanticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1317121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1317121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1317121.clusters.proteins.v11.5.txt",
		        "sequence_path": "1317121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317121.protein.info.v11.5.txt",
		        "node_list_path": "1317121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1317121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusPhoeniculicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus phoeniculicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusPhoeniculicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158610.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158610.protein.info.v11.5.txt",
		        "node_list_path": "1158610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MonosporascusSp5c6aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. 5C6A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSp5c6aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2211642.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2211642.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2211642.clusters.proteins.v11.5.txt",
		        "sequence_path": "2211642.protein.sequences.v11.5.fa",
		        "enrichment_path": "2211642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2211642.protein.info.v11.5.txt",
		        "node_list_path": "2211642.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2211642.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillibacterSpCag241Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. CAG:241 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSpCag241Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262911.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262911.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262911.protein.info.v11.5.txt",
		        "node_list_path": "1262911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusHitonicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus hitonicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusHitonicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "435880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "435880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "435880.clusters.proteins.v11.5.txt",
		        "sequence_path": "435880.protein.sequences.v11.5.fa",
		        "enrichment_path": "435880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435880.protein.info.v11.5.txt",
		        "node_list_path": "435880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "435880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BizioniaArgentinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bizionia argentinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BizioniaArgentinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1046627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1046627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1046627.clusters.proteins.v11.5.txt",
		        "sequence_path": "1046627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046627.protein.info.v11.5.txt",
		        "node_list_path": "1046627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1046627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DomibacillusEnclensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus enclensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusEnclensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1017273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1017273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1017273.protein.info.v11.5.txt",
		        "node_list_path": "1017273.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSpOk268(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK268 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSpOk268", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881048.protein.info.v11.5.txt",
		        "node_list_path": "1881048.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCohniiNbrc15565Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cohnii NBRC 15565 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCohniiNbrc15565Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314751.protein.info.v11.5.txt",
		        "node_list_path": "1314751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpH050(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H050 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpH050", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1759072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759072.protein.info.v11.5.txt",
		        "node_list_path": "1759072.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasJeotgaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasJeotgaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1238190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1238190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1238190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1238190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238190.protein.info.v11.5.txt",
		        "node_list_path": "1238190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1238190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulophagaSpW5c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga sp. W5C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaSpW5c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1888890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1888890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1888890.protein.info.v11.5.txt",
		        "node_list_path": "1888890.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobaculumMassiliaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum massiliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobaculumMassiliaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883066.clusters.proteins.v11.5.txt",
		        "sequence_path": "883066.protein.sequences.v11.5.fa",
		        "enrichment_path": "883066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883066.protein.info.v11.5.txt",
		        "node_list_path": "883066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterParvus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter parvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterParvus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "134533.protein.sequences.v11.5.fa",
		        "enrichment_path": "134533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134533.protein.info.v11.5.txt",
		        "node_list_path": "134533.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumHolothuriorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum holothuriorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumHolothuriorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635173.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635173.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635173.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635173.protein.info.v11.5.txt",
		        "node_list_path": "1635173.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635173.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumPoaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium poae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumPoaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36050.clusters.proteins.v11.5.txt",
		        "sequence_path": "36050.protein.sequences.v11.5.fa",
		        "enrichment_path": "36050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36050.protein.info.v11.5.txt",
		        "node_list_path": "36050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusIngluvieiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ingluviei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusIngluvieiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203076.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203076.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203076.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203076.protein.info.v11.5.txt",
		        "node_list_path": "1203076.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203076.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumSp174(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium sp. 174 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumSp174", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "208596.protein.sequences.v11.5.fa",
		        "enrichment_path": "208596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208596.protein.info.v11.5.txt",
		        "node_list_path": "208596.protein.complete.v11.5.txt"
		    }
		]
    )()

def KetogulonicigeniumRobustum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ketogulonicigenium robustum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KetogulonicigeniumRobustum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "92947.protein.sequences.v11.5.fa",
		        "enrichment_path": "92947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92947.protein.info.v11.5.txt",
		        "node_list_path": "92947.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaFonticolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia fonticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaFonticolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47917.clusters.proteins.v11.5.txt",
		        "sequence_path": "47917.protein.sequences.v11.5.fa",
		        "enrichment_path": "47917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47917.protein.info.v11.5.txt",
		        "node_list_path": "47917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MonosporascusSpMg133(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. MG133 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSpMg133", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2211645.protein.sequences.v11.5.fa",
		        "enrichment_path": "2211645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2211645.protein.info.v11.5.txt",
		        "node_list_path": "2211645.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesRubrolavendulae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces rubrolavendulae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRubrolavendulae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "285473.protein.sequences.v11.5.fa",
		        "enrichment_path": "285473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285473.protein.info.v11.5.txt",
		        "node_list_path": "285473.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhinocladiellaMackenzieiCbs65093(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhinocladiella mackenziei CBS 650.93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhinocladiellaMackenzieiCbs65093", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1442369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1442369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1442369.protein.info.v11.5.txt",
		        "node_list_path": "1442369.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaRhizosphaeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaRhizosphaeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "568872.clusters.info.v11.5.txt",
		        "cluster_tree_path": "568872.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "568872.clusters.proteins.v11.5.txt",
		        "sequence_path": "568872.protein.sequences.v11.5.fa",
		        "enrichment_path": "568872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568872.protein.info.v11.5.txt",
		        "node_list_path": "568872.cluster.nodes.v11.5.txt",
		        "edge_list_path": "568872.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VaribaculumCambrienseDora20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum cambriense DORA20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaribaculumCambrienseDora20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1403948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403948.protein.info.v11.5.txt",
		        "node_list_path": "1403948.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermomicrobiumRoseumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermomicrobium roseum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermomicrobiumRoseumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "309801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "309801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "309801.clusters.proteins.v11.5.txt",
		        "sequence_path": "309801.protein.sequences.v11.5.fa",
		        "enrichment_path": "309801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "309801.protein.info.v11.5.txt",
		        "node_list_path": "309801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "309801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OperophteraBrumataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Operophtera brumata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OperophteraBrumataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "104452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "104452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "104452.clusters.proteins.v11.5.txt",
		        "sequence_path": "104452.protein.sequences.v11.5.fa",
		        "enrichment_path": "104452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104452.protein.info.v11.5.txt",
		        "node_list_path": "104452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "104452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterSpYe315Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter sp. YE315 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterSpYe315Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1609968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1609968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1609968.clusters.proteins.v11.5.txt",
		        "sequence_path": "1609968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1609968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1609968.protein.info.v11.5.txt",
		        "node_list_path": "1609968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1609968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumEquinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium equinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumEquinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "134605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "134605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "134605.clusters.proteins.v11.5.txt",
		        "sequence_path": "134605.protein.sequences.v11.5.fa",
		        "enrichment_path": "134605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134605.protein.info.v11.5.txt",
		        "node_list_path": "134605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "134605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpKrocy2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. KROCY2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpKrocy2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1305732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305732.protein.info.v11.5.txt",
		        "node_list_path": "1305732.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurvibacterLanceolatusAtcc14669Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter lanceolatus ATCC 14669 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurvibacterLanceolatusAtcc14669Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265504.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265504.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265504.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265504.protein.info.v11.5.txt",
		        "node_list_path": "1265504.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265504.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumSodomense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum sodomense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumSodomense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35743.protein.sequences.v11.5.fa",
		        "enrichment_path": "35743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35743.protein.info.v11.5.txt",
		        "node_list_path": "35743.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaSputi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sputi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSputi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089453.protein.info.v11.5.txt",
		        "node_list_path": "1089453.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumGwf1327(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium GWF1_32_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumGwf1327", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798014.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798014.protein.info.v11.5.txt",
		        "node_list_path": "1798014.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichophytonBenhamiaeCbs112371Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton benhamiae CBS 112371 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichophytonBenhamiaeCbs112371Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "663331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "663331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "663331.clusters.proteins.v11.5.txt",
		        "sequence_path": "663331.protein.sequences.v11.5.fa",
		        "enrichment_path": "663331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663331.protein.info.v11.5.txt",
		        "node_list_path": "663331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "663331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnoanaerobaculumSaburreumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoanaerobaculumSaburreumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "467210.clusters.info.v11.5.txt",
		        "cluster_tree_path": "467210.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "467210.clusters.proteins.v11.5.txt",
		        "sequence_path": "467210.protein.sequences.v11.5.fa",
		        "enrichment_path": "467210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "467210.protein.info.v11.5.txt",
		        "node_list_path": "467210.cluster.nodes.v11.5.txt",
		        "edge_list_path": "467210.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LechevalieriaAerocolonigenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lechevalieria aerocolonigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LechevalieriaAerocolonigenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68170.protein.sequences.v11.5.fa",
		        "enrichment_path": "68170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68170.protein.info.v11.5.txt",
		        "node_list_path": "68170.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlossinaPalpalisGambiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glossina palpalis gambiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlossinaPalpalisGambiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67801.clusters.proteins.v11.5.txt",
		        "sequence_path": "67801.protein.sequences.v11.5.fa",
		        "enrichment_path": "67801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67801.protein.info.v11.5.txt",
		        "node_list_path": "67801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusZilligii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus zilligii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusZilligii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1151117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151117.protein.info.v11.5.txt",
		        "node_list_path": "1151117.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusOrisasiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus orisasini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOrisasiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1080071.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1080071.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1080071.clusters.proteins.v11.5.txt",
		        "sequence_path": "1080071.protein.sequences.v11.5.fa",
		        "enrichment_path": "1080071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1080071.protein.info.v11.5.txt",
		        "node_list_path": "1080071.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1080071.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BubalusBubalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bubalus bubalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BubalusBubalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "89462.protein.sequences.v11.5.fa",
		        "enrichment_path": "89462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89462.protein.info.v11.5.txt",
		        "node_list_path": "89462.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaBarkeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaBarkeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "269797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "269797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "269797.clusters.proteins.v11.5.txt",
		        "sequence_path": "269797.protein.sequences.v11.5.fa",
		        "enrichment_path": "269797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269797.protein.info.v11.5.txt",
		        "node_list_path": "269797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "269797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrischellaPerraraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frischella perrara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrischellaPerraraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267021.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267021.protein.info.v11.5.txt",
		        "node_list_path": "1267021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelcococcusSueciensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helcococcus sueciensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelcococcusSueciensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121947.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121947.protein.info.v11.5.txt",
		        "node_list_path": "1121947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VolvoxCarteriFNagariensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Volvox carteri f. nagariensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VolvoxCarteriFNagariensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3068.clusters.proteins.v11.5.txt",
		        "sequence_path": "3068.protein.sequences.v11.5.fa",
		        "enrichment_path": "3068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3068.protein.info.v11.5.txt",
		        "node_list_path": "3068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpAa0539(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. AA0539 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpAa0539", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210045.protein.info.v11.5.txt",
		        "node_list_path": "1210045.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasExtremaustralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas extremaustralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasExtremaustralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117958.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1117958.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1117958.clusters.proteins.v11.5.txt",
		        "sequence_path": "1117958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117958.protein.info.v11.5.txt",
		        "node_list_path": "1117958.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1117958.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PanicumVirgatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Panicum virgatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PanicumVirgatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "38727.protein.sequences.v11.5.fa",
		        "enrichment_path": "38727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38727.protein.info.v11.5.txt",
		        "node_list_path": "38727.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumHuakuii7653r(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium huakuii 7653R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumHuakuii7653r", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "763057.protein.sequences.v11.5.fa",
		        "enrichment_path": "763057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "763057.protein.info.v11.5.txt",
		        "node_list_path": "763057.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusVaginalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusVaginalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1756987.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1756987.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1756987.clusters.proteins.v11.5.txt",
		        "sequence_path": "1756987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1756987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1756987.protein.info.v11.5.txt",
		        "node_list_path": "1756987.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1756987.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonlabensSpYik11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens sp. YIK11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensSpYik11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1453349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1453349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1453349.clusters.proteins.v11.5.txt",
		        "sequence_path": "1453349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453349.protein.info.v11.5.txt",
		        "node_list_path": "1453349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1453349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "505249.clusters.info.v11.5.txt",
		        "cluster_tree_path": "505249.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "505249.clusters.proteins.v11.5.txt",
		        "sequence_path": "505249.protein.sequences.v11.5.fa",
		        "enrichment_path": "505249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "505249.protein.info.v11.5.txt",
		        "node_list_path": "505249.cluster.nodes.v11.5.txt",
		        "edge_list_path": "505249.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag793Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:793 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag793Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262840.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262840.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262840.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262840.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262840.protein.info.v11.5.txt",
		        "node_list_path": "1262840.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262840.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TaeniaAsiaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Taenia asiatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TaeniaAsiaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "60517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "60517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "60517.clusters.proteins.v11.5.txt",
		        "sequence_path": "60517.protein.sequences.v11.5.fa",
		        "enrichment_path": "60517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60517.protein.info.v11.5.txt",
		        "node_list_path": "60517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "60517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp6910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 69-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp6910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895783.protein.info.v11.5.txt",
		        "node_list_path": "1895783.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosospiraSpNsp11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraSpNsp11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855338.protein.info.v11.5.txt",
		        "node_list_path": "1855338.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapsasporaOwczarzakiAtcc30864Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capsaspora owczarzaki ATCC 30864 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsasporaOwczarzakiAtcc30864Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "595528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "595528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "595528.clusters.proteins.v11.5.txt",
		        "sequence_path": "595528.protein.sequences.v11.5.fa",
		        "enrichment_path": "595528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595528.protein.info.v11.5.txt",
		        "node_list_path": "595528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "595528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpFa1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. FA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpFa1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1346710.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1346710.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1346710.clusters.proteins.v11.5.txt",
		        "sequence_path": "1346710.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346710.protein.info.v11.5.txt",
		        "node_list_path": "1346710.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1346710.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinisporaPacificaDsm45543Cns863Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45543 CNS-863 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisporaPacificaDsm45543Cns863Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999542.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999542.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999542.clusters.proteins.v11.5.txt",
		        "sequence_path": "999542.protein.sequences.v11.5.fa",
		        "enrichment_path": "999542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999542.protein.info.v11.5.txt",
		        "node_list_path": "999542.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999542.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SingulisphaeraSpGp187Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Singulisphaera sp. GP187 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SingulisphaeraSpGp187Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882752.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882752.protein.info.v11.5.txt",
		        "node_list_path": "1882752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusNamurensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus namurensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusNamurensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1302286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1302286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1302286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1302286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302286.protein.info.v11.5.txt",
		        "node_list_path": "1302286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1302286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "666685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "666685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "666685.clusters.proteins.v11.5.txt",
		        "sequence_path": "666685.protein.sequences.v11.5.fa",
		        "enrichment_path": "666685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "666685.protein.info.v11.5.txt",
		        "node_list_path": "666685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "666685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaBalticaOs145Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina baltica OS145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaBalticaOs145Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314276.clusters.proteins.v11.5.txt",
		        "sequence_path": "314276.protein.sequences.v11.5.fa",
		        "enrichment_path": "314276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314276.protein.info.v11.5.txt",
		        "node_list_path": "314276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterNitrofigilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter nitrofigilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterNitrofigilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "572480.protein.sequences.v11.5.fa",
		        "enrichment_path": "572480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572480.protein.info.v11.5.txt",
		        "node_list_path": "572480.protein.complete.v11.5.txt"
		    }
		]
    )()

def BatrachochytriumDendrobatidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BatrachochytriumDendrobatidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "109871.protein.sequences.v11.5.fa",
		        "enrichment_path": "109871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109871.protein.info.v11.5.txt",
		        "node_list_path": "109871.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonascusPurpureus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monascus purpureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonascusPurpureus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5098.protein.sequences.v11.5.fa",
		        "enrichment_path": "5098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5098.protein.info.v11.5.txt",
		        "node_list_path": "5098.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpNml980116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML98-0116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpNml980116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "702967.protein.sequences.v11.5.fa",
		        "enrichment_path": "702967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702967.protein.info.v11.5.txt",
		        "node_list_path": "702967.protein.complete.v11.5.txt"
		    }
		]
    )()

def GilliamellaApicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gilliamella apicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilliamellaApicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196095.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196095.protein.info.v11.5.txt",
		        "node_list_path": "1196095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRaac3Tm71(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RAAC3_TM7_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRaac3Tm71", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1394711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394711.protein.info.v11.5.txt",
		        "node_list_path": "1394711.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumAcidisoliDsm12555(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acidisoli DSM 12555 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAcidisoliDsm12555", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121291.protein.info.v11.5.txt",
		        "node_list_path": "1121291.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrypanosomaBruceiBruceiTreu927(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma brucei brucei TREU927 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrypanosomaBruceiBruceiTreu927", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "185431.protein.sequences.v11.5.fa",
		        "enrichment_path": "185431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "185431.protein.info.v11.5.txt",
		        "node_list_path": "185431.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimonasVoraiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimonas voraii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimonasVoraiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "265719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "265719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "265719.clusters.proteins.v11.5.txt",
		        "sequence_path": "265719.protein.sequences.v11.5.fa",
		        "enrichment_path": "265719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265719.protein.info.v11.5.txt",
		        "node_list_path": "265719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "265719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElizabethkingiaMiricola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elizabethkingia miricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElizabethkingiaMiricola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "172045.protein.sequences.v11.5.fa",
		        "enrichment_path": "172045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "172045.protein.info.v11.5.txt",
		        "node_list_path": "172045.protein.complete.v11.5.txt"
		    }
		]
    )()

def FilimonasLacunae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Filimonas lacunae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FilimonasLacunae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "477680.protein.sequences.v11.5.fa",
		        "enrichment_path": "477680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477680.protein.info.v11.5.txt",
		        "node_list_path": "477680.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillatoriaNigroviridis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoria nigroviridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillatoriaNigroviridis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "179408.protein.sequences.v11.5.fa",
		        "enrichment_path": "179408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "179408.protein.info.v11.5.txt",
		        "node_list_path": "179408.protein.complete.v11.5.txt"
		    }
		]
    )()

def CynaraCardunculusVarScolymus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cynara cardunculus var. scolymus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CynaraCardunculusVarScolymus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59895.protein.sequences.v11.5.fa",
		        "enrichment_path": "59895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59895.protein.info.v11.5.txt",
		        "node_list_path": "59895.protein.complete.v11.5.txt"
		    }
		]
    )()

def GulbenkianiaIndicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gulbenkiania indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GulbenkianiaIndicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "375574.clusters.info.v11.5.txt",
		        "cluster_tree_path": "375574.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "375574.clusters.proteins.v11.5.txt",
		        "sequence_path": "375574.protein.sequences.v11.5.fa",
		        "enrichment_path": "375574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375574.protein.info.v11.5.txt",
		        "node_list_path": "375574.cluster.nodes.v11.5.txt",
		        "edge_list_path": "375574.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacillusSuccinogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus succinogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusSuccinogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "339671.protein.sequences.v11.5.fa",
		        "enrichment_path": "339671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "339671.protein.info.v11.5.txt",
		        "node_list_path": "339671.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSoldanellicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium soldanellicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSoldanellicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "311333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "311333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "311333.clusters.proteins.v11.5.txt",
		        "sequence_path": "311333.protein.sequences.v11.5.fa",
		        "enrichment_path": "311333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311333.protein.info.v11.5.txt",
		        "node_list_path": "311333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "311333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg2303638Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_36_38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2303638Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805316.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805316.protein.info.v11.5.txt",
		        "node_list_path": "1805316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasPrydzensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas prydzensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasPrydzensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "182141.clusters.info.v11.5.txt",
		        "cluster_tree_path": "182141.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "182141.clusters.proteins.v11.5.txt",
		        "sequence_path": "182141.protein.sequences.v11.5.fa",
		        "enrichment_path": "182141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "182141.protein.info.v11.5.txt",
		        "node_list_path": "182141.cluster.nodes.v11.5.txt",
		        "edge_list_path": "182141.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaAtlantaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella atlantae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaAtlantaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34059.clusters.proteins.v11.5.txt",
		        "sequence_path": "34059.protein.sequences.v11.5.fa",
		        "enrichment_path": "34059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34059.protein.info.v11.5.txt",
		        "node_list_path": "34059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifoxyc2Full3812Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFOXYC2_FULL_38_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifoxyc2Full3812Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801877.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801877.protein.info.v11.5.txt",
		        "node_list_path": "1801877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioCholeraeO395(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cholerae O395 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCholeraeO395", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "345073.protein.sequences.v11.5.fa",
		        "enrichment_path": "345073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "345073.protein.info.v11.5.txt",
		        "node_list_path": "345073.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaCopri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella copri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaCopri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "537011.protein.sequences.v11.5.fa",
		        "enrichment_path": "537011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537011.protein.info.v11.5.txt",
		        "node_list_path": "537011.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoplasmatalesArchaeonSg8523(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon SG8-52-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmatalesArchaeonSg8523", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803818.protein.info.v11.5.txt",
		        "node_list_path": "1803818.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuthiaMagnificaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruthia magnifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuthiaMagnificaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "413404.clusters.info.v11.5.txt",
		        "cluster_tree_path": "413404.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "413404.clusters.proteins.v11.5.txt",
		        "sequence_path": "413404.protein.sequences.v11.5.fa",
		        "enrichment_path": "413404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "413404.protein.info.v11.5.txt",
		        "node_list_path": "413404.cluster.nodes.v11.5.txt",
		        "edge_list_path": "413404.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZymoseptoriaTriticiSt99ch3d7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici ST99CH_3D7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymoseptoriaTriticiSt99ch3d7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1276538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1276538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1276538.clusters.proteins.v11.5.txt",
		        "sequence_path": "1276538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276538.protein.info.v11.5.txt",
		        "node_list_path": "1276538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1276538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TsukamurellaPseudospumae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tsukamurella pseudospumae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TsukamurellaPseudospumae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "239498.protein.sequences.v11.5.fa",
		        "enrichment_path": "239498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "239498.protein.info.v11.5.txt",
		        "node_list_path": "239498.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4322Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_43_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4322Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802695.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802695.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802695.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802695.protein.info.v11.5.txt",
		        "node_list_path": "1802695.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802695.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusPentosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pentosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPentosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1136177.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1136177.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1136177.clusters.proteins.v11.5.txt",
		        "sequence_path": "1136177.protein.sequences.v11.5.fa",
		        "enrichment_path": "1136177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1136177.protein.info.v11.5.txt",
		        "node_list_path": "1136177.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1136177.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterXylinusNbrc15237Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus NBRC 15237 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterXylinusNbrc15237Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220579.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220579.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220579.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220579.protein.info.v11.5.txt",
		        "node_list_path": "1220579.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220579.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterWiegelii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter wiegelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterWiegelii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "697303.protein.sequences.v11.5.fa",
		        "enrichment_path": "697303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "697303.protein.info.v11.5.txt",
		        "node_list_path": "697303.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterLappiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter lappiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterLappiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "354630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "354630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "354630.clusters.proteins.v11.5.txt",
		        "sequence_path": "354630.protein.sequences.v11.5.fa",
		        "enrichment_path": "354630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "354630.protein.info.v11.5.txt",
		        "node_list_path": "354630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "354630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaStr5aAcyrthosiphonPisum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola str. 5A (Acyrthosiphon pisum) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaStr5aAcyrthosiphonPisum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "563178.protein.sequences.v11.5.fa",
		        "enrichment_path": "563178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563178.protein.info.v11.5.txt",
		        "node_list_path": "563178.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumSpZwu0011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium sp. ZWU0011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumSpZwu0011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1339243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1339243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1339243.protein.info.v11.5.txt",
		        "node_list_path": "1339243.protein.complete.v11.5.txt"
		    }
		]
    )()

def DysgonomonasMacrotermitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas macrotermitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasMacrotermitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1346286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346286.protein.info.v11.5.txt",
		        "node_list_path": "1346286.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusTelluris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus telluris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusTelluris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1190417.protein.sequences.v11.5.fa",
		        "enrichment_path": "1190417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1190417.protein.info.v11.5.txt",
		        "node_list_path": "1190417.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMethylopumilusPlanktonicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methylopumilus planktonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethylopumilusPlanktonicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1581557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581557.protein.info.v11.5.txt",
		        "node_list_path": "1581557.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallionellalesBacteriumGwa254124(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_54_124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallionellalesBacteriumGwa254124", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798243.protein.info.v11.5.txt",
		        "node_list_path": "1798243.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusStrNatl2aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus str. NATL2A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusStrNatl2aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59920.clusters.proteins.v11.5.txt",
		        "sequence_path": "59920.protein.sequences.v11.5.fa",
		        "enrichment_path": "59920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59920.protein.info.v11.5.txt",
		        "node_list_path": "59920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusIhuaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ihuae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusIhuaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232431.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232431.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232431.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232431.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232431.protein.info.v11.5.txt",
		        "node_list_path": "1232431.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232431.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCny243Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNY243 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCny243Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1169161.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1169161.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1169161.clusters.proteins.v11.5.txt",
		        "sequence_path": "1169161.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169161.protein.info.v11.5.txt",
		        "node_list_path": "1169161.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1169161.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaSp6729Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. 67-29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSp6729Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895723.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895723.protein.info.v11.5.txt",
		        "node_list_path": "1895723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NecropsobacterRosorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Necropsobacter rosorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NecropsobacterRosorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "908285.protein.sequences.v11.5.fa",
		        "enrichment_path": "908285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908285.protein.info.v11.5.txt",
		        "node_list_path": "908285.protein.complete.v11.5.txt"
		    }
		]
    )()

def RummeliibacillusStabekisiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rummeliibacillus stabekisii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RummeliibacillusStabekisiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "241244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "241244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "241244.clusters.proteins.v11.5.txt",
		        "sequence_path": "241244.protein.sequences.v11.5.fa",
		        "enrichment_path": "241244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "241244.protein.info.v11.5.txt",
		        "node_list_path": "241244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "241244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4748(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_47_48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4748", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798381.protein.info.v11.5.txt",
		        "node_list_path": "1798381.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrococcusLuteusStrModasa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micrococcus luteus str. modasa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcusLuteusStrModasa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232675.protein.info.v11.5.txt",
		        "node_list_path": "1232675.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFluvii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium fluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFluvii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "468056.protein.sequences.v11.5.fa",
		        "enrichment_path": "468056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "468056.protein.info.v11.5.txt",
		        "node_list_path": "468056.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumSgBin8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SG_bin8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumSgBin8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1827387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827387.protein.info.v11.5.txt",
		        "node_list_path": "1827387.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasHalophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas halophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasHalophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44576.protein.sequences.v11.5.fa",
		        "enrichment_path": "44576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44576.protein.info.v11.5.txt",
		        "node_list_path": "44576.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifcsplowo202Full6764Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO2_02_FULL_67_64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo202Full6764Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797564.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797564.protein.info.v11.5.txt",
		        "node_list_path": "1797564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumDtu065Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU065 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumDtu065Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671641.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671641.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671641.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671641.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671641.protein.info.v11.5.txt",
		        "node_list_path": "1671641.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671641.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpMcba15001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpMcba15001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1898731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1898731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1898731.clusters.proteins.v11.5.txt",
		        "sequence_path": "1898731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898731.protein.info.v11.5.txt",
		        "node_list_path": "1898731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1898731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetarhiziumRobertsii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium robertsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetarhiziumRobertsii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "568076.protein.sequences.v11.5.fa",
		        "enrichment_path": "568076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568076.protein.info.v11.5.txt",
		        "node_list_path": "568076.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpPcc7375(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC7375 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpPcc7375", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "102129.protein.sequences.v11.5.fa",
		        "enrichment_path": "102129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102129.protein.info.v11.5.txt",
		        "node_list_path": "102129.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusAmylophilusDsm20533Jcm1125(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus amylophilus DSM 20533 JCM 1125 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAmylophilusDsm20533Jcm1125", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423721.protein.info.v11.5.txt",
		        "node_list_path": "1423721.protein.complete.v11.5.txt"
		    }
		]
    )()

def FaecalibacteriumSpCag7458120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium sp. CAG:74_58_120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibacteriumSpCag7458120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897005.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897005.protein.info.v11.5.txt",
		        "node_list_path": "1897005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusPeraridilitoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus peraridilitoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusPeraridilitoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "937777.protein.sequences.v11.5.fa",
		        "enrichment_path": "937777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937777.protein.info.v11.5.txt",
		        "node_list_path": "937777.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpNci(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Nci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpNci", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1316444.protein.sequences.v11.0.fa",
		        "enrichment_path": "1316444.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1316444.protein.info.v11.0.txt",
		        "node_list_path": "1316444.protein.complete.v11.0.txt"
		    }
		]
    )()

def KlebsiellaPneumoniaeSubspPneumoniaeHs11286Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. pneumoniae HS11286 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaPneumoniaeSubspPneumoniaeHs11286Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125630.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125630.protein.info.v11.5.txt",
		        "node_list_path": "1125630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrialbaTaiwanensisDsm12281Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialba taiwanensis DSM 12281 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaTaiwanensisDsm12281Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230458.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230458.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230458.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230458.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230458.protein.info.v11.5.txt",
		        "node_list_path": "1230458.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230458.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200251961Sch5331710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-51961_SCH5331710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200251961Sch5331710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834105.protein.info.v11.5.txt",
		        "node_list_path": "1834105.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusXenolissoclinumPacificiensisL6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Xenolissoclinum pacificiensis L6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusXenolissoclinumPacificiensisL6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1401685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401685.protein.info.v11.5.txt",
		        "node_list_path": "1401685.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgarivoransGilvusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agarivorans gilvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgarivoransGilvusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "680279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "680279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "680279.clusters.proteins.v11.5.txt",
		        "sequence_path": "680279.protein.sequences.v11.5.fa",
		        "enrichment_path": "680279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "680279.protein.info.v11.5.txt",
		        "node_list_path": "680279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "680279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpFcs014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FCS014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpFcs014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408304.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408304.protein.info.v11.5.txt",
		        "node_list_path": "1408304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusMalodoratusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus malodoratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusMalodoratusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158601.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158601.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158601.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158601.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158601.protein.info.v11.5.txt",
		        "node_list_path": "1158601.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158601.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolanumTuberosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solanum tuberosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolanumTuberosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4113.clusters.proteins.v11.5.txt",
		        "sequence_path": "4113.protein.sequences.v11.5.fa",
		        "enrichment_path": "4113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4113.protein.info.v11.5.txt",
		        "node_list_path": "4113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteribacillusIranensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteribacillus iranensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteribacillusIranensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930128.protein.sequences.v11.5.fa",
		        "enrichment_path": "930128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930128.protein.info.v11.5.txt",
		        "node_list_path": "930128.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumGwc25713(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWC2_57_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumGwc25713", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801697.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801697.protein.info.v11.5.txt",
		        "node_list_path": "1801697.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9312(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9312", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "74546.protein.sequences.v11.5.fa",
		        "enrichment_path": "74546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74546.protein.info.v11.5.txt",
		        "node_list_path": "74546.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterDefluviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter defluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterDefluviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871111.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871111.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871111.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871111.protein.info.v11.5.txt",
		        "node_list_path": "1871111.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871111.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobellusClavatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobellus clavatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobellusClavatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "660517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "660517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "660517.clusters.proteins.v11.5.txt",
		        "sequence_path": "660517.protein.sequences.v11.5.fa",
		        "enrichment_path": "660517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660517.protein.info.v11.5.txt",
		        "node_list_path": "660517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "660517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterOkinawensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter okinawensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterOkinawensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236501.protein.info.v11.5.txt",
		        "node_list_path": "1236501.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeeuwenhoekiellaSpHeli48Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella sp. HelI48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeeuwenhoekiellaSpHeli48Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392488.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392488.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392488.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392488.protein.info.v11.5.txt",
		        "node_list_path": "1392488.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392488.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfonauticusSpA7a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonauticus sp. A7A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonauticusSpA7a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379281.protein.info.v11.5.txt",
		        "node_list_path": "1379281.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterHyointestinalisSubspHyointestinalisLmg9260Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter hyointestinalis subsp. hyointestinalis LMG 9260 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterHyointestinalisSubspHyointestinalisLmg9260Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1031746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1031746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1031746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1031746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1031746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1031746.protein.info.v11.5.txt",
		        "node_list_path": "1031746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1031746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DromaiusNovaehollandiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dromaius novaehollandiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DromaiusNovaehollandiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8790.protein.sequences.v11.5.fa",
		        "enrichment_path": "8790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8790.protein.info.v11.5.txt",
		        "node_list_path": "8790.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSpChdc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. ChDC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSpChdc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354300.protein.info.v11.5.txt",
		        "node_list_path": "1354300.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoculleusMarisnigri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus marisnigri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusMarisnigri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "368407.protein.sequences.v11.5.fa",
		        "enrichment_path": "368407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "368407.protein.info.v11.5.txt",
		        "node_list_path": "368407.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaAlcalifaciensR901475(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens R90-1475 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaAlcalifaciensR901475", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1256989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1256989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1256989.protein.info.v11.5.txt",
		        "node_list_path": "1256989.protein.complete.v11.5.txt"
		    }
		]
    )()

def MobiluncusCurtisiiAtcc43063(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii ATCC43063 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobiluncusCurtisiiAtcc43063", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "548479.protein.sequences.v11.5.fa",
		        "enrichment_path": "548479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "548479.protein.info.v11.5.txt",
		        "node_list_path": "548479.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanococcusAeolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus aeolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusAeolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "419665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "419665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "419665.clusters.proteins.v11.5.txt",
		        "sequence_path": "419665.protein.sequences.v11.5.fa",
		        "enrichment_path": "419665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419665.protein.info.v11.5.txt",
		        "node_list_path": "419665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "419665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaSpBmg512Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. BMG512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpBmg512Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "222534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "222534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "222534.clusters.proteins.v11.5.txt",
		        "sequence_path": "222534.protein.sequences.v11.5.fa",
		        "enrichment_path": "222534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "222534.protein.info.v11.5.txt",
		        "node_list_path": "222534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "222534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusInfantisAtcc700779(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis ATCC700779 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusInfantisAtcc700779", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "889204.protein.sequences.v11.5.fa",
		        "enrichment_path": "889204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "889204.protein.info.v11.5.txt",
		        "node_list_path": "889204.protein.complete.v11.5.txt"
		    }
		]
    )()

def GillisiaLimnaeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gillisia limnaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GillisiaLimnaeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "865937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "865937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "865937.clusters.proteins.v11.5.txt",
		        "sequence_path": "865937.protein.sequences.v11.5.fa",
		        "enrichment_path": "865937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "865937.protein.info.v11.5.txt",
		        "node_list_path": "865937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "865937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumPsychrophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium psychrophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumPsychrophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "402612.protein.sequences.v11.5.fa",
		        "enrichment_path": "402612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402612.protein.info.v11.5.txt",
		        "node_list_path": "402612.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumGw2011Gwc24417Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium GW2011_GWC2_44_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumGw2011Gwc24417Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619070.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619070.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619070.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619070.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619070.protein.info.v11.5.txt",
		        "node_list_path": "1619070.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619070.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp15544247Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1554424.7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp15544247Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834082.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834082.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834082.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834082.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834082.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834082.protein.info.v11.5.txt",
		        "node_list_path": "1834082.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834082.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacteroidesHalobiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacteroides halobius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacteroidesHalobiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "748449.clusters.info.v11.5.txt",
		        "cluster_tree_path": "748449.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "748449.clusters.proteins.v11.5.txt",
		        "sequence_path": "748449.protein.sequences.v11.5.fa",
		        "enrichment_path": "748449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748449.protein.info.v11.5.txt",
		        "node_list_path": "748449.cluster.nodes.v11.5.txt",
		        "edge_list_path": "748449.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcanobacteriumUrinimassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcanobacterium urinimassiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcanobacteriumUrinimassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871014.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871014.protein.info.v11.5.txt",
		        "node_list_path": "1871014.protein.complete.v11.5.txt"
		    }
		]
    )()

def MartelellaMediterranea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Martelella mediterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MartelellaMediterranea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122214.protein.info.v11.5.txt",
		        "node_list_path": "1122214.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpJca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1414718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414718.protein.info.v11.5.txt",
		        "node_list_path": "1414718.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpS4c9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. S4C9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpS4c9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219581.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219581.protein.info.v11.5.txt",
		        "node_list_path": "1219581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumAlbumDsm18261Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium album DSM 18261 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumAlbumDsm18261Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121122.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121122.protein.info.v11.5.txt",
		        "node_list_path": "1121122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZetaproteobacteriaBacteriumCg2304652Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG2_30_46_52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaproteobacteriaBacteriumCg2304652Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805429.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805429.protein.info.v11.5.txt",
		        "node_list_path": "1805429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolimonasSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solimonas soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolimonasSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123261.protein.info.v11.5.txt",
		        "node_list_path": "1123261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachyspiraIntermediaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira intermedia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraIntermediaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1045858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1045858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1045858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1045858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045858.protein.info.v11.5.txt",
		        "node_list_path": "1045858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1045858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag3212622(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:321_26_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag3212622", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897034.protein.info.v11.5.txt",
		        "node_list_path": "1897034.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNc2008Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NC2008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNc2008Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410627.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410627.protein.info.v11.5.txt",
		        "node_list_path": "1410627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrobaculumArsenaticumDsm13514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum arsenaticum DSM 13514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumArsenaticumDsm13514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "340102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "340102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "340102.clusters.proteins.v11.5.txt",
		        "sequence_path": "340102.protein.sequences.v11.5.fa",
		        "enrichment_path": "340102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340102.protein.info.v11.5.txt",
		        "node_list_path": "340102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "340102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHtcc2207(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2207 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHtcc2207", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314287.protein.sequences.v11.5.fa",
		        "enrichment_path": "314287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314287.protein.info.v11.5.txt",
		        "node_list_path": "314287.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPolymyxaE681(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa E681 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPolymyxaE681", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349520.protein.sequences.v11.5.fa",
		        "enrichment_path": "349520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349520.protein.info.v11.5.txt",
		        "node_list_path": "349520.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaPseudohaemulonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Candida] pseudohaemulonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaPseudohaemulonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "418784.clusters.info.v11.5.txt",
		        "cluster_tree_path": "418784.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "418784.clusters.proteins.v11.5.txt",
		        "sequence_path": "418784.protein.sequences.v11.5.fa",
		        "enrichment_path": "418784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "418784.protein.info.v11.5.txt",
		        "node_list_path": "418784.cluster.nodes.v11.5.txt",
		        "edge_list_path": "418784.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StegodyphusMimosarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stegodyphus mimosarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StegodyphusMimosarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "407821.protein.sequences.v11.5.fa",
		        "enrichment_path": "407821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "407821.protein.info.v11.5.txt",
		        "node_list_path": "407821.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlammeovirgaPacifica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flammeovirga pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlammeovirgaPacifica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "915059.protein.sequences.v11.5.fa",
		        "enrichment_path": "915059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "915059.protein.info.v11.5.txt",
		        "node_list_path": "915059.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfovibrioThiophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio thiophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfovibrioThiophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123376.protein.info.v11.5.txt",
		        "node_list_path": "1123376.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwa2319Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_31_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwa2319Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797314.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797314.protein.info.v11.5.txt",
		        "node_list_path": "1797314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusZhangzhouensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus zhangzhouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusZhangzhouensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1073327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1073327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1073327.clusters.proteins.v11.5.txt",
		        "sequence_path": "1073327.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073327.protein.info.v11.5.txt",
		        "node_list_path": "1073327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1073327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrateuriaSpSoil773(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frateuria sp. Soil773 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrateuriaSpSoil773", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736407.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736407.protein.info.v11.5.txt",
		        "node_list_path": "1736407.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpD16r12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. D16R12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpD16r12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855662.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855662.protein.info.v11.5.txt",
		        "node_list_path": "1855662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9302(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9302 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9302", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "74545.protein.sequences.v11.5.fa",
		        "enrichment_path": "74545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74545.protein.info.v11.5.txt",
		        "node_list_path": "74545.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaXenovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia xenovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaXenovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266265.protein.sequences.v11.5.fa",
		        "enrichment_path": "266265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266265.protein.info.v11.5.txt",
		        "node_list_path": "266265.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfobacillusAcidophilusDsm10332(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfobacillus acidophilus DSM 10332 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfobacillusAcidophilusDsm10332", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679936.protein.sequences.v11.5.fa",
		        "enrichment_path": "679936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679936.protein.info.v11.5.txt",
		        "node_list_path": "679936.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumCg1023722Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium CG1_02_37_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumCg1023722Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805209.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805209.protein.info.v11.5.txt",
		        "node_list_path": "1805209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusConcavusDsm17758Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus concavus DSM 17758 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusConcavusDsm17758Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423735.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423735.protein.info.v11.5.txt",
		        "node_list_path": "1423735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NevskiaSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nevskia soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NevskiaSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122604.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122604.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122604.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122604.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122604.protein.info.v11.5.txt",
		        "node_list_path": "1122604.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122604.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesOctosporusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces octosporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesOctosporusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4899.clusters.proteins.v11.5.txt",
		        "sequence_path": "4899.protein.sequences.v11.5.fa",
		        "enrichment_path": "4899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4899.protein.info.v11.5.txt",
		        "node_list_path": "4899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpJha26(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. JHA26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpJha26", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1917143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917143.protein.info.v11.5.txt",
		        "node_list_path": "1917143.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobacteralesBacteriumCg2306027Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium CG2_30_60_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteralesBacteriumCg2306027Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805129.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805129.protein.info.v11.5.txt",
		        "node_list_path": "1805129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirosomaLingualeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma linguale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaLingualeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "504472.clusters.info.v11.5.txt",
		        "cluster_tree_path": "504472.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "504472.clusters.proteins.v11.5.txt",
		        "sequence_path": "504472.protein.sequences.v11.5.fa",
		        "enrichment_path": "504472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504472.protein.info.v11.5.txt",
		        "node_list_path": "504472.cluster.nodes.v11.5.txt",
		        "edge_list_path": "504472.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermocrispumMunicipaleDsm44069(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermocrispum municipale DSM 44069 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocrispumMunicipaleDsm44069", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111737.protein.info.v11.5.txt",
		        "node_list_path": "1111737.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPasteurianusAtcc43144(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pasteurianus ATCC 43144 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPasteurianusAtcc43144", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "981540.protein.sequences.v11.5.fa",
		        "enrichment_path": "981540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981540.protein.info.v11.5.txt",
		        "node_list_path": "981540.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudovibrioSpAb134Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. Ab134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioSpAb134Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1898042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1898042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1898042.clusters.proteins.v11.5.txt",
		        "sequence_path": "1898042.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898042.protein.info.v11.5.txt",
		        "node_list_path": "1898042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1898042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpHmica12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. HmicA12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpHmica12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1156844.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1156844.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1156844.clusters.proteins.v11.5.txt",
		        "sequence_path": "1156844.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156844.protein.info.v11.5.txt",
		        "node_list_path": "1156844.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1156844.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OnchocercaVolvulusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Onchocerca volvulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OnchocercaVolvulusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6282.clusters.proteins.v11.5.txt",
		        "sequence_path": "6282.protein.sequences.v11.5.fa",
		        "enrichment_path": "6282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6282.protein.info.v11.5.txt",
		        "node_list_path": "6282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanosphaerulaPalustrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosphaerula palustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosphaerulaPalustrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521011.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521011.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521011.clusters.proteins.v11.5.txt",
		        "sequence_path": "521011.protein.sequences.v11.5.fa",
		        "enrichment_path": "521011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521011.protein.info.v11.5.txt",
		        "node_list_path": "521011.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521011.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophilusSp5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. 5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusSp5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1112274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1112274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1112274.clusters.proteins.v11.5.txt",
		        "sequence_path": "1112274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112274.protein.info.v11.5.txt",
		        "node_list_path": "1112274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1112274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermanaerovibrioAcidaminovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermanaerovibrio acidaminovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermanaerovibrioAcidaminovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525903.clusters.proteins.v11.5.txt",
		        "sequence_path": "525903.protein.sequences.v11.5.fa",
		        "enrichment_path": "525903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525903.protein.info.v11.5.txt",
		        "node_list_path": "525903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpMtm3w52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. MTM3W5.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpMtm3w52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805827.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805827.protein.info.v11.5.txt",
		        "node_list_path": "1805827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusParaphrohaemolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus paraphrohaemolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusParaphrohaemolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095743.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095743.protein.info.v11.5.txt",
		        "node_list_path": "1095743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrapisisporaPhaffiiCbs4417(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora phaffii CBS 4417 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrapisisporaPhaffiiCbs4417", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071381.protein.info.v11.5.txt",
		        "node_list_path": "1071381.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcaceaeBacteriumVa2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium VA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcaceaeBacteriumVa2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1476973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1476973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1476973.protein.info.v11.5.txt",
		        "node_list_path": "1476973.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudarthrobacterSiccitoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudarthrobacter siccitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudarthrobacterSiccitoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "861266.clusters.info.v11.5.txt",
		        "cluster_tree_path": "861266.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "861266.clusters.proteins.v11.5.txt",
		        "sequence_path": "861266.protein.sequences.v11.5.fa",
		        "enrichment_path": "861266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861266.protein.info.v11.5.txt",
		        "node_list_path": "861266.cluster.nodes.v11.5.txt",
		        "edge_list_path": "861266.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GramellaFlavaJlt2011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gramella flava JLT2011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaFlavaJlt2011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229726.protein.info.v11.5.txt",
		        "node_list_path": "1229726.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriDsm10701(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri DSM10701 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriDsm10701", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123519.protein.info.v11.5.txt",
		        "node_list_path": "1123519.protein.complete.v11.5.txt"
		    }
		]
    )()

def HuchoHuchoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hucho hucho Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HuchoHuchoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "62062.clusters.info.v11.5.txt",
		        "cluster_tree_path": "62062.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "62062.clusters.proteins.v11.5.txt",
		        "sequence_path": "62062.protein.sequences.v11.5.fa",
		        "enrichment_path": "62062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62062.protein.info.v11.5.txt",
		        "node_list_path": "62062.cluster.nodes.v11.5.txt",
		        "edge_list_path": "62062.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicolaSpMctg156Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola sp. MCTG156 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaSpMctg156Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415756.protein.info.v11.5.txt",
		        "node_list_path": "1415756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwa2407bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA2_40_7b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa2407bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618563.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618563.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618563.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618563.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618563.protein.info.v11.5.txt",
		        "node_list_path": "1618563.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618563.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfatitaleaTepidiphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfatitalea tepidiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfatitaleaTepidiphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1185843.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1185843.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1185843.clusters.proteins.v11.5.txt",
		        "sequence_path": "1185843.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185843.protein.info.v11.5.txt",
		        "node_list_path": "1185843.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1185843.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSuisStrIllinoisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma suis str. Illinois Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSuisStrIllinoisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "768700.clusters.info.v11.5.txt",
		        "cluster_tree_path": "768700.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "768700.clusters.proteins.v11.5.txt",
		        "sequence_path": "768700.protein.sequences.v11.5.fa",
		        "enrichment_path": "768700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768700.protein.info.v11.5.txt",
		        "node_list_path": "768700.cluster.nodes.v11.5.txt",
		        "edge_list_path": "768700.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaAmblyommatisStrGat30v(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia amblyommatis str. GAT-30V graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaAmblyommatisStrGat30v", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1105111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1105111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1105111.protein.info.v11.5.txt",
		        "node_list_path": "1105111.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudovibrioAxinellaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio axinellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioAxinellaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "989403.clusters.info.v11.5.txt",
		        "cluster_tree_path": "989403.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "989403.clusters.proteins.v11.5.txt",
		        "sequence_path": "989403.protein.sequences.v11.5.fa",
		        "enrichment_path": "989403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "989403.protein.info.v11.5.txt",
		        "node_list_path": "989403.cluster.nodes.v11.5.txt",
		        "edge_list_path": "989403.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RamlibacterSpLeaf400(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ramlibacter sp. Leaf400 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RamlibacterSpLeaf400", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736365.protein.info.v11.5.txt",
		        "node_list_path": "1736365.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseivivaxSp22iis10s(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax sp. 22IIs10s graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxSp22iis10s", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1317118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317118.protein.info.v11.5.txt",
		        "node_list_path": "1317118.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordonibacterMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonibacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordonibacterMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841863.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841863.protein.info.v11.5.txt",
		        "node_list_path": "1841863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAllii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus allii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAllii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1847728.protein.sequences.v11.5.fa",
		        "enrichment_path": "1847728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1847728.protein.info.v11.5.txt",
		        "node_list_path": "1847728.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumTaeniosporumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium taeniosporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTaeniosporumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "394958.clusters.info.v11.5.txt",
		        "cluster_tree_path": "394958.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "394958.clusters.proteins.v11.5.txt",
		        "sequence_path": "394958.protein.sequences.v11.5.fa",
		        "enrichment_path": "394958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394958.protein.info.v11.5.txt",
		        "node_list_path": "394958.cluster.nodes.v11.5.txt",
		        "edge_list_path": "394958.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesGordoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides gordonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesGordoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122931.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122931.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122931.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122931.protein.info.v11.5.txt",
		        "node_list_path": "1122931.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122931.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesMerusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles merus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesMerusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "30066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "30066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "30066.clusters.proteins.v11.5.txt",
		        "sequence_path": "30066.protein.sequences.v11.5.fa",
		        "enrichment_path": "30066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30066.protein.info.v11.5.txt",
		        "node_list_path": "30066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "30066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807734.protein.info.v11.5.txt",
		        "node_list_path": "1807734.protein.complete.v11.5.txt"
		    }
		]
    )()

def BeijerinckiaSp28Yea48Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Beijerinckia sp. 28-YEA-48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeijerinckiaSp28Yea48Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882748.protein.info.v11.5.txt",
		        "node_list_path": "1882748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumScgcAaa024D14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA024-D14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumScgcAaa024D14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "932039.clusters.info.v11.5.txt",
		        "cluster_tree_path": "932039.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "932039.clusters.proteins.v11.5.txt",
		        "sequence_path": "932039.protein.sequences.v11.5.fa",
		        "enrichment_path": "932039.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932039.protein.info.v11.5.txt",
		        "node_list_path": "932039.cluster.nodes.v11.5.txt",
		        "edge_list_path": "932039.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpTks(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. TKS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpTks", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1315974.protein.sequences.v11.5.fa",
		        "enrichment_path": "1315974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1315974.protein.info.v11.5.txt",
		        "node_list_path": "1315974.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaPorcinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema porcinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPorcinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "261392.protein.sequences.v11.5.fa",
		        "enrichment_path": "261392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "261392.protein.info.v11.5.txt",
		        "node_list_path": "261392.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConiellaLustricola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coniella lustricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConiellaLustricola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2025994.protein.sequences.v11.5.fa",
		        "enrichment_path": "2025994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2025994.protein.info.v11.5.txt",
		        "node_list_path": "2025994.protein.complete.v11.5.txt"
		    }
		]
    )()

def KtedonobacterRacemiferCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ktedonobacter racemifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KtedonobacterRacemiferCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "485913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "485913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "485913.clusters.proteins.v11.5.txt",
		        "sequence_path": "485913.protein.sequences.v11.5.fa",
		        "enrichment_path": "485913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485913.protein.info.v11.5.txt",
		        "node_list_path": "485913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "485913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OdobenusRosmarus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Odobenus rosmarus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OdobenusRosmarus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9707.protein.sequences.v11.5.fa",
		        "enrichment_path": "9707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9707.protein.info.v11.5.txt",
		        "node_list_path": "9707.protein.complete.v11.5.txt"
		    }
		]
    )()

def VitisViniferaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vitis vinifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VitisViniferaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29760.clusters.proteins.v11.5.txt",
		        "sequence_path": "29760.protein.sequences.v11.5.fa",
		        "enrichment_path": "29760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29760.protein.info.v11.5.txt",
		        "node_list_path": "29760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidithiobacillusFerrooxidansAtcc23270(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans ATCC23270 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithiobacillusFerrooxidansAtcc23270", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243159.protein.sequences.v11.5.fa",
		        "enrichment_path": "243159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243159.protein.info.v11.5.txt",
		        "node_list_path": "243159.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiIai1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli IAI1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiIai1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585034.clusters.proteins.v11.5.txt",
		        "sequence_path": "585034.protein.sequences.v11.5.fa",
		        "enrichment_path": "585034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585034.protein.info.v11.5.txt",
		        "node_list_path": "585034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FluoribacterGormanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fluoribacter gormanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FluoribacterGormanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "464.protein.sequences.v11.5.fa",
		        "enrichment_path": "464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "464.protein.info.v11.5.txt",
		        "node_list_path": "464.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrellaSpEs10322Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrella sp. ES10-3-2-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrellaSpEs10322Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834519.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834519.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834519.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834519.protein.info.v11.5.txt",
		        "node_list_path": "1834519.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834519.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaViswanathiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida viswanathii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaViswanathiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5486.clusters.proteins.v11.5.txt",
		        "sequence_path": "5486.protein.sequences.v11.5.fa",
		        "enrichment_path": "5486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5486.protein.info.v11.5.txt",
		        "node_list_path": "5486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WickerhamomycesCiferriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamomyces ciferrii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WickerhamomycesCiferriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041607.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041607.protein.info.v11.5.txt",
		        "node_list_path": "1041607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfuromonasSoudanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromonas soudanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromonasSoudanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1603606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1603606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1603606.clusters.proteins.v11.5.txt",
		        "sequence_path": "1603606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603606.protein.info.v11.5.txt",
		        "node_list_path": "1603606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1603606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesChartreusis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces chartreusis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesChartreusis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1079986.protein.sequences.v11.5.fa",
		        "enrichment_path": "1079986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1079986.protein.info.v11.5.txt",
		        "node_list_path": "1079986.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaBongoriNctc12419Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella bongori NCTC12419 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaBongoriNctc12419Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "218493.clusters.info.v11.5.txt",
		        "cluster_tree_path": "218493.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "218493.clusters.proteins.v11.5.txt",
		        "sequence_path": "218493.protein.sequences.v11.5.fa",
		        "enrichment_path": "218493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218493.protein.info.v11.5.txt",
		        "node_list_path": "218493.cluster.nodes.v11.5.txt",
		        "edge_list_path": "218493.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanolaciniaPaynteriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanolacinia paynteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolaciniaPaynteriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "230356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "230356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "230356.clusters.proteins.v11.5.txt",
		        "sequence_path": "230356.protein.sequences.v11.5.fa",
		        "enrichment_path": "230356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "230356.protein.info.v11.5.txt",
		        "node_list_path": "230356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "230356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptobacillusRattiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptobacillus ratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptobacillusRattiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720557.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720557.protein.info.v11.5.txt",
		        "node_list_path": "1720557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SiphonobacterAquaeclaraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Siphonobacter aquaeclarae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SiphonobacterAquaeclaraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "563176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "563176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "563176.clusters.proteins.v11.5.txt",
		        "sequence_path": "563176.protein.sequences.v11.5.fa",
		        "enrichment_path": "563176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563176.protein.info.v11.5.txt",
		        "node_list_path": "563176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "563176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpKjj(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KJJ graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpKjj", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1270193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1270193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1270193.protein.info.v11.5.txt",
		        "node_list_path": "1270193.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSenegalensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSenegalensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033744.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033744.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033744.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033744.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033744.protein.info.v11.5.txt",
		        "node_list_path": "1033744.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033744.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterFetusTestudinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus testudinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterFetusTestudinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1244528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1244528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1244528.clusters.proteins.v11.5.txt",
		        "sequence_path": "1244528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1244528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1244528.protein.info.v11.5.txt",
		        "node_list_path": "1244528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1244528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpGxs13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. GXS13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpGxs13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1730094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1730094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1730094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1730094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1730094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1730094.protein.info.v11.5.txt",
		        "node_list_path": "1730094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1730094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumGraminicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum graminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumGraminicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "31870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "31870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "31870.clusters.proteins.v11.5.txt",
		        "sequence_path": "31870.protein.sequences.v11.5.fa",
		        "enrichment_path": "31870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31870.protein.info.v11.5.txt",
		        "node_list_path": "31870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "31870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParapedobacterIndicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parapedobacter indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParapedobacterIndicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1477437.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1477437.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1477437.clusters.proteins.v11.5.txt",
		        "sequence_path": "1477437.protein.sequences.v11.5.fa",
		        "enrichment_path": "1477437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1477437.protein.info.v11.5.txt",
		        "node_list_path": "1477437.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1477437.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSmegmatisMc2155(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium smegmatis MC2155 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSmegmatisMc2155", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246196.protein.sequences.v11.5.fa",
		        "enrichment_path": "246196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246196.protein.info.v11.5.txt",
		        "node_list_path": "246196.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaSpAngR(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. ANG-R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaSpAngR", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577903.protein.info.v11.5.txt",
		        "node_list_path": "1577903.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasSpGpe39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. GPE 39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasSpGpe39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1583099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1583099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1583099.protein.info.v11.5.txt",
		        "node_list_path": "1583099.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpMmlr14006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MMLR14_006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpMmlr14006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1898742.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1898742.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1898742.clusters.proteins.v11.5.txt",
		        "sequence_path": "1898742.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898742.protein.info.v11.5.txt",
		        "node_list_path": "1898742.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1898742.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaMaltophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema maltophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaMaltophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125699.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125699.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125699.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125699.protein.info.v11.5.txt",
		        "node_list_path": "1125699.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125699.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumGleumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium gleum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumGleumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525257.clusters.proteins.v11.5.txt",
		        "sequence_path": "525257.protein.sequences.v11.5.fa",
		        "enrichment_path": "525257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525257.protein.info.v11.5.txt",
		        "node_list_path": "525257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBlochmanniaVaferStrBvaf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blochmannia vafer str. BVAF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBlochmanniaVaferStrBvaf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "859654.protein.sequences.v11.5.fa",
		        "enrichment_path": "859654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "859654.protein.info.v11.5.txt",
		        "node_list_path": "859654.protein.complete.v11.5.txt"
		    }
		]
    )()

def WoodsholeaMaritima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Woodsholea maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WoodsholeaMaritima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123503.protein.info.v11.5.txt",
		        "node_list_path": "1123503.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusMicroti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus microti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusMicroti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "569857.protein.sequences.v11.5.fa",
		        "enrichment_path": "569857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "569857.protein.info.v11.5.txt",
		        "node_list_path": "569857.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumRifcsplowo202Full6214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RIFCSPLOWO2_02_FULL_62_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumRifcsplowo202Full6214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801717.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801717.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801717.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801717.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801717.protein.info.v11.5.txt",
		        "node_list_path": "1801717.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801717.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNanopusillusAcidilobiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nanopusillus acidilobi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNanopusillusAcidilobiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577684.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577684.protein.info.v11.5.txt",
		        "node_list_path": "1577684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OgataeaParapolymorpha(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ogataea parapolymorpha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OgataeaParapolymorpha", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005962.protein.info.v11.5.txt",
		        "node_list_path": "1005962.protein.complete.v11.5.txt"
		    }
		]
    )()

def AchromobacterSpDh1fCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter sp. DH1f Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterSpDh1fCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397275.protein.info.v11.5.txt",
		        "node_list_path": "1397275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpUnc451mf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNC451MF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpUnc451mf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449063.protein.info.v11.5.txt",
		        "node_list_path": "1449063.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full4622Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_46_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full4622Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798475.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798475.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798475.protein.info.v11.5.txt",
		        "node_list_path": "1798475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusSpB2m1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. B2M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusSpB2m1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1490052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1490052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1490052.clusters.proteins.v11.5.txt",
		        "sequence_path": "1490052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1490052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1490052.protein.info.v11.5.txt",
		        "node_list_path": "1490052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1490052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KnoelliaSinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Knoellia sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KnoelliaSinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385520.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385520.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385520.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385520.protein.info.v11.5.txt",
		        "node_list_path": "1385520.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385520.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpSpb78(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. SPB78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpSpb78", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "591157.protein.sequences.v11.5.fa",
		        "enrichment_path": "591157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591157.protein.info.v11.5.txt",
		        "node_list_path": "591157.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSputi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sputi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSputi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111729.protein.info.v11.5.txt",
		        "node_list_path": "1111729.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallaecimonasPentaromativorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallaecimonas pentaromativorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallaecimonasPentaromativorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "584787.protein.sequences.v11.5.fa",
		        "enrichment_path": "584787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "584787.protein.info.v11.5.txt",
		        "node_list_path": "584787.protein.complete.v11.5.txt"
		    }
		]
    )()

def TursiopsTruncatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tursiops truncatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TursiopsTruncatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9739.clusters.proteins.v11.5.txt",
		        "sequence_path": "9739.protein.sequences.v11.5.fa",
		        "enrichment_path": "9739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9739.protein.info.v11.5.txt",
		        "node_list_path": "9739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesScabiei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces scabiei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesScabiei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "680198.protein.sequences.v11.5.fa",
		        "enrichment_path": "680198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "680198.protein.info.v11.5.txt",
		        "node_list_path": "680198.protein.complete.v11.5.txt"
		    }
		]
    )()

def NecatorAmericanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Necator americanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NecatorAmericanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "51031.protein.sequences.v11.5.fa",
		        "enrichment_path": "51031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51031.protein.info.v11.5.txt",
		        "node_list_path": "51031.protein.complete.v11.5.txt"
		    }
		]
    )()

def BotrytisPorri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Botrytis porri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotrytisPorri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "87229.protein.sequences.v11.5.fa",
		        "enrichment_path": "87229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "87229.protein.info.v11.5.txt",
		        "node_list_path": "87229.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraMaduraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura madurae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraMaduraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1394178.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1394178.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1394178.clusters.proteins.v11.5.txt",
		        "sequence_path": "1394178.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394178.protein.info.v11.5.txt",
		        "node_list_path": "1394178.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1394178.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpOralTaxon920Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 920 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpOralTaxon920Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884263.protein.info.v11.5.txt",
		        "node_list_path": "1884263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag217Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag217Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262779.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262779.protein.info.v11.5.txt",
		        "node_list_path": "1262779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasBoliviensisLc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas boliviensis LC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasBoliviensisLc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1072583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1072583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1072583.protein.info.v11.5.txt",
		        "node_list_path": "1072583.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpGm95(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. GM95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpGm95", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881043.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881043.protein.info.v11.5.txt",
		        "node_list_path": "1881043.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumVe20209Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumVe20209Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232447.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232447.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232447.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232447.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232447.protein.info.v11.5.txt",
		        "node_list_path": "1232447.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232447.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HanseniasporaOsmophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hanseniaspora osmophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HanseniasporaOsmophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56408.clusters.proteins.v11.5.txt",
		        "sequence_path": "56408.protein.sequences.v11.5.fa",
		        "enrichment_path": "56408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56408.protein.info.v11.5.txt",
		        "node_list_path": "56408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPlecoglossicidaNbrc103162Dsm15088(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas plecoglossicida NBRC 103162 DSM 15088 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPlecoglossicidaNbrc103162Dsm15088", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1215115.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215115.protein.info.v11.5.txt",
		        "node_list_path": "1215115.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaPseudoobscuraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila pseudoobscura Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaPseudoobscuraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7237.clusters.proteins.v11.5.txt",
		        "sequence_path": "7237.protein.sequences.v11.5.fa",
		        "enrichment_path": "7237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7237.protein.info.v11.5.txt",
		        "node_list_path": "7237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpsilonproteobacteriaBacteriumTcs49(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epsilonproteobacteria bacterium tcs-49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpsilonproteobacteriaBacteriumTcs49", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1742865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742865.protein.info.v11.5.txt",
		        "node_list_path": "1742865.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConiellaLustricolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coniella lustricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConiellaLustricolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2025994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2025994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2025994.clusters.proteins.v11.5.txt",
		        "sequence_path": "2025994.protein.sequences.v11.5.fa",
		        "enrichment_path": "2025994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2025994.protein.info.v11.5.txt",
		        "node_list_path": "2025994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2025994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NannocystisExedensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nannocystis exedens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NannocystisExedensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "54.clusters.info.v11.5.txt",
		        "cluster_tree_path": "54.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "54.clusters.proteins.v11.5.txt",
		        "sequence_path": "54.protein.sequences.v11.5.fa",
		        "enrichment_path": "54.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54.protein.info.v11.5.txt",
		        "node_list_path": "54.cluster.nodes.v11.5.txt",
		        "edge_list_path": "54.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanothermobacterMarburgensisStrMarburgCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter marburgensis str. Marburg Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermobacterMarburgensisStrMarburgCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "79929.clusters.info.v11.5.txt",
		        "cluster_tree_path": "79929.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "79929.clusters.proteins.v11.5.txt",
		        "sequence_path": "79929.protein.sequences.v11.5.fa",
		        "enrichment_path": "79929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79929.protein.info.v11.5.txt",
		        "node_list_path": "79929.cluster.nodes.v11.5.txt",
		        "edge_list_path": "79929.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusColeohominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus coleohominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusColeohominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575594.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575594.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575594.clusters.proteins.v11.5.txt",
		        "sequence_path": "575594.protein.sequences.v11.5.fa",
		        "enrichment_path": "575594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575594.protein.info.v11.5.txt",
		        "node_list_path": "575594.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575594.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionispiraArborisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionispira arboris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionispiraArborisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84035.clusters.proteins.v11.5.txt",
		        "sequence_path": "84035.protein.sequences.v11.5.fa",
		        "enrichment_path": "84035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84035.protein.info.v11.5.txt",
		        "node_list_path": "84035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaOculiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma oculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaOculiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35623.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35623.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35623.clusters.proteins.v11.5.txt",
		        "sequence_path": "35623.protein.sequences.v11.5.fa",
		        "enrichment_path": "35623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35623.protein.info.v11.5.txt",
		        "node_list_path": "35623.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35623.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DasypusNovemcinctusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dasypus novemcinctus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DasypusNovemcinctusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9361.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9361.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9361.clusters.proteins.v11.5.txt",
		        "sequence_path": "9361.protein.sequences.v11.5.fa",
		        "enrichment_path": "9361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9361.protein.info.v11.5.txt",
		        "node_list_path": "9361.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9361.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpW2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. W2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpW2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203261.protein.info.v11.5.txt",
		        "node_list_path": "1203261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumMesoamericanumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium mesoamericanum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumMesoamericanumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211777.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211777.protein.info.v11.5.txt",
		        "node_list_path": "1211777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotorhabdusThracensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photorhabdus thracensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotorhabdusThracensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "230089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "230089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "230089.clusters.proteins.v11.5.txt",
		        "sequence_path": "230089.protein.sequences.v11.5.fa",
		        "enrichment_path": "230089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "230089.protein.info.v11.5.txt",
		        "node_list_path": "230089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "230089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasJaponicaNbrc103040Dsm22348(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas japonica NBRC 103040 DSM 22348 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasJaponicaNbrc103040Dsm22348", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1215104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215104.protein.info.v11.5.txt",
		        "node_list_path": "1215104.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusFabifermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fabifermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFabifermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1400520.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1400520.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1400520.clusters.proteins.v11.5.txt",
		        "sequence_path": "1400520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400520.protein.info.v11.5.txt",
		        "node_list_path": "1400520.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1400520.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumTaeanense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium taeanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumTaeanense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "311334.protein.sequences.v11.5.fa",
		        "enrichment_path": "311334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311334.protein.info.v11.5.txt",
		        "node_list_path": "311334.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanobacteriumSpIppasB1200Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanobacterium sp. IPPAS B-1200 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobacteriumSpIppasB1200Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1562720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1562720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1562720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1562720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1562720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1562720.protein.info.v11.5.txt",
		        "node_list_path": "1562720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1562720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumGw2011Gwe24058(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_40_58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24058", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618991.protein.info.v11.5.txt",
		        "node_list_path": "1618991.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcaceaeBacteriumW5053Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium W5053 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcaceaeBacteriumW5053Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321784.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321784.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321784.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321784.protein.info.v11.5.txt",
		        "node_list_path": "1321784.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321784.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpY57(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Y57 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpY57", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "334801.protein.sequences.v11.5.fa",
		        "enrichment_path": "334801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334801.protein.info.v11.5.txt",
		        "node_list_path": "334801.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldithrixAbyssi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldithrix abyssi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldithrixAbyssi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "880073.protein.sequences.v11.5.fa",
		        "enrichment_path": "880073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880073.protein.info.v11.5.txt",
		        "node_list_path": "880073.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseburiaIntestinalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseburia intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaIntestinalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "166486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "166486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "166486.clusters.proteins.v11.5.txt",
		        "sequence_path": "166486.protein.sequences.v11.5.fa",
		        "enrichment_path": "166486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "166486.protein.info.v11.5.txt",
		        "node_list_path": "166486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "166486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusTaiwanensisDsm21401(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus taiwanensis DSM 21401 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusTaiwanensisDsm21401", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423809.protein.info.v11.5.txt",
		        "node_list_path": "1423809.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesMediterraneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces mediterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesMediterraneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871028.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871028.protein.info.v11.5.txt",
		        "node_list_path": "1871028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo212Full4413b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_12_FULL_44_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo212Full4413b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802711.protein.info.v11.5.txt",
		        "node_list_path": "1802711.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumGw2011Gwa24314(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA2_43_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa24314", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618443.protein.info.v11.5.txt",
		        "node_list_path": "1618443.protein.complete.v11.5.txt"
		    }
		]
    )()

def KazachstaniaSaulgeensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania saulgeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KazachstaniaSaulgeensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1789683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1789683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1789683.clusters.proteins.v11.5.txt",
		        "sequence_path": "1789683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1789683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1789683.protein.info.v11.5.txt",
		        "node_list_path": "1789683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1789683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterAerogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter aerogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterAerogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1028307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028307.protein.info.v11.5.txt",
		        "node_list_path": "1028307.protein.complete.v11.5.txt"
		    }
		]
    )()

def GloeocapsaSpPcc7428Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gloeocapsa sp. PCC7428 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeocapsaSpPcc7428Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173026.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173026.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173026.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173026.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173026.protein.info.v11.5.txt",
		        "node_list_path": "1173026.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173026.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PasteurellaceaeBacterium15036681(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurellaceae bacterium 15-036681 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaceaeBacterium15036681", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1924934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1924934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1924934.protein.info.v11.5.txt",
		        "node_list_path": "1924934.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrancourtellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drancourtella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrancourtellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1632013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1632013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1632013.protein.info.v11.5.txt",
		        "node_list_path": "1632013.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfifellaPfennigii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Afifella pfennigii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfifellaPfennigii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120956.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120956.protein.info.v11.5.txt",
		        "node_list_path": "1120956.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaMarcescensFgi94Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia marcescens FGI94 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaMarcescensFgi94Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1249634.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1249634.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1249634.clusters.proteins.v11.5.txt",
		        "sequence_path": "1249634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249634.protein.info.v11.5.txt",
		        "node_list_path": "1249634.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1249634.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSpWkb8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sp. wkB8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSpWkb8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1545702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545702.protein.info.v11.5.txt",
		        "node_list_path": "1545702.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaimiriBoliviensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saimiri boliviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaimiriBoliviensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "27679.protein.sequences.v11.5.fa",
		        "enrichment_path": "27679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27679.protein.info.v11.5.txt",
		        "node_list_path": "27679.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusBrevisAtcc367Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus brevis ATCC367 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBrevisAtcc367Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "387344.clusters.info.v11.5.txt",
		        "cluster_tree_path": "387344.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "387344.clusters.proteins.v11.5.txt",
		        "sequence_path": "387344.protein.sequences.v11.5.fa",
		        "enrichment_path": "387344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "387344.protein.info.v11.5.txt",
		        "node_list_path": "387344.cluster.nodes.v11.5.txt",
		        "edge_list_path": "387344.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPollutisoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pollutisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPollutisoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1610489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1610489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1610489.clusters.proteins.v11.5.txt",
		        "sequence_path": "1610489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1610489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1610489.protein.info.v11.5.txt",
		        "node_list_path": "1610489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1610489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LoktanellaFryxellensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella fryxellensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaFryxellensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "245187.protein.sequences.v11.5.fa",
		        "enrichment_path": "245187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "245187.protein.info.v11.5.txt",
		        "node_list_path": "245187.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852365.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852365.protein.info.v11.5.txt",
		        "node_list_path": "1852365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3713b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_37_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3713b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802035.protein.info.v11.5.txt",
		        "node_list_path": "1802035.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExophialaOligospermaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exophiala oligosperma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaOligospermaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "215243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "215243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "215243.clusters.proteins.v11.5.txt",
		        "sequence_path": "215243.protein.sequences.v11.5.fa",
		        "enrichment_path": "215243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215243.protein.info.v11.5.txt",
		        "node_list_path": "215243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "215243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaPlymuthicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia plymuthica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaPlymuthicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "82996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "82996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "82996.clusters.proteins.v11.5.txt",
		        "sequence_path": "82996.protein.sequences.v11.5.fa",
		        "enrichment_path": "82996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82996.protein.info.v11.5.txt",
		        "node_list_path": "82996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "82996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacterTundripaludum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacter tundripaludum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacterTundripaludum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "697282.protein.sequences.v11.5.fa",
		        "enrichment_path": "697282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "697282.protein.info.v11.5.txt",
		        "node_list_path": "697282.protein.complete.v11.5.txt"
		    }
		]
    )()

def EhrlichiaCanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EhrlichiaCanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "269484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "269484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "269484.clusters.proteins.v11.5.txt",
		        "sequence_path": "269484.protein.sequences.v11.5.fa",
		        "enrichment_path": "269484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269484.protein.info.v11.5.txt",
		        "node_list_path": "269484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "269484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat28004(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-28004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat28004", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1679165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679165.protein.info.v11.5.txt",
		        "node_list_path": "1679165.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaSpT9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichinella sp. T9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaSpT9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "181606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "181606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "181606.clusters.proteins.v11.5.txt",
		        "sequence_path": "181606.protein.sequences.v11.5.fa",
		        "enrichment_path": "181606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "181606.protein.info.v11.5.txt",
		        "node_list_path": "181606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "181606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5921(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_59_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5921", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798500.protein.info.v11.5.txt",
		        "node_list_path": "1798500.protein.complete.v11.5.txt"
		    }
		]
    )()

def AllofustisSeminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Allofustis seminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllofustisSeminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120978.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120978.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120978.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120978.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120978.protein.info.v11.5.txt",
		        "node_list_path": "1120978.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120978.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumLarrymoorei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium larrymoorei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLarrymoorei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336249.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336249.protein.info.v11.5.txt",
		        "node_list_path": "1336249.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeganemaPerideroedesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meganema perideroedes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeganemaPerideroedesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122218.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122218.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122218.protein.info.v11.5.txt",
		        "node_list_path": "1122218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaParvumStrIndianaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma parvum str. Indiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaParvumStrIndianaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1403316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1403316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1403316.clusters.proteins.v11.5.txt",
		        "sequence_path": "1403316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403316.protein.info.v11.5.txt",
		        "node_list_path": "1403316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1403316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag192Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:192 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag192Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262883.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262883.protein.info.v11.5.txt",
		        "node_list_path": "1262883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSanxanigenens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sanxanigenens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSanxanigenens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123269.protein.info.v11.5.txt",
		        "node_list_path": "1123269.protein.complete.v11.5.txt"
		    }
		]
    )()

def KamptonemaFormosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kamptonema formosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KamptonemaFormosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "402777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "402777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "402777.clusters.proteins.v11.5.txt",
		        "sequence_path": "402777.protein.sequences.v11.5.fa",
		        "enrichment_path": "402777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402777.protein.info.v11.5.txt",
		        "node_list_path": "402777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "402777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpMt2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpMt2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499680.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499680.protein.info.v11.5.txt",
		        "node_list_path": "1499680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTachikawaeaGelatinosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tachikawaea gelatinosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTachikawaeaGelatinosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410383.protein.info.v11.5.txt",
		        "node_list_path": "1410383.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioFrigidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio frigidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioFrigidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121447.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121447.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121447.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121447.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121447.protein.info.v11.5.txt",
		        "node_list_path": "1121447.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121447.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasJatrophae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas jatrophae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasJatrophae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1166337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166337.protein.info.v11.5.txt",
		        "node_list_path": "1166337.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomycesKudriavzeviiIfo1802Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomyces kudriavzevii IFO 1802 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomycesKudriavzeviiIfo1802Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "226230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "226230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "226230.clusters.proteins.v11.5.txt",
		        "sequence_path": "226230.protein.sequences.v11.5.fa",
		        "enrichment_path": "226230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226230.protein.info.v11.5.txt",
		        "node_list_path": "226230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "226230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CetobacteriumSpZor0034Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cetobacterium sp. ZOR0034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CetobacteriumSpZor0034Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1339239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1339239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1339239.clusters.proteins.v11.5.txt",
		        "sequence_path": "1339239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1339239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1339239.protein.info.v11.5.txt",
		        "node_list_path": "1339239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1339239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PannonibacterPhragmitetusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pannonibacter phragmitetus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PannonibacterPhragmitetusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122929.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122929.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122929.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122929.protein.info.v11.5.txt",
		        "node_list_path": "1122929.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122929.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BilophilaWadsworthiaAtcc49260(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia ATCC49260 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BilophilaWadsworthiaAtcc49260", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408428.protein.info.v11.5.txt",
		        "node_list_path": "1408428.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMargulisbacteriaBacteriumGwd239127(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Margulisbacteria bacterium GWD2_39_127 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMargulisbacteriaBacteriumGwd239127", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817871.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817871.protein.info.v11.5.txt",
		        "node_list_path": "1817871.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumPhsc20c1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium PHSC20C1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumPhsc20c1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "312284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "312284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "312284.clusters.proteins.v11.5.txt",
		        "sequence_path": "312284.protein.sequences.v11.5.fa",
		        "enrichment_path": "312284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "312284.protein.info.v11.5.txt",
		        "node_list_path": "312284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "312284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseofuscusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseofuscus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseofuscusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "146922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "146922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "146922.clusters.proteins.v11.5.txt",
		        "sequence_path": "146922.protein.sequences.v11.5.fa",
		        "enrichment_path": "146922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146922.protein.info.v11.5.txt",
		        "node_list_path": "146922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "146922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumRiegelii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium riegelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumRiegelii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "156976.protein.sequences.v11.5.fa",
		        "enrichment_path": "156976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156976.protein.info.v11.5.txt",
		        "node_list_path": "156976.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMicrarchaeotaArchaeonCg1025541(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_55_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1025541", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805251.protein.info.v11.5.txt",
		        "node_list_path": "1805251.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthobacteraceaeBacterium501b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthobacteraceae bacterium 501b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthobacteraceaeBacterium501b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1168059.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168059.protein.info.v11.5.txt",
		        "node_list_path": "1168059.protein.complete.v11.5.txt"
		    }
		]
    )()

def GramellaSpMar2010147Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gramella sp. MAR_2010_147 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaSpMar2010147Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1250205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1250205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1250205.clusters.proteins.v11.5.txt",
		        "sequence_path": "1250205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250205.protein.info.v11.5.txt",
		        "node_list_path": "1250205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1250205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldimicrobiumThiodismutansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldimicrobium thiodismutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldimicrobiumThiodismutansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1653476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1653476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1653476.clusters.proteins.v11.5.txt",
		        "sequence_path": "1653476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1653476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1653476.protein.info.v11.5.txt",
		        "node_list_path": "1653476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1653476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaWillistoni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila willistoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaWillistoni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7260.protein.sequences.v11.5.fa",
		        "enrichment_path": "7260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7260.protein.info.v11.5.txt",
		        "node_list_path": "7260.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrobacterWinogradskyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrobacter winogradskyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrobacterWinogradskyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "323098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "323098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "323098.clusters.proteins.v11.5.txt",
		        "sequence_path": "323098.protein.sequences.v11.5.fa",
		        "enrichment_path": "323098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323098.protein.info.v11.5.txt",
		        "node_list_path": "323098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "323098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KushneriaAvicenniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kushneria avicenniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KushneriaAvicenniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "402385.protein.sequences.v11.5.fa",
		        "enrichment_path": "402385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402385.protein.info.v11.5.txt",
		        "node_list_path": "402385.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterHimalayensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter himalayensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterHimalayensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1591088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1591088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1591088.clusters.proteins.v11.5.txt",
		        "sequence_path": "1591088.protein.sequences.v11.5.fa",
		        "enrichment_path": "1591088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1591088.protein.info.v11.5.txt",
		        "node_list_path": "1591088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1591088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumNematocidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium nematocida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumNematocidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1513896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1513896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1513896.clusters.proteins.v11.5.txt",
		        "sequence_path": "1513896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1513896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1513896.protein.info.v11.5.txt",
		        "node_list_path": "1513896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1513896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusSp29(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus sp. 2.9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusSp29", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577051.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577051.protein.info.v11.5.txt",
		        "node_list_path": "1577051.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusElgiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus elgii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusElgiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1007103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1007103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1007103.clusters.proteins.v11.5.txt",
		        "sequence_path": "1007103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007103.protein.info.v11.5.txt",
		        "node_list_path": "1007103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1007103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumSp174Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium sp. 174 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumSp174Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "208596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "208596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "208596.clusters.proteins.v11.5.txt",
		        "sequence_path": "208596.protein.sequences.v11.5.fa",
		        "enrichment_path": "208596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208596.protein.info.v11.5.txt",
		        "node_list_path": "208596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "208596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusFumigatusAf293(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus fumigatus Af293 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusFumigatusAf293", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "330879.protein.sequences.v11.5.fa",
		        "enrichment_path": "330879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "330879.protein.info.v11.5.txt",
		        "node_list_path": "330879.protein.complete.v11.5.txt"
		    }
		]
    )()

def EremotheciumCymbalariae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium cymbalariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremotheciumCymbalariae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45285.protein.sequences.v11.5.fa",
		        "enrichment_path": "45285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45285.protein.info.v11.5.txt",
		        "node_list_path": "45285.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaEquifetale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma equifetale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaEquifetale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408415.protein.info.v11.5.txt",
		        "node_list_path": "1408415.protein.complete.v11.5.txt"
		    }
		]
    )()

def DickeyaDadantii3937Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii 3937 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaDadantii3937Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "198628.clusters.info.v11.5.txt",
		        "cluster_tree_path": "198628.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "198628.clusters.proteins.v11.5.txt",
		        "sequence_path": "198628.protein.sequences.v11.5.fa",
		        "enrichment_path": "198628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198628.protein.info.v11.5.txt",
		        "node_list_path": "198628.cluster.nodes.v11.5.txt",
		        "edge_list_path": "198628.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusMediterraneensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus mediterraneensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusMediterraneensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1870984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1870984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1870984.clusters.proteins.v11.5.txt",
		        "sequence_path": "1870984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870984.protein.info.v11.5.txt",
		        "node_list_path": "1870984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1870984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasMaltophiliaPml168Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia PML168 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasMaltophiliaPml168Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118235.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118235.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118235.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118235.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118235.protein.info.v11.5.txt",
		        "node_list_path": "1118235.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118235.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumGbs1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium GBS-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumGbs1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1662110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662110.protein.info.v11.5.txt",
		        "node_list_path": "1662110.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBeckwithbacteriaBacteriumRifcsphigho212Full4717Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium RIFCSPHIGHO2_12_FULL_47_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumRifcsphigho212Full4717Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797460.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797460.protein.info.v11.5.txt",
		        "node_list_path": "1797460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliivibrioSalmonicidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliivibrio salmonicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliivibrioSalmonicidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316275.clusters.proteins.v11.5.txt",
		        "sequence_path": "316275.protein.sequences.v11.5.fa",
		        "enrichment_path": "316275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316275.protein.info.v11.5.txt",
		        "node_list_path": "316275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FilamentousCyanobacterium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return filamentous cyanobacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FilamentousCyanobacterium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1128427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128427.protein.info.v11.5.txt",
		        "node_list_path": "1128427.protein.complete.v11.5.txt"
		    }
		]
    )()

def HamiltosporidiumMagnivoraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hamiltosporidium magnivora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HamiltosporidiumMagnivoraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "148818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "148818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "148818.clusters.proteins.v11.5.txt",
		        "sequence_path": "148818.protein.sequences.v11.5.fa",
		        "enrichment_path": "148818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "148818.protein.info.v11.5.txt",
		        "node_list_path": "148818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "148818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusYunnanensisNbrc103083(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus yunnanensis NBRC 103083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusYunnanensisNbrc103083", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219029.protein.info.v11.5.txt",
		        "node_list_path": "1219029.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpMku1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. MKU1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpMku1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1745182.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1745182.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1745182.clusters.proteins.v11.5.txt",
		        "sequence_path": "1745182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1745182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1745182.protein.info.v11.5.txt",
		        "node_list_path": "1745182.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1745182.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DraconibacteriumSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Draconibacterium sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DraconibacteriumSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1544798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1544798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1544798.protein.info.v11.5.txt",
		        "node_list_path": "1544798.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhaeobacterInhibensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter inhibens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterInhibensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391619.clusters.proteins.v11.5.txt",
		        "sequence_path": "391619.protein.sequences.v11.5.fa",
		        "enrichment_path": "391619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391619.protein.info.v11.5.txt",
		        "node_list_path": "391619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NoviherbaspirillumAutotrophicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Noviherbaspirillum autotrophicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NoviherbaspirillumAutotrophicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "709839.clusters.info.v11.5.txt",
		        "cluster_tree_path": "709839.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "709839.clusters.proteins.v11.5.txt",
		        "sequence_path": "709839.protein.sequences.v11.5.fa",
		        "enrichment_path": "709839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709839.protein.info.v11.5.txt",
		        "node_list_path": "709839.cluster.nodes.v11.5.txt",
		        "edge_list_path": "709839.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PteropusAlectoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pteropus alecto Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PteropusAlectoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9402.clusters.proteins.v11.5.txt",
		        "sequence_path": "9402.protein.sequences.v11.5.fa",
		        "enrichment_path": "9402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9402.protein.info.v11.5.txt",
		        "node_list_path": "9402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurivirgaCaldicuralii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurivirga caldicuralii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurivirgaCaldicuralii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "364032.protein.sequences.v11.5.fa",
		        "enrichment_path": "364032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "364032.protein.info.v11.5.txt",
		        "node_list_path": "364032.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaSpF0581Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. F0581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaSpF0581Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321774.protein.info.v11.5.txt",
		        "node_list_path": "1321774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasAmylolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas amylolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasAmylolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1859457.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1859457.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1859457.clusters.proteins.v11.5.txt",
		        "sequence_path": "1859457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1859457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1859457.protein.info.v11.5.txt",
		        "node_list_path": "1859457.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1859457.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusSpMarseilleP2143(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. Marseille-P2143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusSpMarseilleP2143", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1745712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1745712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1745712.protein.info.v11.5.txt",
		        "node_list_path": "1745712.protein.complete.v11.5.txt"
		    }
		]
    )()

def EudoraeaAdriatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eudoraea adriatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EudoraeaAdriatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121875.protein.info.v11.5.txt",
		        "node_list_path": "1121875.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemonchusPlacei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemonchus placei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemonchusPlacei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6290.protein.sequences.v11.5.fa",
		        "enrichment_path": "6290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6290.protein.info.v11.5.txt",
		        "node_list_path": "6290.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusTellurisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus telluris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusTellurisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1190417.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1190417.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1190417.clusters.proteins.v11.5.txt",
		        "sequence_path": "1190417.protein.sequences.v11.5.fa",
		        "enrichment_path": "1190417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1190417.protein.info.v11.5.txt",
		        "node_list_path": "1190417.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1190417.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynchytriumMicrobalumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synchytrium microbalum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynchytriumMicrobalumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1806994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1806994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1806994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1806994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806994.protein.info.v11.5.txt",
		        "node_list_path": "1806994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1806994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FischerellaSpNies3754Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fischerella sp. NIES-3754 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FischerellaSpNies3754Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752063.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752063.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752063.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752063.protein.info.v11.5.txt",
		        "node_list_path": "1752063.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752063.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusThermophilusHb27Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus HB27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusThermophilusHb27Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "262724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "262724.clusters.proteins.v11.5.txt",
		        "sequence_path": "262724.protein.sequences.v11.5.fa",
		        "enrichment_path": "262724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262724.protein.info.v11.5.txt",
		        "node_list_path": "262724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "262724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassospiraAlkalitolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira alkalitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraAlkalitolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293890.protein.info.v11.5.txt",
		        "node_list_path": "1293890.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPolymyxaSc2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa SC2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPolymyxaSc2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "886882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "886882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "886882.clusters.proteins.v11.5.txt",
		        "sequence_path": "886882.protein.sequences.v11.5.fa",
		        "enrichment_path": "886882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "886882.protein.info.v11.5.txt",
		        "node_list_path": "886882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "886882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpNcr5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. NCR5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpNcr5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1978342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978342.protein.info.v11.5.txt",
		        "node_list_path": "1978342.protein.complete.v11.5.txt"
		    }
		]
    )()

def LacimicrobiumAlkaliphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lacimicrobium alkaliphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacimicrobiumAlkaliphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1526571.protein.sequences.v11.5.fa",
		        "enrichment_path": "1526571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1526571.protein.info.v11.5.txt",
		        "node_list_path": "1526571.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyramidobacterSpC128(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyramidobacter sp. C12-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyramidobacterSpC128", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1943580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1943580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1943580.protein.info.v11.5.txt",
		        "node_list_path": "1943580.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChoanephoraCucurbitarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Choanephora cucurbitarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChoanephoraCucurbitarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "101091.clusters.info.v11.5.txt",
		        "cluster_tree_path": "101091.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "101091.clusters.proteins.v11.5.txt",
		        "sequence_path": "101091.protein.sequences.v11.5.fa",
		        "enrichment_path": "101091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101091.protein.info.v11.5.txt",
		        "node_list_path": "101091.cluster.nodes.v11.5.txt",
		        "edge_list_path": "101091.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CajanusCajan(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cajanus cajan graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CajanusCajan", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3821.protein.sequences.v11.5.fa",
		        "enrichment_path": "3821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3821.protein.info.v11.5.txt",
		        "node_list_path": "3821.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasHankookensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas hankookensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasHankookensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "563996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "563996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "563996.clusters.proteins.v11.5.txt",
		        "sequence_path": "563996.protein.sequences.v11.5.fa",
		        "enrichment_path": "563996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563996.protein.info.v11.5.txt",
		        "node_list_path": "563996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "563996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHtcc1062(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC1062 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHtcc1062", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "335992.protein.sequences.v11.5.fa",
		        "enrichment_path": "335992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335992.protein.info.v11.5.txt",
		        "node_list_path": "335992.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexusAurantiacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexus aurantiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexusAurantiacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "324602.protein.sequences.v11.5.fa",
		        "enrichment_path": "324602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "324602.protein.info.v11.5.txt",
		        "node_list_path": "324602.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldivirgaSpMu80(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldivirga sp. MU80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldivirgaSpMu80", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1650354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1650354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1650354.protein.info.v11.5.txt",
		        "node_list_path": "1650354.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumJdfr80(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr80", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935110.protein.info.v11.5.txt",
		        "node_list_path": "1935110.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrientiaTsutsugamushiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Orientia tsutsugamushi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrientiaTsutsugamushiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "357244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "357244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "357244.clusters.proteins.v11.5.txt",
		        "sequence_path": "357244.protein.sequences.v11.5.fa",
		        "enrichment_path": "357244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357244.protein.info.v11.5.txt",
		        "node_list_path": "357244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "357244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlligatorMississippiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alligator mississippiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlligatorMississippiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8496.clusters.proteins.v11.5.txt",
		        "sequence_path": "8496.protein.sequences.v11.5.fa",
		        "enrichment_path": "8496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8496.protein.info.v11.5.txt",
		        "node_list_path": "8496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaPsychrophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaPsychrophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "225848.protein.sequences.v11.5.fa",
		        "enrichment_path": "225848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225848.protein.info.v11.5.txt",
		        "node_list_path": "225848.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasKnackmussii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas knackmussii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasKnackmussii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1301098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1301098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1301098.protein.info.v11.5.txt",
		        "node_list_path": "1301098.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag299Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag299Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262792.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262792.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262792.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262792.protein.info.v11.5.txt",
		        "node_list_path": "1262792.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262792.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KorarchaeumCryptofilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Korarchaeum cryptofilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KorarchaeumCryptofilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "374847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "374847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "374847.clusters.proteins.v11.5.txt",
		        "sequence_path": "374847.protein.sequences.v11.5.fa",
		        "enrichment_path": "374847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "374847.protein.info.v11.5.txt",
		        "node_list_path": "374847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "374847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PacificibacterMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pacificibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PacificibacterMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658057.clusters.proteins.v11.5.txt",
		        "sequence_path": "658057.protein.sequences.v11.5.fa",
		        "enrichment_path": "658057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658057.protein.info.v11.5.txt",
		        "node_list_path": "658057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKerfeldbacteriaBacteriumRifoxya2Full3824Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFOXYA2_FULL_38_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifoxya2Full3824Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798546.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798546.protein.info.v11.5.txt",
		        "node_list_path": "1798546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpKmsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. KMS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpKmsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "189918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "189918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "189918.clusters.proteins.v11.5.txt",
		        "sequence_path": "189918.protein.sequences.v11.5.fa",
		        "enrichment_path": "189918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189918.protein.info.v11.5.txt",
		        "node_list_path": "189918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "189918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarmoricolaAequoreus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marmoricola aequoreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarmoricolaAequoreus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "397278.protein.sequences.v11.5.fa",
		        "enrichment_path": "397278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397278.protein.info.v11.5.txt",
		        "node_list_path": "397278.protein.complete.v11.5.txt"
		    }
		]
    )()

def PoeciliaLatipinna(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Poecilia latipinna graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PoeciliaLatipinna", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "48699.protein.sequences.v11.5.fa",
		        "enrichment_path": "48699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48699.protein.info.v11.5.txt",
		        "node_list_path": "48699.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo202Full6726Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_02_FULL_67_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202Full6726Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797492.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797492.protein.info.v11.5.txt",
		        "node_list_path": "1797492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusSp2g(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. 2G graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSp2g", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1570939.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570939.protein.info.v11.5.txt",
		        "node_list_path": "1570939.protein.complete.v11.5.txt"
		    }
		]
    )()

def NonomuraeaCandidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea candida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaCandidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "359159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "359159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "359159.clusters.proteins.v11.5.txt",
		        "sequence_path": "359159.protein.sequences.v11.5.fa",
		        "enrichment_path": "359159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "359159.protein.info.v11.5.txt",
		        "node_list_path": "359159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "359159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenoanaerobacteriumSaccharovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenoanaerobacterium saccharovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenoanaerobacteriumSaccharovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "474960.protein.sequences.v11.5.fa",
		        "enrichment_path": "474960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "474960.protein.info.v11.5.txt",
		        "node_list_path": "474960.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpJs42Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. JS42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpJs42Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "232721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "232721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "232721.clusters.proteins.v11.5.txt",
		        "sequence_path": "232721.protein.sequences.v11.5.fa",
		        "enrichment_path": "232721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "232721.protein.info.v11.5.txt",
		        "node_list_path": "232721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "232721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaeniglutamicibacterAntarcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paeniglutamicibacter antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaeniglutamicibacterAntarcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "494023.protein.sequences.v11.5.fa",
		        "enrichment_path": "494023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "494023.protein.info.v11.5.txt",
		        "node_list_path": "494023.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumCucumisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium cucumis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumCucumisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "416016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "416016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "416016.clusters.proteins.v11.5.txt",
		        "sequence_path": "416016.protein.sequences.v11.5.fa",
		        "enrichment_path": "416016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416016.protein.info.v11.5.txt",
		        "node_list_path": "416016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "416016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRbg163611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_36_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg163611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802481.protein.info.v11.5.txt",
		        "node_list_path": "1802481.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkelbacteriaBacteriumRifcsphigho212Full369(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFCSPHIGHO2_12_FULL_36_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifcsphigho212Full369", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797469.protein.info.v11.5.txt",
		        "node_list_path": "1797469.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumMedpeSwsndG2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium MedPE-SWsnd-G2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumMedpeSwsndG2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1860095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860095.protein.info.v11.5.txt",
		        "node_list_path": "1860095.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867008(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867008", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1659202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659202.protein.info.v11.5.txt",
		        "node_list_path": "1659202.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaOralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28134.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28134.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28134.clusters.proteins.v11.5.txt",
		        "sequence_path": "28134.protein.sequences.v11.5.fa",
		        "enrichment_path": "28134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28134.protein.info.v11.5.txt",
		        "node_list_path": "28134.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28134.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusNakamurai(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus nakamurai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusNakamurai", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1793963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1793963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1793963.protein.info.v11.5.txt",
		        "node_list_path": "1793963.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwa24512(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_45_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa24512", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797805.protein.info.v11.5.txt",
		        "node_list_path": "1797805.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasMacleodiiBlack(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Black graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasMacleodiiBlack", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1004785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004785.protein.info.v11.5.txt",
		        "node_list_path": "1004785.protein.complete.v11.5.txt"
		    }
		]
    )()

def GranulibacterBethesdensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Granulibacter bethesdensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulibacterBethesdensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391165.clusters.proteins.v11.5.txt",
		        "sequence_path": "391165.protein.sequences.v11.5.fa",
		        "enrichment_path": "391165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391165.protein.info.v11.5.txt",
		        "node_list_path": "391165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusOralisSk255(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis SK255 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOralisSk255", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005704.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005704.protein.info.v11.5.txt",
		        "node_list_path": "1005704.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaTribocorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella tribocorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaTribocorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "382640.protein.sequences.v11.5.fa",
		        "enrichment_path": "382640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "382640.protein.info.v11.5.txt",
		        "node_list_path": "382640.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumEndosymbiontOfPedicinusBadii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Pedicinus badii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumEndosymbiontOfPedicinusBadii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1719126.protein.sequences.v11.5.fa",
		        "enrichment_path": "1719126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1719126.protein.info.v11.5.txt",
		        "node_list_path": "1719126.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumRadiobacter(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium radiobacter graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumRadiobacter", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "311403.protein.sequences.v11.5.fa",
		        "enrichment_path": "311403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311403.protein.info.v11.5.txt",
		        "node_list_path": "311403.protein.complete.v11.5.txt"
		    }
		]
    )()

def RathayibacterOskolensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rathayibacter oskolensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RathayibacterOskolensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1891671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891671.protein.info.v11.5.txt",
		        "node_list_path": "1891671.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumBovisDsm19482Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium bovis DSM 19482 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumBovisDsm19482Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121284.protein.info.v11.5.txt",
		        "node_list_path": "1121284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpMcba15001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpMcba15001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1898731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898731.protein.info.v11.5.txt",
		        "node_list_path": "1898731.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfonisporaThiosulfatigenesDsm11270Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonispora thiosulfatigenes DSM 11270 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonisporaThiosulfatigenesDsm11270Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "656914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "656914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "656914.clusters.proteins.v11.5.txt",
		        "sequence_path": "656914.protein.sequences.v11.5.fa",
		        "enrichment_path": "656914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656914.protein.info.v11.5.txt",
		        "node_list_path": "656914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "656914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydatigeraTaeniaeformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydatigera taeniaeformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydatigeraTaeniaeformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6205.protein.sequences.v11.5.fa",
		        "enrichment_path": "6205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6205.protein.info.v11.5.txt",
		        "node_list_path": "6205.protein.complete.v11.5.txt"
		    }
		]
    )()

def PiscirickettsiaLitoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Piscirickettsia litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiscirickettsiaLitoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1891921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891921.protein.info.v11.5.txt",
		        "node_list_path": "1891921.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesXylophagus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces xylophagus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesXylophagus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "285514.protein.sequences.v11.5.fa",
		        "enrichment_path": "285514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285514.protein.info.v11.5.txt",
		        "node_list_path": "285514.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioBastinii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio bastinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioBastinii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121441.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121441.protein.info.v11.5.txt",
		        "node_list_path": "1121441.protein.complete.v11.5.txt"
		    }
		]
    )()

def FischerellaMuscicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fischerella muscicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FischerellaMuscicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "306281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "306281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "306281.clusters.proteins.v11.5.txt",
		        "sequence_path": "306281.protein.sequences.v11.5.fa",
		        "enrichment_path": "306281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306281.protein.info.v11.5.txt",
		        "node_list_path": "306281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "306281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinokineosporaTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinokineosporaTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "155974.protein.sequences.v11.5.fa",
		        "enrichment_path": "155974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "155974.protein.info.v11.5.txt",
		        "node_list_path": "155974.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinomonasSpSbi22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. SBI22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasSpSbi22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1561206.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1561206.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1561206.clusters.proteins.v11.5.txt",
		        "sequence_path": "1561206.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561206.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561206.protein.info.v11.5.txt",
		        "node_list_path": "1561206.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1561206.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBeckwithbacteriaBacteriumGw2011Gwa24310Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium GW2011_GWA2_43_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumGw2011Gwa24310Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618369.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618369.protein.info.v11.5.txt",
		        "node_list_path": "1618369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaAncashensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella ancashensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaAncashensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1318743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1318743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1318743.clusters.proteins.v11.5.txt",
		        "sequence_path": "1318743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1318743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1318743.protein.info.v11.5.txt",
		        "node_list_path": "1318743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1318743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumAustralicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium australicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumAustralicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "754035.protein.sequences.v11.5.fa",
		        "enrichment_path": "754035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754035.protein.info.v11.5.txt",
		        "node_list_path": "754035.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasHaloplanktisTb64(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis TB64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasHaloplanktisTb64", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1333507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333507.protein.info.v11.5.txt",
		        "node_list_path": "1333507.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumVe20208(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20208 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumVe20208", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232449.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232449.protein.info.v11.5.txt",
		        "node_list_path": "1232449.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonosigaBrevicollisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monosiga brevicollis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosigaBrevicollisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "81824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "81824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "81824.clusters.proteins.v11.5.txt",
		        "sequence_path": "81824.protein.sequences.v11.5.fa",
		        "enrichment_path": "81824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81824.protein.info.v11.5.txt",
		        "node_list_path": "81824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "81824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioPaciniiDsm19139Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio pacinii DSM 19139 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioPaciniiDsm19139Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123494.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123494.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123494.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123494.protein.info.v11.5.txt",
		        "node_list_path": "1123494.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123494.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlegusellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olegusella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlegusellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776381.protein.info.v11.5.txt",
		        "node_list_path": "1776381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalococcusSaccharolyticusDsm5350Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halococcus saccharolyticus DSM 5350 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusSaccharolyticusDsm5350Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227455.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227455.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227455.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227455.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227455.protein.info.v11.5.txt",
		        "node_list_path": "1227455.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227455.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE2479Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2479 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE2479Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834134.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834134.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834134.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834134.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834134.protein.info.v11.5.txt",
		        "node_list_path": "1834134.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834134.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellvibrionaceaeBacterium1162tS0a05(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrionaceae bacterium 1162T.S.0a.05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrionaceaeBacterium1162tS0a05", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1286364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286364.protein.info.v11.5.txt",
		        "node_list_path": "1286364.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerotignumPropionicumDsm1682(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerotignum propionicum DSM 1682 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotignumPropionicumDsm1682", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "991789.protein.sequences.v11.5.fa",
		        "enrichment_path": "991789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "991789.protein.info.v11.5.txt",
		        "node_list_path": "991789.protein.complete.v11.5.txt"
		    }
		]
    )()

def DolosicoccusPaucivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dolosicoccus paucivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DolosicoccusPaucivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84521.clusters.proteins.v11.5.txt",
		        "sequence_path": "84521.protein.sequences.v11.5.fa",
		        "enrichment_path": "84521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84521.protein.info.v11.5.txt",
		        "node_list_path": "84521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VaribaculumCambrienseDora20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum cambriense DORA20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaribaculumCambrienseDora20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1403948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1403948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1403948.clusters.proteins.v11.5.txt",
		        "sequence_path": "1403948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403948.protein.info.v11.5.txt",
		        "node_list_path": "1403948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1403948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium1456faaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 1456FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium1456faaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658655.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658655.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658655.clusters.proteins.v11.5.txt",
		        "sequence_path": "658655.protein.sequences.v11.5.fa",
		        "enrichment_path": "658655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658655.protein.info.v11.5.txt",
		        "node_list_path": "658655.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658655.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasPanacis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas panacis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasPanacis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1560345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1560345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1560345.protein.info.v11.5.txt",
		        "node_list_path": "1560345.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioPutealisDsm16056Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio putealis DSM 16056 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioPutealisDsm16056Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121462.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121462.protein.info.v11.5.txt",
		        "node_list_path": "1121462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesDavawensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces davawensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesDavawensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1214101.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1214101.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1214101.clusters.proteins.v11.5.txt",
		        "sequence_path": "1214101.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214101.protein.info.v11.5.txt",
		        "node_list_path": "1214101.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1214101.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioCarbinoliphilusSubspOakridgensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio carbinoliphilus subsp. oakridgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioCarbinoliphilusSubspOakridgensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "694327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "694327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "694327.clusters.proteins.v11.5.txt",
		        "sequence_path": "694327.protein.sequences.v11.5.fa",
		        "enrichment_path": "694327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694327.protein.info.v11.5.txt",
		        "node_list_path": "694327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "694327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrobacterWinogradskyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrobacter winogradskyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrobacterWinogradskyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "323098.protein.sequences.v11.5.fa",
		        "enrichment_path": "323098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323098.protein.info.v11.5.txt",
		        "node_list_path": "323098.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraNoguchii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira noguchii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraNoguchii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28182.protein.sequences.v11.5.fa",
		        "enrichment_path": "28182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28182.protein.info.v11.5.txt",
		        "node_list_path": "28182.protein.complete.v11.5.txt"
		    }
		]
    )()

def SanguibacterGelidistatuariae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter gelidistatuariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SanguibacterGelidistatuariae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1814289.protein.sequences.v11.5.fa",
		        "enrichment_path": "1814289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1814289.protein.info.v11.5.txt",
		        "node_list_path": "1814289.protein.complete.v11.5.txt"
		    }
		]
    )()

def PectobacteriumSpScc3193Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium sp. SCC3193 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumSpScc3193Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1166016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1166016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1166016.clusters.proteins.v11.5.txt",
		        "sequence_path": "1166016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166016.protein.info.v11.5.txt",
		        "node_list_path": "1166016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1166016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaueraChlorobenzoicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera chlorobenzoica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraChlorobenzoicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "96773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "96773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "96773.clusters.proteins.v11.5.txt",
		        "sequence_path": "96773.protein.sequences.v11.5.fa",
		        "enrichment_path": "96773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "96773.protein.info.v11.5.txt",
		        "node_list_path": "96773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "96773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumRifcsplowo212Full3515Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RIFCSPLOWO2_12_FULL_35_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumRifcsplowo212Full3515Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797364.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797364.protein.info.v11.5.txt",
		        "node_list_path": "1797364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaSimulans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila simulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaSimulans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7240.protein.sequences.v11.5.fa",
		        "enrichment_path": "7240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7240.protein.info.v11.5.txt",
		        "node_list_path": "7240.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumVe20218(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20218 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumVe20218", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232446.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232446.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232446.protein.info.v11.5.txt",
		        "node_list_path": "1232446.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwb13912Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13912Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618574.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618574.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618574.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618574.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618574.protein.info.v11.5.txt",
		        "node_list_path": "1618574.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618574.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaSp7321(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. 73-21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaSp7321", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895809.protein.info.v11.5.txt",
		        "node_list_path": "1895809.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasMaltophiliaS028(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia S028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasMaltophiliaS028", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210005.protein.info.v11.5.txt",
		        "node_list_path": "1210005.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClonorchisSinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clonorchis sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClonorchisSinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "79923.clusters.info.v11.5.txt",
		        "cluster_tree_path": "79923.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "79923.clusters.proteins.v11.5.txt",
		        "sequence_path": "79923.protein.sequences.v11.5.fa",
		        "enrichment_path": "79923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79923.protein.info.v11.5.txt",
		        "node_list_path": "79923.cluster.nodes.v11.5.txt",
		        "edge_list_path": "79923.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasAlbilineansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas albilineans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasAlbilineansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "380358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "380358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "380358.clusters.proteins.v11.5.txt",
		        "sequence_path": "380358.protein.sequences.v11.5.fa",
		        "enrichment_path": "380358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380358.protein.info.v11.5.txt",
		        "node_list_path": "380358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "380358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasSalmonicida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSalmonicida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "382245.protein.sequences.v11.5.fa",
		        "enrichment_path": "382245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "382245.protein.info.v11.5.txt",
		        "node_list_path": "382245.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerobaculumMobile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobaculum mobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobaculumMobile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "891968.protein.sequences.v11.5.fa",
		        "enrichment_path": "891968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "891968.protein.info.v11.5.txt",
		        "node_list_path": "891968.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaBergensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBergensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585502.clusters.proteins.v11.5.txt",
		        "sequence_path": "585502.protein.sequences.v11.5.fa",
		        "enrichment_path": "585502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585502.protein.info.v11.5.txt",
		        "node_list_path": "585502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMarimammalium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus marimammalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMarimammalium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123306.protein.info.v11.5.txt",
		        "node_list_path": "1123306.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumHominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumHominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "162426.protein.sequences.v11.5.fa",
		        "enrichment_path": "162426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "162426.protein.info.v11.5.txt",
		        "node_list_path": "162426.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulophagaBaltica18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga baltica 18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaBaltica18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348584.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348584.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348584.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348584.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348584.protein.info.v11.5.txt",
		        "node_list_path": "1348584.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348584.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DomibacillusAminovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus aminovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusAminovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29332.protein.sequences.v11.5.fa",
		        "enrichment_path": "29332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29332.protein.info.v11.5.txt",
		        "node_list_path": "29332.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasRuminantiumAc2024(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium AC2024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasRuminantiumAc2024", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392501.protein.info.v11.5.txt",
		        "node_list_path": "1392501.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosarchaeumLimniumSfb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosarchaeum limnium SFB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosarchaeumLimniumSfb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "886738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "886738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "886738.clusters.proteins.v11.5.txt",
		        "sequence_path": "886738.protein.sequences.v11.5.fa",
		        "enrichment_path": "886738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "886738.protein.info.v11.5.txt",
		        "node_list_path": "886738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "886738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho201Full4622bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_01_FULL_46_22b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho201Full4622bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802301.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802301.protein.info.v11.5.txt",
		        "node_list_path": "1802301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaParisiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella parisiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaParisiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45071.protein.sequences.v11.5.fa",
		        "enrichment_path": "45071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45071.protein.info.v11.5.txt",
		        "node_list_path": "45071.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSonorensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sonorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSonorensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1274524.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1274524.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1274524.clusters.proteins.v11.5.txt",
		        "sequence_path": "1274524.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274524.protein.info.v11.5.txt",
		        "node_list_path": "1274524.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1274524.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzoarcusSpKh32cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azoarcus sp. KH32C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzoarcusSpKh32cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "748247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "748247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "748247.clusters.proteins.v11.5.txt",
		        "sequence_path": "748247.protein.sequences.v11.5.fa",
		        "enrichment_path": "748247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748247.protein.info.v11.5.txt",
		        "node_list_path": "748247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "748247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaTuricataeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia turicatae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaTuricataeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314724.clusters.proteins.v11.5.txt",
		        "sequence_path": "314724.protein.sequences.v11.5.fa",
		        "enrichment_path": "314724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314724.protein.info.v11.5.txt",
		        "node_list_path": "314724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaBacilliformisVer097(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis Ver097 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaBacilliformisVer097", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293911.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293911.protein.info.v11.5.txt",
		        "node_list_path": "1293911.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpDabAl43b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. DAB_AL43B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpDabAl43b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1028416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028416.protein.info.v11.5.txt",
		        "node_list_path": "1028416.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmodiophoraBrassicaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodiophora brassicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiophoraBrassicaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37360.clusters.proteins.v11.5.txt",
		        "sequence_path": "37360.protein.sequences.v11.5.fa",
		        "enrichment_path": "37360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37360.protein.info.v11.5.txt",
		        "node_list_path": "37360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaAviumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella avium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaAviumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "360910.clusters.info.v11.5.txt",
		        "cluster_tree_path": "360910.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "360910.clusters.proteins.v11.5.txt",
		        "sequence_path": "360910.protein.sequences.v11.5.fa",
		        "enrichment_path": "360910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360910.protein.info.v11.5.txt",
		        "node_list_path": "360910.cluster.nodes.v11.5.txt",
		        "edge_list_path": "360910.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaGallinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaGallinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29557.clusters.proteins.v11.5.txt",
		        "sequence_path": "29557.protein.sequences.v11.5.fa",
		        "enrichment_path": "29557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29557.protein.info.v11.5.txt",
		        "node_list_path": "29557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusSendaiensisNbrc100866(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus sendaiensis NBRC 100866 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusSendaiensisNbrc100866", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220572.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220572.protein.info.v11.5.txt",
		        "node_list_path": "1220572.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaMirum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma mirum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaMirum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "838561.protein.sequences.v11.5.fa",
		        "enrichment_path": "838561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "838561.protein.info.v11.5.txt",
		        "node_list_path": "838561.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat44921(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-44921 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat44921", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1912214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912214.protein.info.v11.5.txt",
		        "node_list_path": "1912214.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylibiumSpCf059(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylibium sp. CF059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylibiumSpCf059", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500261.protein.info.v11.5.txt",
		        "node_list_path": "1500261.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasAeruginosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas aeruginosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAeruginosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "287.protein.sequences.v11.5.fa",
		        "enrichment_path": "287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "287.protein.info.v11.5.txt",
		        "node_list_path": "287.protein.complete.v11.5.txt"
		    }
		]
    )()

def MelopsittacusUndulatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Melopsittacus undulatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MelopsittacusUndulatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13146.protein.sequences.v11.5.fa",
		        "enrichment_path": "13146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13146.protein.info.v11.5.txt",
		        "node_list_path": "13146.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusChitonophagus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus chitonophagus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusChitonophagus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "54262.protein.sequences.v11.5.fa",
		        "enrichment_path": "54262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54262.protein.info.v11.5.txt",
		        "node_list_path": "54262.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentibacillusPersicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus persicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentibacillusPersicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "640948.protein.sequences.v11.5.fa",
		        "enrichment_path": "640948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640948.protein.info.v11.5.txt",
		        "node_list_path": "640948.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusMarinonascensNbrc14363Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus marinonascens NBRC 14363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusMarinonascensNbrc14363Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219020.protein.info.v11.5.txt",
		        "node_list_path": "1219020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KozakiaBaliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kozakia baliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KozakiaBaliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "153496.protein.sequences.v11.5.fa",
		        "enrichment_path": "153496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "153496.protein.info.v11.5.txt",
		        "node_list_path": "153496.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf22816Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_28_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf22816Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619077.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619077.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619077.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619077.protein.info.v11.5.txt",
		        "node_list_path": "1619077.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619077.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpTd01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. TD01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpTd01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999141.protein.sequences.v11.5.fa",
		        "enrichment_path": "999141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999141.protein.info.v11.5.txt",
		        "node_list_path": "999141.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpThb2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. thb2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpThb2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "172088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "172088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "172088.clusters.proteins.v11.5.txt",
		        "sequence_path": "172088.protein.sequences.v11.5.fa",
		        "enrichment_path": "172088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "172088.protein.info.v11.5.txt",
		        "node_list_path": "172088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "172088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpCag776Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:776 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpCag776Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262906.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262906.protein.info.v11.5.txt",
		        "node_list_path": "1262906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsphigho202Full5616(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_02_FULL_56_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho202Full5616", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797542.protein.info.v11.5.txt",
		        "node_list_path": "1797542.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylococcusCapsulatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylococcus capsulatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylococcusCapsulatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243233.protein.sequences.v11.5.fa",
		        "enrichment_path": "243233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243233.protein.info.v11.5.txt",
		        "node_list_path": "243233.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonadalesBacteriumTw7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonadales bacterium TW7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonadalesBacteriumTw7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "156578.clusters.info.v11.5.txt",
		        "cluster_tree_path": "156578.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "156578.clusters.proteins.v11.5.txt",
		        "sequence_path": "156578.protein.sequences.v11.5.fa",
		        "enrichment_path": "156578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156578.protein.info.v11.5.txt",
		        "node_list_path": "156578.cluster.nodes.v11.5.txt",
		        "edge_list_path": "156578.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGa0074130(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0074130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGa0074130", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752197.protein.info.v11.5.txt",
		        "node_list_path": "1752197.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaprolegniaParasiticaCbs22365(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saprolegnia parasitica CBS 223.65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaprolegniaParasiticaCbs22365", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "695850.protein.sequences.v11.5.fa",
		        "enrichment_path": "695850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "695850.protein.info.v11.5.txt",
		        "node_list_path": "695850.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeptuniibacterCaesariensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neptuniibacter caesariensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptuniibacterCaesariensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "207954.protein.sequences.v11.5.fa",
		        "enrichment_path": "207954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "207954.protein.info.v11.5.txt",
		        "node_list_path": "207954.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpGfb01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. GFB01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpGfb01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1662190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1662190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1662190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1662190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662190.protein.info.v11.5.txt",
		        "node_list_path": "1662190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1662190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRifcsplowo212Full5410(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO2_12_FULL_54_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212Full5410", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797186.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797186.protein.info.v11.5.txt",
		        "node_list_path": "1797186.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetrahymenaThermophilaSb210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetrahymena thermophila SB210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrahymenaThermophilaSb210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "312017.protein.sequences.v11.5.fa",
		        "enrichment_path": "312017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "312017.protein.info.v11.5.txt",
		        "node_list_path": "312017.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterRadioresistensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter radioresistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterRadioresistensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "575589.clusters.info.v11.5.txt",
		        "cluster_tree_path": "575589.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "575589.clusters.proteins.v11.5.txt",
		        "sequence_path": "575589.protein.sequences.v11.5.fa",
		        "enrichment_path": "575589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575589.protein.info.v11.5.txt",
		        "node_list_path": "575589.cluster.nodes.v11.5.txt",
		        "edge_list_path": "575589.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioPiger(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio piger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioPiger", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411464.protein.sequences.v11.5.fa",
		        "enrichment_path": "411464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411464.protein.info.v11.5.txt",
		        "node_list_path": "411464.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaMegapolitanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia megapolitana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaMegapolitanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "420953.clusters.info.v11.5.txt",
		        "cluster_tree_path": "420953.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "420953.clusters.proteins.v11.5.txt",
		        "sequence_path": "420953.protein.sequences.v11.5.fa",
		        "enrichment_path": "420953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420953.protein.info.v11.5.txt",
		        "node_list_path": "420953.cluster.nodes.v11.5.txt",
		        "edge_list_path": "420953.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioBrasiliensisJcm12178(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio brasiliensis JCM 12178 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioBrasiliensisJcm12178", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1294020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294020.protein.info.v11.5.txt",
		        "node_list_path": "1294020.protein.complete.v11.5.txt"
		    }
		]
    )()

def TheileriaParvaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Theileria parva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheileriaParvaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5875.clusters.proteins.v11.5.txt",
		        "sequence_path": "5875.protein.sequences.v11.5.fa",
		        "enrichment_path": "5875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5875.protein.info.v11.5.txt",
		        "node_list_path": "5875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermicanusAegyptiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermicanus aegyptius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermicanusAegyptiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089548.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089548.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089548.protein.info.v11.5.txt",
		        "node_list_path": "1089548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaBacilliformisVer097Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis Ver097 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaBacilliformisVer097Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293911.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293911.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293911.protein.info.v11.5.txt",
		        "node_list_path": "1293911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasSalmonicidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSalmonicidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "382245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "382245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "382245.clusters.proteins.v11.5.txt",
		        "sequence_path": "382245.protein.sequences.v11.5.fa",
		        "enrichment_path": "382245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "382245.protein.info.v11.5.txt",
		        "node_list_path": "382245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "382245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterDonghicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter donghicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterDonghicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1300350.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1300350.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1300350.clusters.proteins.v11.5.txt",
		        "sequence_path": "1300350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300350.protein.info.v11.5.txt",
		        "node_list_path": "1300350.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1300350.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesCellulosilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides cellulosilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCellulosilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1268240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268240.protein.info.v11.5.txt",
		        "node_list_path": "1268240.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSimulansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium simulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSimulansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "146827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "146827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "146827.clusters.proteins.v11.5.txt",
		        "sequence_path": "146827.protein.sequences.v11.5.fa",
		        "enrichment_path": "146827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146827.protein.info.v11.5.txt",
		        "node_list_path": "146827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "146827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfomicrobiumEscambienseDsm10707Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium escambiense DSM 10707 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfomicrobiumEscambienseDsm10707Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121411.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121411.protein.info.v11.5.txt",
		        "node_list_path": "1121411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyadobacterSpSg02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter sp. SG02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterSpSg02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855291.protein.info.v11.5.txt",
		        "node_list_path": "1855291.protein.complete.v11.5.txt"
		    }
		]
    )()

def PatagioenasFasciataMonilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Patagioenas fasciata monilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PatagioenasFasciataMonilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "372326.clusters.info.v11.5.txt",
		        "cluster_tree_path": "372326.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "372326.clusters.proteins.v11.5.txt",
		        "sequence_path": "372326.protein.sequences.v11.5.fa",
		        "enrichment_path": "372326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "372326.protein.info.v11.5.txt",
		        "node_list_path": "372326.cluster.nodes.v11.5.txt",
		        "edge_list_path": "372326.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaSputigenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga sputigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaSputigenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553177.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553177.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553177.clusters.proteins.v11.5.txt",
		        "sequence_path": "553177.protein.sequences.v11.5.fa",
		        "enrichment_path": "553177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553177.protein.info.v11.5.txt",
		        "node_list_path": "553177.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553177.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaRochalimaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella rochalimae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaRochalimaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "685782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "685782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "685782.clusters.proteins.v11.5.txt",
		        "sequence_path": "685782.protein.sequences.v11.5.fa",
		        "enrichment_path": "685782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "685782.protein.info.v11.5.txt",
		        "node_list_path": "685782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "685782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27264Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27264 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27264Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1850362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1850362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1850362.clusters.proteins.v11.5.txt",
		        "sequence_path": "1850362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850362.protein.info.v11.5.txt",
		        "node_list_path": "1850362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1850362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioLitoralisDsm17657Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio litoralis DSM 17657 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioLitoralisDsm17657Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123493.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123493.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123493.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123493.protein.info.v11.5.txt",
		        "node_list_path": "1123493.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123493.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacteroidesHalobius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacteroides halobius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacteroidesHalobius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "748449.protein.sequences.v11.5.fa",
		        "enrichment_path": "748449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748449.protein.info.v11.5.txt",
		        "node_list_path": "748449.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriumCapsulatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacterium capsulatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriumCapsulatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "240015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "240015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "240015.clusters.proteins.v11.5.txt",
		        "sequence_path": "240015.protein.sequences.v11.5.fa",
		        "enrichment_path": "240015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240015.protein.info.v11.5.txt",
		        "node_list_path": "240015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "240015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisHaa2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris HaA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisHaa2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316058.protein.sequences.v11.5.fa",
		        "enrichment_path": "316058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316058.protein.info.v11.5.txt",
		        "node_list_path": "316058.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSonorensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sonorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSonorensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1004316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004316.protein.info.v11.5.txt",
		        "node_list_path": "1004316.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumAkagiiDsm12554Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium akagii DSM 12554 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAkagiiDsm12554Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121293.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121293.protein.info.v11.5.txt",
		        "node_list_path": "1121293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharospirillumImpatiens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharospirillum impatiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharospirillumImpatiens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123228.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123228.protein.info.v11.5.txt",
		        "node_list_path": "1123228.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium3157faact1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 3157FAACT1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium3157faact1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658086.protein.sequences.v11.5.fa",
		        "enrichment_path": "658086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658086.protein.info.v11.5.txt",
		        "node_list_path": "658086.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaSpF0517(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0517 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaSpF0517", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227266.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227266.protein.info.v11.5.txt",
		        "node_list_path": "1227266.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasLinyingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas linyingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasLinyingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "915471.protein.sequences.v11.5.fa",
		        "enrichment_path": "915471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "915471.protein.info.v11.5.txt",
		        "node_list_path": "915471.protein.complete.v11.5.txt"
		    }
		]
    )()

def RathayibacterSpLeaf185(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rathayibacter sp. Leaf185 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RathayibacterSpLeaf185", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736292.protein.info.v11.5.txt",
		        "node_list_path": "1736292.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpRd62(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. RD6.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpRd62", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "260936.protein.sequences.v11.5.fa",
		        "enrichment_path": "260936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "260936.protein.info.v11.5.txt",
		        "node_list_path": "260936.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaProwazekiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia prowazekii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaProwazekiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272947.clusters.proteins.v11.5.txt",
		        "sequence_path": "272947.protein.sequences.v11.5.fa",
		        "enrichment_path": "272947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272947.protein.info.v11.5.txt",
		        "node_list_path": "272947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpEr2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. ER2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpEr2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1519438.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1519438.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1519438.clusters.proteins.v11.5.txt",
		        "sequence_path": "1519438.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519438.protein.info.v11.5.txt",
		        "node_list_path": "1519438.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1519438.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyaloscyphaBicolorECluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyaloscypha bicolor E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyaloscyphaBicolorECluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095630.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095630.protein.info.v11.5.txt",
		        "node_list_path": "1095630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinokineosporaEnzanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora enzanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinokineosporaEnzanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120934.protein.info.v11.5.txt",
		        "node_list_path": "1120934.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasTaeanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas taeanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasTaeanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "284577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "284577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "284577.clusters.proteins.v11.5.txt",
		        "sequence_path": "284577.protein.sequences.v11.5.fa",
		        "enrichment_path": "284577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284577.protein.info.v11.5.txt",
		        "node_list_path": "284577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "284577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasPolarisDsm16579(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas polaris DSM 16579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasPolarisDsm16579", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122206.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122206.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122206.protein.info.v11.5.txt",
		        "node_list_path": "1122206.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumParmense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium parmense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumParmense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "185642.protein.sequences.v11.5.fa",
		        "enrichment_path": "185642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "185642.protein.info.v11.5.txt",
		        "node_list_path": "185642.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArsenicicoccusBolidensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arsenicicoccus bolidensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArsenicicoccusBolidensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121017.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121017.protein.info.v11.5.txt",
		        "node_list_path": "1121017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumGwf2339Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWF2_33_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumGwf2339Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798430.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798430.protein.info.v11.5.txt",
		        "node_list_path": "1798430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu075(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU075 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu075", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671659.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671659.protein.info.v11.5.txt",
		        "node_list_path": "1671659.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumHolothuriorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum holothuriorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumHolothuriorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635173.protein.info.v11.5.txt",
		        "node_list_path": "1635173.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpSoil750Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil750 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpSoil750Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736398.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736398.protein.info.v11.5.txt",
		        "node_list_path": "1736398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PatulibacterAmericanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Patulibacter americanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PatulibacterAmericanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122939.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122939.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122939.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122939.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122939.protein.info.v11.5.txt",
		        "node_list_path": "1122939.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122939.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaPnomenusaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea pnomenusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaPnomenusaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93220.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93220.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93220.clusters.proteins.v11.5.txt",
		        "sequence_path": "93220.protein.sequences.v11.5.fa",
		        "enrichment_path": "93220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93220.protein.info.v11.5.txt",
		        "node_list_path": "93220.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93220.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusBackiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus backii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBackiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "375175.clusters.info.v11.5.txt",
		        "cluster_tree_path": "375175.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "375175.clusters.proteins.v11.5.txt",
		        "sequence_path": "375175.protein.sequences.v11.5.fa",
		        "enrichment_path": "375175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375175.protein.info.v11.5.txt",
		        "node_list_path": "375175.cluster.nodes.v11.5.txt",
		        "edge_list_path": "375175.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasRuminantiumAb3002(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium AB3002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasRuminantiumAb3002", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392502.protein.info.v11.5.txt",
		        "node_list_path": "1392502.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSegnicrescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter segnicrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSegnicrescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "430453.protein.sequences.v11.5.fa",
		        "enrichment_path": "430453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "430453.protein.info.v11.5.txt",
		        "node_list_path": "430453.protein.complete.v11.5.txt"
		    }
		]
    )()

def SorexAraneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sorex araneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SorexAraneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42254.protein.sequences.v11.5.fa",
		        "enrichment_path": "42254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42254.protein.info.v11.5.txt",
		        "node_list_path": "42254.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpMitS9508(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. MIT S9508 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpMitS9508", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801629.protein.info.v11.5.txt",
		        "node_list_path": "1801629.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeomicrobiumSpJcm19038Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM19038 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeomicrobiumSpJcm19038Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1460635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1460635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1460635.clusters.proteins.v11.5.txt",
		        "sequence_path": "1460635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460635.protein.info.v11.5.txt",
		        "node_list_path": "1460635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1460635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsaiaPlatycodiSf21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asaia platycodi SF21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsaiaPlatycodiSf21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1382230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382230.protein.info.v11.5.txt",
		        "node_list_path": "1382230.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusOdoratitofuiDsm19909Jcm15043Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus odoratitofui DSM 19909 JCM 15043 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOdoratitofuiDsm19909Jcm15043Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423776.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423776.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423776.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423776.protein.info.v11.5.txt",
		        "node_list_path": "1423776.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423776.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LabrenziaSuaedaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Labrenzia suaedae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrenziaSuaedaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "735517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "735517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "735517.clusters.proteins.v11.5.txt",
		        "sequence_path": "735517.protein.sequences.v11.5.fa",
		        "enrichment_path": "735517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "735517.protein.info.v11.5.txt",
		        "node_list_path": "735517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "735517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasHistidinilyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas histidinilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasHistidinilyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "439228.clusters.info.v11.5.txt",
		        "cluster_tree_path": "439228.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "439228.clusters.proteins.v11.5.txt",
		        "sequence_path": "439228.protein.sequences.v11.5.fa",
		        "enrichment_path": "439228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439228.protein.info.v11.5.txt",
		        "node_list_path": "439228.cluster.nodes.v11.5.txt",
		        "edge_list_path": "439228.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AneurinibacillusMigulanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aneurinibacillus migulanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AneurinibacillusMigulanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47500.protein.sequences.v11.5.fa",
		        "enrichment_path": "47500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47500.protein.info.v11.5.txt",
		        "node_list_path": "47500.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraWolbachiiSerovarCodiceStrCdc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira wolbachii serovar Codice str. CDC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraWolbachiiSerovarCodiceStrCdc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218599.protein.info.v11.5.txt",
		        "node_list_path": "1218599.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanifilumFulgidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planifilum fulgidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanifilumFulgidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "201973.protein.sequences.v11.5.fa",
		        "enrichment_path": "201973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "201973.protein.info.v11.5.txt",
		        "node_list_path": "201973.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwc26514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_65_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc26514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797820.protein.info.v11.5.txt",
		        "node_list_path": "1797820.protein.complete.v11.5.txt"
		    }
		]
    )()

def HortaeaWerneckiiExf2000Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hortaea werneckii EXF-2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HortaeaWerneckiiExf2000Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157616.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157616.protein.info.v11.5.txt",
		        "node_list_path": "1157616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumVenenatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium venenatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumVenenatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56646.clusters.proteins.v11.5.txt",
		        "sequence_path": "56646.protein.sequences.v11.5.fa",
		        "enrichment_path": "56646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56646.protein.info.v11.5.txt",
		        "node_list_path": "56646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterPaludis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter paludis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterPaludis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "714943.protein.sequences.v11.5.fa",
		        "enrichment_path": "714943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "714943.protein.info.v11.5.txt",
		        "node_list_path": "714943.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoplanesUtahensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes utahensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesUtahensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1869.protein.info.v11.5.txt",
		        "node_list_path": "1869.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusArgenteus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus argenteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusArgenteus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "985002.protein.sequences.v11.5.fa",
		        "enrichment_path": "985002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985002.protein.info.v11.5.txt",
		        "node_list_path": "985002.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPelagibacterSpHimb1321Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. HIMB1321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPelagibacterSpHimb1321Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1388755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1388755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1388755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1388755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1388755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1388755.protein.info.v11.5.txt",
		        "node_list_path": "1388755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1388755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZymoseptoriaTriticiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymoseptoriaTriticiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1047171.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1047171.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1047171.clusters.proteins.v11.5.txt",
		        "sequence_path": "1047171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1047171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1047171.protein.info.v11.5.txt",
		        "node_list_path": "1047171.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1047171.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfurococcusMucosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurococcus mucosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurococcusMucosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765177.protein.sequences.v11.5.fa",
		        "enrichment_path": "765177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765177.protein.info.v11.5.txt",
		        "node_list_path": "765177.protein.complete.v11.5.txt"
		    }
		]
    )()

def SuccinispiraMobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Succinispira mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuccinispiraMobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1069080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069080.protein.info.v11.5.txt",
		        "node_list_path": "1069080.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhaeospirillumFulvum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeospirillum fulvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeospirillumFulvum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1316936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1316936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1316936.protein.info.v11.5.txt",
		        "node_list_path": "1316936.protein.complete.v11.5.txt"
		    }
		]
    )()

def EggerthellaSpYy7918(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eggerthella sp. YY7918 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthellaSpYy7918", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "502558.protein.sequences.v11.5.fa",
		        "enrichment_path": "502558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502558.protein.info.v11.5.txt",
		        "node_list_path": "502558.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaViridisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora viridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaViridisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471857.clusters.proteins.v11.5.txt",
		        "sequence_path": "471857.protein.sequences.v11.5.fa",
		        "enrichment_path": "471857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471857.protein.info.v11.5.txt",
		        "node_list_path": "471857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaMacacaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella macacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaMacacaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230338.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230338.protein.info.v11.5.txt",
		        "node_list_path": "1230338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh8020Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh8020Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32052.clusters.proteins.v11.5.txt",
		        "sequence_path": "32052.protein.sequences.v11.5.fa",
		        "enrichment_path": "32052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32052.protein.info.v11.5.txt",
		        "node_list_path": "32052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumZucineumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium zucineum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumZucineumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "450851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "450851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "450851.clusters.proteins.v11.5.txt",
		        "sequence_path": "450851.protein.sequences.v11.5.fa",
		        "enrichment_path": "450851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "450851.protein.info.v11.5.txt",
		        "node_list_path": "450851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "450851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhialophoraAmericanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phialophora americana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhialophoraAmericanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5601.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5601.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5601.clusters.proteins.v11.5.txt",
		        "sequence_path": "5601.protein.sequences.v11.5.fa",
		        "enrichment_path": "5601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5601.protein.info.v11.5.txt",
		        "node_list_path": "5601.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5601.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RegiellaInsecticolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Regiella insecticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RegiellaInsecticolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "663321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "663321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "663321.clusters.proteins.v11.5.txt",
		        "sequence_path": "663321.protein.sequences.v11.5.fa",
		        "enrichment_path": "663321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663321.protein.info.v11.5.txt",
		        "node_list_path": "663321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "663321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterTerrenus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter terrenus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterTerrenus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629124.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629124.protein.info.v11.5.txt",
		        "node_list_path": "1629124.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedBacteroidesSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Bacteroides sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedBacteroidesSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "162156.protein.sequences.v11.5.fa",
		        "enrichment_path": "162156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "162156.protein.info.v11.5.txt",
		        "node_list_path": "162156.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusGalactosidilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus galactosidilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGalactosidilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "217031.protein.sequences.v11.5.fa",
		        "enrichment_path": "217031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "217031.protein.info.v11.5.txt",
		        "node_list_path": "217031.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg166914(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_69_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg166914", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797661.protein.info.v11.5.txt",
		        "node_list_path": "1797661.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterMathraniiSubspMathraniiStrA3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter mathranii subsp. mathranii str. A3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterMathraniiSubspMathraniiStrA3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "583358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "583358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "583358.clusters.proteins.v11.5.txt",
		        "sequence_path": "583358.protein.sequences.v11.5.fa",
		        "enrichment_path": "583358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "583358.protein.info.v11.5.txt",
		        "node_list_path": "583358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "583358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusAlbus7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Ruminococcus albus 7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusAlbus7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "697329.clusters.info.v11.0.txt",
		        "cluster_tree_path": "697329.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "697329.clusters.proteins.v11.0.txt",
		        "sequence_path": "697329.protein.sequences.v11.0.fa",
		        "enrichment_path": "697329.protein.enrichment.terms.v11.0.txt",
		        "info_path": "697329.protein.info.v11.0.txt",
		        "node_list_path": "697329.cluster.nodes.v11.0.txt",
		        "edge_list_path": "697329.protein.cluster.v11.0.txt"
		    }
		]
    )()

def AspergillusNigerAtcc1015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus niger ATCC 1015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusNigerAtcc1015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "380704.protein.sequences.v11.5.fa",
		        "enrichment_path": "380704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380704.protein.info.v11.5.txt",
		        "node_list_path": "380704.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolirubrobacteralesBacteriumUrhd0059(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solirubrobacterales bacterium URHD0059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolirubrobacteralesBacteriumUrhd0059", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380390.protein.info.v11.5.txt",
		        "node_list_path": "1380390.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnt360Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT360 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnt360Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288080.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288080.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288080.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288080.protein.info.v11.5.txt",
		        "node_list_path": "1288080.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288080.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StomoxysCalcitrans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stomoxys calcitrans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StomoxysCalcitrans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35570.protein.sequences.v11.5.fa",
		        "enrichment_path": "35570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35570.protein.info.v11.5.txt",
		        "node_list_path": "35570.protein.complete.v11.5.txt"
		    }
		]
    )()

def FacklamiaIgnava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Facklamia ignava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FacklamiaIgnava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883112.protein.sequences.v11.5.fa",
		        "enrichment_path": "883112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883112.protein.info.v11.5.txt",
		        "node_list_path": "883112.protein.complete.v11.5.txt"
		    }
		]
    )()

def TermitomycesSpJ132Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Termitomyces sp. J132 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TermitomycesSpJ132Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1306850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1306850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1306850.clusters.proteins.v11.5.txt",
		        "sequence_path": "1306850.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306850.protein.info.v11.5.txt",
		        "node_list_path": "1306850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1306850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpathasporaPassalidarumNrrlY27907Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spathaspora passalidarum NRRL Y-27907 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpathasporaPassalidarumNrrlY27907Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "619300.clusters.info.v11.5.txt",
		        "cluster_tree_path": "619300.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "619300.clusters.proteins.v11.5.txt",
		        "sequence_path": "619300.protein.sequences.v11.5.fa",
		        "enrichment_path": "619300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "619300.protein.info.v11.5.txt",
		        "node_list_path": "619300.cluster.nodes.v11.5.txt",
		        "edge_list_path": "619300.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusThermomutatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus thermomutatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusThermomutatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "41047.protein.sequences.v11.5.fa",
		        "enrichment_path": "41047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41047.protein.info.v11.5.txt",
		        "node_list_path": "41047.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaCyaneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora cyanea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaCyaneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "882082.clusters.info.v11.5.txt",
		        "cluster_tree_path": "882082.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "882082.clusters.proteins.v11.5.txt",
		        "sequence_path": "882082.protein.sequences.v11.5.fa",
		        "enrichment_path": "882082.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882082.protein.info.v11.5.txt",
		        "node_list_path": "882082.cluster.nodes.v11.5.txt",
		        "edge_list_path": "882082.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumGenomosp3StrCfbp6623(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium genomosp. 3 str. CFBP 6623 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumGenomosp3StrCfbp6623", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1183432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1183432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1183432.protein.info.v11.5.txt",
		        "node_list_path": "1183432.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaSpJb15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. JB15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpJb15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1933906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1933906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1933906.clusters.proteins.v11.5.txt",
		        "sequence_path": "1933906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933906.protein.info.v11.5.txt",
		        "node_list_path": "1933906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1933906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwf1496(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWF1_49_6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwf1496", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802189.protein.info.v11.5.txt",
		        "node_list_path": "1802189.protein.complete.v11.5.txt"
		    }
		]
    )()

def BremiaLactucaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bremia lactucae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BremiaLactucaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4779.clusters.proteins.v11.5.txt",
		        "sequence_path": "4779.protein.sequences.v11.5.fa",
		        "enrichment_path": "4779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4779.protein.info.v11.5.txt",
		        "node_list_path": "4779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonasBadiaDsm17552(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas badia DSM 17552 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasBadiaDsm17552", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121348.protein.info.v11.5.txt",
		        "node_list_path": "1121348.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSpRim47Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSpRim47Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1100721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1100721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1100721.clusters.proteins.v11.5.txt",
		        "sequence_path": "1100721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1100721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1100721.protein.info.v11.5.txt",
		        "node_list_path": "1100721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1100721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DehalogenimonasAlkenigignensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalogenimonas alkenigignens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalogenimonasAlkenigignensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217799.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217799.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217799.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217799.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217799.protein.info.v11.5.txt",
		        "node_list_path": "1217799.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217799.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastomycesParvus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces parvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomycesParvus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2060905.protein.sequences.v11.5.fa",
		        "enrichment_path": "2060905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2060905.protein.info.v11.5.txt",
		        "node_list_path": "2060905.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5013(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_50_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5013", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798661.protein.info.v11.5.txt",
		        "node_list_path": "1798661.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumTestudinoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium testudinoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumTestudinoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "136857.protein.sequences.v11.5.fa",
		        "enrichment_path": "136857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "136857.protein.info.v11.5.txt",
		        "node_list_path": "136857.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioFrigidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio frigidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioFrigidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121447.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121447.protein.info.v11.5.txt",
		        "node_list_path": "1121447.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwc26514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_65_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc26514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797820.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797820.protein.info.v11.5.txt",
		        "node_list_path": "1797820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusPrevotiiAcs065vcol13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus prevotii ACS065VCol13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusPrevotiiAcs065vcol13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "879305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "879305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "879305.clusters.proteins.v11.5.txt",
		        "sequence_path": "879305.protein.sequences.v11.5.fa",
		        "enrichment_path": "879305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879305.protein.info.v11.5.txt",
		        "node_list_path": "879305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "879305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KosakoniaCowanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kosakonia cowanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KosakoniaCowanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "208223.protein.sequences.v11.5.fa",
		        "enrichment_path": "208223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208223.protein.info.v11.5.txt",
		        "node_list_path": "208223.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterPapayaeJcm25143(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter papayae JCM 25143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterPapayaeJcm25143", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1234671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234671.protein.info.v11.5.txt",
		        "node_list_path": "1234671.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaArthritidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma arthritidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaArthritidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243272.protein.sequences.v11.5.fa",
		        "enrichment_path": "243272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243272.protein.info.v11.5.txt",
		        "node_list_path": "243272.protein.complete.v11.5.txt"
		    }
		]
    )()

def OdoribacterLaneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Odoribacter laneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OdoribacterLaneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742817.clusters.proteins.v11.5.txt",
		        "sequence_path": "742817.protein.sequences.v11.5.fa",
		        "enrichment_path": "742817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742817.protein.info.v11.5.txt",
		        "node_list_path": "742817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhycicoccusCremeus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phycicoccus cremeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycicoccusCremeus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "587636.protein.sequences.v11.5.fa",
		        "enrichment_path": "587636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "587636.protein.info.v11.5.txt",
		        "node_list_path": "587636.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterJejuni81176Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter jejuni 81176 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterJejuni81176Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "354242.clusters.info.v11.5.txt",
		        "cluster_tree_path": "354242.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "354242.clusters.proteins.v11.5.txt",
		        "sequence_path": "354242.protein.sequences.v11.5.fa",
		        "enrichment_path": "354242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "354242.protein.info.v11.5.txt",
		        "node_list_path": "354242.cluster.nodes.v11.5.txt",
		        "edge_list_path": "354242.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpUrha0056Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. URHA0056 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpUrha0056Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298858.protein.info.v11.5.txt",
		        "node_list_path": "1298858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusPomorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus pomorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusPomorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111479.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111479.protein.info.v11.5.txt",
		        "node_list_path": "1111479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactococcusPlantarumNbrc100936Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus plantarum NBRC 100936 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusPlantarumNbrc100936Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348632.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348632.protein.info.v11.5.txt",
		        "node_list_path": "1348632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaproniaEpimyces(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capronia epimyces graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaproniaEpimyces", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43228.protein.sequences.v11.5.fa",
		        "enrichment_path": "43228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43228.protein.info.v11.5.txt",
		        "node_list_path": "43228.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterConcisus13826Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter concisus 13826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterConcisus13826Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "360104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "360104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "360104.clusters.proteins.v11.5.txt",
		        "sequence_path": "360104.protein.sequences.v11.5.fa",
		        "enrichment_path": "360104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360104.protein.info.v11.5.txt",
		        "node_list_path": "360104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "360104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterToluenoxydansJcm15764(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter toluenoxydans JCM 15764 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterToluenoxydansJcm15764", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1294260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294260.protein.info.v11.5.txt",
		        "node_list_path": "1294260.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuberMelanosporumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tuber melanosporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuberMelanosporumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39416.clusters.proteins.v11.5.txt",
		        "sequence_path": "39416.protein.sequences.v11.5.fa",
		        "enrichment_path": "39416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39416.protein.info.v11.5.txt",
		        "node_list_path": "39416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasMontanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas montana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasMontanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1843236.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1843236.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1843236.clusters.proteins.v11.5.txt",
		        "sequence_path": "1843236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1843236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1843236.protein.info.v11.5.txt",
		        "node_list_path": "1843236.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1843236.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesMerdae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides merdae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesMerdae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411477.protein.sequences.v11.5.fa",
		        "enrichment_path": "411477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411477.protein.info.v11.5.txt",
		        "node_list_path": "411477.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumRhizogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium rhizogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumRhizogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "359.protein.sequences.v11.5.fa",
		        "enrichment_path": "359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "359.protein.info.v11.5.txt",
		        "node_list_path": "359.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusSpYim77409Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus sp. YIM77409 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusSpYim77409Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449080.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449080.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449080.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449080.protein.info.v11.5.txt",
		        "node_list_path": "1449080.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449080.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsplowo212Full4426Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_12_FULL_44_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo212Full4426Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802130.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802130.protein.info.v11.5.txt",
		        "node_list_path": "1802130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlebsiellaPneumoniaeSubspRhinoscleromatisAtcc13884(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. rhinoscleromatis ATCC 13884 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaPneumoniaeSubspRhinoscleromatisAtcc13884", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "667127.protein.sequences.v11.5.fa",
		        "enrichment_path": "667127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667127.protein.info.v11.5.txt",
		        "node_list_path": "667127.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaematospirillumJordaniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haematospirillum jordaniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaematospirillumJordaniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1549855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1549855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1549855.clusters.proteins.v11.5.txt",
		        "sequence_path": "1549855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1549855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1549855.protein.info.v11.5.txt",
		        "node_list_path": "1549855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1549855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumGbs1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium GBS-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumGbs1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1662110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1662110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1662110.clusters.proteins.v11.5.txt",
		        "sequence_path": "1662110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662110.protein.info.v11.5.txt",
		        "node_list_path": "1662110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1662110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlantibacterSpLeaf314(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plantibacter sp. Leaf314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlantibacterSpLeaf314", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736333.protein.info.v11.5.txt",
		        "node_list_path": "1736333.protein.complete.v11.5.txt"
		    }
		]
    )()

def AltibacterLentusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Altibacter lentus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltibacterLentusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223410.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223410.protein.info.v11.5.txt",
		        "node_list_path": "1223410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumCg1024390(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_43_90 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg1024390", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805281.protein.info.v11.5.txt",
		        "node_list_path": "1805281.protein.complete.v11.5.txt"
		    }
		]
    )()

def WilliamsiaSpLeaf354(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Williamsia sp. Leaf354 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WilliamsiaSpLeaf354", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736349.protein.info.v11.5.txt",
		        "node_list_path": "1736349.protein.complete.v11.5.txt"
		    }
		]
    )()

def KetogulonicigeniumVulgareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ketogulonicigenium vulgare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KetogulonicigeniumVulgareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "759362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "759362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "759362.clusters.proteins.v11.5.txt",
		        "sequence_path": "759362.protein.sequences.v11.5.fa",
		        "enrichment_path": "759362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759362.protein.info.v11.5.txt",
		        "node_list_path": "759362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "759362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifoxya1Full4018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYA1_FULL_40_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxya1Full4018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802532.protein.info.v11.5.txt",
		        "node_list_path": "1802532.protein.complete.v11.5.txt"
		    }
		]
    )()

def DelftiaAcidovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Delftia acidovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DelftiaAcidovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398578.protein.sequences.v11.5.fa",
		        "enrichment_path": "398578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398578.protein.info.v11.5.txt",
		        "node_list_path": "398578.protein.complete.v11.5.txt"
		    }
		]
    )()

def IdiomarinaSpMccc1a10513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sp. MCCC1A10513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaSpMccc1a10513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1517416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1517416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1517416.protein.info.v11.5.txt",
		        "node_list_path": "1517416.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpDmb20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. DMB20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpDmb20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1642570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1642570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1642570.protein.info.v11.5.txt",
		        "node_list_path": "1642570.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumInsubricumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium insubricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumInsubricumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "444597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "444597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "444597.clusters.proteins.v11.5.txt",
		        "sequence_path": "444597.protein.sequences.v11.5.fa",
		        "enrichment_path": "444597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444597.protein.info.v11.5.txt",
		        "node_list_path": "444597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "444597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizophagusIrregularisDaom197198wCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM 197198w Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizophagusIrregularisDaom197198wCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1432141.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1432141.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1432141.clusters.proteins.v11.5.txt",
		        "sequence_path": "1432141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432141.protein.info.v11.5.txt",
		        "node_list_path": "1432141.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1432141.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasFungiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas fungiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasFungiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1137284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1137284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1137284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1137284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137284.protein.info.v11.5.txt",
		        "node_list_path": "1137284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1137284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaOrisC735Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris C735 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOrisC735Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "563008.clusters.info.v11.5.txt",
		        "cluster_tree_path": "563008.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "563008.clusters.proteins.v11.5.txt",
		        "sequence_path": "563008.protein.sequences.v11.5.fa",
		        "enrichment_path": "563008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563008.protein.info.v11.5.txt",
		        "node_list_path": "563008.cluster.nodes.v11.5.txt",
		        "edge_list_path": "563008.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaeBacteriumRifcsphigho212Full4911(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPHIGHO2_12_FULL_49_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaeBacteriumRifcsphigho212Full4911", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797603.protein.info.v11.5.txt",
		        "node_list_path": "1797603.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusRiograndensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus riograndensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusRiograndensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "483937.protein.sequences.v11.5.fa",
		        "enrichment_path": "483937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483937.protein.info.v11.5.txt",
		        "node_list_path": "483937.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusKyotonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus kyotonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusKyotonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398843.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398843.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398843.clusters.proteins.v11.5.txt",
		        "sequence_path": "398843.protein.sequences.v11.5.fa",
		        "enrichment_path": "398843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398843.protein.info.v11.5.txt",
		        "node_list_path": "398843.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398843.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpFf12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FF12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpFf12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1608584.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1608584.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1608584.clusters.proteins.v11.5.txt",
		        "sequence_path": "1608584.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608584.protein.info.v11.5.txt",
		        "node_list_path": "1608584.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1608584.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacterSphaeroidesAtcc17025Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter sphaeroides ATCC17025 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterSphaeroidesAtcc17025Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349102.clusters.proteins.v11.5.txt",
		        "sequence_path": "349102.protein.sequences.v11.5.fa",
		        "enrichment_path": "349102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349102.protein.info.v11.5.txt",
		        "node_list_path": "349102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpMit0801(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0801 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpMit0801", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1501269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1501269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1501269.protein.info.v11.5.txt",
		        "node_list_path": "1501269.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumClariflavum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium clariflavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumClariflavum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "720554.protein.sequences.v11.5.fa",
		        "enrichment_path": "720554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "720554.protein.info.v11.5.txt",
		        "node_list_path": "720554.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4415c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_44_15c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4415c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802333.protein.info.v11.5.txt",
		        "node_list_path": "1802333.protein.complete.v11.5.txt"
		    }
		]
    )()

def IdiomarinaSp513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sp. 5.13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaSp513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1929465.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1929465.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1929465.clusters.proteins.v11.5.txt",
		        "sequence_path": "1929465.protein.sequences.v11.5.fa",
		        "enrichment_path": "1929465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1929465.protein.info.v11.5.txt",
		        "node_list_path": "1929465.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1929465.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu070Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU070 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu070Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671655.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671655.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671655.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671655.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671655.protein.info.v11.5.txt",
		        "node_list_path": "1671655.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671655.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterPedocola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter pedocola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterPedocola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1792845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792845.protein.info.v11.5.txt",
		        "node_list_path": "1792845.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalovivaxRuber(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halovivax ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalovivaxRuber", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "797302.protein.sequences.v11.5.fa",
		        "enrichment_path": "797302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797302.protein.info.v11.5.txt",
		        "node_list_path": "797302.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHaemofelisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma haemofelis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHaemofelisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "859194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "859194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "859194.clusters.proteins.v11.5.txt",
		        "sequence_path": "859194.protein.sequences.v11.5.fa",
		        "enrichment_path": "859194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "859194.protein.info.v11.5.txt",
		        "node_list_path": "859194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "859194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGastranaerophilusPhascolarctosicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilus phascolarctosicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGastranaerophilusPhascolarctosicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906137.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906137.protein.info.v11.5.txt",
		        "node_list_path": "1906137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumPlexicaudatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium plexicaudatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumPlexicaudatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235802.protein.info.v11.5.txt",
		        "node_list_path": "1235802.protein.complete.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaBp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Bp graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaBp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "224915.protein.sequences.v11.5.fa",
		        "enrichment_path": "224915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224915.protein.info.v11.5.txt",
		        "node_list_path": "224915.protein.complete.v11.5.txt"
		    }
		]
    )()

def CroceibacterAtlanticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Croceibacter atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CroceibacterAtlanticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216432.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216432.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216432.clusters.proteins.v11.5.txt",
		        "sequence_path": "216432.protein.sequences.v11.5.fa",
		        "enrichment_path": "216432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216432.protein.info.v11.5.txt",
		        "node_list_path": "216432.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216432.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionNc10BacteriumRifcsplowo202Full6622Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division NC10 bacterium RIFCSPLOWO2_02_FULL_66_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionNc10BacteriumRifcsplowo202Full6622Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801658.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801658.protein.info.v11.5.txt",
		        "node_list_path": "1801658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSp316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSp316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1603293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1603293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1603293.clusters.proteins.v11.5.txt",
		        "sequence_path": "1603293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603293.protein.info.v11.5.txt",
		        "node_list_path": "1603293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1603293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusEquinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus equinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusEquinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525379.clusters.proteins.v11.5.txt",
		        "sequence_path": "525379.protein.sequences.v11.5.fa",
		        "enrichment_path": "525379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525379.protein.info.v11.5.txt",
		        "node_list_path": "525379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CnuibacterPhyscomitrellaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cnuibacter physcomitrellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CnuibacterPhyscomitrellaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619308.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619308.protein.info.v11.5.txt",
		        "node_list_path": "1619308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterGlycinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter glycinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterGlycinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582702.clusters.proteins.v11.5.txt",
		        "sequence_path": "582702.protein.sequences.v11.5.fa",
		        "enrichment_path": "582702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582702.protein.info.v11.5.txt",
		        "node_list_path": "582702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TannerellaSp6158faaCt1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tannerella sp. 6_1_58FAA_CT1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TannerellaSp6158faaCt1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665949.protein.sequences.v11.5.fa",
		        "enrichment_path": "665949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665949.protein.info.v11.5.txt",
		        "node_list_path": "665949.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollimonasSpOk242Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collimonas sp. OK242 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollimonasSpOk242Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798195.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798195.protein.info.v11.5.txt",
		        "node_list_path": "1798195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenibacterCertesii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arenibacter certesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenibacterCertesii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121011.protein.info.v11.5.txt",
		        "node_list_path": "1121011.protein.complete.v11.5.txt"
		    }
		]
    )()

def StachybotrysChlorohalonataIbt40285Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stachybotrys chlorohalonata IBT 40285 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StachybotrysChlorohalonataIbt40285Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1283841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1283841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1283841.clusters.proteins.v11.5.txt",
		        "sequence_path": "1283841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283841.protein.info.v11.5.txt",
		        "node_list_path": "1283841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1283841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSp166amftsuCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 166amftsu Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp166amftsuCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761753.protein.info.v11.5.txt",
		        "node_list_path": "1761753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeobacterSpCect5382Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter sp. CECT 5382 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterSpCect5382Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1712645.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1712645.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1712645.clusters.proteins.v11.5.txt",
		        "sequence_path": "1712645.protein.sequences.v11.5.fa",
		        "enrichment_path": "1712645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1712645.protein.info.v11.5.txt",
		        "node_list_path": "1712645.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1712645.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FerrovumSpPnJ185Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrovum sp. PN-J185 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrovumSpPnJ185Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1356306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1356306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1356306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1356306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1356306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1356306.protein.info.v11.5.txt",
		        "node_list_path": "1356306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1356306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasSpL53140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. L53140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSpL53140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1207058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1207058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1207058.protein.info.v11.5.txt",
		        "node_list_path": "1207058.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpYr477(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR477 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpYr477", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500295.protein.info.v11.5.txt",
		        "node_list_path": "1500295.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoccidioidesImmitisH5384(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis H538.4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesImmitisH5384", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "396776.protein.sequences.v11.5.fa",
		        "enrichment_path": "396776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396776.protein.info.v11.5.txt",
		        "node_list_path": "396776.protein.complete.v11.5.txt"
		    }
		]
    )()

def HafniaAlveiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hafnia alvei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HafniaAlveiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1453496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1453496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1453496.clusters.proteins.v11.5.txt",
		        "sequence_path": "1453496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453496.protein.info.v11.5.txt",
		        "node_list_path": "1453496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1453496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EikenellaSpNml02A017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eikenella sp. NML02-A-017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EikenellaSpNml02A017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1795827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1795827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1795827.clusters.proteins.v11.5.txt",
		        "sequence_path": "1795827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795827.protein.info.v11.5.txt",
		        "node_list_path": "1795827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1795827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LutibacterOricola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lutibacter oricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutibacterOricola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762486.protein.sequences.v11.5.fa",
		        "enrichment_path": "762486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762486.protein.info.v11.5.txt",
		        "node_list_path": "762486.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusFlavithermusYunnanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus yunnanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusFlavithermusYunnanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380408.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380408.protein.info.v11.5.txt",
		        "node_list_path": "1380408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimimonasHalophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limimonas halophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimimonasHalophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1082479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1082479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1082479.clusters.proteins.v11.5.txt",
		        "sequence_path": "1082479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1082479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1082479.protein.info.v11.5.txt",
		        "node_list_path": "1082479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1082479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NipponiaNipponCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nipponia nippon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NipponiaNipponCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "128390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "128390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "128390.clusters.proteins.v11.5.txt",
		        "sequence_path": "128390.protein.sequences.v11.5.fa",
		        "enrichment_path": "128390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "128390.protein.info.v11.5.txt",
		        "node_list_path": "128390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "128390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasCircumdentariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas circumdentaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasCircumdentariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29524.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29524.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29524.clusters.proteins.v11.5.txt",
		        "sequence_path": "29524.protein.sequences.v11.5.fa",
		        "enrichment_path": "29524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29524.protein.info.v11.5.txt",
		        "node_list_path": "29524.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29524.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UreaplasmaParvum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ureaplasma parvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UreaplasmaParvum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "273119.protein.sequences.v11.5.fa",
		        "enrichment_path": "273119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273119.protein.info.v11.5.txt",
		        "node_list_path": "273119.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionimicrobiumSpBv2f7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionimicrobium sp. BV2F7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionimicrobiumSpBv2f7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111131.protein.info.v11.5.txt",
		        "node_list_path": "1111131.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumCag3125820(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium CAG:312_58_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumCag3125820", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897025.protein.info.v11.5.txt",
		        "node_list_path": "1897025.protein.complete.v11.5.txt"
		    }
		]
    )()

def FragariaVescaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fragaria vesca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FragariaVescaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "57918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "57918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "57918.clusters.proteins.v11.5.txt",
		        "sequence_path": "57918.protein.sequences.v11.5.fa",
		        "enrichment_path": "57918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "57918.protein.info.v11.5.txt",
		        "node_list_path": "57918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "57918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSpCb01531Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora sp. CB01531 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSpCb01531Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1718947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1718947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1718947.clusters.proteins.v11.5.txt",
		        "sequence_path": "1718947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1718947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1718947.protein.info.v11.5.txt",
		        "node_list_path": "1718947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1718947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomaduraMacraNbrc14102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura macra NBRC 14102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraMacraNbrc14102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220564.protein.info.v11.5.txt",
		        "node_list_path": "1220564.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachionusPlicatilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachionus plicatilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachionusPlicatilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10195.protein.sequences.v11.5.fa",
		        "enrichment_path": "10195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10195.protein.info.v11.5.txt",
		        "node_list_path": "10195.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterPragensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter pragensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterPragensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1806892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806892.protein.info.v11.5.txt",
		        "node_list_path": "1806892.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacterSphaeroidesAtcc17025(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter sphaeroides ATCC17025 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterSphaeroidesAtcc17025", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349102.protein.sequences.v11.5.fa",
		        "enrichment_path": "349102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349102.protein.info.v11.5.txt",
		        "node_list_path": "349102.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgaricusBisporusVarBurnettiiJb137S8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agaricus bisporus var. burnettii JB137-S8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgaricusBisporusVarBurnettiiJb137S8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "597362.protein.sequences.v11.5.fa",
		        "enrichment_path": "597362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "597362.protein.info.v11.5.txt",
		        "node_list_path": "597362.protein.complete.v11.5.txt"
		    }
		]
    )()

def KurthiaSp11kri321(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kurthia sp. 11kri321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KurthiaSp11kri321", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1750719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1750719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1750719.protein.info.v11.5.txt",
		        "node_list_path": "1750719.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentisphaeraAraneosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaera araneosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraAraneosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313628.protein.sequences.v11.5.fa",
		        "enrichment_path": "313628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313628.protein.info.v11.5.txt",
		        "node_list_path": "313628.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioHarveyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio harveyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioHarveyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "669.clusters.info.v11.5.txt",
		        "cluster_tree_path": "669.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "669.clusters.proteins.v11.5.txt",
		        "sequence_path": "669.protein.sequences.v11.5.fa",
		        "enrichment_path": "669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "669.protein.info.v11.5.txt",
		        "node_list_path": "669.cluster.nodes.v11.5.txt",
		        "edge_list_path": "669.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwa26142Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_61_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwa26142Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797923.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797923.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797923.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797923.protein.info.v11.5.txt",
		        "node_list_path": "1797923.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797923.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpZxy2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ZXY-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpZxy2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1806905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1806905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1806905.clusters.proteins.v11.5.txt",
		        "sequence_path": "1806905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806905.protein.info.v11.5.txt",
		        "node_list_path": "1806905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1806905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusMisasensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus misasensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusMisasensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121382.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121382.protein.info.v11.5.txt",
		        "node_list_path": "1121382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OphiostomaPiceaeUamh11346(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ophiostoma piceae UAMH 11346 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiostomaPiceaeUamh11346", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262450.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262450.protein.info.v11.5.txt",
		        "node_list_path": "1262450.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriaSymbiontBfo1OfFrankliniellaOccidentalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo1 of Frankliniella occidentalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriaSymbiontBfo1OfFrankliniellaOccidentalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1628855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628855.protein.info.v11.5.txt",
		        "node_list_path": "1628855.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMethylopumilusPlanktonicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methylopumilus planktonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethylopumilusPlanktonicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1581557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1581557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1581557.clusters.proteins.v11.5.txt",
		        "sequence_path": "1581557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581557.protein.info.v11.5.txt",
		        "node_list_path": "1581557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1581557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinophagaRupis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga rupis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaRupis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573321.protein.sequences.v11.5.fa",
		        "enrichment_path": "573321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573321.protein.info.v11.5.txt",
		        "node_list_path": "573321.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAmyloliquefaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAmyloliquefaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326423.clusters.proteins.v11.5.txt",
		        "sequence_path": "326423.protein.sequences.v11.5.fa",
		        "enrichment_path": "326423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326423.protein.info.v11.5.txt",
		        "node_list_path": "326423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpCag611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpCag611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262905.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262905.protein.info.v11.5.txt",
		        "node_list_path": "1262905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpGxt6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. GXT6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpGxt6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "711393.protein.sequences.v11.5.fa",
		        "enrichment_path": "711393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "711393.protein.info.v11.5.txt",
		        "node_list_path": "711393.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErysipelatoclostridiumRamosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysipelatoclostridium ramosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelatoclostridiumRamosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445974.clusters.proteins.v11.5.txt",
		        "sequence_path": "445974.protein.sequences.v11.5.fa",
		        "enrichment_path": "445974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445974.protein.info.v11.5.txt",
		        "node_list_path": "445974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchaaliaMeyeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schaalia meyeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchaaliaMeyeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52773.clusters.proteins.v11.5.txt",
		        "sequence_path": "52773.protein.sequences.v11.5.fa",
		        "enrichment_path": "52773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52773.protein.info.v11.5.txt",
		        "node_list_path": "52773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaBuccaeAtcc33574(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccae ATCC33574 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBuccaeAtcc33574", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "873513.protein.sequences.v11.5.fa",
		        "enrichment_path": "873513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "873513.protein.info.v11.5.txt",
		        "node_list_path": "873513.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusViridansLl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus viridans LL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusViridansLl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1175629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1175629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1175629.protein.info.v11.5.txt",
		        "node_list_path": "1175629.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaPalmaeJ233(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma palmae J233 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaPalmaeJ233", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1318466.protein.sequences.v11.5.fa",
		        "enrichment_path": "1318466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1318466.protein.info.v11.5.txt",
		        "node_list_path": "1318466.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaAlcalifaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaAlcalifaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "520999.protein.sequences.v11.0.fa",
		        "enrichment_path": "520999.protein.enrichment.terms.v11.0.txt",
		        "info_path": "520999.protein.info.v11.0.txt",
		        "node_list_path": "520999.protein.complete.v11.0.txt"
		    }
		]
    )()

def NaumovozymaCastelliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma castellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NaumovozymaCastelliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "27288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "27288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "27288.clusters.proteins.v11.5.txt",
		        "sequence_path": "27288.protein.sequences.v11.5.fa",
		        "enrichment_path": "27288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27288.protein.info.v11.5.txt",
		        "node_list_path": "27288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "27288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumAlcoholivoraxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum alcoholivorax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumAlcoholivoraxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121422.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121422.protein.info.v11.5.txt",
		        "node_list_path": "1121422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermotogaSp5064(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga sp. 50_64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaSp5064", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635259.protein.info.v11.5.txt",
		        "node_list_path": "1635259.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCl6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CL6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCl6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499683.protein.info.v11.5.txt",
		        "node_list_path": "1499683.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanoplasmaTermitumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanoplasma termitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanoplasmaTermitumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577791.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577791.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577791.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577791.protein.info.v11.5.txt",
		        "node_list_path": "1577791.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577791.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiopsisSpCnr923Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. CNR-923 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisSpCnr923Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1904965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1904965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1904965.clusters.proteins.v11.5.txt",
		        "sequence_path": "1904965.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904965.protein.info.v11.5.txt",
		        "node_list_path": "1904965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1904965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpMc2013Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MC2013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpMc2013Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280686.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280686.protein.info.v11.5.txt",
		        "node_list_path": "1280686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSeleniipraecipitans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas seleniipraecipitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSeleniipraecipitans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "640205.protein.sequences.v11.5.fa",
		        "enrichment_path": "640205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640205.protein.info.v11.5.txt",
		        "node_list_path": "640205.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioPonticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ponticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioPonticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "265668.protein.sequences.v11.5.fa",
		        "enrichment_path": "265668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265668.protein.info.v11.5.txt",
		        "node_list_path": "265668.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiIai39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli IAI39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiIai39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585057.protein.sequences.v11.5.fa",
		        "enrichment_path": "585057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585057.protein.info.v11.5.txt",
		        "node_list_path": "585057.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusPanacihumiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus panacihumi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusPanacihumiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408254.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408254.protein.info.v11.5.txt",
		        "node_list_path": "1408254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCarsonellaRuddiiCsIsolateThao2000(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii CS isolate Thao2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCarsonellaRuddiiCsIsolateThao2000", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1202537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202537.protein.info.v11.5.txt",
		        "node_list_path": "1202537.protein.complete.v11.5.txt"
		    }
		]
    )()

def CamelinaSativaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Camelina sativa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CamelinaSativaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "90675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "90675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "90675.clusters.proteins.v11.5.txt",
		        "sequence_path": "90675.protein.sequences.v11.5.fa",
		        "enrichment_path": "90675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90675.protein.info.v11.5.txt",
		        "node_list_path": "90675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "90675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusGasseri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gasseri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGasseri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "324831.protein.sequences.v11.5.fa",
		        "enrichment_path": "324831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "324831.protein.info.v11.5.txt",
		        "node_list_path": "324831.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeeksellaVirosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weeksella virosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeeksellaVirosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "865938.clusters.info.v11.5.txt",
		        "cluster_tree_path": "865938.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "865938.clusters.proteins.v11.5.txt",
		        "sequence_path": "865938.protein.sequences.v11.5.fa",
		        "enrichment_path": "865938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "865938.protein.info.v11.5.txt",
		        "node_list_path": "865938.cluster.nodes.v11.5.txt",
		        "edge_list_path": "865938.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPortnoybacteriaBacteriumRbg19ftCombo367(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RBG_19FT_COMBO_36_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRbg19ftCombo367", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801992.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801992.protein.info.v11.5.txt",
		        "node_list_path": "1801992.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPabuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus pabuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPabuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1472.protein.sequences.v11.5.fa",
		        "enrichment_path": "1472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1472.protein.info.v11.5.txt",
		        "node_list_path": "1472.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumLuteumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium luteum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumLuteumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "421531.clusters.info.v11.5.txt",
		        "cluster_tree_path": "421531.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "421531.clusters.proteins.v11.5.txt",
		        "sequence_path": "421531.protein.sequences.v11.5.fa",
		        "enrichment_path": "421531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "421531.protein.info.v11.5.txt",
		        "node_list_path": "421531.cluster.nodes.v11.5.txt",
		        "edge_list_path": "421531.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensNz007(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens NZ007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensNz007", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "690597.protein.sequences.v11.5.fa",
		        "enrichment_path": "690597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690597.protein.info.v11.5.txt",
		        "node_list_path": "690597.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureimonasSpLeaf454(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf454 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpLeaf454", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736381.protein.info.v11.5.txt",
		        "node_list_path": "1736381.protein.complete.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpNele67Bin005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nele67-Bin005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpNele67Bin005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1764963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1764963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1764963.clusters.proteins.v11.5.txt",
		        "sequence_path": "1764963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1764963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1764963.protein.info.v11.5.txt",
		        "node_list_path": "1764963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1764963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwb25519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWB2_55_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwb25519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797814.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797814.protein.info.v11.5.txt",
		        "node_list_path": "1797814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusVillosusKin24T80(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus villosus KIN24-T80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusVillosusKin24T80", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1069083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069083.protein.info.v11.5.txt",
		        "node_list_path": "1069083.protein.complete.v11.5.txt"
		    }
		]
    )()

def FomitopsisRoseaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fomitopsis rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FomitopsisRoseaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34475.clusters.proteins.v11.5.txt",
		        "sequence_path": "34475.protein.sequences.v11.5.fa",
		        "enrichment_path": "34475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34475.protein.info.v11.5.txt",
		        "node_list_path": "34475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudopelagicolaGijangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudopelagicola gijangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudopelagicolaGijangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1470563.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1470563.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1470563.clusters.proteins.v11.5.txt",
		        "sequence_path": "1470563.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470563.protein.info.v11.5.txt",
		        "node_list_path": "1470563.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1470563.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsphigho201Full4522(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_01_FULL_45_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho201Full4522", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802114.protein.info.v11.5.txt",
		        "node_list_path": "1802114.protein.complete.v11.5.txt"
		    }
		]
    )()

def CupriavidusSpUsmaa24Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. USMAA2-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusSpUsmaa24Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "876364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "876364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "876364.clusters.proteins.v11.5.txt",
		        "sequence_path": "876364.protein.sequences.v11.5.fa",
		        "enrichment_path": "876364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "876364.protein.info.v11.5.txt",
		        "node_list_path": "876364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "876364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeophocaenaAsiaeorientalisAsiaeorientalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neophocaena asiaeorientalis asiaeorientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeophocaenaAsiaeorientalisAsiaeorientalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1706337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1706337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1706337.clusters.proteins.v11.5.txt",
		        "sequence_path": "1706337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1706337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1706337.protein.info.v11.5.txt",
		        "node_list_path": "1706337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1706337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag273Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:273 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag273Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262789.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262789.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262789.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262789.protein.info.v11.5.txt",
		        "node_list_path": "1262789.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262789.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaFungorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia fungorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaFungorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "134537.protein.sequences.v11.5.fa",
		        "enrichment_path": "134537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134537.protein.info.v11.5.txt",
		        "node_list_path": "134537.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyellaGinsengisoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyella ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaGinsengisoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1234364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234364.protein.info.v11.5.txt",
		        "node_list_path": "1234364.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumCg1023721(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium CG1_02_37_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumCg1023721", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805145.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805145.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805145.protein.info.v11.5.txt",
		        "node_list_path": "1805145.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusRuberCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusRuberCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "504800.clusters.info.v11.5.txt",
		        "cluster_tree_path": "504800.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "504800.clusters.proteins.v11.5.txt",
		        "sequence_path": "504800.protein.sequences.v11.5.fa",
		        "enrichment_path": "504800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504800.protein.info.v11.5.txt",
		        "node_list_path": "504800.cluster.nodes.v11.5.txt",
		        "edge_list_path": "504800.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusTianmuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus tianmuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusTianmuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "624147.protein.sequences.v11.5.fa",
		        "enrichment_path": "624147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "624147.protein.info.v11.5.txt",
		        "node_list_path": "624147.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanotheceSpPcc7424(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7424 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanotheceSpPcc7424", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "65393.protein.sequences.v11.5.fa",
		        "enrichment_path": "65393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65393.protein.info.v11.5.txt",
		        "node_list_path": "65393.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaGlumae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia glumae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaGlumae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "626418.protein.sequences.v11.5.fa",
		        "enrichment_path": "626418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626418.protein.info.v11.5.txt",
		        "node_list_path": "626418.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpF3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. F-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpF3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1840095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1840095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1840095.clusters.proteins.v11.5.txt",
		        "sequence_path": "1840095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1840095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1840095.protein.info.v11.5.txt",
		        "node_list_path": "1840095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1840095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpizellomycesPunctatusDaomBr117(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spizellomyces punctatus DAOM BR117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpizellomycesPunctatusDaomBr117", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "645134.protein.sequences.v11.5.fa",
		        "enrichment_path": "645134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645134.protein.info.v11.5.txt",
		        "node_list_path": "645134.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastococcusSaxobsidens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus saxobsidens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusSaxobsidens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1146883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1146883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1146883.protein.info.v11.5.txt",
		        "node_list_path": "1146883.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeptunomonasAntarctica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neptunomonas antarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptunomonasAntarctica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "619304.protein.sequences.v11.5.fa",
		        "enrichment_path": "619304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "619304.protein.info.v11.5.txt",
		        "node_list_path": "619304.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaSpCf038(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. CF038 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpCf038", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881045.protein.info.v11.5.txt",
		        "node_list_path": "1881045.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5630Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_56_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5630Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798499.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798499.protein.info.v11.5.txt",
		        "node_list_path": "1798499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalipigerThiooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salipiger thiooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalipigerThiooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "282683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "282683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "282683.clusters.proteins.v11.5.txt",
		        "sequence_path": "282683.protein.sequences.v11.5.fa",
		        "enrichment_path": "282683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "282683.protein.info.v11.5.txt",
		        "node_list_path": "282683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "282683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesObesiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes obesi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesObesiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118061.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118061.protein.info.v11.5.txt",
		        "node_list_path": "1118061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAeruginosaPao1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas aeruginosa PAO1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAeruginosaPao1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "208964.clusters.info.v11.5.txt",
		        "cluster_tree_path": "208964.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "208964.clusters.proteins.v11.5.txt",
		        "sequence_path": "208964.protein.sequences.v11.5.fa",
		        "enrichment_path": "208964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208964.protein.info.v11.5.txt",
		        "node_list_path": "208964.cluster.nodes.v11.5.txt",
		        "edge_list_path": "208964.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarineGroupIThaumarchaeoteScgcAaa799D11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote SCGC AAA799-D11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineGroupIThaumarchaeoteScgcAaa799D11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502291.protein.info.v11.5.txt",
		        "node_list_path": "1502291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSullae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sullae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSullae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041146.protein.info.v11.5.txt",
		        "node_list_path": "1041146.protein.complete.v11.5.txt"
		    }
		]
    )()

def ReyranellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Reyranella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ReyranellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1205680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1205680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1205680.protein.info.v11.5.txt",
		        "node_list_path": "1205680.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachanceaThermotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachancea thermotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachanceaThermotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "381046.clusters.info.v11.5.txt",
		        "cluster_tree_path": "381046.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "381046.clusters.proteins.v11.5.txt",
		        "sequence_path": "381046.protein.sequences.v11.5.fa",
		        "enrichment_path": "381046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381046.protein.info.v11.5.txt",
		        "node_list_path": "381046.cluster.nodes.v11.5.txt",
		        "edge_list_path": "381046.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFlectens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas flectens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFlectens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336237.protein.info.v11.5.txt",
		        "node_list_path": "1336237.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpIhbB17019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. IHB B 17019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpIhbB17019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1721091.protein.sequences.v11.5.fa",
		        "enrichment_path": "1721091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1721091.protein.info.v11.5.txt",
		        "node_list_path": "1721091.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerrimicrobiumAcidiphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferrimicrobium acidiphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrimicrobiumAcidiphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121877.protein.info.v11.5.txt",
		        "node_list_path": "1121877.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfurisporaThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurispora thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurisporaThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121472.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121472.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121472.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121472.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121472.protein.info.v11.5.txt",
		        "node_list_path": "1121472.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121472.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumJohnsoniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium johnsoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumJohnsoniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "376686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "376686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "376686.clusters.proteins.v11.5.txt",
		        "sequence_path": "376686.protein.sequences.v11.5.fa",
		        "enrichment_path": "376686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376686.protein.info.v11.5.txt",
		        "node_list_path": "376686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "376686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHimb058Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HIMB058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHimb058Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144932.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144932.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144932.protein.info.v11.5.txt",
		        "node_list_path": "1144932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa23710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_37_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa23710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618810.protein.info.v11.5.txt",
		        "node_list_path": "1618810.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusBackii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus backii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBackii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "375175.protein.sequences.v11.5.fa",
		        "enrichment_path": "375175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375175.protein.info.v11.5.txt",
		        "node_list_path": "375175.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaCinereaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria cinerea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaCinereaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546262.clusters.proteins.v11.5.txt",
		        "sequence_path": "546262.protein.sequences.v11.5.fa",
		        "enrichment_path": "546262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546262.protein.info.v11.5.txt",
		        "node_list_path": "546262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho201Full3717Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_37_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3717Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798588.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798588.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798588.protein.info.v11.5.txt",
		        "node_list_path": "1798588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacteriumSpPsu2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium sp. PSU-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacteriumSpPsu2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930849.protein.info.v11.5.txt",
		        "node_list_path": "1930849.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospirillalesBacteriumUrhd0017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium URHD0017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillalesBacteriumUrhd0017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380357.protein.info.v11.5.txt",
		        "node_list_path": "1380357.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteiniclasticumRuminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteiniclasticum ruminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteiniclasticumRuminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410668.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410668.protein.info.v11.5.txt",
		        "node_list_path": "1410668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HepatobacterPenaei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hepatobacter penaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HepatobacterPenaei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1274402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274402.protein.info.v11.5.txt",
		        "node_list_path": "1274402.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnhydraLutrisKenyoni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enhydra lutris kenyoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnhydraLutrisKenyoni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391180.protein.sequences.v11.5.fa",
		        "enrichment_path": "391180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391180.protein.info.v11.5.txt",
		        "node_list_path": "391180.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurvibacterSpGwa26395Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter sp. GWA2_63_95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurvibacterSpGwa26395Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797746.protein.info.v11.5.txt",
		        "node_list_path": "1797746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatabacterHongkongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catabacter hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatabacterHongkongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "270498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "270498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "270498.clusters.proteins.v11.5.txt",
		        "sequence_path": "270498.protein.sequences.v11.5.fa",
		        "enrichment_path": "270498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "270498.protein.info.v11.5.txt",
		        "node_list_path": "270498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "270498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_35_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801748.protein.info.v11.5.txt",
		        "node_list_path": "1801748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc23210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC2_32_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc23210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618918.protein.info.v11.5.txt",
		        "node_list_path": "1618918.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSputigenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sputigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSputigenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546271.clusters.proteins.v11.5.txt",
		        "sequence_path": "546271.protein.sequences.v11.5.fa",
		        "enrichment_path": "546271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546271.protein.info.v11.5.txt",
		        "node_list_path": "546271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaAmylovoraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia amylovora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaAmylovoraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665029.clusters.proteins.v11.5.txt",
		        "sequence_path": "665029.protein.sequences.v11.5.fa",
		        "enrichment_path": "665029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665029.protein.info.v11.5.txt",
		        "node_list_path": "665029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaAlhagiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea alhagi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaAlhagiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1891675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1891675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1891675.clusters.proteins.v11.5.txt",
		        "sequence_path": "1891675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891675.protein.info.v11.5.txt",
		        "node_list_path": "1891675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1891675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusFordiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus fordii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusFordiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121090.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121090.protein.info.v11.5.txt",
		        "node_list_path": "1121090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasInfelixCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas infelix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasInfelixCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679201.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679201.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679201.clusters.proteins.v11.5.txt",
		        "sequence_path": "679201.protein.sequences.v11.5.fa",
		        "enrichment_path": "679201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679201.protein.info.v11.5.txt",
		        "node_list_path": "679201.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679201.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumRifcsphigho201Full5025Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium RIFCSPHIGHO2_01_FULL_50_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumRifcsphigho201Full5025Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817722.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817722.protein.info.v11.5.txt",
		        "node_list_path": "1817722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpRoot935Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root935 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpRoot935Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736610.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736610.protein.info.v11.5.txt",
		        "node_list_path": "1736610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpPh3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. ph3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpPh3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118058.protein.info.v11.5.txt",
		        "node_list_path": "1118058.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasViridiflava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas viridiflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasViridiflava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33069.protein.sequences.v11.5.fa",
		        "enrichment_path": "33069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33069.protein.info.v11.5.txt",
		        "node_list_path": "33069.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaSabaudiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma sabaudiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaSabaudiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1276257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276257.protein.info.v11.5.txt",
		        "node_list_path": "1276257.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterLipolyticusBf04cf4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter lipolyticus BF04CF4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterLipolyticusBf04cf4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1046724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046724.protein.info.v11.5.txt",
		        "node_list_path": "1046724.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpF0473(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0473 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpF0473", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999423.protein.sequences.v11.5.fa",
		        "enrichment_path": "999423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999423.protein.info.v11.5.txt",
		        "node_list_path": "999423.protein.complete.v11.5.txt"
		    }
		]
    )()

def PontibacterActiniarumDsm19842(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter actiniarum DSM 19842 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterActiniarumDsm19842", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "709015.protein.sequences.v11.5.fa",
		        "enrichment_path": "709015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709015.protein.info.v11.5.txt",
		        "node_list_path": "709015.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0337(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0337 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0337", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "706439.protein.sequences.v11.5.fa",
		        "enrichment_path": "706439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706439.protein.info.v11.5.txt",
		        "node_list_path": "706439.protein.complete.v11.5.txt"
		    }
		]
    )()

def DenitrobacteriumDetoxificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Denitrobacterium detoxificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DenitrobacteriumDetoxificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "79604.protein.sequences.v11.5.fa",
		        "enrichment_path": "79604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79604.protein.info.v11.5.txt",
		        "node_list_path": "79604.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaPutida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia putida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaPutida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1141883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141883.protein.info.v11.5.txt",
		        "node_list_path": "1141883.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusXylanexedensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus xylanexedens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusXylanexedensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "528191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "528191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "528191.clusters.proteins.v11.5.txt",
		        "sequence_path": "528191.protein.sequences.v11.5.fa",
		        "enrichment_path": "528191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "528191.protein.info.v11.5.txt",
		        "node_list_path": "528191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "528191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycesLimnophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces limnophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycesLimnophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521674.protein.sequences.v11.5.fa",
		        "enrichment_path": "521674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521674.protein.info.v11.5.txt",
		        "node_list_path": "521674.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrancisellaSpTx077308(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella sp. TX077308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaSpTx077308", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573569.protein.sequences.v11.5.fa",
		        "enrichment_path": "573569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573569.protein.info.v11.5.txt",
		        "node_list_path": "573569.protein.complete.v11.5.txt"
		    }
		]
    )()

def FervidobacteriumNodosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium nodosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidobacteriumNodosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "381764.protein.sequences.v11.5.fa",
		        "enrichment_path": "381764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381764.protein.info.v11.5.txt",
		        "node_list_path": "381764.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridioidesMangenotiiLm2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridioides mangenotii LM2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridioidesMangenotiiLm2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392497.protein.info.v11.5.txt",
		        "node_list_path": "1392497.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnabaenaSpPcc7108Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anabaena sp. PCC7108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabaenaSpPcc7108Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "163908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "163908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "163908.clusters.proteins.v11.5.txt",
		        "sequence_path": "163908.protein.sequences.v11.5.fa",
		        "enrichment_path": "163908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "163908.protein.info.v11.5.txt",
		        "node_list_path": "163908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "163908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumPerfringensStr13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium perfringens str. 13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPerfringensStr13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "195102.protein.sequences.v11.5.fa",
		        "enrichment_path": "195102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195102.protein.info.v11.5.txt",
		        "node_list_path": "195102.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumAntarcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumAntarcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1358423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1358423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1358423.clusters.proteins.v11.5.txt",
		        "sequence_path": "1358423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1358423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1358423.protein.info.v11.5.txt",
		        "node_list_path": "1358423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1358423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HippocampusComes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hippocampus comes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HippocampusComes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "109280.protein.sequences.v11.5.fa",
		        "enrichment_path": "109280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109280.protein.info.v11.5.txt",
		        "node_list_path": "109280.protein.complete.v11.5.txt"
		    }
		]
    )()

def TropicibacterNaphthalenivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tropicibacter naphthalenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TropicibacterNaphthalenivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "441103.protein.sequences.v11.5.fa",
		        "enrichment_path": "441103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441103.protein.info.v11.5.txt",
		        "node_list_path": "441103.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4234(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_12_FULL_42_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4234", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802314.protein.info.v11.5.txt",
		        "node_list_path": "1802314.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpNe3005(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. ne3005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpNe3005", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761887.protein.info.v11.5.txt",
		        "node_list_path": "1761887.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusBombycisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus bombycis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusBombycisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "109264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "109264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "109264.clusters.proteins.v11.5.txt",
		        "sequence_path": "109264.protein.sequences.v11.5.fa",
		        "enrichment_path": "109264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109264.protein.info.v11.5.txt",
		        "node_list_path": "109264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "109264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesKebangsaanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces kebangsaanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesKebangsaanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "864058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "864058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "864058.clusters.proteins.v11.5.txt",
		        "sequence_path": "864058.protein.sequences.v11.5.fa",
		        "enrichment_path": "864058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864058.protein.info.v11.5.txt",
		        "node_list_path": "864058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "864058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumChkci001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium CHKCI001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumChkci001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1780378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780378.protein.info.v11.5.txt",
		        "node_list_path": "1780378.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumGubbeenenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium gubbeenense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumGubbeenenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122237.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122237.protein.info.v11.5.txt",
		        "node_list_path": "1122237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SediminibacteriumSpOr53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium sp. OR53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacteriumSpOr53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "925409.protein.sequences.v11.5.fa",
		        "enrichment_path": "925409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "925409.protein.info.v11.5.txt",
		        "node_list_path": "925409.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovibacillusThermophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novibacillus thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovibacillusThermophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1471761.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1471761.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1471761.clusters.proteins.v11.5.txt",
		        "sequence_path": "1471761.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471761.protein.info.v11.5.txt",
		        "node_list_path": "1471761.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1471761.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumSubtropicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium subtropicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumSubtropicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1638989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638989.protein.info.v11.5.txt",
		        "node_list_path": "1638989.protein.complete.v11.5.txt"
		    }
		]
    )()

def UncinocarpusReesiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Uncinocarpus reesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UncinocarpusReesiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33188.clusters.proteins.v11.5.txt",
		        "sequence_path": "33188.protein.sequences.v11.5.fa",
		        "enrichment_path": "33188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33188.protein.info.v11.5.txt",
		        "node_list_path": "33188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OxalobacterFormigenesHoxbls(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes HOxBLS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OxalobacterFormigenesHoxbls", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "556268.protein.sequences.v11.5.fa",
		        "enrichment_path": "556268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556268.protein.info.v11.5.txt",
		        "node_list_path": "556268.protein.complete.v11.5.txt"
		    }
		]
    )()

def SmittiumCulicis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Smittium culicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmittiumCulicis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "133412.protein.sequences.v11.5.fa",
		        "enrichment_path": "133412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133412.protein.info.v11.5.txt",
		        "node_list_path": "133412.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobacteraceaeBacterium4572351(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium 4572_35.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteraceaeBacterium4572351", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1971627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971627.protein.info.v11.5.txt",
		        "node_list_path": "1971627.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTokpelaiaHoelldobleriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tokpelaia hoelldoblerii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTokpelaiaHoelldobleriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1902579.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1902579.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1902579.clusters.proteins.v11.5.txt",
		        "sequence_path": "1902579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1902579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1902579.protein.info.v11.5.txt",
		        "node_list_path": "1902579.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1902579.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumAe2021Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium AE2021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumAe2021Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392491.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392491.protein.info.v11.5.txt",
		        "node_list_path": "1392491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EuryarchaeotaArchaeonJdfr21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon JdFR-21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EuryarchaeotaArchaeonJdfr21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935139.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935139.protein.info.v11.5.txt",
		        "node_list_path": "1935139.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpEprs66Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. EpRS66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpEprs66Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1743140.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1743140.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1743140.clusters.proteins.v11.5.txt",
		        "sequence_path": "1743140.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743140.protein.info.v11.5.txt",
		        "node_list_path": "1743140.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1743140.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaMobile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma mobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaMobile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "267748.protein.sequences.v11.5.fa",
		        "enrichment_path": "267748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267748.protein.info.v11.5.txt",
		        "node_list_path": "267748.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnasPlatyrhynchosPlatyrhynchosCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anas platyrhynchos platyrhynchos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnasPlatyrhynchosPlatyrhynchosCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8840.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8840.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8840.clusters.proteins.v11.5.txt",
		        "sequence_path": "8840.protein.sequences.v11.5.fa",
		        "enrichment_path": "8840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8840.protein.info.v11.5.txt",
		        "node_list_path": "8840.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8840.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaSalsinemoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina salsinemoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSalsinemoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "577470.protein.sequences.v11.5.fa",
		        "enrichment_path": "577470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "577470.protein.info.v11.5.txt",
		        "node_list_path": "577470.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaKrabiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora krabiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaKrabiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "307121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "307121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "307121.clusters.proteins.v11.5.txt",
		        "sequence_path": "307121.protein.sequences.v11.5.fa",
		        "enrichment_path": "307121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "307121.protein.info.v11.5.txt",
		        "node_list_path": "307121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "307121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinoplanesPhilippinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes philippinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesPhilippinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35752.clusters.proteins.v11.5.txt",
		        "sequence_path": "35752.protein.sequences.v11.5.fa",
		        "enrichment_path": "35752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35752.protein.info.v11.5.txt",
		        "node_list_path": "35752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAbyssalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces abyssalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAbyssalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "933944.protein.sequences.v11.5.fa",
		        "enrichment_path": "933944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933944.protein.info.v11.5.txt",
		        "node_list_path": "933944.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusInfluenzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus influenzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusInfluenzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "71421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "71421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "71421.clusters.proteins.v11.5.txt",
		        "sequence_path": "71421.protein.sequences.v11.5.fa",
		        "enrichment_path": "71421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "71421.protein.info.v11.5.txt",
		        "node_list_path": "71421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "71421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlleyaSpVcsa23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olleya sp. VCSA23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlleyaSpVcsa23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "745717.protein.sequences.v11.5.fa",
		        "enrichment_path": "745717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745717.protein.info.v11.5.txt",
		        "node_list_path": "745717.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacaedibacterSymbiosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracaedibacter symbiosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacaedibacterSymbiosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "244582.protein.sequences.v11.5.fa",
		        "enrichment_path": "244582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244582.protein.info.v11.5.txt",
		        "node_list_path": "244582.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp32133Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3213.3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp32133Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855348.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855348.protein.info.v11.5.txt",
		        "node_list_path": "1855348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfacinumInfernumDsm9756(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfacinum infernum DSM 9756 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfacinumInfernumDsm9756", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121391.protein.info.v11.5.txt",
		        "node_list_path": "1121391.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSilaceusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces silaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSilaceusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "545123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "545123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "545123.clusters.proteins.v11.5.txt",
		        "sequence_path": "545123.protein.sequences.v11.5.fa",
		        "enrichment_path": "545123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545123.protein.info.v11.5.txt",
		        "node_list_path": "545123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "545123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermovirgaLienii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermovirga lienii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermovirgaLienii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "580340.protein.sequences.v11.5.fa",
		        "enrichment_path": "580340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "580340.protein.info.v11.5.txt",
		        "node_list_path": "580340.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4558(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4558 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4558", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977876.protein.info.v11.5.txt",
		        "node_list_path": "1977876.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanothermusFervidusDsm2088(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanothermus fervidus DSM 2088 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermusFervidusDsm2088", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "523846.protein.sequences.v11.5.fa",
		        "enrichment_path": "523846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523846.protein.info.v11.5.txt",
		        "node_list_path": "523846.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaballeroniaHypogeiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia hypogeia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaHypogeiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777140.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777140.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777140.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777140.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777140.protein.info.v11.5.txt",
		        "node_list_path": "1777140.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777140.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpNuni2hMbin003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nuni2H_MBin003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpNuni2hMbin003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884657.protein.info.v11.5.txt",
		        "node_list_path": "1884657.protein.complete.v11.5.txt"
		    }
		]
    )()

def EremococcusColeocolaDsm15696(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eremococcus coleocola DSM15696 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremococcusColeocolaDsm15696", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121871.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121871.protein.info.v11.5.txt",
		        "node_list_path": "1121871.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpUrhc0008Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. URHC0008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpUrhc0008Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380350.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380350.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380350.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380350.protein.info.v11.5.txt",
		        "node_list_path": "1380350.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380350.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSuccinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus succinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSuccinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61015.clusters.proteins.v11.5.txt",
		        "sequence_path": "61015.protein.sequences.v11.5.fa",
		        "enrichment_path": "61015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61015.protein.info.v11.5.txt",
		        "node_list_path": "61015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlagellimonasEckloniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flagellimonas eckloniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlagellimonasEckloniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "346185.clusters.info.v11.5.txt",
		        "cluster_tree_path": "346185.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "346185.clusters.proteins.v11.5.txt",
		        "sequence_path": "346185.protein.sequences.v11.5.fa",
		        "enrichment_path": "346185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "346185.protein.info.v11.5.txt",
		        "node_list_path": "346185.cluster.nodes.v11.5.txt",
		        "edge_list_path": "346185.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasCampestrisMusacearumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris musacearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCampestrisMusacearumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094184.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094184.protein.info.v11.5.txt",
		        "node_list_path": "1094184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiUmn026Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli UMN026 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiUmn026Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585056.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585056.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585056.clusters.proteins.v11.5.txt",
		        "sequence_path": "585056.protein.sequences.v11.5.fa",
		        "enrichment_path": "585056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585056.protein.info.v11.5.txt",
		        "node_list_path": "585056.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585056.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VulcanisaetaDistributa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vulcanisaeta distributa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulcanisaetaDistributa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "572478.protein.sequences.v11.5.fa",
		        "enrichment_path": "572478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572478.protein.info.v11.5.txt",
		        "node_list_path": "572478.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpMl3wCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. ML3W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpMl3wCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1538644.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1538644.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1538644.clusters.proteins.v11.5.txt",
		        "sequence_path": "1538644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1538644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1538644.protein.info.v11.5.txt",
		        "node_list_path": "1538644.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1538644.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumBranchiophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium branchiophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumBranchiophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1034807.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1034807.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1034807.clusters.proteins.v11.5.txt",
		        "sequence_path": "1034807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034807.protein.info.v11.5.txt",
		        "node_list_path": "1034807.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1034807.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasLevii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas levii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasLevii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122973.protein.info.v11.5.txt",
		        "node_list_path": "1122973.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegasphaeraCerevisiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera cerevisiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraCerevisiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39029.clusters.proteins.v11.5.txt",
		        "sequence_path": "39029.protein.sequences.v11.5.fa",
		        "enrichment_path": "39029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39029.protein.info.v11.5.txt",
		        "node_list_path": "39029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaAnisaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella anisa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaAnisaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230343.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230343.protein.info.v11.5.txt",
		        "node_list_path": "1230343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaMayoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia mayonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaMayoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674146.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674146.protein.info.v11.5.txt",
		        "node_list_path": "1674146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterLongus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter longus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterLongus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1044.protein.info.v11.5.txt",
		        "node_list_path": "1044.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaceaeBacteriumIbvucb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium IBVUCB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaceaeBacteriumIbvucb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1985173.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1985173.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1985173.clusters.proteins.v11.5.txt",
		        "sequence_path": "1985173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1985173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1985173.protein.info.v11.5.txt",
		        "node_list_path": "1985173.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1985173.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VulcanisaetaMoutnovskiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vulcanisaeta moutnovskia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulcanisaetaMoutnovskiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "985053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "985053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "985053.clusters.proteins.v11.5.txt",
		        "sequence_path": "985053.protein.sequences.v11.5.fa",
		        "enrichment_path": "985053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985053.protein.info.v11.5.txt",
		        "node_list_path": "985053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "985053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterMarensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter marensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterMarensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "543877.protein.sequences.v11.5.fa",
		        "enrichment_path": "543877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543877.protein.info.v11.5.txt",
		        "node_list_path": "543877.protein.complete.v11.5.txt"
		    }
		]
    )()

def RathayibacterTriticiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rathayibacter tritici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RathayibacterTriticiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33888.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33888.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33888.clusters.proteins.v11.5.txt",
		        "sequence_path": "33888.protein.sequences.v11.5.fa",
		        "enrichment_path": "33888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33888.protein.info.v11.5.txt",
		        "node_list_path": "33888.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33888.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosocosmicusOleophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosocosmicus oleophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosocosmicusOleophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1353260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353260.protein.info.v11.5.txt",
		        "node_list_path": "1353260.protein.complete.v11.5.txt"
		    }
		]
    )()

def TatumellaPtyseos(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tatumella ptyseos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TatumellaPtyseos", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005995.protein.info.v11.5.txt",
		        "node_list_path": "1005995.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynergistesJonesii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synergistes jonesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynergistesJonesii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2754.protein.sequences.v11.5.fa",
		        "enrichment_path": "2754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2754.protein.info.v11.5.txt",
		        "node_list_path": "2754.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseochromogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseochromogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseochromogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68214.clusters.proteins.v11.5.txt",
		        "sequence_path": "68214.protein.sequences.v11.5.fa",
		        "enrichment_path": "68214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68214.protein.info.v11.5.txt",
		        "node_list_path": "68214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GluconobacterJaponicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterJaponicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "376620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "376620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "376620.clusters.proteins.v11.5.txt",
		        "sequence_path": "376620.protein.sequences.v11.5.fa",
		        "enrichment_path": "376620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376620.protein.info.v11.5.txt",
		        "node_list_path": "376620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "376620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisOrientalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisOrientalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125971.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125971.protein.info.v11.5.txt",
		        "node_list_path": "1125971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterLitoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterLitoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "335975.protein.sequences.v11.5.fa",
		        "enrichment_path": "335975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335975.protein.info.v11.5.txt",
		        "node_list_path": "335975.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaMultiformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella multiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMultiformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888743.protein.sequences.v11.5.fa",
		        "enrichment_path": "888743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888743.protein.info.v11.5.txt",
		        "node_list_path": "888743.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusOkhensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus okhensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusOkhensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "333138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "333138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "333138.clusters.proteins.v11.5.txt",
		        "sequence_path": "333138.protein.sequences.v11.5.fa",
		        "enrichment_path": "333138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "333138.protein.info.v11.5.txt",
		        "node_list_path": "333138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "333138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSmithii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus smithii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSmithii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665952.protein.sequences.v11.5.fa",
		        "enrichment_path": "665952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665952.protein.info.v11.5.txt",
		        "node_list_path": "665952.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumRhizosphaerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumRhizosphaerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "346179.protein.sequences.v11.5.fa",
		        "enrichment_path": "346179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "346179.protein.info.v11.5.txt",
		        "node_list_path": "346179.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCellulolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cellulolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCellulolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "394503.protein.sequences.v11.5.fa",
		        "enrichment_path": "394503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394503.protein.info.v11.5.txt",
		        "node_list_path": "394503.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaballeroniaMegalochromosomata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia megalochromosomata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaMegalochromosomata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1399969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399969.protein.info.v11.5.txt",
		        "node_list_path": "1399969.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusOligofermentansDsm15707Lmg22743Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oligofermentans DSM 15707 LMG 22743 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOligofermentansDsm15707Lmg22743Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423778.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423778.protein.info.v11.5.txt",
		        "node_list_path": "1423778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumImcc26256Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium IMCC26256 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumImcc26256Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1650658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1650658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1650658.clusters.proteins.v11.5.txt",
		        "sequence_path": "1650658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1650658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1650658.protein.info.v11.5.txt",
		        "node_list_path": "1650658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1650658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenalcaligenesHominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenalcaligenes hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenalcaligenesHominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "643674.clusters.info.v11.5.txt",
		        "cluster_tree_path": "643674.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "643674.clusters.proteins.v11.5.txt",
		        "sequence_path": "643674.protein.sequences.v11.5.fa",
		        "enrichment_path": "643674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "643674.protein.info.v11.5.txt",
		        "node_list_path": "643674.cluster.nodes.v11.5.txt",
		        "edge_list_path": "643674.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpAbg(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. ABG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpAbg", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423322.protein.info.v11.5.txt",
		        "node_list_path": "1423322.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrialbaMagadii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrialba magadii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaMagadii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "547559.protein.sequences.v11.5.fa",
		        "enrichment_path": "547559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547559.protein.info.v11.5.txt",
		        "node_list_path": "547559.protein.complete.v11.5.txt"
		    }
		]
    )()

def PediococcusEthanolidurans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus ethanolidurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusEthanolidurans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "319653.protein.sequences.v11.5.fa",
		        "enrichment_path": "319653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319653.protein.info.v11.5.txt",
		        "node_list_path": "319653.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeitlerinemaSpPcc9228Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC 9228 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeitlerinemaSpPcc9228Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "111611.clusters.info.v11.5.txt",
		        "cluster_tree_path": "111611.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "111611.clusters.proteins.v11.5.txt",
		        "sequence_path": "111611.protein.sequences.v11.5.fa",
		        "enrichment_path": "111611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "111611.protein.info.v11.5.txt",
		        "node_list_path": "111611.cluster.nodes.v11.5.txt",
		        "edge_list_path": "111611.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarineActinobacteriumMedacidiG2aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G2A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineActinobacteriumMedacidiG2aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1550400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1550400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1550400.clusters.proteins.v11.5.txt",
		        "sequence_path": "1550400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550400.protein.info.v11.5.txt",
		        "node_list_path": "1550400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1550400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusFaecalisV583(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecalis V583 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusFaecalisV583", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "226185.protein.sequences.v11.5.fa",
		        "enrichment_path": "226185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226185.protein.info.v11.5.txt",
		        "node_list_path": "226185.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCf386Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. cf386 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCf386Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761904.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761904.protein.info.v11.5.txt",
		        "node_list_path": "1761904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaValaisianaTom4006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia valaisiana Tom4006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaValaisianaTom4006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1398491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1398491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1398491.clusters.proteins.v11.5.txt",
		        "sequence_path": "1398491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1398491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1398491.protein.info.v11.5.txt",
		        "node_list_path": "1398491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1398491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSiliginis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus siliginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSiliginis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "348151.protein.sequences.v11.5.fa",
		        "enrichment_path": "348151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "348151.protein.info.v11.5.txt",
		        "node_list_path": "348151.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasIndica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasIndica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "428993.protein.sequences.v11.5.fa",
		        "enrichment_path": "428993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428993.protein.info.v11.5.txt",
		        "node_list_path": "428993.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumAcamd2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium acAMD-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumAcamd2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1504318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1504318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1504318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1504318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504318.protein.info.v11.5.txt",
		        "node_list_path": "1504318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1504318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraJaponica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraJaponica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1325564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325564.protein.info.v11.5.txt",
		        "node_list_path": "1325564.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitreicellaSp357Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citreicella sp. 357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitreicellaSp357Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "766499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "766499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "766499.clusters.proteins.v11.5.txt",
		        "sequence_path": "766499.protein.sequences.v11.5.fa",
		        "enrichment_path": "766499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "766499.protein.info.v11.5.txt",
		        "node_list_path": "766499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "766499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FomitopsisPinicolaFp58527Ss1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fomitopsis pinicola FP-58527 SS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FomitopsisPinicolaFp58527Ss1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743788.protein.sequences.v11.5.fa",
		        "enrichment_path": "743788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743788.protein.info.v11.5.txt",
		        "node_list_path": "743788.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassolituusOleivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassolituus oleivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassolituusOleivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298593.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298593.protein.info.v11.5.txt",
		        "node_list_path": "1298593.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpHl111(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. HL-111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpHl111", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798193.protein.info.v11.5.txt",
		        "node_list_path": "1798193.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusSaccharolyticusJop10301Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus saccharolyticus JOP 1030-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusSaccharolyticusJop10301Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1450539.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1450539.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1450539.clusters.proteins.v11.5.txt",
		        "sequence_path": "1450539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450539.protein.info.v11.5.txt",
		        "node_list_path": "1450539.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1450539.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemellaSanguinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemella sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaSanguinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "562983.protein.sequences.v11.5.fa",
		        "enrichment_path": "562983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562983.protein.info.v11.5.txt",
		        "node_list_path": "562983.protein.complete.v11.5.txt"
		    }
		]
    )()

def VaribaculumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaribaculumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852372.protein.info.v11.5.txt",
		        "node_list_path": "1852372.protein.complete.v11.5.txt"
		    }
		]
    )()

def CognatishimiaMaritimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cognatishimia maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CognatishimiaMaritimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "870908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "870908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "870908.clusters.proteins.v11.5.txt",
		        "sequence_path": "870908.protein.sequences.v11.5.fa",
		        "enrichment_path": "870908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "870908.protein.info.v11.5.txt",
		        "node_list_path": "870908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "870908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeptunomonasJaponica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neptunomonas japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptunomonasJaponica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122599.protein.info.v11.5.txt",
		        "node_list_path": "1122599.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasMonteilii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas monteilii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMonteilii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "76759.protein.sequences.v11.5.fa",
		        "enrichment_path": "76759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76759.protein.info.v11.5.txt",
		        "node_list_path": "76759.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpAtcc6931(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. ATCC6931 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpAtcc6931", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1487956.protein.sequences.v11.5.fa",
		        "enrichment_path": "1487956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1487956.protein.info.v11.5.txt",
		        "node_list_path": "1487956.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpNb77(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. NB77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpNb77", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1342301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1342301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1342301.protein.info.v11.5.txt",
		        "node_list_path": "1342301.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpCcge1003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpCcge1003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "640512.protein.sequences.v11.5.fa",
		        "enrichment_path": "640512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640512.protein.info.v11.5.txt",
		        "node_list_path": "640512.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumGwa2478Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_47_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa2478Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801840.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801840.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801840.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801840.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801840.protein.info.v11.5.txt",
		        "node_list_path": "1801840.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801840.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpUsba49(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. USBA 49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpUsba49", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881060.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881060.protein.info.v11.5.txt",
		        "node_list_path": "1881060.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaSpHmsc062g07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella sp. HMSC062G07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaSpHmsc062g07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739330.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739330.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739330.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739330.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739330.protein.info.v11.5.txt",
		        "node_list_path": "1739330.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739330.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaGranularumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma granularum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaGranularumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278304.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278304.protein.info.v11.5.txt",
		        "node_list_path": "1278304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TraorellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Traorella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TraorellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1903263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903263.protein.info.v11.5.txt",
		        "node_list_path": "1903263.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErysiphePulchra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erysiphe pulchra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysiphePulchra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "225359.protein.sequences.v11.5.fa",
		        "enrichment_path": "225359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225359.protein.info.v11.5.txt",
		        "node_list_path": "225359.protein.complete.v11.5.txt"
		    }
		]
    )()

def SordariaMacrosporaKHell(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sordaria macrospora k-hell graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SordariaMacrosporaKHell", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "771870.protein.sequences.v11.5.fa",
		        "enrichment_path": "771870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "771870.protein.info.v11.5.txt",
		        "node_list_path": "771870.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpCc9311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpCc9311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "64471.protein.sequences.v11.5.fa",
		        "enrichment_path": "64471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64471.protein.info.v11.5.txt",
		        "node_list_path": "64471.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumChubuenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium chubuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumChubuenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "710421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "710421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "710421.clusters.proteins.v11.5.txt",
		        "sequence_path": "710421.protein.sequences.v11.5.fa",
		        "enrichment_path": "710421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710421.protein.info.v11.5.txt",
		        "node_list_path": "710421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "710421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorDanielii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor danielii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorDanielii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1387557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387557.protein.info.v11.5.txt",
		        "node_list_path": "1387557.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaSpPsnih1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. PSNIH1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpPsnih1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1484158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1484158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1484158.clusters.proteins.v11.5.txt",
		        "sequence_path": "1484158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484158.protein.info.v11.5.txt",
		        "node_list_path": "1484158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1484158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzospirillumHumicireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum humicireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumHumicireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1226968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1226968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1226968.protein.info.v11.5.txt",
		        "node_list_path": "1226968.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobiBacteriumOlb4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobi bacterium OLB4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiBacteriumOlb4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617411.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617411.protein.info.v11.5.txt",
		        "node_list_path": "1617411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermanaerovibrioAcidaminovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermanaerovibrio acidaminovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermanaerovibrioAcidaminovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525903.protein.sequences.v11.5.fa",
		        "enrichment_path": "525903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525903.protein.info.v11.5.txt",
		        "node_list_path": "525903.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesOctosporus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces octosporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesOctosporus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4899.protein.sequences.v11.5.fa",
		        "enrichment_path": "4899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4899.protein.info.v11.5.txt",
		        "node_list_path": "4899.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWallbacteriaBacteriumGwc24935Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wallbacteria bacterium GWC2_49_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWallbacteriaBacteriumGwc24935Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817813.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817813.protein.info.v11.5.txt",
		        "node_list_path": "1817813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumThermocisternumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum thermocisternum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumThermocisternumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121430.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121430.protein.info.v11.5.txt",
		        "node_list_path": "1121430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DichomitusSqualensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dichomitus squalens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DichomitusSqualensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "114155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "114155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "114155.clusters.proteins.v11.5.txt",
		        "sequence_path": "114155.protein.sequences.v11.5.fa",
		        "enrichment_path": "114155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "114155.protein.info.v11.5.txt",
		        "node_list_path": "114155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "114155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterArcticusA12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter arcticus A12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterArcticusA12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206103.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206103.protein.info.v11.5.txt",
		        "node_list_path": "1206103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterHominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterHominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "360107.protein.sequences.v11.5.fa",
		        "enrichment_path": "360107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360107.protein.info.v11.5.txt",
		        "node_list_path": "360107.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfobacillusAcidophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfobacillus acidophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfobacillusAcidophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1051632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051632.protein.info.v11.5.txt",
		        "node_list_path": "1051632.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCb02488Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB02488 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCb02488Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703920.protein.info.v11.5.txt",
		        "node_list_path": "1703920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenovibrioMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenovibrio marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenovibrioMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28885.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28885.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28885.clusters.proteins.v11.5.txt",
		        "sequence_path": "28885.protein.sequences.v11.5.fa",
		        "enrichment_path": "28885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28885.protein.info.v11.5.txt",
		        "node_list_path": "28885.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28885.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsplowo212Full3610(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO2_12_FULL_36_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo212Full3610", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802630.protein.info.v11.5.txt",
		        "node_list_path": "1802630.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaSpAtcc39006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. ATCC39006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpAtcc39006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "104623.clusters.info.v11.5.txt",
		        "cluster_tree_path": "104623.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "104623.clusters.proteins.v11.5.txt",
		        "sequence_path": "104623.protein.sequences.v11.5.fa",
		        "enrichment_path": "104623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104623.protein.info.v11.5.txt",
		        "node_list_path": "104623.cluster.nodes.v11.5.txt",
		        "edge_list_path": "104623.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag138Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:138 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag138Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262775.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262775.protein.info.v11.5.txt",
		        "node_list_path": "1262775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPlatensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces platensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPlatensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "58346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "58346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "58346.clusters.proteins.v11.5.txt",
		        "sequence_path": "58346.protein.sequences.v11.5.fa",
		        "enrichment_path": "58346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58346.protein.info.v11.5.txt",
		        "node_list_path": "58346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "58346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusWentiiDto134e9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus wentii DTO 134E9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusWentiiDto134e9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1073089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073089.protein.info.v11.5.txt",
		        "node_list_path": "1073089.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpTc228Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. tc2-28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpTc228Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761888.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761888.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761888.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761888.protein.info.v11.5.txt",
		        "node_list_path": "1761888.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761888.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MobilicoccusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobilicoccus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobilicoccusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1522310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1522310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1522310.clusters.proteins.v11.5.txt",
		        "sequence_path": "1522310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522310.protein.info.v11.5.txt",
		        "node_list_path": "1522310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1522310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho201Full399(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_39_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full399", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801735.protein.info.v11.5.txt",
		        "node_list_path": "1801735.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlossinaAusteniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glossina austeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlossinaAusteniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7395.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7395.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7395.clusters.proteins.v11.5.txt",
		        "sequence_path": "7395.protein.sequences.v11.5.fa",
		        "enrichment_path": "7395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7395.protein.info.v11.5.txt",
		        "node_list_path": "7395.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7395.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpBplanCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. BPLAN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpBplanCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "600809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "600809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "600809.clusters.proteins.v11.5.txt",
		        "sequence_path": "600809.protein.sequences.v11.5.fa",
		        "enrichment_path": "600809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "600809.protein.info.v11.5.txt",
		        "node_list_path": "600809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "600809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusHaemolyticusM21621(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M21621 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusHaemolyticusM21621", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1028805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028805.protein.info.v11.5.txt",
		        "node_list_path": "1028805.protein.complete.v11.5.txt"
		    }
		]
    )()

def PerlucidibacaPiscinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Perlucidibaca piscinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PerlucidibacaPiscinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122951.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122951.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122951.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122951.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122951.protein.info.v11.5.txt",
		        "node_list_path": "1122951.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122951.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusJannaschiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus jannaschii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusJannaschiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243232.clusters.proteins.v11.5.txt",
		        "sequence_path": "243232.protein.sequences.v11.5.fa",
		        "enrichment_path": "243232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243232.protein.info.v11.5.txt",
		        "node_list_path": "243232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpTth04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. TTH0-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpTth04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1646498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1646498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1646498.protein.info.v11.5.txt",
		        "node_list_path": "1646498.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurovumSpNbc371Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum sp. NBC371 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurovumSpNbc371Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "387093.clusters.info.v11.5.txt",
		        "cluster_tree_path": "387093.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "387093.clusters.proteins.v11.5.txt",
		        "sequence_path": "387093.protein.sequences.v11.5.fa",
		        "enrichment_path": "387093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "387093.protein.info.v11.5.txt",
		        "node_list_path": "387093.cluster.nodes.v11.5.txt",
		        "edge_list_path": "387093.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaHenselaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella henselae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaHenselaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "283166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "283166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "283166.clusters.proteins.v11.5.txt",
		        "sequence_path": "283166.protein.sequences.v11.5.fa",
		        "enrichment_path": "283166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283166.protein.info.v11.5.txt",
		        "node_list_path": "283166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "283166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacteriumCsp16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium CSP1-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacteriumCsp16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1640509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640509.protein.info.v11.5.txt",
		        "node_list_path": "1640509.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPachastrellae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pachastrellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPachastrellae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "254161.protein.sequences.v11.5.fa",
		        "enrichment_path": "254161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "254161.protein.info.v11.5.txt",
		        "node_list_path": "254161.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldicoprobacterFaecalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicoprobacter faecalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicoprobacterFaecalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "937334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "937334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "937334.clusters.proteins.v11.5.txt",
		        "sequence_path": "937334.protein.sequences.v11.5.fa",
		        "enrichment_path": "937334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937334.protein.info.v11.5.txt",
		        "node_list_path": "937334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "937334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesLuteusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesLuteusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1915400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1915400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1915400.clusters.proteins.v11.5.txt",
		        "sequence_path": "1915400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915400.protein.info.v11.5.txt",
		        "node_list_path": "1915400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1915400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusInfantisSk970(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis SK970 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusInfantisSk970", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035189.protein.info.v11.5.txt",
		        "node_list_path": "1035189.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSepticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium septicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSepticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1341646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341646.protein.info.v11.5.txt",
		        "node_list_path": "1341646.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChrysolophusPictus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chrysolophus pictus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChrysolophusPictus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9089.protein.sequences.v11.5.fa",
		        "enrichment_path": "9089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9089.protein.info.v11.5.txt",
		        "node_list_path": "9089.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasNoxiaF0398Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas noxia F0398 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasNoxiaF0398Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "702437.clusters.info.v11.5.txt",
		        "cluster_tree_path": "702437.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "702437.clusters.proteins.v11.5.txt",
		        "sequence_path": "702437.protein.sequences.v11.5.fa",
		        "enrichment_path": "702437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702437.protein.info.v11.5.txt",
		        "node_list_path": "702437.cluster.nodes.v11.5.txt",
		        "edge_list_path": "702437.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaAustraliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytoplasma australiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaAustraliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59748.protein.sequences.v11.5.fa",
		        "enrichment_path": "59748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59748.protein.info.v11.5.txt",
		        "node_list_path": "59748.protein.complete.v11.5.txt"
		    }
		]
    )()

def YonghaparkiaSpRoot332Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yonghaparkia sp. Root332 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YonghaparkiaSpRoot332Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736516.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736516.protein.info.v11.5.txt",
		        "node_list_path": "1736516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumCg2303166(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG2_30_31_66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumCg2303166", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805159.protein.info.v11.5.txt",
		        "node_list_path": "1805159.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumGw2011Gwc14715Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWC1_47_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwc14715Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618364.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618364.protein.info.v11.5.txt",
		        "node_list_path": "1618364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldanaerovirgaAcetigignensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldanaerovirga acetigignens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldanaerovirgaAcetigignensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "447595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "447595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "447595.clusters.proteins.v11.5.txt",
		        "sequence_path": "447595.protein.sequences.v11.5.fa",
		        "enrichment_path": "447595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "447595.protein.info.v11.5.txt",
		        "node_list_path": "447595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "447595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KryptolebiasMarmoratus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kryptolebias marmoratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KryptolebiasMarmoratus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37003.protein.sequences.v11.5.fa",
		        "enrichment_path": "37003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37003.protein.info.v11.5.txt",
		        "node_list_path": "37003.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfurobacteriumSpTc51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurobacterium sp. TC51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurobacteriumSpTc51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158318.protein.info.v11.5.txt",
		        "node_list_path": "1158318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1844972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1844972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1844972.protein.info.v11.5.txt",
		        "node_list_path": "1844972.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaedibacterSp38128Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caedibacter sp. 38-128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaedibacterSp38128Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895736.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895736.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895736.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895736.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895736.protein.info.v11.5.txt",
		        "node_list_path": "1895736.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895736.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPullorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma pullorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPullorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "48003.protein.sequences.v11.5.fa",
		        "enrichment_path": "48003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48003.protein.info.v11.5.txt",
		        "node_list_path": "48003.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrycteropusAferCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Orycteropus afer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrycteropusAferCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9818.clusters.proteins.v11.5.txt",
		        "sequence_path": "9818.protein.sequences.v11.5.fa",
		        "enrichment_path": "9818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9818.protein.info.v11.5.txt",
		        "node_list_path": "9818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumWolinskyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium wolinskyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumWolinskyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59750.clusters.proteins.v11.5.txt",
		        "sequence_path": "59750.protein.sequences.v11.5.fa",
		        "enrichment_path": "59750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59750.protein.info.v11.5.txt",
		        "node_list_path": "59750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMuproteobacteriaBacteriumRbg166411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_64_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817758.protein.info.v11.5.txt",
		        "node_list_path": "1817758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BipolarisOryzaeAtcc44560(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris oryzae ATCC 44560 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisOryzaeAtcc44560", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930090.protein.sequences.v11.5.fa",
		        "enrichment_path": "930090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930090.protein.info.v11.5.txt",
		        "node_list_path": "930090.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat22090(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-22090 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat22090", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1581038.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581038.protein.info.v11.5.txt",
		        "node_list_path": "1581038.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumKomanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium komanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumKomanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566885.protein.info.v11.5.txt",
		        "node_list_path": "1566885.protein.complete.v11.5.txt"
		    }
		]
    )()

def SnodgrassellaAlviScgcAb598O02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Snodgrassella alvi SCGC AB-598-O02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SnodgrassellaAlviScgcAb598O02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1443103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443103.protein.info.v11.5.txt",
		        "node_list_path": "1443103.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAtelocyanobacteriumThalassaIsolateAlohaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atelocyanobacterium thalassa isolate ALOHA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAtelocyanobacteriumThalassaIsolateAlohaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1453429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1453429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1453429.clusters.proteins.v11.5.txt",
		        "sequence_path": "1453429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453429.protein.info.v11.5.txt",
		        "node_list_path": "1453429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1453429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusTurcosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus turcosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusTurcosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1245748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245748.protein.info.v11.5.txt",
		        "node_list_path": "1245748.protein.complete.v11.5.txt"
		    }
		]
    )()

def SanguibacterSuareziiNbrc16159(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter suarezii NBRC 16159 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SanguibacterSuareziiNbrc16159", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223525.protein.info.v11.5.txt",
		        "node_list_path": "1223525.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpHzm(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. HZM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpHzm", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1454010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454010.protein.info.v11.5.txt",
		        "node_list_path": "1454010.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumHydrocarbonoxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium hydrocarbonoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumHydrocarbonoxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "273678.clusters.info.v11.5.txt",
		        "cluster_tree_path": "273678.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "273678.clusters.proteins.v11.5.txt",
		        "sequence_path": "273678.protein.sequences.v11.5.fa",
		        "enrichment_path": "273678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273678.protein.info.v11.5.txt",
		        "node_list_path": "273678.cluster.nodes.v11.5.txt",
		        "edge_list_path": "273678.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfuricurvumSpGwf24489(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. GWF2_44_89 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricurvumSpGwf24489", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802241.protein.info.v11.5.txt",
		        "node_list_path": "1802241.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "294.clusters.info.v11.5.txt",
		        "cluster_tree_path": "294.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "294.clusters.proteins.v11.5.txt",
		        "sequence_path": "294.protein.sequences.v11.5.fa",
		        "enrichment_path": "294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294.protein.info.v11.5.txt",
		        "node_list_path": "294.cluster.nodes.v11.5.txt",
		        "edge_list_path": "294.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumProfundiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium profundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumProfundiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "450380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "450380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "450380.clusters.proteins.v11.5.txt",
		        "sequence_path": "450380.protein.sequences.v11.5.fa",
		        "enrichment_path": "450380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "450380.protein.info.v11.5.txt",
		        "node_list_path": "450380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "450380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalothrixSpPcc7103(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC7103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalothrixSpPcc7103", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32057.protein.sequences.v11.5.fa",
		        "enrichment_path": "32057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32057.protein.info.v11.5.txt",
		        "node_list_path": "32057.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNiyogibacteriaBacteriumRifcsplowo202Full4513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Niyogibacteria bacterium RIFCSPLOWO2_02_FULL_45_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNiyogibacteriaBacteriumRifcsplowo202Full4513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801725.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801725.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801725.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801725.protein.info.v11.5.txt",
		        "node_list_path": "1801725.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801725.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMarincola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas marincola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMarincola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "437900.protein.sequences.v11.5.fa",
		        "enrichment_path": "437900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "437900.protein.info.v11.5.txt",
		        "node_list_path": "437900.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrobaculumNeutrophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum neutrophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumNeutrophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "444157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "444157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "444157.clusters.proteins.v11.5.txt",
		        "sequence_path": "444157.protein.sequences.v11.5.fa",
		        "enrichment_path": "444157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444157.protein.info.v11.5.txt",
		        "node_list_path": "444157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "444157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665571.clusters.proteins.v11.5.txt",
		        "sequence_path": "665571.protein.sequences.v11.5.fa",
		        "enrichment_path": "665571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665571.protein.info.v11.5.txt",
		        "node_list_path": "665571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProtochlamydiaAmoebophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Protochlamydia amoebophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProtochlamydiaAmoebophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264201.protein.sequences.v11.5.fa",
		        "enrichment_path": "264201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264201.protein.info.v11.5.txt",
		        "node_list_path": "264201.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpMarseilleP2415Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. Marseille-P2415 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpMarseilleP2415Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805471.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805471.protein.info.v11.5.txt",
		        "node_list_path": "1805471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaPaurometabolicaYim90007Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora paurometabolica YIM 90007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaPaurometabolicaYim90007Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "882084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "882084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "882084.clusters.proteins.v11.5.txt",
		        "sequence_path": "882084.protein.sequences.v11.5.fa",
		        "enrichment_path": "882084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882084.protein.info.v11.5.txt",
		        "node_list_path": "882084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "882084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaPersicinaNbrc102418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia persicina NBRC 102418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaPersicinaNbrc102418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219360.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219360.protein.info.v11.5.txt",
		        "node_list_path": "1219360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaIntermedia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Candida] intermedia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaIntermedia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45354.protein.sequences.v11.5.fa",
		        "enrichment_path": "45354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45354.protein.info.v11.5.txt",
		        "node_list_path": "45354.protein.complete.v11.5.txt"
		    }
		]
    )()

def CatenariaAnguillulaePl171(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catenaria anguillulae PL171 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenariaAnguillulaePl171", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765915.protein.sequences.v11.5.fa",
		        "enrichment_path": "765915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765915.protein.info.v11.5.txt",
		        "node_list_path": "765915.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinopolymorphaCephalotaxi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinopolymorpha cephalotaxi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolymorphaCephalotaxi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "504797.protein.sequences.v11.5.fa",
		        "enrichment_path": "504797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504797.protein.info.v11.5.txt",
		        "node_list_path": "504797.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumAmmoniigenesNbrc101786(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium ammoniigenes NBRC 101786 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumAmmoniigenesNbrc101786", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223517.protein.info.v11.5.txt",
		        "node_list_path": "1223517.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGastranaerophilalesBacteriumZag111Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium Zag_111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumZag111Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906167.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906167.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906167.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906167.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906167.protein.info.v11.5.txt",
		        "node_list_path": "1906167.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906167.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusShacheensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus shacheensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusShacheensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1649580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1649580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1649580.protein.info.v11.5.txt",
		        "node_list_path": "1649580.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusNanhaiticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius nanhaiticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusNanhaiticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573024.protein.sequences.v11.5.fa",
		        "enrichment_path": "573024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573024.protein.info.v11.5.txt",
		        "node_list_path": "573024.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConidiobolusCoronatusNrrl28638(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Conidiobolus coronatus NRRL 28638 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConidiobolusCoronatusNrrl28638", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "796925.protein.sequences.v11.5.fa",
		        "enrichment_path": "796925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796925.protein.info.v11.5.txt",
		        "node_list_path": "796925.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesAlkalitoleransDsm16699Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides alkalitolerans DSM 16699 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesAlkalitoleransDsm16699Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122608.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122608.protein.info.v11.5.txt",
		        "node_list_path": "1122608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceaniovalibusGuishaninsula(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceaniovalibus guishaninsula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceaniovalibusGuishaninsula", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231392.protein.info.v11.5.txt",
		        "node_list_path": "1231392.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpDw54(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. DW54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpDw54", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1178540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1178540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1178540.protein.info.v11.5.txt",
		        "node_list_path": "1178540.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinophytocolaXinjiangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinophytocola xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinophytocolaXinjiangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "485602.clusters.info.v11.5.txt",
		        "cluster_tree_path": "485602.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "485602.clusters.proteins.v11.5.txt",
		        "sequence_path": "485602.protein.sequences.v11.5.fa",
		        "enrichment_path": "485602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485602.protein.info.v11.5.txt",
		        "node_list_path": "485602.cluster.nodes.v11.5.txt",
		        "edge_list_path": "485602.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifcsphigho202Full5326(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFCSPHIGHO2_02_FULL_53_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifcsphigho202Full5326", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802566.protein.info.v11.5.txt",
		        "node_list_path": "1802566.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumLotiUsda3471(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti USDA3471 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumLotiUsda3471", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1040983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1040983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1040983.protein.info.v11.5.txt",
		        "node_list_path": "1040983.protein.complete.v11.5.txt"
		    }
		]
    )()

def WallemiaIchthyophagaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wallemia ichthyophaga Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WallemiaIchthyophagaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "245174.clusters.info.v11.5.txt",
		        "cluster_tree_path": "245174.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "245174.clusters.proteins.v11.5.txt",
		        "sequence_path": "245174.protein.sequences.v11.5.fa",
		        "enrichment_path": "245174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "245174.protein.info.v11.5.txt",
		        "node_list_path": "245174.cluster.nodes.v11.5.txt",
		        "edge_list_path": "245174.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinivibrioSpEs052(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio sp. ES.052 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivibrioSpEs052", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882823.protein.info.v11.5.txt",
		        "node_list_path": "1882823.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusIners(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus iners graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusIners", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "713605.protein.sequences.v11.5.fa",
		        "enrichment_path": "713605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713605.protein.info.v11.5.txt",
		        "node_list_path": "713605.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumLeiognathiMandapamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi mandapamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumLeiognathiMandapamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1001530.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1001530.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1001530.clusters.proteins.v11.5.txt",
		        "sequence_path": "1001530.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001530.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001530.protein.info.v11.5.txt",
		        "node_list_path": "1001530.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1001530.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaDrozanskiiLlap1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella drozanskii LLAP-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaDrozanskiiLlap1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1212489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1212489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1212489.clusters.proteins.v11.5.txt",
		        "sequence_path": "1212489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1212489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1212489.protein.info.v11.5.txt",
		        "node_list_path": "1212489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1212489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprobacillusSpCag605Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus sp. CAG:605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprobacillusSpCag605Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262855.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262855.protein.info.v11.5.txt",
		        "node_list_path": "1262855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsphigho202Full4712Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_02_FULL_47_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho202Full4712Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802137.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802137.protein.info.v11.5.txt",
		        "node_list_path": "1802137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpB04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. B04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpB04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945860.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945860.protein.info.v11.5.txt",
		        "node_list_path": "1945860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacteriumMelA1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium MEL.A1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacteriumMelA1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1899017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1899017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1899017.clusters.proteins.v11.5.txt",
		        "sequence_path": "1899017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1899017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1899017.protein.info.v11.5.txt",
		        "node_list_path": "1899017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1899017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophothermusSpDtu052(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophothermus sp. DTU052 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophothermusSpDtu052", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671631.protein.info.v11.5.txt",
		        "node_list_path": "1671631.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterOryzifermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter oryzifermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterOryzifermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1633874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1633874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1633874.clusters.proteins.v11.5.txt",
		        "sequence_path": "1633874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1633874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1633874.protein.info.v11.5.txt",
		        "node_list_path": "1633874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1633874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpNb77Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. NB77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpNb77Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1342301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1342301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1342301.clusters.proteins.v11.5.txt",
		        "sequence_path": "1342301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1342301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1342301.protein.info.v11.5.txt",
		        "node_list_path": "1342301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1342301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag1031(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1031 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag1031", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262917.protein.info.v11.5.txt",
		        "node_list_path": "1262917.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpHpa0247(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. HPA0247 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpHpa0247", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203556.protein.info.v11.5.txt",
		        "node_list_path": "1203556.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenericutesBacteriumGwf25713(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWF2_57_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenericutesBacteriumGwf25713", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802354.protein.info.v11.5.txt",
		        "node_list_path": "1802354.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpRoot186Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root186 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpRoot186Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736485.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736485.protein.info.v11.5.txt",
		        "node_list_path": "1736485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasCampestrisPvCampestrisStrAtcc33913Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris pv. campestris str. ATCC 33913 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCampestrisPvCampestrisStrAtcc33913Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "190485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "190485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "190485.clusters.proteins.v11.5.txt",
		        "sequence_path": "190485.protein.sequences.v11.5.fa",
		        "enrichment_path": "190485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190485.protein.info.v11.5.txt",
		        "node_list_path": "190485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "190485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasSp67h29bpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. 67H29BP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSp67h29bpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "864563.clusters.info.v11.5.txt",
		        "cluster_tree_path": "864563.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "864563.clusters.proteins.v11.5.txt",
		        "sequence_path": "864563.protein.sequences.v11.5.fa",
		        "enrichment_path": "864563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864563.protein.info.v11.5.txt",
		        "node_list_path": "864563.cluster.nodes.v11.5.txt",
		        "edge_list_path": "864563.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSymbiosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] symbiosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSymbiosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1512.clusters.proteins.v11.5.txt",
		        "sequence_path": "1512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1512.protein.info.v11.5.txt",
		        "node_list_path": "1512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParvibaculumLavamentivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parvibaculum lavamentivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvibaculumLavamentivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "402881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "402881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "402881.clusters.proteins.v11.5.txt",
		        "sequence_path": "402881.protein.sequences.v11.5.fa",
		        "enrichment_path": "402881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402881.protein.info.v11.5.txt",
		        "node_list_path": "402881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "402881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumBica18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BICA1-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumBica18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1531962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1531962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1531962.clusters.proteins.v11.5.txt",
		        "sequence_path": "1531962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1531962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1531962.protein.info.v11.5.txt",
		        "node_list_path": "1531962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1531962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaprevotellaXylaniphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraprevotella xylaniphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaprevotellaXylaniphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762982.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762982.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762982.clusters.proteins.v11.5.txt",
		        "sequence_path": "762982.protein.sequences.v11.5.fa",
		        "enrichment_path": "762982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762982.protein.info.v11.5.txt",
		        "node_list_path": "762982.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762982.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumKansasiiAtcc12478(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii ATCC12478 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumKansasiiAtcc12478", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "557599.protein.sequences.v11.5.fa",
		        "enrichment_path": "557599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "557599.protein.info.v11.5.txt",
		        "node_list_path": "557599.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpCf136(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. CF136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpCf136", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144313.protein.info.v11.5.txt",
		        "node_list_path": "1144313.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwb16080Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWB1_60_80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwb16080Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802177.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802177.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802177.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802177.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802177.protein.info.v11.5.txt",
		        "node_list_path": "1802177.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802177.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusGinsenosidimutansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ginsenosidimutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGinsenosidimutansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1007676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1007676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1007676.clusters.proteins.v11.5.txt",
		        "sequence_path": "1007676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007676.protein.info.v11.5.txt",
		        "node_list_path": "1007676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1007676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EgrettaGarzettaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Egretta garzetta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EgrettaGarzettaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "188379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "188379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "188379.clusters.proteins.v11.5.txt",
		        "sequence_path": "188379.protein.sequences.v11.5.fa",
		        "enrichment_path": "188379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188379.protein.info.v11.5.txt",
		        "node_list_path": "188379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "188379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumSpXm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. XM-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumSpXm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1663591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1663591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1663591.protein.info.v11.5.txt",
		        "node_list_path": "1663591.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpUw4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. UW4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpUw4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1207075.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1207075.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1207075.clusters.proteins.v11.5.txt",
		        "sequence_path": "1207075.protein.sequences.v11.5.fa",
		        "enrichment_path": "1207075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1207075.protein.info.v11.5.txt",
		        "node_list_path": "1207075.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1207075.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpCsm2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. CSM-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpCsm2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1975722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1975722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1975722.clusters.proteins.v11.5.txt",
		        "sequence_path": "1975722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1975722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1975722.protein.info.v11.5.txt",
		        "node_list_path": "1975722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1975722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpXs5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. XS5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpXs5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1775636.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1775636.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1775636.clusters.proteins.v11.5.txt",
		        "sequence_path": "1775636.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775636.protein.info.v11.5.txt",
		        "node_list_path": "1775636.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1775636.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AidingimonasHalophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aidingimonas halophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AidingimonasHalophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "574349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "574349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "574349.clusters.proteins.v11.5.txt",
		        "sequence_path": "574349.protein.sequences.v11.5.fa",
		        "enrichment_path": "574349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574349.protein.info.v11.5.txt",
		        "node_list_path": "574349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "574349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusUvarumDsm19971Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus uvarum DSM 19971 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusUvarumDsm19971Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423812.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423812.protein.info.v11.5.txt",
		        "node_list_path": "1423812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumFormicicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium formicicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumFormicicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2162.protein.sequences.v11.5.fa",
		        "enrichment_path": "2162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2162.protein.info.v11.5.txt",
		        "node_list_path": "2162.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpCf108Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. CF108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpCf108Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882758.protein.info.v11.5.txt",
		        "node_list_path": "1882758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218084.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218084.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218084.protein.info.v11.5.txt",
		        "node_list_path": "1218084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocellaConradii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanocella conradii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocellaConradii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041930.protein.info.v11.5.txt",
		        "node_list_path": "1041930.protein.complete.v11.5.txt"
		    }
		]
    )()

def WigglesworthiaGlossinidiaEndosymbiontOfGlossinaMorsitansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia endosymbiont of Glossina morsitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WigglesworthiaGlossinidiaEndosymbiontOfGlossinaMorsitansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1142511.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1142511.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1142511.clusters.proteins.v11.5.txt",
		        "sequence_path": "1142511.protein.sequences.v11.5.fa",
		        "enrichment_path": "1142511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1142511.protein.info.v11.5.txt",
		        "node_list_path": "1142511.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1142511.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PararhizobiumPolonicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pararhizobium polonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PararhizobiumPolonicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1612624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1612624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1612624.clusters.proteins.v11.5.txt",
		        "sequence_path": "1612624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1612624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1612624.protein.info.v11.5.txt",
		        "node_list_path": "1612624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1612624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassomonasViridans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassomonas viridans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassomonasViridans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "137584.protein.sequences.v11.5.fa",
		        "enrichment_path": "137584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137584.protein.info.v11.5.txt",
		        "node_list_path": "137584.protein.complete.v11.5.txt"
		    }
		]
    )()

def BelnapiaSpF41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Belnapia sp. F-4-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BelnapiaSpF41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1545443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545443.protein.info.v11.5.txt",
		        "node_list_path": "1545443.protein.complete.v11.5.txt"
		    }
		]
    )()

def HuchoHucho(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hucho hucho graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HuchoHucho", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "62062.protein.sequences.v11.5.fa",
		        "enrichment_path": "62062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62062.protein.info.v11.5.txt",
		        "node_list_path": "62062.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudorhodoplanesSinuspersiciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodoplanes sinuspersici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodoplanesSinuspersiciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235591.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235591.protein.info.v11.5.txt",
		        "node_list_path": "1235591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OreniaMetallireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Orenia metallireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OreniaMetallireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1413210.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1413210.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1413210.clusters.proteins.v11.5.txt",
		        "sequence_path": "1413210.protein.sequences.v11.5.fa",
		        "enrichment_path": "1413210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1413210.protein.info.v11.5.txt",
		        "node_list_path": "1413210.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1413210.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusHalmapalusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus halmapalus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHalmapalusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "79882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "79882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "79882.clusters.proteins.v11.5.txt",
		        "sequence_path": "79882.protein.sequences.v11.5.fa",
		        "enrichment_path": "79882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79882.protein.info.v11.5.txt",
		        "node_list_path": "79882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "79882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaplasmaMarginaleMariesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Anaplasma marginale Maries Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "AnaplasmaMarginaleMariesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "234826.clusters.info.v11.0.txt",
		        "cluster_tree_path": "234826.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "234826.clusters.proteins.v11.0.txt",
		        "sequence_path": "234826.protein.sequences.v11.0.fa",
		        "enrichment_path": "234826.protein.enrichment.terms.v11.0.txt",
		        "info_path": "234826.protein.info.v11.0.txt",
		        "node_list_path": "234826.cluster.nodes.v11.0.txt",
		        "edge_list_path": "234826.protein.cluster.v11.0.txt"
		    }
		]
    )()

def StreptococcusSpC150(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. C150 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpC150", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "435842.protein.sequences.v11.5.fa",
		        "enrichment_path": "435842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435842.protein.info.v11.5.txt",
		        "node_list_path": "435842.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735689.protein.info.v11.5.txt",
		        "node_list_path": "1735689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusThioreducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus thioreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusThioreducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "277988.protein.sequences.v11.5.fa",
		        "enrichment_path": "277988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "277988.protein.info.v11.5.txt",
		        "node_list_path": "277988.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasProtegensCha0(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas protegens CHA0 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasProtegensCha0", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1124983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1124983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1124983.protein.info.v11.5.txt",
		        "node_list_path": "1124983.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterSedentariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sedentarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSedentariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1411621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1411621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1411621.clusters.proteins.v11.5.txt",
		        "sequence_path": "1411621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1411621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1411621.protein.info.v11.5.txt",
		        "node_list_path": "1411621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1411621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaueraPhenolivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thauera phenolivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraPhenolivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1792543.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792543.protein.info.v11.5.txt",
		        "node_list_path": "1792543.protein.complete.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsUnilateralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps unilateralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsUnilateralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "268505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "268505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "268505.clusters.proteins.v11.5.txt",
		        "sequence_path": "268505.protein.sequences.v11.5.fa",
		        "enrichment_path": "268505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "268505.protein.info.v11.5.txt",
		        "node_list_path": "268505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "268505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3812bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_38_12b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3812bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802214.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802214.protein.info.v11.5.txt",
		        "node_list_path": "1802214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesViridochromogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces viridochromogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesViridochromogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "591159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "591159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "591159.clusters.proteins.v11.5.txt",
		        "sequence_path": "591159.protein.sequences.v11.5.fa",
		        "enrichment_path": "591159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591159.protein.info.v11.5.txt",
		        "node_list_path": "591159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "591159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTaa204(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA204 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTaa204", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1289387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1289387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1289387.protein.info.v11.5.txt",
		        "node_list_path": "1289387.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmphiprionOcellarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amphiprion ocellaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphiprionOcellarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "80972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "80972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "80972.clusters.proteins.v11.5.txt",
		        "sequence_path": "80972.protein.sequences.v11.5.fa",
		        "enrichment_path": "80972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80972.protein.info.v11.5.txt",
		        "node_list_path": "80972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "80972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitratireductorPacificus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitratireductor pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratireductorPacificus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391937.protein.sequences.v11.5.fa",
		        "enrichment_path": "391937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391937.protein.info.v11.5.txt",
		        "node_list_path": "391937.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsphigho202Full4011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO2_02_FULL_40_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho202Full4011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797858.protein.info.v11.5.txt",
		        "node_list_path": "1797858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumGwf24514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_45_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumGwf24514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798572.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798572.protein.info.v11.5.txt",
		        "node_list_path": "1798572.protein.complete.v11.5.txt"
		    }
		]
    )()

def CrinaliumEpipsammum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crinalium epipsammum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrinaliumEpipsammum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173022.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173022.protein.info.v11.5.txt",
		        "node_list_path": "1173022.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonasTestosteroniKf1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas testosteroni KF1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasTestosteroniKf1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "399795.clusters.info.v11.5.txt",
		        "cluster_tree_path": "399795.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "399795.clusters.proteins.v11.5.txt",
		        "sequence_path": "399795.protein.sequences.v11.5.fa",
		        "enrichment_path": "399795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399795.protein.info.v11.5.txt",
		        "node_list_path": "399795.cluster.nodes.v11.5.txt",
		        "edge_list_path": "399795.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrocebusMurinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microcebus murinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrocebusMurinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "30608.protein.sequences.v11.5.fa",
		        "enrichment_path": "30608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30608.protein.info.v11.5.txt",
		        "node_list_path": "30608.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiobacillusThioparus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus thioparus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusThioparus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123393.protein.info.v11.5.txt",
		        "node_list_path": "1123393.protein.complete.v11.5.txt"
		    }
		]
    )()

def AptenodytesForsteri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aptenodytes forsteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AptenodytesForsteri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9233.protein.sequences.v11.5.fa",
		        "enrichment_path": "9233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9233.protein.info.v11.5.txt",
		        "node_list_path": "9233.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeomicrobiumSpJcm19055(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM 19055 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeomicrobiumSpJcm19055", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1460649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460649.protein.info.v11.5.txt",
		        "node_list_path": "1460649.protein.complete.v11.5.txt"
		    }
		]
    )()

def FundulusHeteroclitusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fundulus heteroclitus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FundulusHeteroclitusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8078.clusters.proteins.v11.5.txt",
		        "sequence_path": "8078.protein.sequences.v11.5.fa",
		        "enrichment_path": "8078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8078.protein.info.v11.5.txt",
		        "node_list_path": "8078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusSpJcm19060Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. JCM 19060 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusSpJcm19060Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1481930.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1481930.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1481930.clusters.proteins.v11.5.txt",
		        "sequence_path": "1481930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1481930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1481930.protein.info.v11.5.txt",
		        "node_list_path": "1481930.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1481930.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasResinovoransDsm21078Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas resinovorans DSM21078 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasResinovoransDsm21078Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123020.protein.info.v11.5.txt",
		        "node_list_path": "1123020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KazachstaniaAfricanaCbs2517Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania africana CBS 2517 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KazachstaniaAfricanaCbs2517Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071382.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071382.protein.info.v11.5.txt",
		        "node_list_path": "1071382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LaetiporusSulphureus9353(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Laetiporus sulphureus 93-53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LaetiporusSulphureus9353", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314785.protein.info.v11.5.txt",
		        "node_list_path": "1314785.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCellostaticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces cellostaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCellostaticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67285.clusters.proteins.v11.5.txt",
		        "sequence_path": "67285.protein.sequences.v11.5.fa",
		        "enrichment_path": "67285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67285.protein.info.v11.5.txt",
		        "node_list_path": "67285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChelativoransSpBnc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chelativorans sp. BNC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelativoransSpBnc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266779.protein.sequences.v11.5.fa",
		        "enrichment_path": "266779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266779.protein.info.v11.5.txt",
		        "node_list_path": "266779.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonadalesBacteriumGa0077559Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium Ga0077559 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonadalesBacteriumGa0077559Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752233.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752233.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752233.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752233.protein.info.v11.5.txt",
		        "node_list_path": "1752233.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752233.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivirgaSpongicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseivirga spongicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivirgaSpongicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "333140.clusters.info.v11.5.txt",
		        "cluster_tree_path": "333140.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "333140.clusters.proteins.v11.5.txt",
		        "sequence_path": "333140.protein.sequences.v11.5.fa",
		        "enrichment_path": "333140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "333140.protein.info.v11.5.txt",
		        "node_list_path": "333140.cluster.nodes.v11.5.txt",
		        "edge_list_path": "333140.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsPolyrhachisFurcataBcc54312Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps polyrhachis-furcata BCC 54312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsPolyrhachisFurcataBcc54312Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1330021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1330021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1330021.clusters.proteins.v11.5.txt",
		        "sequence_path": "1330021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1330021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1330021.protein.info.v11.5.txt",
		        "node_list_path": "1330021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1330021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusDaejeonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus daejeonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusDaejeonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122917.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122917.protein.info.v11.5.txt",
		        "node_list_path": "1122917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophilalesBacteriumLsucc0135Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophilales bacterium LSUCC0135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilalesBacteriumLsucc0135Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1778481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1778481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1778481.clusters.proteins.v11.5.txt",
		        "sequence_path": "1778481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1778481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1778481.protein.info.v11.5.txt",
		        "node_list_path": "1778481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1778481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsphigho201Full4349(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO2_01_FULL_43_49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho201Full4349", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797856.protein.info.v11.5.txt",
		        "node_list_path": "1797856.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurimonasAutotrophicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas autotrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasAutotrophicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "563040.clusters.info.v11.5.txt",
		        "cluster_tree_path": "563040.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "563040.clusters.proteins.v11.5.txt",
		        "sequence_path": "563040.protein.sequences.v11.5.fa",
		        "enrichment_path": "563040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563040.protein.info.v11.5.txt",
		        "node_list_path": "563040.cluster.nodes.v11.5.txt",
		        "edge_list_path": "563040.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterKyonggiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter kyonggiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterKyonggiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "595670.clusters.info.v11.5.txt",
		        "cluster_tree_path": "595670.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "595670.clusters.proteins.v11.5.txt",
		        "sequence_path": "595670.protein.sequences.v11.5.fa",
		        "enrichment_path": "595670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595670.protein.info.v11.5.txt",
		        "node_list_path": "595670.cluster.nodes.v11.5.txt",
		        "edge_list_path": "595670.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylocapsaAcidiphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylocapsa acidiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocapsaAcidiphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "395964.protein.sequences.v11.5.fa",
		        "enrichment_path": "395964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395964.protein.info.v11.5.txt",
		        "node_list_path": "395964.protein.complete.v11.5.txt"
		    }
		]
    )()

def DokdoniaSpPro95(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dokdonia sp. PRO95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DokdoniaSpPro95", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1239415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1239415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1239415.protein.info.v11.5.txt",
		        "node_list_path": "1239415.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumMa2020(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MA2020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumMa2020", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408323.protein.info.v11.5.txt",
		        "node_list_path": "1408323.protein.complete.v11.5.txt"
		    }
		]
    )()

def LitoreibacterAscidiaceicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Litoreibacter ascidiaceicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LitoreibacterAscidiaceicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1486859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1486859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1486859.protein.info.v11.5.txt",
		        "node_list_path": "1486859.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAchromatiumPalustre(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Achromatium palustre graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAchromatiumPalustre", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1662188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662188.protein.info.v11.5.txt",
		        "node_list_path": "1662188.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_41_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798676.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798676.protein.info.v11.5.txt",
		        "node_list_path": "1798676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAsturiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas asturiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAsturiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1190415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1190415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1190415.clusters.proteins.v11.5.txt",
		        "sequence_path": "1190415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1190415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1190415.protein.info.v11.5.txt",
		        "node_list_path": "1190415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1190415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiaBacteriumScgcAaa160I06(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium SCGC AAA160-I06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiaBacteriumScgcAaa160I06", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1007123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007123.protein.info.v11.5.txt",
		        "node_list_path": "1007123.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrosporumGypseumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microsporum gypseum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrosporumGypseumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "63402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "63402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "63402.clusters.proteins.v11.5.txt",
		        "sequence_path": "63402.protein.sequences.v11.5.fa",
		        "enrichment_path": "63402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63402.protein.info.v11.5.txt",
		        "node_list_path": "63402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "63402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioSpOr37Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. OR37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioSpOr37Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798186.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798186.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798186.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798186.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798186.protein.info.v11.5.txt",
		        "node_list_path": "1798186.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798186.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKuenenbacteriaBacteriumRifcsphigho202Full3913(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium RIFCSPHIGHO2_02_FULL_39_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumRifcsphigho202Full3913", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798561.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798561.protein.info.v11.5.txt",
		        "node_list_path": "1798561.protein.complete.v11.5.txt"
		    }
		]
    )()

def DerxiaGummosaDsm723(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Derxia gummosa DSM 723 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DerxiaGummosaDsm723", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121388.protein.info.v11.5.txt",
		        "node_list_path": "1121388.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanibacterAnophelisNbrc107843(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janibacter anophelis NBRC 107843 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterAnophelisNbrc107843", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216968.protein.info.v11.5.txt",
		        "node_list_path": "1216968.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaBelliiOsu85389Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia bellii OSU85389 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaBelliiOsu85389Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391896.clusters.proteins.v11.5.txt",
		        "sequence_path": "391896.protein.sequences.v11.5.fa",
		        "enrichment_path": "391896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391896.protein.info.v11.5.txt",
		        "node_list_path": "391896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacterAkesuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter akesuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterAkesuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "388950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "388950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "388950.clusters.proteins.v11.5.txt",
		        "sequence_path": "388950.protein.sequences.v11.5.fa",
		        "enrichment_path": "388950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388950.protein.info.v11.5.txt",
		        "node_list_path": "388950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "388950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAdolescentisAtcc15703(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium adolescentis ATCC 15703 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAdolescentisAtcc15703", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "367928.protein.sequences.v11.5.fa",
		        "enrichment_path": "367928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "367928.protein.info.v11.5.txt",
		        "node_list_path": "367928.protein.complete.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaAk(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ak graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaAk", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005090.protein.info.v11.5.txt",
		        "node_list_path": "1005090.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalegentibacterFlavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter flavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterFlavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "287099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "287099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "287099.clusters.proteins.v11.5.txt",
		        "sequence_path": "287099.protein.sequences.v11.5.fa",
		        "enrichment_path": "287099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "287099.protein.info.v11.5.txt",
		        "node_list_path": "287099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "287099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyadobacterAlkalitolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter alkalitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterAlkalitolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121481.protein.info.v11.5.txt",
		        "node_list_path": "1121481.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterKivuiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter kivui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterKivuiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2325.clusters.proteins.v11.5.txt",
		        "sequence_path": "2325.protein.sequences.v11.5.fa",
		        "enrichment_path": "2325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2325.protein.info.v11.5.txt",
		        "node_list_path": "2325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusIbericusCbs121593Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ibericus CBS 121593 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusIbericusCbs121593Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1448316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1448316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1448316.clusters.proteins.v11.5.txt",
		        "sequence_path": "1448316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448316.protein.info.v11.5.txt",
		        "node_list_path": "1448316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1448316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MobiluncusMulierisAtcc35243Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris ATCC35243 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobiluncusMulierisAtcc35243Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585199.clusters.proteins.v11.5.txt",
		        "sequence_path": "585199.protein.sequences.v11.5.fa",
		        "enrichment_path": "585199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585199.protein.info.v11.5.txt",
		        "node_list_path": "585199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParvimonasSpOralTaxon110StrF0139Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parvimonas sp. oral taxon 110 str. F0139 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvimonasSpOralTaxon110StrF0139Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "767100.clusters.info.v11.5.txt",
		        "cluster_tree_path": "767100.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "767100.clusters.proteins.v11.5.txt",
		        "sequence_path": "767100.protein.sequences.v11.5.fa",
		        "enrichment_path": "767100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767100.protein.info.v11.5.txt",
		        "node_list_path": "767100.cluster.nodes.v11.5.txt",
		        "edge_list_path": "767100.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpOlga172Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. OLGA172 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpOlga172Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1804984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1804984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1804984.clusters.proteins.v11.5.txt",
		        "sequence_path": "1804984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1804984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1804984.protein.info.v11.5.txt",
		        "node_list_path": "1804984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1804984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CytophagaAurantiaca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cytophaga aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CytophagaAurantiaca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121373.protein.info.v11.5.txt",
		        "node_list_path": "1121373.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalanaeroarchaeumSulfurireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halanaeroarchaeum sulfurireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaeroarchaeumSulfurireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1604004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1604004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1604004.clusters.proteins.v11.5.txt",
		        "sequence_path": "1604004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1604004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1604004.protein.info.v11.5.txt",
		        "node_list_path": "1604004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1604004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpAap58Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. AAP58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpAap58Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523422.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523422.protein.info.v11.5.txt",
		        "node_list_path": "1523422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpFlCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Fl Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpFlCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1506583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1506583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1506583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1506583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1506583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1506583.protein.info.v11.5.txt",
		        "node_list_path": "1506583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1506583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCaseiBl23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus casei BL23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCaseiBl23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "543734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "543734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "543734.clusters.proteins.v11.5.txt",
		        "sequence_path": "543734.protein.sequences.v11.5.fa",
		        "enrichment_path": "543734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543734.protein.info.v11.5.txt",
		        "node_list_path": "543734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "543734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaSchlechtendaliaChinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Schlechtendalia chinensis) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaSchlechtendaliaChinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118110.protein.sequences.v11.5.fa",
		        "enrichment_path": "118110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118110.protein.info.v11.5.txt",
		        "node_list_path": "118110.protein.complete.v11.5.txt"
		    }
		]
    )()

def ToxoplasmaGondiiVeg(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Toxoplasma gondii VEG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ToxoplasmaGondiiVeg", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "432359.protein.sequences.v11.5.fa",
		        "enrichment_path": "432359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "432359.protein.info.v11.5.txt",
		        "node_list_path": "432359.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumG11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium G11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumG11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1200747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200747.protein.info.v11.5.txt",
		        "node_list_path": "1200747.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesCryophilusOy26(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces cryophilus OY26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesCryophilusOy26", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "653667.protein.sequences.v11.5.fa",
		        "enrichment_path": "653667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "653667.protein.info.v11.5.txt",
		        "node_list_path": "653667.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusGobiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus gobiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusGobiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "745776.protein.sequences.v11.5.fa",
		        "enrichment_path": "745776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745776.protein.info.v11.5.txt",
		        "node_list_path": "745776.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthromitusSpSfbmousenlCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBmouseNL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthromitusSpSfbmousenlCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1508644.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1508644.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1508644.clusters.proteins.v11.5.txt",
		        "sequence_path": "1508644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1508644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1508644.protein.info.v11.5.txt",
		        "node_list_path": "1508644.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1508644.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhoenicibacterCongonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phoenicibacter congonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhoenicibacterCongonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1944646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1944646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1944646.protein.info.v11.5.txt",
		        "node_list_path": "1944646.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumColombienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium colombiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumColombienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041522.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041522.protein.info.v11.5.txt",
		        "node_list_path": "1041522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OchrobactrumSpP6bsIii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum sp. P6BS-III graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OchrobactrumSpP6bsIii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1920636.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920636.protein.info.v11.5.txt",
		        "node_list_path": "1920636.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpFxj1172Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. FXJ1.172 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpFxj1172Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "710705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "710705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "710705.clusters.proteins.v11.5.txt",
		        "sequence_path": "710705.protein.sequences.v11.5.fa",
		        "enrichment_path": "710705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710705.protein.info.v11.5.txt",
		        "node_list_path": "710705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "710705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumIndicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium indicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumIndicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122238.protein.info.v11.5.txt",
		        "node_list_path": "1122238.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaludibacteriumYongneupenseDsm18731Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paludibacterium yongneupense DSM 18731 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaludibacteriumYongneupenseDsm18731Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122928.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122928.protein.info.v11.5.txt",
		        "node_list_path": "1122928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpK31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. K31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpK31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "366602.protein.sequences.v11.5.fa",
		        "enrichment_path": "366602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366602.protein.info.v11.5.txt",
		        "node_list_path": "366602.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSp228(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. 228 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSp228", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1192054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192054.protein.info.v11.5.txt",
		        "node_list_path": "1192054.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumOxysporumFo5176(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum Fo5176 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumOxysporumFo5176", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "660025.protein.sequences.v11.5.fa",
		        "enrichment_path": "660025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660025.protein.info.v11.5.txt",
		        "node_list_path": "660025.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAlsense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium alsense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAlsense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "324058.protein.sequences.v11.5.fa",
		        "enrichment_path": "324058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "324058.protein.info.v11.5.txt",
		        "node_list_path": "324058.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParasitellaParasiticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parasitella parasitica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParasitellaParasiticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35722.clusters.proteins.v11.5.txt",
		        "sequence_path": "35722.protein.sequences.v11.5.fa",
		        "enrichment_path": "35722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35722.protein.info.v11.5.txt",
		        "node_list_path": "35722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalarsenatibacterSilvermanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halarsenatibacter silvermanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalarsenatibacterSilvermanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321763.protein.sequences.v11.5.fa",
		        "enrichment_path": "321763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321763.protein.info.v11.5.txt",
		        "node_list_path": "321763.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpongiibacterSpImcc21906Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spongiibacter sp. IMCC21906 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpongiibacterSpImcc21906Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1620392.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1620392.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1620392.clusters.proteins.v11.5.txt",
		        "sequence_path": "1620392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1620392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1620392.protein.info.v11.5.txt",
		        "node_list_path": "1620392.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1620392.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PiscibacillusSalipiscariusJcm13188Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Piscibacillus salipiscarius JCM 13188 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiscibacillusSalipiscariusJcm13188Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1294022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1294022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1294022.clusters.proteins.v11.5.txt",
		        "sequence_path": "1294022.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294022.protein.info.v11.5.txt",
		        "node_list_path": "1294022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1294022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DysgonomonasGadei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas gadei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasGadei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742766.protein.sequences.v11.5.fa",
		        "enrichment_path": "742766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742766.protein.info.v11.5.txt",
		        "node_list_path": "742766.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpAe3004(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpAe3004", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1506994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1506994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1506994.protein.info.v11.5.txt",
		        "node_list_path": "1506994.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumSpWn1359Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium sp. WN1359 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumSpWn1359Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1266845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1266845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1266845.clusters.proteins.v11.5.txt",
		        "sequence_path": "1266845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266845.protein.info.v11.5.txt",
		        "node_list_path": "1266845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1266845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaCincinnatiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella cincinnatiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaCincinnatiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28085.protein.sequences.v11.5.fa",
		        "enrichment_path": "28085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28085.protein.info.v11.5.txt",
		        "node_list_path": "28085.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumChkci001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium CHKCI001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumChkci001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1780378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1780378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1780378.clusters.proteins.v11.5.txt",
		        "sequence_path": "1780378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780378.protein.info.v11.5.txt",
		        "node_list_path": "1780378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1780378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumMicromatiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium micromati Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumMicromatiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "229205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "229205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "229205.clusters.proteins.v11.5.txt",
		        "sequence_path": "229205.protein.sequences.v11.5.fa",
		        "enrichment_path": "229205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229205.protein.info.v11.5.txt",
		        "node_list_path": "229205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "229205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesNdongoniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides ndongoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesNdongoniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1903262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1903262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1903262.clusters.proteins.v11.5.txt",
		        "sequence_path": "1903262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903262.protein.info.v11.5.txt",
		        "node_list_path": "1903262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1903262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCoagulansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coagulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCoagulansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1398.clusters.proteins.v11.5.txt",
		        "sequence_path": "1398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1398.protein.info.v11.5.txt",
		        "node_list_path": "1398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TorrubiellaHemipterigenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Torrubiella hemipterigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TorrubiellaHemipterigenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1531966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1531966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1531966.clusters.proteins.v11.5.txt",
		        "sequence_path": "1531966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1531966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1531966.protein.info.v11.5.txt",
		        "node_list_path": "1531966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1531966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FervidicolaFerrireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fervidicola ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidicolaFerrireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "520764.protein.sequences.v11.5.fa",
		        "enrichment_path": "520764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "520764.protein.info.v11.5.txt",
		        "node_list_path": "520764.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusAminovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus aminovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusAminovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34004.protein.sequences.v11.5.fa",
		        "enrichment_path": "34004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34004.protein.info.v11.5.txt",
		        "node_list_path": "34004.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminiclostridiumHungatei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminiclostridium hungatei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminiclostridiumHungatei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "48256.protein.sequences.v11.5.fa",
		        "enrichment_path": "48256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48256.protein.info.v11.5.txt",
		        "node_list_path": "48256.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSp651402Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-1402 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSp651402Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895861.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895861.protein.info.v11.5.txt",
		        "node_list_path": "1895861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf86Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf86Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736242.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736242.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736242.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736242.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736242.protein.info.v11.5.txt",
		        "node_list_path": "1736242.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736242.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanomonosporaSphaerica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planomonospora sphaerica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanomonosporaSphaerica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "161355.protein.sequences.v11.5.fa",
		        "enrichment_path": "161355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161355.protein.info.v11.5.txt",
		        "node_list_path": "161355.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpGd11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GD11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpGd11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1274374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274374.protein.info.v11.5.txt",
		        "node_list_path": "1274374.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSpGj21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. GJ21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSpGj21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "113574.clusters.info.v11.5.txt",
		        "cluster_tree_path": "113574.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "113574.clusters.proteins.v11.5.txt",
		        "sequence_path": "113574.protein.sequences.v11.5.fa",
		        "enrichment_path": "113574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113574.protein.info.v11.5.txt",
		        "node_list_path": "113574.cluster.nodes.v11.5.txt",
		        "edge_list_path": "113574.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf456(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf456 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf456", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736382.protein.info.v11.5.txt",
		        "node_list_path": "1736382.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpKiost1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. KIOST1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpKiost1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229172.protein.info.v11.5.txt",
		        "node_list_path": "1229172.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumSp47agom205m(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. 47AGOM205m graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumSp47agom205m", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380384.protein.info.v11.5.txt",
		        "node_list_path": "1380384.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioGigasCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio gigas Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioGigasCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121448.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121448.protein.info.v11.5.txt",
		        "node_list_path": "1121448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAzotoformansLmg9581Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus azotoformans LMG 9581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAzotoformansLmg9581Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131731.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131731.protein.info.v11.5.txt",
		        "node_list_path": "1131731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorSaccharolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor saccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorSaccharolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351627.clusters.proteins.v11.5.txt",
		        "sequence_path": "351627.protein.sequences.v11.5.fa",
		        "enrichment_path": "351627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351627.protein.info.v11.5.txt",
		        "node_list_path": "351627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichinellaSpT8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichinella sp. T8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaSpT8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "92180.protein.sequences.v11.5.fa",
		        "enrichment_path": "92180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92180.protein.info.v11.5.txt",
		        "node_list_path": "92180.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpP6a1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. P6A1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpP6a1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410612.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410612.protein.info.v11.5.txt",
		        "node_list_path": "1410612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaEnoeca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella enoeca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaEnoeca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235815.protein.info.v11.5.txt",
		        "node_list_path": "1235815.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlautiaObeumA2162(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blautia obeum A2-162 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaObeumA2162", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "657314.protein.sequences.v11.5.fa",
		        "enrichment_path": "657314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657314.protein.info.v11.5.txt",
		        "node_list_path": "657314.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichophytonRubrum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton rubrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichophytonRubrum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5551.protein.sequences.v11.5.fa",
		        "enrichment_path": "5551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5551.protein.info.v11.5.txt",
		        "node_list_path": "5551.protein.complete.v11.5.txt"
		    }
		]
    )()

def MartelellaSpAd3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Martelella sp. AD-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MartelellaSpAd3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "686597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "686597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "686597.clusters.proteins.v11.5.txt",
		        "sequence_path": "686597.protein.sequences.v11.5.fa",
		        "enrichment_path": "686597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686597.protein.info.v11.5.txt",
		        "node_list_path": "686597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "686597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumCaspActino2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium casp-actino2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumCaspActino2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1661699.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1661699.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1661699.clusters.proteins.v11.5.txt",
		        "sequence_path": "1661699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661699.protein.info.v11.5.txt",
		        "node_list_path": "1661699.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1661699.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaNigrescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella nigrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaNigrescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "997352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "997352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "997352.clusters.proteins.v11.5.txt",
		        "sequence_path": "997352.protein.sequences.v11.5.fa",
		        "enrichment_path": "997352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997352.protein.info.v11.5.txt",
		        "node_list_path": "997352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "997352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumMolle(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium molle graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumMolle", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216903.protein.sequences.v11.5.fa",
		        "enrichment_path": "216903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216903.protein.info.v11.5.txt",
		        "node_list_path": "216903.protein.complete.v11.5.txt"
		    }
		]
    )()

def CetobacteriumCeti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cetobacterium ceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CetobacteriumCeti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "180163.protein.sequences.v11.5.fa",
		        "enrichment_path": "180163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180163.protein.info.v11.5.txt",
		        "node_list_path": "180163.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHydrothermarchaeotaArchaeonJdfr18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrothermarchaeota archaeon JdFR-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHydrothermarchaeotaArchaeonJdfr18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935129.protein.info.v11.5.txt",
		        "node_list_path": "1935129.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlaviflexusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flaviflexus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlaviflexusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1522309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522309.protein.info.v11.5.txt",
		        "node_list_path": "1522309.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesMirabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces mirabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesMirabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68239.clusters.proteins.v11.5.txt",
		        "sequence_path": "68239.protein.sequences.v11.5.fa",
		        "enrichment_path": "68239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68239.protein.info.v11.5.txt",
		        "node_list_path": "68239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsialesBacteriumAc37b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium Ac37b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsialesBacteriumAc37b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1528098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1528098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1528098.protein.info.v11.5.txt",
		        "node_list_path": "1528098.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpTomc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. TomC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpTomc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1562888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1562888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1562888.protein.info.v11.5.txt",
		        "node_list_path": "1562888.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpEl159(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. EL159 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpEl159", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566270.protein.info.v11.5.txt",
		        "node_list_path": "1566270.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetaBajacaliforniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta bajacaliforniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaBajacaliforniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123274.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123274.protein.info.v11.5.txt",
		        "node_list_path": "1123274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodospirillalesBacterium6911(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium 69-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillalesBacterium6911", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895825.protein.info.v11.5.txt",
		        "node_list_path": "1895825.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraFlavalbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura flavalba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraFlavalbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "561175.clusters.info.v11.5.txt",
		        "cluster_tree_path": "561175.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "561175.clusters.proteins.v11.5.txt",
		        "sequence_path": "561175.protein.sequences.v11.5.fa",
		        "enrichment_path": "561175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561175.protein.info.v11.5.txt",
		        "node_list_path": "561175.cluster.nodes.v11.5.txt",
		        "edge_list_path": "561175.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TuberBorchii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tuber borchii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuberBorchii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42251.protein.sequences.v11.5.fa",
		        "enrichment_path": "42251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42251.protein.info.v11.5.txt",
		        "node_list_path": "42251.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaEnhydra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia enhydra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaEnhydra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665118.protein.sequences.v11.5.fa",
		        "enrichment_path": "665118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665118.protein.info.v11.5.txt",
		        "node_list_path": "665118.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesLuteus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesLuteus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1844.protein.sequences.v11.5.fa",
		        "enrichment_path": "1844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1844.protein.info.v11.5.txt",
		        "node_list_path": "1844.protein.complete.v11.5.txt"
		    }
		]
    )()

def GranulicellaTundricolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Granulicella tundricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicellaTundricolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1198114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1198114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1198114.clusters.proteins.v11.5.txt",
		        "sequence_path": "1198114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198114.protein.info.v11.5.txt",
		        "node_list_path": "1198114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1198114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusNamurensisDsm19117(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus namurensis DSM 19117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusNamurensisDsm19117", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423773.protein.info.v11.5.txt",
		        "node_list_path": "1423773.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifcsplowo201Full5118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_01_FULL_51_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo201Full5118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801925.protein.info.v11.5.txt",
		        "node_list_path": "1801925.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumClariflavumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium clariflavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumClariflavumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "720554.clusters.info.v11.5.txt",
		        "cluster_tree_path": "720554.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "720554.clusters.proteins.v11.5.txt",
		        "sequence_path": "720554.protein.sequences.v11.5.fa",
		        "enrichment_path": "720554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "720554.protein.info.v11.5.txt",
		        "node_list_path": "720554.cluster.nodes.v11.5.txt",
		        "edge_list_path": "720554.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusPohliae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus pohliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusPohliae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120973.protein.info.v11.5.txt",
		        "node_list_path": "1120973.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumSubspPolymorphumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum subsp. polymorphum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumSubspPolymorphumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "76857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "76857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "76857.clusters.proteins.v11.5.txt",
		        "sequence_path": "76857.protein.sequences.v11.5.fa",
		        "enrichment_path": "76857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76857.protein.info.v11.5.txt",
		        "node_list_path": "76857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "76857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrabulsiellaOdontotermitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trabulsiella odontotermitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrabulsiellaOdontotermitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "379893.protein.sequences.v11.5.fa",
		        "enrichment_path": "379893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "379893.protein.info.v11.5.txt",
		        "node_list_path": "379893.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrococcusAbyssi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus abyssi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusAbyssi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272844.protein.sequences.v11.5.fa",
		        "enrichment_path": "272844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272844.protein.info.v11.5.txt",
		        "node_list_path": "272844.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthobacterAutotrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthobacter autotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthobacterAutotrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "78245.protein.sequences.v11.5.fa",
		        "enrichment_path": "78245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78245.protein.info.v11.5.txt",
		        "node_list_path": "78245.protein.complete.v11.5.txt"
		    }
		]
    )()

def StanieriaCyanosphaera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stanieria cyanosphaera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StanieriaCyanosphaera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "111780.protein.sequences.v11.5.fa",
		        "enrichment_path": "111780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "111780.protein.info.v11.5.txt",
		        "node_list_path": "111780.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesNiger(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces niger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesNiger", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66373.protein.sequences.v11.5.fa",
		        "enrichment_path": "66373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66373.protein.info.v11.5.txt",
		        "node_list_path": "66373.protein.complete.v11.5.txt"
		    }
		]
    )()

def BabesiaBovis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Babesia bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BabesiaBovis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5865.protein.sequences.v11.5.fa",
		        "enrichment_path": "5865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5865.protein.info.v11.5.txt",
		        "node_list_path": "5865.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPacebacteriaBacteriumGw2011Gwa14610Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium GW2011_GWA1_46_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacebacteriaBacteriumGw2011Gwa14610Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618469.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618469.protein.info.v11.5.txt",
		        "node_list_path": "1618469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylovulumMiyakonenseHt12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylovulum miyakonense HT12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylovulumMiyakonenseHt12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1078846.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078846.protein.info.v11.5.txt",
		        "node_list_path": "1078846.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonJdfr11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon JdFR-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonJdfr11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935119.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935119.protein.info.v11.5.txt",
		        "node_list_path": "1935119.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosotenuisCloacaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis cloacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosotenuisCloacaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1603555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1603555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1603555.clusters.proteins.v11.5.txt",
		        "sequence_path": "1603555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603555.protein.info.v11.5.txt",
		        "node_list_path": "1603555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1603555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaTasmaniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia tasmaniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaTasmaniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "465817.protein.sequences.v11.5.fa",
		        "enrichment_path": "465817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "465817.protein.info.v11.5.txt",
		        "node_list_path": "465817.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhycisphaeraeBacteriumSm2330(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phycisphaerae bacterium SM23_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycisphaeraeBacteriumSm2330", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703411.protein.info.v11.5.txt",
		        "node_list_path": "1703411.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloversatilisUniversalisFam5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloversatilis universalis FAM5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloversatilisUniversalisFam5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1000565.protein.sequences.v11.5.fa",
		        "enrichment_path": "1000565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1000565.protein.info.v11.5.txt",
		        "node_list_path": "1000565.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrachymyrmexSeptentrionalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trachymyrmex septentrionalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrachymyrmexSeptentrionalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34720.protein.sequences.v11.5.fa",
		        "enrichment_path": "34720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34720.protein.info.v11.5.txt",
		        "node_list_path": "34720.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasAestuarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasAestuarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52441.protein.sequences.v11.5.fa",
		        "enrichment_path": "52441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52441.protein.info.v11.5.txt",
		        "node_list_path": "52441.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumGraminearumPh1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium graminearum PH-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumGraminearumPh1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "229533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "229533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "229533.clusters.proteins.v11.5.txt",
		        "sequence_path": "229533.protein.sequences.v11.5.fa",
		        "enrichment_path": "229533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229533.protein.info.v11.5.txt",
		        "node_list_path": "229533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "229533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusAlveiTs15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alvei TS15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusAlveiTs15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117108.protein.info.v11.5.txt",
		        "node_list_path": "1117108.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterSuisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter suis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSuisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "710393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "710393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "710393.clusters.proteins.v11.5.txt",
		        "sequence_path": "710393.protein.sequences.v11.5.fa",
		        "enrichment_path": "710393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710393.protein.info.v11.5.txt",
		        "node_list_path": "710393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "710393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaGamsiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma gamsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaGamsiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398673.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398673.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398673.clusters.proteins.v11.5.txt",
		        "sequence_path": "398673.protein.sequences.v11.5.fa",
		        "enrichment_path": "398673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398673.protein.info.v11.5.txt",
		        "node_list_path": "398673.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398673.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasArabiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas arabiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasArabiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "874454.protein.sequences.v11.5.fa",
		        "enrichment_path": "874454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "874454.protein.info.v11.5.txt",
		        "node_list_path": "874454.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpIbvss1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. IBVSS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpIbvss1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1985171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1985171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1985171.protein.info.v11.5.txt",
		        "node_list_path": "1985171.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoturnixJaponicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coturnix japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoturnixJaponicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93934.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93934.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93934.clusters.proteins.v11.5.txt",
		        "sequence_path": "93934.protein.sequences.v11.5.fa",
		        "enrichment_path": "93934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93934.protein.info.v11.5.txt",
		        "node_list_path": "93934.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93934.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumPerfoetens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium perfoetens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumPerfoetens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408439.protein.info.v11.5.txt",
		        "node_list_path": "1408439.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaeromyxobacterSpFw1095(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaeromyxobacter sp. Fw1095 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeromyxobacterSpFw1095", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "404589.protein.sequences.v11.5.fa",
		        "enrichment_path": "404589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "404589.protein.info.v11.5.txt",
		        "node_list_path": "404589.protein.complete.v11.5.txt"
		    }
		]
    )()

def HungatellaHathewayi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hungatella hathewayi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HungatellaHathewayi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "154046.protein.sequences.v11.5.fa",
		        "enrichment_path": "154046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "154046.protein.info.v11.5.txt",
		        "node_list_path": "154046.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmodiumVinckei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium vinckei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumVinckei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5860.protein.sequences.v11.5.fa",
		        "enrichment_path": "5860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5860.protein.info.v11.5.txt",
		        "node_list_path": "5860.protein.complete.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaDiuraphisNoxiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Diuraphis noxia) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaDiuraphisNoxiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118101.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118101.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118101.clusters.proteins.v11.5.txt",
		        "sequence_path": "118101.protein.sequences.v11.5.fa",
		        "enrichment_path": "118101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118101.protein.info.v11.5.txt",
		        "node_list_path": "118101.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118101.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PythiumUltimum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pythium ultimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PythiumUltimum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "65071.protein.sequences.v11.5.fa",
		        "enrichment_path": "65071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65071.protein.info.v11.5.txt",
		        "node_list_path": "65071.protein.complete.v11.5.txt"
		    }
		]
    )()

def LabrenziaAlexandrii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Labrenzia alexandrii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrenziaAlexandrii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "388408.protein.sequences.v11.5.fa",
		        "enrichment_path": "388408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388408.protein.info.v11.5.txt",
		        "node_list_path": "388408.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumFrigidicarnis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium frigidicarnis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumFrigidicarnis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84698.protein.sequences.v11.5.fa",
		        "enrichment_path": "84698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84698.protein.info.v11.5.txt",
		        "node_list_path": "84698.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaAnserinaEsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia anserina Es Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaAnserinaEsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1365188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1365188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1365188.clusters.proteins.v11.5.txt",
		        "sequence_path": "1365188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1365188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1365188.protein.info.v11.5.txt",
		        "node_list_path": "1365188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1365188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaueraSp63Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. 63 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraSp63Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "497321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "497321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "497321.clusters.proteins.v11.5.txt",
		        "sequence_path": "497321.protein.sequences.v11.5.fa",
		        "enrichment_path": "497321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "497321.protein.info.v11.5.txt",
		        "node_list_path": "497321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "497321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaCsv86Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida CSV86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaCsv86Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005395.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005395.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005395.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005395.protein.info.v11.5.txt",
		        "node_list_path": "1005395.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005395.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacterium3818(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 38-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacterium3818", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895746.protein.info.v11.5.txt",
		        "node_list_path": "1895746.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium3157faact1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 3157FAACT1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium3157faact1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658086.clusters.proteins.v11.5.txt",
		        "sequence_path": "658086.protein.sequences.v11.5.fa",
		        "enrichment_path": "658086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658086.protein.info.v11.5.txt",
		        "node_list_path": "658086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusGammatolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus gammatolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusGammatolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "593117.protein.sequences.v11.5.fa",
		        "enrichment_path": "593117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "593117.protein.info.v11.5.txt",
		        "node_list_path": "593117.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_46_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817824.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817824.protein.info.v11.5.txt",
		        "node_list_path": "1817824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfatatorIndicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfatator indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfatatorIndicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "667014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "667014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "667014.clusters.proteins.v11.5.txt",
		        "sequence_path": "667014.protein.sequences.v11.5.fa",
		        "enrichment_path": "667014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667014.protein.info.v11.5.txt",
		        "node_list_path": "667014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "667014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaInsidiosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia insidiosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaInsidiosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "190721.protein.sequences.v11.5.fa",
		        "enrichment_path": "190721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190721.protein.info.v11.5.txt",
		        "node_list_path": "190721.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinospirillumMinutulumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinospirillum minutulum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinospirillumMinutulumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122212.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122212.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122212.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122212.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122212.protein.info.v11.5.txt",
		        "node_list_path": "1122212.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122212.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslp40081(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLP40081 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslp40081", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1536769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536769.protein.info.v11.5.txt",
		        "node_list_path": "1536769.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusProtochlamydiaNaegleriophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Protochlamydia naegleriophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusProtochlamydiaNaegleriophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "389348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "389348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "389348.clusters.proteins.v11.5.txt",
		        "sequence_path": "389348.protein.sequences.v11.5.fa",
		        "enrichment_path": "389348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "389348.protein.info.v11.5.txt",
		        "node_list_path": "389348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "389348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusParacollinoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paracollinoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParacollinoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "240427.protein.sequences.v11.5.fa",
		        "enrichment_path": "240427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240427.protein.info.v11.5.txt",
		        "node_list_path": "240427.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanococcoidesVulcaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanococcoides vulcani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcoidesVulcaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1353158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1353158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1353158.clusters.proteins.v11.5.txt",
		        "sequence_path": "1353158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353158.protein.info.v11.5.txt",
		        "node_list_path": "1353158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1353158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasDaqiaonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas daqiaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasDaqiaonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "650850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "650850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "650850.clusters.proteins.v11.5.txt",
		        "sequence_path": "650850.protein.sequences.v11.5.fa",
		        "enrichment_path": "650850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "650850.protein.info.v11.5.txt",
		        "node_list_path": "650850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "650850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureimonasSpAu12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpAu12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1638161.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638161.protein.info.v11.5.txt",
		        "node_list_path": "1638161.protein.complete.v11.5.txt"
		    }
		]
    )()

def PoseidonocellaSedimentorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Poseidonocella sedimentorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PoseidonocellaSedimentorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "871652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "871652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "871652.clusters.proteins.v11.5.txt",
		        "sequence_path": "871652.protein.sequences.v11.5.fa",
		        "enrichment_path": "871652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871652.protein.info.v11.5.txt",
		        "node_list_path": "871652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "871652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloropiconPrimusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloropicon primus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloropiconPrimusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1764295.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1764295.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1764295.clusters.proteins.v11.5.txt",
		        "sequence_path": "1764295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1764295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1764295.protein.info.v11.5.txt",
		        "node_list_path": "1764295.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1764295.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRbg167010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RBG_16_70_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRbg167010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797174.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797174.protein.info.v11.5.txt",
		        "node_list_path": "1797174.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumParadoxumJwYl7Dsm7308Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] paradoxum JW-YL-7 DSM 7308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumParadoxumJwYl7Dsm7308Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121328.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121328.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121328.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121328.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121328.protein.info.v11.5.txt",
		        "node_list_path": "1121328.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121328.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanococcusVannieliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus vannielii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusVannieliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "406327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "406327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "406327.clusters.proteins.v11.5.txt",
		        "sequence_path": "406327.protein.sequences.v11.5.fa",
		        "enrichment_path": "406327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406327.protein.info.v11.5.txt",
		        "node_list_path": "406327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "406327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusRuminisAtcc27782(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ruminis ATCC27782 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusRuminisAtcc27782", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1069534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069534.protein.info.v11.5.txt",
		        "node_list_path": "1069534.protein.complete.v11.5.txt"
		    }
		]
    )()

def RobinsoniellaPeoriensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Robinsoniella peoriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RobinsoniellaPeoriensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "180332.protein.sequences.v11.5.fa",
		        "enrichment_path": "180332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180332.protein.info.v11.5.txt",
		        "node_list_path": "180332.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChromohalobacterSalexigens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chromohalobacter salexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromohalobacterSalexigens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290398.protein.sequences.v11.5.fa",
		        "enrichment_path": "290398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290398.protein.info.v11.5.txt",
		        "node_list_path": "290398.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLeaf311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLeaf311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736332.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736332.protein.info.v11.5.txt",
		        "node_list_path": "1736332.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusSydowiiCbs59365(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sydowii CBS 593.65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusSydowiiCbs59365", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1036612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036612.protein.info.v11.5.txt",
		        "node_list_path": "1036612.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyxococcusFulvus124b02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus fulvus 124B02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcusFulvus124b02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1334629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1334629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1334629.protein.info.v11.5.txt",
		        "node_list_path": "1334629.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaribacterDokdonensisDsw5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter dokdonensis DSW-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterDokdonensisDsw5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1300348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1300348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1300348.clusters.proteins.v11.5.txt",
		        "sequence_path": "1300348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300348.protein.info.v11.5.txt",
		        "node_list_path": "1300348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1300348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElectrophorusElectricusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Electrophorus electricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElectrophorusElectricusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8005.clusters.proteins.v11.5.txt",
		        "sequence_path": "8005.protein.sequences.v11.5.fa",
		        "enrichment_path": "8005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8005.protein.info.v11.5.txt",
		        "node_list_path": "8005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAgilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus agilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAgilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1601.protein.sequences.v11.5.fa",
		        "enrichment_path": "1601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1601.protein.info.v11.5.txt",
		        "node_list_path": "1601.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhoceaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phocea massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhoceaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841867.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841867.protein.info.v11.5.txt",
		        "node_list_path": "1841867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyricicoccusPullicaecorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyricicoccus pullicaecorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyricicoccusPullicaecorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203606.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203606.protein.info.v11.5.txt",
		        "node_list_path": "1203606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumAcamd5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium acAMD5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumAcamd5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1504319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504319.protein.info.v11.5.txt",
		        "node_list_path": "1504319.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerticilliumLongisporum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verticillium longisporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerticilliumLongisporum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "100787.protein.sequences.v11.5.fa",
		        "enrichment_path": "100787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "100787.protein.info.v11.5.txt",
		        "node_list_path": "100787.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeoasaiaChiangmaiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neoasaia chiangmaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeoasaiaChiangmaiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "320497.protein.sequences.v11.5.fa",
		        "enrichment_path": "320497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "320497.protein.info.v11.5.txt",
		        "node_list_path": "320497.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumRoquefortiFm164(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium roqueforti FM164 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumRoquefortiFm164", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1365484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1365484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1365484.protein.info.v11.5.txt",
		        "node_list_path": "1365484.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxWautersiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax wautersii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxWautersiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1177982.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1177982.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1177982.clusters.proteins.v11.5.txt",
		        "sequence_path": "1177982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177982.protein.info.v11.5.txt",
		        "node_list_path": "1177982.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1177982.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RutstroemiaSpNjr2017aWrk4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rutstroemia sp. NJR-2017a WRK4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RutstroemiaSpNjr2017aWrk4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2070412.protein.sequences.v11.5.fa",
		        "enrichment_path": "2070412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2070412.protein.info.v11.5.txt",
		        "node_list_path": "2070412.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizophagusSpMucl43196Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus sp. MUCL 43196 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizophagusSpMucl43196Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803374.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803374.protein.info.v11.5.txt",
		        "node_list_path": "1803374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixibacteriaBacterium448493Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium 4484_93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixibacteriaBacterium448493Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1970780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1970780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1970780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1970780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970780.protein.info.v11.5.txt",
		        "node_list_path": "1970780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1970780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpUnc358mftsu51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. UNC358MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpUnc358mftsu51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449049.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449049.protein.info.v11.5.txt",
		        "node_list_path": "1449049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumAutotrophicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum autotrophicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumAutotrophicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "180195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "180195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "180195.clusters.proteins.v11.5.txt",
		        "sequence_path": "180195.protein.sequences.v11.5.fa",
		        "enrichment_path": "180195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180195.protein.info.v11.5.txt",
		        "node_list_path": "180195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "180195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RheinheimeraBalticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera baltica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraBalticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123053.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123053.protein.info.v11.5.txt",
		        "node_list_path": "1123053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilaceaeBacteriumUrhb0048Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHB0048 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilaceaeBacteriumUrhb0048Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380347.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380347.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380347.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380347.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380347.protein.info.v11.5.txt",
		        "node_list_path": "1380347.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380347.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrypanosomaTheileriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma theileri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrypanosomaTheileriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67003.clusters.proteins.v11.5.txt",
		        "sequence_path": "67003.protein.sequences.v11.5.fa",
		        "enrichment_path": "67003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67003.protein.info.v11.5.txt",
		        "node_list_path": "67003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonadalesBacteriumTw7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonadales bacterium TW7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonadalesBacteriumTw7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "156578.protein.sequences.v11.5.fa",
		        "enrichment_path": "156578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156578.protein.info.v11.5.txt",
		        "node_list_path": "156578.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetothermiaBacterium6432Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetothermia bacterium 64_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetothermiaBacterium6432Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635286.protein.info.v11.5.txt",
		        "node_list_path": "1635286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthobacteraceaeBacterium501bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthobacteraceae bacterium 501b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthobacteraceaeBacterium501bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1168059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1168059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1168059.clusters.proteins.v11.5.txt",
		        "sequence_path": "1168059.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168059.protein.info.v11.5.txt",
		        "node_list_path": "1168059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1168059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionCpr3Bacterium4484211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR3 bacterium 4484_211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionCpr3Bacterium4484211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1968527.protein.sequences.v11.5.fa",
		        "enrichment_path": "1968527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1968527.protein.info.v11.5.txt",
		        "node_list_path": "1968527.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumParaoxydansDh1b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium paraoxydans DH1b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumParaoxydansDh1b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1416752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416752.protein.info.v11.5.txt",
		        "node_list_path": "1416752.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesIndicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesIndicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "417292.protein.sequences.v11.5.fa",
		        "enrichment_path": "417292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "417292.protein.info.v11.5.txt",
		        "node_list_path": "417292.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidithiobacillusCaldusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus caldus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithiobacillusCaldusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "637389.clusters.info.v11.5.txt",
		        "cluster_tree_path": "637389.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "637389.clusters.proteins.v11.5.txt",
		        "sequence_path": "637389.protein.sequences.v11.5.fa",
		        "enrichment_path": "637389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637389.protein.info.v11.5.txt",
		        "node_list_path": "637389.cluster.nodes.v11.5.txt",
		        "edge_list_path": "637389.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlrhCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALRh Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlrhCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1266911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1266911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1266911.clusters.proteins.v11.5.txt",
		        "sequence_path": "1266911.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266911.protein.info.v11.5.txt",
		        "node_list_path": "1266911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1266911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferYueqingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer yueqingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferYueqingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658219.protein.sequences.v11.5.fa",
		        "enrichment_path": "658219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658219.protein.info.v11.5.txt",
		        "node_list_path": "658219.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaSpT8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichinella sp. T8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaSpT8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "92180.clusters.info.v11.5.txt",
		        "cluster_tree_path": "92180.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "92180.clusters.proteins.v11.5.txt",
		        "sequence_path": "92180.protein.sequences.v11.5.fa",
		        "enrichment_path": "92180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92180.protein.info.v11.5.txt",
		        "node_list_path": "92180.cluster.nodes.v11.5.txt",
		        "edge_list_path": "92180.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasAdhaerensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas adhaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasAdhaerensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280949.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280949.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280949.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280949.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280949.protein.info.v11.5.txt",
		        "node_list_path": "1280949.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280949.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumHominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumHominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "162426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "162426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "162426.clusters.proteins.v11.5.txt",
		        "sequence_path": "162426.protein.sequences.v11.5.fa",
		        "enrichment_path": "162426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "162426.protein.info.v11.5.txt",
		        "node_list_path": "162426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "162426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusPneumoniaeD39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae D39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPneumoniaeD39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "373153.clusters.info.v11.5.txt",
		        "cluster_tree_path": "373153.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "373153.clusters.proteins.v11.5.txt",
		        "sequence_path": "373153.protein.sequences.v11.5.fa",
		        "enrichment_path": "373153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "373153.protein.info.v11.5.txt",
		        "node_list_path": "373153.cluster.nodes.v11.5.txt",
		        "edge_list_path": "373153.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoelleriellaLiberaRcef2490(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moelleriella libera RCEF 2490 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoelleriellaLiberaRcef2490", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1081109.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081109.protein.info.v11.5.txt",
		        "node_list_path": "1081109.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaGirerdiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma girerdii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaGirerdiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1318617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1318617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1318617.clusters.proteins.v11.5.txt",
		        "sequence_path": "1318617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1318617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1318617.protein.info.v11.5.txt",
		        "node_list_path": "1318617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1318617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpOralTaxon414(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. oral taxon 414 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpOralTaxon414", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "712122.protein.sequences.v11.5.fa",
		        "enrichment_path": "712122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712122.protein.info.v11.5.txt",
		        "node_list_path": "712122.protein.complete.v11.5.txt"
		    }
		]
    )()

def DysgonomonasHofstadiiJcm17038Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas hofstadii JCM 17038 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasHofstadiiJcm17038Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298597.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298597.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298597.protein.info.v11.5.txt",
		        "node_list_path": "1298597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpOv219Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. OV219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpOv219Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884377.protein.info.v11.5.txt",
		        "node_list_path": "1884377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatenibacteriumSpCag290(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catenibacterium sp. CAG:290 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenibacteriumSpCag290", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262767.protein.info.v11.5.txt",
		        "node_list_path": "1262767.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaInyonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora inyonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaInyonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47866.protein.sequences.v11.5.fa",
		        "enrichment_path": "47866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47866.protein.info.v11.5.txt",
		        "node_list_path": "47866.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_45_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618832.protein.info.v11.5.txt",
		        "node_list_path": "1618832.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusTuaregi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus tuaregi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusTuaregi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816681.protein.info.v11.5.txt",
		        "node_list_path": "1816681.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulophagaLyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga lytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaLyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "867900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "867900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "867900.clusters.proteins.v11.5.txt",
		        "sequence_path": "867900.protein.sequences.v11.5.fa",
		        "enrichment_path": "867900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867900.protein.info.v11.5.txt",
		        "node_list_path": "867900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "867900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmatimonadetesBacteriumScn7022Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium SCN 70-22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonadetesBacteriumScn7022Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660163.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660163.protein.info.v11.5.txt",
		        "node_list_path": "1660163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZetaproteobacteriaBacteriumCg2305937(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG2_30_59_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaproteobacteriaBacteriumCg2305937", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805430.protein.info.v11.5.txt",
		        "node_list_path": "1805430.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumKa00274(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium KA00274 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumKa00274", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1497955.protein.sequences.v11.5.fa",
		        "enrichment_path": "1497955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1497955.protein.info.v11.5.txt",
		        "node_list_path": "1497955.protein.complete.v11.5.txt"
		    }
		]
    )()

def OctadecabacterArcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Octadecabacter arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OctadecabacterArcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391616.clusters.proteins.v11.5.txt",
		        "sequence_path": "391616.protein.sequences.v11.5.fa",
		        "enrichment_path": "391616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391616.protein.info.v11.5.txt",
		        "node_list_path": "391616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262816.protein.info.v11.5.txt",
		        "node_list_path": "1262816.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaTyphimuriumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica Typhimurium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaTyphimuriumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "90371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "90371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "90371.clusters.proteins.v11.5.txt",
		        "sequence_path": "90371.protein.sequences.v11.5.fa",
		        "enrichment_path": "90371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90371.protein.info.v11.5.txt",
		        "node_list_path": "90371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "90371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesHalstedii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces halstedii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesHalstedii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1944.protein.info.v11.5.txt",
		        "node_list_path": "1944.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasCupida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas cupida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasCupida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44933.protein.sequences.v11.5.fa",
		        "enrichment_path": "44933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44933.protein.info.v11.5.txt",
		        "node_list_path": "44933.protein.complete.v11.5.txt"
		    }
		]
    )()

def PilodermaCroceumF1598(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Piloderma croceum F 1598 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PilodermaCroceumF1598", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765440.protein.sequences.v11.5.fa",
		        "enrichment_path": "765440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765440.protein.info.v11.5.txt",
		        "node_list_path": "765440.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwe23937(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWE2_39_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwe23937", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618950.protein.info.v11.5.txt",
		        "node_list_path": "1618950.protein.complete.v11.5.txt"
		    }
		]
    )()

def EggerthiaCatenaformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eggerthia catenaformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthiaCatenaformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999415.protein.sequences.v11.5.fa",
		        "enrichment_path": "999415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999415.protein.info.v11.5.txt",
		        "node_list_path": "999415.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrolunatusSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microlunatus soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrolunatusSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "630515.protein.sequences.v11.5.fa",
		        "enrichment_path": "630515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "630515.protein.info.v11.5.txt",
		        "node_list_path": "630515.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaueraSp27(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. 27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraSp27", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "305700.protein.sequences.v11.5.fa",
		        "enrichment_path": "305700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "305700.protein.info.v11.5.txt",
		        "node_list_path": "305700.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpathasporaPassalidarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spathaspora passalidarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpathasporaPassalidarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "340170.clusters.info.v11.5.txt",
		        "cluster_tree_path": "340170.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "340170.clusters.proteins.v11.5.txt",
		        "sequence_path": "340170.protein.sequences.v11.5.fa",
		        "enrichment_path": "340170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340170.protein.info.v11.5.txt",
		        "node_list_path": "340170.cluster.nodes.v11.5.txt",
		        "edge_list_path": "340170.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMjm8645(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MJM8645 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMjm8645", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120523.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120523.protein.info.v11.5.txt",
		        "node_list_path": "1120523.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumSubtropicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium subtropicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumSubtropicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1638989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1638989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1638989.clusters.proteins.v11.5.txt",
		        "sequence_path": "1638989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638989.protein.info.v11.5.txt",
		        "node_list_path": "1638989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1638989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalidrisPygmaea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Calidris pygmaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalidrisPygmaea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "425635.protein.sequences.v11.5.fa",
		        "enrichment_path": "425635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425635.protein.info.v11.5.txt",
		        "node_list_path": "425635.protein.complete.v11.5.txt"
		    }
		]
    )()

def PilibacterTermitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pilibacter termitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PilibacterTermitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "263852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "263852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "263852.clusters.proteins.v11.5.txt",
		        "sequence_path": "263852.protein.sequences.v11.5.fa",
		        "enrichment_path": "263852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263852.protein.info.v11.5.txt",
		        "node_list_path": "263852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "263852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc136108Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_36_108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc136108Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618894.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618894.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618894.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618894.protein.info.v11.5.txt",
		        "node_list_path": "1618894.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618894.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaEutrophaJmp134(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia eutropha JMP134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaEutrophaJmp134", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264198.protein.sequences.v11.5.fa",
		        "enrichment_path": "264198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264198.protein.info.v11.5.txt",
		        "node_list_path": "264198.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellvibrioJaponicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioJaponicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "498211.clusters.info.v11.5.txt",
		        "cluster_tree_path": "498211.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "498211.clusters.proteins.v11.5.txt",
		        "sequence_path": "498211.protein.sequences.v11.5.fa",
		        "enrichment_path": "498211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498211.protein.info.v11.5.txt",
		        "node_list_path": "498211.cluster.nodes.v11.5.txt",
		        "edge_list_path": "498211.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesCoprocolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides coprocola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCoprocolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "470145.clusters.info.v11.5.txt",
		        "cluster_tree_path": "470145.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "470145.clusters.proteins.v11.5.txt",
		        "sequence_path": "470145.protein.sequences.v11.5.fa",
		        "enrichment_path": "470145.protein.enrichment.terms.v11.5.txt",
		        "info_path": "470145.protein.info.v11.5.txt",
		        "node_list_path": "470145.cluster.nodes.v11.5.txt",
		        "edge_list_path": "470145.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpKordi52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpKordi52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585425.protein.sequences.v11.5.fa",
		        "enrichment_path": "585425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585425.protein.info.v11.5.txt",
		        "node_list_path": "585425.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastococcusSpDsm46838(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 46838 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusSpDsm46838", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798228.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798228.protein.info.v11.5.txt",
		        "node_list_path": "1798228.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassotaleaSpPp2459Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassotalea sp. PP2-459 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassotaleaSpPp2459Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1742724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1742724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1742724.clusters.proteins.v11.5.txt",
		        "sequence_path": "1742724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742724.protein.info.v11.5.txt",
		        "node_list_path": "1742724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1742724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRoot61Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRoot61Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736570.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736570.protein.info.v11.5.txt",
		        "node_list_path": "1736570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloferaxMucosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloferax mucosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloferaxMucosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "662479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "662479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "662479.clusters.proteins.v11.5.txt",
		        "sequence_path": "662479.protein.sequences.v11.5.fa",
		        "enrichment_path": "662479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "662479.protein.info.v11.5.txt",
		        "node_list_path": "662479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "662479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprococcusCatusGd7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus catus GD/7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprococcusCatusGd7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717962.protein.sequences.v11.5.fa",
		        "enrichment_path": "717962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717962.protein.info.v11.5.txt",
		        "node_list_path": "717962.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAvermitilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces avermitilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAvermitilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "227882.protein.sequences.v11.5.fa",
		        "enrichment_path": "227882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227882.protein.info.v11.5.txt",
		        "node_list_path": "227882.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaPallens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella pallens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaPallens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "997353.protein.sequences.v11.5.fa",
		        "enrichment_path": "997353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997353.protein.info.v11.5.txt",
		        "node_list_path": "997353.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpUnccl20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. UNCCL20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpUnccl20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502773.protein.info.v11.5.txt",
		        "node_list_path": "1502773.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastomonasSpRac04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastomonas sp. RAC04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomonasSpRac04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1842535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1842535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1842535.clusters.proteins.v11.5.txt",
		        "sequence_path": "1842535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842535.protein.info.v11.5.txt",
		        "node_list_path": "1842535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1842535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FasciolaGigantica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fasciola gigantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FasciolaGigantica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46835.protein.sequences.v11.5.fa",
		        "enrichment_path": "46835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46835.protein.info.v11.5.txt",
		        "node_list_path": "46835.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrauserellaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prauserella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrauserellaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "530584.clusters.info.v11.5.txt",
		        "cluster_tree_path": "530584.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "530584.clusters.proteins.v11.5.txt",
		        "sequence_path": "530584.protein.sequences.v11.5.fa",
		        "enrichment_path": "530584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "530584.protein.info.v11.5.txt",
		        "node_list_path": "530584.cluster.nodes.v11.5.txt",
		        "edge_list_path": "530584.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PajaroellobacterAbortibovisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pajaroellobacter abortibovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PajaroellobacterAbortibovisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882918.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882918.protein.info.v11.5.txt",
		        "node_list_path": "1882918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE1747Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E1747 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE1747Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834128.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834128.protein.info.v11.5.txt",
		        "node_list_path": "1834128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSoliNbrc102451(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus soli NBRC 102451 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSoliNbrc102451", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348630.protein.info.v11.5.txt",
		        "node_list_path": "1348630.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpTcuHl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TCU-HL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpTcuHl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1856685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1856685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1856685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1856685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1856685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1856685.protein.info.v11.5.txt",
		        "node_list_path": "1856685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1856685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpF0425(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0425 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpF0425", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "904296.protein.sequences.v11.5.fa",
		        "enrichment_path": "904296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904296.protein.info.v11.5.txt",
		        "node_list_path": "904296.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterSp638Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter sp. 638 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterSp638Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "399742.clusters.info.v11.5.txt",
		        "cluster_tree_path": "399742.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "399742.clusters.proteins.v11.5.txt",
		        "sequence_path": "399742.protein.sequences.v11.5.fa",
		        "enrichment_path": "399742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399742.protein.info.v11.5.txt",
		        "node_list_path": "399742.cluster.nodes.v11.5.txt",
		        "edge_list_path": "399742.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TepidiphilusMargaritiferCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tepidiphilus margaritifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidiphilusMargaritiferCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123354.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123354.protein.info.v11.5.txt",
		        "node_list_path": "1123354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrachymyrmexCornetzi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trachymyrmex cornetzi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrachymyrmexCornetzi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471704.protein.sequences.v11.5.fa",
		        "enrichment_path": "471704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471704.protein.info.v11.5.txt",
		        "node_list_path": "471704.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumVe20208Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20208 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumVe20208Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232449.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232449.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232449.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232449.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232449.protein.info.v11.5.txt",
		        "node_list_path": "1232449.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232449.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerotignumPropionicumDsm1682Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerotignum propionicum DSM 1682 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotignumPropionicumDsm1682Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "991789.clusters.info.v11.5.txt",
		        "cluster_tree_path": "991789.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "991789.clusters.proteins.v11.5.txt",
		        "sequence_path": "991789.protein.sequences.v11.5.fa",
		        "enrichment_path": "991789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "991789.protein.info.v11.5.txt",
		        "node_list_path": "991789.cluster.nodes.v11.5.txt",
		        "edge_list_path": "991789.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GanodermaSinenseZz02141Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ganoderma sinense ZZ0214-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GanodermaSinenseZz02141Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1077348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1077348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1077348.clusters.proteins.v11.5.txt",
		        "sequence_path": "1077348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077348.protein.info.v11.5.txt",
		        "node_list_path": "1077348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1077348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacticigeniumNaphtae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lacticigenium naphtae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacticigeniumNaphtae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122143.protein.info.v11.5.txt",
		        "node_list_path": "1122143.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesClavuligerus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces clavuligerus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesClavuligerus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "443255.protein.sequences.v11.5.fa",
		        "enrichment_path": "443255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443255.protein.info.v11.5.txt",
		        "node_list_path": "443255.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRbg16408Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RBG_16_40_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRbg16408Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797388.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797388.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797388.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797388.protein.info.v11.5.txt",
		        "node_list_path": "1797388.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797388.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphiprionPerculaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amphiprion percula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphiprionPerculaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "161767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "161767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "161767.clusters.proteins.v11.5.txt",
		        "sequence_path": "161767.protein.sequences.v11.5.fa",
		        "enrichment_path": "161767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161767.protein.info.v11.5.txt",
		        "node_list_path": "161767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "161767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesHumiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesHumiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1428620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1428620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1428620.clusters.proteins.v11.5.txt",
		        "sequence_path": "1428620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1428620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1428620.protein.info.v11.5.txt",
		        "node_list_path": "1428620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1428620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrobacterHamburgensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrobacter hamburgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrobacterHamburgensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "323097.clusters.info.v11.5.txt",
		        "cluster_tree_path": "323097.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "323097.clusters.proteins.v11.5.txt",
		        "sequence_path": "323097.protein.sequences.v11.5.fa",
		        "enrichment_path": "323097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323097.protein.info.v11.5.txt",
		        "node_list_path": "323097.cluster.nodes.v11.5.txt",
		        "edge_list_path": "323097.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaDrancourtiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella drancourtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaDrancourtiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658187.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658187.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658187.clusters.proteins.v11.5.txt",
		        "sequence_path": "658187.protein.sequences.v11.5.fa",
		        "enrichment_path": "658187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658187.protein.info.v11.5.txt",
		        "node_list_path": "658187.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658187.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfolobusSolfataricusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus solfataricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusSolfataricusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "273057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "273057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "273057.clusters.proteins.v11.5.txt",
		        "sequence_path": "273057.protein.sequences.v11.5.fa",
		        "enrichment_path": "273057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273057.protein.info.v11.5.txt",
		        "node_list_path": "273057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "273057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalipaludibacillusAurantiacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salipaludibacillus aurantiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalipaludibacillusAurantiacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1601833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1601833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1601833.protein.info.v11.5.txt",
		        "node_list_path": "1601833.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasArtemidisF0399Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas artemidis F0399 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasArtemidisF0399Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "749551.clusters.info.v11.5.txt",
		        "cluster_tree_path": "749551.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "749551.clusters.proteins.v11.5.txt",
		        "sequence_path": "749551.protein.sequences.v11.5.fa",
		        "enrichment_path": "749551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "749551.protein.info.v11.5.txt",
		        "node_list_path": "749551.cluster.nodes.v11.5.txt",
		        "edge_list_path": "749551.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MusaAcuminataSubspMalaccensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Musa acuminata subsp. malaccensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusaAcuminataSubspMalaccensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "214687.clusters.info.v11.5.txt",
		        "cluster_tree_path": "214687.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "214687.clusters.proteins.v11.5.txt",
		        "sequence_path": "214687.protein.sequences.v11.5.fa",
		        "enrichment_path": "214687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "214687.protein.info.v11.5.txt",
		        "node_list_path": "214687.cluster.nodes.v11.5.txt",
		        "edge_list_path": "214687.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PisolithusMicrocarpus441Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pisolithus microcarpus 441 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PisolithusMicrocarpus441Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765257.clusters.proteins.v11.5.txt",
		        "sequence_path": "765257.protein.sequences.v11.5.fa",
		        "enrichment_path": "765257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765257.protein.info.v11.5.txt",
		        "node_list_path": "765257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophomonasSpDtu018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas sp. DTU018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophomonasSpDtu018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671629.protein.info.v11.5.txt",
		        "node_list_path": "1671629.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobacteriumVacuolatumDsm3385(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterium vacuolatum DSM 3385 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteriumVacuolatumDsm3385", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121400.protein.info.v11.5.txt",
		        "node_list_path": "1121400.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaKristenseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia kristensenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaKristenseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28152.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28152.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28152.clusters.proteins.v11.5.txt",
		        "sequence_path": "28152.protein.sequences.v11.5.fa",
		        "enrichment_path": "28152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28152.protein.info.v11.5.txt",
		        "node_list_path": "28152.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28152.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpAe3009Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpAe3009Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280666.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280666.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280666.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280666.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280666.protein.info.v11.5.txt",
		        "node_list_path": "1280666.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280666.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogulbenkianiaFerrooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogulbenkianiaFerrooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "279714.protein.sequences.v11.5.fa",
		        "enrichment_path": "279714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279714.protein.info.v11.5.txt",
		        "node_list_path": "279714.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusNidulansFgscA4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus nidulans FGSC A4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusNidulansFgscA4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "227321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "227321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "227321.clusters.proteins.v11.5.txt",
		        "sequence_path": "227321.protein.sequences.v11.5.fa",
		        "enrichment_path": "227321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227321.protein.info.v11.5.txt",
		        "node_list_path": "227321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "227321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifoxya2Full479(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYA2_FULL_47_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxya2Full479", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797995.protein.info.v11.5.txt",
		        "node_list_path": "1797995.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterMallensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter mallensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterMallensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "652787.clusters.info.v11.5.txt",
		        "cluster_tree_path": "652787.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "652787.clusters.proteins.v11.5.txt",
		        "sequence_path": "652787.protein.sequences.v11.5.fa",
		        "enrichment_path": "652787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "652787.protein.info.v11.5.txt",
		        "node_list_path": "652787.cluster.nodes.v11.5.txt",
		        "edge_list_path": "652787.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaAsterYellowsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma aster yellows Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaAsterYellowsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "322098.clusters.info.v11.0.txt",
		        "cluster_tree_path": "322098.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "322098.clusters.proteins.v11.0.txt",
		        "sequence_path": "322098.protein.sequences.v11.0.fa",
		        "enrichment_path": "322098.protein.enrichment.terms.v11.0.txt",
		        "info_path": "322098.protein.info.v11.0.txt",
		        "node_list_path": "322098.cluster.nodes.v11.0.txt",
		        "edge_list_path": "322098.protein.cluster.v11.0.txt"
		    }
		]
    )()

def MarivivensSpJlt3646Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marivivens sp. JLT3646 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivivensSpJlt3646Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1920883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1920883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1920883.clusters.proteins.v11.5.txt",
		        "sequence_path": "1920883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920883.protein.info.v11.5.txt",
		        "node_list_path": "1920883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1920883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConsotaellaSalsifontis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Consotaella salsifontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConsotaellaSalsifontis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1365950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1365950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1365950.protein.info.v11.5.txt",
		        "node_list_path": "1365950.protein.complete.v11.5.txt"
		    }
		]
    )()

def PectobacteriumWasabiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium wasabiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumWasabiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "561231.protein.sequences.v11.5.fa",
		        "enrichment_path": "561231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561231.protein.info.v11.5.txt",
		        "node_list_path": "561231.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNk4a136(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNk4a136", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "877420.protein.sequences.v11.5.fa",
		        "enrichment_path": "877420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877420.protein.info.v11.5.txt",
		        "node_list_path": "877420.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxSpDg881Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. DG881 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxSpDg881Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "236097.clusters.info.v11.5.txt",
		        "cluster_tree_path": "236097.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "236097.clusters.proteins.v11.5.txt",
		        "sequence_path": "236097.protein.sequences.v11.5.fa",
		        "enrichment_path": "236097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "236097.protein.info.v11.5.txt",
		        "node_list_path": "236097.cluster.nodes.v11.5.txt",
		        "edge_list_path": "236097.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnaporthiopsisPoaeAtcc64411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnaporthiopsis poae ATCC 64411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnaporthiopsisPoaeAtcc64411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644358.protein.sequences.v11.5.fa",
		        "enrichment_path": "644358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644358.protein.info.v11.5.txt",
		        "node_list_path": "644358.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSericytochromatiaBacteriumS15bMn24Cbmw12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sericytochromatia bacterium S15B-MN24 CBMW_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSericytochromatiaBacteriumS15bMn24Cbmw12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1919279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1919279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1919279.clusters.proteins.v11.5.txt",
		        "sequence_path": "1919279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1919279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1919279.protein.info.v11.5.txt",
		        "node_list_path": "1919279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1919279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslH80548Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSL H8-0548 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslH80548Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1920422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1920422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1920422.clusters.proteins.v11.5.txt",
		        "sequence_path": "1920422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920422.protein.info.v11.5.txt",
		        "node_list_path": "1920422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1920422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacillusPsychroduransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacillus psychrodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacillusPsychroduransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "126157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "126157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "126157.clusters.proteins.v11.5.txt",
		        "sequence_path": "126157.protein.sequences.v11.5.fa",
		        "enrichment_path": "126157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "126157.protein.info.v11.5.txt",
		        "node_list_path": "126157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "126157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JeotgalibacillusSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalibacillus soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalibacillusSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "889306.protein.sequences.v11.5.fa",
		        "enrichment_path": "889306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "889306.protein.info.v11.5.txt",
		        "node_list_path": "889306.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterGhanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter ghanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterGhanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "431306.protein.sequences.v11.5.fa",
		        "enrichment_path": "431306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431306.protein.info.v11.5.txt",
		        "node_list_path": "431306.protein.complete.v11.5.txt"
		    }
		]
    )()

def HordeumVulgareSubspVulgare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hordeum vulgare subsp. vulgare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HordeumVulgareSubspVulgare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "112509.protein.sequences.v11.5.fa",
		        "enrichment_path": "112509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112509.protein.info.v11.5.txt",
		        "node_list_path": "112509.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusXiamenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusXiamenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1178537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1178537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1178537.clusters.proteins.v11.5.txt",
		        "sequence_path": "1178537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1178537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1178537.protein.info.v11.5.txt",
		        "node_list_path": "1178537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1178537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumSm2331(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium SM23_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumSm2331", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703762.protein.info.v11.5.txt",
		        "node_list_path": "1703762.protein.complete.v11.5.txt"
		    }
		]
    )()

def NematostellaVectensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nematostella vectensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NematostellaVectensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45351.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45351.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45351.clusters.proteins.v11.5.txt",
		        "sequence_path": "45351.protein.sequences.v11.5.fa",
		        "enrichment_path": "45351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45351.protein.info.v11.5.txt",
		        "node_list_path": "45351.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45351.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BudviciaAquaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Budvicia aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BudviciaAquaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111728.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111728.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111728.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111728.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111728.protein.info.v11.5.txt",
		        "node_list_path": "1111728.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111728.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuegeriaPomeroyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria pomeroyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaPomeroyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246200.clusters.proteins.v11.5.txt",
		        "sequence_path": "246200.protein.sequences.v11.5.fa",
		        "enrichment_path": "246200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246200.protein.info.v11.5.txt",
		        "node_list_path": "246200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb243498i20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB243_498I20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb243498i20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1471493.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1471493.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1471493.clusters.proteins.v11.5.txt",
		        "sequence_path": "1471493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471493.protein.info.v11.5.txt",
		        "node_list_path": "1471493.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1471493.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSp32oWCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 32O-W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSp32oWCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1695218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1695218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1695218.clusters.proteins.v11.5.txt",
		        "sequence_path": "1695218.protein.sequences.v11.5.fa",
		        "enrichment_path": "1695218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1695218.protein.info.v11.5.txt",
		        "node_list_path": "1695218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1695218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HylemonellaGracilisAtcc19624(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hylemonella gracilis ATCC19624 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HylemonellaGracilisAtcc19624", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "887062.protein.sequences.v11.5.fa",
		        "enrichment_path": "887062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "887062.protein.info.v11.5.txt",
		        "node_list_path": "887062.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls920Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS920 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls920Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463921.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463921.protein.info.v11.5.txt",
		        "node_list_path": "1463921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroherpetonThalassiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroherpeton thalassium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroherpetonThalassiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "517418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "517418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "517418.clusters.proteins.v11.5.txt",
		        "sequence_path": "517418.protein.sequences.v11.5.fa",
		        "enrichment_path": "517418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "517418.protein.info.v11.5.txt",
		        "node_list_path": "517418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "517418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHlucco18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCO18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHlucco18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1666917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666917.protein.info.v11.5.txt",
		        "node_list_path": "1666917.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaAgarilyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina agarilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaAgarilyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "620914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "620914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "620914.clusters.proteins.v11.5.txt",
		        "sequence_path": "620914.protein.sequences.v11.5.fa",
		        "enrichment_path": "620914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "620914.protein.info.v11.5.txt",
		        "node_list_path": "620914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "620914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaueraSpMz1t(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. MZ1T graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraSpMz1t", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "85643.protein.sequences.v11.5.fa",
		        "enrichment_path": "85643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85643.protein.info.v11.5.txt",
		        "node_list_path": "85643.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifcsplowo212Full4812(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPLOWO2_12_FULL_48_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsplowo212Full4812", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801643.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801643.protein.info.v11.5.txt",
		        "node_list_path": "1801643.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusTubingensisCbs13448Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus tubingensis CBS 134.48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusTubingensisCbs13448Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "767770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "767770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "767770.clusters.proteins.v11.5.txt",
		        "sequence_path": "767770.protein.sequences.v11.5.fa",
		        "enrichment_path": "767770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767770.protein.info.v11.5.txt",
		        "node_list_path": "767770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "767770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterSp4636(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter sp. 46_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterSp4636", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896965.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896965.protein.info.v11.5.txt",
		        "node_list_path": "1896965.protein.complete.v11.5.txt"
		    }
		]
    )()

def PunctulariaStrigosozonata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Punctularia strigosozonata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PunctulariaStrigosozonata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "202698.protein.sequences.v11.5.fa",
		        "enrichment_path": "202698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202698.protein.info.v11.5.txt",
		        "node_list_path": "202698.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpRoot720Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root720 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpRoot720Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736595.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736595.protein.info.v11.5.txt",
		        "node_list_path": "1736595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophusSpGwc25631(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophus sp. GWC2_56_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophusSpGwc25631", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802291.protein.info.v11.5.txt",
		        "node_list_path": "1802291.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonasSpScn6556(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas sp. SCN 65-56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasSpScn6556", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660095.protein.info.v11.5.txt",
		        "node_list_path": "1660095.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrobacterFarmeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter farmeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterFarmeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1114922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114922.protein.info.v11.5.txt",
		        "node_list_path": "1114922.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesVulturisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces vulturis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesVulturisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1857645.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1857645.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1857645.clusters.proteins.v11.5.txt",
		        "sequence_path": "1857645.protein.sequences.v11.5.fa",
		        "enrichment_path": "1857645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1857645.protein.info.v11.5.txt",
		        "node_list_path": "1857645.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1857645.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSuisStrIllinois(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma suis str. Illinois graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSuisStrIllinois", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "768700.protein.sequences.v11.5.fa",
		        "enrichment_path": "768700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768700.protein.info.v11.5.txt",
		        "node_list_path": "768700.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot1220Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1220 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot1220Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736432.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736432.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736432.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736432.protein.info.v11.5.txt",
		        "node_list_path": "1736432.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736432.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpSfd(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. SFD graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpSfd", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805635.protein.info.v11.5.txt",
		        "node_list_path": "1805635.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaliaeetusLeucocephalus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haliaeetus leucocephalus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaliaeetusLeucocephalus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52644.protein.sequences.v11.5.fa",
		        "enrichment_path": "52644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52644.protein.info.v11.5.txt",
		        "node_list_path": "52644.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusNurukiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus nuruki Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusNurukiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1886670.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1886670.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1886670.clusters.proteins.v11.5.txt",
		        "sequence_path": "1886670.protein.sequences.v11.5.fa",
		        "enrichment_path": "1886670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1886670.protein.info.v11.5.txt",
		        "node_list_path": "1886670.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1886670.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthromitusSpSfbmousejapanCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBmouseJapan Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthromitusSpSfbmousejapanCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1029718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1029718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1029718.clusters.proteins.v11.5.txt",
		        "sequence_path": "1029718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1029718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1029718.protein.info.v11.5.txt",
		        "node_list_path": "1029718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1029718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumAqs3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium AqS3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumAqs3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1732023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1732023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1732023.protein.info.v11.5.txt",
		        "node_list_path": "1732023.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsaiaAstilbisJcm15831(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asaia astilbis JCM 15831 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsaiaAstilbisJcm15831", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236500.protein.info.v11.5.txt",
		        "node_list_path": "1236500.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTuberculosisVariantMicroti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant microti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTuberculosisVariantMicroti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806.protein.info.v11.5.txt",
		        "node_list_path": "1806.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpJs23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. JS23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpJs23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1770053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1770053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1770053.clusters.proteins.v11.5.txt",
		        "sequence_path": "1770053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1770053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1770053.protein.info.v11.5.txt",
		        "node_list_path": "1770053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1770053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag581(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag581", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262890.protein.info.v11.5.txt",
		        "node_list_path": "1262890.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaeCc1513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaeCc1513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1357275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357275.protein.info.v11.5.txt",
		        "node_list_path": "1357275.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumMucogenicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium mucogenicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumMucogenicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56689.protein.sequences.v11.5.fa",
		        "enrichment_path": "56689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56689.protein.info.v11.5.txt",
		        "node_list_path": "56689.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumBrhC36(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium BRH_c36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumBrhC36", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1734406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1734406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1734406.protein.info.v11.5.txt",
		        "node_list_path": "1734406.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwe13517(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_35_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe13517", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618707.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618707.protein.info.v11.5.txt",
		        "node_list_path": "1618707.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfipiaBroomeaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Afipia broomeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaBroomeaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883078.clusters.proteins.v11.5.txt",
		        "sequence_path": "883078.protein.sequences.v11.5.fa",
		        "enrichment_path": "883078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883078.protein.info.v11.5.txt",
		        "node_list_path": "883078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SediminimonasQiaohouensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sediminimonas qiaohouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminimonasQiaohouensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123247.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123247.protein.info.v11.5.txt",
		        "node_list_path": "1123247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SediminibacteriumSalmoneumNbrc103935Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium salmoneum NBRC 103935 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacteriumSalmoneumNbrc103935Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1400522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1400522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1400522.clusters.proteins.v11.5.txt",
		        "sequence_path": "1400522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400522.protein.info.v11.5.txt",
		        "node_list_path": "1400522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1400522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WenyingzhuangiaFucanilyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wenyingzhuangia fucanilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WenyingzhuangiaFucanilyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1790137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1790137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1790137.clusters.proteins.v11.5.txt",
		        "sequence_path": "1790137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1790137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1790137.protein.info.v11.5.txt",
		        "node_list_path": "1790137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1790137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSmegmatisJs623Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium smegmatis JS623 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSmegmatisJs623Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "710686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "710686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "710686.clusters.proteins.v11.5.txt",
		        "sequence_path": "710686.protein.sequences.v11.5.fa",
		        "enrichment_path": "710686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710686.protein.info.v11.5.txt",
		        "node_list_path": "710686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "710686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusGinsenosidimutans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ginsenosidimutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGinsenosidimutans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1007676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007676.protein.info.v11.5.txt",
		        "node_list_path": "1007676.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusNanhaiticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius nanhaiticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusNanhaiticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573024.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573024.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573024.clusters.proteins.v11.5.txt",
		        "sequence_path": "573024.protein.sequences.v11.5.fa",
		        "enrichment_path": "573024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573024.protein.info.v11.5.txt",
		        "node_list_path": "573024.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573024.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMuproteobacteriaBacteriumRifcsphigho201Full6516(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RIFCSPHIGHO2_01_FULL_65_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRifcsphigho201Full6516", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817764.protein.info.v11.5.txt",
		        "node_list_path": "1817764.protein.complete.v11.5.txt"
		    }
		]
    )()

def OdoribacterSplanchnicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Odoribacter splanchnicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OdoribacterSplanchnicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "709991.protein.sequences.v11.5.fa",
		        "enrichment_path": "709991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709991.protein.info.v11.5.txt",
		        "node_list_path": "709991.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumFb2012(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium FB2012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumFb2012", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520817.protein.info.v11.5.txt",
		        "node_list_path": "1520817.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchistosomaHaematobium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma haematobium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaHaematobium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6185.protein.sequences.v11.5.fa",
		        "enrichment_path": "6185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6185.protein.info.v11.5.txt",
		        "node_list_path": "6185.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterAtlanticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterAtlanticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1648404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1648404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1648404.protein.info.v11.5.txt",
		        "node_list_path": "1648404.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaSpNrrlS836(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia sp. NRRL S-836 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSpNrrlS836", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1519492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519492.protein.info.v11.5.txt",
		        "node_list_path": "1519492.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiK12SubstrMg1655Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli K12 substr. MG1655 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiK12SubstrMg1655Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "511145.clusters.info.v11.5.txt",
		        "cluster_tree_path": "511145.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "511145.clusters.proteins.v11.5.txt",
		        "sequence_path": "511145.protein.sequences.v11.5.fa",
		        "enrichment_path": "511145.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511145.protein.info.v11.5.txt",
		        "node_list_path": "511145.cluster.nodes.v11.5.txt",
		        "edge_list_path": "511145.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OttowiaThiooxydansDsm14619(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ottowia thiooxydans DSM 14619 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OttowiaThiooxydansDsm14619", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122623.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122623.protein.info.v11.5.txt",
		        "node_list_path": "1122623.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE2733Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2733 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE2733Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834138.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834138.protein.info.v11.5.txt",
		        "node_list_path": "1834138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium6137faa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 6_1_37FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium6137faa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658656.protein.sequences.v11.5.fa",
		        "enrichment_path": "658656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658656.protein.info.v11.5.txt",
		        "node_list_path": "658656.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalalkalicoccusJeotgaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halalkalicoccus jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalalkalicoccusJeotgaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "795797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "795797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "795797.clusters.proteins.v11.5.txt",
		        "sequence_path": "795797.protein.sequences.v11.5.fa",
		        "enrichment_path": "795797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "795797.protein.info.v11.5.txt",
		        "node_list_path": "795797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "795797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoclavibacterHelvolus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoclavibacter helvolus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoclavibacterHelvolus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "255205.protein.sequences.v11.5.fa",
		        "enrichment_path": "255205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "255205.protein.info.v11.5.txt",
		        "node_list_path": "255205.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobaculumAquaticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobaculum aquaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobaculumAquaticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1312852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1312852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1312852.protein.info.v11.5.txt",
		        "node_list_path": "1312852.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaCatarrhalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella catarrhalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaCatarrhalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "857571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "857571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "857571.clusters.proteins.v11.5.txt",
		        "sequence_path": "857571.protein.sequences.v11.5.fa",
		        "enrichment_path": "857571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857571.protein.info.v11.5.txt",
		        "node_list_path": "857571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "857571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaSpCulex(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Culex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaSpCulex", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "570417.protein.sequences.v11.0.fa",
		        "enrichment_path": "570417.protein.enrichment.terms.v11.0.txt",
		        "info_path": "570417.protein.info.v11.0.txt",
		        "node_list_path": "570417.protein.complete.v11.0.txt"
		    }
		]
    )()

def LegionellaLondiniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella londiniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaLondiniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45068.protein.sequences.v11.5.fa",
		        "enrichment_path": "45068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45068.protein.info.v11.5.txt",
		        "node_list_path": "45068.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgiphilusAromaticivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algiphilus aromaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgiphilusAromaticivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415780.protein.info.v11.5.txt",
		        "node_list_path": "1415780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpJs614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. JS614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpJs614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "196162.clusters.info.v11.5.txt",
		        "cluster_tree_path": "196162.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "196162.clusters.proteins.v11.5.txt",
		        "sequence_path": "196162.protein.sequences.v11.5.fa",
		        "enrichment_path": "196162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "196162.protein.info.v11.5.txt",
		        "node_list_path": "196162.cluster.nodes.v11.5.txt",
		        "edge_list_path": "196162.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalieaRubraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haliea rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalieaRubraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265313.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265313.protein.info.v11.5.txt",
		        "node_list_path": "1265313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusRatti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus ratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusRatti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "699248.protein.sequences.v11.5.fa",
		        "enrichment_path": "699248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "699248.protein.info.v11.5.txt",
		        "node_list_path": "699248.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaSpGwc16184(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema sp. GWC1_61_84 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSpGwc16184", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802380.protein.info.v11.5.txt",
		        "node_list_path": "1802380.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpRcc307Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. RCC307 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpRcc307Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316278.clusters.proteins.v11.5.txt",
		        "sequence_path": "316278.protein.sequences.v11.5.fa",
		        "enrichment_path": "316278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316278.protein.info.v11.5.txt",
		        "node_list_path": "316278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodospirillalesBacterium7018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium 70-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillalesBacterium7018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895826.protein.info.v11.5.txt",
		        "node_list_path": "1895826.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassobiusActivusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassobius activus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobiusActivusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1715691.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1715691.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1715691.clusters.proteins.v11.5.txt",
		        "sequence_path": "1715691.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715691.protein.info.v11.5.txt",
		        "node_list_path": "1715691.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1715691.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaHaemolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaHaemolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "75985.protein.sequences.v11.5.fa",
		        "enrichment_path": "75985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75985.protein.info.v11.5.txt",
		        "node_list_path": "75985.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaPinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga pinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaPinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "485918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "485918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "485918.clusters.proteins.v11.5.txt",
		        "sequence_path": "485918.protein.sequences.v11.5.fa",
		        "enrichment_path": "485918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485918.protein.info.v11.5.txt",
		        "node_list_path": "485918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "485918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusSpOv096(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. OV096 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusSpOv096", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855314.protein.info.v11.5.txt",
		        "node_list_path": "1855314.protein.complete.v11.5.txt"
		    }
		]
    )()

def LabrenziaAlexandriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Labrenzia alexandrii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrenziaAlexandriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "388408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "388408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "388408.clusters.proteins.v11.5.txt",
		        "sequence_path": "388408.protein.sequences.v11.5.fa",
		        "enrichment_path": "388408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388408.protein.info.v11.5.txt",
		        "node_list_path": "388408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "388408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferDonghaiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer donghaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferDonghaiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "494016.protein.sequences.v11.5.fa",
		        "enrichment_path": "494016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "494016.protein.info.v11.5.txt",
		        "node_list_path": "494016.protein.complete.v11.5.txt"
		    }
		]
    )()

def BasidiobolusMeristosporusCbs93173(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Basidiobolus meristosporus CBS 931.73 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BasidiobolusMeristosporusCbs93173", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314790.protein.info.v11.5.txt",
		        "node_list_path": "1314790.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoriobacteriumGlomeransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coriobacterium glomerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacteriumGlomeransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "700015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "700015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "700015.clusters.proteins.v11.5.txt",
		        "sequence_path": "700015.protein.sequences.v11.5.fa",
		        "enrichment_path": "700015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "700015.protein.info.v11.5.txt",
		        "node_list_path": "700015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "700015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls340Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS340 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls340Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463901.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463901.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463901.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463901.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463901.protein.info.v11.5.txt",
		        "node_list_path": "1463901.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463901.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KazachstaniaAfricanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania africana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KazachstaniaAfricanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "432096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "432096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "432096.clusters.proteins.v11.5.txt",
		        "sequence_path": "432096.protein.sequences.v11.5.fa",
		        "enrichment_path": "432096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "432096.protein.info.v11.5.txt",
		        "node_list_path": "432096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "432096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorvusBrachyrhynchosCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corvus brachyrhynchos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorvusBrachyrhynchosCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "85066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "85066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "85066.clusters.proteins.v11.5.txt",
		        "sequence_path": "85066.protein.sequences.v11.5.fa",
		        "enrichment_path": "85066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85066.protein.info.v11.5.txt",
		        "node_list_path": "85066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "85066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophilusSpOh31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. OH31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusSpOh31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1387312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1387312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1387312.clusters.proteins.v11.5.txt",
		        "sequence_path": "1387312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387312.protein.info.v11.5.txt",
		        "node_list_path": "1387312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1387312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumCg23041165(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium CG2_30_41_165 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumCg23041165", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805254.protein.info.v11.5.txt",
		        "node_list_path": "1805254.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaPhagedenis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema phagedenis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPhagedenis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "754027.protein.sequences.v11.5.fa",
		        "enrichment_path": "754027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754027.protein.info.v11.5.txt",
		        "node_list_path": "754027.protein.complete.v11.5.txt"
		    }
		]
    )()

def KytococcusSedentariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kytococcus sedentarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KytococcusSedentariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "478801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "478801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "478801.clusters.proteins.v11.5.txt",
		        "sequence_path": "478801.protein.sequences.v11.5.fa",
		        "enrichment_path": "478801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "478801.protein.info.v11.5.txt",
		        "node_list_path": "478801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "478801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1023915(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_39_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023915", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805304.protein.info.v11.5.txt",
		        "node_list_path": "1805304.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaloranaerobacterSpTr13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caloranaerobacter sp. TR13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloranaerobacterSpTr13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1302151.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1302151.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1302151.clusters.proteins.v11.5.txt",
		        "sequence_path": "1302151.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302151.protein.info.v11.5.txt",
		        "node_list_path": "1302151.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1302151.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MixiaOsmundaeIam14324Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mixia osmundae IAM 14324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MixiaOsmundaeIam14324Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "764103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "764103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "764103.clusters.proteins.v11.5.txt",
		        "sequence_path": "764103.protein.sequences.v11.5.fa",
		        "enrichment_path": "764103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "764103.protein.info.v11.5.txt",
		        "node_list_path": "764103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "764103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaPolysaccharea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaPolysaccharea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546267.protein.sequences.v11.5.fa",
		        "enrichment_path": "546267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546267.protein.info.v11.5.txt",
		        "node_list_path": "546267.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusLaterosporusLmg15441Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus laterosporus LMG15441 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusLaterosporusLmg15441Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1042163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1042163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1042163.clusters.proteins.v11.5.txt",
		        "sequence_path": "1042163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042163.protein.info.v11.5.txt",
		        "node_list_path": "1042163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1042163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerosalibacterSpNd1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerosalibacter sp. ND1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerosalibacterSpNd1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1347392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347392.protein.info.v11.5.txt",
		        "node_list_path": "1347392.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpSa39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. SA39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpSa39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263625.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263625.protein.info.v11.5.txt",
		        "node_list_path": "1263625.protein.complete.v11.5.txt"
		    }
		]
    )()

def MalasseziaGlobosaCbs7966(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Malassezia globosa CBS 7966 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalasseziaGlobosaCbs7966", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "425265.protein.sequences.v11.5.fa",
		        "enrichment_path": "425265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425265.protein.info.v11.5.txt",
		        "node_list_path": "425265.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasSalmonicidaSubspMasoucidaNbrc13784Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. masoucida NBRC 13784 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSalmonicidaSubspMasoucidaNbrc13784Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216980.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216980.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216980.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216980.protein.info.v11.5.txt",
		        "node_list_path": "1216980.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216980.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasAxonopodisCitri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis citri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasAxonopodisCitri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "190486.protein.sequences.v11.5.fa",
		        "enrichment_path": "190486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190486.protein.info.v11.5.txt",
		        "node_list_path": "190486.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaPolysacchareaNs342(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea NS342 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaPolysacchareaNs342", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "933269.protein.sequences.v11.5.fa",
		        "enrichment_path": "933269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933269.protein.info.v11.5.txt",
		        "node_list_path": "933269.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpAt0102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. AT01-02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpAt0102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1571877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1571877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1571877.protein.info.v11.5.txt",
		        "node_list_path": "1571877.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterWuianusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter wuianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterWuianusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1743168.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1743168.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1743168.clusters.proteins.v11.5.txt",
		        "sequence_path": "1743168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743168.protein.info.v11.5.txt",
		        "node_list_path": "1743168.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1743168.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinidiaChinensisVarChinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinidia chinensis var. chinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinidiaChinensisVarChinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1590841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1590841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1590841.clusters.proteins.v11.5.txt",
		        "sequence_path": "1590841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1590841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1590841.protein.info.v11.5.txt",
		        "node_list_path": "1590841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1590841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MacacaNemestrina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Macaca nemestrina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacacaNemestrina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9545.protein.sequences.v11.5.fa",
		        "enrichment_path": "9545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9545.protein.info.v11.5.txt",
		        "node_list_path": "9545.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpCc9311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpCc9311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "64471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "64471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "64471.clusters.proteins.v11.5.txt",
		        "sequence_path": "64471.protein.sequences.v11.5.fa",
		        "enrichment_path": "64471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64471.protein.info.v11.5.txt",
		        "node_list_path": "64471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "64471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentzeaWaywayandensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentzea waywayandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentzeaWaywayandensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84724.protein.sequences.v11.5.fa",
		        "enrichment_path": "84724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84724.protein.info.v11.5.txt",
		        "node_list_path": "84724.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinokineosporaInagensisDsm44258Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora inagensis DSM 44258 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinokineosporaInagensisDsm44258Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120935.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120935.protein.info.v11.5.txt",
		        "node_list_path": "1120935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterGangotriensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter gangotriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterGangotriensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1276920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276920.protein.info.v11.5.txt",
		        "node_list_path": "1276920.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifoxyb1Full3916Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYB1_FULL_39_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyb1Full3916Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801803.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801803.protein.info.v11.5.txt",
		        "node_list_path": "1801803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YoungiibacterFragilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Youngiibacter fragilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YoungiibacterFragilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "994573.clusters.info.v11.5.txt",
		        "cluster_tree_path": "994573.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "994573.clusters.proteins.v11.5.txt",
		        "sequence_path": "994573.protein.sequences.v11.5.fa",
		        "enrichment_path": "994573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "994573.protein.info.v11.5.txt",
		        "node_list_path": "994573.cluster.nodes.v11.5.txt",
		        "edge_list_path": "994573.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiisalibacterPaucivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiisalibacter paucivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiisalibacterPaucivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121289.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121289.protein.info.v11.5.txt",
		        "node_list_path": "1121289.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumXylanophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium xylanophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumXylanophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336241.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336241.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336241.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336241.protein.info.v11.5.txt",
		        "node_list_path": "1336241.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336241.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpRv15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. RV15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpRv15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "909626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "909626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "909626.clusters.proteins.v11.5.txt",
		        "sequence_path": "909626.protein.sequences.v11.5.fa",
		        "enrichment_path": "909626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "909626.protein.info.v11.5.txt",
		        "node_list_path": "909626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "909626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusParviboronicapiensJcm18861Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus parviboronicapiens JCM 18861 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusParviboronicapiensJcm18861Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293591.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293591.protein.info.v11.5.txt",
		        "node_list_path": "1293591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpMcba15008Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpMcba15008Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1898736.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1898736.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1898736.clusters.proteins.v11.5.txt",
		        "sequence_path": "1898736.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898736.protein.info.v11.5.txt",
		        "node_list_path": "1898736.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1898736.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpCf299(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. CF299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpCf299", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500284.protein.info.v11.5.txt",
		        "node_list_path": "1500284.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3616Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_01_FULL_36_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3616Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802200.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802200.protein.info.v11.5.txt",
		        "node_list_path": "1802200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CetobacteriumCetiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cetobacterium ceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CetobacteriumCetiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "180163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "180163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "180163.clusters.proteins.v11.5.txt",
		        "sequence_path": "180163.protein.sequences.v11.5.fa",
		        "enrichment_path": "180163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180163.protein.info.v11.5.txt",
		        "node_list_path": "180163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "180163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquimarinaLongaSw024(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina longa SW024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaLongaSw024", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379258.protein.info.v11.5.txt",
		        "node_list_path": "1379258.protein.complete.v11.5.txt"
		    }
		]
    )()

def PythonBivittatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Python bivittatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PythonBivittatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "176946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "176946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "176946.clusters.proteins.v11.5.txt",
		        "sequence_path": "176946.protein.sequences.v11.5.fa",
		        "enrichment_path": "176946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "176946.protein.info.v11.5.txt",
		        "node_list_path": "176946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "176946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumSpWn1359(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium sp. WN1359 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumSpWn1359", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1266845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266845.protein.info.v11.5.txt",
		        "node_list_path": "1266845.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiothrixDisciformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix disciformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiothrixDisciformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123399.protein.info.v11.5.txt",
		        "node_list_path": "1123399.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaVirilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila virilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaVirilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7244.clusters.proteins.v11.5.txt",
		        "sequence_path": "7244.protein.sequences.v11.5.fa",
		        "enrichment_path": "7244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7244.protein.info.v11.5.txt",
		        "node_list_path": "7244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospirillumFerriphilumMl04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospirillum ferriphilum ML-04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospirillumFerriphilumMl04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1048260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1048260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1048260.clusters.proteins.v11.5.txt",
		        "sequence_path": "1048260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048260.protein.info.v11.5.txt",
		        "node_list_path": "1048260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1048260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichurisMuris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichuris muris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichurisMuris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "70415.protein.sequences.v11.5.fa",
		        "enrichment_path": "70415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "70415.protein.info.v11.5.txt",
		        "node_list_path": "70415.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaFalloniiLlap10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella fallonii LLAP-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaFalloniiLlap10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1212491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1212491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1212491.protein.info.v11.5.txt",
		        "node_list_path": "1212491.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusKaustophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus kaustophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusKaustophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "235909.protein.sequences.v11.5.fa",
		        "enrichment_path": "235909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "235909.protein.info.v11.5.txt",
		        "node_list_path": "235909.protein.complete.v11.5.txt"
		    }
		]
    )()

def EntomoplasmaMelaleucaeAtcc49191Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Entomoplasma melaleucae ATCC 49191 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EntomoplasmaMelaleucaeAtcc49191Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408435.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408435.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408435.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408435.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408435.protein.info.v11.5.txt",
		        "node_list_path": "1408435.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408435.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls87(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls87", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463920.protein.info.v11.5.txt",
		        "node_list_path": "1463920.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizopusAzygosporusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus azygosporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopusAzygosporusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86630.clusters.proteins.v11.5.txt",
		        "sequence_path": "86630.protein.sequences.v11.5.fa",
		        "enrichment_path": "86630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86630.protein.info.v11.5.txt",
		        "node_list_path": "86630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedAcidilobusSpMgCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Acidilobus sp. MG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedAcidilobusSpMgCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410573.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410573.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410573.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410573.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410573.protein.info.v11.5.txt",
		        "node_list_path": "1410573.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410573.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaOdoriferaDsm4582(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia odorifera DSM 4582 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaOdoriferaDsm4582", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "667129.protein.sequences.v11.5.fa",
		        "enrichment_path": "667129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667129.protein.info.v11.5.txt",
		        "node_list_path": "667129.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzospirillumSpCag239Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum sp. CAG:239 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumSpCag239Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262705.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262705.protein.info.v11.5.txt",
		        "node_list_path": "1262705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesMarseilloanorexicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes marseilloanorexicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesMarseilloanorexicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211813.protein.info.v11.5.txt",
		        "node_list_path": "1211813.protein.complete.v11.5.txt"
		    }
		]
    )()

def XylellaFastidiosa9a5cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylella fastidiosa 9a5c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylellaFastidiosa9a5cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "160492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "160492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "160492.clusters.proteins.v11.5.txt",
		        "sequence_path": "160492.protein.sequences.v11.5.fa",
		        "enrichment_path": "160492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "160492.protein.info.v11.5.txt",
		        "node_list_path": "160492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "160492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarispirochaetaAestuariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marispirochaeta aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarispirochaetaAestuariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1963862.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1963862.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1963862.clusters.proteins.v11.5.txt",
		        "sequence_path": "1963862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1963862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1963862.protein.info.v11.5.txt",
		        "node_list_path": "1963862.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1963862.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KosmotogaPacifica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kosmotoga pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KosmotogaPacifica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1330330.protein.sequences.v11.5.fa",
		        "enrichment_path": "1330330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1330330.protein.info.v11.5.txt",
		        "node_list_path": "1330330.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusSwuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus swuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusSwuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1182571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1182571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1182571.clusters.proteins.v11.5.txt",
		        "sequence_path": "1182571.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182571.protein.info.v11.5.txt",
		        "node_list_path": "1182571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1182571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpOv174Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. OV174 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpOv174Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855300.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855300.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855300.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855300.protein.info.v11.5.txt",
		        "node_list_path": "1855300.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855300.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrospiraNitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira nitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrospiraNitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1742973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742973.protein.info.v11.5.txt",
		        "node_list_path": "1742973.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpB05Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. B05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpB05Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945859.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945859.protein.info.v11.5.txt",
		        "node_list_path": "1945859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "176090.protein.sequences.v11.5.fa",
		        "enrichment_path": "176090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "176090.protein.info.v11.5.txt",
		        "node_list_path": "176090.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanomicrobiaArchaeonDtu008Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanomicrobia archaeon DTU008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomicrobiaArchaeonDtu008Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1675034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1675034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1675034.clusters.proteins.v11.5.txt",
		        "sequence_path": "1675034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1675034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1675034.protein.info.v11.5.txt",
		        "node_list_path": "1675034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1675034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpRd272(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Rd 27.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpRd272", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926479.protein.info.v11.5.txt",
		        "node_list_path": "1926479.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpM313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. m313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpM313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "406124.clusters.info.v11.5.txt",
		        "cluster_tree_path": "406124.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "406124.clusters.proteins.v11.5.txt",
		        "sequence_path": "406124.protein.sequences.v11.5.fa",
		        "enrichment_path": "406124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406124.protein.info.v11.5.txt",
		        "node_list_path": "406124.cluster.nodes.v11.5.txt",
		        "edge_list_path": "406124.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaLupiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea lupini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaLupiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1036779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1036779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1036779.clusters.proteins.v11.5.txt",
		        "sequence_path": "1036779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036779.protein.info.v11.5.txt",
		        "node_list_path": "1036779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1036779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaPoulsoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma poulsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaPoulsoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2138.clusters.proteins.v11.5.txt",
		        "sequence_path": "2138.protein.sequences.v11.5.fa",
		        "enrichment_path": "2138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2138.protein.info.v11.5.txt",
		        "node_list_path": "2138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho201Full3615Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_36_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3615Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798586.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798586.protein.info.v11.5.txt",
		        "node_list_path": "1798586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaKunkeliiCr23xCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma kunkelii CR2-3x Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaKunkeliiCr23xCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "273035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "273035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "273035.clusters.proteins.v11.5.txt",
		        "sequence_path": "273035.protein.sequences.v11.5.fa",
		        "enrichment_path": "273035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273035.protein.info.v11.5.txt",
		        "node_list_path": "273035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "273035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg2304411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_44_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805317.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805317.protein.info.v11.5.txt",
		        "node_list_path": "1805317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConiosporiumApollinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coniosporium apollinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConiosporiumApollinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61459.clusters.proteins.v11.5.txt",
		        "sequence_path": "61459.protein.sequences.v11.5.fa",
		        "enrichment_path": "61459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61459.protein.info.v11.5.txt",
		        "node_list_path": "61459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalococcusAgarilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halococcus agarilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusAgarilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232219.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232219.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232219.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232219.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232219.protein.info.v11.5.txt",
		        "node_list_path": "1232219.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232219.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FictibacillusPhosphorivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fictibacillus phosphorivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FictibacillusPhosphorivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1221500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1221500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1221500.clusters.proteins.v11.5.txt",
		        "sequence_path": "1221500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1221500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1221500.protein.info.v11.5.txt",
		        "node_list_path": "1221500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1221500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfTrichogrammaPretiosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Trichogramma pretiosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfTrichogrammaPretiosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "125593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "125593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "125593.clusters.proteins.v11.5.txt",
		        "sequence_path": "125593.protein.sequences.v11.5.fa",
		        "enrichment_path": "125593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "125593.protein.info.v11.5.txt",
		        "node_list_path": "125593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "125593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumAtcc25586(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum ATCC25586 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumAtcc25586", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "190304.protein.sequences.v11.5.fa",
		        "enrichment_path": "190304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190304.protein.info.v11.5.txt",
		        "node_list_path": "190304.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusProteolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus proteolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusProteolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "693977.protein.sequences.v11.5.fa",
		        "enrichment_path": "693977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693977.protein.info.v11.5.txt",
		        "node_list_path": "693977.protein.complete.v11.5.txt"
		    }
		]
    )()

def HirundoRusticaRusticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hirundo rustica rustica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HirundoRusticaRusticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "333673.clusters.info.v11.5.txt",
		        "cluster_tree_path": "333673.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "333673.clusters.proteins.v11.5.txt",
		        "sequence_path": "333673.protein.sequences.v11.5.fa",
		        "enrichment_path": "333673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "333673.protein.info.v11.5.txt",
		        "node_list_path": "333673.cluster.nodes.v11.5.txt",
		        "edge_list_path": "333673.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoriobacteriaceaeBacterium6813(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium 68-1-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacteriaceaeBacterium6813", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1531429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1531429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1531429.protein.info.v11.5.txt",
		        "node_list_path": "1531429.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumScophthalmumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium scophthalmum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumScophthalmumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59733.clusters.proteins.v11.5.txt",
		        "sequence_path": "59733.protein.sequences.v11.5.fa",
		        "enrichment_path": "59733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59733.protein.info.v11.5.txt",
		        "node_list_path": "59733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24610(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_46_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24610", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618835.protein.info.v11.5.txt",
		        "node_list_path": "1618835.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWs6BacteriumOlb20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium OLB20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWs6BacteriumOlb20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617426.protein.info.v11.5.txt",
		        "node_list_path": "1617426.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg166914Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_69_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg166914Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797661.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797661.protein.info.v11.5.txt",
		        "node_list_path": "1797661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSp20bnCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. 20BN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSp20bnCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499686.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499686.protein.info.v11.5.txt",
		        "node_list_path": "1499686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHaemofelis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma haemofelis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHaemofelis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "859194.protein.sequences.v11.5.fa",
		        "enrichment_path": "859194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "859194.protein.info.v11.5.txt",
		        "node_list_path": "859194.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAgalactiae2603vRCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae 2603V/R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAgalactiae2603vRCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "208435.clusters.info.v11.5.txt",
		        "cluster_tree_path": "208435.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "208435.clusters.proteins.v11.5.txt",
		        "sequence_path": "208435.protein.sequences.v11.5.fa",
		        "enrichment_path": "208435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208435.protein.info.v11.5.txt",
		        "node_list_path": "208435.cluster.nodes.v11.5.txt",
		        "edge_list_path": "208435.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1024082Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_40_82 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024082Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805306.protein.info.v11.5.txt",
		        "node_list_path": "1805306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RobiginitaleaMyxolifaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Robiginitalea myxolifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RobiginitaleaMyxolifaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "400055.protein.sequences.v11.5.fa",
		        "enrichment_path": "400055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400055.protein.info.v11.5.txt",
		        "node_list_path": "400055.protein.complete.v11.5.txt"
		    }
		]
    )()

def PapilioXuthus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Papilio xuthus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PapilioXuthus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66420.protein.sequences.v11.5.fa",
		        "enrichment_path": "66420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66420.protein.info.v11.5.txt",
		        "node_list_path": "66420.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSatsumensisDsm16230Jcm12392Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus satsumensis DSM 16230 JCM 12392 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSatsumensisDsm16230Jcm12392Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423801.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423801.protein.info.v11.5.txt",
		        "node_list_path": "1423801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquincolaTertiaricarbonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquincola tertiaricarbonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquincolaTertiaricarbonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391953.protein.sequences.v11.5.fa",
		        "enrichment_path": "391953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391953.protein.info.v11.5.txt",
		        "node_list_path": "391953.protein.complete.v11.5.txt"
		    }
		]
    )()

def MorchellaConicaCcbas932(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Morchella conica CCBAS932 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MorchellaConicaCcbas932", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392247.protein.info.v11.5.txt",
		        "node_list_path": "1392247.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasOryzaePvOryzaeKacc10331(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae pv. oryzae KACC 10331 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasOryzaePvOryzaeKacc10331", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "291331.protein.sequences.v11.5.fa",
		        "enrichment_path": "291331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "291331.protein.info.v11.5.txt",
		        "node_list_path": "291331.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphaeramiaOrbicularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphaeramia orbicularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaeramiaOrbicularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "375764.protein.sequences.v11.5.fa",
		        "enrichment_path": "375764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375764.protein.info.v11.5.txt",
		        "node_list_path": "375764.protein.complete.v11.5.txt"
		    }
		]
    )()

def CalidrisPugnaxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Calidris pugnax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalidrisPugnaxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "198806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "198806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "198806.clusters.proteins.v11.5.txt",
		        "sequence_path": "198806.protein.sequences.v11.5.fa",
		        "enrichment_path": "198806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198806.protein.info.v11.5.txt",
		        "node_list_path": "198806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "198806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKerfeldbacteriaBacteriumRifcsphigho202Full4214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPHIGHO2_02_FULL_42_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsphigho202Full4214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798540.protein.info.v11.5.txt",
		        "node_list_path": "1798540.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetonemaLongum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetonema longum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetonemaLongum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1009370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009370.protein.info.v11.5.txt",
		        "node_list_path": "1009370.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterUlvicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter ulvicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterUlvicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "228959.protein.sequences.v11.5.fa",
		        "enrichment_path": "228959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228959.protein.info.v11.5.txt",
		        "node_list_path": "228959.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrococcalesBacterium72143(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 72-143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcalesBacterium72143", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895790.protein.info.v11.5.txt",
		        "node_list_path": "1895790.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeersiaPerrieri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leersia perrieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeersiaPerrieri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "77586.protein.sequences.v11.5.fa",
		        "enrichment_path": "77586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77586.protein.info.v11.5.txt",
		        "node_list_path": "77586.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSviceusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sviceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSviceusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "463191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "463191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "463191.clusters.proteins.v11.5.txt",
		        "sequence_path": "463191.protein.sequences.v11.5.fa",
		        "enrichment_path": "463191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "463191.protein.info.v11.5.txt",
		        "node_list_path": "463191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "463191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasLipolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas lipolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasLipolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "570156.protein.sequences.v11.5.fa",
		        "enrichment_path": "570156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570156.protein.info.v11.5.txt",
		        "node_list_path": "570156.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTerrybacteriaBacteriumRifcsphigho201Full4817Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPHIGHO2_01_FULL_48_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsphigho201Full4817Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802362.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802362.protein.info.v11.5.txt",
		        "node_list_path": "1802362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAcidophilusNcfmCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus NCFM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAcidophilusNcfmCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272621.clusters.proteins.v11.5.txt",
		        "sequence_path": "272621.protein.sequences.v11.5.fa",
		        "enrichment_path": "272621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272621.protein.info.v11.5.txt",
		        "node_list_path": "272621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumAquaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium aquae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumAquaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1195763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1195763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1195763.clusters.proteins.v11.5.txt",
		        "sequence_path": "1195763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1195763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1195763.protein.info.v11.5.txt",
		        "node_list_path": "1195763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1195763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasMexicana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas mexicana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasMexicana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "128785.protein.sequences.v11.5.fa",
		        "enrichment_path": "128785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "128785.protein.info.v11.5.txt",
		        "node_list_path": "128785.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp11000297Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1100029.7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp11000297Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834067.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834067.protein.info.v11.5.txt",
		        "node_list_path": "1834067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpJgi0001016M12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. JGI 0001016-M12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpJgi0001016M12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1286832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286832.protein.info.v11.5.txt",
		        "node_list_path": "1286832.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisRemaneiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis remanei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisRemaneiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "31234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "31234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "31234.clusters.proteins.v11.5.txt",
		        "sequence_path": "31234.protein.sequences.v11.5.fa",
		        "enrichment_path": "31234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31234.protein.info.v11.5.txt",
		        "node_list_path": "31234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "31234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoactinomycesSpDsm45891Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. DSM 45891 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoactinomycesSpDsm45891Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761907.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761907.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761907.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761907.protein.info.v11.5.txt",
		        "node_list_path": "1761907.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761907.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf236131Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_36_131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf236131Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619081.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619081.protein.info.v11.5.txt",
		        "node_list_path": "1619081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaNorimbergensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea norimbergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaNorimbergensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93219.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93219.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93219.clusters.proteins.v11.5.txt",
		        "sequence_path": "93219.protein.sequences.v11.5.fa",
		        "enrichment_path": "93219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93219.protein.info.v11.5.txt",
		        "node_list_path": "93219.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93219.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynergistalesBacterium5424(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synergistales bacterium 54_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynergistalesBacterium5424", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635272.protein.info.v11.5.txt",
		        "node_list_path": "1635272.protein.complete.v11.5.txt"
		    }
		]
    )()

def SeriolaLalandiDorsalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Seriola lalandi dorsalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SeriolaLalandiDorsalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841481.protein.info.v11.5.txt",
		        "node_list_path": "1841481.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChaetomiumThermophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChaetomiumThermophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "209285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "209285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "209285.clusters.proteins.v11.5.txt",
		        "sequence_path": "209285.protein.sequences.v11.5.fa",
		        "enrichment_path": "209285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "209285.protein.info.v11.5.txt",
		        "node_list_path": "209285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "209285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSoliNbrc106424Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax soli NBRC 106424 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSoliNbrc106424Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321611.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321611.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321611.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321611.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321611.protein.info.v11.5.txt",
		        "node_list_path": "1321611.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321611.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalanaerobiumSalsuginisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halanaerobium salsuginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaerobiumSalsuginisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29563.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29563.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29563.clusters.proteins.v11.5.txt",
		        "sequence_path": "29563.protein.sequences.v11.5.fa",
		        "enrichment_path": "29563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29563.protein.info.v11.5.txt",
		        "node_list_path": "29563.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29563.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenimonasOryziterraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas oryziterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenimonasOryziterraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121015.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121015.protein.info.v11.5.txt",
		        "node_list_path": "1121015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumU91iCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium U9-1i Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumU91iCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1605283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1605283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1605283.clusters.proteins.v11.5.txt",
		        "sequence_path": "1605283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1605283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1605283.protein.info.v11.5.txt",
		        "node_list_path": "1605283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1605283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasIssachenkonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas issachenkonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasIssachenkonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "152297.protein.sequences.v11.5.fa",
		        "enrichment_path": "152297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "152297.protein.info.v11.5.txt",
		        "node_list_path": "152297.protein.complete.v11.5.txt"
		    }
		]
    )()

def PerlucidibacaAquaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Perlucidibaca aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PerlucidibacaAquaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852776.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852776.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852776.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852776.protein.info.v11.5.txt",
		        "node_list_path": "1852776.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852776.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumDiernhoferiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium diernhoferi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumDiernhoferiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801.protein.info.v11.5.txt",
		        "node_list_path": "1801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpLappah108Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. LaPpAH108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpLappah108Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1155714.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1155714.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1155714.clusters.proteins.v11.5.txt",
		        "sequence_path": "1155714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1155714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1155714.protein.info.v11.5.txt",
		        "node_list_path": "1155714.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1155714.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicoccusHaloduransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus halodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusHaloduransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "407035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "407035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "407035.clusters.proteins.v11.5.txt",
		        "sequence_path": "407035.protein.sequences.v11.5.fa",
		        "enrichment_path": "407035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "407035.protein.info.v11.5.txt",
		        "node_list_path": "407035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "407035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSenegalense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium senegalense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSenegalense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033737.protein.info.v11.5.txt",
		        "node_list_path": "1033737.protein.complete.v11.5.txt"
		    }
		]
    )()

def VirgibacillusSpVm5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus sp. Vm5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusSpVm5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1462526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1462526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1462526.clusters.proteins.v11.5.txt",
		        "sequence_path": "1462526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462526.protein.info.v11.5.txt",
		        "node_list_path": "1462526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1462526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphimedonQueenslandica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amphimedon queenslandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphimedonQueenslandica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "400682.protein.sequences.v11.5.fa",
		        "enrichment_path": "400682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400682.protein.info.v11.5.txt",
		        "node_list_path": "400682.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpAa4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. AA4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpAa4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "591158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "591158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "591158.clusters.proteins.v11.5.txt",
		        "sequence_path": "591158.protein.sequences.v11.5.fa",
		        "enrichment_path": "591158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591158.protein.info.v11.5.txt",
		        "node_list_path": "591158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "591158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusHominisSk119Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus hominis SK119 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusHominisSk119Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "629742.clusters.info.v11.5.txt",
		        "cluster_tree_path": "629742.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "629742.clusters.proteins.v11.5.txt",
		        "sequence_path": "629742.protein.sequences.v11.5.fa",
		        "enrichment_path": "629742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "629742.protein.info.v11.5.txt",
		        "node_list_path": "629742.cluster.nodes.v11.5.txt",
		        "edge_list_path": "629742.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumAurum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium aurum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumAurum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1791.protein.info.v11.5.txt",
		        "node_list_path": "1791.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag474Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:474 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag474Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262926.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262926.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262926.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262926.protein.info.v11.5.txt",
		        "node_list_path": "1262926.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262926.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumInterjectumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium interjectum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumInterjectumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33895.clusters.proteins.v11.5.txt",
		        "sequence_path": "33895.protein.sequences.v11.5.fa",
		        "enrichment_path": "33895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33895.protein.info.v11.5.txt",
		        "node_list_path": "33895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCoahuilensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coahuilensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCoahuilensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "441769.clusters.info.v11.5.txt",
		        "cluster_tree_path": "441769.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "441769.clusters.proteins.v11.5.txt",
		        "sequence_path": "441769.protein.sequences.v11.5.fa",
		        "enrichment_path": "441769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441769.protein.info.v11.5.txt",
		        "node_list_path": "441769.cluster.nodes.v11.5.txt",
		        "edge_list_path": "441769.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsphigho202Full4811(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPHIGHO2_02_FULL_48_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202Full4811", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801856.protein.info.v11.5.txt",
		        "node_list_path": "1801856.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAvium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium avium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAvium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44454.protein.sequences.v11.5.fa",
		        "enrichment_path": "44454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44454.protein.info.v11.5.txt",
		        "node_list_path": "44454.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusPomorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus pomorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusPomorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111479.protein.info.v11.5.txt",
		        "node_list_path": "1111479.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusCandidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus candidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusCandidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "41067.protein.sequences.v11.5.fa",
		        "enrichment_path": "41067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41067.protein.info.v11.5.txt",
		        "node_list_path": "41067.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraAlexanderiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira alexanderi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraAlexanderiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "100053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "100053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "100053.clusters.proteins.v11.5.txt",
		        "sequence_path": "100053.protein.sequences.v11.5.fa",
		        "enrichment_path": "100053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "100053.protein.info.v11.5.txt",
		        "node_list_path": "100053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "100053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GelidibacterMesophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gelidibacter mesophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GelidibacterMesophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121912.protein.info.v11.5.txt",
		        "node_list_path": "1121912.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumRectaleAtcc33656Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Eubacterium] rectale ATCC 33656 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumRectaleAtcc33656Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "515619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "515619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "515619.clusters.proteins.v11.5.txt",
		        "sequence_path": "515619.protein.sequences.v11.5.fa",
		        "enrichment_path": "515619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515619.protein.info.v11.5.txt",
		        "node_list_path": "515619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "515619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesMassiliensisDnlkv3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis dnLKV3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesMassiliensisDnlkv3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235788.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235788.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235788.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235788.protein.info.v11.5.txt",
		        "node_list_path": "1235788.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235788.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WallemiaIchthyophagaExf994Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wallemia ichthyophaga EXF-994 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WallemiaIchthyophagaExf994Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1299270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1299270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1299270.clusters.proteins.v11.5.txt",
		        "sequence_path": "1299270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1299270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1299270.protein.info.v11.5.txt",
		        "node_list_path": "1299270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1299270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesPyogenesDsm20611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides pyogenes DSM20611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesPyogenesDsm20611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121100.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121100.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121100.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121100.protein.info.v11.5.txt",
		        "node_list_path": "1121100.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121100.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastomonasSpAap53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastomonas sp. AAP53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomonasSpAap53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1248760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1248760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1248760.protein.info.v11.5.txt",
		        "node_list_path": "1248760.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesSp627Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. 627 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSp627Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1501391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1501391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1501391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1501391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1501391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1501391.protein.info.v11.5.txt",
		        "node_list_path": "1501391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1501391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpY57Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Y57 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpY57Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "334801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "334801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "334801.clusters.proteins.v11.5.txt",
		        "sequence_path": "334801.protein.sequences.v11.5.fa",
		        "enrichment_path": "334801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334801.protein.info.v11.5.txt",
		        "node_list_path": "334801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "334801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiorhodococcusSpAk35Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiorhodococcus sp. AK35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiorhodococcusSpAk35Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1249627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1249627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1249627.clusters.proteins.v11.5.txt",
		        "sequence_path": "1249627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249627.protein.info.v11.5.txt",
		        "node_list_path": "1249627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1249627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoccomyxaSubellipsoideaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coccomyxa subellipsoidea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccomyxaSubellipsoideaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "248742.clusters.info.v11.5.txt",
		        "cluster_tree_path": "248742.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "248742.clusters.proteins.v11.5.txt",
		        "sequence_path": "248742.protein.sequences.v11.5.fa",
		        "enrichment_path": "248742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "248742.protein.info.v11.5.txt",
		        "node_list_path": "248742.cluster.nodes.v11.5.txt",
		        "edge_list_path": "248742.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrinickiaSymbiotica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trinickia symbiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrinickiaSymbiotica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "863227.protein.sequences.v11.5.fa",
		        "enrichment_path": "863227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "863227.protein.info.v11.5.txt",
		        "node_list_path": "863227.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriovoraxSpSeq25v(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. Seq25V graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriovoraxSpSeq25v", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1201288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1201288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1201288.protein.info.v11.5.txt",
		        "node_list_path": "1201288.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwa14423(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_44_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa14423", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618558.protein.info.v11.5.txt",
		        "node_list_path": "1618558.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachionusPlicatilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachionus plicatilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachionusPlicatilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10195.clusters.proteins.v11.5.txt",
		        "sequence_path": "10195.protein.sequences.v11.5.fa",
		        "enrichment_path": "10195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10195.protein.info.v11.5.txt",
		        "node_list_path": "10195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpKiost1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. KIOST1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpKiost1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229172.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229172.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229172.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229172.protein.info.v11.5.txt",
		        "node_list_path": "1229172.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229172.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BaumanniaCicadellinicolaStrHcHomalodiscaCoagulata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Baumannia cicadellinicola str. Hc (Homalodisca coagulata) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BaumanniaCicadellinicolaStrHcHomalodiscaCoagulata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "374463.protein.sequences.v11.5.fa",
		        "enrichment_path": "374463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "374463.protein.info.v11.5.txt",
		        "node_list_path": "374463.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusChitonophagusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus chitonophagus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusChitonophagusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "54262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "54262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "54262.clusters.proteins.v11.5.txt",
		        "sequence_path": "54262.protein.sequences.v11.5.fa",
		        "enrichment_path": "54262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54262.protein.info.v11.5.txt",
		        "node_list_path": "54262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "54262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HoefleaPhototrophica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hoeflea phototrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoefleaPhototrophica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411684.protein.sequences.v11.5.fa",
		        "enrichment_path": "411684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411684.protein.info.v11.5.txt",
		        "node_list_path": "411684.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterFiliformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter filiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterFiliformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "55758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "55758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "55758.clusters.proteins.v11.5.txt",
		        "sequence_path": "55758.protein.sequences.v11.5.fa",
		        "enrichment_path": "55758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55758.protein.info.v11.5.txt",
		        "node_list_path": "55758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "55758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSordelliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sordellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSordelliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1292035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1292035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1292035.clusters.proteins.v11.5.txt",
		        "sequence_path": "1292035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292035.protein.info.v11.5.txt",
		        "node_list_path": "1292035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1292035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolyporusBrumalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polyporus brumalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolyporusBrumalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "139420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "139420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "139420.clusters.proteins.v11.5.txt",
		        "sequence_path": "139420.protein.sequences.v11.5.fa",
		        "enrichment_path": "139420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "139420.protein.info.v11.5.txt",
		        "node_list_path": "139420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "139420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho201Full4623(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_01_FULL_46_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho201Full4623", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802382.protein.info.v11.5.txt",
		        "node_list_path": "1802382.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusLutimarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius lutimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusLutimarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005928.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005928.protein.info.v11.5.txt",
		        "node_list_path": "1005928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrunusPersicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prunus persica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrunusPersicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3760.clusters.proteins.v11.5.txt",
		        "sequence_path": "3760.protein.sequences.v11.5.fa",
		        "enrichment_path": "3760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3760.protein.info.v11.5.txt",
		        "node_list_path": "3760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulochytriumProtostelioidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulochytrium protostelioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulochytriumProtostelioidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1555241.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1555241.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1555241.clusters.proteins.v11.5.txt",
		        "sequence_path": "1555241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1555241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1555241.protein.info.v11.5.txt",
		        "node_list_path": "1555241.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1555241.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSp3910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 39-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSp3910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895745.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895745.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895745.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895745.protein.info.v11.5.txt",
		        "node_list_path": "1895745.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895745.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3914(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3914", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798383.protein.info.v11.5.txt",
		        "node_list_path": "1798383.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDelongbacteriaBacteriumGwf24014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Delongbacteria bacterium GWF2_40_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDelongbacteriaBacteriumGwf24014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817817.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817817.protein.info.v11.5.txt",
		        "node_list_path": "1817817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UlvibacterLitoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ulvibacter litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UlvibacterLitoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "227084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "227084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "227084.clusters.proteins.v11.5.txt",
		        "sequence_path": "227084.protein.sequences.v11.5.fa",
		        "enrichment_path": "227084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227084.protein.info.v11.5.txt",
		        "node_list_path": "227084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "227084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanibacterTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janibacter terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "103817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "103817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "103817.clusters.proteins.v11.5.txt",
		        "sequence_path": "103817.protein.sequences.v11.5.fa",
		        "enrichment_path": "103817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103817.protein.info.v11.5.txt",
		        "node_list_path": "103817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "103817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomonasSpLw13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas sp. LW13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasSpLw13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "107637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "107637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "107637.clusters.proteins.v11.5.txt",
		        "sequence_path": "107637.protein.sequences.v11.5.fa",
		        "enrichment_path": "107637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "107637.protein.info.v11.5.txt",
		        "node_list_path": "107637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "107637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNk4a144(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A144 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNk4a144", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "877421.protein.sequences.v11.5.fa",
		        "enrichment_path": "877421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877421.protein.info.v11.5.txt",
		        "node_list_path": "877421.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalolactibacillusMiurensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halolactibacillus miurensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolactibacillusMiurensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "306541.protein.sequences.v11.5.fa",
		        "enrichment_path": "306541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306541.protein.info.v11.5.txt",
		        "node_list_path": "306541.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterPeloridisLmg23910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter peloridis LMG 23910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterPeloridisLmg23910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1388753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1388753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1388753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1388753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1388753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1388753.protein.info.v11.5.txt",
		        "node_list_path": "1388753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1388753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TepidimonasFonticaldiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tepidimonas fonticaldi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidimonasFonticaldiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1101373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1101373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1101373.clusters.proteins.v11.5.txt",
		        "sequence_path": "1101373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101373.protein.info.v11.5.txt",
		        "node_list_path": "1101373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1101373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumAquae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium aquae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumAquae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1195763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1195763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1195763.protein.info.v11.5.txt",
		        "node_list_path": "1195763.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastococcusSpDsm46786(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 46786 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusSpDsm46786", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798227.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798227.protein.info.v11.5.txt",
		        "node_list_path": "1798227.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpWmma185(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. WMMA185 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpWmma185", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679318.protein.sequences.v11.5.fa",
		        "enrichment_path": "679318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679318.protein.info.v11.5.txt",
		        "node_list_path": "679318.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaAvicenniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora avicenniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaAvicenniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1198245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1198245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1198245.clusters.proteins.v11.5.txt",
		        "sequence_path": "1198245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198245.protein.info.v11.5.txt",
		        "node_list_path": "1198245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1198245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FructobacillusFructosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fructobacillus fructosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FructobacillusFructosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930946.clusters.proteins.v11.5.txt",
		        "sequence_path": "930946.protein.sequences.v11.5.fa",
		        "enrichment_path": "930946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930946.protein.info.v11.5.txt",
		        "node_list_path": "930946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpEs1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. ES1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpEs1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1396858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1396858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1396858.protein.info.v11.5.txt",
		        "node_list_path": "1396858.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlycineMaxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glycine max Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlycineMaxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3847.clusters.proteins.v11.5.txt",
		        "sequence_path": "3847.protein.sequences.v11.5.fa",
		        "enrichment_path": "3847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3847.protein.info.v11.5.txt",
		        "node_list_path": "3847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaTularensisNovicida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella tularensis novicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaTularensisNovicida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "676032.protein.sequences.v11.5.fa",
		        "enrichment_path": "676032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "676032.protein.info.v11.5.txt",
		        "node_list_path": "676032.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesocricetusAuratusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesocricetus auratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesocricetusAuratusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10036.clusters.proteins.v11.5.txt",
		        "sequence_path": "10036.protein.sequences.v11.5.fa",
		        "enrichment_path": "10036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10036.protein.info.v11.5.txt",
		        "node_list_path": "10036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumSgBin9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SG_bin9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumSgBin9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1827385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827385.protein.info.v11.5.txt",
		        "node_list_path": "1827385.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKapabacteriaThiocyanatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kapabacteria thiocyanatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKapabacteriaThiocyanatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895771.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895771.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895771.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895771.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895771.protein.info.v11.5.txt",
		        "node_list_path": "1895771.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895771.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifcsphigho202Full5326Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFCSPHIGHO2_02_FULL_53_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifcsphigho202Full5326Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802566.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802566.protein.info.v11.5.txt",
		        "node_list_path": "1802566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaMaculosaOt289(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella maculosa OT 289 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMaculosaOt289", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999422.protein.sequences.v11.5.fa",
		        "enrichment_path": "999422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999422.protein.info.v11.5.txt",
		        "node_list_path": "999422.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumJoshi001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium JOSHI001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumJoshi001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "864051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "864051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "864051.clusters.proteins.v11.5.txt",
		        "sequence_path": "864051.protein.sequences.v11.5.fa",
		        "enrichment_path": "864051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864051.protein.info.v11.5.txt",
		        "node_list_path": "864051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "864051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSpV48(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. V48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpV48", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "509635.protein.sequences.v11.5.fa",
		        "enrichment_path": "509635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "509635.protein.info.v11.5.txt",
		        "node_list_path": "509635.protein.complete.v11.5.txt"
		    }
		]
    )()

def MinicystisRosea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Minicystis rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MinicystisRosea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888845.protein.sequences.v11.5.fa",
		        "enrichment_path": "888845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888845.protein.info.v11.5.txt",
		        "node_list_path": "888845.protein.complete.v11.5.txt"
		    }
		]
    )()

def IntrasporangiaceaeBacteriumUrhb0013(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Intrasporangiaceae bacterium URHB0013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntrasporangiaceaeBacteriumUrhb0013", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380370.protein.info.v11.5.txt",
		        "node_list_path": "1380370.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusGhanensisDsm18630(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ghanensis DSM 18630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGhanensisDsm18630", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423750.protein.info.v11.5.txt",
		        "node_list_path": "1423750.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnabaenaSpCaAtcc33047(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anabaena sp. CA ATCC 33047 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabaenaSpCaAtcc33047", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52271.protein.sequences.v11.5.fa",
		        "enrichment_path": "52271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52271.protein.info.v11.5.txt",
		        "node_list_path": "52271.protein.complete.v11.5.txt"
		    }
		]
    )()

def TremellaMesentericaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tremella mesenterica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TremellaMesentericaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5217.clusters.proteins.v11.5.txt",
		        "sequence_path": "5217.protein.sequences.v11.5.fa",
		        "enrichment_path": "5217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5217.protein.info.v11.5.txt",
		        "node_list_path": "5217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaOtitidiscaviarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia otitidiscaviarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaOtitidiscaviarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206732.protein.info.v11.5.txt",
		        "node_list_path": "1206732.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumParaseoulense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium paraseoulense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumParaseoulense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "590652.protein.sequences.v11.5.fa",
		        "enrichment_path": "590652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "590652.protein.info.v11.5.txt",
		        "node_list_path": "590652.protein.complete.v11.5.txt"
		    }
		]
    )()

def MangrovimonasSpSt2l12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. ST2L12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MangrovimonasSpSt2l12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1645915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1645915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1645915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1645915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1645915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1645915.protein.info.v11.5.txt",
		        "node_list_path": "1645915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1645915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GuillardiaTheta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Guillardia theta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GuillardiaTheta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "55529.protein.sequences.v11.5.fa",
		        "enrichment_path": "55529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55529.protein.info.v11.5.txt",
		        "node_list_path": "55529.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloversatilisSpRac08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloversatilis sp. RAC08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloversatilisSpRac08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1842540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1842540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1842540.clusters.proteins.v11.5.txt",
		        "sequence_path": "1842540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842540.protein.info.v11.5.txt",
		        "node_list_path": "1842540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1842540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusGinsengihumi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ginsengihumi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusGinsengihumi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122919.protein.info.v11.5.txt",
		        "node_list_path": "1122919.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChelonobacterOrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chelonobacter oris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelonobacterOrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "505317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "505317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "505317.clusters.proteins.v11.5.txt",
		        "sequence_path": "505317.protein.sequences.v11.5.fa",
		        "enrichment_path": "505317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "505317.protein.info.v11.5.txt",
		        "node_list_path": "505317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "505317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OchrobactrumIntermedium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum intermedium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OchrobactrumIntermedium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "94625.protein.sequences.v11.5.fa",
		        "enrichment_path": "94625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94625.protein.info.v11.5.txt",
		        "node_list_path": "94625.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuthiaMagnifica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruthia magnifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuthiaMagnifica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "413404.protein.sequences.v11.5.fa",
		        "enrichment_path": "413404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "413404.protein.info.v11.5.txt",
		        "node_list_path": "413404.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo212Full4526(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_12_FULL_45_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo212Full4526", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798525.protein.info.v11.5.txt",
		        "node_list_path": "1798525.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichococcusCollinsii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichococcus collinsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichococcusCollinsii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "157076.protein.sequences.v11.5.fa",
		        "enrichment_path": "157076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157076.protein.info.v11.5.txt",
		        "node_list_path": "157076.protein.complete.v11.5.txt"
		    }
		]
    )()

def DickeyaDadantiiEch703(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii Ech703 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaDadantiiEch703", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "579405.protein.sequences.v11.5.fa",
		        "enrichment_path": "579405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579405.protein.info.v11.5.txt",
		        "node_list_path": "579405.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumAcetireducensDsm10703(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acetireducens DSM 10703 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAcetireducensDsm10703", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121290.protein.info.v11.5.txt",
		        "node_list_path": "1121290.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpWsm3224Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. WSM3224 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpWsm3224Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1040986.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1040986.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1040986.clusters.proteins.v11.5.txt",
		        "sequence_path": "1040986.protein.sequences.v11.5.fa",
		        "enrichment_path": "1040986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1040986.protein.info.v11.5.txt",
		        "node_list_path": "1040986.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1040986.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BotrytisCinereaBcdw1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Botrytis cinerea BcDW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotrytisCinereaBcdw1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1290391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1290391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1290391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1290391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1290391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1290391.protein.info.v11.5.txt",
		        "node_list_path": "1290391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1290391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaFermentansM64(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma fermentans M64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaFermentansM64", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "943945.protein.sequences.v11.5.fa",
		        "enrichment_path": "943945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "943945.protein.info.v11.5.txt",
		        "node_list_path": "943945.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaValaisianaVs116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia valaisiana VS116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaValaisianaVs116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445987.protein.sequences.v11.5.fa",
		        "enrichment_path": "445987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445987.protein.info.v11.5.txt",
		        "node_list_path": "445987.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpPbcCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. PBC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpPbcCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "795665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "795665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "795665.clusters.proteins.v11.5.txt",
		        "sequence_path": "795665.protein.sequences.v11.5.fa",
		        "enrichment_path": "795665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "795665.protein.info.v11.5.txt",
		        "node_list_path": "795665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "795665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylocystisBryophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylocystis bryophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocystisBryophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655015.clusters.proteins.v11.5.txt",
		        "sequence_path": "655015.protein.sequences.v11.5.fa",
		        "enrichment_path": "655015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655015.protein.info.v11.5.txt",
		        "node_list_path": "655015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ScardoviaWiggsiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scardovia wiggsiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScardoviaWiggsiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "857290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "857290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "857290.clusters.proteins.v11.5.txt",
		        "sequence_path": "857290.protein.sequences.v11.5.fa",
		        "enrichment_path": "857290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857290.protein.info.v11.5.txt",
		        "node_list_path": "857290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "857290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpMum116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MUM 116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpMum116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1678002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678002.protein.info.v11.5.txt",
		        "node_list_path": "1678002.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriA1501Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri A1501 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriA1501Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "379731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "379731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "379731.clusters.proteins.v11.5.txt",
		        "sequence_path": "379731.protein.sequences.v11.5.fa",
		        "enrichment_path": "379731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "379731.protein.info.v11.5.txt",
		        "node_list_path": "379731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "379731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSalina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas salina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSalina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42565.protein.sequences.v11.5.fa",
		        "enrichment_path": "42565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42565.protein.info.v11.5.txt",
		        "node_list_path": "42565.protein.complete.v11.5.txt"
		    }
		]
    )()

def TamlanaNanhaiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tamlana nanhaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TamlanaNanhaiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1382798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382798.protein.info.v11.5.txt",
		        "node_list_path": "1382798.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusBuchneriAtcc11577(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri ATCC11577 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBuchneriAtcc11577", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525318.protein.sequences.v11.5.fa",
		        "enrichment_path": "525318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525318.protein.info.v11.5.txt",
		        "node_list_path": "525318.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquisalimonasAsiaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquisalimonas asiatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquisalimonasAsiaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "406100.clusters.info.v11.5.txt",
		        "cluster_tree_path": "406100.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "406100.clusters.proteins.v11.5.txt",
		        "sequence_path": "406100.protein.sequences.v11.5.fa",
		        "enrichment_path": "406100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406100.protein.info.v11.5.txt",
		        "node_list_path": "406100.cluster.nodes.v11.5.txt",
		        "edge_list_path": "406100.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AplysiaCalifornica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aplysia californica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AplysiaCalifornica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6500.protein.sequences.v11.5.fa",
		        "enrichment_path": "6500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6500.protein.info.v11.5.txt",
		        "node_list_path": "6500.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriSdmlac(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri SDMLAC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriSdmlac", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1109445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1109445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1109445.protein.info.v11.5.txt",
		        "node_list_path": "1109445.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgromycesSpLeaf222(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agromyces sp. Leaf222 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesSpLeaf222", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735688.protein.info.v11.5.txt",
		        "node_list_path": "1735688.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumSpAf4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumSpAf4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1325735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1325735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1325735.clusters.proteins.v11.5.txt",
		        "sequence_path": "1325735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325735.protein.info.v11.5.txt",
		        "node_list_path": "1325735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1325735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrauserellaRugosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prauserella rugosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrauserellaRugosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43354.protein.sequences.v11.5.fa",
		        "enrichment_path": "43354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43354.protein.info.v11.5.txt",
		        "node_list_path": "43354.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpYr459(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR459 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpYr459", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500292.protein.info.v11.5.txt",
		        "node_list_path": "1500292.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumUc511d10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-1D10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumUc511d10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1697787.protein.sequences.v11.5.fa",
		        "enrichment_path": "1697787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1697787.protein.info.v11.5.txt",
		        "node_list_path": "1697787.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloferacalesArchaeonDl31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Haloferacales archaeon DL31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "HaloferacalesArchaeonDl31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "756883.protein.sequences.v11.0.fa",
		        "enrichment_path": "756883.protein.enrichment.terms.v11.0.txt",
		        "info_path": "756883.protein.info.v11.0.txt",
		        "node_list_path": "756883.protein.complete.v11.0.txt"
		    }
		]
    )()

def PolynucleobacterSpQlwP1data2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. QLW-P1DATA-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterSpQlwP1data2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1743167.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743167.protein.info.v11.5.txt",
		        "node_list_path": "1743167.protein.complete.v11.5.txt"
		    }
		]
    )()

def GalbibacterMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Galbibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GalbibacterMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "555500.protein.sequences.v11.5.fa",
		        "enrichment_path": "555500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555500.protein.info.v11.5.txt",
		        "node_list_path": "555500.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusParasanguinisAtcc903(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis ATCC903 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusParasanguinisAtcc903", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888048.protein.sequences.v11.5.fa",
		        "enrichment_path": "888048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888048.protein.info.v11.5.txt",
		        "node_list_path": "888048.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitromicrobiumBathyomarinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citromicrobium bathyomarinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitromicrobiumBathyomarinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "685035.protein.sequences.v11.5.fa",
		        "enrichment_path": "685035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "685035.protein.info.v11.5.txt",
		        "node_list_path": "685035.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaIhumiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella ihumii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaIhumiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1917878.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1917878.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1917878.clusters.proteins.v11.5.txt",
		        "sequence_path": "1917878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917878.protein.info.v11.5.txt",
		        "node_list_path": "1917878.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1917878.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SkermanellaAerolataKacc11604Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Skermanella aerolata KACC 11604 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SkermanellaAerolataKacc11604Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385368.protein.info.v11.5.txt",
		        "node_list_path": "1385368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlaciecolaNitratireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaNitratireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1085623.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1085623.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1085623.clusters.proteins.v11.5.txt",
		        "sequence_path": "1085623.protein.sequences.v11.5.fa",
		        "enrichment_path": "1085623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1085623.protein.info.v11.5.txt",
		        "node_list_path": "1085623.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1085623.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioSpOr37(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. OR37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioSpOr37", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798186.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798186.protein.info.v11.5.txt",
		        "node_list_path": "1798186.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumHwasookiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium hwasookii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumHwasookiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216362.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216362.protein.info.v11.5.txt",
		        "node_list_path": "1216362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FervidobacteriumIslandicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium islandicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidobacteriumIslandicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2423.protein.sequences.v11.5.fa",
		        "enrichment_path": "2423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2423.protein.info.v11.5.txt",
		        "node_list_path": "2423.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumCulicisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium culicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumCulicisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "680127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "680127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "680127.clusters.proteins.v11.5.txt",
		        "sequence_path": "680127.protein.sequences.v11.5.fa",
		        "enrichment_path": "680127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "680127.protein.info.v11.5.txt",
		        "node_list_path": "680127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "680127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZetaproteobacteriaBacteriumTag1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium TAG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaproteobacteriaBacteriumTag1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1485545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1485545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1485545.clusters.proteins.v11.5.txt",
		        "sequence_path": "1485545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1485545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1485545.protein.info.v11.5.txt",
		        "node_list_path": "1485545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1485545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcyrthosiphonPisum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acyrthosiphon pisum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcyrthosiphonPisum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7029.protein.sequences.v11.5.fa",
		        "enrichment_path": "7029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7029.protein.info.v11.5.txt",
		        "node_list_path": "7029.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusGilvus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus gilvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusGilvus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158614.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158614.protein.info.v11.5.txt",
		        "node_list_path": "1158614.protein.complete.v11.5.txt"
		    }
		]
    )()

def AequorivitaSoesokkakensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aequorivita soesokkakensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AequorivitaSoesokkakensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385699.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385699.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385699.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385699.protein.info.v11.5.txt",
		        "node_list_path": "1385699.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385699.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacillusStearothermophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus stearothermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusStearothermophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1295642.protein.sequences.v11.5.fa",
		        "enrichment_path": "1295642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1295642.protein.info.v11.5.txt",
		        "node_list_path": "1295642.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf89(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf89 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf89", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736245.protein.info.v11.5.txt",
		        "node_list_path": "1736245.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterNosocomialis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter nosocomialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterNosocomialis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "106654.protein.sequences.v11.5.fa",
		        "enrichment_path": "106654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106654.protein.info.v11.5.txt",
		        "node_list_path": "106654.protein.complete.v11.5.txt"
		    }
		]
    )()

def TinamusGuttatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tinamus guttatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TinamusGuttatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "94827.protein.sequences.v11.5.fa",
		        "enrichment_path": "94827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94827.protein.info.v11.5.txt",
		        "node_list_path": "94827.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalimicrobiumHalophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salimicrobium halophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalimicrobiumHalophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86666.protein.sequences.v11.5.fa",
		        "enrichment_path": "86666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86666.protein.info.v11.5.txt",
		        "node_list_path": "86666.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaShandongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia shandongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaShandongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121928.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121928.protein.info.v11.5.txt",
		        "node_list_path": "1121928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaladaptatusSpR4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haladaptatus sp. R4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaladaptatusSpR4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1679489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679489.protein.info.v11.5.txt",
		        "node_list_path": "1679489.protein.complete.v11.5.txt"
		    }
		]
    )()

def RisungbinellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Risungbinella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RisungbinellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1329796.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1329796.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1329796.clusters.proteins.v11.5.txt",
		        "sequence_path": "1329796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1329796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1329796.protein.info.v11.5.txt",
		        "node_list_path": "1329796.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1329796.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFischerbacteriaBacteriumRbg13378(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fischerbacteria bacterium RBG_13_37_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFischerbacteriaBacteriumRbg13378", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817863.protein.info.v11.5.txt",
		        "node_list_path": "1817863.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCatenulae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces catenulae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCatenulae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66875.protein.sequences.v11.5.fa",
		        "enrichment_path": "66875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66875.protein.info.v11.5.txt",
		        "node_list_path": "66875.protein.complete.v11.5.txt"
		    }
		]
    )()

def SuccinimonasAmylolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Succinimonas amylolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuccinimonasAmylolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265507.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265507.protein.info.v11.5.txt",
		        "node_list_path": "1265507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaAsaccharolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia asaccharolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaAsaccharolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123024.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123024.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123024.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123024.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123024.protein.info.v11.5.txt",
		        "node_list_path": "1123024.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123024.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusSclerotialis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sclerotialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusSclerotialis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2070753.protein.sequences.v11.5.fa",
		        "enrichment_path": "2070753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2070753.protein.info.v11.5.txt",
		        "node_list_path": "2070753.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriiaBacterium4080(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriia bacterium 40-80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriiaBacterium4080", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895763.protein.info.v11.5.txt",
		        "node_list_path": "1895763.protein.complete.v11.5.txt"
		    }
		]
    )()

def RubritaleaSqualenifaciensDsm18772(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubritalea squalenifaciens DSM 18772 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubritaleaSqualenifaciensDsm18772", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123071.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123071.protein.info.v11.5.txt",
		        "node_list_path": "1123071.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemellaHaemolysans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemella haemolysans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaHaemolysans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379.protein.info.v11.5.txt",
		        "node_list_path": "1379.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSoil764Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil764 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSoil764Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736403.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736403.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736403.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736403.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736403.protein.info.v11.5.txt",
		        "node_list_path": "1736403.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736403.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyellaJaponicaA8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyella japonica A8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaJaponicaA8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217721.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217721.protein.info.v11.5.txt",
		        "node_list_path": "1217721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WinogradskyellaThalassocola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Winogradskyella thalassocola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinogradskyellaThalassocola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262004.protein.sequences.v11.5.fa",
		        "enrichment_path": "262004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262004.protein.info.v11.5.txt",
		        "node_list_path": "262004.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParachlamydiaSpC2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parachlamydia sp. C2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParachlamydiaSpC2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1414722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1414722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1414722.clusters.proteins.v11.5.txt",
		        "sequence_path": "1414722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414722.protein.info.v11.5.txt",
		        "node_list_path": "1414722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1414722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusMachipongonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus machipongonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusMachipongonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "388413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "388413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "388413.clusters.proteins.v11.5.txt",
		        "sequence_path": "388413.protein.sequences.v11.5.fa",
		        "enrichment_path": "388413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388413.protein.info.v11.5.txt",
		        "node_list_path": "388413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "388413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpM47t1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. M47T1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpM47t1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1179778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179778.protein.info.v11.5.txt",
		        "node_list_path": "1179778.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterOrleanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter orleanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterOrleanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "104099.protein.sequences.v11.5.fa",
		        "enrichment_path": "104099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104099.protein.info.v11.5.txt",
		        "node_list_path": "104099.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphenodonPunctatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphenodon punctatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphenodonPunctatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8508.clusters.proteins.v11.5.txt",
		        "sequence_path": "8508.protein.sequences.v11.5.fa",
		        "enrichment_path": "8508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8508.protein.info.v11.5.txt",
		        "node_list_path": "8508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobotryumLychnidisDioicaeP1a1Lamole(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbotryum lychnidis-dioicae p1A1 Lamole graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobotryumLychnidisDioicaeP1a1Lamole", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "683840.protein.sequences.v11.5.fa",
		        "enrichment_path": "683840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683840.protein.info.v11.5.txt",
		        "node_list_path": "683840.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChinchillaLanigera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chinchilla lanigera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChinchillaLanigera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34839.protein.sequences.v11.5.fa",
		        "enrichment_path": "34839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34839.protein.info.v11.5.txt",
		        "node_list_path": "34839.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifcsplowo201Full6413(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO2_01_FULL_64_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201Full6413", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797948.protein.info.v11.5.txt",
		        "node_list_path": "1797948.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPacaense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pacaense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPacaense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816684.protein.info.v11.5.txt",
		        "node_list_path": "1816684.protein.complete.v11.5.txt"
		    }
		]
    )()

def DrosophilaYakuba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila yakuba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaYakuba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7245.protein.sequences.v11.5.fa",
		        "enrichment_path": "7245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7245.protein.info.v11.5.txt",
		        "node_list_path": "7245.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb243495d8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB243_495D8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb243495d8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1471469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471469.protein.info.v11.5.txt",
		        "node_list_path": "1471469.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumM181(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium M181 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumM181", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235792.protein.info.v11.5.txt",
		        "node_list_path": "1235792.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumSubspAnimalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum subsp. animalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumSubspAnimalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "76859.protein.sequences.v11.5.fa",
		        "enrichment_path": "76859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76859.protein.info.v11.5.txt",
		        "node_list_path": "76859.protein.complete.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpAs2mBin001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. AS2M-Bin001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpAs2mBin001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1764958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1764958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1764958.protein.info.v11.5.txt",
		        "node_list_path": "1764958.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf99(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf99 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf99", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736251.protein.info.v11.5.txt",
		        "node_list_path": "1736251.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNecrophorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNecrophorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "859.protein.sequences.v11.5.fa",
		        "enrichment_path": "859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "859.protein.info.v11.5.txt",
		        "node_list_path": "859.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHtcc2080(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2080 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2080", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "247639.protein.sequences.v11.0.fa",
		        "enrichment_path": "247639.protein.enrichment.terms.v11.0.txt",
		        "info_path": "247639.protein.info.v11.0.txt",
		        "node_list_path": "247639.protein.complete.v11.0.txt"
		    }
		]
    )()

def RhodanobacterSpC06Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpC06Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945854.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945854.protein.info.v11.5.txt",
		        "node_list_path": "1945854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasMuralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas muralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasMuralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "119000.clusters.info.v11.5.txt",
		        "cluster_tree_path": "119000.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "119000.clusters.proteins.v11.5.txt",
		        "sequence_path": "119000.protein.sequences.v11.5.fa",
		        "enrichment_path": "119000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "119000.protein.info.v11.5.txt",
		        "node_list_path": "119000.cluster.nodes.v11.5.txt",
		        "edge_list_path": "119000.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichinellaPseudospiralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichinella pseudospiralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaPseudospiralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6337.protein.sequences.v11.5.fa",
		        "enrichment_path": "6337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6337.protein.info.v11.5.txt",
		        "node_list_path": "6337.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacterCrescentusOr37(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter crescentus OR37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterCrescentusOr37", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1292034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292034.protein.info.v11.5.txt",
		        "node_list_path": "1292034.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophaceaeBacteriumCg2305814Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophaceae bacterium CG2_30_58_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophaceaeBacteriumCg2305814Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805378.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805378.protein.info.v11.5.txt",
		        "node_list_path": "1805378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumArachidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium arachidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumArachidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1416778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416778.protein.info.v11.5.txt",
		        "node_list_path": "1416778.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfurococcusFermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurococcus fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurococcusFermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "768672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "768672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "768672.clusters.proteins.v11.5.txt",
		        "sequence_path": "768672.protein.sequences.v11.5.fa",
		        "enrichment_path": "768672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768672.protein.info.v11.5.txt",
		        "node_list_path": "768672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "768672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NadsoniaFulvescensVarElongataDsm6958Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nadsonia fulvescens var. elongata DSM 6958 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NadsoniaFulvescensVarElongataDsm6958Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "857566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "857566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "857566.clusters.proteins.v11.5.txt",
		        "sequence_path": "857566.protein.sequences.v11.5.fa",
		        "enrichment_path": "857566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857566.protein.info.v11.5.txt",
		        "node_list_path": "857566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "857566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaVarigenaUsmarc1296Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena USMARC1296 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaVarigenaUsmarc1296Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1433287.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1433287.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1433287.clusters.proteins.v11.0.txt",
		        "sequence_path": "1433287.protein.sequences.v11.0.fa",
		        "enrichment_path": "1433287.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1433287.protein.info.v11.0.txt",
		        "node_list_path": "1433287.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1433287.protein.cluster.v11.0.txt"
		    }
		]
    )()

def ChlamydiaeBacteriumSm2339Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium SM23_39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaeBacteriumSm2339Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1704235.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1704235.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1704235.clusters.proteins.v11.5.txt",
		        "sequence_path": "1704235.protein.sequences.v11.5.fa",
		        "enrichment_path": "1704235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1704235.protein.info.v11.5.txt",
		        "node_list_path": "1704235.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1704235.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusThioglobusSingularisPs1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus singularis PS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThioglobusSingularisPs1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125411.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125411.protein.info.v11.5.txt",
		        "node_list_path": "1125411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LishizheniaTianjinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lishizhenia tianjinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LishizheniaTianjinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "477690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "477690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "477690.clusters.proteins.v11.5.txt",
		        "sequence_path": "477690.protein.sequences.v11.5.fa",
		        "enrichment_path": "477690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477690.protein.info.v11.5.txt",
		        "node_list_path": "477690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "477690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusJorgensenbacteriaBacteriumRifcsplowo201Full4525b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPLOWO2_01_FULL_45_25b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsplowo201Full4525b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798471.protein.info.v11.5.txt",
		        "node_list_path": "1798471.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf117(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf117", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736260.protein.info.v11.5.txt",
		        "node_list_path": "1736260.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaSalsilacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella salsilacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaSalsilacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "195913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "195913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "195913.clusters.proteins.v11.5.txt",
		        "sequence_path": "195913.protein.sequences.v11.5.fa",
		        "enrichment_path": "195913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195913.protein.info.v11.5.txt",
		        "node_list_path": "195913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "195913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriCcug29243Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri CCUG 29243 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriCcug29243Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196835.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196835.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196835.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196835.protein.info.v11.5.txt",
		        "node_list_path": "1196835.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196835.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporothrixSchenckii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporothrix schenckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporothrixSchenckii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29908.protein.sequences.v11.5.fa",
		        "enrichment_path": "29908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29908.protein.info.v11.5.txt",
		        "node_list_path": "29908.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovispirillumItersoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novispirillum itersonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovispirillumItersoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1279038.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1279038.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1279038.clusters.proteins.v11.5.txt",
		        "sequence_path": "1279038.protein.sequences.v11.5.fa",
		        "enrichment_path": "1279038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1279038.protein.info.v11.5.txt",
		        "node_list_path": "1279038.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1279038.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubeoparvulumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubeoparvulum massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubeoparvulumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1631346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1631346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1631346.clusters.proteins.v11.5.txt",
		        "sequence_path": "1631346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1631346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1631346.protein.info.v11.5.txt",
		        "node_list_path": "1631346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1631346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSp23gom1509mCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. 23GOM1509m Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSp23gom1509mCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380358.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380358.protein.info.v11.5.txt",
		        "node_list_path": "1380358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrapisisporaPhaffiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora phaffii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrapisisporaPhaffiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "113608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "113608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "113608.clusters.proteins.v11.5.txt",
		        "sequence_path": "113608.protein.sequences.v11.5.fa",
		        "enrichment_path": "113608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113608.protein.info.v11.5.txt",
		        "node_list_path": "113608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "113608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpCf108(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. CF108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpCf108", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882758.protein.info.v11.5.txt",
		        "node_list_path": "1882758.protein.complete.v11.5.txt"
		    }
		]
    )()

def KurthiaSpJc8e(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kurthia sp. JC8E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KurthiaSpJc8e", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033740.protein.info.v11.5.txt",
		        "node_list_path": "1033740.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerticilliumNonalfalfaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verticillium nonalfalfae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerticilliumNonalfalfaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1051616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1051616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1051616.clusters.proteins.v11.5.txt",
		        "sequence_path": "1051616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051616.protein.info.v11.5.txt",
		        "node_list_path": "1051616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1051616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaCellobiosiphilaDsm17781Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta cellobiosiphila DSM 17781 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaCellobiosiphilaDsm17781Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123275.protein.info.v11.5.txt",
		        "node_list_path": "1123275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusManganicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus manganicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusManganicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1384049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1384049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1384049.clusters.proteins.v11.5.txt",
		        "sequence_path": "1384049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384049.protein.info.v11.5.txt",
		        "node_list_path": "1384049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1384049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlenkiaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klenkia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlenkiaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1960309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1960309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1960309.protein.info.v11.5.txt",
		        "node_list_path": "1960309.protein.complete.v11.5.txt"
		    }
		]
    )()

def PoseidonocellaSedimentorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Poseidonocella sedimentorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PoseidonocellaSedimentorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "871652.protein.sequences.v11.5.fa",
		        "enrichment_path": "871652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871652.protein.info.v11.5.txt",
		        "node_list_path": "871652.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhormidesmisPriestleyiBc1401Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi BC1401 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhormidesmisPriestleyiBc1401Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1850361.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1850361.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1850361.clusters.proteins.v11.5.txt",
		        "sequence_path": "1850361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850361.protein.info.v11.5.txt",
		        "node_list_path": "1850361.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1850361.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumRifoxya2Full3321Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYA2_FULL_33_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxya2Full3321Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801902.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801902.protein.info.v11.5.txt",
		        "node_list_path": "1801902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumPhoceensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium phoceensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPhoceensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1650661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1650661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1650661.protein.info.v11.5.txt",
		        "node_list_path": "1650661.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumTaihuenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium taihuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumTaihuenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1141221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1141221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1141221.clusters.proteins.v11.5.txt",
		        "sequence_path": "1141221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141221.protein.info.v11.5.txt",
		        "node_list_path": "1141221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1141221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterHormaecheiSubspXiangfangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. xiangfangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterHormaecheiSubspXiangfangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1296536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1296536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1296536.clusters.proteins.v11.5.txt",
		        "sequence_path": "1296536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296536.protein.info.v11.5.txt",
		        "node_list_path": "1296536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1296536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaXinjiangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaXinjiangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "882086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "882086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "882086.clusters.proteins.v11.5.txt",
		        "sequence_path": "882086.protein.sequences.v11.5.fa",
		        "enrichment_path": "882086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882086.protein.info.v11.5.txt",
		        "node_list_path": "882086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "882086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EumetaJaponica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eumeta japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EumetaJaponica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "151549.protein.sequences.v11.5.fa",
		        "enrichment_path": "151549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "151549.protein.info.v11.5.txt",
		        "node_list_path": "151549.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsplowo212Full5210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO2_12_FULL_52_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo212Full5210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798305.protein.info.v11.5.txt",
		        "node_list_path": "1798305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumColicanisDsm13634Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium colicanis DSM 13634 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumColicanisDsm13634Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121305.protein.info.v11.5.txt",
		        "node_list_path": "1121305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoritellaDasanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moritella dasanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoritellaDasanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1201293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1201293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1201293.protein.info.v11.5.txt",
		        "node_list_path": "1201293.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifoxyb2Full4511Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYB2_FULL_45_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyb2Full4511Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802421.protein.info.v11.5.txt",
		        "node_list_path": "1802421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumJlt2015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium JLT2015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumJlt2015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1234595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1234595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1234595.clusters.proteins.v11.5.txt",
		        "sequence_path": "1234595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234595.protein.info.v11.5.txt",
		        "node_list_path": "1234595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1234595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasLinyingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas linyingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasLinyingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "915471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "915471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "915471.clusters.proteins.v11.5.txt",
		        "sequence_path": "915471.protein.sequences.v11.5.fa",
		        "enrichment_path": "915471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "915471.protein.info.v11.5.txt",
		        "node_list_path": "915471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "915471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitreicellaSp357(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citreicella sp. 357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitreicellaSp357", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "766499.protein.sequences.v11.5.fa",
		        "enrichment_path": "766499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "766499.protein.info.v11.5.txt",
		        "node_list_path": "766499.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaIsraelensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella israelensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaIsraelensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "454.protein.sequences.v11.5.fa",
		        "enrichment_path": "454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454.protein.info.v11.5.txt",
		        "node_list_path": "454.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCaenarcanumBioreactoricola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Caenarcanum bioreactoricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCaenarcanumBioreactoricola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906166.protein.info.v11.5.txt",
		        "node_list_path": "1906166.protein.complete.v11.5.txt"
		    }
		]
    )()

def IdeonellaSakaiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ideonella sakaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdeonellaSakaiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1547922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1547922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1547922.clusters.proteins.v11.5.txt",
		        "sequence_path": "1547922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1547922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1547922.protein.info.v11.5.txt",
		        "node_list_path": "1547922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1547922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacterium4423Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 44-23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacterium4423Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895927.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895927.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895927.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895927.protein.info.v11.5.txt",
		        "node_list_path": "1895927.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895927.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioAlginolyticusNbrc15630Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus NBRC15630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioAlginolyticusNbrc15630Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219076.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219076.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219076.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219076.protein.info.v11.5.txt",
		        "node_list_path": "1219076.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219076.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSpZagget8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. Zagget8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpZagget8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930002.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930002.protein.info.v11.5.txt",
		        "node_list_path": "1930002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumCosmeticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium cosmeticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumCosmeticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "258533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "258533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "258533.clusters.proteins.v11.5.txt",
		        "sequence_path": "258533.protein.sequences.v11.5.fa",
		        "enrichment_path": "258533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "258533.protein.info.v11.5.txt",
		        "node_list_path": "258533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "258533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprothermobacterPlatensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprothermobacter platensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprothermobacterPlatensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1259795.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1259795.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1259795.clusters.proteins.v11.5.txt",
		        "sequence_path": "1259795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1259795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1259795.protein.info.v11.5.txt",
		        "node_list_path": "1259795.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1259795.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraCrunogenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira crunogena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraCrunogenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "317025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "317025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "317025.clusters.proteins.v11.5.txt",
		        "sequence_path": "317025.protein.sequences.v11.5.fa",
		        "enrichment_path": "317025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317025.protein.info.v11.5.txt",
		        "node_list_path": "317025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "317025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumYsb2008Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium YSB2008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumYsb2008Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410633.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410633.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410633.protein.info.v11.5.txt",
		        "node_list_path": "1410633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesIsraeliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces israelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesIsraeliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120944.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120944.protein.info.v11.5.txt",
		        "node_list_path": "1120944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926285.protein.info.v11.5.txt",
		        "node_list_path": "1926285.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMicrarchaeotaArchaeonCg1024740Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_47_40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1024740Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805247.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805247.protein.info.v11.5.txt",
		        "node_list_path": "1805247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WohlfahrtiimonasLarvaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas larvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WohlfahrtiimonasLarvaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157986.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157986.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157986.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157986.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157986.protein.info.v11.5.txt",
		        "node_list_path": "1157986.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157986.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaSalina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena salina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaSalina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227488.protein.info.v11.5.txt",
		        "node_list_path": "1227488.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesFragilisYch46Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis YCH46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFragilisYch46Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "295405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "295405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "295405.clusters.proteins.v11.5.txt",
		        "sequence_path": "295405.protein.sequences.v11.5.fa",
		        "enrichment_path": "295405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "295405.protein.info.v11.5.txt",
		        "node_list_path": "295405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "295405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasSchubertiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas schubertii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSchubertiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "652.clusters.proteins.v11.5.txt",
		        "sequence_path": "652.protein.sequences.v11.5.fa",
		        "enrichment_path": "652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "652.protein.info.v11.5.txt",
		        "node_list_path": "652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LaribacterHongkongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Laribacter hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LaribacterHongkongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "557598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "557598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "557598.clusters.proteins.v11.5.txt",
		        "sequence_path": "557598.protein.sequences.v11.5.fa",
		        "enrichment_path": "557598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "557598.protein.info.v11.5.txt",
		        "node_list_path": "557598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "557598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMendocinaEgdaq5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina EGDAQ5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMendocinaEgdaq5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1390370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1390370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1390370.protein.info.v11.5.txt",
		        "node_list_path": "1390370.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr27Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr27Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1934984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1934984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1934984.clusters.proteins.v11.5.txt",
		        "sequence_path": "1934984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934984.protein.info.v11.5.txt",
		        "node_list_path": "1934984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1934984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProvidenciaHeimbachaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia heimbachae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaHeimbachaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "333962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "333962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "333962.clusters.proteins.v11.5.txt",
		        "sequence_path": "333962.protein.sequences.v11.5.fa",
		        "enrichment_path": "333962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "333962.protein.info.v11.5.txt",
		        "node_list_path": "333962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "333962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full4328Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_43_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full4328Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798287.protein.info.v11.5.txt",
		        "node_list_path": "1798287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumOranimenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium oranimense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumOranimenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1300143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1300143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1300143.clusters.proteins.v11.5.txt",
		        "sequence_path": "1300143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300143.protein.info.v11.5.txt",
		        "node_list_path": "1300143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1300143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IsobaculumMelis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Isobaculum melis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IsobaculumMelis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "142588.protein.sequences.v11.5.fa",
		        "enrichment_path": "142588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "142588.protein.info.v11.5.txt",
		        "node_list_path": "142588.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusIndicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusIndicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246786.protein.sequences.v11.5.fa",
		        "enrichment_path": "246786.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246786.protein.info.v11.5.txt",
		        "node_list_path": "246786.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusThermophilusLmd9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus LMD9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusThermophilusLmd9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "322159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "322159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "322159.clusters.proteins.v11.5.txt",
		        "sequence_path": "322159.protein.sequences.v11.5.fa",
		        "enrichment_path": "322159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "322159.protein.info.v11.5.txt",
		        "node_list_path": "322159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "322159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaScoposCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella scopos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaScoposCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236518.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236518.protein.info.v11.5.txt",
		        "node_list_path": "1236518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumGb30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum GB30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumGb30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041142.protein.sequences.v11.0.fa",
		        "enrichment_path": "1041142.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1041142.protein.info.v11.0.txt",
		        "node_list_path": "1041142.protein.complete.v11.0.txt"
		    }
		]
    )()

def AcidaminococcusIntestini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidaminococcus intestini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminococcusIntestini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "568816.protein.sequences.v11.5.fa",
		        "enrichment_path": "568816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568816.protein.info.v11.5.txt",
		        "node_list_path": "568816.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisDassonvillei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis dassonvillei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisDassonvillei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "446468.protein.sequences.v11.5.fa",
		        "enrichment_path": "446468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446468.protein.info.v11.5.txt",
		        "node_list_path": "446468.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesGraminisolvensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides graminisolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesGraminisolvensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121097.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121097.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121097.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121097.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121097.protein.info.v11.5.txt",
		        "node_list_path": "1121097.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121097.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4510cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_02_FULL_45_10c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4510cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798410.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798410.protein.info.v11.5.txt",
		        "node_list_path": "1798410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureimonasSpLeaf324Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpLeaf324Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736336.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736336.protein.info.v11.5.txt",
		        "node_list_path": "1736336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_01_FULL_44_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798407.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798407.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798407.protein.info.v11.5.txt",
		        "node_list_path": "1798407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalostagnicolaSpA56(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halostagnicola sp. A56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalostagnicolaSpA56", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1495067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495067.protein.info.v11.5.txt",
		        "node_list_path": "1495067.protein.complete.v11.5.txt"
		    }
		]
    )()

def NegativicoccusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Negativicoccus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NegativicoccusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1702287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1702287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1702287.protein.info.v11.5.txt",
		        "node_list_path": "1702287.protein.complete.v11.5.txt"
		    }
		]
    )()

def SanguibacterMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SanguibacterMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "285351.protein.sequences.v11.5.fa",
		        "enrichment_path": "285351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285351.protein.info.v11.5.txt",
		        "node_list_path": "285351.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag1295924(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:129_59_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag1295924", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897028.protein.info.v11.5.txt",
		        "node_list_path": "1897028.protein.complete.v11.5.txt"
		    }
		]
    )()

def NioellaNitratireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nioella nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NioellaNitratireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1287720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287720.protein.info.v11.5.txt",
		        "node_list_path": "1287720.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwe24242Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_42_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwe24242Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797339.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797339.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797339.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797339.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797339.protein.info.v11.5.txt",
		        "node_list_path": "1797339.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797339.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaAltamirensisNbrc108246Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia altamirensis NBRC 108246 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAltamirensisNbrc108246Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210064.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210064.protein.info.v11.5.txt",
		        "node_list_path": "1210064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesVitaminophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces vitaminophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesVitaminophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123322.protein.info.v11.5.txt",
		        "node_list_path": "1123322.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf24317(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_43_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf24317", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619085.protein.info.v11.5.txt",
		        "node_list_path": "1619085.protein.complete.v11.5.txt"
		    }
		]
    )()

def AminiphilusCircumscriptus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aminiphilus circumscriptus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminiphilusCircumscriptus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304874.protein.info.v11.5.txt",
		        "node_list_path": "1304874.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumGiardiniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium giardinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumGiardiniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041139.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041139.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041139.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041139.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041139.protein.info.v11.5.txt",
		        "node_list_path": "1041139.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041139.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoplasmaFlorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesoplasma florum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoplasmaFlorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "265311.protein.sequences.v11.5.fa",
		        "enrichment_path": "265311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265311.protein.info.v11.5.txt",
		        "node_list_path": "265311.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumCanariasense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium canariasense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumCanariasense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "228230.protein.sequences.v11.5.fa",
		        "enrichment_path": "228230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228230.protein.info.v11.5.txt",
		        "node_list_path": "228230.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusMaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618.protein.info.v11.5.txt",
		        "node_list_path": "1618.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp21331(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2133.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp21331", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881021.protein.info.v11.5.txt",
		        "node_list_path": "1881021.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumUlcerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium ulcerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumUlcerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469617.protein.sequences.v11.5.fa",
		        "enrichment_path": "469617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469617.protein.info.v11.5.txt",
		        "node_list_path": "469617.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioIshigakensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ishigakensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioIshigakensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1481914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1481914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1481914.clusters.proteins.v11.5.txt",
		        "sequence_path": "1481914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1481914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1481914.protein.info.v11.5.txt",
		        "node_list_path": "1481914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1481914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaribacterStanieri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter stanieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterStanieri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "440514.protein.sequences.v11.5.fa",
		        "enrichment_path": "440514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "440514.protein.info.v11.5.txt",
		        "node_list_path": "440514.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFormosensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas formosensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFormosensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1002526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1002526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1002526.clusters.proteins.v11.5.txt",
		        "sequence_path": "1002526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002526.protein.info.v11.5.txt",
		        "node_list_path": "1002526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1002526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusHominickii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus hominickii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusHominickii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351679.protein.sequences.v11.5.fa",
		        "enrichment_path": "351679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351679.protein.info.v11.5.txt",
		        "node_list_path": "351679.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpNe3005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. ne3005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpNe3005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761887.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761887.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761887.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761887.protein.info.v11.5.txt",
		        "node_list_path": "1761887.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761887.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermosinusCarboxydivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosinus carboxydivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosinusCarboxydivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "401526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "401526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "401526.clusters.proteins.v11.5.txt",
		        "sequence_path": "401526.protein.sequences.v11.5.fa",
		        "enrichment_path": "401526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "401526.protein.info.v11.5.txt",
		        "node_list_path": "401526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "401526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JonquetellaAnthropiDsm22815(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jonquetella anthropi DSM22815 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JonquetellaAnthropiDsm22815", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "885272.protein.sequences.v11.5.fa",
		        "enrichment_path": "885272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "885272.protein.info.v11.5.txt",
		        "node_list_path": "885272.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerticilliumAlfalfaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verticillium alfalfae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerticilliumAlfalfaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1051613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1051613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1051613.clusters.proteins.v11.5.txt",
		        "sequence_path": "1051613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051613.protein.info.v11.5.txt",
		        "node_list_path": "1051613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1051613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LaccariaAmethystinaLaam081Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Laccaria amethystina LaAM-08-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LaccariaAmethystinaLaam081Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095629.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095629.protein.info.v11.5.txt",
		        "node_list_path": "1095629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpAc2005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AC2005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpAc2005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280672.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280672.protein.info.v11.5.txt",
		        "node_list_path": "1280672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkaliflexusImshenetskiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkaliflexus imshenetskii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkaliflexusImshenetskiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "927658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "927658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "927658.clusters.proteins.v11.5.txt",
		        "sequence_path": "927658.protein.sequences.v11.5.fa",
		        "enrichment_path": "927658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927658.protein.info.v11.5.txt",
		        "node_list_path": "927658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "927658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobiumLimicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium limicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumLimicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290315.protein.sequences.v11.5.fa",
		        "enrichment_path": "290315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290315.protein.info.v11.5.txt",
		        "node_list_path": "290315.protein.complete.v11.5.txt"
		    }
		]
    )()

def AllomycesMacrogynusAtcc38327(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Allomyces macrogynus ATCC 38327 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllomycesMacrogynusAtcc38327", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "578462.protein.sequences.v11.5.fa",
		        "enrichment_path": "578462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578462.protein.info.v11.5.txt",
		        "node_list_path": "578462.protein.complete.v11.5.txt"
		    }
		]
    )()

def BibersteiniaTrehalosi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bibersteinia trehalosi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BibersteiniaTrehalosi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263831.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263831.protein.info.v11.5.txt",
		        "node_list_path": "1263831.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaConceptionensis9403948(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella conceptionensis 9403948 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaConceptionensis9403948", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1197728.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197728.protein.info.v11.5.txt",
		        "node_list_path": "1197728.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpPh3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. ph3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpPh3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118058.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118058.protein.info.v11.5.txt",
		        "node_list_path": "1118058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PucciniaSorghiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Puccinia sorghi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PucciniaSorghiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "27349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "27349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "27349.clusters.proteins.v11.5.txt",
		        "sequence_path": "27349.protein.sequences.v11.5.fa",
		        "enrichment_path": "27349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27349.protein.info.v11.5.txt",
		        "node_list_path": "27349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "27349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JannaschiaSeosinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia seosinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaSeosinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313367.clusters.proteins.v11.5.txt",
		        "sequence_path": "313367.protein.sequences.v11.5.fa",
		        "enrichment_path": "313367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313367.protein.info.v11.5.txt",
		        "node_list_path": "313367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusVanfongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus vanfongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusVanfongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120968.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120968.protein.info.v11.5.txt",
		        "node_list_path": "1120968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesLongwoodensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces longwoodensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesLongwoodensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68231.protein.sequences.v11.5.fa",
		        "enrichment_path": "68231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68231.protein.info.v11.5.txt",
		        "node_list_path": "68231.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumBarchaimii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium barchaimii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumBarchaimii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420591.protein.info.v11.5.txt",
		        "node_list_path": "1420591.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumUrealyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium urealyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumUrealyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "504474.protein.sequences.v11.5.fa",
		        "enrichment_path": "504474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504474.protein.info.v11.5.txt",
		        "node_list_path": "504474.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlectobacillusMajorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flectobacillus major Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlectobacillusMajorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "929703.clusters.info.v11.5.txt",
		        "cluster_tree_path": "929703.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "929703.clusters.proteins.v11.5.txt",
		        "sequence_path": "929703.protein.sequences.v11.5.fa",
		        "enrichment_path": "929703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929703.protein.info.v11.5.txt",
		        "node_list_path": "929703.cluster.nodes.v11.5.txt",
		        "edge_list_path": "929703.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4717(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_47_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4717", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802143.protein.info.v11.5.txt",
		        "node_list_path": "1802143.protein.complete.v11.5.txt"
		    }
		]
    )()

def LacinutrixSpHelI90(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix sp. Hel_I_90 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixSpHelI90", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1249999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249999.protein.info.v11.5.txt",
		        "node_list_path": "1249999.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaSpLeaf139Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. Leaf139 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpLeaf139Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736272.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736272.protein.info.v11.5.txt",
		        "node_list_path": "1736272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacillusBrevisX23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus brevis X23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusBrevisX23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1200792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200792.protein.info.v11.5.txt",
		        "node_list_path": "1200792.protein.complete.v11.5.txt"
		    }
		]
    )()

def RubrimonasCliftonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubrimonas cliftonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrimonasCliftonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "89524.protein.sequences.v11.5.fa",
		        "enrichment_path": "89524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89524.protein.info.v11.5.txt",
		        "node_list_path": "89524.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoritellaViscosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moritella viscosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoritellaViscosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "80854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "80854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "80854.clusters.proteins.v11.5.txt",
		        "sequence_path": "80854.protein.sequences.v11.5.fa",
		        "enrichment_path": "80854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80854.protein.info.v11.5.txt",
		        "node_list_path": "80854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "80854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu064Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU064 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu064Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1676155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1676155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1676155.clusters.proteins.v11.5.txt",
		        "sequence_path": "1676155.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676155.protein.info.v11.5.txt",
		        "node_list_path": "1676155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1676155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TatumellaSpNml063099(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tatumella sp. NML063099 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TatumellaSpNml063099", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1344012.protein.sequences.v11.5.fa",
		        "enrichment_path": "1344012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1344012.protein.info.v11.5.txt",
		        "node_list_path": "1344012.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaSpSc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. Sc1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpSc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "593105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "593105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "593105.clusters.proteins.v11.5.txt",
		        "sequence_path": "593105.protein.sequences.v11.5.fa",
		        "enrichment_path": "593105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "593105.protein.info.v11.5.txt",
		        "node_list_path": "593105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "593105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSoil736(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil736 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSoil736", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736395.protein.info.v11.5.txt",
		        "node_list_path": "1736395.protein.complete.v11.5.txt"
		    }
		]
    )()

def PandoraeaVervactiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea vervacti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaVervactiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "656178.clusters.info.v11.5.txt",
		        "cluster_tree_path": "656178.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "656178.clusters.proteins.v11.5.txt",
		        "sequence_path": "656178.protein.sequences.v11.5.fa",
		        "enrichment_path": "656178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656178.protein.info.v11.5.txt",
		        "node_list_path": "656178.cluster.nodes.v11.5.txt",
		        "edge_list_path": "656178.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifoxya12Full5229Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFOXYA12_FULL_52_29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxya12Full5229Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802571.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802571.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802571.protein.info.v11.5.txt",
		        "node_list_path": "1802571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusStrMit9303Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus str. MIT 9303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusStrMit9303Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59922.clusters.proteins.v11.5.txt",
		        "sequence_path": "59922.protein.sequences.v11.5.fa",
		        "enrichment_path": "59922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59922.protein.info.v11.5.txt",
		        "node_list_path": "59922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusDefluvii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus defluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusDefluvii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1323361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1323361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1323361.protein.info.v11.5.txt",
		        "node_list_path": "1323361.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPorcinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus porcinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPorcinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "873448.protein.sequences.v11.5.fa",
		        "enrichment_path": "873448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "873448.protein.info.v11.5.txt",
		        "node_list_path": "873448.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSp6614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. 66-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSp6614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895752.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895752.protein.info.v11.5.txt",
		        "node_list_path": "1895752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1925762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1925762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1925762.protein.info.v11.5.txt",
		        "node_list_path": "1925762.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesWedmorensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces wedmorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesWedmorensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43759.protein.sequences.v11.5.fa",
		        "enrichment_path": "43759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43759.protein.info.v11.5.txt",
		        "node_list_path": "43759.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpYs1r(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. YS1r graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpYs1r", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1532558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1532558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1532558.protein.info.v11.5.txt",
		        "node_list_path": "1532558.protein.complete.v11.5.txt"
		    }
		]
    )()

def MacropusEugeniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Macropus eugenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacropusEugeniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9315.clusters.proteins.v11.5.txt",
		        "sequence_path": "9315.protein.sequences.v11.5.fa",
		        "enrichment_path": "9315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9315.protein.info.v11.5.txt",
		        "node_list_path": "9315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumBrhC8a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRH_c8a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumBrhC8a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629715.protein.info.v11.5.txt",
		        "node_list_path": "1629715.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpCm6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. CM6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpCm6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936580.clusters.proteins.v11.5.txt",
		        "sequence_path": "936580.protein.sequences.v11.5.fa",
		        "enrichment_path": "936580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936580.protein.info.v11.5.txt",
		        "node_list_path": "936580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DysgonomonasCapnocytophagoidesDsm22835(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas capnocytophagoides DSM 22835 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasCapnocytophagoidesDsm22835", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121485.protein.info.v11.5.txt",
		        "node_list_path": "1121485.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClonorchisSinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clonorchis sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClonorchisSinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "79923.protein.sequences.v11.5.fa",
		        "enrichment_path": "79923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79923.protein.info.v11.5.txt",
		        "node_list_path": "79923.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaIniectaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia iniecta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaIniectaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1560201.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1560201.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1560201.clusters.proteins.v11.5.txt",
		        "sequence_path": "1560201.protein.sequences.v11.5.fa",
		        "enrichment_path": "1560201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1560201.protein.info.v11.5.txt",
		        "node_list_path": "1560201.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1560201.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylorubrumSalsuginis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylorubrum salsuginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylorubrumSalsuginis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "414703.protein.sequences.v11.5.fa",
		        "enrichment_path": "414703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "414703.protein.info.v11.5.txt",
		        "node_list_path": "414703.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusTianmuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus tianmuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusTianmuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "624147.clusters.info.v11.5.txt",
		        "cluster_tree_path": "624147.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "624147.clusters.proteins.v11.5.txt",
		        "sequence_path": "624147.protein.sequences.v11.5.fa",
		        "enrichment_path": "624147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "624147.protein.info.v11.5.txt",
		        "node_list_path": "624147.cluster.nodes.v11.5.txt",
		        "edge_list_path": "624147.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaFarcinicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia farcinica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaFarcinicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "247156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "247156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "247156.clusters.proteins.v11.5.txt",
		        "sequence_path": "247156.protein.sequences.v11.5.fa",
		        "enrichment_path": "247156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247156.protein.info.v11.5.txt",
		        "node_list_path": "247156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "247156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfocapsaSulfexigensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfocapsa sulfexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfocapsaSulfexigensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1167006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1167006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1167006.clusters.proteins.v11.5.txt",
		        "sequence_path": "1167006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1167006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1167006.protein.info.v11.5.txt",
		        "node_list_path": "1167006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1167006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudorhodobacterFerrugineus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodobacter ferrugineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodobacterFerrugineus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "77008.protein.sequences.v11.5.fa",
		        "enrichment_path": "77008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77008.protein.info.v11.5.txt",
		        "node_list_path": "77008.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAtelocyanobacteriumThalassaIsolateAloha(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atelocyanobacterium thalassa isolate ALOHA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAtelocyanobacteriumThalassaIsolateAloha", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1453429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453429.protein.info.v11.5.txt",
		        "node_list_path": "1453429.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioHalioticoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio halioticoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioHalioticoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219072.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219072.protein.info.v11.5.txt",
		        "node_list_path": "1219072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpDg25aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. DG25A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpDg25aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385663.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385663.protein.info.v11.5.txt",
		        "node_list_path": "1385663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4716Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_47_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4716Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798690.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798690.protein.info.v11.5.txt",
		        "node_list_path": "1798690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThorselliaAnophelisDsm18579Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thorsellia anophelis DSM 18579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThorselliaAnophelisDsm18579Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123402.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123402.protein.info.v11.5.txt",
		        "node_list_path": "1123402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSantoriniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter santoriniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSantoriniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288826.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288826.protein.info.v11.5.txt",
		        "node_list_path": "1288826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonB262Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B26-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB262Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1779371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1779371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1779371.clusters.proteins.v11.5.txt",
		        "sequence_path": "1779371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1779371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1779371.protein.info.v11.5.txt",
		        "node_list_path": "1779371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1779371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumSpJkg1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. JKG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumSpJkg1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1128421.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1128421.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1128421.clusters.proteins.v11.0.txt",
		        "sequence_path": "1128421.protein.sequences.v11.0.fa",
		        "enrichment_path": "1128421.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1128421.protein.info.v11.0.txt",
		        "node_list_path": "1128421.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1128421.protein.cluster.v11.0.txt"
		    }
		]
    )()

def HoefleaSp108(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hoeflea sp. 108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoefleaSp108", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1116369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116369.protein.info.v11.5.txt",
		        "node_list_path": "1116369.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParageobacillusCaldoxylosilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parageobacillus caldoxylosilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParageobacillusCaldoxylosilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "81408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "81408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "81408.clusters.proteins.v11.5.txt",
		        "sequence_path": "81408.protein.sequences.v11.5.fa",
		        "enrichment_path": "81408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81408.protein.info.v11.5.txt",
		        "node_list_path": "81408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "81408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumRifcsplowo201Full4818(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPLOWO2_01_FULL_48_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsplowo201Full4818", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817743.protein.info.v11.5.txt",
		        "node_list_path": "1817743.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa2439bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_43_9b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa2439bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618828.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618828.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618828.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618828.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618828.protein.info.v11.5.txt",
		        "node_list_path": "1618828.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618828.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ScytonemaHofmanni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scytonema hofmanni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScytonemaHofmanni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1469607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469607.protein.info.v11.5.txt",
		        "node_list_path": "1469607.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterItalicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter italicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterItalicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "580331.protein.sequences.v11.5.fa",
		        "enrichment_path": "580331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "580331.protein.info.v11.5.txt",
		        "node_list_path": "580331.protein.complete.v11.5.txt"
		    }
		]
    )()

def CeleribacterNeptuniusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Celeribacter neptunius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeleribacterNeptuniusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "588602.clusters.info.v11.5.txt",
		        "cluster_tree_path": "588602.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "588602.clusters.proteins.v11.5.txt",
		        "sequence_path": "588602.protein.sequences.v11.5.fa",
		        "enrichment_path": "588602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588602.protein.info.v11.5.txt",
		        "node_list_path": "588602.cluster.nodes.v11.5.txt",
		        "edge_list_path": "588602.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinibacteriumSpPamc21357(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinibacterium sp. PAMC 21357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinibacteriumSpPamc21357", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1112215.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112215.protein.info.v11.5.txt",
		        "node_list_path": "1112215.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpScn5710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. SCN 57-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpScn5710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660094.protein.info.v11.5.txt",
		        "node_list_path": "1660094.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHoaglandellaEndobiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hoaglandella endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHoaglandellaEndobiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1778263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1778263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1778263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1778263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1778263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1778263.protein.info.v11.5.txt",
		        "node_list_path": "1778263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1778263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryomycesMinteriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryomyces minteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryomycesMinteriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "331657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "331657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "331657.clusters.proteins.v11.5.txt",
		        "sequence_path": "331657.protein.sequences.v11.5.fa",
		        "enrichment_path": "331657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331657.protein.info.v11.5.txt",
		        "node_list_path": "331657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "331657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WilliamwhitmaniaTaraxaci(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Williamwhitmania taraxaci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WilliamwhitmaniaTaraxaci", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1640674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640674.protein.info.v11.5.txt",
		        "node_list_path": "1640674.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaQuintana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella quintana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaQuintana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "283165.protein.sequences.v11.5.fa",
		        "enrichment_path": "283165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283165.protein.info.v11.5.txt",
		        "node_list_path": "283165.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasMexicanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas mexicana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasMexicanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "128785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "128785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "128785.clusters.proteins.v11.5.txt",
		        "sequence_path": "128785.protein.sequences.v11.5.fa",
		        "enrichment_path": "128785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "128785.protein.info.v11.5.txt",
		        "node_list_path": "128785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "128785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetivibrioEthanolgignensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetivibrio ethanolgignens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetivibrioEthanolgignensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290052.clusters.proteins.v11.5.txt",
		        "sequence_path": "290052.protein.sequences.v11.5.fa",
		        "enrichment_path": "290052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290052.protein.info.v11.5.txt",
		        "node_list_path": "290052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpAap1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpAap1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523413.protein.info.v11.5.txt",
		        "node_list_path": "1523413.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusKodakarensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus kodakarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusKodakarensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69014.protein.sequences.v11.5.fa",
		        "enrichment_path": "69014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69014.protein.info.v11.5.txt",
		        "node_list_path": "69014.protein.complete.v11.5.txt"
		    }
		]
    )()

def JonquetellaAnthropiE333e1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jonquetella anthropi E333E1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JonquetellaAnthropiE333e1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "645512.protein.sequences.v11.5.fa",
		        "enrichment_path": "645512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645512.protein.info.v11.5.txt",
		        "node_list_path": "645512.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumChocolatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium chocolatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumChocolatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84292.protein.sequences.v11.5.fa",
		        "enrichment_path": "84292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84292.protein.info.v11.5.txt",
		        "node_list_path": "84292.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusVogelbacteriaBacteriumRifoxyd1Full5118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_51_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full5118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802440.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802440.protein.info.v11.5.txt",
		        "node_list_path": "1802440.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeisingeraAquimarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leisingera aquimarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraAquimarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999611.protein.sequences.v11.5.fa",
		        "enrichment_path": "999611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999611.protein.info.v11.5.txt",
		        "node_list_path": "999611.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospinaGracilis3211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospina gracilis 3/211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospinaGracilis3211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1266370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1266370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1266370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1266370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266370.protein.info.v11.5.txt",
		        "node_list_path": "1266370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1266370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSenegalenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium senegalense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSenegalenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033737.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033737.protein.info.v11.5.txt",
		        "node_list_path": "1033737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TalaromycesAtroroseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces atroroseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesAtroroseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1441469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1441469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1441469.protein.info.v11.5.txt",
		        "node_list_path": "1441469.protein.complete.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterEuropaeusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter europaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterEuropaeusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33995.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33995.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33995.clusters.proteins.v11.5.txt",
		        "sequence_path": "33995.protein.sequences.v11.5.fa",
		        "enrichment_path": "33995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33995.protein.info.v11.5.txt",
		        "node_list_path": "33995.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33995.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusEquiSubspZooepidemicusAtcc35246(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus equi subsp. zooepidemicus ATCC 35246 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusEquiSubspZooepidemicusAtcc35246", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1051072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051072.protein.info.v11.5.txt",
		        "node_list_path": "1051072.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeomicrobiumSpJcm19037(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM19037 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeomicrobiumSpJcm19037", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1460634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460634.protein.info.v11.5.txt",
		        "node_list_path": "1460634.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesChristyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles christyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesChristyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43041.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43041.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43041.clusters.proteins.v11.5.txt",
		        "sequence_path": "43041.protein.sequences.v11.5.fa",
		        "enrichment_path": "43041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43041.protein.info.v11.5.txt",
		        "node_list_path": "43041.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43041.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnsiferSpWsm1721Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. WSM1721 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferSpWsm1721Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041159.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041159.protein.info.v11.5.txt",
		        "node_list_path": "1041159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpAp23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. AP23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpAp23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "499656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "499656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "499656.clusters.proteins.v11.5.txt",
		        "sequence_path": "499656.protein.sequences.v11.5.fa",
		        "enrichment_path": "499656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "499656.protein.info.v11.5.txt",
		        "node_list_path": "499656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "499656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SiansivirgaZeaxanthinifaciensCcSamt1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Siansivirga zeaxanthinifaciens CC-SAMT-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SiansivirgaZeaxanthinifaciensCcSamt1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1454006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454006.protein.info.v11.5.txt",
		        "node_list_path": "1454006.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermanaerothrixDaxensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermanaerothrix daxensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermanaerothrixDaxensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "869279.protein.sequences.v11.5.fa",
		        "enrichment_path": "869279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869279.protein.info.v11.5.txt",
		        "node_list_path": "869279.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastopirellulaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastopirellula marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastopirellulaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314230.protein.sequences.v11.5.fa",
		        "enrichment_path": "314230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314230.protein.info.v11.5.txt",
		        "node_list_path": "314230.protein.complete.v11.5.txt"
		    }
		]
    )()

def RiemerellaColumbipharyngis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Riemerella columbipharyngis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RiemerellaColumbipharyngis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071918.protein.info.v11.5.txt",
		        "node_list_path": "1071918.protein.complete.v11.5.txt"
		    }
		]
    )()

def TalaromycesStipitatusAtcc10500(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces stipitatus ATCC 10500 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesStipitatusAtcc10500", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "441959.protein.sequences.v11.5.fa",
		        "enrichment_path": "441959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441959.protein.info.v11.5.txt",
		        "node_list_path": "441959.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasAstaxanthinifaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas astaxanthinifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasAstaxanthinifaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123267.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123267.protein.info.v11.5.txt",
		        "node_list_path": "1123267.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaPalmaeJ233Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma palmae J233 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaPalmaeJ233Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1318466.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1318466.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1318466.clusters.proteins.v11.5.txt",
		        "sequence_path": "1318466.protein.sequences.v11.5.fa",
		        "enrichment_path": "1318466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1318466.protein.info.v11.5.txt",
		        "node_list_path": "1318466.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1318466.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusAfricanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus africanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusAfricanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1137993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137993.protein.info.v11.5.txt",
		        "node_list_path": "1137993.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacterialesBacteriumUtchb2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteriales bacterium UTCHB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacterialesBacteriumUtchb2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1961105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1961105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1961105.clusters.proteins.v11.5.txt",
		        "sequence_path": "1961105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961105.protein.info.v11.5.txt",
		        "node_list_path": "1961105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1961105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GelidibacterAlgens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gelidibacter algens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GelidibacterAlgens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "49280.protein.sequences.v11.5.fa",
		        "enrichment_path": "49280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "49280.protein.info.v11.5.txt",
		        "node_list_path": "49280.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasRhizosphaerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasRhizosphaerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216142.protein.sequences.v11.5.fa",
		        "enrichment_path": "216142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216142.protein.info.v11.5.txt",
		        "node_list_path": "216142.protein.complete.v11.5.txt"
		    }
		]
    )()

def BosTaurusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bos taurus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BosTaurusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9913.clusters.proteins.v11.5.txt",
		        "sequence_path": "9913.protein.sequences.v11.5.fa",
		        "enrichment_path": "9913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9913.protein.info.v11.5.txt",
		        "node_list_path": "9913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpKk3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. KK3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpKk3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855728.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855728.protein.info.v11.5.txt",
		        "node_list_path": "1855728.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulophagaSpHelI12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga sp. Hel_I_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaSpHelI12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1249972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1249972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1249972.clusters.proteins.v11.5.txt",
		        "sequence_path": "1249972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249972.protein.info.v11.5.txt",
		        "node_list_path": "1249972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1249972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkaliphilusTransvaalensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkaliphilus transvaalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkaliphilusTransvaalensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408422.protein.info.v11.5.txt",
		        "node_list_path": "1408422.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacteriumThermosaccharolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium thermosaccharolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacteriumThermosaccharolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "580327.protein.sequences.v11.5.fa",
		        "enrichment_path": "580327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "580327.protein.info.v11.5.txt",
		        "node_list_path": "580327.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurvibacterSpPaeUmCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter sp. PAE-UM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurvibacterSpPaeUmCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1714344.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1714344.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1714344.clusters.proteins.v11.5.txt",
		        "sequence_path": "1714344.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714344.protein.info.v11.5.txt",
		        "node_list_path": "1714344.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1714344.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrovirgaGuangxiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microvirga guangxiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaGuangxiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "549386.protein.sequences.v11.5.fa",
		        "enrichment_path": "549386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "549386.protein.info.v11.5.txt",
		        "node_list_path": "549386.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpHjm029Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. HJM029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpHjm029Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1433844.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1433844.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1433844.clusters.proteins.v11.5.txt",
		        "sequence_path": "1433844.protein.sequences.v11.5.fa",
		        "enrichment_path": "1433844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1433844.protein.info.v11.5.txt",
		        "node_list_path": "1433844.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1433844.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpilithonimonasTenaxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas tenax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpilithonimonasTenaxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121870.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121870.protein.info.v11.5.txt",
		        "node_list_path": "1121870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusCurdlanolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus curdlanolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusCurdlanolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717606.protein.sequences.v11.5.fa",
		        "enrichment_path": "717606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717606.protein.info.v11.5.txt",
		        "node_list_path": "717606.protein.complete.v11.5.txt"
		    }
		]
    )()

def FabibacterSp4d4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fabibacter sp. 4D4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FabibacterSp4d4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1889784.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1889784.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1889784.clusters.proteins.v11.5.txt",
		        "sequence_path": "1889784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889784.protein.info.v11.5.txt",
		        "node_list_path": "1889784.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1889784.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OryzaSativaJaponicaGroupCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Japonica Group Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaSativaJaponicaGroupCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39947.clusters.proteins.v11.5.txt",
		        "sequence_path": "39947.protein.sequences.v11.5.fa",
		        "enrichment_path": "39947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39947.protein.info.v11.5.txt",
		        "node_list_path": "39947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag10605727(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:1060_57_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag10605727", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896975.protein.info.v11.5.txt",
		        "node_list_path": "1896975.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802660.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802660.protein.info.v11.5.txt",
		        "node_list_path": "1802660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusGigeriorumDsm23908Crbip2485Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gigeriorum DSM 23908 CRBIP 24.85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGigeriorumDsm23908Crbip2485Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423751.protein.info.v11.5.txt",
		        "node_list_path": "1423751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSpechtbacteriaBacteriumRifcsplowo212Full3822(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_12_FULL_38_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo212Full3822", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802165.protein.info.v11.5.txt",
		        "node_list_path": "1802165.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsplowo212Full5210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO2_12_FULL_52_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo212Full5210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798305.protein.info.v11.5.txt",
		        "node_list_path": "1798305.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterSinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterSinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1743157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743157.protein.info.v11.5.txt",
		        "node_list_path": "1743157.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacaBarguzinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobaca barguzinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacaBarguzinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "441209.protein.sequences.v11.5.fa",
		        "enrichment_path": "441209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441209.protein.info.v11.5.txt",
		        "node_list_path": "441209.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSporothermodurans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sporothermodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSporothermodurans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46224.protein.sequences.v11.5.fa",
		        "enrichment_path": "46224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46224.protein.info.v11.5.txt",
		        "node_list_path": "46224.protein.complete.v11.5.txt"
		    }
		]
    )()

def GilliamellaMensalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gilliamella mensalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilliamellaMensalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1908520.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1908520.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1908520.clusters.proteins.v11.5.txt",
		        "sequence_path": "1908520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908520.protein.info.v11.5.txt",
		        "node_list_path": "1908520.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1908520.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureimonasSpLeaf427(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf427 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasSpLeaf427", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736375.protein.info.v11.5.txt",
		        "node_list_path": "1736375.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesHongkongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesHongkongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "178339.protein.sequences.v11.5.fa",
		        "enrichment_path": "178339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178339.protein.info.v11.5.txt",
		        "node_list_path": "178339.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaAlsaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella alsatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaAlsaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094551.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094551.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094551.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094551.protein.info.v11.5.txt",
		        "node_list_path": "1094551.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094551.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesMelas(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles melas graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesMelas", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34690.protein.sequences.v11.5.fa",
		        "enrichment_path": "34690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34690.protein.info.v11.5.txt",
		        "node_list_path": "34690.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpCcge510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. CCGE510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpCcge510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1132836.protein.sequences.v11.5.fa",
		        "enrichment_path": "1132836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1132836.protein.info.v11.5.txt",
		        "node_list_path": "1132836.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumLemurum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium lemurum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumLemurum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1603886.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603886.protein.info.v11.5.txt",
		        "node_list_path": "1603886.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaVeteranaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia veterana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaVeteranaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206743.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206743.protein.info.v11.5.txt",
		        "node_list_path": "1206743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumDtu015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumDtu015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671637.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671637.protein.info.v11.5.txt",
		        "node_list_path": "1671637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NodosilineaNodulosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nodosilinea nodulosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NodosilineaNodulosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118166.protein.sequences.v11.5.fa",
		        "enrichment_path": "118166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118166.protein.info.v11.5.txt",
		        "node_list_path": "118166.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaFlavescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaFlavescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "484.protein.sequences.v11.5.fa",
		        "enrichment_path": "484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484.protein.info.v11.5.txt",
		        "node_list_path": "484.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMassiliglacieiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus massiliglaciei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMassiliglacieiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816693.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816693.protein.info.v11.5.txt",
		        "node_list_path": "1816693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusCapitisSubspCapitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus capitis subsp. capitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusCapitisSubspCapitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "72758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "72758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "72758.clusters.proteins.v11.5.txt",
		        "sequence_path": "72758.protein.sequences.v11.5.fa",
		        "enrichment_path": "72758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72758.protein.info.v11.5.txt",
		        "node_list_path": "72758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "72758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumRhizosphaerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumRhizosphaerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1672749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1672749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1672749.protein.info.v11.5.txt",
		        "node_list_path": "1672749.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpM412017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. M41(2017) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpM412017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1955065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1955065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1955065.clusters.proteins.v11.5.txt",
		        "sequence_path": "1955065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1955065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1955065.protein.info.v11.5.txt",
		        "node_list_path": "1955065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1955065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonadaceaeBacteriumScn6820Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium SCN 68-20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonadaceaeBacteriumScn6820Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660161.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660161.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660161.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660161.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660161.protein.info.v11.5.txt",
		        "node_list_path": "1660161.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660161.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaMonacensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia monacensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaMonacensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "109232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "109232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "109232.clusters.proteins.v11.5.txt",
		        "sequence_path": "109232.protein.sequences.v11.5.fa",
		        "enrichment_path": "109232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109232.protein.info.v11.5.txt",
		        "node_list_path": "109232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "109232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumVe20209(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumVe20209", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232447.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232447.protein.info.v11.5.txt",
		        "node_list_path": "1232447.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasGuangdongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas guangdongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasGuangdongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1245526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245526.protein.info.v11.5.txt",
		        "node_list_path": "1245526.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanidioschyzonMerolae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanidioschyzon merolae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanidioschyzonMerolae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45157.protein.sequences.v11.5.fa",
		        "enrichment_path": "45157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45157.protein.info.v11.5.txt",
		        "node_list_path": "45157.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumScgcAaa076P09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA076-P09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumScgcAaa076P09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1007118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007118.protein.info.v11.5.txt",
		        "node_list_path": "1007118.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaPiriflorinigransCfbp5888(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia piriflorinigrans CFBP 5888 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaPiriflorinigransCfbp5888", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1161919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1161919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1161919.protein.info.v11.5.txt",
		        "node_list_path": "1161919.protein.complete.v11.5.txt"
		    }
		]
    )()

def AggregatibacterActinomycetemcomitansHk1651(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans HK1651 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterActinomycetemcomitansHk1651", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272556.protein.sequences.v11.5.fa",
		        "enrichment_path": "272556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272556.protein.info.v11.5.txt",
		        "node_list_path": "272556.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioclavaSpSk1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. SK-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaSpSk1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1889770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889770.protein.info.v11.5.txt",
		        "node_list_path": "1889770.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho201Full3725(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_37_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full3725", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801731.protein.info.v11.5.txt",
		        "node_list_path": "1801731.protein.complete.v11.5.txt"
		    }
		]
    )()

def AchromobacterInsuavis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter insuavis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterInsuavis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1003200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1003200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1003200.protein.info.v11.5.txt",
		        "node_list_path": "1003200.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastocystisSpAtcc50177NandIi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastocystis sp. ATCC 50177/Nand II graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastocystisSpAtcc50177NandIi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "478820.protein.sequences.v11.5.fa",
		        "enrichment_path": "478820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "478820.protein.info.v11.5.txt",
		        "node_list_path": "478820.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag114(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag114", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263001.protein.info.v11.5.txt",
		        "node_list_path": "1263001.protein.complete.v11.5.txt"
		    }
		]
    )()

def LitoreibacterAscidiaceicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Litoreibacter ascidiaceicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LitoreibacterAscidiaceicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1486859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1486859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1486859.clusters.proteins.v11.5.txt",
		        "sequence_path": "1486859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1486859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1486859.protein.info.v11.5.txt",
		        "node_list_path": "1486859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1486859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAbietaniphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas abietaniphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAbietaniphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "89065.protein.sequences.v11.5.fa",
		        "enrichment_path": "89065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89065.protein.info.v11.5.txt",
		        "node_list_path": "89065.protein.complete.v11.5.txt"
		    }
		]
    )()

def StruthioCamelusAustralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Struthio camelus australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StruthioCamelusAustralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "441894.protein.sequences.v11.5.fa",
		        "enrichment_path": "441894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441894.protein.info.v11.5.txt",
		        "node_list_path": "441894.protein.complete.v11.5.txt"
		    }
		]
    )()

def SneathiaAmnii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sneathia amnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SneathiaAmnii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "187101.protein.sequences.v11.5.fa",
		        "enrichment_path": "187101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "187101.protein.info.v11.5.txt",
		        "node_list_path": "187101.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechocystisSpPcc7509Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC7509 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechocystisSpPcc7509Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "927677.clusters.info.v11.5.txt",
		        "cluster_tree_path": "927677.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "927677.clusters.proteins.v11.5.txt",
		        "sequence_path": "927677.protein.sequences.v11.5.fa",
		        "enrichment_path": "927677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927677.protein.info.v11.5.txt",
		        "node_list_path": "927677.cluster.nodes.v11.5.txt",
		        "edge_list_path": "927677.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumSpLk1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium sp. LK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumSpLk1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1628193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628193.protein.info.v11.5.txt",
		        "node_list_path": "1628193.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinomonasAtrocyaneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinomonas atrocyanea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinomonasAtrocyaneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37927.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37927.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37927.clusters.proteins.v11.5.txt",
		        "sequence_path": "37927.protein.sequences.v11.5.fa",
		        "enrichment_path": "37927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37927.protein.info.v11.5.txt",
		        "node_list_path": "37927.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37927.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzotobacterVinelandiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azotobacter vinelandii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzotobacterVinelandiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "322710.clusters.info.v11.5.txt",
		        "cluster_tree_path": "322710.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "322710.clusters.proteins.v11.5.txt",
		        "sequence_path": "322710.protein.sequences.v11.5.fa",
		        "enrichment_path": "322710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "322710.protein.info.v11.5.txt",
		        "node_list_path": "322710.cluster.nodes.v11.5.txt",
		        "edge_list_path": "322710.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterHominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterHominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "360107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "360107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "360107.clusters.proteins.v11.5.txt",
		        "sequence_path": "360107.protein.sequences.v11.5.fa",
		        "enrichment_path": "360107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360107.protein.info.v11.5.txt",
		        "node_list_path": "360107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "360107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumDurum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium durum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumDurum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035195.protein.info.v11.5.txt",
		        "node_list_path": "1035195.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAgalactiaeNem316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae NEM316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAgalactiaeNem316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "211110.protein.sequences.v11.5.fa",
		        "enrichment_path": "211110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211110.protein.info.v11.5.txt",
		        "node_list_path": "211110.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAdiutrixIntracellularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adiutrix intracellularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAdiutrixIntracellularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1705730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705730.protein.info.v11.5.txt",
		        "node_list_path": "1705730.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagirhabdusAlkalitolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagirhabdus alkalitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagirhabdusAlkalitolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1612202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1612202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1612202.protein.info.v11.5.txt",
		        "node_list_path": "1612202.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumAlamii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium alamii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumAlamii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "492774.protein.sequences.v11.5.fa",
		        "enrichment_path": "492774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "492774.protein.info.v11.5.txt",
		        "node_list_path": "492774.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3921(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3921", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802519.protein.info.v11.5.txt",
		        "node_list_path": "1802519.protein.complete.v11.5.txt"
		    }
		]
    )()

def AccipiterNisusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Accipiter nisus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AccipiterNisusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "211598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "211598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "211598.clusters.proteins.v11.5.txt",
		        "sequence_path": "211598.protein.sequences.v11.5.fa",
		        "enrichment_path": "211598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211598.protein.info.v11.5.txt",
		        "node_list_path": "211598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "211598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusJacksonbacteriaBacteriumRifoxya2Full4312Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jacksonbacteria bacterium RIFOXYA2_FULL_43_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJacksonbacteriaBacteriumRifoxya2Full4312Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798462.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798462.protein.info.v11.5.txt",
		        "node_list_path": "1798462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag520(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:520 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag520", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262929.protein.info.v11.5.txt",
		        "node_list_path": "1262929.protein.complete.v11.5.txt"
		    }
		]
    )()

def HamiltonellaDefensa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hamiltonella defensa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HamiltonellaDefensa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "572265.protein.sequences.v11.5.fa",
		        "enrichment_path": "572265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572265.protein.info.v11.5.txt",
		        "node_list_path": "572265.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpBgiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Bgi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpBgiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1186051.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1186051.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1186051.clusters.proteins.v11.0.txt",
		        "sequence_path": "1186051.protein.sequences.v11.0.fa",
		        "enrichment_path": "1186051.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1186051.protein.info.v11.0.txt",
		        "node_list_path": "1186051.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1186051.protein.cluster.v11.0.txt"
		    }
		]
    )()

def MusCaroli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mus caroli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusCaroli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10089.protein.sequences.v11.5.fa",
		        "enrichment_path": "10089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10089.protein.info.v11.5.txt",
		        "node_list_path": "10089.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4515(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_01_FULL_45_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4515", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802132.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802132.protein.info.v11.5.txt",
		        "node_list_path": "1802132.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaSpF0381Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0381 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaSpF0381Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1127692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1127692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1127692.clusters.proteins.v11.5.txt",
		        "sequence_path": "1127692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127692.protein.info.v11.5.txt",
		        "node_list_path": "1127692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1127692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfolobusSolfataricus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus solfataricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusSolfataricus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "273057.protein.sequences.v11.5.fa",
		        "enrichment_path": "273057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273057.protein.info.v11.5.txt",
		        "node_list_path": "273057.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCampbellbacteriaBacteriumRifoxyc2Full3525(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFOXYC2_FULL_35_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifoxyc2Full3525", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797582.protein.info.v11.5.txt",
		        "node_list_path": "1797582.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusPanisDsm6035(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus panis DSM 6035 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPanisDsm6035", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423782.protein.info.v11.5.txt",
		        "node_list_path": "1423782.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRifoxyd1Full5531Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1_FULL_55_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1Full5531Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797404.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797404.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797404.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797404.protein.info.v11.5.txt",
		        "node_list_path": "1797404.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797404.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JonesiaDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jonesia denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JonesiaDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471856.protein.sequences.v11.5.fa",
		        "enrichment_path": "471856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471856.protein.info.v11.5.txt",
		        "node_list_path": "471856.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSomaliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces somaliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSomaliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1134445.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1134445.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1134445.clusters.proteins.v11.5.txt",
		        "sequence_path": "1134445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134445.protein.info.v11.5.txt",
		        "node_list_path": "1134445.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1134445.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpCmf222Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Cmf 22.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpCmf222Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926478.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926478.protein.info.v11.5.txt",
		        "node_list_path": "1926478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpBp1148(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. BP1-148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpBp1148", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "645274.protein.sequences.v11.5.fa",
		        "enrichment_path": "645274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645274.protein.info.v11.5.txt",
		        "node_list_path": "645274.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor3BacteriumSm2342Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR_3 bacterium SM23_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor3BacteriumSm2342Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703779.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703779.protein.info.v11.5.txt",
		        "node_list_path": "1703779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaGoodfellowiiDsm19756(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia goodfellowii DSM 19756 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaGoodfellowiiDsm19756", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "714315.protein.sequences.v11.5.fa",
		        "enrichment_path": "714315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "714315.protein.info.v11.5.txt",
		        "node_list_path": "714315.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumPhlei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium phlei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumPhlei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1771.protein.sequences.v11.5.fa",
		        "enrichment_path": "1771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1771.protein.info.v11.5.txt",
		        "node_list_path": "1771.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrotetrasporaMalaysiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microtetraspora malaysiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrotetrasporaMalaysiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "161358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "161358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "161358.clusters.proteins.v11.5.txt",
		        "sequence_path": "161358.protein.sequences.v11.5.fa",
		        "enrichment_path": "161358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161358.protein.info.v11.5.txt",
		        "node_list_path": "161358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "161358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag1031Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1031 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag1031Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262917.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262917.protein.info.v11.5.txt",
		        "node_list_path": "1262917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EctothiorhodospiraSpPhs1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ectothiorhodospira sp. PHS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctothiorhodospiraSpPhs1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "519989.protein.sequences.v11.5.fa",
		        "enrichment_path": "519989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519989.protein.info.v11.5.txt",
		        "node_list_path": "519989.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwa26142(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_61_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwa26142", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797923.protein.info.v11.5.txt",
		        "node_list_path": "1797923.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumLinensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium linens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumLinensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "321955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "321955.clusters.proteins.v11.5.txt",
		        "sequence_path": "321955.protein.sequences.v11.5.fa",
		        "enrichment_path": "321955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321955.protein.info.v11.5.txt",
		        "node_list_path": "321955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "321955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaAlbertiiTw07627Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia albertii TW07627 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaAlbertiiTw07627Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "502347.clusters.info.v11.5.txt",
		        "cluster_tree_path": "502347.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "502347.clusters.proteins.v11.5.txt",
		        "sequence_path": "502347.protein.sequences.v11.5.fa",
		        "enrichment_path": "502347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502347.protein.info.v11.5.txt",
		        "node_list_path": "502347.cluster.nodes.v11.5.txt",
		        "edge_list_path": "502347.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp6910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 69-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp6910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895783.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895783.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895783.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895783.protein.info.v11.5.txt",
		        "node_list_path": "1895783.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895783.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZetaproteobacteriaBacteriumCg2305937Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG2_30_59_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaproteobacteriaBacteriumCg2305937Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805430.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805430.protein.info.v11.5.txt",
		        "node_list_path": "1805430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonadalesBacteriumBs08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonadales bacterium BS08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonadalesBacteriumBs08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895005.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895005.protein.info.v11.5.txt",
		        "node_list_path": "1895005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaplasmaMarginaleMaries(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Anaplasma marginale Maries graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "AnaplasmaMarginaleMaries", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "234826.protein.sequences.v11.0.fa",
		        "enrichment_path": "234826.protein.enrichment.terms.v11.0.txt",
		        "info_path": "234826.protein.info.v11.0.txt",
		        "node_list_path": "234826.protein.complete.v11.0.txt"
		    }
		]
    )()

def RhizobiumOryziradicisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium oryziradicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumOryziradicisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1867956.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1867956.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1867956.clusters.proteins.v11.5.txt",
		        "sequence_path": "1867956.protein.sequences.v11.5.fa",
		        "enrichment_path": "1867956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1867956.protein.info.v11.5.txt",
		        "node_list_path": "1867956.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1867956.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudovibrioSpTunPsc045I4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. Tun.PSC04-5.I4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioSpTunPsc045I4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798213.protein.info.v11.5.txt",
		        "node_list_path": "1798213.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpR372017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. R37(2017) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpR372017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1981685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1981685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1981685.protein.info.v11.5.txt",
		        "node_list_path": "1981685.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesKatraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces katrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesKatraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68223.clusters.proteins.v11.5.txt",
		        "sequence_path": "68223.protein.sequences.v11.5.fa",
		        "enrichment_path": "68223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68223.protein.info.v11.5.txt",
		        "node_list_path": "68223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpFh2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FH2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpFh2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674291.protein.info.v11.5.txt",
		        "node_list_path": "1674291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumSpDsm25559(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. DSM 25559 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumSpDsm25559", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907666.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907666.protein.info.v11.5.txt",
		        "node_list_path": "1907666.protein.complete.v11.5.txt"
		    }
		]
    )()

def NegativibacillusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Negativibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NegativibacillusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871035.protein.info.v11.5.txt",
		        "node_list_path": "1871035.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumHigginsianumImi349063(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum higginsianum IMI 349063 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumHigginsianumImi349063", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "759273.protein.sequences.v11.5.fa",
		        "enrichment_path": "759273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759273.protein.info.v11.5.txt",
		        "node_list_path": "759273.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasHumiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasHumiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "405444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "405444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "405444.clusters.proteins.v11.5.txt",
		        "sequence_path": "405444.protein.sequences.v11.5.fa",
		        "enrichment_path": "405444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405444.protein.info.v11.5.txt",
		        "node_list_path": "405444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "405444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMegateriumQmB1551Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus megaterium QM B1551 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMegateriumQmB1551Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "545693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "545693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "545693.clusters.proteins.v11.5.txt",
		        "sequence_path": "545693.protein.sequences.v11.5.fa",
		        "enrichment_path": "545693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545693.protein.info.v11.5.txt",
		        "node_list_path": "545693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "545693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaInyonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora inyonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaInyonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47866.clusters.proteins.v11.5.txt",
		        "sequence_path": "47866.protein.sequences.v11.5.fa",
		        "enrichment_path": "47866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47866.protein.info.v11.5.txt",
		        "node_list_path": "47866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesGallinarumDsm18171Jcm13658(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides gallinarum DSM 18171 JCM 13658 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesGallinarumDsm18171Jcm13658", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121096.protein.info.v11.5.txt",
		        "node_list_path": "1121096.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpAntH11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ant H11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpAntH11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1564113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1564113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1564113.clusters.proteins.v11.5.txt",
		        "sequence_path": "1564113.protein.sequences.v11.5.fa",
		        "enrichment_path": "1564113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1564113.protein.info.v11.5.txt",
		        "node_list_path": "1564113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1564113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaSpQh12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sp. QH-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSpQh12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437876.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437876.protein.info.v11.5.txt",
		        "node_list_path": "1437876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemellaHaemolysansM341Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella haemolysans M341 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaHaemolysansM341Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "562981.clusters.info.v11.5.txt",
		        "cluster_tree_path": "562981.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "562981.clusters.proteins.v11.5.txt",
		        "sequence_path": "562981.protein.sequences.v11.5.fa",
		        "enrichment_path": "562981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562981.protein.info.v11.5.txt",
		        "node_list_path": "562981.cluster.nodes.v11.5.txt",
		        "edge_list_path": "562981.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpUasws1009(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. UASWS1009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpUasws1009", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566387.protein.info.v11.5.txt",
		        "node_list_path": "1566387.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg166022Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_60_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg166022Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797656.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797656.protein.info.v11.5.txt",
		        "node_list_path": "1797656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo212Full4614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_12_FULL_46_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo212Full4614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801797.protein.info.v11.5.txt",
		        "node_list_path": "1801797.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRedseaS39B2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. REDSEA-S39_B2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRedseaS39B2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811558.protein.info.v11.5.txt",
		        "node_list_path": "1811558.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSp88a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 88A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSp88a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131813.protein.info.v11.5.txt",
		        "node_list_path": "1131813.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaBongoriNctc12419(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella bongori NCTC12419 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaBongoriNctc12419", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "218493.protein.sequences.v11.5.fa",
		        "enrichment_path": "218493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218493.protein.info.v11.5.txt",
		        "node_list_path": "218493.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph3623Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH 3623 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph3623Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217698.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217698.protein.info.v11.5.txt",
		        "node_list_path": "1217698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonlabensSpongiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens spongiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensSpongiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "331648.protein.sequences.v11.5.fa",
		        "enrichment_path": "331648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331648.protein.info.v11.5.txt",
		        "node_list_path": "331648.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaGranularum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma granularum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaGranularum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278304.protein.info.v11.5.txt",
		        "node_list_path": "1278304.protein.complete.v11.5.txt"
		    }
		]
    )()

def KinetoplastibacteriumGalatii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium galatii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KinetoplastibacteriumGalatii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208921.protein.info.v11.5.txt",
		        "node_list_path": "1208921.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_45_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618832.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618832.protein.info.v11.5.txt",
		        "node_list_path": "1618832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NesterenkoniaSpNp1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. NP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesterenkoniaSpNp1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232429.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232429.protein.info.v11.5.txt",
		        "node_list_path": "1232429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumAcnesKpa171202(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes KPA171202 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumAcnesKpa171202", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "267747.protein.sequences.v11.5.fa",
		        "enrichment_path": "267747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267747.protein.info.v11.5.txt",
		        "node_list_path": "267747.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumFormicicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium formicicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumFormicicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2162.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2162.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2162.clusters.proteins.v11.5.txt",
		        "sequence_path": "2162.protein.sequences.v11.5.fa",
		        "enrichment_path": "2162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2162.protein.info.v11.5.txt",
		        "node_list_path": "2162.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2162.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfuritaleaHydrogenivoransSk43h(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfuritalea hydrogenivorans sk43H graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuritaleaHydrogenivoransSk43h", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223802.protein.info.v11.5.txt",
		        "node_list_path": "1223802.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh7803(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 7803 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh7803", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32051.protein.sequences.v11.5.fa",
		        "enrichment_path": "32051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32051.protein.info.v11.5.txt",
		        "node_list_path": "32051.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeptuniibacterPectenicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neptuniibacter pectenicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptuniibacterPectenicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1806669.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806669.protein.info.v11.5.txt",
		        "node_list_path": "1806669.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumGa0077533(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium Ga0077533 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumGa0077533", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752234.protein.info.v11.5.txt",
		        "node_list_path": "1752234.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSingulareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium singulare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSingulareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "161899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "161899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "161899.clusters.proteins.v11.5.txt",
		        "sequence_path": "161899.protein.sequences.v11.5.fa",
		        "enrichment_path": "161899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161899.protein.info.v11.5.txt",
		        "node_list_path": "161899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "161899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesSalanitronisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides salanitronis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSalanitronisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "667015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "667015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "667015.clusters.proteins.v11.5.txt",
		        "sequence_path": "667015.protein.sequences.v11.5.fa",
		        "enrichment_path": "667015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667015.protein.info.v11.5.txt",
		        "node_list_path": "667015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "667015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CephaloticoccusPrimusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cephaloticoccus primus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CephaloticoccusPrimusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1548207.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1548207.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1548207.clusters.proteins.v11.5.txt",
		        "sequence_path": "1548207.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548207.protein.info.v11.5.txt",
		        "node_list_path": "1548207.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1548207.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslH70326Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSL H7-0326 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslH70326Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1921144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1921144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1921144.clusters.proteins.v11.5.txt",
		        "sequence_path": "1921144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921144.protein.info.v11.5.txt",
		        "node_list_path": "1921144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1921144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMassiliosenegalensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus massiliosenegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMassiliosenegalensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1034347.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034347.protein.info.v11.5.txt",
		        "node_list_path": "1034347.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa23827Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_38_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa23827Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618812.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618812.protein.info.v11.5.txt",
		        "node_list_path": "1618812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaStagnalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia stagnalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaStagnalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1503054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1503054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1503054.protein.info.v11.5.txt",
		        "node_list_path": "1503054.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu064(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU064 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu064", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1676155.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676155.protein.info.v11.5.txt",
		        "node_list_path": "1676155.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiastellaPopuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Niastella populi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiastellaPopuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "550983.protein.sequences.v11.5.fa",
		        "enrichment_path": "550983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "550983.protein.info.v11.5.txt",
		        "node_list_path": "550983.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChelonobacterOris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chelonobacter oris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelonobacterOris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "505317.protein.sequences.v11.5.fa",
		        "enrichment_path": "505317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "505317.protein.info.v11.5.txt",
		        "node_list_path": "505317.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpMitS9509(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. MIT S9509 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpMitS9509", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801630.protein.info.v11.5.txt",
		        "node_list_path": "1801630.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpLeaf141(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf141 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpLeaf141", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736273.protein.info.v11.5.txt",
		        "node_list_path": "1736273.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpEur3121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. EUR3 1.2.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpEur3121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1305734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305734.protein.info.v11.5.txt",
		        "node_list_path": "1305734.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaceaeBacteriumUrhe0068Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium URHE0068 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaceaeBacteriumUrhe0068Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380348.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380348.protein.info.v11.5.txt",
		        "node_list_path": "1380348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpPcc7375Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC7375 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpPcc7375Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "102129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "102129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "102129.clusters.proteins.v11.5.txt",
		        "sequence_path": "102129.protein.sequences.v11.5.fa",
		        "enrichment_path": "102129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102129.protein.info.v11.5.txt",
		        "node_list_path": "102129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "102129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRoot122(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root122 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRoot122", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736431.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736431.protein.info.v11.5.txt",
		        "node_list_path": "1736431.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalanaerobiumHydrogeniformans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halanaerobium hydrogeniformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaerobiumHydrogeniformans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "656519.protein.sequences.v11.5.fa",
		        "enrichment_path": "656519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656519.protein.info.v11.5.txt",
		        "node_list_path": "656519.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDesantisbacteriaBacteriumCg1024989Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG1_02_49_89 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg1024989Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817894.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817894.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817894.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817894.protein.info.v11.5.txt",
		        "node_list_path": "1817894.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817894.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmantichitinumUrsilacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amantichitinum ursilacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmantichitinumUrsilacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "857265.protein.sequences.v11.5.fa",
		        "enrichment_path": "857265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857265.protein.info.v11.5.txt",
		        "node_list_path": "857265.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumNovyiNt(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium novyi NT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumNovyiNt", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "386415.protein.sequences.v11.5.fa",
		        "enrichment_path": "386415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "386415.protein.info.v11.5.txt",
		        "node_list_path": "386415.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterUlvicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter ulvicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterUlvicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "228959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "228959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "228959.clusters.proteins.v11.5.txt",
		        "sequence_path": "228959.protein.sequences.v11.5.fa",
		        "enrichment_path": "228959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228959.protein.info.v11.5.txt",
		        "node_list_path": "228959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "228959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FilifactorAlocis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Filifactor alocis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FilifactorAlocis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546269.protein.sequences.v11.5.fa",
		        "enrichment_path": "546269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546269.protein.info.v11.5.txt",
		        "node_list_path": "546269.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrunusMumeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prunus mume Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrunusMumeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "102107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "102107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "102107.clusters.proteins.v11.5.txt",
		        "sequence_path": "102107.protein.sequences.v11.5.fa",
		        "enrichment_path": "102107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102107.protein.info.v11.5.txt",
		        "node_list_path": "102107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "102107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionCpr1BacteriumGw2011Gwc14913Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR1 bacterium GW2011_GWC1_49_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionCpr1BacteriumGw2011Gwc14913Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618342.protein.info.v11.5.txt",
		        "node_list_path": "1618342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonasSpSn2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. SN2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasSpSn2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "715451.clusters.info.v11.5.txt",
		        "cluster_tree_path": "715451.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "715451.clusters.proteins.v11.5.txt",
		        "sequence_path": "715451.protein.sequences.v11.5.fa",
		        "enrichment_path": "715451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "715451.protein.info.v11.5.txt",
		        "node_list_path": "715451.cluster.nodes.v11.5.txt",
		        "edge_list_path": "715451.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesLuti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides luti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesLuti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1297750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297750.protein.info.v11.5.txt",
		        "node_list_path": "1297750.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycetaceaeBacteriumBa112Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomycetaceae bacterium BA112 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycetaceaeBacteriumBa112Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1823756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1823756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1823756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1823756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1823756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1823756.protein.info.v11.5.txt",
		        "node_list_path": "1823756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1823756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PanicumMiliaceumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Panicum miliaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PanicumMiliaceumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4540.clusters.proteins.v11.5.txt",
		        "sequence_path": "4540.protein.sequences.v11.5.fa",
		        "enrichment_path": "4540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4540.protein.info.v11.5.txt",
		        "node_list_path": "4540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MalasseziaSympodialisAtcc42132(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Malassezia sympodialis ATCC 42132 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalasseziaSympodialisAtcc42132", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230383.protein.info.v11.5.txt",
		        "node_list_path": "1230383.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusDestructans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus destructans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusDestructans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655981.protein.sequences.v11.5.fa",
		        "enrichment_path": "655981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655981.protein.info.v11.5.txt",
		        "node_list_path": "655981.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterCibariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter cibarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterCibariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1442598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1442598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1442598.clusters.proteins.v11.5.txt",
		        "sequence_path": "1442598.protein.sequences.v11.5.fa",
		        "enrichment_path": "1442598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1442598.protein.info.v11.5.txt",
		        "node_list_path": "1442598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1442598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisAlaskensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis alaskensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisAlaskensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "317655.protein.sequences.v11.5.fa",
		        "enrichment_path": "317655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317655.protein.info.v11.5.txt",
		        "node_list_path": "317655.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpCp53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Cp53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpCp53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "443598.protein.sequences.v11.5.fa",
		        "enrichment_path": "443598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443598.protein.info.v11.5.txt",
		        "node_list_path": "443598.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlantibacterFlavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plantibacter flavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlantibacterFlavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "150123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "150123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "150123.clusters.proteins.v11.5.txt",
		        "sequence_path": "150123.protein.sequences.v11.5.fa",
		        "enrichment_path": "150123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150123.protein.info.v11.5.txt",
		        "node_list_path": "150123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "150123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasHaloplanktisTb64Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis TB64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasHaloplanktisTb64Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1333507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1333507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1333507.clusters.proteins.v11.5.txt",
		        "sequence_path": "1333507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333507.protein.info.v11.5.txt",
		        "node_list_path": "1333507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1333507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9201Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9201 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9201Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93057.clusters.proteins.v11.5.txt",
		        "sequence_path": "93057.protein.sequences.v11.5.fa",
		        "enrichment_path": "93057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93057.protein.info.v11.5.txt",
		        "node_list_path": "93057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMannanilyticusJcm10596(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mannanilyticus JCM 10596 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMannanilyticusJcm10596", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236954.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236954.protein.info.v11.5.txt",
		        "node_list_path": "1236954.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusSzentirmaiiDsm16338Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus szentirmaii DSM 16338 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusSzentirmaiiDsm16338Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1427518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1427518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1427518.clusters.proteins.v11.5.txt",
		        "sequence_path": "1427518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1427518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1427518.protein.info.v11.5.txt",
		        "node_list_path": "1427518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1427518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaNorimbergensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea norimbergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaNorimbergensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93219.protein.sequences.v11.5.fa",
		        "enrichment_path": "93219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93219.protein.info.v11.5.txt",
		        "node_list_path": "93219.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4222(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_42_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4222", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798391.protein.info.v11.5.txt",
		        "node_list_path": "1798391.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlS350(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL S-350 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlS350", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463902.protein.info.v11.5.txt",
		        "node_list_path": "1463902.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuminiphilusSyltensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luminiphilus syltensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuminiphilusSyltensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "565045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "565045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "565045.clusters.proteins.v11.5.txt",
		        "sequence_path": "565045.protein.sequences.v11.5.fa",
		        "enrichment_path": "565045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565045.protein.info.v11.5.txt",
		        "node_list_path": "565045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "565045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophagaAminisulfidivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga aminisulfidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaAminisulfidivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1026882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1026882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1026882.protein.info.v11.5.txt",
		        "node_list_path": "1026882.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumCyclohexanicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium cyclohexanicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumCyclohexanicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "64702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "64702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "64702.clusters.proteins.v11.5.txt",
		        "sequence_path": "64702.protein.sequences.v11.5.fa",
		        "enrichment_path": "64702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64702.protein.info.v11.5.txt",
		        "node_list_path": "64702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "64702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaStewartiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea stewartii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaStewartiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66269.clusters.proteins.v11.5.txt",
		        "sequence_path": "66269.protein.sequences.v11.5.fa",
		        "enrichment_path": "66269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66269.protein.info.v11.5.txt",
		        "node_list_path": "66269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCarsonellaRuddiiHtIsolateThao2000(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii HT isolate Thao2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCarsonellaRuddiiHtIsolateThao2000", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1202539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202539.protein.info.v11.5.txt",
		        "node_list_path": "1202539.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolibacterUsitatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solibacter usitatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolibacterUsitatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "234267.protein.sequences.v11.5.fa",
		        "enrichment_path": "234267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "234267.protein.info.v11.5.txt",
		        "node_list_path": "234267.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanibaculumPacificum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanibaculum pacificum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanibaculumPacificum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "580166.protein.sequences.v11.5.fa",
		        "enrichment_path": "580166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "580166.protein.info.v11.5.txt",
		        "node_list_path": "580166.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag433Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:433 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag433Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262806.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262806.protein.info.v11.5.txt",
		        "node_list_path": "1262806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusVillorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus villorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusVillorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158604.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158604.protein.info.v11.5.txt",
		        "node_list_path": "1158604.protein.complete.v11.5.txt"
		    }
		]
    )()

def PapioAnubisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Papio anubis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PapioAnubisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9555.clusters.proteins.v11.5.txt",
		        "sequence_path": "9555.protein.sequences.v11.5.fa",
		        "enrichment_path": "9555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9555.protein.info.v11.5.txt",
		        "node_list_path": "9555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCrk20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCrk20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1452536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1452536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1452536.clusters.proteins.v11.5.txt",
		        "sequence_path": "1452536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1452536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1452536.protein.info.v11.5.txt",
		        "node_list_path": "1452536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1452536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliellaBurgdorferiB31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borreliella burgdorferi B31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliellaBurgdorferiB31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "224326.clusters.info.v11.5.txt",
		        "cluster_tree_path": "224326.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "224326.clusters.proteins.v11.5.txt",
		        "sequence_path": "224326.protein.sequences.v11.5.fa",
		        "enrichment_path": "224326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224326.protein.info.v11.5.txt",
		        "node_list_path": "224326.cluster.nodes.v11.5.txt",
		        "edge_list_path": "224326.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraWeiliiSerovarRanarumStrIcftCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira weilii serovar Ranarum str. ICFT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraWeiliiSerovarRanarumStrIcftCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218598.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218598.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218598.protein.info.v11.5.txt",
		        "node_list_path": "1218598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaIndica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaIndica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1159017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159017.protein.info.v11.5.txt",
		        "node_list_path": "1159017.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaematobacterMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haematobacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaematobacterMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "195105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "195105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "195105.clusters.proteins.v11.5.txt",
		        "sequence_path": "195105.protein.sequences.v11.5.fa",
		        "enrichment_path": "195105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195105.protein.info.v11.5.txt",
		        "node_list_path": "195105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "195105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MonosporascusSpMg133Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. MG133 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSpMg133Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2211645.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2211645.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2211645.clusters.proteins.v11.5.txt",
		        "sequence_path": "2211645.protein.sequences.v11.5.fa",
		        "enrichment_path": "2211645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2211645.protein.info.v11.5.txt",
		        "node_list_path": "2211645.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2211645.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAb2028(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AB2028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAb2028", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408319.protein.info.v11.5.txt",
		        "node_list_path": "1408319.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmantichitinumUrsilacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amantichitinum ursilacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmantichitinumUrsilacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "857265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "857265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "857265.clusters.proteins.v11.5.txt",
		        "sequence_path": "857265.protein.sequences.v11.5.fa",
		        "enrichment_path": "857265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857265.protein.info.v11.5.txt",
		        "node_list_path": "857265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "857265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag272(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:272 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag272", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263015.protein.info.v11.5.txt",
		        "node_list_path": "1263015.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCyaneogriseusSubspNoncyanogenus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces cyaneogriseus subsp. noncyanogenus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCyaneogriseusSubspNoncyanogenus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "477245.protein.sequences.v11.5.fa",
		        "enrichment_path": "477245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477245.protein.info.v11.5.txt",
		        "node_list_path": "477245.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfatibacillumAlkenivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfatibacillumAlkenivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "439235.protein.sequences.v11.5.fa",
		        "enrichment_path": "439235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439235.protein.info.v11.5.txt",
		        "node_list_path": "439235.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphaerulinaMusivaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaerulina musiva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerulinaMusivaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "85929.clusters.info.v11.5.txt",
		        "cluster_tree_path": "85929.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "85929.clusters.proteins.v11.5.txt",
		        "sequence_path": "85929.protein.sequences.v11.5.fa",
		        "enrichment_path": "85929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85929.protein.info.v11.5.txt",
		        "node_list_path": "85929.cluster.nodes.v11.5.txt",
		        "edge_list_path": "85929.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TessaracoccusSpZs01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus sp. ZS01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusSpZs01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906324.protein.info.v11.5.txt",
		        "node_list_path": "1906324.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerotruncusSpCag528(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. CAG:528 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotruncusSpCag528", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262700.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262700.protein.info.v11.5.txt",
		        "node_list_path": "1262700.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegasphaeraSpNp3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. NP3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraSpNp3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232428.protein.info.v11.5.txt",
		        "node_list_path": "1232428.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeptuniibacterMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neptuniibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptuniibacterMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1806670.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1806670.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1806670.clusters.proteins.v11.5.txt",
		        "sequence_path": "1806670.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806670.protein.info.v11.5.txt",
		        "node_list_path": "1806670.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1806670.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp155Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 155 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp155Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157943.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157943.protein.info.v11.5.txt",
		        "node_list_path": "1157943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExophialaSideris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exophiala sideris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaSideris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1016849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1016849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1016849.protein.info.v11.5.txt",
		        "node_list_path": "1016849.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioHarveyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio harveyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioHarveyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "669.protein.sequences.v11.5.fa",
		        "enrichment_path": "669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "669.protein.info.v11.5.txt",
		        "node_list_path": "669.protein.complete.v11.5.txt"
		    }
		]
    )()

def MuricaudaAntarcticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Muricauda antarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuricaudaAntarcticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1055723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1055723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1055723.clusters.proteins.v11.5.txt",
		        "sequence_path": "1055723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1055723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1055723.protein.info.v11.5.txt",
		        "node_list_path": "1055723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1055723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TogniniaMinimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Togninia minima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TogniniaMinimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "223192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "223192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "223192.clusters.proteins.v11.5.txt",
		        "sequence_path": "223192.protein.sequences.v11.5.fa",
		        "enrichment_path": "223192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223192.protein.info.v11.5.txt",
		        "node_list_path": "223192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "223192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls340(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS340 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls340", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463901.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463901.protein.info.v11.5.txt",
		        "node_list_path": "1463901.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseburiaSpCag182(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:182 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSpCag182", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262942.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262942.protein.info.v11.5.txt",
		        "node_list_path": "1262942.protein.complete.v11.5.txt"
		    }
		]
    )()

def ToxocaraCanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Toxocara canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ToxocaraCanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6265.clusters.proteins.v11.5.txt",
		        "sequence_path": "6265.protein.sequences.v11.5.fa",
		        "enrichment_path": "6265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6265.protein.info.v11.5.txt",
		        "node_list_path": "6265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JannaschiaSpEhc01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia sp. EhC01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaSpEhc01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849359.protein.info.v11.5.txt",
		        "node_list_path": "1849359.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaricaPapayaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carica papaya Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaricaPapayaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3649.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3649.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3649.clusters.proteins.v11.5.txt",
		        "sequence_path": "3649.protein.sequences.v11.5.fa",
		        "enrichment_path": "3649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3649.protein.info.v11.5.txt",
		        "node_list_path": "3649.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3649.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlomeribacterGigasporarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glomeribacter gigasporarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlomeribacterGigasporarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1070319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1070319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1070319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1070319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1070319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1070319.protein.info.v11.5.txt",
		        "node_list_path": "1070319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1070319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266128.protein.sequences.v11.5.fa",
		        "enrichment_path": "266128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266128.protein.info.v11.5.txt",
		        "node_list_path": "266128.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSabulinigri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sabulinigri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSabulinigri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "472181.protein.sequences.v11.5.fa",
		        "enrichment_path": "472181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472181.protein.info.v11.5.txt",
		        "node_list_path": "472181.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterArupensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter arupensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterArupensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "342002.protein.sequences.v11.5.fa",
		        "enrichment_path": "342002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342002.protein.info.v11.5.txt",
		        "node_list_path": "342002.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpLeaf48Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpLeaf48Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736221.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736221.protein.info.v11.5.txt",
		        "node_list_path": "1736221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraFaineiSerovarHurstbridgeStrBut6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira fainei serovar Hurstbridge str. BUT 6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraFaineiSerovarHurstbridgeStrBut6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193011.protein.info.v11.5.txt",
		        "node_list_path": "1193011.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldanaerobacterSubterraneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldanaerobacter subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldanaerobacterSubterraneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "273068.protein.sequences.v11.5.fa",
		        "enrichment_path": "273068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273068.protein.info.v11.5.txt",
		        "node_list_path": "273068.protein.complete.v11.5.txt"
		    }
		]
    )()

def KingellaKingaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kingella kingae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KingellaKingaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "887327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "887327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "887327.clusters.proteins.v11.5.txt",
		        "sequence_path": "887327.protein.sequences.v11.5.fa",
		        "enrichment_path": "887327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "887327.protein.info.v11.5.txt",
		        "node_list_path": "887327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "887327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwf13135Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWF1_31_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwf13135Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618600.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618600.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618600.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618600.protein.info.v11.5.txt",
		        "node_list_path": "1618600.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618600.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacterium3541Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium 35_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacterium3541Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897008.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897008.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897008.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897008.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897008.protein.info.v11.5.txt",
		        "node_list_path": "1897008.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897008.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichococcusFlocculiformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichococcus flocculiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichococcusFlocculiformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "82803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "82803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "82803.clusters.proteins.v11.5.txt",
		        "sequence_path": "82803.protein.sequences.v11.5.fa",
		        "enrichment_path": "82803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82803.protein.info.v11.5.txt",
		        "node_list_path": "82803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "82803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoriobacteriaceaeBacteriumEmtcatb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium EMTCatB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacteriaceaeBacteriumEmtcatb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1927122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1927122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1927122.clusters.proteins.v11.5.txt",
		        "sequence_path": "1927122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1927122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1927122.protein.info.v11.5.txt",
		        "node_list_path": "1927122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1927122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotorhabdusThracensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photorhabdus thracensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotorhabdusThracensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "230089.protein.sequences.v11.5.fa",
		        "enrichment_path": "230089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "230089.protein.info.v11.5.txt",
		        "node_list_path": "230089.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisMethanolica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis methanolica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisMethanolica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1068978.protein.sequences.v11.5.fa",
		        "enrichment_path": "1068978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1068978.protein.info.v11.5.txt",
		        "node_list_path": "1068978.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacterium6732(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 67-32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacterium6732", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895729.protein.info.v11.5.txt",
		        "node_list_path": "1895729.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumSodomenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum sodomense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumSodomenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35743.clusters.proteins.v11.5.txt",
		        "sequence_path": "35743.protein.sequences.v11.5.fa",
		        "enrichment_path": "35743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35743.protein.info.v11.5.txt",
		        "node_list_path": "35743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolibacillusSilvestris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solibacillus silvestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolibacillusSilvestris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1002809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002809.protein.info.v11.5.txt",
		        "node_list_path": "1002809.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumTerrigenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium terrigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumTerrigenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "402734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "402734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "402734.clusters.proteins.v11.5.txt",
		        "sequence_path": "402734.protein.sequences.v11.5.fa",
		        "enrichment_path": "402734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402734.protein.info.v11.5.txt",
		        "node_list_path": "402734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "402734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColwelliaAestuariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaAestuariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "329993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "329993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "329993.clusters.proteins.v11.5.txt",
		        "sequence_path": "329993.protein.sequences.v11.5.fa",
		        "enrichment_path": "329993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "329993.protein.info.v11.5.txt",
		        "node_list_path": "329993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "329993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetallosphaeraCuprina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metallosphaera cuprina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetallosphaeraCuprina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1006006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1006006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1006006.protein.info.v11.5.txt",
		        "node_list_path": "1006006.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylibiumSpNzg(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylibium sp. NZG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylibiumSpNzg", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1686064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686064.protein.info.v11.5.txt",
		        "node_list_path": "1686064.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpKrmcy2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. KRMCY2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpKrmcy2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304865.protein.info.v11.5.txt",
		        "node_list_path": "1304865.protein.complete.v11.5.txt"
		    }
		]
    )()

def ValsaMaliVarPyri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Valsa mali var. pyri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ValsaMaliVarPyri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "694573.protein.sequences.v11.5.fa",
		        "enrichment_path": "694573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694573.protein.info.v11.5.txt",
		        "node_list_path": "694573.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusHeilongjiangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus heilongjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHeilongjiangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1074467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1074467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1074467.clusters.proteins.v11.5.txt",
		        "sequence_path": "1074467.protein.sequences.v11.5.fa",
		        "enrichment_path": "1074467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1074467.protein.info.v11.5.txt",
		        "node_list_path": "1074467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1074467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxDieselolei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax dieselolei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxDieselolei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930169.protein.sequences.v11.5.fa",
		        "enrichment_path": "930169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930169.protein.info.v11.5.txt",
		        "node_list_path": "930169.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetschnikowiaBicuspidataVarBicuspidataNrrlYb4993Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metschnikowia bicuspidata var. bicuspidata NRRL YB-4993 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetschnikowiaBicuspidataVarBicuspidataNrrlYb4993Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "869754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "869754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "869754.clusters.proteins.v11.5.txt",
		        "sequence_path": "869754.protein.sequences.v11.5.fa",
		        "enrichment_path": "869754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869754.protein.info.v11.5.txt",
		        "node_list_path": "869754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "869754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterLwoffiiWj10621(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii WJ10621 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterLwoffiiWj10621", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1046625.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046625.protein.info.v11.5.txt",
		        "node_list_path": "1046625.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacterium4616(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 46-16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacterium4616", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895925.protein.info.v11.5.txt",
		        "node_list_path": "1895925.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerobacillusMacyaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobacillus macyae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobacillusMacyaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "157733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "157733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "157733.clusters.proteins.v11.5.txt",
		        "sequence_path": "157733.protein.sequences.v11.5.fa",
		        "enrichment_path": "157733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157733.protein.info.v11.5.txt",
		        "node_list_path": "157733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "157733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LingulaAnatina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lingula anatina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LingulaAnatina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7574.protein.sequences.v11.5.fa",
		        "enrichment_path": "7574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7574.protein.info.v11.5.txt",
		        "node_list_path": "7574.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807735.protein.info.v11.5.txt",
		        "node_list_path": "1807735.protein.complete.v11.5.txt"
		    }
		]
    )()

def WigglesworthiaGlossinidiaSpGbrCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia sp. Gbr Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WigglesworthiaGlossinidiaSpGbrCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36870.clusters.info.v11.0.txt",
		        "cluster_tree_path": "36870.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "36870.clusters.proteins.v11.0.txt",
		        "sequence_path": "36870.protein.sequences.v11.0.fa",
		        "enrichment_path": "36870.protein.enrichment.terms.v11.0.txt",
		        "info_path": "36870.protein.info.v11.0.txt",
		        "node_list_path": "36870.cluster.nodes.v11.0.txt",
		        "edge_list_path": "36870.protein.cluster.v11.0.txt"
		    }
		]
    )()

def TannerellaSpOralTaxonHot286(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tannerella sp. oral taxon HOT-286 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TannerellaSpOralTaxonHot286", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "712710.protein.sequences.v11.5.fa",
		        "enrichment_path": "712710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712710.protein.info.v11.5.txt",
		        "node_list_path": "712710.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpLf1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. LF1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpLf1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499688.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499688.protein.info.v11.5.txt",
		        "node_list_path": "1499688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapsellaRubella(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capsella rubella graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsellaRubella", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "81985.protein.sequences.v11.5.fa",
		        "enrichment_path": "81985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81985.protein.info.v11.5.txt",
		        "node_list_path": "81985.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpDmhc10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. DMHC 10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpDmhc10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "747377.protein.sequences.v11.5.fa",
		        "enrichment_path": "747377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747377.protein.info.v11.5.txt",
		        "node_list_path": "747377.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastomycesDermatitidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces dermatitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomycesDermatitidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5039.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5039.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5039.clusters.proteins.v11.5.txt",
		        "sequence_path": "5039.protein.sequences.v11.5.fa",
		        "enrichment_path": "5039.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5039.protein.info.v11.5.txt",
		        "node_list_path": "5039.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5039.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumMalaysiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium malaysiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumMalaysiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348853.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348853.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348853.protein.info.v11.5.txt",
		        "node_list_path": "1348853.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThielaviaTerrestrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thielavia terrestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThielaviaTerrestrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35720.clusters.proteins.v11.5.txt",
		        "sequence_path": "35720.protein.sequences.v11.5.fa",
		        "enrichment_path": "35720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35720.protein.info.v11.5.txt",
		        "node_list_path": "35720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphaerochaetaPleomorphaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaerochaeta pleomorpha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerochaetaPleomorphaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "158190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "158190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "158190.clusters.proteins.v11.5.txt",
		        "sequence_path": "158190.protein.sequences.v11.5.fa",
		        "enrichment_path": "158190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158190.protein.info.v11.5.txt",
		        "node_list_path": "158190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "158190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusKawachii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus kawachii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusKawachii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40384.protein.sequences.v11.5.fa",
		        "enrichment_path": "40384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40384.protein.info.v11.5.txt",
		        "node_list_path": "40384.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpCag472(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:472 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpCag472", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262904.protein.info.v11.5.txt",
		        "node_list_path": "1262904.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusSuryakundensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus suryakundensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusSuryakundensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1325335.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325335.protein.info.v11.5.txt",
		        "node_list_path": "1325335.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRbg164011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_40_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802483.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802483.protein.info.v11.5.txt",
		        "node_list_path": "1802483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FormosaHaliotisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Formosa haliotis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaHaliotisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1555194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1555194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1555194.clusters.proteins.v11.5.txt",
		        "sequence_path": "1555194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1555194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1555194.protein.info.v11.5.txt",
		        "node_list_path": "1555194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1555194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAmylolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium amylolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAmylolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121298.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121298.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121298.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121298.protein.info.v11.5.txt",
		        "node_list_path": "1121298.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121298.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusBrantaeDsm23927(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus brantae DSM 23927 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBrantaeDsm23927", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423727.protein.info.v11.5.txt",
		        "node_list_path": "1423727.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospirillumRubrumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillum rubrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillumRubrumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "269796.clusters.info.v11.5.txt",
		        "cluster_tree_path": "269796.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "269796.clusters.proteins.v11.5.txt",
		        "sequence_path": "269796.protein.sequences.v11.5.fa",
		        "enrichment_path": "269796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269796.protein.info.v11.5.txt",
		        "node_list_path": "269796.cluster.nodes.v11.5.txt",
		        "edge_list_path": "269796.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachyspiraSpCag700(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira sp. CAG:700 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraSpCag700", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262760.protein.info.v11.5.txt",
		        "node_list_path": "1262760.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpLeaf201Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf201 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpLeaf201Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735672.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735672.protein.info.v11.5.txt",
		        "node_list_path": "1735672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatenovulumMaritimumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catenovulum maritimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenovulumMaritimumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1513271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1513271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1513271.clusters.proteins.v11.5.txt",
		        "sequence_path": "1513271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1513271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1513271.protein.info.v11.5.txt",
		        "node_list_path": "1513271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1513271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1024112Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_41_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024112Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805307.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805307.protein.info.v11.5.txt",
		        "node_list_path": "1805307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag58Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag58Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262824.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262824.protein.info.v11.5.txt",
		        "node_list_path": "1262824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacterialesBacterium5955(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteriales bacterium 59-55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacterialesBacterium5955", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895690.protein.info.v11.5.txt",
		        "node_list_path": "1895690.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterSenuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter senuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterSenuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "386913.protein.sequences.v11.5.fa",
		        "enrichment_path": "386913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "386913.protein.info.v11.5.txt",
		        "node_list_path": "386913.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumArizonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium arizonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumArizonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1835702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1835702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1835702.protein.info.v11.5.txt",
		        "node_list_path": "1835702.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusParacollinoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paracollinoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParacollinoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "240427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "240427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "240427.clusters.proteins.v11.5.txt",
		        "sequence_path": "240427.protein.sequences.v11.5.fa",
		        "enrichment_path": "240427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240427.protein.info.v11.5.txt",
		        "node_list_path": "240427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "240427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumS5A14aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium S5-A14a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumS5A14aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230734.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230734.protein.info.v11.5.txt",
		        "node_list_path": "1230734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumPleistoceniumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium pleistocenium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumPleistoceniumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449343.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449343.protein.info.v11.5.txt",
		        "node_list_path": "1449343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaceaeBacteriumDtu079(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU079 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaceaeBacteriumDtu079", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671645.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671645.protein.info.v11.5.txt",
		        "node_list_path": "1671645.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusSanaruensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus sanaruensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusSanaruensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1727163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1727163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1727163.protein.info.v11.5.txt",
		        "node_list_path": "1727163.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumHoustonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium houstonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumHoustonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "146021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "146021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "146021.clusters.proteins.v11.5.txt",
		        "sequence_path": "146021.protein.sequences.v11.5.fa",
		        "enrichment_path": "146021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146021.protein.info.v11.5.txt",
		        "node_list_path": "146021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "146021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_41_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802702.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802702.protein.info.v11.5.txt",
		        "node_list_path": "1802702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaCinaraConfinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara confinis) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaCinaraConfinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1878935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1878935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1878935.protein.info.v11.5.txt",
		        "node_list_path": "1878935.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisAlkaliphilaYim80379(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis alkaliphila YIM 80379 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisAlkaliphilaYim80379", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246461.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246461.protein.info.v11.5.txt",
		        "node_list_path": "1246461.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaUrininfantis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella urininfantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaUrininfantis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871033.protein.info.v11.5.txt",
		        "node_list_path": "1871033.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRickettsiellaIsopodorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rickettsiella isopodorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRickettsiellaIsopodorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1225476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1225476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1225476.clusters.proteins.v11.5.txt",
		        "sequence_path": "1225476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225476.protein.info.v11.5.txt",
		        "node_list_path": "1225476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1225476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumHumireducensNbrc106098Dsm45392(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium humireducens NBRC 106098 DSM 45392 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumHumireducensNbrc106098Dsm45392", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223515.protein.info.v11.5.txt",
		        "node_list_path": "1223515.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfonatronovibrioHydrogenovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronovibrio hydrogenovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronovibrioHydrogenovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121413.protein.info.v11.5.txt",
		        "node_list_path": "1121413.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerosphaeraAminiphilaDsm21120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerosphaera aminiphila DSM 21120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerosphaeraAminiphilaDsm21120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120995.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120995.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120995.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120995.protein.info.v11.5.txt",
		        "node_list_path": "1120995.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120995.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycosphaerellaPiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycosphaerella pini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycosphaerellaPiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "64363.clusters.info.v11.5.txt",
		        "cluster_tree_path": "64363.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "64363.clusters.proteins.v11.5.txt",
		        "sequence_path": "64363.protein.sequences.v11.5.fa",
		        "enrichment_path": "64363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64363.protein.info.v11.5.txt",
		        "node_list_path": "64363.cluster.nodes.v11.5.txt",
		        "edge_list_path": "64363.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyadobacterKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "408657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "408657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "408657.clusters.proteins.v11.5.txt",
		        "sequence_path": "408657.protein.sequences.v11.5.fa",
		        "enrichment_path": "408657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408657.protein.info.v11.5.txt",
		        "node_list_path": "408657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "408657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalolaminaSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halolamina sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolaminaSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1480675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1480675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1480675.clusters.proteins.v11.5.txt",
		        "sequence_path": "1480675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1480675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1480675.protein.info.v11.5.txt",
		        "node_list_path": "1480675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1480675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusXiphinematobacterSpIdahoGrapeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Xiphinematobacter sp. Idaho Grape Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusXiphinematobacterSpIdahoGrapeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1704307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1704307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1704307.clusters.proteins.v11.5.txt",
		        "sequence_path": "1704307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1704307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1704307.protein.info.v11.5.txt",
		        "node_list_path": "1704307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1704307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrenobacterLuteusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crenobacter luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenobacterLuteusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1452487.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1452487.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1452487.clusters.proteins.v11.5.txt",
		        "sequence_path": "1452487.protein.sequences.v11.5.fa",
		        "enrichment_path": "1452487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1452487.protein.info.v11.5.txt",
		        "node_list_path": "1452487.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1452487.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacteralesBacteriumFibro01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacterales bacterium Fibro_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacteralesBacteriumFibro01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674899.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674899.protein.info.v11.5.txt",
		        "node_list_path": "1674899.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusGallinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusGallinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293.protein.info.v11.5.txt",
		        "node_list_path": "1293.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp14822926(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1482292.6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp14822926", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834081.protein.info.v11.5.txt",
		        "node_list_path": "1834081.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumPseudograminearumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium pseudograminearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumPseudograminearumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "101028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "101028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "101028.clusters.proteins.v11.5.txt",
		        "sequence_path": "101028.protein.sequences.v11.5.fa",
		        "enrichment_path": "101028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101028.protein.info.v11.5.txt",
		        "node_list_path": "101028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "101028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MegaseliaScalarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megaselia scalaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegaseliaScalarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36166.clusters.proteins.v11.5.txt",
		        "sequence_path": "36166.protein.sequences.v11.5.fa",
		        "enrichment_path": "36166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36166.protein.info.v11.5.txt",
		        "node_list_path": "36166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrypanosomaCruziCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma cruzi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrypanosomaCruziCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5693.clusters.proteins.v11.5.txt",
		        "sequence_path": "5693.protein.sequences.v11.5.fa",
		        "enrichment_path": "5693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5693.protein.info.v11.5.txt",
		        "node_list_path": "5693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "74547.protein.sequences.v11.5.fa",
		        "enrichment_path": "74547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74547.protein.info.v11.5.txt",
		        "node_list_path": "74547.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSp6729(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. 67-29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSp6729", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895723.protein.info.v11.5.txt",
		        "node_list_path": "1895723.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquitaleaMagnusonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquitalea magnusonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquitaleaMagnusonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "332411.protein.sequences.v11.5.fa",
		        "enrichment_path": "332411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332411.protein.info.v11.5.txt",
		        "node_list_path": "332411.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaArvensicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga arvensicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaArvensicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29529.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29529.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29529.clusters.proteins.v11.5.txt",
		        "sequence_path": "29529.protein.sequences.v11.5.fa",
		        "enrichment_path": "29529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29529.protein.info.v11.5.txt",
		        "node_list_path": "29529.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29529.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaSocranskiiVpidr56br1116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema socranskii VPIDR56BR1116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSocranskiiVpidr56br1116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125725.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125725.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125725.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125725.protein.info.v11.5.txt",
		        "node_list_path": "1125725.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125725.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GilliamellaSpNG2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gilliamella sp. N-G2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilliamellaSpNG2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1970471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970471.protein.info.v11.5.txt",
		        "node_list_path": "1970471.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumAgarivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumAgarivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1908389.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1908389.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1908389.clusters.proteins.v11.5.txt",
		        "sequence_path": "1908389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908389.protein.info.v11.5.txt",
		        "node_list_path": "1908389.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1908389.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMarginalisIcmp9505(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas marginalis ICMP 9505 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMarginalisIcmp9505", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1198317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198317.protein.info.v11.5.txt",
		        "node_list_path": "1198317.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasDokdonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasDokdonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "344882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "344882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "344882.clusters.proteins.v11.5.txt",
		        "sequence_path": "344882.protein.sequences.v11.5.fa",
		        "enrichment_path": "344882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "344882.protein.info.v11.5.txt",
		        "node_list_path": "344882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "344882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterOralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter oralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterOralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66851.clusters.proteins.v11.5.txt",
		        "sequence_path": "66851.protein.sequences.v11.5.fa",
		        "enrichment_path": "66851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66851.protein.info.v11.5.txt",
		        "node_list_path": "66851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SuhomycesTanzawaensisNrrlY17324Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Suhomyces tanzawaensis NRRL Y-17324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuhomycesTanzawaensisNrrlY17324Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "984487.clusters.info.v11.5.txt",
		        "cluster_tree_path": "984487.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "984487.clusters.proteins.v11.5.txt",
		        "sequence_path": "984487.protein.sequences.v11.5.fa",
		        "enrichment_path": "984487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "984487.protein.info.v11.5.txt",
		        "node_list_path": "984487.cluster.nodes.v11.5.txt",
		        "edge_list_path": "984487.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalothrixSpPcc7507Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC7507 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalothrixSpPcc7507Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "99598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "99598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "99598.clusters.proteins.v11.5.txt",
		        "sequence_path": "99598.protein.sequences.v11.5.fa",
		        "enrichment_path": "99598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "99598.protein.info.v11.5.txt",
		        "node_list_path": "99598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "99598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SlackiaExigua(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Slackia exigua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SlackiaExigua", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649764.protein.sequences.v11.5.fa",
		        "enrichment_path": "649764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649764.protein.info.v11.5.txt",
		        "node_list_path": "649764.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumCaspActino2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium casp-actino2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumCaspActino2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1661699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661699.protein.info.v11.5.txt",
		        "node_list_path": "1661699.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusHiraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus hirae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusHiraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "768486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "768486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "768486.clusters.proteins.v11.5.txt",
		        "sequence_path": "768486.protein.sequences.v11.5.fa",
		        "enrichment_path": "768486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768486.protein.info.v11.5.txt",
		        "node_list_path": "768486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "768486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterBilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter bilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterBilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "613026.clusters.info.v11.5.txt",
		        "cluster_tree_path": "613026.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "613026.clusters.proteins.v11.5.txt",
		        "sequence_path": "613026.protein.sequences.v11.5.fa",
		        "enrichment_path": "613026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "613026.protein.info.v11.5.txt",
		        "node_list_path": "613026.cluster.nodes.v11.5.txt",
		        "edge_list_path": "613026.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRbg134110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RBG_13_41_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRbg134110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801849.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801849.protein.info.v11.5.txt",
		        "node_list_path": "1801849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OttowiaSpOralTaxon894(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ottowia sp. oral taxon 894 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OttowiaSpOralTaxon894", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658672.protein.info.v11.5.txt",
		        "node_list_path": "1658672.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumUkl132(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium UKL13-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumUkl132", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1690485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690485.protein.info.v11.5.txt",
		        "node_list_path": "1690485.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumImcc3088(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium IMCC3088 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumImcc3088", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "876044.protein.sequences.v11.0.fa",
		        "enrichment_path": "876044.protein.enrichment.terms.v11.0.txt",
		        "info_path": "876044.protein.info.v11.0.txt",
		        "node_list_path": "876044.protein.complete.v11.0.txt"
		    }
		]
    )()

def SynergistetesBacteriumJgi0000079D21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synergistetes bacterium JGI 0000079-D21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynergistetesBacteriumJgi0000079D21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1104568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104568.protein.info.v11.5.txt",
		        "node_list_path": "1104568.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPlecoglossicidaNbrc103162Dsm15088Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas plecoglossicida NBRC 103162 DSM 15088 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPlecoglossicidaNbrc103162Dsm15088Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1215115.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1215115.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1215115.clusters.proteins.v11.5.txt",
		        "sequence_path": "1215115.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215115.protein.info.v11.5.txt",
		        "node_list_path": "1215115.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1215115.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSpRim47(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSpRim47", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1100721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1100721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1100721.protein.info.v11.5.txt",
		        "node_list_path": "1100721.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasPhyllosphaeraeFa2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas phyllosphaerae FA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasPhyllosphaeraeFa2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1090319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1090319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1090319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1090319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1090319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1090319.protein.info.v11.5.txt",
		        "node_list_path": "1090319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1090319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusYoungiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus youngiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusYoungiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "768710.protein.sequences.v11.5.fa",
		        "enrichment_path": "768710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768710.protein.info.v11.5.txt",
		        "node_list_path": "768710.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasSpLeaf131(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Leaf131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasSpLeaf131", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736270.protein.info.v11.5.txt",
		        "node_list_path": "1736270.protein.complete.v11.5.txt"
		    }
		]
    )()

def VulgatibacterIncomptus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vulgatibacter incomptus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulgatibacterIncomptus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1391653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391653.protein.info.v11.5.txt",
		        "node_list_path": "1391653.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMustelaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium mustelae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMustelaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "571915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "571915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "571915.clusters.proteins.v11.5.txt",
		        "sequence_path": "571915.protein.sequences.v11.5.fa",
		        "enrichment_path": "571915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571915.protein.info.v11.5.txt",
		        "node_list_path": "571915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "571915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShigellaSonnei53gCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shigella sonnei 53G Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShigellaSonnei53gCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216599.clusters.proteins.v11.5.txt",
		        "sequence_path": "216599.protein.sequences.v11.5.fa",
		        "enrichment_path": "216599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216599.protein.info.v11.5.txt",
		        "node_list_path": "216599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAquaticusDsm21051Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus aquaticus DSM 21051 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAquaticusDsm21051Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423725.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423725.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423725.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423725.protein.info.v11.5.txt",
		        "node_list_path": "1423725.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423725.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusMundtii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus mundtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusMundtii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1300150.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300150.protein.info.v11.5.txt",
		        "node_list_path": "1300150.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusProvidenciaSiddallii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Providencia siddallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusProvidenciaSiddallii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1715285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715285.protein.info.v11.5.txt",
		        "node_list_path": "1715285.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteralesBacteriumAlpha01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium Alpha_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteralesBacteriumAlpha01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674810.protein.info.v11.5.txt",
		        "node_list_path": "1674810.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpJ14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. J14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpJ14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935845.clusters.proteins.v11.5.txt",
		        "sequence_path": "935845.protein.sequences.v11.5.fa",
		        "enrichment_path": "935845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935845.protein.info.v11.5.txt",
		        "node_list_path": "935845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusSpLm3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. LM3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusSpLm3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1938608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1938608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1938608.clusters.proteins.v11.5.txt",
		        "sequence_path": "1938608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938608.protein.info.v11.5.txt",
		        "node_list_path": "1938608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1938608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusHorneckiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus horneckiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHorneckiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "549687.protein.sequences.v11.5.fa",
		        "enrichment_path": "549687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "549687.protein.info.v11.5.txt",
		        "node_list_path": "549687.protein.complete.v11.5.txt"
		    }
		]
    )()

def BursaphelenchusXylophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bursaphelenchus xylophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BursaphelenchusXylophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6326.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6326.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6326.clusters.proteins.v11.5.txt",
		        "sequence_path": "6326.protein.sequences.v11.5.fa",
		        "enrichment_path": "6326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6326.protein.info.v11.5.txt",
		        "node_list_path": "6326.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6326.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpragueaLophii42110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spraguea lophii 42_110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpragueaLophii42110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1358809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1358809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1358809.clusters.proteins.v11.5.txt",
		        "sequence_path": "1358809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1358809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1358809.protein.info.v11.5.txt",
		        "node_list_path": "1358809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1358809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BabesiaEqui(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Babesia equi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BabesiaEqui", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5872.protein.sequences.v11.5.fa",
		        "enrichment_path": "5872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5872.protein.info.v11.5.txt",
		        "node_list_path": "5872.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterJaachiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter jaachi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterJaachiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1677920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1677920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1677920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1677920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1677920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1677920.protein.info.v11.5.txt",
		        "node_list_path": "1677920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1677920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBohemicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bohemicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBohemicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437606.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437606.protein.info.v11.5.txt",
		        "node_list_path": "1437606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpLeaf307Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Leaf307 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpLeaf307Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736331.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736331.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736331.protein.info.v11.5.txt",
		        "node_list_path": "1736331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpKks102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. KKS102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpKks102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "358220.clusters.info.v11.5.txt",
		        "cluster_tree_path": "358220.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "358220.clusters.proteins.v11.5.txt",
		        "sequence_path": "358220.protein.sequences.v11.5.fa",
		        "enrichment_path": "358220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "358220.protein.info.v11.5.txt",
		        "node_list_path": "358220.cluster.nodes.v11.5.txt",
		        "edge_list_path": "358220.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfurobacteriumThermolithotrophumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurobacterium thermolithotrophum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurobacteriumThermolithotrophumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "868864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "868864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "868864.clusters.proteins.v11.5.txt",
		        "sequence_path": "868864.protein.sequences.v11.5.fa",
		        "enrichment_path": "868864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "868864.protein.info.v11.5.txt",
		        "node_list_path": "868864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "868864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PygoscelisAdeliaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pygoscelis adeliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PygoscelisAdeliaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9238.clusters.proteins.v11.5.txt",
		        "sequence_path": "9238.protein.sequences.v11.5.fa",
		        "enrichment_path": "9238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9238.protein.info.v11.5.txt",
		        "node_list_path": "9238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ApteryxOweniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Apteryx owenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApteryxOweniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8824.clusters.proteins.v11.5.txt",
		        "sequence_path": "8824.protein.sequences.v11.5.fa",
		        "enrichment_path": "8824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8824.protein.info.v11.5.txt",
		        "node_list_path": "8824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumSpUch001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. UCH001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumSpUch001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1581011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581011.protein.info.v11.5.txt",
		        "node_list_path": "1581011.protein.complete.v11.5.txt"
		    }
		]
    )()

def VaribaculumCambrienseDsm15806Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum cambriense DSM15806 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaribaculumCambrienseDsm15806Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123488.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123488.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123488.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123488.protein.info.v11.5.txt",
		        "node_list_path": "1123488.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123488.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PucciniaGraminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Puccinia graminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PucciniaGraminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5297.protein.sequences.v11.5.fa",
		        "enrichment_path": "5297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5297.protein.info.v11.5.txt",
		        "node_list_path": "5297.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumAlkaliphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum alkaliphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumAlkaliphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121423.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121423.protein.info.v11.5.txt",
		        "node_list_path": "1121423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProvidenciaHeimbachae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Providencia heimbachae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaHeimbachae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "333962.protein.sequences.v11.5.fa",
		        "enrichment_path": "333962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "333962.protein.info.v11.5.txt",
		        "node_list_path": "333962.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpRoot52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Root52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpRoot52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736552.protein.info.v11.5.txt",
		        "node_list_path": "1736552.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumSpSma27(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium sp. SMA-27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumSpSma27", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1495336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495336.protein.info.v11.5.txt",
		        "node_list_path": "1495336.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAgalactiae14628Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae 14628 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAgalactiae14628Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1110504.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1110504.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1110504.clusters.proteins.v11.5.txt",
		        "sequence_path": "1110504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1110504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1110504.protein.info.v11.5.txt",
		        "node_list_path": "1110504.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1110504.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPuniciscabieiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces puniciscabiei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPuniciscabieiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "164348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "164348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "164348.clusters.proteins.v11.5.txt",
		        "sequence_path": "164348.protein.sequences.v11.5.fa",
		        "enrichment_path": "164348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "164348.protein.info.v11.5.txt",
		        "node_list_path": "164348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "164348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrassicaOleracea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brassica oleracea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrassicaOleracea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3712.protein.sequences.v11.5.fa",
		        "enrichment_path": "3712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3712.protein.info.v11.5.txt",
		        "node_list_path": "3712.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaBombiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella bombi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaBombiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1505725.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1505725.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1505725.clusters.proteins.v11.5.txt",
		        "sequence_path": "1505725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505725.protein.info.v11.5.txt",
		        "node_list_path": "1505725.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1505725.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSanguinisSk49(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSanguinisSk49", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888808.protein.sequences.v11.5.fa",
		        "enrichment_path": "888808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888808.protein.info.v11.5.txt",
		        "node_list_path": "888808.protein.complete.v11.5.txt"
		    }
		]
    )()

def CastellaniellaDefragransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Castellaniella defragrans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CastellaniellaDefragransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437824.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437824.protein.info.v11.5.txt",
		        "node_list_path": "1437824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RicinusCommunisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ricinus communis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RicinusCommunisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3988.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3988.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3988.clusters.proteins.v11.5.txt",
		        "sequence_path": "3988.protein.sequences.v11.5.fa",
		        "enrichment_path": "3988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3988.protein.info.v11.5.txt",
		        "node_list_path": "3988.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3988.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAzambacteriaBacteriumRifcsplowo201Full4626Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPLOWO2_01_FULL_46_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsplowo201Full4626Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797299.protein.info.v11.5.txt",
		        "node_list_path": "1797299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlenkiaTaihuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klenkia taihuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlenkiaTaihuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1225127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1225127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1225127.clusters.proteins.v11.5.txt",
		        "sequence_path": "1225127.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225127.protein.info.v11.5.txt",
		        "node_list_path": "1225127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1225127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusIniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus iniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusIniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1346.clusters.proteins.v11.5.txt",
		        "sequence_path": "1346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346.protein.info.v11.5.txt",
		        "node_list_path": "1346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1294143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294143.protein.info.v11.5.txt",
		        "node_list_path": "1294143.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnt318Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT318 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnt318Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288079.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288079.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288079.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288079.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288079.protein.info.v11.5.txt",
		        "node_list_path": "1288079.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288079.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf117Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf117Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736260.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736260.protein.info.v11.5.txt",
		        "node_list_path": "1736260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacillusPleuropneumoniae5bL20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae 5b L20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusPleuropneumoniae5bL20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "416269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "416269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "416269.clusters.proteins.v11.5.txt",
		        "sequence_path": "416269.protein.sequences.v11.5.fa",
		        "enrichment_path": "416269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416269.protein.info.v11.5.txt",
		        "node_list_path": "416269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "416269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpZor0019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. ZOR0019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpZor0019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1339233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1339233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1339233.protein.info.v11.5.txt",
		        "node_list_path": "1339233.protein.complete.v11.5.txt"
		    }
		]
    )()

def QuadrisphaeraSpDsm44207(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Quadrisphaera sp. DSM 44207 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "QuadrisphaeraSpDsm44207", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881057.protein.info.v11.5.txt",
		        "node_list_path": "1881057.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprinopsisMarcescibilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprinopsis marcescibilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprinopsisMarcescibilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "230819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "230819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "230819.clusters.proteins.v11.5.txt",
		        "sequence_path": "230819.protein.sequences.v11.5.fa",
		        "enrichment_path": "230819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "230819.protein.info.v11.5.txt",
		        "node_list_path": "230819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "230819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PneumocystisJiroveciiSe8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii SE8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PneumocystisJiroveciiSe8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1209962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1209962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1209962.clusters.proteins.v11.5.txt",
		        "sequence_path": "1209962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1209962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1209962.protein.info.v11.5.txt",
		        "node_list_path": "1209962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1209962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonasAustralica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas australica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasAustralica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "589873.protein.sequences.v11.5.fa",
		        "enrichment_path": "589873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "589873.protein.info.v11.5.txt",
		        "node_list_path": "589873.protein.complete.v11.5.txt"
		    }
		]
    )()

def AminicenantesBacteriumAaa252a02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium AAA252A02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "AminicenantesBacteriumAaa252a02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1047013.protein.sequences.v11.0.fa",
		        "enrichment_path": "1047013.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1047013.protein.info.v11.0.txt",
		        "node_list_path": "1047013.protein.complete.v11.0.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumWds1c4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium WDS1C4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumWds1c4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1914408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1914408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1914408.clusters.proteins.v11.5.txt",
		        "sequence_path": "1914408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1914408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1914408.protein.info.v11.5.txt",
		        "node_list_path": "1914408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1914408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LonsdaleaBritannicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lonsdalea britannica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LonsdaleaBritannicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1082704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1082704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1082704.clusters.proteins.v11.5.txt",
		        "sequence_path": "1082704.protein.sequences.v11.5.fa",
		        "enrichment_path": "1082704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1082704.protein.info.v11.5.txt",
		        "node_list_path": "1082704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1082704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMarithrixSpCanyon246Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Marithrix sp. Canyon 246 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMarithrixSpCanyon246Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1827136.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1827136.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1827136.clusters.proteins.v11.5.txt",
		        "sequence_path": "1827136.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827136.protein.info.v11.5.txt",
		        "node_list_path": "1827136.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1827136.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9302Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9302 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9302Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "74545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "74545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "74545.clusters.proteins.v11.5.txt",
		        "sequence_path": "74545.protein.sequences.v11.5.fa",
		        "enrichment_path": "74545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74545.protein.info.v11.5.txt",
		        "node_list_path": "74545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "74545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TremaOrientale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trema orientale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TremaOrientale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "63057.protein.sequences.v11.5.fa",
		        "enrichment_path": "63057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63057.protein.info.v11.5.txt",
		        "node_list_path": "63057.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPhytoplasmaAurantifolia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma aurantifolia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPhytoplasmaAurantifolia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "180978.protein.sequences.v11.5.fa",
		        "enrichment_path": "180978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180978.protein.info.v11.5.txt",
		        "node_list_path": "180978.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsplowo202Full4812(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_02_FULL_48_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo202Full4812", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802407.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802407.protein.info.v11.5.txt",
		        "node_list_path": "1802407.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasCanoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas canoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasCanoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36875.protein.sequences.v11.5.fa",
		        "enrichment_path": "36875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36875.protein.info.v11.5.txt",
		        "node_list_path": "36875.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylacidiphilumKamchatkenseKam1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylacidiphilum kamchatkense Kam1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylacidiphilumKamchatkenseKam1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1202785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1202785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1202785.clusters.proteins.v11.5.txt",
		        "sequence_path": "1202785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202785.protein.info.v11.5.txt",
		        "node_list_path": "1202785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1202785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioSpEjy3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. EJY3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpEjy3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1116375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116375.protein.info.v11.5.txt",
		        "node_list_path": "1116375.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesParvulusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces parvulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesParvulusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "146923.clusters.info.v11.5.txt",
		        "cluster_tree_path": "146923.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "146923.clusters.proteins.v11.5.txt",
		        "sequence_path": "146923.protein.sequences.v11.5.fa",
		        "enrichment_path": "146923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146923.protein.info.v11.5.txt",
		        "node_list_path": "146923.cluster.nodes.v11.5.txt",
		        "edge_list_path": "146923.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KoribacterVersatilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Koribacter versatilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KoribacterVersatilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "204669.clusters.info.v11.5.txt",
		        "cluster_tree_path": "204669.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "204669.clusters.proteins.v11.5.txt",
		        "sequence_path": "204669.protein.sequences.v11.5.fa",
		        "enrichment_path": "204669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "204669.protein.info.v11.5.txt",
		        "node_list_path": "204669.cluster.nodes.v11.5.txt",
		        "edge_list_path": "204669.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpBsc265(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. BSC265 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpBsc265", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1549812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1549812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1549812.protein.info.v11.5.txt",
		        "node_list_path": "1549812.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifoxyb1Full4711Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFOXYB1_FULL_47_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifoxyb1Full4711Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798401.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798401.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798401.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798401.protein.info.v11.5.txt",
		        "node_list_path": "1798401.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798401.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumCg1023112(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_31_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg1023112", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805280.protein.info.v11.5.txt",
		        "node_list_path": "1805280.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSp113p3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. 113P3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSp113p3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "292913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "292913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "292913.clusters.proteins.v11.5.txt",
		        "sequence_path": "292913.protein.sequences.v11.5.fa",
		        "enrichment_path": "292913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292913.protein.info.v11.5.txt",
		        "node_list_path": "292913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "292913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeopsychrobacterElectrodiphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geopsychrobacter electrodiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeopsychrobacterElectrodiphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121918.protein.info.v11.5.txt",
		        "node_list_path": "1121918.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusNageliiDsm13675Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nagelii DSM 13675 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusNageliiDsm13675Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122150.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122150.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122150.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122150.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122150.protein.info.v11.5.txt",
		        "node_list_path": "1122150.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122150.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusNovofumigatusIbt16806Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus novofumigatus IBT 16806 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusNovofumigatusIbt16806Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392255.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392255.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392255.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392255.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392255.protein.info.v11.5.txt",
		        "node_list_path": "1392255.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392255.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassomonasActiniarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassomonas actiniarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassomonasActiniarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "485447.clusters.info.v11.5.txt",
		        "cluster_tree_path": "485447.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "485447.clusters.proteins.v11.5.txt",
		        "sequence_path": "485447.protein.sequences.v11.5.fa",
		        "enrichment_path": "485447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485447.protein.info.v11.5.txt",
		        "node_list_path": "485447.cluster.nodes.v11.5.txt",
		        "edge_list_path": "485447.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpAed(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. AED graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpAed", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423323.protein.info.v11.5.txt",
		        "node_list_path": "1423323.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag798(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:798 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag798", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262841.protein.info.v11.5.txt",
		        "node_list_path": "1262841.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpGa1999Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1999 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpGa1999Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1772275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1772275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1772275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1772275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772275.protein.info.v11.5.txt",
		        "node_list_path": "1772275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1772275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpB1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. B1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpB1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1938756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1938756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1938756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1938756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938756.protein.info.v11.5.txt",
		        "node_list_path": "1938756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1938756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpWmmb322(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. WMMB 322 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpWmmb322", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1286821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286821.protein.info.v11.5.txt",
		        "node_list_path": "1286821.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlexithrixDorotheae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flexithrix dorotheae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlexithrixDorotheae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121904.protein.info.v11.5.txt",
		        "node_list_path": "1121904.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf357(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf357", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736350.protein.info.v11.5.txt",
		        "node_list_path": "1736350.protein.complete.v11.5.txt"
		    }
		]
    )()

def FacklamiaLanguidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Facklamia languida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FacklamiaLanguidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883113.clusters.proteins.v11.5.txt",
		        "sequence_path": "883113.protein.sequences.v11.5.fa",
		        "enrichment_path": "883113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883113.protein.info.v11.5.txt",
		        "node_list_path": "883113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfuromusaKysingii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromusa kysingii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromusaKysingii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37625.protein.sequences.v11.5.fa",
		        "enrichment_path": "37625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37625.protein.info.v11.5.txt",
		        "node_list_path": "37625.protein.complete.v11.5.txt"
		    }
		]
    )()

def PiriformosporaIndica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Piriformospora indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiriformosporaIndica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "65672.protein.sequences.v11.5.fa",
		        "enrichment_path": "65672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65672.protein.info.v11.5.txt",
		        "node_list_path": "65672.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoproteusTenaxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoproteus tenax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoproteusTenaxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "768679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "768679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "768679.clusters.proteins.v11.5.txt",
		        "sequence_path": "768679.protein.sequences.v11.5.fa",
		        "enrichment_path": "768679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768679.protein.info.v11.5.txt",
		        "node_list_path": "768679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "768679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GloeophyllumTrabeumAtcc11539Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gloeophyllum trabeum ATCC 11539 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeophyllumTrabeumAtcc11539Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "670483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "670483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "670483.clusters.proteins.v11.5.txt",
		        "sequence_path": "670483.protein.sequences.v11.5.fa",
		        "enrichment_path": "670483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670483.protein.info.v11.5.txt",
		        "node_list_path": "670483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "670483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpF0040Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0040 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpF0040Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035197.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035197.protein.info.v11.5.txt",
		        "node_list_path": "1035197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeomicrobiumSpJcm19055Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM 19055 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeomicrobiumSpJcm19055Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1460649.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1460649.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1460649.clusters.proteins.v11.5.txt",
		        "sequence_path": "1460649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460649.protein.info.v11.5.txt",
		        "node_list_path": "1460649.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1460649.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SandarakinorhabdusLimnophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sandarakinorhabdus limnophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SandarakinorhabdusLimnophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123240.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123240.protein.info.v11.5.txt",
		        "node_list_path": "1123240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoplasmatalesArchaeonSm150(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon SM1-50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmatalesArchaeonSm150", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803815.protein.info.v11.5.txt",
		        "node_list_path": "1803815.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteimonasAbyssi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas abyssi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteimonasAbyssi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1247514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1247514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1247514.protein.info.v11.5.txt",
		        "node_list_path": "1247514.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhycicoccusSpSoil748Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Soil748 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycicoccusSpSoil748Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736397.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736397.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736397.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736397.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736397.protein.info.v11.5.txt",
		        "node_list_path": "1736397.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736397.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCompostiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus composti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCompostiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423734.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423734.protein.info.v11.5.txt",
		        "node_list_path": "1423734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifcsplowo201Full5118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_01_FULL_51_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo201Full5118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801925.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801925.protein.info.v11.5.txt",
		        "node_list_path": "1801925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsplowo202Full5016Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_02_FULL_50_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo202Full5016Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797881.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797881.protein.info.v11.5.txt",
		        "node_list_path": "1797881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinivibrioSpEs052Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio sp. ES.052 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivibrioSpEs052Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882823.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882823.protein.info.v11.5.txt",
		        "node_list_path": "1882823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZunongwangiaProfundaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zunongwangia profunda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZunongwangiaProfundaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655815.clusters.proteins.v11.5.txt",
		        "sequence_path": "655815.protein.sequences.v11.5.fa",
		        "enrichment_path": "655815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655815.protein.info.v11.5.txt",
		        "node_list_path": "655815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PucciniaTriticina11BbbdRace1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Puccinia triticina 1-1 BBBD Race 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PucciniaTriticina11BbbdRace1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "630390.protein.sequences.v11.5.fa",
		        "enrichment_path": "630390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "630390.protein.info.v11.5.txt",
		        "node_list_path": "630390.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusParacaseiAtcc334(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paracasei ATCC 334 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParacaseiAtcc334", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321967.protein.sequences.v11.5.fa",
		        "enrichment_path": "321967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321967.protein.info.v11.5.txt",
		        "node_list_path": "321967.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAppendicisCip107643(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium appendicis CIP 107643 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAppendicisCip107643", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1161099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1161099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1161099.protein.info.v11.5.txt",
		        "node_list_path": "1161099.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfonatronovibrioMagnus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronovibrio magnus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronovibrioMagnus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "698827.protein.sequences.v11.5.fa",
		        "enrichment_path": "698827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698827.protein.info.v11.5.txt",
		        "node_list_path": "698827.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf469(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf469 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf469", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736387.protein.info.v11.5.txt",
		        "node_list_path": "1736387.protein.complete.v11.5.txt"
		    }
		]
    )()

def TraorellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Traorella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TraorellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1903263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1903263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1903263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1903263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903263.protein.info.v11.5.txt",
		        "node_list_path": "1903263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1903263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerriglobusSpTaa43(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terriglobus sp. TAA 43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerriglobusSpTaa43", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "278961.protein.sequences.v11.5.fa",
		        "enrichment_path": "278961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278961.protein.info.v11.5.txt",
		        "node_list_path": "278961.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeucaenae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leucaenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeucaenae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041147.protein.info.v11.5.txt",
		        "node_list_path": "1041147.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterKyonggiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter kyonggiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterKyonggiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "595670.protein.sequences.v11.5.fa",
		        "enrichment_path": "595670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595670.protein.info.v11.5.txt",
		        "node_list_path": "595670.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetallibacteriumScheffleri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metallibacterium scheffleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetallibacteriumScheffleri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "993689.protein.sequences.v11.5.fa",
		        "enrichment_path": "993689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "993689.protein.info.v11.5.txt",
		        "node_list_path": "993689.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaVacuolataZ761(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina vacuolata Z-761 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaVacuolataZ761", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434123.protein.info.v11.5.txt",
		        "node_list_path": "1434123.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsaiaAstilbisJcm15831Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asaia astilbis JCM 15831 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsaiaAstilbisJcm15831Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236500.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236500.protein.info.v11.5.txt",
		        "node_list_path": "1236500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CulexQuinquefasciatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Culex quinquefasciatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CulexQuinquefasciatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7176.protein.sequences.v11.5.fa",
		        "enrichment_path": "7176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7176.protein.info.v11.5.txt",
		        "node_list_path": "7176.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirosomaPanaciterraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma panaciterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaPanaciterraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123277.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123277.protein.info.v11.5.txt",
		        "node_list_path": "1123277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeucosporidiumCreatinivorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucosporidium creatinivorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucosporidiumCreatinivorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "106004.protein.sequences.v11.5.fa",
		        "enrichment_path": "106004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106004.protein.info.v11.5.txt",
		        "node_list_path": "106004.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacterium6920(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium 69-20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacterium6920", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895696.protein.info.v11.5.txt",
		        "node_list_path": "1895696.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpCcge1002(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpCcge1002", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "640511.protein.sequences.v11.5.fa",
		        "enrichment_path": "640511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640511.protein.info.v11.5.txt",
		        "node_list_path": "640511.protein.complete.v11.5.txt"
		    }
		]
    )()

def WohlfahrtiimonasChitiniclasticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas chitiniclastica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WohlfahrtiimonasChitiniclasticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123502.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123502.protein.info.v11.5.txt",
		        "node_list_path": "1123502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaAobensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia aobensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAobensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206720.protein.info.v11.5.txt",
		        "node_list_path": "1206720.protein.complete.v11.5.txt"
		    }
		]
    )()

def HungateiclostridiaceaeBacteriumKb18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hungateiclostridiaceae bacterium KB18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HungateiclostridiaceaeBacteriumKb18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834198.protein.info.v11.5.txt",
		        "node_list_path": "1834198.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerpetosiphonGeysericolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herpetosiphon geysericola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerpetosiphonGeysericolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "70996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "70996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "70996.clusters.proteins.v11.5.txt",
		        "sequence_path": "70996.protein.sequences.v11.5.fa",
		        "enrichment_path": "70996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "70996.protein.info.v11.5.txt",
		        "node_list_path": "70996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "70996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GulbenkianiaIndica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gulbenkiania indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GulbenkianiaIndica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "375574.protein.sequences.v11.5.fa",
		        "enrichment_path": "375574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375574.protein.info.v11.5.txt",
		        "node_list_path": "375574.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesIndicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesIndicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "417292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "417292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "417292.clusters.proteins.v11.5.txt",
		        "sequence_path": "417292.protein.sequences.v11.5.fa",
		        "enrichment_path": "417292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "417292.protein.info.v11.5.txt",
		        "node_list_path": "417292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "417292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrametesCoccineaBrfm310(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trametes coccinea BRFM310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrametesCoccineaBrfm310", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1353009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353009.protein.info.v11.5.txt",
		        "node_list_path": "1353009.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoactinomycesDaqus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoactinomyces daqus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoactinomycesDaqus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1329516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1329516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1329516.protein.info.v11.5.txt",
		        "node_list_path": "1329516.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumLlx17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium LLX17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumLlx17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229203.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229203.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229203.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229203.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229203.protein.info.v11.5.txt",
		        "node_list_path": "1229203.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229203.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlivibacterSitiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olivibacter sitiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlivibacterSitiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122621.protein.info.v11.5.txt",
		        "node_list_path": "1122621.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusPseudintermediusHku1003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus pseudintermedius HKU10-03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusPseudintermediusHku1003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "937773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "937773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "937773.clusters.proteins.v11.5.txt",
		        "sequence_path": "937773.protein.sequences.v11.5.fa",
		        "enrichment_path": "937773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937773.protein.info.v11.5.txt",
		        "node_list_path": "937773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "937773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTriplexCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium triplex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTriplexCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47839.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47839.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47839.clusters.proteins.v11.5.txt",
		        "sequence_path": "47839.protein.sequences.v11.5.fa",
		        "enrichment_path": "47839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47839.protein.info.v11.5.txt",
		        "node_list_path": "47839.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47839.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusVariansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus varians Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusVariansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1145276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1145276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1145276.clusters.proteins.v11.5.txt",
		        "sequence_path": "1145276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1145276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1145276.protein.info.v11.5.txt",
		        "node_list_path": "1145276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1145276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedOscillibacterSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Oscillibacter sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedOscillibacterSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "876091.clusters.info.v11.5.txt",
		        "cluster_tree_path": "876091.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "876091.clusters.proteins.v11.5.txt",
		        "sequence_path": "876091.protein.sequences.v11.5.fa",
		        "enrichment_path": "876091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "876091.protein.info.v11.5.txt",
		        "node_list_path": "876091.cluster.nodes.v11.5.txt",
		        "edge_list_path": "876091.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeonGw2011Ar10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return archaeon GW2011_AR10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeonGw2011Ar10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1579370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579370.protein.info.v11.5.txt",
		        "node_list_path": "1579370.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpLeaf127Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf127 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpLeaf127Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736267.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736267.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736267.protein.info.v11.5.txt",
		        "node_list_path": "1736267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinimicrobiumTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinimicrobium terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinimicrobiumTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123234.protein.info.v11.5.txt",
		        "node_list_path": "1123234.protein.complete.v11.5.txt"
		    }
		]
    )()

def KlebsiellaPneumoniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaPneumoniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573.clusters.proteins.v11.5.txt",
		        "sequence_path": "573.protein.sequences.v11.5.fa",
		        "enrichment_path": "573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573.protein.info.v11.5.txt",
		        "node_list_path": "573.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiaBacteriumJgi0000039D08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium JGI 0000039-D08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiaBacteriumJgi0000039D08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1047055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1047055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1047055.clusters.proteins.v11.5.txt",
		        "sequence_path": "1047055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1047055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1047055.protein.info.v11.5.txt",
		        "node_list_path": "1047055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1047055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAbscessus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium abscessus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAbscessus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36809.protein.sequences.v11.5.fa",
		        "enrichment_path": "36809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36809.protein.info.v11.5.txt",
		        "node_list_path": "36809.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaFonticolaRb25Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia fonticola RB25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaFonticolaRb25Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1441930.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1441930.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1441930.clusters.proteins.v11.5.txt",
		        "sequence_path": "1441930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1441930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1441930.protein.info.v11.5.txt",
		        "node_list_path": "1441930.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1441930.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb1468(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_46_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb1468", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618880.protein.info.v11.5.txt",
		        "node_list_path": "1618880.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaMicansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella micans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMicansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883158.clusters.proteins.v11.5.txt",
		        "sequence_path": "883158.protein.sequences.v11.5.fa",
		        "enrichment_path": "883158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883158.protein.info.v11.5.txt",
		        "node_list_path": "883158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioMagneticusRs1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio magneticus RS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioMagneticusRs1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573370.protein.sequences.v11.5.fa",
		        "enrichment_path": "573370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573370.protein.info.v11.5.txt",
		        "node_list_path": "573370.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycesBrasiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycesBrasiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "756272.protein.sequences.v11.5.fa",
		        "enrichment_path": "756272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "756272.protein.info.v11.5.txt",
		        "node_list_path": "756272.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSubsaxonicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium subsaxonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSubsaxonicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121898.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121898.protein.info.v11.5.txt",
		        "node_list_path": "1121898.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxBorkumensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax borkumensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxBorkumensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "393595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "393595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "393595.clusters.proteins.v11.5.txt",
		        "sequence_path": "393595.protein.sequences.v11.5.fa",
		        "enrichment_path": "393595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393595.protein.info.v11.5.txt",
		        "node_list_path": "393595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "393595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButtiauxellaAgrestis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buttiauxella agrestis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButtiauxellaAgrestis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1006004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1006004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1006004.protein.info.v11.5.txt",
		        "node_list_path": "1006004.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulosimicrobiumSpTh20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulosimicrobium sp. TH-20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulosimicrobiumSpTh20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1980001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1980001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1980001.clusters.proteins.v11.5.txt",
		        "sequence_path": "1980001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1980001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1980001.protein.info.v11.5.txt",
		        "node_list_path": "1980001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1980001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AphanizomenonFlosAquaeUkl13Pb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aphanizomenon flos-aquae UKL13-PB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AphanizomenonFlosAquaeUkl13Pb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803587.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803587.protein.info.v11.5.txt",
		        "node_list_path": "1803587.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMycoplasmaHaemobosCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemobos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMycoplasmaHaemobosCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "432608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "432608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "432608.clusters.proteins.v11.5.txt",
		        "sequence_path": "432608.protein.sequences.v11.5.fa",
		        "enrichment_path": "432608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "432608.protein.info.v11.5.txt",
		        "node_list_path": "432608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "432608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpCag776(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:776 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpCag776", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262906.protein.info.v11.5.txt",
		        "node_list_path": "1262906.protein.complete.v11.5.txt"
		    }
		]
    )()

def HenriciellaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Henriciella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HenriciellaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121949.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121949.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121949.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121949.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121949.protein.info.v11.5.txt",
		        "node_list_path": "1121949.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121949.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfonatronovibrioMagnusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronovibrio magnus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronovibrioMagnusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "698827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "698827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "698827.clusters.proteins.v11.5.txt",
		        "sequence_path": "698827.protein.sequences.v11.5.fa",
		        "enrichment_path": "698827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698827.protein.info.v11.5.txt",
		        "node_list_path": "698827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "698827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastomycesDermatitidisEr3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces dermatitidis ER-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomycesDermatitidisEr3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "559297.clusters.info.v11.5.txt",
		        "cluster_tree_path": "559297.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "559297.clusters.proteins.v11.5.txt",
		        "sequence_path": "559297.protein.sequences.v11.5.fa",
		        "enrichment_path": "559297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559297.protein.info.v11.5.txt",
		        "node_list_path": "559297.cluster.nodes.v11.5.txt",
		        "edge_list_path": "559297.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OpisthorchisFelineusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Opisthorchis felineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpisthorchisFelineusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "147828.clusters.info.v11.5.txt",
		        "cluster_tree_path": "147828.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "147828.clusters.proteins.v11.5.txt",
		        "sequence_path": "147828.protein.sequences.v11.5.fa",
		        "enrichment_path": "147828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "147828.protein.info.v11.5.txt",
		        "node_list_path": "147828.cluster.nodes.v11.5.txt",
		        "edge_list_path": "147828.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraCrunogena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira crunogena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraCrunogena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "317025.protein.sequences.v11.5.fa",
		        "enrichment_path": "317025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317025.protein.info.v11.5.txt",
		        "node_list_path": "317025.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioCaribbeanicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio caribbeanicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCaribbeanicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "796620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "796620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "796620.clusters.proteins.v11.5.txt",
		        "sequence_path": "796620.protein.sequences.v11.5.fa",
		        "enrichment_path": "796620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796620.protein.info.v11.5.txt",
		        "node_list_path": "796620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "796620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterSaguiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter saguini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSaguiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1548018.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1548018.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1548018.clusters.proteins.v11.5.txt",
		        "sequence_path": "1548018.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548018.protein.info.v11.5.txt",
		        "node_list_path": "1548018.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1548018.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaAgglomeransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea agglomerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaAgglomeransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "549.clusters.proteins.v11.5.txt",
		        "sequence_path": "549.protein.sequences.v11.5.fa",
		        "enrichment_path": "549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "549.protein.info.v11.5.txt",
		        "node_list_path": "549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioNeptunius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio neptunius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioNeptunius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "170651.protein.sequences.v11.5.fa",
		        "enrichment_path": "170651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "170651.protein.info.v11.5.txt",
		        "node_list_path": "170651.protein.complete.v11.5.txt"
		    }
		]
    )()

def AegilopsTauschiiSubspStrangulata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aegilops tauschii subsp. strangulata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AegilopsTauschiiSubspStrangulata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "200361.protein.sequences.v11.5.fa",
		        "enrichment_path": "200361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200361.protein.info.v11.5.txt",
		        "node_list_path": "200361.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaSp9096(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. 9096 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSp9096", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500894.protein.info.v11.5.txt",
		        "node_list_path": "1500894.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpAp50(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. AP50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpAp50", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884369.protein.info.v11.5.txt",
		        "node_list_path": "1884369.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosotenuisUzonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis uzonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosotenuisUzonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1407055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1407055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1407055.clusters.proteins.v11.5.txt",
		        "sequence_path": "1407055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1407055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1407055.protein.info.v11.5.txt",
		        "node_list_path": "1407055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1407055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoplasmaAcidophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasma acidophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmaAcidophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "273075.clusters.info.v11.5.txt",
		        "cluster_tree_path": "273075.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "273075.clusters.proteins.v11.5.txt",
		        "sequence_path": "273075.protein.sequences.v11.5.fa",
		        "enrichment_path": "273075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273075.protein.info.v11.5.txt",
		        "node_list_path": "273075.cluster.nodes.v11.5.txt",
		        "edge_list_path": "273075.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMarinimicrobiaBacteriumCg1024814(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Marinimicrobia bacterium CG1_02_48_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMarinimicrobiaBacteriumCg1024814", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805240.protein.info.v11.5.txt",
		        "node_list_path": "1805240.protein.complete.v11.5.txt"
		    }
		]
    )()

def KordiimonasLipolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kordiimonas lipolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KordiimonasLipolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1662421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662421.protein.info.v11.5.txt",
		        "node_list_path": "1662421.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibularhizoctoniaSpCbs109695Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibularhizoctonia sp. CBS 109695 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibularhizoctoniaSpCbs109695Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "436010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "436010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "436010.clusters.proteins.v11.5.txt",
		        "sequence_path": "436010.protein.sequences.v11.5.fa",
		        "enrichment_path": "436010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436010.protein.info.v11.5.txt",
		        "node_list_path": "436010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "436010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpSka58Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SKA58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpSka58Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314266.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314266.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314266.clusters.proteins.v11.5.txt",
		        "sequence_path": "314266.protein.sequences.v11.5.fa",
		        "enrichment_path": "314266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314266.protein.info.v11.5.txt",
		        "node_list_path": "314266.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314266.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpDfci1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. DFCI1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpDfci1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230476.protein.info.v11.5.txt",
		        "node_list_path": "1230476.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollichthysLucidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collichthys lucidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollichthysLucidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "240159.protein.sequences.v11.5.fa",
		        "enrichment_path": "240159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240159.protein.info.v11.5.txt",
		        "node_list_path": "240159.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo212Full4413bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_12_FULL_44_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo212Full4413bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802711.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802711.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802711.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802711.protein.info.v11.5.txt",
		        "node_list_path": "1802711.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802711.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloglycomycesAlbusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloglycomyces albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloglycomycesAlbusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089549.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089549.protein.info.v11.5.txt",
		        "node_list_path": "1089549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumGa0077528(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium Ga0077528 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumGa0077528", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752212.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752212.protein.info.v11.5.txt",
		        "node_list_path": "1752212.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumGwd23259Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWD2_32_59 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumGwd23259Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797680.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797680.protein.info.v11.5.txt",
		        "node_list_path": "1797680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpL74(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. L74 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpL74", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1560217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1560217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1560217.protein.info.v11.5.txt",
		        "node_list_path": "1560217.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtheneCuniculariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Athene cunicularia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtheneCuniculariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "194338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "194338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "194338.clusters.proteins.v11.5.txt",
		        "sequence_path": "194338.protein.sequences.v11.5.fa",
		        "enrichment_path": "194338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "194338.protein.info.v11.5.txt",
		        "node_list_path": "194338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "194338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHtcc2143Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2143Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "247633.clusters.info.v11.0.txt",
		        "cluster_tree_path": "247633.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "247633.clusters.proteins.v11.0.txt",
		        "sequence_path": "247633.protein.sequences.v11.0.fa",
		        "enrichment_path": "247633.protein.enrichment.terms.v11.0.txt",
		        "info_path": "247633.protein.info.v11.0.txt",
		        "node_list_path": "247633.cluster.nodes.v11.0.txt",
		        "edge_list_path": "247633.protein.cluster.v11.0.txt"
		    }
		]
    )()

def PyrobaculumArsenaticumDsm13514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum arsenaticum DSM 13514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumArsenaticumDsm13514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "340102.protein.sequences.v11.5.fa",
		        "enrichment_path": "340102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340102.protein.info.v11.5.txt",
		        "node_list_path": "340102.protein.complete.v11.5.txt"
		    }
		]
    )()

def NannospalaxGalili(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nannospalax galili graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NannospalaxGalili", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1026970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1026970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1026970.protein.info.v11.5.txt",
		        "node_list_path": "1026970.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusHamsteriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hamsteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHamsteriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423754.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423754.protein.info.v11.5.txt",
		        "node_list_path": "1423754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsSpCamponotiLeonardiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps sp. camponoti-leonardi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsSpCamponotiLeonardiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2039875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2039875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2039875.clusters.proteins.v11.5.txt",
		        "sequence_path": "2039875.protein.sequences.v11.5.fa",
		        "enrichment_path": "2039875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2039875.protein.info.v11.5.txt",
		        "node_list_path": "2039875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2039875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptothrixCholodnii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptothrix cholodnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptothrixCholodnii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "395495.protein.sequences.v11.5.fa",
		        "enrichment_path": "395495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395495.protein.info.v11.5.txt",
		        "node_list_path": "395495.protein.complete.v11.5.txt"
		    }
		]
    )()

def NanohaloarchaeaArchaeonB1Br10U2g1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon B1-Br10_U2g1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NanohaloarchaeaArchaeonB1Br10U2g1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729453.protein.info.v11.5.txt",
		        "node_list_path": "1729453.protein.complete.v11.5.txt"
		    }
		]
    )()

def VaribaculumTimonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum timonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaribaculumTimonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1964383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1964383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1964383.clusters.proteins.v11.5.txt",
		        "sequence_path": "1964383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1964383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1964383.protein.info.v11.5.txt",
		        "node_list_path": "1964383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1964383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysobacterEnzymogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter enzymogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterEnzymogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69.protein.sequences.v11.5.fa",
		        "enrichment_path": "69.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69.protein.info.v11.5.txt",
		        "node_list_path": "69.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumOculi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium oculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumOculi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1544416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1544416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1544416.protein.info.v11.5.txt",
		        "node_list_path": "1544416.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndosymbiontOfTevniaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Tevnia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndosymbiontOfTevniaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1049564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1049564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1049564.clusters.proteins.v11.5.txt",
		        "sequence_path": "1049564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1049564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1049564.protein.info.v11.5.txt",
		        "node_list_path": "1049564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1049564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium maris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1224163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1224163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1224163.clusters.proteins.v11.5.txt",
		        "sequence_path": "1224163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224163.protein.info.v11.5.txt",
		        "node_list_path": "1224163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1224163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrobacterFarmeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter farmeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterFarmeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1114922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1114922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1114922.clusters.proteins.v11.5.txt",
		        "sequence_path": "1114922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114922.protein.info.v11.5.txt",
		        "node_list_path": "1114922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1114922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE2733(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2733 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE2733", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834138.protein.info.v11.5.txt",
		        "node_list_path": "1834138.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelosinusFermentansJbw45(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus fermentans JBW45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelosinusFermentansJbw45", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1192197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192197.protein.info.v11.5.txt",
		        "node_list_path": "1192197.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYonathbacteriaBacteriumRifoxyc2Full479(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFOXYC2_FULL_47_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifoxyc2Full479", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802729.protein.info.v11.5.txt",
		        "node_list_path": "1802729.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGwa1418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GWA1_41_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGwa1418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802471.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802471.protein.info.v11.5.txt",
		        "node_list_path": "1802471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryomorphaceaeBacteriumAsp1005aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium ASP10-05a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryomorphaceaeBacteriumAsp1005aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1622232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1622232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1622232.clusters.proteins.v11.5.txt",
		        "sequence_path": "1622232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622232.protein.info.v11.5.txt",
		        "node_list_path": "1622232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1622232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RufibacterSpDg15cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rufibacter sp. DG15C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RufibacterSpDg15cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379909.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379909.protein.info.v11.5.txt",
		        "node_list_path": "1379909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaCrassostreaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia crassostreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaCrassostreaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53428.clusters.proteins.v11.5.txt",
		        "sequence_path": "53428.protein.sequences.v11.5.fa",
		        "enrichment_path": "53428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53428.protein.info.v11.5.txt",
		        "node_list_path": "53428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumArthrosphaeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium arthrosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumArthrosphaeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "651561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "651561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "651561.clusters.proteins.v11.5.txt",
		        "sequence_path": "651561.protein.sequences.v11.5.fa",
		        "enrichment_path": "651561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "651561.protein.info.v11.5.txt",
		        "node_list_path": "651561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "651561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalococcusMorrhuae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halococcus morrhuae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusMorrhuae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "931277.protein.sequences.v11.5.fa",
		        "enrichment_path": "931277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "931277.protein.info.v11.5.txt",
		        "node_list_path": "931277.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSelenatarsenatisSf1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus selenatarsenatis SF-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSelenatarsenatisSf1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321606.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321606.protein.info.v11.5.txt",
		        "node_list_path": "1321606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodovulumSpEs010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. ES.010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovulumSpEs010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882821.protein.info.v11.5.txt",
		        "node_list_path": "1882821.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmillariaOstoyae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Armillaria ostoyae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmillariaOstoyae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47428.protein.sequences.v11.5.fa",
		        "enrichment_path": "47428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47428.protein.info.v11.5.txt",
		        "node_list_path": "47428.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifoxya1Full4114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFOXYA1_FULL_41_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifoxya1Full4114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797737.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797737.protein.info.v11.5.txt",
		        "node_list_path": "1797737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeiothermusChliarophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus chliarophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusChliarophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926560.protein.sequences.v11.5.fa",
		        "enrichment_path": "926560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926560.protein.info.v11.5.txt",
		        "node_list_path": "926560.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusDelbrueckiiAtcc11842(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii ATCC11842 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusDelbrueckiiAtcc11842", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "390333.protein.sequences.v11.0.fa",
		        "enrichment_path": "390333.protein.enrichment.terms.v11.0.txt",
		        "info_path": "390333.protein.info.v11.0.txt",
		        "node_list_path": "390333.protein.complete.v11.0.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium2146faaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 2146FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium2146faaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742723.clusters.proteins.v11.5.txt",
		        "sequence_path": "742723.protein.sequences.v11.5.fa",
		        "enrichment_path": "742723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742723.protein.info.v11.5.txt",
		        "node_list_path": "742723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpElb17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. ELB17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpElb17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "270374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "270374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "270374.clusters.proteins.v11.5.txt",
		        "sequence_path": "270374.protein.sequences.v11.5.fa",
		        "enrichment_path": "270374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "270374.protein.info.v11.5.txt",
		        "node_list_path": "270374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "270374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrococcalesBacterium7315(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 73-15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcalesBacterium7315", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895792.protein.info.v11.5.txt",
		        "node_list_path": "1895792.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpHgf2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. HGF2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpHgf2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "908340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "908340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "908340.clusters.proteins.v11.5.txt",
		        "sequence_path": "908340.protein.sequences.v11.5.fa",
		        "enrichment_path": "908340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908340.protein.info.v11.5.txt",
		        "node_list_path": "908340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "908340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusOdinarchaeotaArchaeonLcb4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Odinarchaeota archaeon LCB_4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOdinarchaeotaArchaeonLcb4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841599.protein.info.v11.5.txt",
		        "node_list_path": "1841599.protein.complete.v11.5.txt"
		    }
		]
    )()

def WickerhamomycesCiferriiNrrlY1031Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamomyces ciferrii NRRL Y-1031 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WickerhamomycesCiferriiNrrlY1031Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206466.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206466.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206466.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206466.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206466.protein.info.v11.5.txt",
		        "node_list_path": "1206466.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206466.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRoot180(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root180 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRoot180", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736483.protein.info.v11.5.txt",
		        "node_list_path": "1736483.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpCl154(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. CL154 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpCl154", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798214.protein.info.v11.5.txt",
		        "node_list_path": "1798214.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpNio1057(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. NIO-1057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpNio1057", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "993071.protein.sequences.v11.5.fa",
		        "enrichment_path": "993071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "993071.protein.info.v11.5.txt",
		        "node_list_path": "993071.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermosulfurimonasDismutans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermosulfurimonas dismutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosulfurimonasDismutans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999894.protein.sequences.v11.5.fa",
		        "enrichment_path": "999894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999894.protein.info.v11.5.txt",
		        "node_list_path": "999894.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpA2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. A2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpA2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "298701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "298701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "298701.clusters.proteins.v11.5.txt",
		        "sequence_path": "298701.protein.sequences.v11.5.fa",
		        "enrichment_path": "298701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "298701.protein.info.v11.5.txt",
		        "node_list_path": "298701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "298701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquifexAeolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquifex aeolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquifexAeolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "224324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "224324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "224324.clusters.proteins.v11.5.txt",
		        "sequence_path": "224324.protein.sequences.v11.5.fa",
		        "enrichment_path": "224324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224324.protein.info.v11.5.txt",
		        "node_list_path": "224324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "224324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusDucreyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus ducreyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusDucreyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "233412.clusters.info.v11.5.txt",
		        "cluster_tree_path": "233412.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "233412.clusters.proteins.v11.5.txt",
		        "sequence_path": "233412.protein.sequences.v11.5.fa",
		        "enrichment_path": "233412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "233412.protein.info.v11.5.txt",
		        "node_list_path": "233412.cluster.nodes.v11.5.txt",
		        "edge_list_path": "233412.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarmoricolaScoriaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marmoricola scoriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarmoricolaScoriaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "642780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "642780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "642780.clusters.proteins.v11.5.txt",
		        "sequence_path": "642780.protein.sequences.v11.5.fa",
		        "enrichment_path": "642780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "642780.protein.info.v11.5.txt",
		        "node_list_path": "642780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "642780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanobisporaRoseaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planobispora rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanobisporaRoseaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35762.clusters.proteins.v11.5.txt",
		        "sequence_path": "35762.protein.sequences.v11.5.fa",
		        "enrichment_path": "35762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35762.protein.info.v11.5.txt",
		        "node_list_path": "35762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloteneraVersatilis7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera versatilis 7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraVersatilis7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1101193.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1101193.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1101193.clusters.proteins.v11.5.txt",
		        "sequence_path": "1101193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101193.protein.info.v11.5.txt",
		        "node_list_path": "1101193.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1101193.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGsub(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Gsub graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGsub", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1615892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1615892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1615892.protein.info.v11.5.txt",
		        "node_list_path": "1615892.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisRubidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis rubida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisRubidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "112413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "112413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "112413.clusters.proteins.v11.5.txt",
		        "sequence_path": "112413.protein.sequences.v11.5.fa",
		        "enrichment_path": "112413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112413.protein.info.v11.5.txt",
		        "node_list_path": "112413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "112413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RamazzottiusVarieornatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ramazzottius varieornatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RamazzottiusVarieornatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "947166.protein.sequences.v11.5.fa",
		        "enrichment_path": "947166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "947166.protein.info.v11.5.txt",
		        "node_list_path": "947166.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfDrosophilaSimulansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila simulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophilaSimulansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236908.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236908.protein.info.v11.5.txt",
		        "node_list_path": "1236908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasGudaonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas gudaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasGudaonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "376427.protein.sequences.v11.5.fa",
		        "enrichment_path": "376427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376427.protein.info.v11.5.txt",
		        "node_list_path": "376427.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumInterjectum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium interjectum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumInterjectum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33895.protein.sequences.v11.5.fa",
		        "enrichment_path": "33895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33895.protein.info.v11.5.txt",
		        "node_list_path": "33895.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaAgarilytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina agarilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaAgarilytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "620914.protein.sequences.v11.5.fa",
		        "enrichment_path": "620914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "620914.protein.info.v11.5.txt",
		        "node_list_path": "620914.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeeuwenhoekiellaBlandensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella blandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeeuwenhoekiellaBlandensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398720.clusters.proteins.v11.5.txt",
		        "sequence_path": "398720.protein.sequences.v11.5.fa",
		        "enrichment_path": "398720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398720.protein.info.v11.5.txt",
		        "node_list_path": "398720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasPantelleriensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas pantelleriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasPantelleriensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "48727.protein.sequences.v11.5.fa",
		        "enrichment_path": "48727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48727.protein.info.v11.5.txt",
		        "node_list_path": "48727.protein.complete.v11.5.txt"
		    }
		]
    )()

def MannheimiaHaemolyticaBovineCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica BOVINE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaHaemolyticaBovineCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "669262.clusters.info.v11.0.txt",
		        "cluster_tree_path": "669262.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "669262.clusters.proteins.v11.0.txt",
		        "sequence_path": "669262.protein.sequences.v11.0.fa",
		        "enrichment_path": "669262.protein.enrichment.terms.v11.0.txt",
		        "info_path": "669262.protein.info.v11.0.txt",
		        "node_list_path": "669262.cluster.nodes.v11.0.txt",
		        "edge_list_path": "669262.protein.cluster.v11.0.txt"
		    }
		]
    )()

def PowellomycesHirtusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Powellomyces hirtus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PowellomycesHirtusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "109895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "109895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "109895.clusters.proteins.v11.5.txt",
		        "sequence_path": "109895.protein.sequences.v11.5.fa",
		        "enrichment_path": "109895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109895.protein.info.v11.5.txt",
		        "node_list_path": "109895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "109895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaOxidasicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina oxidasica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaOxidasicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "676199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "676199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "676199.clusters.proteins.v11.5.txt",
		        "sequence_path": "676199.protein.sequences.v11.5.fa",
		        "enrichment_path": "676199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "676199.protein.info.v11.5.txt",
		        "node_list_path": "676199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "676199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WenxiniaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wenxinia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WenxiniaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123501.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123501.protein.info.v11.5.txt",
		        "node_list_path": "1123501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusSpJdfr02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sp. JdFR-02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSpJdfr02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935003.protein.info.v11.5.txt",
		        "node_list_path": "1935003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpWcd2001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. WCD2001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpWcd2001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280681.protein.info.v11.5.txt",
		        "node_list_path": "1280681.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharibacterSpAm169(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharibacter sp. AM169 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharibacterSpAm169", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1343158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1343158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1343158.protein.info.v11.5.txt",
		        "node_list_path": "1343158.protein.complete.v11.5.txt"
		    }
		]
    )()

def BeauveriaBassiana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Beauveria bassiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeauveriaBassiana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "176275.protein.sequences.v11.5.fa",
		        "enrichment_path": "176275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "176275.protein.info.v11.5.txt",
		        "node_list_path": "176275.protein.complete.v11.5.txt"
		    }
		]
    )()

def VulcanisaetaSpJchs4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vulcanisaeta sp. JCHS_4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulcanisaetaSpJchs4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1714253.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714253.protein.info.v11.5.txt",
		        "node_list_path": "1714253.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpOrs278Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. ORS278 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpOrs278Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "114615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "114615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "114615.clusters.proteins.v11.5.txt",
		        "sequence_path": "114615.protein.sequences.v11.5.fa",
		        "enrichment_path": "114615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "114615.protein.info.v11.5.txt",
		        "node_list_path": "114615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "114615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusPasteuri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus pasteuri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusPasteuri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45972.protein.sequences.v11.5.fa",
		        "enrichment_path": "45972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45972.protein.info.v11.5.txt",
		        "node_list_path": "45972.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobacteraceaeBacteriumRaap1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium RAAP-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteraceaeBacteriumRaap1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735114.protein.info.v11.5.txt",
		        "node_list_path": "1735114.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusOrientalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusOrientalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "334253.clusters.info.v11.5.txt",
		        "cluster_tree_path": "334253.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "334253.clusters.proteins.v11.5.txt",
		        "sequence_path": "334253.protein.sequences.v11.5.fa",
		        "enrichment_path": "334253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334253.protein.info.v11.5.txt",
		        "node_list_path": "334253.cluster.nodes.v11.5.txt",
		        "edge_list_path": "334253.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisOrientalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisOrientalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125971.protein.info.v11.5.txt",
		        "node_list_path": "1125971.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalococcusThailandensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halococcus thailandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusThailandensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227457.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227457.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227457.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227457.protein.info.v11.5.txt",
		        "node_list_path": "1227457.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227457.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FranconibacterPulverisDsm19144Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Franconibacter pulveris DSM 19144 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FranconibacterPulverisDsm19144Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121863.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121863.protein.info.v11.5.txt",
		        "node_list_path": "1121863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DickeyaSp2b12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya sp. 2B12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaSp2b12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577887.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577887.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577887.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577887.protein.info.v11.5.txt",
		        "node_list_path": "1577887.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577887.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinivibrioAlkaliphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinivibrio alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinivibrioAlkaliphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1313304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313304.protein.info.v11.5.txt",
		        "node_list_path": "1313304.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteibacterSp9135(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter sp. 9135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterSp9135", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500893.protein.info.v11.5.txt",
		        "node_list_path": "1500893.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermaerobacterSubterraneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermaerobacter subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermaerobacterSubterraneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "867903.protein.sequences.v11.5.fa",
		        "enrichment_path": "867903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867903.protein.info.v11.5.txt",
		        "node_list_path": "867903.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobacteraceaeBacteriumCg2305140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium CG2_30_51_40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteraceaeBacteriumCg2305140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805128.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805128.protein.info.v11.5.txt",
		        "node_list_path": "1805128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658218.clusters.proteins.v11.5.txt",
		        "sequence_path": "658218.protein.sequences.v11.5.fa",
		        "enrichment_path": "658218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658218.protein.info.v11.5.txt",
		        "node_list_path": "658218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusMelliventris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus melliventris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMelliventris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218507.protein.info.v11.5.txt",
		        "node_list_path": "1218507.protein.complete.v11.5.txt"
		    }
		]
    )()

def BabjeviellaInositovoraNrrlY12698Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Babjeviella inositovora NRRL Y-12698 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BabjeviellaInositovoraNrrlY12698Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "984486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "984486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "984486.clusters.proteins.v11.5.txt",
		        "sequence_path": "984486.protein.sequences.v11.5.fa",
		        "enrichment_path": "984486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "984486.protein.info.v11.5.txt",
		        "node_list_path": "984486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "984486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpYr096Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. yr096 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpYr096Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761750.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761750.protein.info.v11.5.txt",
		        "node_list_path": "1761750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrialbaceaeArchaeonB1Br10E2g2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon B1-Br10_E2g2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaceaeArchaeonB1Br10E2g2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729458.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729458.protein.info.v11.5.txt",
		        "node_list_path": "1729458.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaSteigerwaltiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella steigerwaltii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaSteigerwaltiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "460.clusters.proteins.v11.5.txt",
		        "sequence_path": "460.protein.sequences.v11.5.fa",
		        "enrichment_path": "460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "460.protein.info.v11.5.txt",
		        "node_list_path": "460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarmoricolaSpUrhb0036(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marmoricola sp. URHB0036 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarmoricolaSpUrhb0036", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298863.protein.info.v11.5.txt",
		        "node_list_path": "1298863.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200251971Sch5477799ACluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-51971_SCH5477799-a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200251971Sch5477799ACluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834106.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834106.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834106.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834106.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834106.protein.info.v11.5.txt",
		        "node_list_path": "1834106.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834106.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OerskoviaTurbataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oerskovia turbata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OerskoviaTurbataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1713.clusters.proteins.v11.5.txt",
		        "sequence_path": "1713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1713.protein.info.v11.5.txt",
		        "node_list_path": "1713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DehalococcoidesSpJdfr54Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides sp. JdFR-54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalococcoidesSpJdfr54Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935047.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935047.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935047.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935047.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935047.protein.info.v11.5.txt",
		        "node_list_path": "1935047.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935047.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerracidiphilusGabretensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terracidiphilus gabretensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerracidiphilusGabretensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577687.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577687.protein.info.v11.5.txt",
		        "node_list_path": "1577687.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslh70357Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslh70357Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1536774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1536774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1536774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1536774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536774.protein.info.v11.5.txt",
		        "node_list_path": "1536774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1536774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpAkyn10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. AKYN10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpAkyn10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349820.protein.info.v11.5.txt",
		        "node_list_path": "1349820.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusSpCcbus3uf1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus sp. CCBUS3UF1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusSpCcbus3uf1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111069.protein.info.v11.5.txt",
		        "node_list_path": "1111069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterChlorophenolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter chlorophenolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterChlorophenolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "452863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "452863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "452863.clusters.proteins.v11.5.txt",
		        "sequence_path": "452863.protein.sequences.v11.5.fa",
		        "enrichment_path": "452863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452863.protein.info.v11.5.txt",
		        "node_list_path": "452863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "452863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LawsoniaIntracellularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lawsonia intracellularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LawsoniaIntracellularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "363253.protein.sequences.v11.5.fa",
		        "enrichment_path": "363253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "363253.protein.info.v11.5.txt",
		        "node_list_path": "363253.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaSp119Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. 1.19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSp119Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1925589.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1925589.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1925589.clusters.proteins.v11.5.txt",
		        "sequence_path": "1925589.protein.sequences.v11.5.fa",
		        "enrichment_path": "1925589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1925589.protein.info.v11.5.txt",
		        "node_list_path": "1925589.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1925589.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AscobolusImmersusRn42Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ascobolus immersus RN42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AscobolusImmersusRn42Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1160509.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1160509.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1160509.clusters.proteins.v11.5.txt",
		        "sequence_path": "1160509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160509.protein.info.v11.5.txt",
		        "node_list_path": "1160509.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1160509.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodovulumSpMb263Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. MB263 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovulumSpMb263Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "308754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "308754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "308754.clusters.proteins.v11.5.txt",
		        "sequence_path": "308754.protein.sequences.v11.5.fa",
		        "enrichment_path": "308754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "308754.protein.info.v11.5.txt",
		        "node_list_path": "308754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "308754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArhodomonasAquaeoleiDsm8974Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arhodomonas aquaeolei DSM 8974 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArhodomonasAquaeoleiDsm8974Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121016.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121016.protein.info.v11.5.txt",
		        "node_list_path": "1121016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DethiosulfatibacterAminovoransDsm17477Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dethiosulfatibacter aminovorans DSM 17477 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DethiosulfatibacterAminovoransDsm17477Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121476.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121476.protein.info.v11.5.txt",
		        "node_list_path": "1121476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrnithobacteriumRhinotrachealeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ornithobacterium rhinotracheale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithobacteriumRhinotrachealeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "867902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "867902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "867902.clusters.proteins.v11.5.txt",
		        "sequence_path": "867902.protein.sequences.v11.5.fa",
		        "enrichment_path": "867902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867902.protein.info.v11.5.txt",
		        "node_list_path": "867902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "867902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LaodelphaxStriatellus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Laodelphax striatellus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LaodelphaxStriatellus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "195883.protein.sequences.v11.5.fa",
		        "enrichment_path": "195883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195883.protein.info.v11.5.txt",
		        "node_list_path": "195883.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropithecusCoquereli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propithecus coquereli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropithecusCoquereli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "379532.protein.sequences.v11.5.fa",
		        "enrichment_path": "379532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "379532.protein.info.v11.5.txt",
		        "node_list_path": "379532.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPerorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus peroris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPerorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888746.clusters.proteins.v11.5.txt",
		        "sequence_path": "888746.protein.sequences.v11.5.fa",
		        "enrichment_path": "888746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888746.protein.info.v11.5.txt",
		        "node_list_path": "888746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSoliNbrc100801Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas soli NBRC 100801 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSoliNbrc100801Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219055.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219055.protein.info.v11.5.txt",
		        "node_list_path": "1219055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeromyscusManiculatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peromyscus maniculatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeromyscusManiculatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10042.clusters.proteins.v11.5.txt",
		        "sequence_path": "10042.protein.sequences.v11.5.fa",
		        "enrichment_path": "10042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10042.protein.info.v11.5.txt",
		        "node_list_path": "10042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OerskoviaEnterophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oerskovia enterophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OerskoviaEnterophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43678.protein.sequences.v11.5.fa",
		        "enrichment_path": "43678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43678.protein.info.v11.5.txt",
		        "node_list_path": "43678.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAlbusAlbus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Streptomyces albus albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAlbusAlbus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67257.protein.sequences.v11.0.fa",
		        "enrichment_path": "67257.protein.enrichment.terms.v11.0.txt",
		        "info_path": "67257.protein.info.v11.0.txt",
		        "node_list_path": "67257.protein.complete.v11.0.txt"
		    }
		]
    )()

def SulfitobacterLitoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterLitoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "335975.clusters.info.v11.5.txt",
		        "cluster_tree_path": "335975.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "335975.clusters.proteins.v11.5.txt",
		        "sequence_path": "335975.protein.sequences.v11.5.fa",
		        "enrichment_path": "335975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335975.protein.info.v11.5.txt",
		        "node_list_path": "335975.cluster.nodes.v11.5.txt",
		        "edge_list_path": "335975.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBeckwithbacteriaBacteriumGw2011Gwa24310(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium GW2011_GWA2_43_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumGw2011Gwa24310", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618369.protein.info.v11.5.txt",
		        "node_list_path": "1618369.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpIcm47Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. ICM47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpIcm47Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936548.clusters.proteins.v11.5.txt",
		        "sequence_path": "936548.protein.sequences.v11.5.fa",
		        "enrichment_path": "936548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936548.protein.info.v11.5.txt",
		        "node_list_path": "936548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronincolaFerrireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronincola ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronincolaFerrireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "393762.protein.sequences.v11.5.fa",
		        "enrichment_path": "393762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393762.protein.info.v11.5.txt",
		        "node_list_path": "393762.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterovibrioSpJcm19048Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio sp. JCM 19048 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioSpJcm19048Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1460642.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1460642.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1460642.clusters.proteins.v11.5.txt",
		        "sequence_path": "1460642.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460642.protein.info.v11.5.txt",
		        "node_list_path": "1460642.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1460642.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwa13921(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_39_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa13921", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618550.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618550.protein.info.v11.5.txt",
		        "node_list_path": "1618550.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaGrimesiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia grimesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaGrimesiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "82995.clusters.info.v11.5.txt",
		        "cluster_tree_path": "82995.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "82995.clusters.proteins.v11.5.txt",
		        "sequence_path": "82995.protein.sequences.v11.5.fa",
		        "enrichment_path": "82995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82995.protein.info.v11.5.txt",
		        "node_list_path": "82995.cluster.nodes.v11.5.txt",
		        "edge_list_path": "82995.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFluviicolaRiflensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fluviicola riflensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFluviicolaRiflensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798018.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798018.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798018.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798018.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798018.protein.info.v11.5.txt",
		        "node_list_path": "1798018.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798018.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SideroxydansSpGwf25914Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sideroxydans sp. GWF2_59_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SideroxydansSpGwf25914Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802154.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802154.protein.info.v11.5.txt",
		        "node_list_path": "1802154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OpitutusTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Opitutus terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpitutusTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "452637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "452637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "452637.clusters.proteins.v11.5.txt",
		        "sequence_path": "452637.protein.sequences.v11.5.fa",
		        "enrichment_path": "452637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452637.protein.info.v11.5.txt",
		        "node_list_path": "452637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "452637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BipolarisOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "101162.clusters.info.v11.5.txt",
		        "cluster_tree_path": "101162.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "101162.clusters.proteins.v11.5.txt",
		        "sequence_path": "101162.protein.sequences.v11.5.fa",
		        "enrichment_path": "101162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101162.protein.info.v11.5.txt",
		        "node_list_path": "101162.cluster.nodes.v11.5.txt",
		        "edge_list_path": "101162.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPortnoybacteriaBacteriumRbg13408Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RBG_13_40_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRbg13408Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801990.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801990.protein.info.v11.5.txt",
		        "node_list_path": "1801990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobaculumSchaaliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum schaalii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobaculumSchaaliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883067.clusters.proteins.v11.5.txt",
		        "sequence_path": "883067.protein.sequences.v11.5.fa",
		        "enrichment_path": "883067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883067.protein.info.v11.5.txt",
		        "node_list_path": "883067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrialbaceaeArchaeonTcBr11E2g28(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon Tc-Br11_E2g28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaceaeArchaeonTcBr11E2g28", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729463.protein.info.v11.5.txt",
		        "node_list_path": "1729463.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaBronchisepticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella bronchiseptica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaBronchisepticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "257310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "257310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "257310.clusters.proteins.v11.5.txt",
		        "sequence_path": "257310.protein.sequences.v11.5.fa",
		        "enrichment_path": "257310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "257310.protein.info.v11.5.txt",
		        "node_list_path": "257310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "257310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasAsaccharolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas asaccharolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasAsaccharolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "879243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "879243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "879243.clusters.proteins.v11.5.txt",
		        "sequence_path": "879243.protein.sequences.v11.5.fa",
		        "enrichment_path": "879243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879243.protein.info.v11.5.txt",
		        "node_list_path": "879243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "879243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesMelasCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles melas Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesMelasCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34690.clusters.proteins.v11.5.txt",
		        "sequence_path": "34690.protein.sequences.v11.5.fa",
		        "enrichment_path": "34690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34690.protein.info.v11.5.txt",
		        "node_list_path": "34690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaedibacterAcanthamoebaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caedibacter acanthamoebae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaedibacterAcanthamoebaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "244581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "244581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "244581.clusters.proteins.v11.5.txt",
		        "sequence_path": "244581.protein.sequences.v11.5.fa",
		        "enrichment_path": "244581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244581.protein.info.v11.5.txt",
		        "node_list_path": "244581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "244581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumMiluonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium miluonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumMiluonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411945.clusters.proteins.v11.5.txt",
		        "sequence_path": "411945.protein.sequences.v11.5.fa",
		        "enrichment_path": "411945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411945.protein.info.v11.5.txt",
		        "node_list_path": "411945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusSb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus SB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusSb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59926.protein.sequences.v11.5.fa",
		        "enrichment_path": "59926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59926.protein.info.v11.5.txt",
		        "node_list_path": "59926.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasGudaonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas gudaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasGudaonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "376427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "376427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "376427.clusters.proteins.v11.5.txt",
		        "sequence_path": "376427.protein.sequences.v11.5.fa",
		        "enrichment_path": "376427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376427.protein.info.v11.5.txt",
		        "node_list_path": "376427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "376427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusManliponensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus manliponensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusManliponensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "574376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "574376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "574376.clusters.proteins.v11.5.txt",
		        "sequence_path": "574376.protein.sequences.v11.5.fa",
		        "enrichment_path": "574376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574376.protein.info.v11.5.txt",
		        "node_list_path": "574376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "574376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaSputiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sputi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSputiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089453.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089453.protein.info.v11.5.txt",
		        "node_list_path": "1089453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcremoniumChrysogenumAtcc11550Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acremonium chrysogenum ATCC 11550 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcremoniumChrysogenumAtcc11550Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "857340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "857340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "857340.clusters.proteins.v11.5.txt",
		        "sequence_path": "857340.protein.sequences.v11.5.fa",
		        "enrichment_path": "857340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857340.protein.info.v11.5.txt",
		        "node_list_path": "857340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "857340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlsenellaSpKh3b4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella sp. KH3B4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaSpKh3b4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855394.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855394.protein.info.v11.5.txt",
		        "node_list_path": "1855394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhialocephalaSubalpinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phialocephala subalpina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhialocephalaSubalpinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "576137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "576137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "576137.clusters.proteins.v11.5.txt",
		        "sequence_path": "576137.protein.sequences.v11.5.fa",
		        "enrichment_path": "576137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "576137.protein.info.v11.5.txt",
		        "node_list_path": "576137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "576137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioHalioticoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio halioticoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioHalioticoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219072.protein.info.v11.5.txt",
		        "node_list_path": "1219072.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumKuznetsovii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum kuznetsovii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumKuznetsovii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "760568.protein.sequences.v11.5.fa",
		        "enrichment_path": "760568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "760568.protein.info.v11.5.txt",
		        "node_list_path": "760568.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeminorellaGrimontii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leminorella grimontii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeminorellaGrimontii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005999.protein.info.v11.5.txt",
		        "node_list_path": "1005999.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsplowo212Full4312(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_12_FULL_43_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo212Full4312", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798692.protein.info.v11.5.txt",
		        "node_list_path": "1798692.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifoxyb1Full4319Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYB1_FULL_43_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxyb1Full4319Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801649.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801649.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801649.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801649.protein.info.v11.5.txt",
		        "node_list_path": "1801649.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801649.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LonsdaleaQuercinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lonsdalea quercina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LonsdaleaQuercinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1082705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1082705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1082705.clusters.proteins.v11.5.txt",
		        "sequence_path": "1082705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1082705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1082705.protein.info.v11.5.txt",
		        "node_list_path": "1082705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1082705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacinutrixSpPamc27137Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix sp. PAMC27137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixSpPamc27137Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1469557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1469557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1469557.clusters.proteins.v11.5.txt",
		        "sequence_path": "1469557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469557.protein.info.v11.5.txt",
		        "node_list_path": "1469557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1469557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EctothiorhodosinusMongolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ectothiorhodosinus mongolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctothiorhodosinusMongolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "233100.protein.sequences.v11.5.fa",
		        "enrichment_path": "233100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "233100.protein.info.v11.5.txt",
		        "node_list_path": "233100.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaRettgeriDmel1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia rettgeri Dmel1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaRettgeriDmel1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1141663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1141663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1141663.clusters.proteins.v11.5.txt",
		        "sequence_path": "1141663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141663.protein.info.v11.5.txt",
		        "node_list_path": "1141663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1141663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlleyaSpVcsm12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olleya sp. VCSM12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlleyaSpVcsm12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "745718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "745718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "745718.clusters.proteins.v11.5.txt",
		        "sequence_path": "745718.protein.sequences.v11.5.fa",
		        "enrichment_path": "745718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745718.protein.info.v11.5.txt",
		        "node_list_path": "745718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "745718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumAcidaminophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium acidaminophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumAcidaminophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1286171.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1286171.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1286171.clusters.proteins.v11.5.txt",
		        "sequence_path": "1286171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286171.protein.info.v11.5.txt",
		        "node_list_path": "1286171.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1286171.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RheinheimeraSpSa1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera sp. SA_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraSpSa1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1827365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827365.protein.info.v11.5.txt",
		        "node_list_path": "1827365.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureococcusAnophagefferens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureococcus anophagefferens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureococcusAnophagefferens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44056.protein.sequences.v11.5.fa",
		        "enrichment_path": "44056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44056.protein.info.v11.5.txt",
		        "node_list_path": "44056.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaryophanonTenue(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caryophanon tenue graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaryophanonTenue", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33978.protein.sequences.v11.5.fa",
		        "enrichment_path": "33978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33978.protein.info.v11.5.txt",
		        "node_list_path": "33978.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaArabinofermentansNrrlYb2248Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Candida] arabinofermentans NRRL YB-2248 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaArabinofermentansNrrlYb2248Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983967.clusters.proteins.v11.5.txt",
		        "sequence_path": "983967.protein.sequences.v11.5.fa",
		        "enrichment_path": "983967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983967.protein.info.v11.5.txt",
		        "node_list_path": "983967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HeliocybeSulcataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Heliocybe sulcata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeliocybeSulcataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5364.clusters.proteins.v11.5.txt",
		        "sequence_path": "5364.protein.sequences.v11.5.fa",
		        "enrichment_path": "5364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5364.protein.info.v11.5.txt",
		        "node_list_path": "5364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeuconostocCitreum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc citreum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocCitreum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349519.protein.sequences.v11.5.fa",
		        "enrichment_path": "349519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349519.protein.info.v11.5.txt",
		        "node_list_path": "349519.protein.complete.v11.5.txt"
		    }
		]
    )()

def CucumisMeloVarMakuwa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cucumis melo var. makuwa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CucumisMeloVarMakuwa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1194695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194695.protein.info.v11.5.txt",
		        "node_list_path": "1194695.protein.complete.v11.5.txt"
		    }
		]
    )()

def TypeBSymbiontOfPlautiaStaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Type-B symbiont of Plautia stali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TypeBSymbiontOfPlautiaStaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1560354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1560354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1560354.clusters.proteins.v11.5.txt",
		        "sequence_path": "1560354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1560354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1560354.protein.info.v11.5.txt",
		        "node_list_path": "1560354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1560354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpPp1y(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. PP1Y graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpPp1y", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "702113.protein.sequences.v11.5.fa",
		        "enrichment_path": "702113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702113.protein.info.v11.5.txt",
		        "node_list_path": "702113.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrioBacteriovorusStrTiberius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus str. Tiberius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrioBacteriovorusStrTiberius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1069642.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069642.protein.info.v11.5.txt",
		        "node_list_path": "1069642.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpRoot930Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Root930 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpRoot930Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736609.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736609.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736609.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736609.protein.info.v11.5.txt",
		        "node_list_path": "1736609.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736609.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpEpsL25Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. EpS/L25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpEpsL25Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1749078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1749078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1749078.clusters.proteins.v11.5.txt",
		        "sequence_path": "1749078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1749078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1749078.protein.info.v11.5.txt",
		        "node_list_path": "1749078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1749078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalothermothrixSpDtu029(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halothermothrix sp. DTU029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalothermothrixSpDtu029", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671624.protein.info.v11.5.txt",
		        "node_list_path": "1671624.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElectrophorusElectricus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Electrophorus electricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElectrophorusElectricus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8005.protein.sequences.v11.5.fa",
		        "enrichment_path": "8005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8005.protein.info.v11.5.txt",
		        "node_list_path": "8005.protein.complete.v11.5.txt"
		    }
		]
    )()

def GillisiaSpHeli29Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gillisia sp. HelI29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GillisiaSpHeli29Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1249975.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1249975.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1249975.clusters.proteins.v11.5.txt",
		        "sequence_path": "1249975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249975.protein.info.v11.5.txt",
		        "node_list_path": "1249975.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1249975.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpAw25m09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. AW25M09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpAw25m09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1268303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268303.protein.info.v11.5.txt",
		        "node_list_path": "1268303.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassilibacillusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassilibacillusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1806837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1806837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1806837.clusters.proteins.v11.5.txt",
		        "sequence_path": "1806837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806837.protein.info.v11.5.txt",
		        "node_list_path": "1806837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1806837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpTne862(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. TNe-862 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpTne862", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "416944.protein.sequences.v11.5.fa",
		        "enrichment_path": "416944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416944.protein.info.v11.5.txt",
		        "node_list_path": "416944.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSubterraneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSubterraneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "335973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "335973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "335973.clusters.proteins.v11.5.txt",
		        "sequence_path": "335973.protein.sequences.v11.5.fa",
		        "enrichment_path": "335973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335973.protein.info.v11.5.txt",
		        "node_list_path": "335973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "335973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumJaponicumUsda124(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum USDA124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumJaponicumUsda124", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1038862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038862.protein.info.v11.5.txt",
		        "node_list_path": "1038862.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusFermentumIfo3956(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fermentum IFO3956 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFermentumIfo3956", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "334390.protein.sequences.v11.5.fa",
		        "enrichment_path": "334390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334390.protein.info.v11.5.txt",
		        "node_list_path": "334390.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterHartoniusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter hartonius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterHartoniusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "425514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "425514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "425514.clusters.proteins.v11.5.txt",
		        "sequence_path": "425514.protein.sequences.v11.5.fa",
		        "enrichment_path": "425514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425514.protein.info.v11.5.txt",
		        "node_list_path": "425514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "425514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacterium6411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 64-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacterium6411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895709.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895709.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895709.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895709.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895709.protein.info.v11.5.txt",
		        "node_list_path": "1895709.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895709.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanidioschyzonMerolaeStrain10dCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanidioschyzon merolae strain 10D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanidioschyzonMerolaeStrain10dCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "280699.clusters.info.v11.5.txt",
		        "cluster_tree_path": "280699.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "280699.clusters.proteins.v11.5.txt",
		        "sequence_path": "280699.protein.sequences.v11.5.fa",
		        "enrichment_path": "280699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "280699.protein.info.v11.5.txt",
		        "node_list_path": "280699.cluster.nodes.v11.5.txt",
		        "edge_list_path": "280699.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807754.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807754.protein.info.v11.5.txt",
		        "node_list_path": "1807754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KaistiaSoliDsm19436Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kaistia soli DSM 19436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KaistiaSoliDsm19436Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122133.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122133.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122133.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122133.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122133.protein.info.v11.5.txt",
		        "node_list_path": "1122133.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122133.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaeTomato(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae tomato graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaeTomato", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "223283.protein.sequences.v11.5.fa",
		        "enrichment_path": "223283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223283.protein.info.v11.5.txt",
		        "node_list_path": "223283.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlwc3742Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3742 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlwc3742Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463934.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463934.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463934.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463934.protein.info.v11.5.txt",
		        "node_list_path": "1463934.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463934.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfCimexLectulariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Cimex lectularius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfCimexLectulariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246273.clusters.proteins.v11.5.txt",
		        "sequence_path": "246273.protein.sequences.v11.5.fa",
		        "enrichment_path": "246273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246273.protein.info.v11.5.txt",
		        "node_list_path": "246273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErysipheNecatorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysiphe necator Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipheNecatorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52586.clusters.proteins.v11.5.txt",
		        "sequence_path": "52586.protein.sequences.v11.5.fa",
		        "enrichment_path": "52586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52586.protein.info.v11.5.txt",
		        "node_list_path": "52586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasXanthomarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas xanthomarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasXanthomarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "271420.protein.sequences.v11.5.fa",
		        "enrichment_path": "271420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "271420.protein.info.v11.5.txt",
		        "node_list_path": "271420.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusStomatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus stomatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusStomatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596315.clusters.proteins.v11.5.txt",
		        "sequence_path": "596315.protein.sequences.v11.5.fa",
		        "enrichment_path": "596315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596315.protein.info.v11.5.txt",
		        "node_list_path": "596315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaAlbicansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida albicans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaAlbicansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5476.clusters.proteins.v11.5.txt",
		        "sequence_path": "5476.protein.sequences.v11.5.fa",
		        "enrichment_path": "5476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5476.protein.info.v11.5.txt",
		        "node_list_path": "5476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusSp2319x1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sp. 2319x1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSp2319x1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674923.protein.info.v11.5.txt",
		        "node_list_path": "1674923.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpErg5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. ERG5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpErg5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1381597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1381597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1381597.clusters.proteins.v11.5.txt",
		        "sequence_path": "1381597.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381597.protein.info.v11.5.txt",
		        "node_list_path": "1381597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1381597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AuriculariaDelicata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Auricularia delicata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AuriculariaDelicata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "160860.protein.sequences.v11.5.fa",
		        "enrichment_path": "160860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "160860.protein.info.v11.5.txt",
		        "node_list_path": "160860.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyronemaOmphalodesCbs100304Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyronema omphalodes CBS 100304 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyronemaOmphalodesCbs100304Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1076935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1076935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1076935.clusters.proteins.v11.5.txt",
		        "sequence_path": "1076935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076935.protein.info.v11.5.txt",
		        "node_list_path": "1076935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1076935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPneumoniaeM129Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae M129 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPneumoniaeM129Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272634.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272634.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272634.clusters.proteins.v11.5.txt",
		        "sequence_path": "272634.protein.sequences.v11.5.fa",
		        "enrichment_path": "272634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272634.protein.info.v11.5.txt",
		        "node_list_path": "272634.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272634.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobulbusJaponicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbusJaponicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121403.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121403.protein.info.v11.5.txt",
		        "node_list_path": "1121403.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaUniformisNbrc13702Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia uniformis NBRC 13702 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaUniformisNbrc13702Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210100.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210100.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210100.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210100.protein.info.v11.5.txt",
		        "node_list_path": "1210100.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210100.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesOlivochromogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces olivochromogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesOlivochromogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1963.protein.info.v11.5.txt",
		        "node_list_path": "1963.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrancisellaSpMa067296Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella sp. MA067296 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaSpMa067296Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "475375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "475375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "475375.clusters.proteins.v11.5.txt",
		        "sequence_path": "475375.protein.sequences.v11.5.fa",
		        "enrichment_path": "475375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "475375.protein.info.v11.5.txt",
		        "node_list_path": "475375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "475375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaviibacterAbscessus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caviibacter abscessus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaviibacterAbscessus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1766719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1766719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1766719.protein.info.v11.5.txt",
		        "node_list_path": "1766719.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaProteobacteriumAap99Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return beta proteobacterium AAP99 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaProteobacteriumAap99Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523428.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523428.protein.info.v11.5.txt",
		        "node_list_path": "1523428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoniaPhycicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesonia phycicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoniaPhycicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "579105.protein.sequences.v11.5.fa",
		        "enrichment_path": "579105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579105.protein.info.v11.5.txt",
		        "node_list_path": "579105.protein.complete.v11.5.txt"
		    }
		]
    )()

def SodalisGlossinidius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sodalis glossinidius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SodalisGlossinidius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "343509.protein.sequences.v11.5.fa",
		        "enrichment_path": "343509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "343509.protein.info.v11.5.txt",
		        "node_list_path": "343509.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesRoseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRoseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66430.clusters.proteins.v11.5.txt",
		        "sequence_path": "66430.protein.sequences.v11.5.fa",
		        "enrichment_path": "66430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66430.protein.info.v11.5.txt",
		        "node_list_path": "66430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho212Full6025Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_12_FULL_60_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho212Full6025Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802399.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802399.protein.info.v11.5.txt",
		        "node_list_path": "1802399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpCcgeLa001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. CCGE-LA001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpCcgeLa001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223566.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223566.protein.info.v11.5.txt",
		        "node_list_path": "1223566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitromicrobiumSpJlt1363Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citromicrobium sp. JLT1363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitromicrobiumSpJlt1363Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "517722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "517722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "517722.clusters.proteins.v11.5.txt",
		        "sequence_path": "517722.protein.sequences.v11.5.fa",
		        "enrichment_path": "517722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "517722.protein.info.v11.5.txt",
		        "node_list_path": "517722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "517722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaproniaCoronata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capronia coronata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaproniaCoronata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43229.protein.sequences.v11.5.fa",
		        "enrichment_path": "43229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43229.protein.info.v11.5.txt",
		        "node_list_path": "43229.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpOv322Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. OV322 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpOv322Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882764.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882764.protein.info.v11.5.txt",
		        "node_list_path": "1882764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaVarigenaUsmarc1261Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena USMARC1261 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaVarigenaUsmarc1261Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1432056.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1432056.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1432056.clusters.proteins.v11.0.txt",
		        "sequence_path": "1432056.protein.sequences.v11.0.fa",
		        "enrichment_path": "1432056.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1432056.protein.info.v11.0.txt",
		        "node_list_path": "1432056.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1432056.protein.cluster.v11.0.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full5121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_51_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full5121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802773.protein.info.v11.5.txt",
		        "node_list_path": "1802773.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPacebacteriaBacteriumCg1024331(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium CG1_02_43_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacebacteriaBacteriumCg1024331", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805299.protein.info.v11.5.txt",
		        "node_list_path": "1805299.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaBrachyanthaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza brachyantha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaBrachyanthaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4533.clusters.proteins.v11.5.txt",
		        "sequence_path": "4533.protein.sequences.v11.5.fa",
		        "enrichment_path": "4533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4533.protein.info.v11.5.txt",
		        "node_list_path": "4533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporothrixInsectorumRcef264Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporothrix insectorum RCEF 264 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporothrixInsectorumRcef264Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1081102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1081102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1081102.clusters.proteins.v11.5.txt",
		        "sequence_path": "1081102.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081102.protein.info.v11.5.txt",
		        "node_list_path": "1081102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1081102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FormivibrioCitricus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Formivibrio citricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormivibrioCitricus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83765.protein.sequences.v11.5.fa",
		        "enrichment_path": "83765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83765.protein.info.v11.5.txt",
		        "node_list_path": "83765.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusTerrigenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus terrigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusTerrigenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122927.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122927.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122927.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122927.protein.info.v11.5.txt",
		        "node_list_path": "1122927.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122927.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AminobacterAminovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aminobacter aminovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminobacterAminovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83263.clusters.proteins.v11.5.txt",
		        "sequence_path": "83263.protein.sequences.v11.5.fa",
		        "enrichment_path": "83263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83263.protein.info.v11.5.txt",
		        "node_list_path": "83263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpOv641Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. OV641 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpOv641Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881068.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881068.protein.info.v11.5.txt",
		        "node_list_path": "1881068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FervidobacteriumNodosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium nodosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidobacteriumNodosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "381764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "381764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "381764.clusters.proteins.v11.5.txt",
		        "sequence_path": "381764.protein.sequences.v11.5.fa",
		        "enrichment_path": "381764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381764.protein.info.v11.5.txt",
		        "node_list_path": "381764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "381764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiorhodococcusDrewsiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiorhodococcus drewsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiorhodococcusDrewsiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765913.clusters.proteins.v11.5.txt",
		        "sequence_path": "765913.protein.sequences.v11.5.fa",
		        "enrichment_path": "765913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765913.protein.info.v11.5.txt",
		        "node_list_path": "765913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpAccc05744(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. ACCC05744 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpAccc05744", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229276.protein.info.v11.5.txt",
		        "node_list_path": "1229276.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyricicoccusPullicaecorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyricicoccus pullicaecorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyricicoccusPullicaecorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203606.protein.info.v11.5.txt",
		        "node_list_path": "1203606.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpHgh0039Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. HGH0039 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpHgh0039Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1078505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1078505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1078505.clusters.proteins.v11.5.txt",
		        "sequence_path": "1078505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078505.protein.info.v11.5.txt",
		        "node_list_path": "1078505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1078505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LodderomycesElongisporusNrrlYb4239Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lodderomyces elongisporus NRRL YB-4239 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LodderomycesElongisporusNrrlYb4239Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "379508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "379508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "379508.clusters.proteins.v11.5.txt",
		        "sequence_path": "379508.protein.sequences.v11.5.fa",
		        "enrichment_path": "379508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "379508.protein.info.v11.5.txt",
		        "node_list_path": "379508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "379508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfuricurvumSpRifrc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. RIFRC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricurvumSpRifrc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1249480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1249480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1249480.clusters.proteins.v11.5.txt",
		        "sequence_path": "1249480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249480.protein.info.v11.5.txt",
		        "node_list_path": "1249480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1249480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrachymyrmexZeteki(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trachymyrmex zeteki graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrachymyrmexZeteki", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "64791.protein.sequences.v11.5.fa",
		        "enrichment_path": "64791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64791.protein.info.v11.5.txt",
		        "node_list_path": "64791.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "490629.protein.sequences.v11.5.fa",
		        "enrichment_path": "490629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "490629.protein.info.v11.5.txt",
		        "node_list_path": "490629.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinocyclocheilusAnshuiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinocyclocheilus anshuiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinocyclocheilusAnshuiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1608454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1608454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1608454.clusters.proteins.v11.5.txt",
		        "sequence_path": "1608454.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608454.protein.info.v11.5.txt",
		        "node_list_path": "1608454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1608454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSp83Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSp83Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131812.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131812.protein.info.v11.5.txt",
		        "node_list_path": "1131812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAmylolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus amylolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAmylolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585524.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585524.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585524.clusters.proteins.v11.5.txt",
		        "sequence_path": "585524.protein.sequences.v11.5.fa",
		        "enrichment_path": "585524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585524.protein.info.v11.5.txt",
		        "node_list_path": "585524.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585524.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "522492.protein.sequences.v11.5.fa",
		        "enrichment_path": "522492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "522492.protein.info.v11.5.txt",
		        "node_list_path": "522492.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp7136Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 71-36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp7136Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895788.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895788.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895788.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895788.protein.info.v11.5.txt",
		        "node_list_path": "1895788.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895788.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRoot140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRoot140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736460.protein.info.v11.5.txt",
		        "node_list_path": "1736460.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag115Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:115 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag115Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262878.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262878.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262878.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262878.protein.info.v11.5.txt",
		        "node_list_path": "1262878.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262878.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwe23937Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWE2_39_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwe23937Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618950.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618950.protein.info.v11.5.txt",
		        "node_list_path": "1618950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChelatococcusSpCo6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chelatococcus sp. CO-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelatococcusSpCo6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1702325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1702325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1702325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1702325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1702325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1702325.protein.info.v11.5.txt",
		        "node_list_path": "1702325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1702325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpHm582Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. HM58-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpHm582Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1778770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1778770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1778770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1778770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1778770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1778770.protein.info.v11.5.txt",
		        "node_list_path": "1778770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1778770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YooniaVestfoldensisDsm16212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yoonia vestfoldensis DSM 16212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YooniaVestfoldensisDsm16212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122181.protein.info.v11.5.txt",
		        "node_list_path": "1122181.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaDumasiana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria dumasiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaDumasiana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1931275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1931275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1931275.protein.info.v11.5.txt",
		        "node_list_path": "1931275.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg164411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_44_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg164411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797837.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797837.protein.info.v11.5.txt",
		        "node_list_path": "1797837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterHormaecheiSubspXiangfangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. xiangfangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterHormaecheiSubspXiangfangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1296536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296536.protein.info.v11.5.txt",
		        "node_list_path": "1296536.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedTermiteGroup1BacteriumPhylotypeRsD17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Termite group 1 bacterium phylotype Rs-D17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedTermiteGroup1BacteriumPhylotypeRsD17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471821.protein.sequences.v11.5.fa",
		        "enrichment_path": "471821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471821.protein.info.v11.5.txt",
		        "node_list_path": "471821.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumGwa1448(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium GWA1_44_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumGwa1448", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802591.protein.info.v11.5.txt",
		        "node_list_path": "1802591.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAurimucosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium aurimucosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAurimucosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "548476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "548476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "548476.clusters.proteins.v11.5.txt",
		        "sequence_path": "548476.protein.sequences.v11.5.fa",
		        "enrichment_path": "548476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "548476.protein.info.v11.5.txt",
		        "node_list_path": "548476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "548476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RathayibacterToxicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rathayibacter toxicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RathayibacterToxicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123052.protein.info.v11.5.txt",
		        "node_list_path": "1123052.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumDecumbens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium decumbens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumDecumbens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69771.protein.sequences.v11.5.fa",
		        "enrichment_path": "69771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69771.protein.info.v11.5.txt",
		        "node_list_path": "69771.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonadalesBacterium6313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 63-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonadalesBacterium6313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895867.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895867.protein.info.v11.5.txt",
		        "node_list_path": "1895867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiocapsaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiocapsa marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiocapsaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "768671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "768671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "768671.clusters.proteins.v11.5.txt",
		        "sequence_path": "768671.protein.sequences.v11.5.fa",
		        "enrichment_path": "768671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768671.protein.info.v11.5.txt",
		        "node_list_path": "768671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "768671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusBadius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus badius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusBadius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1455.protein.sequences.v11.5.fa",
		        "enrichment_path": "1455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1455.protein.info.v11.5.txt",
		        "node_list_path": "1455.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSp99Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. 99 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSp99Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1163419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1163419.clusters.proteins.v11.5.txt",
		        "sequence_path": "1163419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163419.protein.info.v11.5.txt",
		        "node_list_path": "1163419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1163419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumCb782Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum CB782 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumCb782Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033991.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1033991.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1033991.clusters.proteins.v11.0.txt",
		        "sequence_path": "1033991.protein.sequences.v11.0.fa",
		        "enrichment_path": "1033991.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1033991.protein.info.v11.0.txt",
		        "node_list_path": "1033991.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1033991.protein.cluster.v11.0.txt"
		    }
		]
    )()

def BalneatrixAlpicaDsm16621Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Balneatrix alpica DSM 16621 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BalneatrixAlpicaDsm16621Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121103.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121103.protein.info.v11.5.txt",
		        "node_list_path": "1121103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpLeaf26Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. Leaf26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpLeaf26Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735693.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735693.protein.info.v11.5.txt",
		        "node_list_path": "1735693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EchinococcusGranulosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Echinococcus granulosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EchinococcusGranulosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6210.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6210.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6210.clusters.proteins.v11.5.txt",
		        "sequence_path": "6210.protein.sequences.v11.5.fa",
		        "enrichment_path": "6210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6210.protein.info.v11.5.txt",
		        "node_list_path": "6210.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6210.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseicitreumAntarcticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseicitreum antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseicitreumAntarcticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "564137.protein.sequences.v11.5.fa",
		        "enrichment_path": "564137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "564137.protein.info.v11.5.txt",
		        "node_list_path": "564137.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWs6BacteriumRifoxyb1Full3315(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium RIFOXYB1_FULL_33_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWs6BacteriumRifoxyb1Full3315", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817897.protein.info.v11.5.txt",
		        "node_list_path": "1817897.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionCpr2BacteriumGw2011Gwc23935(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR2 bacterium GW2011_GWC2_39_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionCpr2BacteriumGw2011Gwc23935", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618346.protein.info.v11.5.txt",
		        "node_list_path": "1618346.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaSubspHoutenaeStrAtccBaa1581(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. houtenae str. ATCC BAA-1581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaSubspHoutenaeStrAtccBaa1581", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "523831.protein.sequences.v11.5.fa",
		        "enrichment_path": "523831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523831.protein.info.v11.5.txt",
		        "node_list_path": "523831.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasCryotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas cryotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasCryotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131553.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131553.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131553.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131553.protein.info.v11.5.txt",
		        "node_list_path": "1131553.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131553.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SorangiumCellulosumSo01572Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sorangium cellulosum So01572 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SorangiumCellulosumSo01572Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1254432.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1254432.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1254432.clusters.proteins.v11.5.txt",
		        "sequence_path": "1254432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1254432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1254432.protein.info.v11.5.txt",
		        "node_list_path": "1254432.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1254432.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfonauticusSpA7aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonauticus sp. A7A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonauticusSpA7aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379281.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379281.protein.info.v11.5.txt",
		        "node_list_path": "1379281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpUmwwy(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UMWWY graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpUmwwy", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1370121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1370121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1370121.protein.info.v11.5.txt",
		        "node_list_path": "1370121.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloteneraSpL2l1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera sp. L2L1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraSpL2l1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502770.protein.info.v11.5.txt",
		        "node_list_path": "1502770.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoalloteichusHymeniacidonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoalloteichus hymeniacidonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoalloteichusHymeniacidonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "340345.protein.sequences.v11.5.fa",
		        "enrichment_path": "340345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340345.protein.info.v11.5.txt",
		        "node_list_path": "340345.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaMeridionalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryza meridionalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaMeridionalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40149.protein.sequences.v11.5.fa",
		        "enrichment_path": "40149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40149.protein.info.v11.5.txt",
		        "node_list_path": "40149.protein.complete.v11.5.txt"
		    }
		]
    )()

def HumibacillusSpDsm29435Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Humibacillus sp. DSM 29435 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HumibacillusSpDsm29435Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1869167.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1869167.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1869167.clusters.proteins.v11.5.txt",
		        "sequence_path": "1869167.protein.sequences.v11.5.fa",
		        "enrichment_path": "1869167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1869167.protein.info.v11.5.txt",
		        "node_list_path": "1869167.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1869167.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaCynos(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma cynos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaCynos", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246955.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246955.protein.info.v11.5.txt",
		        "node_list_path": "1246955.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBrocadiaCaroliniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia caroliniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBrocadiaCaroliniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1004156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1004156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1004156.clusters.proteins.v11.5.txt",
		        "sequence_path": "1004156.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004156.protein.info.v11.5.txt",
		        "node_list_path": "1004156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1004156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureobasidiumSubglacialeExf2481(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium subglaciale EXF-2481 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureobasidiumSubglacialeExf2481", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1043005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1043005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1043005.protein.info.v11.5.txt",
		        "node_list_path": "1043005.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpYr247Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. yr247 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpYr247Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761880.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761880.protein.info.v11.5.txt",
		        "node_list_path": "1761880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MuribaculumIntestinale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Muribaculum intestinale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuribaculumIntestinale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1796646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796646.protein.info.v11.5.txt",
		        "node_list_path": "1796646.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasOryzaePxo99aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae PXO99A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasOryzaePxo99aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "360094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "360094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "360094.clusters.proteins.v11.5.txt",
		        "sequence_path": "360094.protein.sequences.v11.5.fa",
		        "enrichment_path": "360094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360094.protein.info.v11.5.txt",
		        "node_list_path": "360094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "360094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSpYr412Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. YR412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpYr412Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881030.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881030.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881030.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881030.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881030.protein.info.v11.5.txt",
		        "node_list_path": "1881030.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881030.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisSk564(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK564 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisSk564", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585203.protein.sequences.v11.5.fa",
		        "enrichment_path": "585203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585203.protein.info.v11.5.txt",
		        "node_list_path": "585203.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumOxidotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium oxidotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumOxidotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397699.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397699.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397699.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397699.protein.info.v11.5.txt",
		        "node_list_path": "1397699.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397699.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4422(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_44_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4422", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802669.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802669.protein.info.v11.5.txt",
		        "node_list_path": "1802669.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumPsychroaquaticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium psychroaquaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumPsychroaquaticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "561061.protein.sequences.v11.5.fa",
		        "enrichment_path": "561061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561061.protein.info.v11.5.txt",
		        "node_list_path": "561061.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpCot290Oh3588(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT-290 OH3588 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpCot290Oh3588", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1515617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1515617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1515617.protein.info.v11.5.txt",
		        "node_list_path": "1515617.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasNoxiaAtcc43541Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas noxia ATCC43541 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasNoxiaAtcc43541Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585503.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585503.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585503.clusters.proteins.v11.5.txt",
		        "sequence_path": "585503.protein.sequences.v11.5.fa",
		        "enrichment_path": "585503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585503.protein.info.v11.5.txt",
		        "node_list_path": "585503.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585503.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPacebacteriaBacteriumCg1024331Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium CG1_02_43_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacebacteriaBacteriumCg1024331Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805299.protein.info.v11.5.txt",
		        "node_list_path": "1805299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumLitorale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium litorale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumLitorale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121324.protein.info.v11.5.txt",
		        "node_list_path": "1121324.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHimb55(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HIMB55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHimb55", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "745014.protein.sequences.v11.0.fa",
		        "enrichment_path": "745014.protein.enrichment.terms.v11.0.txt",
		        "info_path": "745014.protein.info.v11.0.txt",
		        "node_list_path": "745014.protein.complete.v11.0.txt"
		    }
		]
    )()

def ThelaziaCallipaedaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thelazia callipaeda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThelaziaCallipaedaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "103827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "103827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "103827.clusters.proteins.v11.5.txt",
		        "sequence_path": "103827.protein.sequences.v11.5.fa",
		        "enrichment_path": "103827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103827.protein.info.v11.5.txt",
		        "node_list_path": "103827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "103827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesPombe972h(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces pombe 972h- graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesPombe972h", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "284812.protein.sequences.v11.5.fa",
		        "enrichment_path": "284812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284812.protein.info.v11.5.txt",
		        "node_list_path": "284812.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumRadiotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium radiotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumRadiotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426355.protein.sequences.v11.5.fa",
		        "enrichment_path": "426355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426355.protein.info.v11.5.txt",
		        "node_list_path": "426355.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoccidioidesImmitisH5384Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis H538.4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesImmitisH5384Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "396776.clusters.info.v11.5.txt",
		        "cluster_tree_path": "396776.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "396776.clusters.proteins.v11.5.txt",
		        "sequence_path": "396776.protein.sequences.v11.5.fa",
		        "enrichment_path": "396776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396776.protein.info.v11.5.txt",
		        "node_list_path": "396776.cluster.nodes.v11.5.txt",
		        "edge_list_path": "396776.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMacedonicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus macedonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMacedonicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1116231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1116231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1116231.clusters.proteins.v11.5.txt",
		        "sequence_path": "1116231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116231.protein.info.v11.5.txt",
		        "node_list_path": "1116231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1116231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AltibacterLentus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Altibacter lentus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltibacterLentus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223410.protein.info.v11.5.txt",
		        "node_list_path": "1223410.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSp1501(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. 1501 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSp1501", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1002339.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002339.protein.info.v11.5.txt",
		        "node_list_path": "1002339.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterMobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterMobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "488533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "488533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "488533.clusters.proteins.v11.5.txt",
		        "sequence_path": "488533.protein.sequences.v11.5.fa",
		        "enrichment_path": "488533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "488533.protein.info.v11.5.txt",
		        "node_list_path": "488533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "488533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrobacterSpMgh106(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sp. MGH106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterSpMgh106", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1686381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686381.protein.info.v11.5.txt",
		        "node_list_path": "1686381.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriovoraxSpBsw11ivCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. BSW11IV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriovoraxSpBsw11ivCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1353529.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1353529.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1353529.clusters.proteins.v11.5.txt",
		        "sequence_path": "1353529.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353529.protein.info.v11.5.txt",
		        "node_list_path": "1353529.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1353529.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NecatorAmericanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Necator americanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NecatorAmericanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "51031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "51031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "51031.clusters.proteins.v11.5.txt",
		        "sequence_path": "51031.protein.sequences.v11.5.fa",
		        "enrichment_path": "51031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51031.protein.info.v11.5.txt",
		        "node_list_path": "51031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "51031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumTanacetiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum tanaceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumTanacetiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1306861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1306861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1306861.clusters.proteins.v11.5.txt",
		        "sequence_path": "1306861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306861.protein.info.v11.5.txt",
		        "node_list_path": "1306861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1306861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VulcanisaetaMoutnovskia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vulcanisaeta moutnovskia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulcanisaetaMoutnovskia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "985053.protein.sequences.v11.5.fa",
		        "enrichment_path": "985053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985053.protein.info.v11.5.txt",
		        "node_list_path": "985053.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalotaleaAlkalilentaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halotalea alkalilenta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalotaleaAlkalilentaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "376489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "376489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "376489.clusters.proteins.v11.5.txt",
		        "sequence_path": "376489.protein.sequences.v11.5.fa",
		        "enrichment_path": "376489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376489.protein.info.v11.5.txt",
		        "node_list_path": "376489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "376489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaDoshiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella doshiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaDoshiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094553.protein.info.v11.5.txt",
		        "node_list_path": "1094553.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiobacillusDenitrificansDsm12475(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus denitrificans DSM12475 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusDenitrificansDsm12475", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123392.protein.info.v11.5.txt",
		        "node_list_path": "1123392.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAcetothermiaBacteriumJdfr52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acetothermia bacterium JdFR-52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAcetothermiaBacteriumJdfr52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935106.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935106.protein.info.v11.5.txt",
		        "node_list_path": "1935106.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhialocephalaScopiformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phialocephala scopiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhialocephalaScopiformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "149040.clusters.info.v11.5.txt",
		        "cluster_tree_path": "149040.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "149040.clusters.proteins.v11.5.txt",
		        "sequence_path": "149040.protein.sequences.v11.5.fa",
		        "enrichment_path": "149040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "149040.protein.info.v11.5.txt",
		        "node_list_path": "149040.cluster.nodes.v11.5.txt",
		        "edge_list_path": "149040.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesFlavidovirensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavidovirens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesFlavidovirensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123319.protein.info.v11.5.txt",
		        "node_list_path": "1123319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusCarbonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus carbonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusCarbonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "105422.protein.sequences.v11.5.fa",
		        "enrichment_path": "105422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105422.protein.info.v11.5.txt",
		        "node_list_path": "105422.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelcobacillusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helcobacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelcobacillusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521392.protein.sequences.v11.5.fa",
		        "enrichment_path": "521392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521392.protein.info.v11.5.txt",
		        "node_list_path": "521392.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27245(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27245 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27245", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1684144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1684144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1684144.protein.info.v11.5.txt",
		        "node_list_path": "1684144.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanotheceSpPcc7425(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7425 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanotheceSpPcc7425", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "395961.protein.sequences.v11.5.fa",
		        "enrichment_path": "395961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395961.protein.info.v11.5.txt",
		        "node_list_path": "395961.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesBacteriumOlb23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates bacterium OLB23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesBacteriumOlb23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617429.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617429.protein.info.v11.5.txt",
		        "node_list_path": "1617429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumOlb10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumOlb10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617421.protein.info.v11.5.txt",
		        "node_list_path": "1617421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobialesBacteriumClorobi01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobiales bacterium Clorobi_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobialesBacteriumClorobi01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674889.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674889.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674889.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674889.protein.info.v11.5.txt",
		        "node_list_path": "1674889.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674889.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeodactylibacterXiamenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeodactylibacter xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeodactylibacterXiamenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1524460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1524460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1524460.protein.info.v11.5.txt",
		        "node_list_path": "1524460.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisSk321(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisSk321", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585202.protein.sequences.v11.5.fa",
		        "enrichment_path": "585202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585202.protein.info.v11.5.txt",
		        "node_list_path": "585202.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolemyaElarraichensisGillSymbiontCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solemya elarraichensis gill symbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolemyaElarraichensisGillSymbiontCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1918949.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1918949.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1918949.clusters.proteins.v11.5.txt",
		        "sequence_path": "1918949.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918949.protein.info.v11.5.txt",
		        "node_list_path": "1918949.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1918949.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminobacterAmylophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminobacter amylophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminobacterAmylophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "867.protein.sequences.v11.5.fa",
		        "enrichment_path": "867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867.protein.info.v11.5.txt",
		        "node_list_path": "867.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpC9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. C9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpC9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1943579.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1943579.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1943579.clusters.proteins.v11.5.txt",
		        "sequence_path": "1943579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1943579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1943579.protein.info.v11.5.txt",
		        "node_list_path": "1943579.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1943579.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TakifuguRubripesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Takifugu rubripes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TakifuguRubripesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "31033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "31033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "31033.clusters.proteins.v11.5.txt",
		        "sequence_path": "31033.protein.sequences.v11.5.fa",
		        "enrichment_path": "31033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31033.protein.info.v11.5.txt",
		        "node_list_path": "31033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "31033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaedimonasVaricaedens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caedimonas varicaedens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaedimonasVaricaedens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629334.protein.info.v11.5.txt",
		        "node_list_path": "1629334.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerofustisStercorihominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerofustis stercorihominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerofustisStercorihominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445971.protein.sequences.v11.5.fa",
		        "enrichment_path": "445971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445971.protein.info.v11.5.txt",
		        "node_list_path": "445971.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag462Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:462 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag462Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262740.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262740.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262740.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262740.protein.info.v11.5.txt",
		        "node_list_path": "1262740.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262740.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioVulgarisHildenboroughCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio vulgaris Hildenborough Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioVulgarisHildenboroughCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "882.clusters.proteins.v11.5.txt",
		        "sequence_path": "882.protein.sequences.v11.5.fa",
		        "enrichment_path": "882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882.protein.info.v11.5.txt",
		        "node_list_path": "882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaSpPamc26642(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. PAMC 26642 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpPamc26642", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1792307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792307.protein.info.v11.5.txt",
		        "node_list_path": "1792307.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfolobusMetallicusDsm6482Jcm9184Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus metallicus DSM 6482 JCM 9184 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusMetallicusDsm6482Jcm9184Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "523847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "523847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "523847.clusters.proteins.v11.5.txt",
		        "sequence_path": "523847.protein.sequences.v11.5.fa",
		        "enrichment_path": "523847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523847.protein.info.v11.5.txt",
		        "node_list_path": "523847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "523847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpNku1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. NkU-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpNku1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095009.protein.info.v11.5.txt",
		        "node_list_path": "1095009.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetitomaculumRuminisDsm5522(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetitomaculum ruminis DSM 5522 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetitomaculumRuminisDsm5522", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120918.protein.info.v11.5.txt",
		        "node_list_path": "1120918.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumSpA39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium sp. A39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumSpA39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1860100.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1860100.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1860100.clusters.proteins.v11.5.txt",
		        "sequence_path": "1860100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860100.protein.info.v11.5.txt",
		        "node_list_path": "1860100.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1860100.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiothrixFlexilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix flexilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiothrixFlexilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123400.protein.info.v11.5.txt",
		        "node_list_path": "1123400.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumPseudograminearum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium pseudograminearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumPseudograminearum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "101028.protein.sequences.v11.5.fa",
		        "enrichment_path": "101028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101028.protein.info.v11.5.txt",
		        "node_list_path": "101028.protein.complete.v11.5.txt"
		    }
		]
    )()

def NumidumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Numidum massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NumidumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1522315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1522315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1522315.clusters.proteins.v11.5.txt",
		        "sequence_path": "1522315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522315.protein.info.v11.5.txt",
		        "node_list_path": "1522315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1522315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CladophialophoraCarrionii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora carrionii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CladophialophoraCarrionii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86049.protein.sequences.v11.5.fa",
		        "enrichment_path": "86049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86049.protein.info.v11.5.txt",
		        "node_list_path": "86049.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusDelbrueckii2038Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii 2038 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusDelbrueckii2038Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "353496.clusters.info.v11.0.txt",
		        "cluster_tree_path": "353496.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "353496.clusters.proteins.v11.0.txt",
		        "sequence_path": "353496.protein.sequences.v11.0.fa",
		        "enrichment_path": "353496.protein.enrichment.terms.v11.0.txt",
		        "info_path": "353496.protein.info.v11.0.txt",
		        "node_list_path": "353496.cluster.nodes.v11.0.txt",
		        "edge_list_path": "353496.protein.cluster.v11.0.txt"
		    }
		]
    )()

def AcidobacteriaceaeBacteriumKbs96(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs96", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267535.protein.info.v11.5.txt",
		        "node_list_path": "1267535.protein.complete.v11.5.txt"
		    }
		]
    )()

def NoviherbaspirillumAutotrophicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Noviherbaspirillum autotrophicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NoviherbaspirillumAutotrophicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "709839.protein.sequences.v11.5.fa",
		        "enrichment_path": "709839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709839.protein.info.v11.5.txt",
		        "node_list_path": "709839.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpUw4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. UW4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpUw4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1207075.protein.sequences.v11.5.fa",
		        "enrichment_path": "1207075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1207075.protein.info.v11.5.txt",
		        "node_list_path": "1207075.protein.complete.v11.5.txt"
		    }
		]
    )()

def SanguibacterSpLeaf3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter sp. Leaf3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SanguibacterSpLeaf3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736209.protein.info.v11.5.txt",
		        "node_list_path": "1736209.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeF0167(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae F0167 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeF0167", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575593.protein.sequences.v11.5.fa",
		        "enrichment_path": "575593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575593.protein.info.v11.5.txt",
		        "node_list_path": "575593.protein.complete.v11.5.txt"
		    }
		]
    )()

def LutibaculumBaratangenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lutibaculum baratangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutibaculumBaratangenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "631454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "631454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "631454.clusters.proteins.v11.5.txt",
		        "sequence_path": "631454.protein.sequences.v11.5.fa",
		        "enrichment_path": "631454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "631454.protein.info.v11.5.txt",
		        "node_list_path": "631454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "631454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZunongwangiaMangroviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zunongwangia mangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZunongwangiaMangroviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1334022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1334022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1334022.clusters.proteins.v11.5.txt",
		        "sequence_path": "1334022.protein.sequences.v11.5.fa",
		        "enrichment_path": "1334022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1334022.protein.info.v11.5.txt",
		        "node_list_path": "1334022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1334022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloquadratumWalsbyiDsm16790Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi DSM16790 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloquadratumWalsbyiDsm16790Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "362976.clusters.info.v11.5.txt",
		        "cluster_tree_path": "362976.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "362976.clusters.proteins.v11.5.txt",
		        "sequence_path": "362976.protein.sequences.v11.5.fa",
		        "enrichment_path": "362976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362976.protein.info.v11.5.txt",
		        "node_list_path": "362976.cluster.nodes.v11.5.txt",
		        "edge_list_path": "362976.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrotaleaFlava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrotalea flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrotaleaFlava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "714549.protein.sequences.v11.5.fa",
		        "enrichment_path": "714549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "714549.protein.info.v11.5.txt",
		        "node_list_path": "714549.protein.complete.v11.5.txt"
		    }
		]
    )()

def IdiomarinaSpA28l(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sp. A28L graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaSpA28l", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1036674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036674.protein.info.v11.5.txt",
		        "node_list_path": "1036674.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenococcusSpPcc7305Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenococcus sp. PCC7305 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenococcusSpPcc7305Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "102125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "102125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "102125.clusters.proteins.v11.5.txt",
		        "sequence_path": "102125.protein.sequences.v11.5.fa",
		        "enrichment_path": "102125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102125.protein.info.v11.5.txt",
		        "node_list_path": "102125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "102125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSakeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sakei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSakeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314315.clusters.proteins.v11.5.txt",
		        "sequence_path": "314315.protein.sequences.v11.5.fa",
		        "enrichment_path": "314315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314315.protein.info.v11.5.txt",
		        "node_list_path": "314315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusVillorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus villorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusVillorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158604.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158604.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158604.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158604.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158604.protein.info.v11.5.txt",
		        "node_list_path": "1158604.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158604.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusAcidocaldariusDsm446(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius DSM446 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusAcidocaldariusDsm446", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521098.protein.sequences.v11.5.fa",
		        "enrichment_path": "521098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521098.protein.info.v11.5.txt",
		        "node_list_path": "521098.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchleiferiaThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schleiferia thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchleiferiaThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1453500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453500.protein.info.v11.5.txt",
		        "node_list_path": "1453500.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAgassiziiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma agassizii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAgassiziiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33922.clusters.proteins.v11.5.txt",
		        "sequence_path": "33922.protein.sequences.v11.5.fa",
		        "enrichment_path": "33922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33922.protein.info.v11.5.txt",
		        "node_list_path": "33922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterSpMit055293(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT 05-5293 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSpMit055293", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1548149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548149.protein.info.v11.5.txt",
		        "node_list_path": "1548149.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwa25611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_56_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa25611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619044.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619044.protein.info.v11.5.txt",
		        "node_list_path": "1619044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb241528n17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241_528N17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb241528n17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1471456.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471456.protein.info.v11.5.txt",
		        "node_list_path": "1471456.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusRhodnii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus rhodnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusRhodnii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1273125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1273125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1273125.protein.info.v11.5.txt",
		        "node_list_path": "1273125.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisSpCnt312(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. CNT312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisSpCnt312", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1137268.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137268.protein.info.v11.5.txt",
		        "node_list_path": "1137268.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusPushchinoensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus pushchinoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusPushchinoensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "150248.protein.sequences.v11.5.fa",
		        "enrichment_path": "150248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150248.protein.info.v11.5.txt",
		        "node_list_path": "150248.protein.complete.v11.5.txt"
		    }
		]
    )()

def WinogradskyellaSpPg2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Winogradskyella sp. PG-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinogradskyellaSpPg2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "754409.clusters.info.v11.5.txt",
		        "cluster_tree_path": "754409.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "754409.clusters.proteins.v11.5.txt",
		        "sequence_path": "754409.protein.sequences.v11.5.fa",
		        "enrichment_path": "754409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754409.protein.info.v11.5.txt",
		        "node_list_path": "754409.cluster.nodes.v11.5.txt",
		        "edge_list_path": "754409.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OryzaBrachyantha(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryza brachyantha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaBrachyantha", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4533.protein.sequences.v11.5.fa",
		        "enrichment_path": "4533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4533.protein.info.v11.5.txt",
		        "node_list_path": "4533.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassomonasViridansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassomonas viridans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassomonasViridansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "137584.clusters.info.v11.5.txt",
		        "cluster_tree_path": "137584.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "137584.clusters.proteins.v11.5.txt",
		        "sequence_path": "137584.protein.sequences.v11.5.fa",
		        "enrichment_path": "137584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137584.protein.info.v11.5.txt",
		        "node_list_path": "137584.cluster.nodes.v11.5.txt",
		        "edge_list_path": "137584.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynergistesSp31syn1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synergistes sp. 31syn1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynergistesSp31syn1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "457415.protein.sequences.v11.5.fa",
		        "enrichment_path": "457415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457415.protein.info.v11.5.txt",
		        "node_list_path": "457415.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpRoot65Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. Root65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpRoot65Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736576.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736576.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736576.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736576.protein.info.v11.5.txt",
		        "node_list_path": "1736576.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736576.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf24266(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_42_66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf24266", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797351.protein.info.v11.5.txt",
		        "node_list_path": "1797351.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumVaccae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium vaccae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumVaccae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1194972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194972.protein.info.v11.5.txt",
		        "node_list_path": "1194972.protein.complete.v11.5.txt"
		    }
		]
    )()

def DebaryomycesHanseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Debaryomyces hansenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DebaryomycesHanseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4959.clusters.proteins.v11.5.txt",
		        "sequence_path": "4959.protein.sequences.v11.5.fa",
		        "enrichment_path": "4959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4959.protein.info.v11.5.txt",
		        "node_list_path": "4959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumHimb114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumHimb114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "684719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "684719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "684719.clusters.proteins.v11.5.txt",
		        "sequence_path": "684719.protein.sequences.v11.5.fa",
		        "enrichment_path": "684719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "684719.protein.info.v11.5.txt",
		        "node_list_path": "684719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "684719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionivibrioDicarboxylicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionivibrio dicarboxylicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionivibrioDicarboxylicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83767.protein.sequences.v11.5.fa",
		        "enrichment_path": "83767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83767.protein.info.v11.5.txt",
		        "node_list_path": "83767.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasIndica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasIndica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "137658.protein.sequences.v11.5.fa",
		        "enrichment_path": "137658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137658.protein.info.v11.5.txt",
		        "node_list_path": "137658.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumThermoalcaliphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] thermoalcaliphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumThermoalcaliphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29349.protein.sequences.v11.5.fa",
		        "enrichment_path": "29349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29349.protein.info.v11.5.txt",
		        "node_list_path": "29349.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisVancoresmycina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis vancoresmycina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisVancoresmycina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "208444.protein.sequences.v11.5.fa",
		        "enrichment_path": "208444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208444.protein.info.v11.5.txt",
		        "node_list_path": "208444.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110056(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110056 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110056", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1570345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570345.protein.info.v11.5.txt",
		        "node_list_path": "1570345.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylocapsaAurea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylocapsa aurea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocapsaAurea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "663610.protein.sequences.v11.5.fa",
		        "enrichment_path": "663610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663610.protein.info.v11.5.txt",
		        "node_list_path": "663610.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesCaccaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides caccae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCaccaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411901.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411901.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411901.clusters.proteins.v11.5.txt",
		        "sequence_path": "411901.protein.sequences.v11.5.fa",
		        "enrichment_path": "411901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411901.protein.info.v11.5.txt",
		        "node_list_path": "411901.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411901.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PiromycesFinnisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Piromyces finnis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiromycesFinnisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1754191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1754191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1754191.clusters.proteins.v11.5.txt",
		        "sequence_path": "1754191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1754191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1754191.protein.info.v11.5.txt",
		        "node_list_path": "1754191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1754191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesOlivochromogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces olivochromogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesOlivochromogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1963.clusters.proteins.v11.5.txt",
		        "sequence_path": "1963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1963.protein.info.v11.5.txt",
		        "node_list_path": "1963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpJlsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JLS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpJlsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "164757.clusters.info.v11.5.txt",
		        "cluster_tree_path": "164757.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "164757.clusters.proteins.v11.5.txt",
		        "sequence_path": "164757.protein.sequences.v11.5.fa",
		        "enrichment_path": "164757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "164757.protein.info.v11.5.txt",
		        "node_list_path": "164757.cluster.nodes.v11.5.txt",
		        "edge_list_path": "164757.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaMultisaccharivorax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella multisaccharivorax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMultisaccharivorax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "688246.protein.sequences.v11.5.fa",
		        "enrichment_path": "688246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688246.protein.info.v11.5.txt",
		        "node_list_path": "688246.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNealsonbacteriaBacteriumRbg133615Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RBG_13_36_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRbg133615Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801660.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801660.protein.info.v11.5.txt",
		        "node_list_path": "1801660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag389Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:389 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag389Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262801.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262801.protein.info.v11.5.txt",
		        "node_list_path": "1262801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanococcusRifietoensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planococcus rifietoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusRifietoensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "200991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "200991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "200991.clusters.proteins.v11.5.txt",
		        "sequence_path": "200991.protein.sequences.v11.5.fa",
		        "enrichment_path": "200991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200991.protein.info.v11.5.txt",
		        "node_list_path": "200991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "200991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiorhodospiraSibiricaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiorhodospira sibirica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiorhodospiraSibiricaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765914.clusters.proteins.v11.5.txt",
		        "sequence_path": "765914.protein.sequences.v11.5.fa",
		        "enrichment_path": "765914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765914.protein.info.v11.5.txt",
		        "node_list_path": "765914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumSpAb2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. AB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumSpAb2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1484479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484479.protein.info.v11.5.txt",
		        "node_list_path": "1484479.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobonumTyrrellensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobonum tyrrellensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobonumTyrrellensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1324957.protein.sequences.v11.5.fa",
		        "enrichment_path": "1324957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1324957.protein.info.v11.5.txt",
		        "node_list_path": "1324957.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaVincentii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema vincentii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaVincentii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596324.protein.sequences.v11.5.fa",
		        "enrichment_path": "596324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596324.protein.info.v11.5.txt",
		        "node_list_path": "596324.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusAnaerobius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusAnaerobius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261.protein.info.v11.5.txt",
		        "node_list_path": "1261.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaSanticrucisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella santicrucis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaSanticrucisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45074.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45074.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45074.clusters.proteins.v11.5.txt",
		        "sequence_path": "45074.protein.sequences.v11.5.fa",
		        "enrichment_path": "45074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45074.protein.info.v11.5.txt",
		        "node_list_path": "45074.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45074.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DanionellaTranslucidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Danionella translucida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DanionellaTranslucidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "623744.clusters.info.v11.5.txt",
		        "cluster_tree_path": "623744.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "623744.clusters.proteins.v11.5.txt",
		        "sequence_path": "623744.protein.sequences.v11.5.fa",
		        "enrichment_path": "623744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "623744.protein.info.v11.5.txt",
		        "node_list_path": "623744.cluster.nodes.v11.5.txt",
		        "edge_list_path": "623744.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SmaragdicoccusNiigatensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Smaragdicoccus niigatensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmaragdicoccusNiigatensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123258.protein.info.v11.5.txt",
		        "node_list_path": "1123258.protein.complete.v11.5.txt"
		    }
		]
    )()

def BaumanniaCicadellinicolaStrHcHomalodiscaCoagulataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Baumannia cicadellinicola str. Hc (Homalodisca coagulata) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BaumanniaCicadellinicolaStrHcHomalodiscaCoagulataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "374463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "374463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "374463.clusters.proteins.v11.5.txt",
		        "sequence_path": "374463.protein.sequences.v11.5.fa",
		        "enrichment_path": "374463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "374463.protein.info.v11.5.txt",
		        "node_list_path": "374463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "374463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpRoot1497Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. Root1497 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpRoot1497Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736474.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736474.protein.info.v11.5.txt",
		        "node_list_path": "1736474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaRattaustraliani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella rattaustraliani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaRattaustraliani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1205681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1205681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1205681.protein.info.v11.5.txt",
		        "node_list_path": "1205681.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpOv608Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. OV608 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpOv608Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882768.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882768.protein.info.v11.5.txt",
		        "node_list_path": "1882768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaDisiensJcm6334Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella disiens JCM6334 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaDisiensJcm6334Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235811.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235811.protein.info.v11.5.txt",
		        "node_list_path": "1235811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JeotgalicoccusPsychrophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalicoccus psychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalicoccusPsychrophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122129.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122129.protein.info.v11.5.txt",
		        "node_list_path": "1122129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioPonticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ponticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioPonticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "265668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "265668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "265668.clusters.proteins.v11.5.txt",
		        "sequence_path": "265668.protein.sequences.v11.5.fa",
		        "enrichment_path": "265668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265668.protein.info.v11.5.txt",
		        "node_list_path": "265668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "265668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteibacterSp329mfsha(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter sp. 329MFSha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterSp329mfsha", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798239.protein.info.v11.5.txt",
		        "node_list_path": "1798239.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0310(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0310", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888052.protein.sequences.v11.5.fa",
		        "enrichment_path": "888052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888052.protein.info.v11.5.txt",
		        "node_list_path": "888052.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumAlkaliphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum alkaliphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumAlkaliphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121423.protein.info.v11.5.txt",
		        "node_list_path": "1121423.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomicrobiumPiriformeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomicrobium piriforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomicrobiumPiriformeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1576369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1576369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1576369.clusters.proteins.v11.5.txt",
		        "sequence_path": "1576369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1576369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1576369.protein.info.v11.5.txt",
		        "node_list_path": "1576369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1576369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaPulmonicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea pulmonicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaPulmonicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93221.clusters.proteins.v11.5.txt",
		        "sequence_path": "93221.protein.sequences.v11.5.fa",
		        "enrichment_path": "93221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93221.protein.info.v11.5.txt",
		        "node_list_path": "93221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAkibai(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus akibai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAkibai", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236973.protein.info.v11.5.txt",
		        "node_list_path": "1236973.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMojavensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mojavensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMojavensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1051501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1051501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1051501.clusters.proteins.v11.5.txt",
		        "sequence_path": "1051501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051501.protein.info.v11.5.txt",
		        "node_list_path": "1051501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1051501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterPiechaudiiAtcc43553(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii ATCC43553 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterPiechaudiiAtcc43553", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742159.protein.sequences.v11.5.fa",
		        "enrichment_path": "742159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742159.protein.info.v11.5.txt",
		        "node_list_path": "742159.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrinickiaSymbioticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trinickia symbiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrinickiaSymbioticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "863227.clusters.info.v11.5.txt",
		        "cluster_tree_path": "863227.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "863227.clusters.proteins.v11.5.txt",
		        "sequence_path": "863227.protein.sequences.v11.5.fa",
		        "enrichment_path": "863227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "863227.protein.info.v11.5.txt",
		        "node_list_path": "863227.cluster.nodes.v11.5.txt",
		        "edge_list_path": "863227.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FacklamiaHominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Facklamia hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FacklamiaHominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883110.clusters.proteins.v11.5.txt",
		        "sequence_path": "883110.protein.sequences.v11.5.fa",
		        "enrichment_path": "883110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883110.protein.info.v11.5.txt",
		        "node_list_path": "883110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyotisDavidiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myotis davidii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyotisDavidiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "225400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "225400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "225400.clusters.proteins.v11.5.txt",
		        "sequence_path": "225400.protein.sequences.v11.5.fa",
		        "enrichment_path": "225400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225400.protein.info.v11.5.txt",
		        "node_list_path": "225400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "225400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerfeziaBoudieriAtccMya4762(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terfezia boudieri ATCC MYA-4762 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerfeziaBoudieriAtccMya4762", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1051890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051890.protein.info.v11.5.txt",
		        "node_list_path": "1051890.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpCnj954(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. CNJ-954 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpCnj954", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1904962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904962.protein.info.v11.5.txt",
		        "node_list_path": "1904962.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4516Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_12_FULL_45_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4516Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802315.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802315.protein.info.v11.5.txt",
		        "node_list_path": "1802315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaGoodfellowiiDsm19756Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia goodfellowii DSM 19756 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaGoodfellowiiDsm19756Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "714315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "714315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "714315.clusters.proteins.v11.5.txt",
		        "sequence_path": "714315.protein.sequences.v11.5.fa",
		        "enrichment_path": "714315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "714315.protein.info.v11.5.txt",
		        "node_list_path": "714315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "714315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidaceaeBacteriumBroad1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioidaceae bacterium Broad1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidaceaeBacteriumBroad1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "408672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "408672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "408672.clusters.proteins.v11.5.txt",
		        "sequence_path": "408672.protein.sequences.v11.5.fa",
		        "enrichment_path": "408672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408672.protein.info.v11.5.txt",
		        "node_list_path": "408672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "408672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterPyloriSouthafrica7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori SouthAfrica7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterPyloriSouthafrica7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "907239.protein.sequences.v11.5.fa",
		        "enrichment_path": "907239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "907239.protein.info.v11.5.txt",
		        "node_list_path": "907239.protein.complete.v11.5.txt"
		    }
		]
    )()

def RikenellaceaeBacteriumDtu001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium DTU001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RikenellaceaeBacteriumDtu001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671664.protein.info.v11.5.txt",
		        "node_list_path": "1671664.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPelagibacterSpHimb1321(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. HIMB1321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPelagibacterSpHimb1321", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1388755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1388755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1388755.protein.info.v11.5.txt",
		        "node_list_path": "1388755.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanobacteriumAponinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanobacterium aponinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobacteriumAponinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "755178.protein.sequences.v11.5.fa",
		        "enrichment_path": "755178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "755178.protein.info.v11.5.txt",
		        "node_list_path": "755178.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumL18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium L18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumL18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229486.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229486.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229486.protein.info.v11.5.txt",
		        "node_list_path": "1229486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MobiluncusMulieris281(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris 281 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobiluncusMulieris281", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596328.protein.sequences.v11.5.fa",
		        "enrichment_path": "596328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596328.protein.info.v11.5.txt",
		        "node_list_path": "596328.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasLitoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasLitoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "797277.protein.sequences.v11.5.fa",
		        "enrichment_path": "797277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797277.protein.info.v11.5.txt",
		        "node_list_path": "797277.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaDentasiniJcm15908(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella dentasini JCM 15908 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaDentasiniJcm15908", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236509.protein.info.v11.5.txt",
		        "node_list_path": "1236509.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumSpJ15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium sp. J15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumSpJ15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "265901.clusters.info.v11.5.txt",
		        "cluster_tree_path": "265901.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "265901.clusters.proteins.v11.5.txt",
		        "sequence_path": "265901.protein.sequences.v11.5.fa",
		        "enrichment_path": "265901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265901.protein.info.v11.5.txt",
		        "node_list_path": "265901.cluster.nodes.v11.5.txt",
		        "edge_list_path": "265901.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyadobacterBeijingensisDsm21582Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter beijingensis DSM 21582 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterBeijingensisDsm21582Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121482.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121482.protein.info.v11.5.txt",
		        "node_list_path": "1121482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimimaricolaPyoseonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limimaricola pyoseonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimimaricolaPyoseonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521013.clusters.proteins.v11.5.txt",
		        "sequence_path": "521013.protein.sequences.v11.5.fa",
		        "enrichment_path": "521013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521013.protein.info.v11.5.txt",
		        "node_list_path": "521013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumNitrativoransNl23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium nitrativorans NL23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumNitrativoransNl23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1029756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1029756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1029756.protein.info.v11.5.txt",
		        "node_list_path": "1029756.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaEiseniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga eiseniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaEiseniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634771.protein.sequences.v11.5.fa",
		        "enrichment_path": "634771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634771.protein.info.v11.5.txt",
		        "node_list_path": "634771.protein.complete.v11.5.txt"
		    }
		]
    )()

def KwoniellaBestiolaeCbs10118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella bestiolae CBS 10118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KwoniellaBestiolaeCbs10118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1296100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296100.protein.info.v11.5.txt",
		        "node_list_path": "1296100.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaGoodfellowiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia goodfellowii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaGoodfellowiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596323.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596323.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596323.clusters.proteins.v11.5.txt",
		        "sequence_path": "596323.protein.sequences.v11.5.fa",
		        "enrichment_path": "596323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596323.protein.info.v11.5.txt",
		        "node_list_path": "596323.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596323.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasIlicicolaDsm19980(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas ilicicola DSM 19980 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasIlicicolaDsm19980", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121942.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121942.protein.info.v11.5.txt",
		        "node_list_path": "1121942.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoccidioidesImmitisRmscc3703(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis RMSCC 3703 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesImmitisRmscc3703", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "454286.protein.sequences.v11.5.fa",
		        "enrichment_path": "454286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454286.protein.info.v11.5.txt",
		        "node_list_path": "454286.protein.complete.v11.5.txt"
		    }
		]
    )()

def PodarcisMuralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Podarcis muralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PodarcisMuralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "64176.protein.sequences.v11.5.fa",
		        "enrichment_path": "64176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64176.protein.info.v11.5.txt",
		        "node_list_path": "64176.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrococcusFuriosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus furiosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusFuriosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "186497.protein.sequences.v11.5.fa",
		        "enrichment_path": "186497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "186497.protein.info.v11.5.txt",
		        "node_list_path": "186497.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumFerrireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumFerrireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1833852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1833852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1833852.protein.info.v11.5.txt",
		        "node_list_path": "1833852.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcanthamoebaCastellaniiStrNeff(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acanthamoeba castellanii str. Neff graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcanthamoebaCastellaniiStrNeff", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1257118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1257118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1257118.protein.info.v11.5.txt",
		        "node_list_path": "1257118.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobulbusElongatusDsm2908Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus elongatus DSM 2908 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbusElongatusDsm2908Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121402.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121402.protein.info.v11.5.txt",
		        "node_list_path": "1121402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichococcusPalustris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichococcus palustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichococcusPalustris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "140314.protein.sequences.v11.5.fa",
		        "enrichment_path": "140314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "140314.protein.info.v11.5.txt",
		        "node_list_path": "140314.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRbg134510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_13_45_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg134510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798370.protein.info.v11.5.txt",
		        "node_list_path": "1798370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaSpC6a8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema sp. C6A8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSpC6a8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410609.protein.info.v11.5.txt",
		        "node_list_path": "1410609.protein.complete.v11.5.txt"
		    }
		]
    )()

def KwoniellaHeveanensisBcc8398(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella heveanensis BCC8398 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KwoniellaHeveanensisBcc8398", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1296120.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296120.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296120.protein.info.v11.5.txt",
		        "node_list_path": "1296120.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnncaliiaAlgeraePra339(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anncaliia algerae PRA339 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnncaliiaAlgeraePra339", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288291.protein.info.v11.5.txt",
		        "node_list_path": "1288291.protein.complete.v11.5.txt"
		    }
		]
    )()

def GillisiaSpJm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gillisia sp. JM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GillisiaSpJm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1283286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283286.protein.info.v11.5.txt",
		        "node_list_path": "1283286.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSinduriensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sinduriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSinduriensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1384057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384057.protein.info.v11.5.txt",
		        "node_list_path": "1384057.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaTanneraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella tannerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaTanneraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "626522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "626522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "626522.clusters.proteins.v11.5.txt",
		        "sequence_path": "626522.protein.sequences.v11.5.fa",
		        "enrichment_path": "626522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626522.protein.info.v11.5.txt",
		        "node_list_path": "626522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "626522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterAlpinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter alpinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterAlpinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "656366.protein.sequences.v11.5.fa",
		        "enrichment_path": "656366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656366.protein.info.v11.5.txt",
		        "node_list_path": "656366.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRifcsplowo212Full5410Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO2_12_FULL_54_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212Full5410Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797186.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797186.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797186.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797186.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797186.protein.info.v11.5.txt",
		        "node_list_path": "1797186.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797186.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusWynniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus wynnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusWynniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "268407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "268407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "268407.clusters.proteins.v11.5.txt",
		        "sequence_path": "268407.protein.sequences.v11.5.fa",
		        "enrichment_path": "268407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "268407.protein.info.v11.5.txt",
		        "node_list_path": "268407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "268407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusOralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1303.clusters.proteins.v11.5.txt",
		        "sequence_path": "1303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1303.protein.info.v11.5.txt",
		        "node_list_path": "1303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaArizonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia arizonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaArizonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1141647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141647.protein.info.v11.5.txt",
		        "node_list_path": "1141647.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerosporomusaSubterranea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerosporomusa subterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerosporomusaSubterranea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1794912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1794912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1794912.protein.info.v11.5.txt",
		        "node_list_path": "1794912.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAlbusJ1074Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces albus J1074 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAlbusJ1074Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "457425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "457425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "457425.clusters.proteins.v11.5.txt",
		        "sequence_path": "457425.protein.sequences.v11.5.fa",
		        "enrichment_path": "457425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457425.protein.info.v11.5.txt",
		        "node_list_path": "457425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "457425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpD16q13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. D16Q13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpD16q13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855657.protein.info.v11.5.txt",
		        "node_list_path": "1855657.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaSpF0314(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. F0314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSpF0314", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641149.protein.sequences.v11.5.fa",
		        "enrichment_path": "641149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641149.protein.info.v11.5.txt",
		        "node_list_path": "641149.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumAromaticivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium aromaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumAromaticivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "279238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "279238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "279238.clusters.proteins.v11.5.txt",
		        "sequence_path": "279238.protein.sequences.v11.5.fa",
		        "enrichment_path": "279238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279238.protein.info.v11.5.txt",
		        "node_list_path": "279238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "279238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaSpEjp617(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia sp. Ejp617 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaSpEjp617", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "215689.protein.sequences.v11.5.fa",
		        "enrichment_path": "215689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215689.protein.info.v11.5.txt",
		        "node_list_path": "215689.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaFiliformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga filiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaFiliformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "104663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "104663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "104663.clusters.proteins.v11.5.txt",
		        "sequence_path": "104663.protein.sequences.v11.5.fa",
		        "enrichment_path": "104663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104663.protein.info.v11.5.txt",
		        "node_list_path": "104663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "104663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicolaGranulosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola granulosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaGranulosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314256.protein.sequences.v11.5.fa",
		        "enrichment_path": "314256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314256.protein.info.v11.5.txt",
		        "node_list_path": "314256.protein.complete.v11.5.txt"
		    }
		]
    )()

def RufibacterSpDg31dCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rufibacter sp. DG31D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RufibacterSpDg31dCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379910.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379910.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379910.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379910.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379910.protein.info.v11.5.txt",
		        "node_list_path": "1379910.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379910.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisBalhimycinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis balhimycina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisBalhimycinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089545.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089545.protein.info.v11.5.txt",
		        "node_list_path": "1089545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumClostridioformeAgr2157Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] clostridioforme AGR2157 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumClostridioformeAgr2157Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280695.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280695.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280695.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280695.protein.info.v11.5.txt",
		        "node_list_path": "1280695.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280695.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpTth04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. TTH0-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpTth04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1646498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1646498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1646498.clusters.proteins.v11.5.txt",
		        "sequence_path": "1646498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1646498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1646498.protein.info.v11.5.txt",
		        "node_list_path": "1646498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1646498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinokineosporaBangkokensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora bangkokensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinokineosporaBangkokensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193682.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193682.protein.info.v11.5.txt",
		        "node_list_path": "1193682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VagococcusTeuberi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vagococcus teuberi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VagococcusTeuberi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "519472.protein.sequences.v11.5.fa",
		        "enrichment_path": "519472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519472.protein.info.v11.5.txt",
		        "node_list_path": "519472.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho212Full4519b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_12_FULL_45_19b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho212Full4519b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802689.protein.info.v11.5.txt",
		        "node_list_path": "1802689.protein.complete.v11.5.txt"
		    }
		]
    )()

def KutzneriaAlbidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kutzneria albida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KutzneriaAlbidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449976.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449976.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449976.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449976.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449976.protein.info.v11.5.txt",
		        "node_list_path": "1449976.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449976.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasHydrophilaYl17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila YL17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasHydrophilaYl17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1448139.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448139.protein.info.v11.5.txt",
		        "node_list_path": "1448139.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfurellaAmilsii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurella amilsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurellaAmilsii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1562698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1562698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1562698.protein.info.v11.5.txt",
		        "node_list_path": "1562698.protein.complete.v11.5.txt"
		    }
		]
    )()

def CutaneotrichosporonOleaginosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cutaneotrichosporon oleaginosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CutaneotrichosporonOleaginosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "879819.protein.sequences.v11.5.fa",
		        "enrichment_path": "879819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879819.protein.info.v11.5.txt",
		        "node_list_path": "879819.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumGwb1558(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWB1_55_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumGwb1558", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797386.protein.info.v11.5.txt",
		        "node_list_path": "1797386.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpOralTaxon299StrF0039(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. oral taxon 299 str. F0039 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpOralTaxon299StrF0039", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575614.protein.sequences.v11.5.fa",
		        "enrichment_path": "575614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575614.protein.info.v11.5.txt",
		        "node_list_path": "575614.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyclobacteriumHalophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacterium halophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyclobacteriumHalophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1416801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1416801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1416801.clusters.proteins.v11.5.txt",
		        "sequence_path": "1416801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416801.protein.info.v11.5.txt",
		        "node_list_path": "1416801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1416801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaSalmonicida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia salmonicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSalmonicida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53431.protein.sequences.v11.5.fa",
		        "enrichment_path": "53431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53431.protein.info.v11.5.txt",
		        "node_list_path": "53431.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarineGroupIiEuryarchaeoteRedseaS11B3n4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marine group II euryarchaeote REDSEA-S11_B3N4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineGroupIiEuryarchaeoteRedseaS11B3n4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811651.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811651.protein.info.v11.5.txt",
		        "node_list_path": "1811651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag251Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag251Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262886.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262886.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262886.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262886.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262886.protein.info.v11.5.txt",
		        "node_list_path": "1262886.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262886.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SegetibacterKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Segetibacter koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SegetibacterKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123248.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123248.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123248.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123248.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123248.protein.info.v11.5.txt",
		        "node_list_path": "1123248.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123248.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifcsplowo212Full5310Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_12_FULL_53_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo212Full5310Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801930.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801930.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801930.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801930.protein.info.v11.5.txt",
		        "node_list_path": "1801930.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801930.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchistocephalusSolidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schistocephalus solidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistocephalusSolidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "70667.clusters.info.v11.5.txt",
		        "cluster_tree_path": "70667.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "70667.clusters.proteins.v11.5.txt",
		        "sequence_path": "70667.protein.sequences.v11.5.fa",
		        "enrichment_path": "70667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "70667.protein.info.v11.5.txt",
		        "node_list_path": "70667.cluster.nodes.v11.5.txt",
		        "edge_list_path": "70667.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusGallinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGallinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423748.protein.info.v11.5.txt",
		        "node_list_path": "1423748.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSepticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium septicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSepticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1341646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1341646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1341646.clusters.proteins.v11.5.txt",
		        "sequence_path": "1341646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341646.protein.info.v11.5.txt",
		        "node_list_path": "1341646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1341646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg136114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_61_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg136114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797834.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797834.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797834.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797834.protein.info.v11.5.txt",
		        "node_list_path": "1797834.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797834.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterLuteusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterLuteusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "572036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "572036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "572036.clusters.proteins.v11.5.txt",
		        "sequence_path": "572036.protein.sequences.v11.5.fa",
		        "enrichment_path": "572036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572036.protein.info.v11.5.txt",
		        "node_list_path": "572036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "572036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatellicoccusMarimammaliumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catellicoccus marimammalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatellicoccusMarimammaliumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1234409.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1234409.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1234409.clusters.proteins.v11.5.txt",
		        "sequence_path": "1234409.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234409.protein.info.v11.5.txt",
		        "node_list_path": "1234409.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1234409.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalmonellaBongoriN26808Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella bongori N26808 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaBongoriN26808Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1197719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1197719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1197719.clusters.proteins.v11.5.txt",
		        "sequence_path": "1197719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197719.protein.info.v11.5.txt",
		        "node_list_path": "1197719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1197719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VignaAngularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vigna angularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VignaAngularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3914.clusters.proteins.v11.5.txt",
		        "sequence_path": "3914.protein.sequences.v11.5.fa",
		        "enrichment_path": "3914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3914.protein.info.v11.5.txt",
		        "node_list_path": "3914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumSpBs2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. BS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumSpBs2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936550.protein.sequences.v11.5.fa",
		        "enrichment_path": "936550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936550.protein.info.v11.5.txt",
		        "node_list_path": "936550.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPhocaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium phocae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPhocaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "161895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "161895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "161895.clusters.proteins.v11.5.txt",
		        "sequence_path": "161895.protein.sequences.v11.5.fa",
		        "enrichment_path": "161895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161895.protein.info.v11.5.txt",
		        "node_list_path": "161895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "161895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprinopsisCinereaOkayama7130Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprinopsis cinerea okayama7#130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprinopsisCinereaOkayama7130Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "240176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "240176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "240176.clusters.proteins.v11.5.txt",
		        "sequence_path": "240176.protein.sequences.v11.5.fa",
		        "enrichment_path": "240176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240176.protein.info.v11.5.txt",
		        "node_list_path": "240176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "240176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporosarcinaKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "334735.protein.sequences.v11.5.fa",
		        "enrichment_path": "334735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334735.protein.info.v11.5.txt",
		        "node_list_path": "334735.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpUrha0033(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. URHA0033 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpUrha0033", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298862.protein.info.v11.5.txt",
		        "node_list_path": "1298862.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterCuniculorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter cuniculorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterCuniculorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121267.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121267.protein.info.v11.5.txt",
		        "node_list_path": "1121267.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaBryantii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bryantii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBryantii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "77095.protein.sequences.v11.5.fa",
		        "enrichment_path": "77095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77095.protein.info.v11.5.txt",
		        "node_list_path": "77095.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumGillisiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium gillisiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumGillisiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "150146.protein.sequences.v11.5.fa",
		        "enrichment_path": "150146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150146.protein.info.v11.5.txt",
		        "node_list_path": "150146.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophusFodinaeScgcAaa011A17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophus fodinae SCGC AAA011-A17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophusFodinaeScgcAaa011A17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "699264.protein.sequences.v11.5.fa",
		        "enrichment_path": "699264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "699264.protein.info.v11.5.txt",
		        "node_list_path": "699264.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumRifcsplowo201Full3912Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFCSPLOWO2_01_FULL_39_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifcsplowo201Full3912Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801897.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801897.protein.info.v11.5.txt",
		        "node_list_path": "1801897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CycloclasticusSpSymbiontOfPoeciloscleridaSpMCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Poecilosclerida sp. M Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CycloclasticusSpSymbiontOfPoeciloscleridaSpMCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1840537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1840537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1840537.clusters.proteins.v11.5.txt",
		        "sequence_path": "1840537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1840537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1840537.protein.info.v11.5.txt",
		        "node_list_path": "1840537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1840537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumGloeosporioidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum gloeosporioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumGloeosporioidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "474922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "474922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "474922.clusters.proteins.v11.5.txt",
		        "sequence_path": "474922.protein.sequences.v11.5.fa",
		        "enrichment_path": "474922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "474922.protein.info.v11.5.txt",
		        "node_list_path": "474922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "474922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4127(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4127", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802662.protein.info.v11.5.txt",
		        "node_list_path": "1802662.protein.complete.v11.5.txt"
		    }
		]
    )()

def ModestobacterSpDsm44400Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Modestobacter sp. DSM 44400 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ModestobacterSpDsm44400Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1550230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1550230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1550230.clusters.proteins.v11.5.txt",
		        "sequence_path": "1550230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550230.protein.info.v11.5.txt",
		        "node_list_path": "1550230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1550230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaBrevisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBrevisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410666.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410666.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410666.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410666.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410666.protein.info.v11.5.txt",
		        "node_list_path": "1410666.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410666.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetothermiaBacterium6432(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetothermia bacterium 64_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetothermiaBacterium6432", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635286.protein.info.v11.5.txt",
		        "node_list_path": "1635286.protein.complete.v11.5.txt"
		    }
		]
    )()

def CercosporaZeinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cercospora zeina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CercosporaZeinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "348901.clusters.info.v11.5.txt",
		        "cluster_tree_path": "348901.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "348901.clusters.proteins.v11.5.txt",
		        "sequence_path": "348901.protein.sequences.v11.5.fa",
		        "enrichment_path": "348901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "348901.protein.info.v11.5.txt",
		        "node_list_path": "348901.cluster.nodes.v11.5.txt",
		        "edge_list_path": "348901.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumGallicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium gallicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumGallicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041138.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041138.protein.info.v11.5.txt",
		        "node_list_path": "1041138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSalivariusUcc118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus salivarius UCC118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSalivariusUcc118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "362948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "362948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "362948.clusters.proteins.v11.5.txt",
		        "sequence_path": "362948.protein.sequences.v11.5.fa",
		        "enrichment_path": "362948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362948.protein.info.v11.5.txt",
		        "node_list_path": "362948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "362948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBrocadiaSpUtamx1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sp. UTAMX1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBrocadiaSpUtamx1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1961113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1961113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1961113.clusters.proteins.v11.5.txt",
		        "sequence_path": "1961113.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961113.protein.info.v11.5.txt",
		        "node_list_path": "1961113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1961113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonadalesBacteriumRifoxya1Full6910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium RIFOXYA1_FULL_69_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonadalesBacteriumRifoxya1Full6910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802656.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802656.protein.info.v11.5.txt",
		        "node_list_path": "1802656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpRoot342Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root342 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpRoot342Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736519.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736519.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736519.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736519.protein.info.v11.5.txt",
		        "node_list_path": "1736519.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736519.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlexibacterLitoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flexibacter litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlexibacterLitoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "880071.protein.sequences.v11.5.fa",
		        "enrichment_path": "880071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880071.protein.info.v11.5.txt",
		        "node_list_path": "880071.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaSpZbg7aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina sp. ZBG7A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaSpZbg7aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1582223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1582223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1582223.clusters.proteins.v11.5.txt",
		        "sequence_path": "1582223.protein.sequences.v11.5.fa",
		        "enrichment_path": "1582223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1582223.protein.info.v11.5.txt",
		        "node_list_path": "1582223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1582223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CommensalibacterIntestini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Commensalibacter intestini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CommensalibacterIntestini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1088868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1088868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1088868.protein.info.v11.5.txt",
		        "node_list_path": "1088868.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloferaxElongansAtccBaa1513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloferax elongans ATCC BAA-1513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloferaxElongansAtccBaa1513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230453.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230453.protein.info.v11.5.txt",
		        "node_list_path": "1230453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenirhodobacterEnshiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenirhodobacter enshiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenirhodobacterEnshiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1105367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1105367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1105367.clusters.proteins.v11.5.txt",
		        "sequence_path": "1105367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1105367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1105367.protein.info.v11.5.txt",
		        "node_list_path": "1105367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1105367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifcsphigho202Full4012bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_02_FULL_40_12b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho202Full4012bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801639.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801639.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801639.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801639.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801639.protein.info.v11.5.txt",
		        "node_list_path": "1801639.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801639.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LutibacterOricolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lutibacter oricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LutibacterOricolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762486.clusters.proteins.v11.5.txt",
		        "sequence_path": "762486.protein.sequences.v11.5.fa",
		        "enrichment_path": "762486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762486.protein.info.v11.5.txt",
		        "node_list_path": "762486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg135819(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_58_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg135819", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797832.protein.info.v11.5.txt",
		        "node_list_path": "1797832.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesYokosukanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces yokosukanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesYokosukanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67386.clusters.proteins.v11.5.txt",
		        "sequence_path": "67386.protein.sequences.v11.5.fa",
		        "enrichment_path": "67386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67386.protein.info.v11.5.txt",
		        "node_list_path": "67386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSpHh01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. HH01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSpHh01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1198452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198452.protein.info.v11.5.txt",
		        "node_list_path": "1198452.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeminicoccusRoseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geminicoccus roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeminicoccusRoseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089551.protein.info.v11.5.txt",
		        "node_list_path": "1089551.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhialosimplexSpHf37Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phialosimplex sp. HF37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhialosimplexSpHf37Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1960876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1960876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1960876.clusters.proteins.v11.5.txt",
		        "sequence_path": "1960876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1960876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1960876.protein.info.v11.5.txt",
		        "node_list_path": "1960876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1960876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerobiumAcetethylicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobium acetethylicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobiumAcetethylicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619234.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619234.protein.info.v11.5.txt",
		        "node_list_path": "1619234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanobiumSpPcc7001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanobium sp. PCC7001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobiumSpPcc7001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "180281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "180281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "180281.clusters.proteins.v11.5.txt",
		        "sequence_path": "180281.protein.sequences.v11.5.fa",
		        "enrichment_path": "180281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180281.protein.info.v11.5.txt",
		        "node_list_path": "180281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "180281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumSpF0372Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium sp. F0372 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumSpF0372Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203605.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203605.protein.info.v11.5.txt",
		        "node_list_path": "1203605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BombellaIntestini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bombella intestini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BombellaIntestini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1539051.protein.sequences.v11.5.fa",
		        "enrichment_path": "1539051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1539051.protein.info.v11.5.txt",
		        "node_list_path": "1539051.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumGw2011Gwc23922(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWC2_39_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwc23922", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619013.protein.info.v11.5.txt",
		        "node_list_path": "1619013.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCrk20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCrk20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1452536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1452536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1452536.protein.info.v11.5.txt",
		        "node_list_path": "1452536.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlattellaGermanica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blattella germanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattellaGermanica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6973.protein.sequences.v11.5.fa",
		        "enrichment_path": "6973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6973.protein.info.v11.5.txt",
		        "node_list_path": "6973.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpRoot217(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpRoot217", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736492.protein.info.v11.5.txt",
		        "node_list_path": "1736492.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetschnikowiaAffPulcherrimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metschnikowia aff. pulcherrima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetschnikowiaAffPulcherrimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2163413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2163413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2163413.clusters.proteins.v11.5.txt",
		        "sequence_path": "2163413.protein.sequences.v11.5.fa",
		        "enrichment_path": "2163413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2163413.protein.info.v11.5.txt",
		        "node_list_path": "2163413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2163413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusPoinariiG6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus poinarii G6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusPoinariiG6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354304.protein.info.v11.5.txt",
		        "node_list_path": "1354304.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaMuridarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia muridarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaMuridarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243161.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243161.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243161.clusters.proteins.v11.5.txt",
		        "sequence_path": "243161.protein.sequences.v11.5.fa",
		        "enrichment_path": "243161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243161.protein.info.v11.5.txt",
		        "node_list_path": "243161.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243161.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeleribacterBaekdonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Celeribacter baekdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeleribacterBaekdonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208323.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208323.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208323.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208323.protein.info.v11.5.txt",
		        "node_list_path": "1208323.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208323.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterSwuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter swuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSwuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227739.protein.info.v11.5.txt",
		        "node_list_path": "1227739.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterPasteurianus3p3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus 3P3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterPasteurianus3p3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "940282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "940282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "940282.clusters.proteins.v11.5.txt",
		        "sequence_path": "940282.protein.sequences.v11.5.fa",
		        "enrichment_path": "940282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "940282.protein.info.v11.5.txt",
		        "node_list_path": "940282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "940282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHtcc2148(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2148", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "247634.protein.sequences.v11.0.fa",
		        "enrichment_path": "247634.protein.enrichment.terms.v11.0.txt",
		        "info_path": "247634.protein.info.v11.0.txt",
		        "node_list_path": "247634.protein.complete.v11.0.txt"
		    }
		]
    )()

def ElioraeaTepidiphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elioraea tepidiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElioraeaTepidiphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121861.protein.info.v11.5.txt",
		        "node_list_path": "1121861.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSuisEa183292Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis EA183292 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSuisEa183292Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321372.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321372.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321372.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321372.protein.info.v11.5.txt",
		        "node_list_path": "1321372.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321372.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoselliniaNecatrix(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rosellinia necatrix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoselliniaNecatrix", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "77044.protein.sequences.v11.5.fa",
		        "enrichment_path": "77044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77044.protein.info.v11.5.txt",
		        "node_list_path": "77044.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospirillumFerriphilumMl04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospirillum ferriphilum ML-04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospirillumFerriphilumMl04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1048260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048260.protein.info.v11.5.txt",
		        "node_list_path": "1048260.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGa0077532(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077532 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077532", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752201.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752201.protein.info.v11.5.txt",
		        "node_list_path": "1752201.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200240037Sch5390672(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-40037_SCH5390672 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200240037Sch5390672", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834089.protein.info.v11.5.txt",
		        "node_list_path": "1834089.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPacebacteriaBacteriumCg2303639Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium CG2_30_36_39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacebacteriaBacteriumCg2303639Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805300.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805300.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805300.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805300.protein.info.v11.5.txt",
		        "node_list_path": "1805300.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805300.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OribacteriumSinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585501.clusters.proteins.v11.5.txt",
		        "sequence_path": "585501.protein.sequences.v11.5.fa",
		        "enrichment_path": "585501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585501.protein.info.v11.5.txt",
		        "node_list_path": "585501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpBnl1100(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. BNL1100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpBnl1100", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "755731.protein.sequences.v11.5.fa",
		        "enrichment_path": "755731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "755731.protein.info.v11.5.txt",
		        "node_list_path": "755731.protein.complete.v11.5.txt"
		    }
		]
    )()

def IntestinimonasButyriciproducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Intestinimonas butyriciproducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntestinimonasButyriciproducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1297617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297617.protein.info.v11.5.txt",
		        "node_list_path": "1297617.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrovirgaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microvirga massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033741.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033741.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033741.protein.info.v11.5.txt",
		        "node_list_path": "1033741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifoxyd2Full4114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD2_FULL_41_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd2Full4114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798709.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798709.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798709.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798709.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798709.protein.info.v11.5.txt",
		        "node_list_path": "1798709.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798709.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgaricusBisporusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agaricus bisporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgaricusBisporusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5341.clusters.proteins.v11.5.txt",
		        "sequence_path": "5341.protein.sequences.v11.5.fa",
		        "enrichment_path": "5341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5341.protein.info.v11.5.txt",
		        "node_list_path": "5341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaritaleaMyrionectaeDsm19524(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maritalea myrionectae DSM 19524 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaritaleaMyrionectaeDsm19524", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122213.protein.info.v11.5.txt",
		        "node_list_path": "1122213.protein.complete.v11.5.txt"
		    }
		]
    )()

def PusillimonasSpT77Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pusillimonas sp. T77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PusillimonasSpT77Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1007105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1007105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1007105.clusters.proteins.v11.5.txt",
		        "sequence_path": "1007105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007105.protein.info.v11.5.txt",
		        "node_list_path": "1007105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1007105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumAcmicro1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium acMicro-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumAcmicro1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1504316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504316.protein.info.v11.5.txt",
		        "node_list_path": "1504316.protein.complete.v11.5.txt"
		    }
		]
    )()

def LelliottiaAmnigenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lelliottia amnigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LelliottiaAmnigenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61646.clusters.proteins.v11.5.txt",
		        "sequence_path": "61646.protein.sequences.v11.5.fa",
		        "enrichment_path": "61646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61646.protein.info.v11.5.txt",
		        "node_list_path": "61646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinibacterRuberCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinibacter ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinibacterRuberCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "309807.clusters.info.v11.5.txt",
		        "cluster_tree_path": "309807.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "309807.clusters.proteins.v11.5.txt",
		        "sequence_path": "309807.protein.sequences.v11.5.fa",
		        "enrichment_path": "309807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "309807.protein.info.v11.5.txt",
		        "node_list_path": "309807.cluster.nodes.v11.5.txt",
		        "edge_list_path": "309807.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedAcidilobusSpMg(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Acidilobus sp. MG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedAcidilobusSpMg", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410573.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410573.protein.info.v11.5.txt",
		        "node_list_path": "1410573.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoriobacteriaceaeBacteriumGd5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium GD5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacteriaceaeBacteriumGd5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232436.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232436.protein.info.v11.5.txt",
		        "node_list_path": "1232436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophilaceaeBacterium11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophilaceae bacterium 11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilaceaeBacterium11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1101195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101195.protein.info.v11.5.txt",
		        "node_list_path": "1101195.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyricimonasSpMarseilleP2440Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyricimonas sp. Marseille-P2440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyricimonasSpMarseilleP2440Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816677.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816677.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816677.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816677.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816677.protein.info.v11.5.txt",
		        "node_list_path": "1816677.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816677.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphaerobacterThermophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaerobacter thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerobacterThermophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "479434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "479434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "479434.clusters.proteins.v11.5.txt",
		        "sequence_path": "479434.protein.sequences.v11.5.fa",
		        "enrichment_path": "479434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479434.protein.info.v11.5.txt",
		        "node_list_path": "479434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "479434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBohemicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bohemicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBohemicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437606.protein.info.v11.5.txt",
		        "node_list_path": "1437606.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumSpRoot1290Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. Root1290 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumSpRoot1290Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736445.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736445.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736445.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736445.protein.info.v11.5.txt",
		        "node_list_path": "1736445.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736445.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpOk091(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. OK091 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpOk091", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881037.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881037.protein.info.v11.5.txt",
		        "node_list_path": "1881037.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifoxyb1Full4614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFOXYB1_FULL_46_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifoxyb1Full4614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798531.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798531.protein.info.v11.5.txt",
		        "node_list_path": "1798531.protein.complete.v11.5.txt"
		    }
		]
    )()

def SuccinatimonasHippeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Succinatimonas hippei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuccinatimonasHippeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762983.clusters.proteins.v11.5.txt",
		        "sequence_path": "762983.protein.sequences.v11.5.fa",
		        "enrichment_path": "762983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762983.protein.info.v11.5.txt",
		        "node_list_path": "762983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrametesCinnabarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trametes cinnabarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrametesCinnabarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5643.protein.sequences.v11.5.fa",
		        "enrichment_path": "5643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5643.protein.info.v11.5.txt",
		        "node_list_path": "5643.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermaerobacterSubterraneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermaerobacter subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermaerobacterSubterraneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "867903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "867903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "867903.clusters.proteins.v11.5.txt",
		        "sequence_path": "867903.protein.sequences.v11.5.fa",
		        "enrichment_path": "867903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867903.protein.info.v11.5.txt",
		        "node_list_path": "867903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "867903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpYs1rCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. YS1r Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpYs1rCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1532558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1532558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1532558.clusters.proteins.v11.5.txt",
		        "sequence_path": "1532558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1532558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1532558.protein.info.v11.5.txt",
		        "node_list_path": "1532558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1532558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasSobria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas sobria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSobria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "646.protein.sequences.v11.5.fa",
		        "enrichment_path": "646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "646.protein.info.v11.5.txt",
		        "node_list_path": "646.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidithiobacillusFerrivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithiobacillusFerrivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743299.protein.sequences.v11.5.fa",
		        "enrichment_path": "743299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743299.protein.info.v11.5.txt",
		        "node_list_path": "743299.protein.complete.v11.5.txt"
		    }
		]
    )()

def PythiumUltimumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pythium ultimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PythiumUltimumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "65071.clusters.info.v11.5.txt",
		        "cluster_tree_path": "65071.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "65071.clusters.proteins.v11.5.txt",
		        "sequence_path": "65071.protein.sequences.v11.5.fa",
		        "enrichment_path": "65071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65071.protein.info.v11.5.txt",
		        "node_list_path": "65071.cluster.nodes.v11.5.txt",
		        "edge_list_path": "65071.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GelatoporiaSubvermisporaB(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gelatoporia subvermispora B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GelatoporiaSubvermisporaB", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "914234.protein.sequences.v11.5.fa",
		        "enrichment_path": "914234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "914234.protein.info.v11.5.txt",
		        "node_list_path": "914234.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesClarus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides clarus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesClarus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762984.protein.sequences.v11.5.fa",
		        "enrichment_path": "762984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762984.protein.info.v11.5.txt",
		        "node_list_path": "762984.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumDoosanenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium doosanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumDoosanenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "558173.clusters.info.v11.5.txt",
		        "cluster_tree_path": "558173.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "558173.clusters.proteins.v11.5.txt",
		        "sequence_path": "558173.protein.sequences.v11.5.fa",
		        "enrichment_path": "558173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558173.protein.info.v11.5.txt",
		        "node_list_path": "558173.cluster.nodes.v11.5.txt",
		        "edge_list_path": "558173.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpMmlr14006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MMLR14_006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpMmlr14006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1898742.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898742.protein.info.v11.5.txt",
		        "node_list_path": "1898742.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpRr217(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Rr 217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpRr217", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "555793.protein.sequences.v11.5.fa",
		        "enrichment_path": "555793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555793.protein.info.v11.5.txt",
		        "node_list_path": "555793.protein.complete.v11.5.txt"
		    }
		]
    )()

def AdlercreutziaEquolifaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Adlercreutzia equolifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AdlercreutziaEquolifaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1384484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384484.protein.info.v11.5.txt",
		        "node_list_path": "1384484.protein.complete.v11.5.txt"
		    }
		]
    )()

def MariprofundusFerrooxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mariprofundus ferrooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MariprofundusFerrooxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314345.clusters.proteins.v11.5.txt",
		        "sequence_path": "314345.protein.sequences.v11.5.fa",
		        "enrichment_path": "314345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314345.protein.info.v11.5.txt",
		        "node_list_path": "314345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyotisLucifugus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myotis lucifugus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyotisLucifugus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59463.protein.sequences.v11.5.fa",
		        "enrichment_path": "59463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59463.protein.info.v11.5.txt",
		        "node_list_path": "59463.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfobacteriumThermophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfobacteriumThermophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123373.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123373.protein.info.v11.5.txt",
		        "node_list_path": "1123373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaFlavescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaFlavescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1715806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1715806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1715806.clusters.proteins.v11.5.txt",
		        "sequence_path": "1715806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715806.protein.info.v11.5.txt",
		        "node_list_path": "1715806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1715806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPaucisporeusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces paucisporeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPaucisporeusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "310782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "310782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "310782.clusters.proteins.v11.5.txt",
		        "sequence_path": "310782.protein.sequences.v11.5.fa",
		        "enrichment_path": "310782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "310782.protein.info.v11.5.txt",
		        "node_list_path": "310782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "310782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaSpWd121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. WD12.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpWd121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1933903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1933903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1933903.clusters.proteins.v11.5.txt",
		        "sequence_path": "1933903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933903.protein.info.v11.5.txt",
		        "node_list_path": "1933903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1933903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomicrobiumAlbumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomicrobium album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomicrobiumAlbumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "686340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "686340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "686340.clusters.proteins.v11.5.txt",
		        "sequence_path": "686340.protein.sequences.v11.5.fa",
		        "enrichment_path": "686340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686340.protein.info.v11.5.txt",
		        "node_list_path": "686340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "686340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMacedonicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus macedonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMacedonicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1116231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116231.protein.info.v11.5.txt",
		        "node_list_path": "1116231.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtopostipesSuicloacalisDsm15692(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopostipes suicloacalis DSM 15692 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopostipesSuicloacalisDsm15692", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121025.protein.info.v11.5.txt",
		        "node_list_path": "1121025.protein.complete.v11.5.txt"
		    }
		]
    )()

def BeggiatoaLeptomitoformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Beggiatoa leptomitoformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeggiatoaLeptomitoformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "288004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "288004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "288004.clusters.proteins.v11.5.txt",
		        "sequence_path": "288004.protein.sequences.v11.5.fa",
		        "enrichment_path": "288004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "288004.protein.info.v11.5.txt",
		        "node_list_path": "288004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "288004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag413(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:413 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag413", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262803.protein.info.v11.5.txt",
		        "node_list_path": "1262803.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtribacteriaBacteriumScgcAaa252M02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atribacteria bacterium SCGC AAA252-M02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtribacteriaBacteriumScgcAaa252M02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "913317.protein.sequences.v11.5.fa",
		        "enrichment_path": "913317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913317.protein.info.v11.5.txt",
		        "node_list_path": "913317.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonadaceaeBacteriumBrhC29Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonadaceae bacterium BRH_c29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonadaceaeBacteriumBrhC29Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629720.protein.info.v11.5.txt",
		        "node_list_path": "1629720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfomicrobiumOraleDsm12838Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium orale DSM 12838 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfomicrobiumOraleDsm12838Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888061.clusters.proteins.v11.5.txt",
		        "sequence_path": "888061.protein.sequences.v11.5.fa",
		        "enrichment_path": "888061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888061.protein.info.v11.5.txt",
		        "node_list_path": "888061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNealsonbacteriaBacteriumRifoxyb1Full4015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFOXYB1_FULL_40_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifoxyb1Full4015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801677.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801677.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801677.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801677.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801677.protein.info.v11.5.txt",
		        "node_list_path": "1801677.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801677.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumDiphtheriaeNctc13129Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium diphtheriae NCTC 13129 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumDiphtheriaeNctc13129Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "257309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "257309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "257309.clusters.proteins.v11.5.txt",
		        "sequence_path": "257309.protein.sequences.v11.5.fa",
		        "enrichment_path": "257309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "257309.protein.info.v11.5.txt",
		        "node_list_path": "257309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "257309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpJ39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. J39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpJ39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935848.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935848.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935848.clusters.proteins.v11.5.txt",
		        "sequence_path": "935848.protein.sequences.v11.5.fa",
		        "enrichment_path": "935848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935848.protein.info.v11.5.txt",
		        "node_list_path": "935848.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935848.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalilimnicolaEhrlichii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalilimnicola ehrlichii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalilimnicolaEhrlichii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "187272.protein.sequences.v11.5.fa",
		        "enrichment_path": "187272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "187272.protein.info.v11.5.txt",
		        "node_list_path": "187272.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMicrogenomatusAuricolaScgcAaa011E14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Microgenomatus auricola SCGC AAA011-E14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMicrogenomatusAuricolaScgcAaa011E14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1047003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1047003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1047003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1047003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1047003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1047003.protein.info.v11.5.txt",
		        "node_list_path": "1047003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1047003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurimonasSpAst10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. AST10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasSpAst10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1172190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1172190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1172190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1172190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172190.protein.info.v11.5.txt",
		        "node_list_path": "1172190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1172190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiribacterSpUahsp71Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiribacter sp. UAHSP71 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiribacterSpUahsp71Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1335757.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1335757.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1335757.clusters.proteins.v11.5.txt",
		        "sequence_path": "1335757.protein.sequences.v11.5.fa",
		        "enrichment_path": "1335757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1335757.protein.info.v11.5.txt",
		        "node_list_path": "1335757.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1335757.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusFulgidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus fulgidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusFulgidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "224325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "224325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "224325.clusters.proteins.v11.5.txt",
		        "sequence_path": "224325.protein.sequences.v11.5.fa",
		        "enrichment_path": "224325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224325.protein.info.v11.5.txt",
		        "node_list_path": "224325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "224325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CystobacterFerrugineus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cystobacter ferrugineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CystobacterFerrugineus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83449.protein.sequences.v11.5.fa",
		        "enrichment_path": "83449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83449.protein.info.v11.5.txt",
		        "node_list_path": "83449.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelosinusSpUfo1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus sp. UFO1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelosinusSpUfo1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "484770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "484770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "484770.clusters.proteins.v11.5.txt",
		        "sequence_path": "484770.protein.sequences.v11.5.fa",
		        "enrichment_path": "484770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484770.protein.info.v11.5.txt",
		        "node_list_path": "484770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "484770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBombiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bombi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBombiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1341695.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1341695.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1341695.clusters.proteins.v11.5.txt",
		        "sequence_path": "1341695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341695.protein.info.v11.5.txt",
		        "node_list_path": "1341695.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1341695.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpCf079Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. CF079 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpCf079Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882774.protein.info.v11.5.txt",
		        "node_list_path": "1882774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiumAgarilyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobium agarilyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiumAgarilyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122194.protein.info.v11.5.txt",
		        "node_list_path": "1122194.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrametesPubescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trametes pubescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrametesPubescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "154538.protein.sequences.v11.5.fa",
		        "enrichment_path": "154538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "154538.protein.info.v11.5.txt",
		        "node_list_path": "154538.protein.complete.v11.5.txt"
		    }
		]
    )()

def DuganellaSpLeaf126Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. Leaf126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpLeaf126Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736266.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736266.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736266.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736266.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736266.protein.info.v11.5.txt",
		        "node_list_path": "1736266.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736266.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgromycesItalicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agromyces italicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesItalicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120959.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120959.protein.info.v11.5.txt",
		        "node_list_path": "1120959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkiellaCookevillensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkiella cookevillensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkiellaCookevillensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "437022.protein.sequences.v11.5.fa",
		        "enrichment_path": "437022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "437022.protein.info.v11.5.txt",
		        "node_list_path": "437022.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThielaviaTerrestris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thielavia terrestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThielaviaTerrestris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35720.protein.sequences.v11.5.fa",
		        "enrichment_path": "35720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35720.protein.info.v11.5.txt",
		        "node_list_path": "35720.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAdlerbacteriaBacteriumRifoxyc1Full4826(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFOXYC1_FULL_48_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifoxyc1Full4826", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797247.protein.info.v11.5.txt",
		        "node_list_path": "1797247.protein.complete.v11.5.txt"
		    }
		]
    )()

def OpitutaceaeBacteriumTav4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TAV4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpitutaceaeBacteriumTav4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "278959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "278959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "278959.clusters.proteins.v11.5.txt",
		        "sequence_path": "278959.protein.sequences.v11.5.fa",
		        "enrichment_path": "278959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278959.protein.info.v11.5.txt",
		        "node_list_path": "278959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "278959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomaduraHibiscaNbrc15177Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura hibisca NBRC 15177 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraHibiscaNbrc15177Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220559.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220559.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220559.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220559.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220559.protein.info.v11.5.txt",
		        "node_list_path": "1220559.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220559.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoplasmatalesArchaeonAPlasma(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon A-plasma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmatalesArchaeonAPlasma", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "667135.protein.sequences.v11.5.fa",
		        "enrichment_path": "667135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667135.protein.info.v11.5.txt",
		        "node_list_path": "667135.protein.complete.v11.5.txt"
		    }
		]
    )()

def DinoroseobacterShibae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dinoroseobacter shibae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DinoroseobacterShibae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398580.protein.sequences.v11.5.fa",
		        "enrichment_path": "398580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398580.protein.info.v11.5.txt",
		        "node_list_path": "398580.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot1334(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1334 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot1334", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736456.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736456.protein.info.v11.5.txt",
		        "node_list_path": "1736456.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAtratusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces atratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAtratusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1893.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1893.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1893.clusters.proteins.v11.5.txt",
		        "sequence_path": "1893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1893.protein.info.v11.5.txt",
		        "node_list_path": "1893.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1893.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumRifcsplowo202Full4814Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFCSPLOWO2_02_FULL_48_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifcsplowo202Full4814Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801900.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801900.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801900.protein.info.v11.5.txt",
		        "node_list_path": "1801900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSanguinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSanguinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121020.protein.info.v11.5.txt",
		        "node_list_path": "1121020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WinogradskyellaPsychrotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Winogradskyella psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinogradskyellaPsychrotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641526.clusters.proteins.v11.5.txt",
		        "sequence_path": "641526.protein.sequences.v11.5.fa",
		        "enrichment_path": "641526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641526.protein.info.v11.5.txt",
		        "node_list_path": "641526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PirellulaStaleyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pirellula staleyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PirellulaStaleyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "530564.protein.sequences.v11.5.fa",
		        "enrichment_path": "530564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "530564.protein.info.v11.5.txt",
		        "node_list_path": "530564.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAnginosusSk52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus SK52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAnginosusSk52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1000570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1000570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1000570.protein.info.v11.5.txt",
		        "node_list_path": "1000570.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumCamembertiFm013(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium camemberti FM 013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumCamembertiFm013", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1429867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1429867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1429867.protein.info.v11.5.txt",
		        "node_list_path": "1429867.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumGa0077525(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077525 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumGa0077525", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752222.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752222.protein.info.v11.5.txt",
		        "node_list_path": "1752222.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAnginosusDora7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus DORA7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAnginosusDora7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1403946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1403946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1403946.clusters.proteins.v11.5.txt",
		        "sequence_path": "1403946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403946.protein.info.v11.5.txt",
		        "node_list_path": "1403946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1403946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusPacificus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusPacificus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "337701.protein.sequences.v11.5.fa",
		        "enrichment_path": "337701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "337701.protein.info.v11.5.txt",
		        "node_list_path": "337701.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAquilunaSpUbMaderosw2red(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aquiluna sp. UB-MaderosW2red graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAquilunaSpUbMaderosw2red", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855377.protein.info.v11.5.txt",
		        "node_list_path": "1855377.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalonatronumSaccharophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halonatronum saccharophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalonatronumSaccharophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926692.protein.sequences.v11.5.fa",
		        "enrichment_path": "926692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926692.protein.info.v11.5.txt",
		        "node_list_path": "926692.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinilactibacillusPsychrotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinilactibacillus psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinilactibacillusPsychrotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "191770.protein.sequences.v11.5.fa",
		        "enrichment_path": "191770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "191770.protein.info.v11.5.txt",
		        "node_list_path": "191770.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumJoosteiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium joostei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumJoosteiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "112234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "112234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "112234.clusters.proteins.v11.5.txt",
		        "sequence_path": "112234.protein.sequences.v11.5.fa",
		        "enrichment_path": "112234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112234.protein.info.v11.5.txt",
		        "node_list_path": "112234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "112234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccidioidesSpLutziiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides sp. lutzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccidioidesSpLutziiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1048829.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1048829.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1048829.clusters.proteins.v11.5.txt",
		        "sequence_path": "1048829.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048829.protein.info.v11.5.txt",
		        "node_list_path": "1048829.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1048829.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpCc9605(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpCc9605", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "110662.protein.sequences.v11.5.fa",
		        "enrichment_path": "110662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "110662.protein.info.v11.5.txt",
		        "node_list_path": "110662.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterGracilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter gracilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterGracilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553220.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553220.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553220.clusters.proteins.v11.5.txt",
		        "sequence_path": "553220.protein.sequences.v11.5.fa",
		        "enrichment_path": "553220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553220.protein.info.v11.5.txt",
		        "node_list_path": "553220.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553220.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalothrixSpPcc6303(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC6303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalothrixSpPcc6303", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1170562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1170562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1170562.protein.info.v11.5.txt",
		        "node_list_path": "1170562.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag967Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:967 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag967Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262849.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262849.protein.info.v11.5.txt",
		        "node_list_path": "1262849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DentipellisFragilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dentipellis fragilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DentipellisFragilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "205917.protein.sequences.v11.5.fa",
		        "enrichment_path": "205917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "205917.protein.info.v11.5.txt",
		        "node_list_path": "205917.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanolobusProfundi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus profundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolobusProfundi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "487685.protein.sequences.v11.5.fa",
		        "enrichment_path": "487685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487685.protein.info.v11.5.txt",
		        "node_list_path": "487685.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraLucentensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira lucentensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraLucentensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "168935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "168935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "168935.clusters.proteins.v11.5.txt",
		        "sequence_path": "168935.protein.sequences.v11.5.fa",
		        "enrichment_path": "168935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "168935.protein.info.v11.5.txt",
		        "node_list_path": "168935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "168935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SteccherinumOchraceum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Steccherinum ochraceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SteccherinumOchraceum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "92696.protein.sequences.v11.5.fa",
		        "enrichment_path": "92696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92696.protein.info.v11.5.txt",
		        "node_list_path": "92696.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZygosaccharomycesRouxiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zygosaccharomyces rouxii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZygosaccharomycesRouxiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4956.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4956.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4956.clusters.proteins.v11.5.txt",
		        "sequence_path": "4956.protein.sequences.v11.5.fa",
		        "enrichment_path": "4956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4956.protein.info.v11.5.txt",
		        "node_list_path": "4956.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4956.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "464029.protein.sequences.v11.5.fa",
		        "enrichment_path": "464029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "464029.protein.info.v11.5.txt",
		        "node_list_path": "464029.protein.complete.v11.5.txt"
		    }
		]
    )()

def TranquillimonasAlkanivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tranquillimonas alkanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TranquillimonasAlkanivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "441119.clusters.info.v11.5.txt",
		        "cluster_tree_path": "441119.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "441119.clusters.proteins.v11.5.txt",
		        "sequence_path": "441119.protein.sequences.v11.5.fa",
		        "enrichment_path": "441119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441119.protein.info.v11.5.txt",
		        "node_list_path": "441119.cluster.nodes.v11.5.txt",
		        "edge_list_path": "441119.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyphomyrmexCostatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyphomyrmex costatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyphomyrmexCostatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "456900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "456900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "456900.clusters.proteins.v11.5.txt",
		        "sequence_path": "456900.protein.sequences.v11.5.fa",
		        "enrichment_path": "456900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "456900.protein.info.v11.5.txt",
		        "node_list_path": "456900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "456900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BeijerinckiaIndica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Beijerinckia indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeijerinckiaIndica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "395963.protein.sequences.v11.5.fa",
		        "enrichment_path": "395963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395963.protein.info.v11.5.txt",
		        "node_list_path": "395963.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanofastidiosumMethylthiophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanofastidiosum methylthiophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanofastidiosumMethylthiophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1705564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1705564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1705564.clusters.proteins.v11.5.txt",
		        "sequence_path": "1705564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705564.protein.info.v11.5.txt",
		        "node_list_path": "1705564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1705564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_40_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797715.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797715.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797715.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797715.protein.info.v11.5.txt",
		        "node_list_path": "1797715.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797715.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumBohemicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium bohemicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumBohemicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2052828.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2052828.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2052828.clusters.proteins.v11.5.txt",
		        "sequence_path": "2052828.protein.sequences.v11.5.fa",
		        "enrichment_path": "2052828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2052828.protein.info.v11.5.txt",
		        "node_list_path": "2052828.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2052828.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrinemaAltunense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrinema altunense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrinemaAltunense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "222984.protein.sequences.v11.5.fa",
		        "enrichment_path": "222984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "222984.protein.info.v11.5.txt",
		        "node_list_path": "222984.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusBarophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus barophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusBarophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391623.protein.sequences.v11.5.fa",
		        "enrichment_path": "391623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391623.protein.info.v11.5.txt",
		        "node_list_path": "391623.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpThb2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. thb2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpThb2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "172088.protein.sequences.v11.5.fa",
		        "enrichment_path": "172088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "172088.protein.info.v11.5.txt",
		        "node_list_path": "172088.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesCryophilusOy26Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces cryophilus OY26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesCryophilusOy26Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "653667.clusters.info.v11.5.txt",
		        "cluster_tree_path": "653667.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "653667.clusters.proteins.v11.5.txt",
		        "sequence_path": "653667.protein.sequences.v11.5.fa",
		        "enrichment_path": "653667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "653667.protein.info.v11.5.txt",
		        "node_list_path": "653667.cluster.nodes.v11.5.txt",
		        "edge_list_path": "653667.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807757.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807757.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807757.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807757.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807757.protein.info.v11.5.txt",
		        "node_list_path": "1807757.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807757.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumHainanense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium hainanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumHainanense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52131.protein.sequences.v11.5.fa",
		        "enrichment_path": "52131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52131.protein.info.v11.5.txt",
		        "node_list_path": "52131.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusAculeatusAtcc16872(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus aculeatus ATCC 16872 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusAculeatusAtcc16872", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "690307.protein.sequences.v11.5.fa",
		        "enrichment_path": "690307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690307.protein.info.v11.5.txt",
		        "node_list_path": "690307.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusActinosclerus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus actinosclerus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusActinosclerus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1768108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768108.protein.info.v11.5.txt",
		        "node_list_path": "1768108.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegasphaeraPaucivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera paucivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraPaucivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349095.protein.sequences.v11.5.fa",
		        "enrichment_path": "349095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349095.protein.info.v11.5.txt",
		        "node_list_path": "349095.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpBls98(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. BLS98 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpBls98", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "885586.protein.sequences.v11.5.fa",
		        "enrichment_path": "885586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "885586.protein.info.v11.5.txt",
		        "node_list_path": "885586.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacterium13140cm6619Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 13_1_40CM_66_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacterium13140cm6619Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805081.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805081.protein.info.v11.5.txt",
		        "node_list_path": "1805081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumDaeguenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium daeguense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumDaeguenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121286.protein.info.v11.5.txt",
		        "node_list_path": "1121286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusGorillae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gorillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGorillae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1450649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450649.protein.info.v11.5.txt",
		        "node_list_path": "1450649.protein.complete.v11.5.txt"
		    }
		]
    )()

def RubellimicrobiumMesophilumDsm19309(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubellimicrobium mesophilum DSM 19309 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubellimicrobiumMesophilumDsm19309", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "442562.protein.sequences.v11.5.fa",
		        "enrichment_path": "442562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "442562.protein.info.v11.5.txt",
		        "node_list_path": "442562.protein.complete.v11.5.txt"
		    }
		]
    )()

def TorulasporaDelbrueckiiCbs1146(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Torulaspora delbrueckii CBS 1146 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TorulasporaDelbrueckiiCbs1146", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1076872.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076872.protein.info.v11.5.txt",
		        "node_list_path": "1076872.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsplowo201Full3913(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO2_01_FULL_39_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201Full3913", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802624.protein.info.v11.5.txt",
		        "node_list_path": "1802624.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesFinegoldiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides finegoldii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFinegoldiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "483215.clusters.info.v11.5.txt",
		        "cluster_tree_path": "483215.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "483215.clusters.proteins.v11.5.txt",
		        "sequence_path": "483215.protein.sequences.v11.5.fa",
		        "enrichment_path": "483215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483215.protein.info.v11.5.txt",
		        "node_list_path": "483215.cluster.nodes.v11.5.txt",
		        "edge_list_path": "483215.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusHominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423758.protein.info.v11.5.txt",
		        "node_list_path": "1423758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorHydrothermalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor hydrothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorHydrothermalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "632292.protein.sequences.v11.5.fa",
		        "enrichment_path": "632292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632292.protein.info.v11.5.txt",
		        "node_list_path": "632292.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumCommuneCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium commune Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumCommuneCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1505727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1505727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1505727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1505727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505727.protein.info.v11.5.txt",
		        "node_list_path": "1505727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1505727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaConceptionensis9403948Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella conceptionensis 9403948 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaConceptionensis9403948Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1197728.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1197728.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1197728.clusters.proteins.v11.5.txt",
		        "sequence_path": "1197728.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197728.protein.info.v11.5.txt",
		        "node_list_path": "1197728.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1197728.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerotruncusSpCag390(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. CAG:390 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotruncusSpCag390", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262703.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262703.protein.info.v11.5.txt",
		        "node_list_path": "1262703.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumSpNcppb925(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. NCPPB 925 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumSpNcppb925", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1631629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1631629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1631629.protein.info.v11.5.txt",
		        "node_list_path": "1631629.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHtcc2207Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2207 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2207Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314287.clusters.info.v11.0.txt",
		        "cluster_tree_path": "314287.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "314287.clusters.proteins.v11.0.txt",
		        "sequence_path": "314287.protein.sequences.v11.0.fa",
		        "enrichment_path": "314287.protein.enrichment.terms.v11.0.txt",
		        "info_path": "314287.protein.info.v11.0.txt",
		        "node_list_path": "314287.cluster.nodes.v11.0.txt",
		        "edge_list_path": "314287.protein.cluster.v11.0.txt"
		    }
		]
    )()

def PseudomonasCremoricolorata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas cremoricolorata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCremoricolorata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "157783.protein.sequences.v11.5.fa",
		        "enrichment_path": "157783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157783.protein.info.v11.5.txt",
		        "node_list_path": "157783.protein.complete.v11.5.txt"
		    }
		]
    )()

def TepidanaerobacterSyntrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tepidanaerobacter syntrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidanaerobacterSyntrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "224999.protein.sequences.v11.5.fa",
		        "enrichment_path": "224999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224999.protein.info.v11.5.txt",
		        "node_list_path": "224999.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaAustralienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytoplasma australiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaAustralienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59748.clusters.proteins.v11.5.txt",
		        "sequence_path": "59748.protein.sequences.v11.5.fa",
		        "enrichment_path": "59748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59748.protein.info.v11.5.txt",
		        "node_list_path": "59748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobacteriovoraxAntillogorgiicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobacteriovorax antillogorgiicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobacteriovoraxAntillogorgiicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1513793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1513793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1513793.protein.info.v11.5.txt",
		        "node_list_path": "1513793.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpRu37dCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. RU37D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpRu37dCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907397.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907397.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907397.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907397.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907397.protein.info.v11.5.txt",
		        "node_list_path": "1907397.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907397.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ApibacterMensalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Apibacter mensalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApibacterMensalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1586267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1586267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1586267.clusters.proteins.v11.5.txt",
		        "sequence_path": "1586267.protein.sequences.v11.5.fa",
		        "enrichment_path": "1586267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1586267.protein.info.v11.5.txt",
		        "node_list_path": "1586267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1586267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSubterraneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas subterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSubterraneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "416874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "416874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "416874.clusters.proteins.v11.5.txt",
		        "sequence_path": "416874.protein.sequences.v11.5.fa",
		        "enrichment_path": "416874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416874.protein.info.v11.5.txt",
		        "node_list_path": "416874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "416874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AestuariibacterSalexigensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aestuariibacter salexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AestuariibacterSalexigensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120953.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120953.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120953.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120953.protein.info.v11.5.txt",
		        "node_list_path": "1120953.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120953.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrnatilineaApprimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ornatilinea apprima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnatilineaApprimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1134406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1134406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1134406.clusters.proteins.v11.5.txt",
		        "sequence_path": "1134406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134406.protein.info.v11.5.txt",
		        "node_list_path": "1134406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1134406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizophagusIrregularisDaom181602Daom197198(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM 181602=DAOM 197198 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizophagusIrregularisDaom181602Daom197198", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "747089.protein.sequences.v11.5.fa",
		        "enrichment_path": "747089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747089.protein.info.v11.5.txt",
		        "node_list_path": "747089.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusSaccharolyticusJop10301(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus saccharolyticus JOP 1030-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusSaccharolyticusJop10301", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1450539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450539.protein.info.v11.5.txt",
		        "node_list_path": "1450539.protein.complete.v11.5.txt"
		    }
		]
    )()

def CalescamantesBacteriumScgcAaa471M6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Calescamantes bacterium SCGC AAA471-M6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalescamantesBacteriumScgcAaa471M6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1052810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1052810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1052810.protein.info.v11.5.txt",
		        "node_list_path": "1052810.protein.complete.v11.5.txt"
		    }
		]
    )()

def QuasibacillusThermotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Quasibacillus thermotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "QuasibacillusThermotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1221996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1221996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1221996.clusters.proteins.v11.5.txt",
		        "sequence_path": "1221996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1221996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1221996.protein.info.v11.5.txt",
		        "node_list_path": "1221996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1221996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasMediaWsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas media WS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasMediaWsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208104.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208104.protein.info.v11.5.txt",
		        "node_list_path": "1208104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ModestobacterSpLeaf380(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Modestobacter sp. Leaf380 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ModestobacterSpLeaf380", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736356.protein.info.v11.5.txt",
		        "node_list_path": "1736356.protein.complete.v11.5.txt"
		    }
		]
    )()

def ApiotrichumPorosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Apiotrichum porosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApiotrichumPorosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "105984.protein.sequences.v11.5.fa",
		        "enrichment_path": "105984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105984.protein.info.v11.5.txt",
		        "node_list_path": "105984.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMicrarchaeotaArchaeonCg1025115Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_51_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1025115Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805249.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805249.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805249.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805249.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805249.protein.info.v11.5.txt",
		        "node_list_path": "1805249.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805249.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807751.protein.info.v11.5.txt",
		        "node_list_path": "1807751.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumRubens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium rubens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumRubens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1108849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1108849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1108849.protein.info.v11.5.txt",
		        "node_list_path": "1108849.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusKefiriDsm20587Jcm5818(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kefiri DSM 20587 JCM 5818 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKefiriDsm20587Jcm5818", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423764.protein.info.v11.5.txt",
		        "node_list_path": "1423764.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaSpImh(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. IMH graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpImh", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267600.protein.info.v11.5.txt",
		        "node_list_path": "1267600.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaCaribensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia caribensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaCaribensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "75105.protein.sequences.v11.5.fa",
		        "enrichment_path": "75105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75105.protein.info.v11.5.txt",
		        "node_list_path": "75105.protein.complete.v11.5.txt"
		    }
		]
    )()

def MollicutesBacteriumHr1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mollicutes bacterium HR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MollicutesBacteriumHr1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1541959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1541959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1541959.clusters.proteins.v11.5.txt",
		        "sequence_path": "1541959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1541959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1541959.protein.info.v11.5.txt",
		        "node_list_path": "1541959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1541959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParageobacillusThermoglucosidasiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parageobacillus thermoglucosidasius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParageobacillusThermoglucosidasiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1426.clusters.proteins.v11.5.txt",
		        "sequence_path": "1426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1426.protein.info.v11.5.txt",
		        "node_list_path": "1426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpDnf00663(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. DNF00663 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpDnf00663", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1384078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384078.protein.info.v11.5.txt",
		        "node_list_path": "1384078.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseobacterDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "375451.protein.sequences.v11.5.fa",
		        "enrichment_path": "375451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375451.protein.info.v11.5.txt",
		        "node_list_path": "375451.protein.complete.v11.5.txt"
		    }
		]
    )()

def GillisiaSpCal575Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gillisia sp. CAL575 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GillisiaSpCal575Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "985255.clusters.info.v11.5.txt",
		        "cluster_tree_path": "985255.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "985255.clusters.proteins.v11.5.txt",
		        "sequence_path": "985255.protein.sequences.v11.5.fa",
		        "enrichment_path": "985255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985255.protein.info.v11.5.txt",
		        "node_list_path": "985255.cluster.nodes.v11.5.txt",
		        "edge_list_path": "985255.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FaecalibacteriumPrausnitziiL26(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii L26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibacteriumPrausnitziiL26", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "718252.protein.sequences.v11.5.fa",
		        "enrichment_path": "718252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "718252.protein.info.v11.5.txt",
		        "node_list_path": "718252.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpAmel2xe9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Amel2xE9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpAmel2xe9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157634.protein.info.v11.5.txt",
		        "node_list_path": "1157634.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiumSpLsA18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobium sp. LS-A18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiumSpLsA18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1381596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1381596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1381596.clusters.proteins.v11.5.txt",
		        "sequence_path": "1381596.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381596.protein.info.v11.5.txt",
		        "node_list_path": "1381596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1381596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacterium4920(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium 49-20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacterium4920", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895829.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895829.protein.info.v11.5.txt",
		        "node_list_path": "1895829.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmphibacillusMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amphibacillus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphibacillusMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "872970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "872970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "872970.clusters.proteins.v11.5.txt",
		        "sequence_path": "872970.protein.sequences.v11.5.fa",
		        "enrichment_path": "872970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "872970.protein.info.v11.5.txt",
		        "node_list_path": "872970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "872970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumRadiobacterCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium radiobacter Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumRadiobacterCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "311403.clusters.info.v11.5.txt",
		        "cluster_tree_path": "311403.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "311403.clusters.proteins.v11.5.txt",
		        "sequence_path": "311403.protein.sequences.v11.5.fa",
		        "enrichment_path": "311403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311403.protein.info.v11.5.txt",
		        "node_list_path": "311403.cluster.nodes.v11.5.txt",
		        "edge_list_path": "311403.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumJlt2015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium JLT2015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumJlt2015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1234595.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234595.protein.info.v11.5.txt",
		        "node_list_path": "1234595.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucobacterSpAg1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter sp. Ag1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterSpAg1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1642040.protein.sequences.v11.5.fa",
		        "enrichment_path": "1642040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1642040.protein.info.v11.5.txt",
		        "node_list_path": "1642040.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusAlimentariusDsm20249(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus alimentarius DSM 20249 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAlimentariusDsm20249", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423720.protein.info.v11.5.txt",
		        "node_list_path": "1423720.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSp68310(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. 68-3-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSp68310", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1261640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261640.protein.info.v11.5.txt",
		        "node_list_path": "1261640.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumShimoideiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium shimoidei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumShimoideiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29313.clusters.proteins.v11.5.txt",
		        "sequence_path": "29313.protein.sequences.v11.5.fa",
		        "enrichment_path": "29313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29313.protein.info.v11.5.txt",
		        "node_list_path": "29313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrialbaAsiatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrialba asiatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaAsiatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29540.protein.sequences.v11.5.fa",
		        "enrichment_path": "29540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29540.protein.info.v11.5.txt",
		        "node_list_path": "29540.protein.complete.v11.5.txt"
		    }
		]
    )()

def AurantimonasSp22ii1619i(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aurantimonas sp. 22II-16-19i graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AurantimonasSp22ii1619i", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1317114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317114.protein.info.v11.5.txt",
		        "node_list_path": "1317114.protein.complete.v11.5.txt"
		    }
		]
    )()

def IntrasporangiumFlavum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Intrasporangium flavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntrasporangiumFlavum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1428657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1428657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1428657.protein.info.v11.5.txt",
		        "node_list_path": "1428657.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAcidominimus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus acidominimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAcidominimus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1326.protein.info.v11.5.txt",
		        "node_list_path": "1326.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumRiegeliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium riegelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumRiegeliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "156976.clusters.info.v11.5.txt",
		        "cluster_tree_path": "156976.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "156976.clusters.proteins.v11.5.txt",
		        "sequence_path": "156976.protein.sequences.v11.5.fa",
		        "enrichment_path": "156976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156976.protein.info.v11.5.txt",
		        "node_list_path": "156976.cluster.nodes.v11.5.txt",
		        "edge_list_path": "156976.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillibacterRuminantium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter ruminantium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterRuminantium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1007096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007096.protein.info.v11.5.txt",
		        "node_list_path": "1007096.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpEui1cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. EuI1c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpEui1cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "298654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "298654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "298654.clusters.proteins.v11.5.txt",
		        "sequence_path": "298654.protein.sequences.v11.5.fa",
		        "enrichment_path": "298654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "298654.protein.info.v11.5.txt",
		        "node_list_path": "298654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "298654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaHackeliae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella hackeliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaHackeliae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "449.protein.sequences.v11.5.fa",
		        "enrichment_path": "449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "449.protein.info.v11.5.txt",
		        "node_list_path": "449.protein.complete.v11.5.txt"
		    }
		]
    )()

def RobiginitomaculumAntarcticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Robiginitomaculum antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RobiginitomaculumAntarcticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123059.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123059.protein.info.v11.5.txt",
		        "node_list_path": "1123059.protein.complete.v11.5.txt"
		    }
		]
    )()

def AedesAlbopictus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aedes albopictus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AedesAlbopictus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7160.protein.sequences.v11.5.fa",
		        "enrichment_path": "7160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7160.protein.info.v11.5.txt",
		        "node_list_path": "7160.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSporosphaeroides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sporosphaeroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSporosphaeroides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121334.protein.info.v11.5.txt",
		        "node_list_path": "1121334.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpPp1yCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. PP1Y Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpPp1yCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "702113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "702113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "702113.clusters.proteins.v11.5.txt",
		        "sequence_path": "702113.protein.sequences.v11.5.fa",
		        "enrichment_path": "702113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702113.protein.info.v11.5.txt",
		        "node_list_path": "702113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "702113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptotermesSecundusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptotermes secundus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptotermesSecundusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "105785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "105785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "105785.clusters.proteins.v11.5.txt",
		        "sequence_path": "105785.protein.sequences.v11.5.fa",
		        "enrichment_path": "105785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105785.protein.info.v11.5.txt",
		        "node_list_path": "105785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "105785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AvibacteriumParagallinarum72(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum 72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AvibacteriumParagallinarum72", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "948565.protein.sequences.v11.5.fa",
		        "enrichment_path": "948565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "948565.protein.info.v11.5.txt",
		        "node_list_path": "948565.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpMsp13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MSP13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpMsp13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071061.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071061.protein.info.v11.5.txt",
		        "node_list_path": "1071061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusTanneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus tanneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusTanneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220188.protein.info.v11.5.txt",
		        "node_list_path": "1220188.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanobacillusSojaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus sojae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusSojaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582851.clusters.proteins.v11.5.txt",
		        "sequence_path": "582851.protein.sequences.v11.5.fa",
		        "enrichment_path": "582851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582851.protein.info.v11.5.txt",
		        "node_list_path": "582851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LautropiaMirabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lautropia mirabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LautropiaMirabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "887898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "887898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "887898.clusters.proteins.v11.5.txt",
		        "sequence_path": "887898.protein.sequences.v11.5.fa",
		        "enrichment_path": "887898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "887898.protein.info.v11.5.txt",
		        "node_list_path": "887898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "887898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSpAc3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. AC-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSpAc3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1680467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1680467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1680467.clusters.proteins.v11.5.txt",
		        "sequence_path": "1680467.protein.sequences.v11.5.fa",
		        "enrichment_path": "1680467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1680467.protein.info.v11.5.txt",
		        "node_list_path": "1680467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1680467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClavibacterMichiganensisSubspTessellariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis subsp. tessellarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavibacterMichiganensisSubspTessellariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "31965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "31965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "31965.clusters.proteins.v11.5.txt",
		        "sequence_path": "31965.protein.sequences.v11.5.fa",
		        "enrichment_path": "31965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31965.protein.info.v11.5.txt",
		        "node_list_path": "31965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "31965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3719Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_37_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3719Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802514.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802514.protein.info.v11.5.txt",
		        "node_list_path": "1802514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu089(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU089 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu089", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671661.protein.info.v11.5.txt",
		        "node_list_path": "1671661.protein.complete.v11.5.txt"
		    }
		]
    )()

def DechloromonasDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dechloromonas denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DechloromonasDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "281362.protein.sequences.v11.5.fa",
		        "enrichment_path": "281362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "281362.protein.info.v11.5.txt",
		        "node_list_path": "281362.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumCaspActino5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium casp-actino5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumCaspActino5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1661702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1661702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1661702.clusters.proteins.v11.5.txt",
		        "sequence_path": "1661702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661702.protein.info.v11.5.txt",
		        "node_list_path": "1661702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1661702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaPorciDsm25326(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella porci DSM 25326 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaPorciDsm25326", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573983.protein.sequences.v11.5.fa",
		        "enrichment_path": "573983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573983.protein.info.v11.5.txt",
		        "node_list_path": "573983.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpPamc26617(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PAMC26617 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpPamc26617", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1112216.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112216.protein.info.v11.5.txt",
		        "node_list_path": "1112216.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumChkci006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium CHKCI006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumChkci006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1780379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1780379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1780379.clusters.proteins.v11.5.txt",
		        "sequence_path": "1780379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780379.protein.info.v11.5.txt",
		        "node_list_path": "1780379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1780379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophaceaeBacteriumCg2305814(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophaceae bacterium CG2_30_58_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophaceaeBacteriumCg2305814", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805378.protein.info.v11.5.txt",
		        "node_list_path": "1805378.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterArilaitensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter arilaitensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterArilaitensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "861360.protein.sequences.v11.5.fa",
		        "enrichment_path": "861360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861360.protein.info.v11.5.txt",
		        "node_list_path": "861360.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaBronchialisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia bronchialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaBronchialisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "526226.clusters.info.v11.5.txt",
		        "cluster_tree_path": "526226.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "526226.clusters.proteins.v11.5.txt",
		        "sequence_path": "526226.protein.sequences.v11.5.fa",
		        "enrichment_path": "526226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526226.protein.info.v11.5.txt",
		        "node_list_path": "526226.cluster.nodes.v11.5.txt",
		        "edge_list_path": "526226.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctopirusHydrillaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctopirus hydrillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctopirusHydrillaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841610.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841610.protein.info.v11.5.txt",
		        "node_list_path": "1841610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxyc2Full3412(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYC2_FULL_34_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyc2Full3412", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797971.protein.info.v11.5.txt",
		        "node_list_path": "1797971.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumCg2306627Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CG2_30_66_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumCg2306627Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805127.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805127.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805127.protein.info.v11.5.txt",
		        "node_list_path": "1805127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaHaemolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaHaemolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "75985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "75985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "75985.clusters.proteins.v11.5.txt",
		        "sequence_path": "75985.protein.sequences.v11.5.fa",
		        "enrichment_path": "75985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75985.protein.info.v11.5.txt",
		        "node_list_path": "75985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "75985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterSpDh1f(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter sp. DH1f graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterSpDh1f", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397275.protein.info.v11.5.txt",
		        "node_list_path": "1397275.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoplanesMissouriensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes missouriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesMissouriensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "512565.protein.sequences.v11.5.fa",
		        "enrichment_path": "512565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512565.protein.info.v11.5.txt",
		        "node_list_path": "512565.protein.complete.v11.5.txt"
		    }
		]
    )()

def PythiumVexansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pythium vexans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PythiumVexansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42099.clusters.proteins.v11.5.txt",
		        "sequence_path": "42099.protein.sequences.v11.5.fa",
		        "enrichment_path": "42099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42099.protein.info.v11.5.txt",
		        "node_list_path": "42099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaTuricatae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia turicatae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaTuricatae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314724.protein.sequences.v11.5.fa",
		        "enrichment_path": "314724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314724.protein.info.v11.5.txt",
		        "node_list_path": "314724.protein.complete.v11.5.txt"
		    }
		]
    )()

def LipomycesStarkeyiNrrlY11557Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lipomyces starkeyi NRRL Y-11557 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LipomycesStarkeyiNrrlY11557Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675824.clusters.proteins.v11.5.txt",
		        "sequence_path": "675824.protein.sequences.v11.5.fa",
		        "enrichment_path": "675824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675824.protein.info.v11.5.txt",
		        "node_list_path": "675824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpHmsc077f02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. HMSC077F02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpHmsc077f02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739529.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739529.protein.info.v11.5.txt",
		        "node_list_path": "1739529.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprococcusEutactus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus eutactus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprococcusEutactus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411474.protein.sequences.v11.5.fa",
		        "enrichment_path": "411474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411474.protein.info.v11.5.txt",
		        "node_list_path": "411474.protein.complete.v11.5.txt"
		    }
		]
    )()

def XiangellaPhaseoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xiangella phaseoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XiangellaPhaseoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144548.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144548.protein.info.v11.5.txt",
		        "node_list_path": "1144548.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasHalodenitrificansDsm735Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas halodenitrificans DSM 735 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasHalodenitrificansDsm735Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121941.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121941.protein.info.v11.5.txt",
		        "node_list_path": "1121941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaplasmaMarginaleFlorida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma marginale Florida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaplasmaMarginaleFlorida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "320483.protein.sequences.v11.5.fa",
		        "enrichment_path": "320483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "320483.protein.info.v11.5.txt",
		        "node_list_path": "320483.protein.complete.v11.5.txt"
		    }
		]
    )()

def TriticumUrartuCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Triticum urartu Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TriticumUrartuCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4572.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4572.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4572.clusters.proteins.v11.5.txt",
		        "sequence_path": "4572.protein.sequences.v11.5.fa",
		        "enrichment_path": "4572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4572.protein.info.v11.5.txt",
		        "node_list_path": "4572.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4572.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumFreudenreichiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium freudenreichii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumFreudenreichiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "754252.clusters.info.v11.5.txt",
		        "cluster_tree_path": "754252.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "754252.clusters.proteins.v11.5.txt",
		        "sequence_path": "754252.protein.sequences.v11.5.fa",
		        "enrichment_path": "754252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754252.protein.info.v11.5.txt",
		        "node_list_path": "754252.cluster.nodes.v11.5.txt",
		        "edge_list_path": "754252.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusJacksonbacteriaBacteriumRifoxya2Full4312(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jacksonbacteria bacterium RIFOXYA2_FULL_43_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJacksonbacteriaBacteriumRifoxya2Full4312", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798462.protein.info.v11.5.txt",
		        "node_list_path": "1798462.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldilineaAerophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldilinea aerophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldilineaAerophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926550.protein.sequences.v11.5.fa",
		        "enrichment_path": "926550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926550.protein.info.v11.5.txt",
		        "node_list_path": "926550.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4016b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_40_16b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4016b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797714.protein.info.v11.5.txt",
		        "node_list_path": "1797714.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinivibrioCosticolaSubspAlcaliphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio costicola subsp. alcaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivibrioCosticolaSubspAlcaliphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272773.clusters.proteins.v11.5.txt",
		        "sequence_path": "272773.protein.sequences.v11.5.fa",
		        "enrichment_path": "272773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272773.protein.info.v11.5.txt",
		        "node_list_path": "272773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylosinusSpLw4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylosinus sp. LW4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylosinusSpLw4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "136993.protein.sequences.v11.5.fa",
		        "enrichment_path": "136993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "136993.protein.info.v11.5.txt",
		        "node_list_path": "136993.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp11649663Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1164966.3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp11649663Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1856861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1856861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1856861.clusters.proteins.v11.5.txt",
		        "sequence_path": "1856861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1856861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1856861.protein.info.v11.5.txt",
		        "node_list_path": "1856861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1856861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifcsphigho201Full5513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_01_FULL_55_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho201Full5513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801917.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801917.protein.info.v11.5.txt",
		        "node_list_path": "1801917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HepatoplasmaCrinochetorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hepatoplasma crinochetorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HepatoplasmaCrinochetorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1427984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1427984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1427984.protein.info.v11.5.txt",
		        "node_list_path": "1427984.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho201Full3725Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_37_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full3725Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801731.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801731.protein.info.v11.5.txt",
		        "node_list_path": "1801731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldalkalibacillusThermarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldalkalibacillus thermarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldalkalibacillusThermarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "986075.protein.sequences.v11.5.fa",
		        "enrichment_path": "986075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "986075.protein.info.v11.5.txt",
		        "node_list_path": "986075.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalococcusThailandensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halococcus thailandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusThailandensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227457.protein.info.v11.5.txt",
		        "node_list_path": "1227457.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumRifcsphigho201Full6617(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RIFCSPHIGHO2_01_FULL_66_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumRifcsphigho201Full6617", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801712.protein.info.v11.5.txt",
		        "node_list_path": "1801712.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaParisiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella parisiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaParisiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45071.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45071.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45071.clusters.proteins.v11.5.txt",
		        "sequence_path": "45071.protein.sequences.v11.5.fa",
		        "enrichment_path": "45071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45071.protein.info.v11.5.txt",
		        "node_list_path": "45071.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45071.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivirgaSpongicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseivirga spongicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivirgaSpongicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "333140.protein.sequences.v11.5.fa",
		        "enrichment_path": "333140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "333140.protein.info.v11.5.txt",
		        "node_list_path": "333140.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat18017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-18017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat18017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1705566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705566.protein.info.v11.5.txt",
		        "node_list_path": "1705566.protein.complete.v11.5.txt"
		    }
		]
    )()

def ValsaSordida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Valsa sordida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ValsaSordida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "252740.protein.sequences.v11.5.fa",
		        "enrichment_path": "252740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "252740.protein.info.v11.5.txt",
		        "node_list_path": "252740.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumLimnosediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium limnosediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumLimnosediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1341181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341181.protein.info.v11.5.txt",
		        "node_list_path": "1341181.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotogaHypogea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga hypogea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaHypogea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219084.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219084.protein.info.v11.5.txt",
		        "node_list_path": "1219084.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulophagaFucicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga fucicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaFucicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "76595.protein.sequences.v11.5.fa",
		        "enrichment_path": "76595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76595.protein.info.v11.5.txt",
		        "node_list_path": "76595.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusOeniDsm19972(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oeni DSM 19972 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOeniDsm19972", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423777.protein.info.v11.5.txt",
		        "node_list_path": "1423777.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumRuminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum ruminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumRuminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "696281.protein.sequences.v11.5.fa",
		        "enrichment_path": "696281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696281.protein.info.v11.5.txt",
		        "node_list_path": "696281.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidaminococcusFermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidaminococcus fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminococcusFermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "591001.protein.sequences.v11.5.fa",
		        "enrichment_path": "591001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591001.protein.info.v11.5.txt",
		        "node_list_path": "591001.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumPorcinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium porcinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumPorcinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39693.clusters.proteins.v11.5.txt",
		        "sequence_path": "39693.protein.sequences.v11.5.fa",
		        "enrichment_path": "39693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39693.protein.info.v11.5.txt",
		        "node_list_path": "39693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonlabensUlvanivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens ulvanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensUlvanivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "906888.protein.sequences.v11.5.fa",
		        "enrichment_path": "906888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "906888.protein.info.v11.5.txt",
		        "node_list_path": "906888.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacterium4920Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium 49-20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacterium4920Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895829.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895829.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895829.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895829.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895829.protein.info.v11.5.txt",
		        "node_list_path": "1895829.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895829.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumVerruco04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium Verruco_04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumVerruco04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674916.protein.info.v11.5.txt",
		        "node_list_path": "1674916.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloprofundusMarisrubri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloprofundus marisrubri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloprofundusMarisrubri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1514971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1514971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1514971.protein.info.v11.5.txt",
		        "node_list_path": "1514971.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpF0472(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0472 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpF0472", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095752.protein.info.v11.5.txt",
		        "node_list_path": "1095752.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobisporaRosea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbispora rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobisporaRosea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "58117.protein.sequences.v11.5.fa",
		        "enrichment_path": "58117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58117.protein.info.v11.5.txt",
		        "node_list_path": "58117.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaplasmaMarginaleFloridaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma marginale Florida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaplasmaMarginaleFloridaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "320483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "320483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "320483.clusters.proteins.v11.5.txt",
		        "sequence_path": "320483.protein.sequences.v11.5.fa",
		        "enrichment_path": "320483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "320483.protein.info.v11.5.txt",
		        "node_list_path": "320483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "320483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoorellaSp6041(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moorella sp. 60_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoorellaSp6041", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635264.protein.info.v11.5.txt",
		        "node_list_path": "1635264.protein.complete.v11.5.txt"
		    }
		]
    )()

def GolovinomycesCichoracearum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Golovinomyces cichoracearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GolovinomycesCichoracearum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "62708.protein.sequences.v11.5.fa",
		        "enrichment_path": "62708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62708.protein.info.v11.5.txt",
		        "node_list_path": "62708.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumKa00134Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium KA00134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumKa00134Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1588750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1588750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1588750.clusters.proteins.v11.5.txt",
		        "sequence_path": "1588750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588750.protein.info.v11.5.txt",
		        "node_list_path": "1588750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1588750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpRoot70Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpRoot70Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736590.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736590.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736590.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736590.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736590.protein.info.v11.5.txt",
		        "node_list_path": "1736590.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736590.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalariasFasciatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salarias fasciatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalariasFasciatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "181472.protein.sequences.v11.5.fa",
		        "enrichment_path": "181472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "181472.protein.info.v11.5.txt",
		        "node_list_path": "181472.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSp1315Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 13-15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSp1315Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761891.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761891.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761891.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761891.protein.info.v11.5.txt",
		        "node_list_path": "1761891.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761891.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumMoriokaenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium moriokaense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumMoriokaenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39691.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39691.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39691.clusters.proteins.v11.5.txt",
		        "sequence_path": "39691.protein.sequences.v11.5.fa",
		        "enrichment_path": "39691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39691.protein.info.v11.5.txt",
		        "node_list_path": "39691.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39691.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrialbaceaeArchaeonTcBr11E2g28Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon Tc-Br11_E2g28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaceaeArchaeonTcBr11E2g28Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729463.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729463.protein.info.v11.5.txt",
		        "node_list_path": "1729463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaPneumophilaPhiladelphia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila Philadelphia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaPneumophilaPhiladelphia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272624.protein.sequences.v11.5.fa",
		        "enrichment_path": "272624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272624.protein.info.v11.5.txt",
		        "node_list_path": "272624.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastomonasSpCacia14h2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastomonas sp. CACIA14H2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomonasSpCacia14h2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1419876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1419876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1419876.protein.info.v11.5.txt",
		        "node_list_path": "1419876.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesCaccae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides caccae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCaccae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411901.protein.sequences.v11.5.fa",
		        "enrichment_path": "411901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411901.protein.info.v11.5.txt",
		        "node_list_path": "411901.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoccomyxaSubellipsoidea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coccomyxa subellipsoidea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccomyxaSubellipsoidea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "248742.protein.sequences.v11.5.fa",
		        "enrichment_path": "248742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "248742.protein.info.v11.5.txt",
		        "node_list_path": "248742.protein.complete.v11.5.txt"
		    }
		]
    )()

def RalstoniaPickettii12dCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia pickettii 12D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaPickettii12dCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "428406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "428406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "428406.clusters.proteins.v11.5.txt",
		        "sequence_path": "428406.protein.sequences.v11.5.fa",
		        "enrichment_path": "428406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428406.protein.info.v11.5.txt",
		        "node_list_path": "428406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "428406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKomeilibacteriaBacteriumRifoxyd1Full3729(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFOXYD1_FULL_37_29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifoxyd1Full3729", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798557.protein.info.v11.5.txt",
		        "node_list_path": "1798557.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumKuroshiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium kuroshium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumKuroshiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2010991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2010991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2010991.clusters.proteins.v11.5.txt",
		        "sequence_path": "2010991.protein.sequences.v11.5.fa",
		        "enrichment_path": "2010991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2010991.protein.info.v11.5.txt",
		        "node_list_path": "2010991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2010991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterHarbinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter harbinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterHarbinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1353941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1353941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1353941.clusters.proteins.v11.5.txt",
		        "sequence_path": "1353941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353941.protein.info.v11.5.txt",
		        "node_list_path": "1353941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1353941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumNigrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum nigrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumNigrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "696369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "696369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "696369.clusters.proteins.v11.5.txt",
		        "sequence_path": "696369.protein.sequences.v11.5.fa",
		        "enrichment_path": "696369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696369.protein.info.v11.5.txt",
		        "node_list_path": "696369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "696369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpRoot655Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root655 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpRoot655Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736578.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736578.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736578.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736578.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736578.protein.info.v11.5.txt",
		        "node_list_path": "1736578.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736578.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoraliomargaritaAkajimensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coraliomargarita akajimensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoraliomargaritaAkajimensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "583355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "583355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "583355.clusters.proteins.v11.5.txt",
		        "sequence_path": "583355.protein.sequences.v11.5.fa",
		        "enrichment_path": "583355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "583355.protein.info.v11.5.txt",
		        "node_list_path": "583355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "583355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusParabuchneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus parabuchneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParabuchneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "152331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "152331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "152331.clusters.proteins.v11.5.txt",
		        "sequence_path": "152331.protein.sequences.v11.5.fa",
		        "enrichment_path": "152331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "152331.protein.info.v11.5.txt",
		        "node_list_path": "152331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "152331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasTranslucensPvUndulosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas translucens pv. undulosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasTranslucensPvUndulosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "487909.protein.sequences.v11.5.fa",
		        "enrichment_path": "487909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487909.protein.info.v11.5.txt",
		        "node_list_path": "487909.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusMachipongonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus machipongonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusMachipongonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "388413.protein.sequences.v11.5.fa",
		        "enrichment_path": "388413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388413.protein.info.v11.5.txt",
		        "node_list_path": "388413.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpLig30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. lig30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpLig30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1192124.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192124.protein.info.v11.5.txt",
		        "node_list_path": "1192124.protein.complete.v11.5.txt"
		    }
		]
    )()

def CognatiyooniaSediminum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cognatiyoonia sediminum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CognatiyooniaSediminum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1508389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1508389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1508389.protein.info.v11.5.txt",
		        "node_list_path": "1508389.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSpPbn3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. PBN3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpPbn3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397528.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397528.protein.info.v11.5.txt",
		        "node_list_path": "1397528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaLincolnii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella lincolnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaLincolnii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "90241.protein.sequences.v11.5.fa",
		        "enrichment_path": "90241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90241.protein.info.v11.5.txt",
		        "node_list_path": "90241.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarisediminitaleaAggregataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marisediminitalea aggregata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarisediminitaleaAggregataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634436.clusters.proteins.v11.5.txt",
		        "sequence_path": "634436.protein.sequences.v11.5.fa",
		        "enrichment_path": "634436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634436.protein.info.v11.5.txt",
		        "node_list_path": "634436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DolichospermumCircinaleAwqc131cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dolichospermum circinale AWQC131C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DolichospermumCircinaleAwqc131cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398007.clusters.proteins.v11.5.txt",
		        "sequence_path": "398007.protein.sequences.v11.5.fa",
		        "enrichment_path": "398007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398007.protein.info.v11.5.txt",
		        "node_list_path": "398007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioPanuliriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio panuliri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioPanuliriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1381081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1381081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1381081.clusters.proteins.v11.5.txt",
		        "sequence_path": "1381081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381081.protein.info.v11.5.txt",
		        "node_list_path": "1381081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1381081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRbg133914Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RBG_13_39_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRbg133914Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797985.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797985.protein.info.v11.5.txt",
		        "node_list_path": "1797985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EhrlichiaSpHfCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia sp. HF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EhrlichiaSpHfCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391036.clusters.proteins.v11.5.txt",
		        "sequence_path": "391036.protein.sequences.v11.5.fa",
		        "enrichment_path": "391036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391036.protein.info.v11.5.txt",
		        "node_list_path": "391036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMicrarchaeotaArchaeonRbg16369Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon RBG_16_36_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonRbg16369Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801632.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801632.protein.info.v11.5.txt",
		        "node_list_path": "1801632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinisporaArenicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinispora arenicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisporaArenicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391037.protein.sequences.v11.5.fa",
		        "enrichment_path": "391037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391037.protein.info.v11.5.txt",
		        "node_list_path": "391037.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp142mfcol31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 142MFCol31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp142mfcol31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1172179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1172179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1172179.clusters.proteins.v11.5.txt",
		        "sequence_path": "1172179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172179.protein.info.v11.5.txt",
		        "node_list_path": "1172179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1172179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpLeaf336(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf336 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpLeaf336", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736341.protein.info.v11.5.txt",
		        "node_list_path": "1736341.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu089Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU089 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu089Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671661.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671661.protein.info.v11.5.txt",
		        "node_list_path": "1671661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusMucilaginosus3016Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus mucilaginosus 3016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusMucilaginosus3016Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1116391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1116391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1116391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1116391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116391.protein.info.v11.5.txt",
		        "node_list_path": "1116391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1116391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumNeonatale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium neonatale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumNeonatale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "137838.protein.sequences.v11.5.fa",
		        "enrichment_path": "137838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137838.protein.info.v11.5.txt",
		        "node_list_path": "137838.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaParamesenteroidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella paramesenteroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaParamesenteroidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585506.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585506.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585506.clusters.proteins.v11.5.txt",
		        "sequence_path": "585506.protein.sequences.v11.5.fa",
		        "enrichment_path": "585506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585506.protein.info.v11.5.txt",
		        "node_list_path": "585506.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585506.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SuillusLuteusUhSluLm8N1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Suillus luteus UH-Slu-Lm8-n1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuillusLuteusUhSluLm8N1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930992.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930992.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930992.clusters.proteins.v11.5.txt",
		        "sequence_path": "930992.protein.sequences.v11.5.fa",
		        "enrichment_path": "930992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930992.protein.info.v11.5.txt",
		        "node_list_path": "930992.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930992.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzobacteroidesPseudotrichonymphaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azobacteroides pseudotrichonymphae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzobacteroidesPseudotrichonymphaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "511995.clusters.info.v11.5.txt",
		        "cluster_tree_path": "511995.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "511995.clusters.proteins.v11.5.txt",
		        "sequence_path": "511995.protein.sequences.v11.5.fa",
		        "enrichment_path": "511995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511995.protein.info.v11.5.txt",
		        "node_list_path": "511995.cluster.nodes.v11.5.txt",
		        "edge_list_path": "511995.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinosporangiumAlbumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinosporangium album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinosporangiumAlbumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "504805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "504805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "504805.clusters.proteins.v11.5.txt",
		        "sequence_path": "504805.protein.sequences.v11.5.fa",
		        "enrichment_path": "504805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504805.protein.info.v11.5.txt",
		        "node_list_path": "504805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "504805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumAcidipropioniciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acidipropionici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumAcidipropioniciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1171373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1171373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1171373.clusters.proteins.v11.5.txt",
		        "sequence_path": "1171373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1171373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1171373.protein.info.v11.5.txt",
		        "node_list_path": "1171373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1171373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumPropionicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium propionicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumPropionicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "767029.protein.sequences.v11.5.fa",
		        "enrichment_path": "767029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767029.protein.info.v11.5.txt",
		        "node_list_path": "767029.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpOk048(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. OK048 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpOk048", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882761.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882761.protein.info.v11.5.txt",
		        "node_list_path": "1882761.protein.complete.v11.5.txt"
		    }
		]
    )()

def GuillardiaThetaCcmp2712Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Guillardia theta CCMP2712 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GuillardiaThetaCcmp2712Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "905079.clusters.info.v11.5.txt",
		        "cluster_tree_path": "905079.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "905079.clusters.proteins.v11.5.txt",
		        "sequence_path": "905079.protein.sequences.v11.5.fa",
		        "enrichment_path": "905079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "905079.protein.info.v11.5.txt",
		        "node_list_path": "905079.cluster.nodes.v11.5.txt",
		        "edge_list_path": "905079.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAeruginosaPao1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas aeruginosa PAO1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAeruginosaPao1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "208964.protein.sequences.v11.5.fa",
		        "enrichment_path": "208964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208964.protein.info.v11.5.txt",
		        "node_list_path": "208964.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpDd10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpDd10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777878.protein.info.v11.5.txt",
		        "node_list_path": "1777878.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfatibacillumAlkenivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfatibacillumAlkenivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "439235.clusters.info.v11.5.txt",
		        "cluster_tree_path": "439235.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "439235.clusters.proteins.v11.5.txt",
		        "sequence_path": "439235.protein.sequences.v11.5.fa",
		        "enrichment_path": "439235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439235.protein.info.v11.5.txt",
		        "node_list_path": "439235.cluster.nodes.v11.5.txt",
		        "edge_list_path": "439235.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesUncialis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces uncialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesUncialis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1048205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048205.protein.info.v11.5.txt",
		        "node_list_path": "1048205.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasAlcaliphilaJab1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alcaliphila JAB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAlcaliphilaJab1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "741155.protein.sequences.v11.5.fa",
		        "enrichment_path": "741155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "741155.protein.info.v11.5.txt",
		        "node_list_path": "741155.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaCostaiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga costaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaCostaiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1335309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1335309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1335309.clusters.proteins.v11.5.txt",
		        "sequence_path": "1335309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1335309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1335309.protein.info.v11.5.txt",
		        "node_list_path": "1335309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1335309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf24Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf24Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735690.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735690.protein.info.v11.5.txt",
		        "node_list_path": "1735690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirosomaLinguale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma linguale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaLinguale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "504472.protein.sequences.v11.5.fa",
		        "enrichment_path": "504472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504472.protein.info.v11.5.txt",
		        "node_list_path": "504472.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinicolaSpMit1003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicola sp. MIT1003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicolaSpMit1003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882734.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882734.protein.info.v11.5.txt",
		        "node_list_path": "1882734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpNies2104(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. NIES-2104 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpNies2104", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1552121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1552121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1552121.protein.info.v11.5.txt",
		        "node_list_path": "1552121.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwd23333Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWD2_33_33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwd23333Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797328.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797328.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797328.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797328.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797328.protein.info.v11.5.txt",
		        "node_list_path": "1797328.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797328.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterSpRta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter sp. RTa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterSpRta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1532557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1532557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1532557.protein.info.v11.5.txt",
		        "node_list_path": "1532557.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaDoshiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella doshiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaDoshiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094553.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094553.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094553.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094553.protein.info.v11.5.txt",
		        "node_list_path": "1094553.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094553.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumHeidelbergense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium heidelbergense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumHeidelbergense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53376.protein.sequences.v11.5.fa",
		        "enrichment_path": "53376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53376.protein.info.v11.5.txt",
		        "node_list_path": "53376.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrososphaeraEvergladensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrososphaera evergladensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrososphaeraEvergladensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1459636.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1459636.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1459636.clusters.proteins.v11.5.txt",
		        "sequence_path": "1459636.protein.sequences.v11.5.fa",
		        "enrichment_path": "1459636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1459636.protein.info.v11.5.txt",
		        "node_list_path": "1459636.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1459636.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaeCc1557Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1557 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaeCc1557Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1357279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1357279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1357279.clusters.proteins.v11.5.txt",
		        "sequence_path": "1357279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357279.protein.info.v11.5.txt",
		        "node_list_path": "1357279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1357279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumMercantei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium mercantei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumMercantei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1904807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904807.protein.info.v11.5.txt",
		        "node_list_path": "1904807.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrrellaDioscoreaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Orrella dioscoreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrrellaDioscoreaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1851544.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1851544.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1851544.clusters.proteins.v11.5.txt",
		        "sequence_path": "1851544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1851544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1851544.protein.info.v11.5.txt",
		        "node_list_path": "1851544.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1851544.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucorCircinelloidesFLusitanicusCbs27749(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. lusitanicus CBS 277.49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucorCircinelloidesFLusitanicusCbs27749", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "747725.protein.sequences.v11.5.fa",
		        "enrichment_path": "747725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747725.protein.info.v11.5.txt",
		        "node_list_path": "747725.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumHimb59Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB59 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumHimb59Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "744985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "744985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "744985.clusters.proteins.v11.5.txt",
		        "sequence_path": "744985.protein.sequences.v11.5.fa",
		        "enrichment_path": "744985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "744985.protein.info.v11.5.txt",
		        "node_list_path": "744985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "744985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaPealeana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella pealeana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaPealeana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398579.protein.sequences.v11.5.fa",
		        "enrichment_path": "398579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398579.protein.info.v11.5.txt",
		        "node_list_path": "398579.protein.complete.v11.5.txt"
		    }
		]
    )()

def FaecalibacteriumPrausnitziiKle1255Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii KLE1255 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibacteriumPrausnitziiKle1255Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "748224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "748224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "748224.clusters.proteins.v11.5.txt",
		        "sequence_path": "748224.protein.sequences.v11.5.fa",
		        "enrichment_path": "748224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748224.protein.info.v11.5.txt",
		        "node_list_path": "748224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "748224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPacaenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pacaense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPacaenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816684.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816684.protein.info.v11.5.txt",
		        "node_list_path": "1816684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSaprophyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus saprophyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSaprophyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "342451.protein.sequences.v11.5.fa",
		        "enrichment_path": "342451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342451.protein.info.v11.5.txt",
		        "node_list_path": "342451.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumNovocastrense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium novocastrense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumNovocastrense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59813.protein.sequences.v11.5.fa",
		        "enrichment_path": "59813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59813.protein.info.v11.5.txt",
		        "node_list_path": "59813.protein.complete.v11.5.txt"
		    }
		]
    )()

def JaculusJaculusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jaculus jaculus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JaculusJaculusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "51337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "51337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "51337.clusters.proteins.v11.5.txt",
		        "sequence_path": "51337.protein.sequences.v11.5.fa",
		        "enrichment_path": "51337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51337.protein.info.v11.5.txt",
		        "node_list_path": "51337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "51337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronobacteriumGregoryiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronobacterium gregoryi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronobacteriumGregoryiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "797304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "797304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "797304.clusters.proteins.v11.5.txt",
		        "sequence_path": "797304.protein.sequences.v11.5.fa",
		        "enrichment_path": "797304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797304.protein.info.v11.5.txt",
		        "node_list_path": "797304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "797304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusPneumoniaeTigr4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae TIGR4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPneumoniaeTigr4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "170187.clusters.info.v11.5.txt",
		        "cluster_tree_path": "170187.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "170187.clusters.proteins.v11.5.txt",
		        "sequence_path": "170187.protein.sequences.v11.5.fa",
		        "enrichment_path": "170187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "170187.protein.info.v11.5.txt",
		        "node_list_path": "170187.cluster.nodes.v11.5.txt",
		        "edge_list_path": "170187.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolycyclovoransAlgicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polycyclovorans algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolycyclovoransAlgicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415779.protein.info.v11.5.txt",
		        "node_list_path": "1415779.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumLlx17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium LLX17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumLlx17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229203.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229203.protein.info.v11.5.txt",
		        "node_list_path": "1229203.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerruconisGallopava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verruconis gallopava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerruconisGallopava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "253628.protein.sequences.v11.5.fa",
		        "enrichment_path": "253628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "253628.protein.info.v11.5.txt",
		        "node_list_path": "253628.protein.complete.v11.5.txt"
		    }
		]
    )()

def CanisLupus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Canis lupus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CanisLupus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9612.protein.sequences.v11.5.fa",
		        "enrichment_path": "9612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9612.protein.info.v11.5.txt",
		        "node_list_path": "9612.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho202Full5012(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_02_FULL_50_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho202Full5012", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802685.protein.info.v11.5.txt",
		        "node_list_path": "1802685.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaHippikonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma hippikon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaHippikonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408416.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408416.protein.info.v11.5.txt",
		        "node_list_path": "1408416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxParadoxus110bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax paradoxus 110B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxParadoxus110bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157708.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157708.protein.info.v11.5.txt",
		        "node_list_path": "1157708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpN54Mgs139(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. N54.MGS-139 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpN54Mgs139", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1637509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1637509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1637509.protein.info.v11.5.txt",
		        "node_list_path": "1637509.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaSaliphilaYim90502(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora saliphila YIM 90502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaSaliphilaYim90502", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "882085.protein.sequences.v11.5.fa",
		        "enrichment_path": "882085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882085.protein.info.v11.5.txt",
		        "node_list_path": "882085.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpPml113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. PML113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpPml113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1899350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1899350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1899350.protein.info.v11.5.txt",
		        "node_list_path": "1899350.protein.complete.v11.5.txt"
		    }
		]
    )()

def NonlabensUlvanivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens ulvanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensUlvanivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "906888.clusters.info.v11.5.txt",
		        "cluster_tree_path": "906888.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "906888.clusters.proteins.v11.5.txt",
		        "sequence_path": "906888.protein.sequences.v11.5.fa",
		        "enrichment_path": "906888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "906888.protein.info.v11.5.txt",
		        "node_list_path": "906888.cluster.nodes.v11.5.txt",
		        "edge_list_path": "906888.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaSpCag303(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSpCag303", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262944.protein.info.v11.5.txt",
		        "node_list_path": "1262944.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpBsw20308(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. Bsw20308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpBsw20308", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "283699.protein.sequences.v11.5.fa",
		        "enrichment_path": "283699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283699.protein.info.v11.5.txt",
		        "node_list_path": "283699.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTuberculosisVariantBovis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTuberculosisVariantBovis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765.protein.info.v11.5.txt",
		        "node_list_path": "1765.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloferacaceaeArchaeonB1Br10E2g22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloferacaceae archaeon B1-Br10_E2g22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloferacaceaeArchaeonB1Br10E2g22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1732021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1732021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1732021.protein.info.v11.5.txt",
		        "node_list_path": "1732021.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag144(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:144 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag144", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262736.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262736.protein.info.v11.5.txt",
		        "node_list_path": "1262736.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaSpAl04100510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. AL041005-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaSpAl04100510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445576.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445576.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445576.clusters.proteins.v11.5.txt",
		        "sequence_path": "445576.protein.sequences.v11.5.fa",
		        "enrichment_path": "445576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445576.protein.info.v11.5.txt",
		        "node_list_path": "445576.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445576.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4332bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_43_32b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4332bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802306.protein.info.v11.5.txt",
		        "node_list_path": "1802306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpS7Ms2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. S7 MS 2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpS7Ms2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1287488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287488.protein.info.v11.5.txt",
		        "node_list_path": "1287488.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag1944415Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG_194_44_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag1944415Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897037.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897037.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897037.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897037.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897037.protein.info.v11.5.txt",
		        "node_list_path": "1897037.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897037.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MastigocladopsisRepens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mastigocladopsis repens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MastigocladopsisRepens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "221288.protein.sequences.v11.5.fa",
		        "enrichment_path": "221288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221288.protein.info.v11.5.txt",
		        "node_list_path": "221288.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls920(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS920 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls920", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463921.protein.info.v11.5.txt",
		        "node_list_path": "1463921.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHlucco07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCO07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHlucco07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1666914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1666914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1666914.clusters.proteins.v11.5.txt",
		        "sequence_path": "1666914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666914.protein.info.v11.5.txt",
		        "node_list_path": "1666914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1666914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnetofabaAustralisIt1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetofaba australis IT-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetofabaAustralisIt1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434232.protein.info.v11.5.txt",
		        "node_list_path": "1434232.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpBgarf1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. BGARF1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpBgarf1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1664319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1664319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1664319.protein.info.v11.5.txt",
		        "node_list_path": "1664319.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4718Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_47_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4718Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802313.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802313.protein.info.v11.5.txt",
		        "node_list_path": "1802313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaFortuitaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia fortuita Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaFortuitaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777138.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777138.protein.info.v11.5.txt",
		        "node_list_path": "1777138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DoreaLongicatenaDsm13814(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dorea longicatena DSM13814 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaLongicatenaDsm13814", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411462.protein.sequences.v11.5.fa",
		        "enrichment_path": "411462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411462.protein.info.v11.5.txt",
		        "node_list_path": "411462.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhyscomitrellaPatensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Physcomitrella patens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhyscomitrellaPatensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3218.clusters.proteins.v11.5.txt",
		        "sequence_path": "3218.protein.sequences.v11.5.fa",
		        "enrichment_path": "3218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3218.protein.info.v11.5.txt",
		        "node_list_path": "3218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeobacterSp11andimar09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter sp. 11ANDIMAR09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterSp11andimar09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1225647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225647.protein.info.v11.5.txt",
		        "node_list_path": "1225647.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusTrypoxylicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus trypoxylicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusTrypoxylicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "519424.protein.sequences.v11.5.fa",
		        "enrichment_path": "519424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519424.protein.info.v11.5.txt",
		        "node_list_path": "519424.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCellulosi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] cellulosi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCellulosi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29343.protein.sequences.v11.5.fa",
		        "enrichment_path": "29343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29343.protein.info.v11.5.txt",
		        "node_list_path": "29343.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumScgcAaa028A23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA028-A23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumScgcAaa028A23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "932036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "932036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "932036.clusters.proteins.v11.5.txt",
		        "sequence_path": "932036.protein.sequences.v11.5.fa",
		        "enrichment_path": "932036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932036.protein.info.v11.5.txt",
		        "node_list_path": "932036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "932036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeucothrixMucorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucothrix mucor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucothrixMucorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "998674.clusters.info.v11.5.txt",
		        "cluster_tree_path": "998674.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "998674.clusters.proteins.v11.5.txt",
		        "sequence_path": "998674.protein.sequences.v11.5.fa",
		        "enrichment_path": "998674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "998674.protein.info.v11.5.txt",
		        "node_list_path": "998674.cluster.nodes.v11.5.txt",
		        "edge_list_path": "998674.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterLuteus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterLuteus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1581420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581420.protein.info.v11.5.txt",
		        "node_list_path": "1581420.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzospirillumHumicireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum humicireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumHumicireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1226968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1226968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1226968.clusters.proteins.v11.5.txt",
		        "sequence_path": "1226968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1226968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1226968.protein.info.v11.5.txt",
		        "node_list_path": "1226968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1226968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KushneriaAurantiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kushneria aurantia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KushneriaAurantiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122139.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122139.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122139.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122139.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122139.protein.info.v11.5.txt",
		        "node_list_path": "1122139.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122139.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinopolysporaErythraeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora erythraea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolysporaErythraeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "414996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "414996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "414996.clusters.proteins.v11.5.txt",
		        "sequence_path": "414996.protein.sequences.v11.5.fa",
		        "enrichment_path": "414996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "414996.protein.info.v11.5.txt",
		        "node_list_path": "414996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "414996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGlassbacteriaBacteriumRifcsplowo212Full5811Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Glassbacteria bacterium RIFCSPLOWO2_12_FULL_58_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGlassbacteriaBacteriumRifcsplowo212Full5811Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817867.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817867.protein.info.v11.5.txt",
		        "node_list_path": "1817867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CobetiaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cobetia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CobetiaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28258.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28258.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28258.clusters.proteins.v11.5.txt",
		        "sequence_path": "28258.protein.sequences.v11.5.fa",
		        "enrichment_path": "28258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28258.protein.info.v11.5.txt",
		        "node_list_path": "28258.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28258.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusOralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1303.protein.info.v11.5.txt",
		        "node_list_path": "1303.protein.complete.v11.5.txt"
		    }
		]
    )()

def RalstoniaInsidiosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia insidiosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaInsidiosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "190721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "190721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "190721.clusters.proteins.v11.5.txt",
		        "sequence_path": "190721.protein.sequences.v11.5.fa",
		        "enrichment_path": "190721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190721.protein.info.v11.5.txt",
		        "node_list_path": "190721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "190721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusRotai(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus rotai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusRotai", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118060.protein.sequences.v11.5.fa",
		        "enrichment_path": "118060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118060.protein.info.v11.5.txt",
		        "node_list_path": "118060.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaromonasGlacialis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas glacialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasGlacialis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "866564.protein.sequences.v11.5.fa",
		        "enrichment_path": "866564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866564.protein.info.v11.5.txt",
		        "node_list_path": "866564.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioNavarrensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio navarrensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioNavarrensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29495.protein.sequences.v11.5.fa",
		        "enrichment_path": "29495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29495.protein.info.v11.5.txt",
		        "node_list_path": "29495.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfolobusTokodaiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus tokodaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusTokodaiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "273063.clusters.info.v11.5.txt",
		        "cluster_tree_path": "273063.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "273063.clusters.proteins.v11.5.txt",
		        "sequence_path": "273063.protein.sequences.v11.5.fa",
		        "enrichment_path": "273063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273063.protein.info.v11.5.txt",
		        "node_list_path": "273063.cluster.nodes.v11.5.txt",
		        "edge_list_path": "273063.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprothermobacterProteolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprothermobacter proteolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprothermobacterProteolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "309798.protein.sequences.v11.5.fa",
		        "enrichment_path": "309798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "309798.protein.info.v11.5.txt",
		        "node_list_path": "309798.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "361041.protein.sequences.v11.5.fa",
		        "enrichment_path": "361041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "361041.protein.info.v11.5.txt",
		        "node_list_path": "361041.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaHinziiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella hinzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaHinziiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392838.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392838.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392838.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392838.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392838.protein.info.v11.5.txt",
		        "node_list_path": "1392838.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392838.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycesSpShPl62(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces sp. SH-PL62 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycesSpShPl62", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1636152.protein.sequences.v11.5.fa",
		        "enrichment_path": "1636152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1636152.protein.info.v11.5.txt",
		        "node_list_path": "1636152.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpDs20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. DS20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpDs20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1532555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1532555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1532555.protein.info.v11.5.txt",
		        "node_list_path": "1532555.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlammeovirgaceaeBacteriumBbd199112(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flammeovirgaceae bacterium BBD 1991-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlammeovirgaceaeBacteriumBbd199112", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852619.protein.info.v11.5.txt",
		        "node_list_path": "1852619.protein.complete.v11.5.txt"
		    }
		]
    )()

def PectobacteriumBetavasculorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium betavasculorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumBetavasculorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "55207.clusters.info.v11.5.txt",
		        "cluster_tree_path": "55207.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "55207.clusters.proteins.v11.5.txt",
		        "sequence_path": "55207.protein.sequences.v11.5.fa",
		        "enrichment_path": "55207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55207.protein.info.v11.5.txt",
		        "node_list_path": "55207.cluster.nodes.v11.5.txt",
		        "edge_list_path": "55207.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteribacillusPersepolensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteribacillus persepolensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteribacillusPersepolensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "568899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "568899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "568899.clusters.proteins.v11.5.txt",
		        "sequence_path": "568899.protein.sequences.v11.5.fa",
		        "enrichment_path": "568899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568899.protein.info.v11.5.txt",
		        "node_list_path": "568899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "568899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls37(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls37", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463903.protein.info.v11.5.txt",
		        "node_list_path": "1463903.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterLwoffii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterLwoffii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28090.protein.sequences.v11.5.fa",
		        "enrichment_path": "28090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28090.protein.info.v11.5.txt",
		        "node_list_path": "28090.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermobifidaFusca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermobifida fusca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobifidaFusca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "269800.protein.sequences.v11.5.fa",
		        "enrichment_path": "269800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269800.protein.info.v11.5.txt",
		        "node_list_path": "269800.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasVeronii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas veronii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasVeronii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "998088.protein.sequences.v11.5.fa",
		        "enrichment_path": "998088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "998088.protein.info.v11.5.txt",
		        "node_list_path": "998088.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizopusStoloniferCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus stolonifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizopusStoloniferCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4846.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4846.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4846.clusters.proteins.v11.5.txt",
		        "sequence_path": "4846.protein.sequences.v11.5.fa",
		        "enrichment_path": "4846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4846.protein.info.v11.5.txt",
		        "node_list_path": "4846.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4846.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaMazei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina mazei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaMazei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "192952.protein.sequences.v11.5.fa",
		        "enrichment_path": "192952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192952.protein.info.v11.5.txt",
		        "node_list_path": "192952.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichodermaVirens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma virens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaVirens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29875.protein.sequences.v11.5.fa",
		        "enrichment_path": "29875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29875.protein.info.v11.5.txt",
		        "node_list_path": "29875.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumDtu015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumDtu015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671637.protein.info.v11.5.txt",
		        "node_list_path": "1671637.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1024112(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_41_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024112", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805307.protein.info.v11.5.txt",
		        "node_list_path": "1805307.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSpGj21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. GJ21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSpGj21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "113574.protein.sequences.v11.5.fa",
		        "enrichment_path": "113574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113574.protein.info.v11.5.txt",
		        "node_list_path": "113574.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSalivarius57iCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus salivarius 57I Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSalivarius57iCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1046629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1046629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1046629.clusters.proteins.v11.5.txt",
		        "sequence_path": "1046629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046629.protein.info.v11.5.txt",
		        "node_list_path": "1046629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1046629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumXylanophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium xylanophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumXylanophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336241.protein.info.v11.5.txt",
		        "node_list_path": "1336241.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwa25510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_55_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797809.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797809.protein.info.v11.5.txt",
		        "node_list_path": "1797809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PiliocolobusTephroscelesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Piliocolobus tephrosceles Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiliocolobusTephroscelesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "591936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "591936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "591936.clusters.proteins.v11.5.txt",
		        "sequence_path": "591936.protein.sequences.v11.5.fa",
		        "enrichment_path": "591936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591936.protein.info.v11.5.txt",
		        "node_list_path": "591936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "591936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapsasporaOwczarzakiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capsaspora owczarzaki Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsasporaOwczarzakiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "192875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "192875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "192875.clusters.proteins.v11.5.txt",
		        "sequence_path": "192875.protein.sequences.v11.5.fa",
		        "enrichment_path": "192875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192875.protein.info.v11.5.txt",
		        "node_list_path": "192875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "192875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulosilyticumRuminicolaJcm14822(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulosilyticum ruminicola JCM 14822 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulosilyticumRuminicolaJcm14822", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1294025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294025.protein.info.v11.5.txt",
		        "node_list_path": "1294025.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaSpLrs4154Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. LRS4.154 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaSpLrs4154Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1962155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1962155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1962155.clusters.proteins.v11.5.txt",
		        "sequence_path": "1962155.protein.sequences.v11.5.fa",
		        "enrichment_path": "1962155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1962155.protein.info.v11.5.txt",
		        "node_list_path": "1962155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1962155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpGcs4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. GCS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpGcs4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1692239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1692239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1692239.protein.info.v11.5.txt",
		        "node_list_path": "1692239.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsplowo202Full4813b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_02_FULL_48_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo202Full4813b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802283.protein.info.v11.5.txt",
		        "node_list_path": "1802283.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonRbg136020(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_60_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg136020", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797380.protein.info.v11.5.txt",
		        "node_list_path": "1797380.protein.complete.v11.5.txt"
		    }
		]
    )()

def DechloromonasDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dechloromonas denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DechloromonasDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "281362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "281362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "281362.clusters.proteins.v11.5.txt",
		        "sequence_path": "281362.protein.sequences.v11.5.fa",
		        "enrichment_path": "281362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "281362.protein.info.v11.5.txt",
		        "node_list_path": "281362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "281362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumFacile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium facile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumFacile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "51670.protein.sequences.v11.5.fa",
		        "enrichment_path": "51670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51670.protein.info.v11.5.txt",
		        "node_list_path": "51670.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErysipelotrichaceaeBacterium3153(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium 3153 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelotrichaceaeBacterium3153", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658659.protein.sequences.v11.5.fa",
		        "enrichment_path": "658659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658659.protein.info.v11.5.txt",
		        "node_list_path": "658659.protein.complete.v11.5.txt"
		    }
		]
    )()

def MalasseziaVespertilionis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Malassezia vespertilionis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalasseziaVespertilionis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2020962.protein.sequences.v11.5.fa",
		        "enrichment_path": "2020962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2020962.protein.info.v11.5.txt",
		        "node_list_path": "2020962.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumUmmariense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium ummariense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumUmmariense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "913024.protein.sequences.v11.5.fa",
		        "enrichment_path": "913024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913024.protein.info.v11.5.txt",
		        "node_list_path": "913024.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanicellaActignisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicella actignis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicellaActignisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1189325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1189325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1189325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1189325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1189325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1189325.protein.info.v11.5.txt",
		        "node_list_path": "1189325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1189325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def Sar324ClusterBacteriumSar324Ctd7b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return SAR324 cluster bacterium SAR324-CTD7B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar324ClusterBacteriumSar324Ctd7b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1795556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795556.protein.info.v11.5.txt",
		        "node_list_path": "1795556.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifoxyb1Full4319(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYB1_FULL_43_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxyb1Full4319", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801649.protein.info.v11.5.txt",
		        "node_list_path": "1801649.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosotenuisChungbukensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis chungbukensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosotenuisChungbukensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1353246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1353246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1353246.clusters.proteins.v11.5.txt",
		        "sequence_path": "1353246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353246.protein.info.v11.5.txt",
		        "node_list_path": "1353246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1353246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpMsp13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MSP13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpMsp13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071061.protein.info.v11.5.txt",
		        "node_list_path": "1071061.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetarhiziumAnisopliaeBrip53293(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium anisopliae BRIP 53293 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetarhiziumAnisopliaeBrip53293", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1291518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291518.protein.info.v11.5.txt",
		        "node_list_path": "1291518.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpYk2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. YK2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpYk2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1860096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1860096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1860096.clusters.proteins.v11.5.txt",
		        "sequence_path": "1860096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860096.protein.info.v11.5.txt",
		        "node_list_path": "1860096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1860096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WigglesworthiaGlossinidiaSpGmo(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia sp. Gmo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WigglesworthiaGlossinidiaSpGmo", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1142511.protein.sequences.v11.0.fa",
		        "enrichment_path": "1142511.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1142511.protein.info.v11.0.txt",
		        "node_list_path": "1142511.protein.complete.v11.0.txt"
		    }
		]
    )()

def StreptomycesPristinaespiralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces pristinaespiralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPristinaespiralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "457429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "457429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "457429.clusters.proteins.v11.5.txt",
		        "sequence_path": "457429.protein.sequences.v11.5.fa",
		        "enrichment_path": "457429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457429.protein.info.v11.5.txt",
		        "node_list_path": "457429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "457429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisB6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis B6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisB6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "365659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "365659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "365659.clusters.proteins.v11.5.txt",
		        "sequence_path": "365659.protein.sequences.v11.5.fa",
		        "enrichment_path": "365659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "365659.protein.info.v11.5.txt",
		        "node_list_path": "365659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "365659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhyseterCatodon(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Physeter catodon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhyseterCatodon", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9755.protein.sequences.v11.5.fa",
		        "enrichment_path": "9755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9755.protein.info.v11.5.txt",
		        "node_list_path": "9755.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrinickiaCaryophylliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trinickia caryophylli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrinickiaCaryophylliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28094.clusters.proteins.v11.5.txt",
		        "sequence_path": "28094.protein.sequences.v11.5.fa",
		        "enrichment_path": "28094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28094.protein.info.v11.5.txt",
		        "node_list_path": "28094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrenneriaGoodwinii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brenneria goodwinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrenneriaGoodwinii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1109412.protein.sequences.v11.5.fa",
		        "enrichment_path": "1109412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1109412.protein.info.v11.5.txt",
		        "node_list_path": "1109412.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusCapillatusDsm19910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus capillatus DSM 19910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCapillatusDsm19910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423731.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423731.protein.info.v11.5.txt",
		        "node_list_path": "1423731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BalneolaSpEhc07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Balneola sp. EhC07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BalneolaSpEhc07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849360.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849360.protein.info.v11.5.txt",
		        "node_list_path": "1849360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermocrinisAlbus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermocrinis albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocrinisAlbus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "638303.protein.sequences.v11.5.fa",
		        "enrichment_path": "638303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "638303.protein.info.v11.5.txt",
		        "node_list_path": "638303.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioMetschnikoviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio metschnikovii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioMetschnikoviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675813.clusters.proteins.v11.5.txt",
		        "sequence_path": "675813.protein.sequences.v11.5.fa",
		        "enrichment_path": "675813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675813.protein.info.v11.5.txt",
		        "node_list_path": "675813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedClostridiaBacterium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Clostridia bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedClostridiaBacterium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "244328.protein.sequences.v11.5.fa",
		        "enrichment_path": "244328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244328.protein.info.v11.5.txt",
		        "node_list_path": "244328.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3616(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_01_FULL_36_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3616", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802200.protein.info.v11.5.txt",
		        "node_list_path": "1802200.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCsiV(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CSI-V graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCsiV", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1933777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933777.protein.info.v11.5.txt",
		        "node_list_path": "1933777.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpDsm11652(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. DSM 11652 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpDsm11652", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "346222.protein.sequences.v11.5.fa",
		        "enrichment_path": "346222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "346222.protein.info.v11.5.txt",
		        "node_list_path": "346222.protein.complete.v11.5.txt"
		    }
		]
    )()

def BosIndicusXBosTaurusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bos indicus x Bos taurus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BosIndicusXBosTaurusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "30522.clusters.info.v11.5.txt",
		        "cluster_tree_path": "30522.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "30522.clusters.proteins.v11.5.txt",
		        "sequence_path": "30522.protein.sequences.v11.5.fa",
		        "enrichment_path": "30522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30522.protein.info.v11.5.txt",
		        "node_list_path": "30522.cluster.nodes.v11.5.txt",
		        "edge_list_path": "30522.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwb26316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWB2_63_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwb26316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797928.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797928.protein.info.v11.5.txt",
		        "node_list_path": "1797928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumNodatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium nodatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumNodatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1161902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1161902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1161902.clusters.proteins.v11.5.txt",
		        "sequence_path": "1161902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1161902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1161902.protein.info.v11.5.txt",
		        "node_list_path": "1161902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1161902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryobacteriumFlavum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryobacterium flavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryobacteriumFlavum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1424659.protein.sequences.v11.5.fa",
		        "enrichment_path": "1424659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1424659.protein.info.v11.5.txt",
		        "node_list_path": "1424659.protein.complete.v11.5.txt"
		    }
		]
    )()

def MalonomonasRubraDsm5091Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Malonomonas rubra DSM 5091 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalonomonasRubraDsm5091Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122189.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122189.protein.info.v11.5.txt",
		        "node_list_path": "1122189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaInsecticolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia insecticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaInsecticolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "758793.clusters.info.v11.5.txt",
		        "cluster_tree_path": "758793.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "758793.clusters.proteins.v11.5.txt",
		        "sequence_path": "758793.protein.sequences.v11.5.fa",
		        "enrichment_path": "758793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758793.protein.info.v11.5.txt",
		        "node_list_path": "758793.cluster.nodes.v11.5.txt",
		        "edge_list_path": "758793.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumSpSponge(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium sp. sponge graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumSpSponge", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1775432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775432.protein.info.v11.5.txt",
		        "node_list_path": "1775432.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumMola814Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium MOLA814 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumMola814Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408164.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408164.protein.info.v11.5.txt",
		        "node_list_path": "1408164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpPf153(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Pf153 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpPf153", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1699309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1699309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1699309.protein.info.v11.5.txt",
		        "node_list_path": "1699309.protein.complete.v11.5.txt"
		    }
		]
    )()

def RodentibacterMraziiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter mrazii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterMraziiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1908257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1908257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1908257.clusters.proteins.v11.5.txt",
		        "sequence_path": "1908257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908257.protein.info.v11.5.txt",
		        "node_list_path": "1908257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1908257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporichthyaPolymorphaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporichthya polymorpha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporichthyaPolymorphaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1048339.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1048339.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1048339.clusters.proteins.v11.5.txt",
		        "sequence_path": "1048339.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048339.protein.info.v11.5.txt",
		        "node_list_path": "1048339.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1048339.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumSquillarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium squillarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumSquillarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1074488.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1074488.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1074488.clusters.proteins.v11.5.txt",
		        "sequence_path": "1074488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1074488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1074488.protein.info.v11.5.txt",
		        "node_list_path": "1074488.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1074488.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterColiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter coli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterColiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "195.clusters.proteins.v11.5.txt",
		        "sequence_path": "195.protein.sequences.v11.5.fa",
		        "enrichment_path": "195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195.protein.info.v11.5.txt",
		        "node_list_path": "195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NanohaloarchaeaArchaeonSg9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon SG9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NanohaloarchaeaArchaeonSg9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1737403.protein.sequences.v11.5.fa",
		        "enrichment_path": "1737403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1737403.protein.info.v11.5.txt",
		        "node_list_path": "1737403.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlsr1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALSr1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlsr1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "748658.protein.sequences.v11.5.fa",
		        "enrichment_path": "748658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748658.protein.info.v11.5.txt",
		        "node_list_path": "748658.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusFloricolaDsm23037Jcm16512Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus floricola DSM 23037 JCM 16512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFloricolaDsm23037Jcm16512Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423744.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423744.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423744.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423744.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423744.protein.info.v11.5.txt",
		        "node_list_path": "1423744.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423744.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumRubrisubalbicansM1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum rubrisubalbicans M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumRubrisubalbicansM1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1078773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078773.protein.info.v11.5.txt",
		        "node_list_path": "1078773.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHtcc7217Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC7217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHtcc7217Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1400525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1400525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1400525.clusters.proteins.v11.5.txt",
		        "sequence_path": "1400525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400525.protein.info.v11.5.txt",
		        "node_list_path": "1400525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1400525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr35Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr35Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1934992.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1934992.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1934992.clusters.proteins.v11.5.txt",
		        "sequence_path": "1934992.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934992.protein.info.v11.5.txt",
		        "node_list_path": "1934992.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1934992.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusCecorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus cecorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusCecorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121864.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121864.protein.info.v11.5.txt",
		        "node_list_path": "1121864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SandarakinorhabdusLimnophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sandarakinorhabdus limnophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SandarakinorhabdusLimnophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123240.protein.info.v11.5.txt",
		        "node_list_path": "1123240.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosospiraSp5618(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. 56-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraSp5618", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895901.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895901.protein.info.v11.5.txt",
		        "node_list_path": "1895901.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumWolinskyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium wolinskyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumWolinskyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59750.protein.sequences.v11.5.fa",
		        "enrichment_path": "59750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59750.protein.info.v11.5.txt",
		        "node_list_path": "59750.protein.complete.v11.5.txt"
		    }
		]
    )()

def YaniellaHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yaniella halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YaniellaHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123507.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123507.protein.info.v11.5.txt",
		        "node_list_path": "1123507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KinetoplastibacteriumCrithidiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium crithidii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KinetoplastibacteriumCrithidiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208918.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208918.protein.info.v11.5.txt",
		        "node_list_path": "1208918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaceaeSpMortierellaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Burkholderiaceae sp. Mortierella Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaceaeSpMortierellaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1562701.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1562701.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1562701.clusters.proteins.v11.0.txt",
		        "sequence_path": "1562701.protein.sequences.v11.0.fa",
		        "enrichment_path": "1562701.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1562701.protein.info.v11.0.txt",
		        "node_list_path": "1562701.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1562701.protein.cluster.v11.0.txt"
		    }
		]
    )()

def KallipygaGabonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kallipyga gabonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KallipygaGabonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1686287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1686287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1686287.protein.info.v11.5.txt",
		        "node_list_path": "1686287.protein.complete.v11.5.txt"
		    }
		]
    )()

def AromatoleumAromaticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aromatoleum aromaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AromatoleumAromaticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "76114.protein.sequences.v11.5.fa",
		        "enrichment_path": "76114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76114.protein.info.v11.5.txt",
		        "node_list_path": "76114.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5525(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_55_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5525", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798517.protein.info.v11.5.txt",
		        "node_list_path": "1798517.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwb1448Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWB1_44_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwb1448Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618505.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618505.protein.info.v11.5.txt",
		        "node_list_path": "1618505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CroceicoccusMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Croceicoccus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CroceicoccusMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "450378.protein.sequences.v11.5.fa",
		        "enrichment_path": "450378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "450378.protein.info.v11.5.txt",
		        "node_list_path": "450378.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoschusMoschiferus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moschus moschiferus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoschusMoschiferus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68415.protein.sequences.v11.5.fa",
		        "enrichment_path": "68415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68415.protein.info.v11.5.txt",
		        "node_list_path": "68415.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpFc2001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FC2001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpFc2001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280671.protein.info.v11.5.txt",
		        "node_list_path": "1280671.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumCg1025453(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium CG1_02_54_53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumCg1025453", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805323.protein.info.v11.5.txt",
		        "node_list_path": "1805323.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudosphingobacteriumDomesticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudosphingobacterium domesticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudosphingobacteriumDomesticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "407022.protein.sequences.v11.5.fa",
		        "enrichment_path": "407022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "407022.protein.info.v11.5.txt",
		        "node_list_path": "407022.protein.complete.v11.5.txt"
		    }
		]
    )()

def PonticoccusMarisrubri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ponticoccus marisrubri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PonticoccusMarisrubri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1685382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685382.protein.info.v11.5.txt",
		        "node_list_path": "1685382.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudaminobacterSalicylatoxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudaminobacter salicylatoxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudaminobacterSalicylatoxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1192868.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1192868.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1192868.clusters.proteins.v11.5.txt",
		        "sequence_path": "1192868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192868.protein.info.v11.5.txt",
		        "node_list_path": "1192868.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1192868.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydomonasEustigmaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydomonas eustigma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydomonasEustigmaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1157962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1157962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1157962.clusters.proteins.v11.5.txt",
		        "sequence_path": "1157962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157962.protein.info.v11.5.txt",
		        "node_list_path": "1157962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1157962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinospirillumInsulare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinospirillum insulare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinospirillumInsulare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122211.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122211.protein.info.v11.5.txt",
		        "node_list_path": "1122211.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalegentibacterHolothuriorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter holothuriorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterHolothuriorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "241145.protein.sequences.v11.5.fa",
		        "enrichment_path": "241145.protein.enrichment.terms.v11.5.txt",
		        "info_path": "241145.protein.info.v11.5.txt",
		        "node_list_path": "241145.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaBergensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBergensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585502.protein.sequences.v11.5.fa",
		        "enrichment_path": "585502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585502.protein.info.v11.5.txt",
		        "node_list_path": "585502.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlareaLozoyensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glarea lozoyensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlareaLozoyensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "101852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "101852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "101852.clusters.proteins.v11.5.txt",
		        "sequence_path": "101852.protein.sequences.v11.5.fa",
		        "enrichment_path": "101852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101852.protein.info.v11.5.txt",
		        "node_list_path": "101852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "101852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsaiaPrunellaeJcm25354(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asaia prunellae JCM 25354 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsaiaPrunellaeJcm25354", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236502.protein.info.v11.5.txt",
		        "node_list_path": "1236502.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpIcm39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. ICM39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpIcm39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1105029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1105029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1105029.clusters.proteins.v11.5.txt",
		        "sequence_path": "1105029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1105029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1105029.protein.info.v11.5.txt",
		        "node_list_path": "1105029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1105029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ScheffersomycesStipitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scheffersomyces stipitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScheffersomycesStipitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4924.protein.sequences.v11.5.fa",
		        "enrichment_path": "4924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4924.protein.info.v11.5.txt",
		        "node_list_path": "4924.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusAtlanticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusAtlanticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1641875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1641875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1641875.clusters.proteins.v11.5.txt",
		        "sequence_path": "1641875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1641875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1641875.protein.info.v11.5.txt",
		        "node_list_path": "1641875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1641875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenobacterThermophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenobacter thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenobacterThermophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "608538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "608538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "608538.clusters.proteins.v11.5.txt",
		        "sequence_path": "608538.protein.sequences.v11.5.fa",
		        "enrichment_path": "608538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "608538.protein.info.v11.5.txt",
		        "node_list_path": "608538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "608538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpHjm029(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. HJM029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpHjm029", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1433844.protein.sequences.v11.5.fa",
		        "enrichment_path": "1433844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1433844.protein.info.v11.5.txt",
		        "node_list_path": "1433844.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronohydrobacterThiooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronohydrobacter thiooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronohydrobacterThiooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "87172.protein.sequences.v11.5.fa",
		        "enrichment_path": "87172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "87172.protein.info.v11.5.txt",
		        "node_list_path": "87172.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumCpb6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium CPB6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumCpb6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1572656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1572656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1572656.protein.info.v11.5.txt",
		        "node_list_path": "1572656.protein.complete.v11.5.txt"
		    }
		]
    )()

def PimelobacterSimplex(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pimelobacter simplex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PimelobacterSimplex", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2045.protein.sequences.v11.5.fa",
		        "enrichment_path": "2045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2045.protein.info.v11.5.txt",
		        "node_list_path": "2045.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaBrevicatena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia brevicatena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaBrevicatena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206725.protein.info.v11.5.txt",
		        "node_list_path": "1206725.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacterium5039(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 50-39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacterium5039", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895841.protein.info.v11.5.txt",
		        "node_list_path": "1895841.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpOv279(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. OV279 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpOv279", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500285.protein.info.v11.5.txt",
		        "node_list_path": "1500285.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacteriumGwf23715(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium GWF2_37_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacteriumGwf23715", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801606.protein.info.v11.5.txt",
		        "node_list_path": "1801606.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzospirillumHalopraeferens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum halopraeferens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumHalopraeferens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121033.protein.info.v11.5.txt",
		        "node_list_path": "1121033.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Paracoccus denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "318586.clusters.info.v11.0.txt",
		        "cluster_tree_path": "318586.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "318586.clusters.proteins.v11.0.txt",
		        "sequence_path": "318586.protein.sequences.v11.0.fa",
		        "enrichment_path": "318586.protein.enrichment.terms.v11.0.txt",
		        "info_path": "318586.protein.info.v11.0.txt",
		        "node_list_path": "318586.cluster.nodes.v11.0.txt",
		        "edge_list_path": "318586.protein.cluster.v11.0.txt"
		    }
		]
    )()

def StreptomycesSpCf386(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. cf386 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCf386", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761904.protein.info.v11.5.txt",
		        "node_list_path": "1761904.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpVcb2006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. VCB2006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpVcb2006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280679.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280679.protein.info.v11.5.txt",
		        "node_list_path": "1280679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphriteaJaponicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amphritea japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphriteaJaponicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1278309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1278309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1278309.clusters.proteins.v11.5.txt",
		        "sequence_path": "1278309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278309.protein.info.v11.5.txt",
		        "node_list_path": "1278309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1278309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMusc93Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MUSC 93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMusc93Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1428652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1428652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1428652.clusters.proteins.v11.5.txt",
		        "sequence_path": "1428652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1428652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1428652.protein.info.v11.5.txt",
		        "node_list_path": "1428652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1428652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaPelophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina pelophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaPelophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1638984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638984.protein.info.v11.5.txt",
		        "node_list_path": "1638984.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidiaBacterium4341(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidia bacterium 43-41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidiaBacterium4341", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895720.protein.info.v11.5.txt",
		        "node_list_path": "1895720.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerinicoccusChungangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serinicoccus chungangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerinicoccusChungangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "767452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "767452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "767452.clusters.proteins.v11.5.txt",
		        "sequence_path": "767452.protein.sequences.v11.5.fa",
		        "enrichment_path": "767452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767452.protein.info.v11.5.txt",
		        "node_list_path": "767452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "767452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaPhenaziniumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia phenazinium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaPhenaziniumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "60549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "60549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "60549.clusters.proteins.v11.5.txt",
		        "sequence_path": "60549.protein.sequences.v11.5.fa",
		        "enrichment_path": "60549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60549.protein.info.v11.5.txt",
		        "node_list_path": "60549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "60549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrospiraPlatensisYz(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrospira platensis YZ graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrospiraPlatensisYz", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1738638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1738638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1738638.protein.info.v11.5.txt",
		        "node_list_path": "1738638.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGullanellaEndobiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gullanella endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGullanellaEndobiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1070130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1070130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1070130.clusters.proteins.v11.5.txt",
		        "sequence_path": "1070130.protein.sequences.v11.5.fa",
		        "enrichment_path": "1070130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1070130.protein.info.v11.5.txt",
		        "node_list_path": "1070130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1070130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasCampestrisVesicatoriaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris vesicatoria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCampestrisVesicatoriaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316273.clusters.proteins.v11.5.txt",
		        "sequence_path": "316273.protein.sequences.v11.5.fa",
		        "enrichment_path": "316273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316273.protein.info.v11.5.txt",
		        "node_list_path": "316273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag227Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:227 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag227Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263010.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263010.protein.info.v11.5.txt",
		        "node_list_path": "1263010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidianusHospitalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidianus hospitalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidianusHospitalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "933801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "933801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "933801.clusters.proteins.v11.5.txt",
		        "sequence_path": "933801.protein.sequences.v11.5.fa",
		        "enrichment_path": "933801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933801.protein.info.v11.5.txt",
		        "node_list_path": "933801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "933801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaPseudoobscuraPseudoobscuraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila pseudoobscura pseudoobscura Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaPseudoobscuraPseudoobscuraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46245.clusters.proteins.v11.5.txt",
		        "sequence_path": "46245.protein.sequences.v11.5.fa",
		        "enrichment_path": "46245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46245.protein.info.v11.5.txt",
		        "node_list_path": "46245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRbg134613(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_13_46_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg134613", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802479.protein.info.v11.5.txt",
		        "node_list_path": "1802479.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobacteralesBacteriumGwb25626Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium GWB2_56_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteralesBacteriumGwb25626Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797913.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797913.protein.info.v11.5.txt",
		        "node_list_path": "1797913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SediminibacillusAlbusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacillus albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacillusAlbusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "407036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "407036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "407036.clusters.proteins.v11.5.txt",
		        "sequence_path": "407036.protein.sequences.v11.5.fa",
		        "enrichment_path": "407036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "407036.protein.info.v11.5.txt",
		        "node_list_path": "407036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "407036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRbg165211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_52_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg165211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798374.protein.info.v11.5.txt",
		        "node_list_path": "1798374.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full399Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full399Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802040.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802040.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802040.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802040.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802040.protein.info.v11.5.txt",
		        "node_list_path": "1802040.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802040.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioFischeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio fischeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioFischeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "312309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "312309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "312309.clusters.proteins.v11.5.txt",
		        "sequence_path": "312309.protein.sequences.v11.5.fa",
		        "enrichment_path": "312309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "312309.protein.info.v11.5.txt",
		        "node_list_path": "312309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "312309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpC01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpC01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945856.protein.info.v11.5.txt",
		        "node_list_path": "1945856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KitasatosporaMediocidica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora mediocidica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaMediocidica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449347.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449347.protein.info.v11.5.txt",
		        "node_list_path": "1449347.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1024431(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_44_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024431", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805310.protein.info.v11.5.txt",
		        "node_list_path": "1805310.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaTucsonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella tucsonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaTucsonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40335.protein.sequences.v11.5.fa",
		        "enrichment_path": "40335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40335.protein.info.v11.5.txt",
		        "node_list_path": "40335.protein.complete.v11.5.txt"
		    }
		]
    )()

def CetobacteriumSomeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cetobacterium somerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CetobacteriumSomeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1319815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1319815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1319815.clusters.proteins.v11.5.txt",
		        "sequence_path": "1319815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1319815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1319815.protein.info.v11.5.txt",
		        "node_list_path": "1319815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1319815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasSp7392Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. 73-92 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSp7392Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895740.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895740.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895740.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895740.protein.info.v11.5.txt",
		        "node_list_path": "1895740.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895740.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusThorarchaeotaArchaeonSmtz145(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thorarchaeota archaeon SMTZ1-45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThorarchaeotaArchaeonSmtz145", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1706444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1706444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1706444.protein.info.v11.5.txt",
		        "node_list_path": "1706444.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1848.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848.protein.info.v11.5.txt",
		        "node_list_path": "1848.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSpBf4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. BF4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSpBf4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1473546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1473546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1473546.protein.info.v11.5.txt",
		        "node_list_path": "1473546.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpBay1663(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BAY1663 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpBay1663", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1439940.protein.sequences.v11.5.fa",
		        "enrichment_path": "1439940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1439940.protein.info.v11.5.txt",
		        "node_list_path": "1439940.protein.complete.v11.5.txt"
		    }
		]
    )()

def LamprocystisPurpureaDsm4197Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lamprocystis purpurea DSM 4197 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LamprocystisPurpureaDsm4197Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765909.clusters.proteins.v11.5.txt",
		        "sequence_path": "765909.protein.sequences.v11.5.fa",
		        "enrichment_path": "765909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765909.protein.info.v11.5.txt",
		        "node_list_path": "765909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpPrM31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. PR-M31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpPrM31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1471202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1471202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1471202.clusters.proteins.v11.5.txt",
		        "sequence_path": "1471202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471202.protein.info.v11.5.txt",
		        "node_list_path": "1471202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1471202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesFragilisNctc9343(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis NCTC 9343 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFragilisNctc9343", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272559.protein.sequences.v11.5.fa",
		        "enrichment_path": "272559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272559.protein.info.v11.5.txt",
		        "node_list_path": "272559.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMassilionigeriensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus massilionigeriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMassilionigeriensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805475.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805475.protein.info.v11.5.txt",
		        "node_list_path": "1805475.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLindowbacteriaBacteriumRifcsplowo212Full6227(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lindowbacteria bacterium RIFCSPLOWO2_12_FULL_62_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLindowbacteriaBacteriumRifcsplowo212Full6227", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817870.protein.info.v11.5.txt",
		        "node_list_path": "1817870.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpAe2015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE2015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpAe2015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280663.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280663.protein.info.v11.5.txt",
		        "node_list_path": "1280663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfovibrioThiophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio thiophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfovibrioThiophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123376.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123376.protein.info.v11.5.txt",
		        "node_list_path": "1123376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusIhuae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ihuae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusIhuae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232431.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232431.protein.info.v11.5.txt",
		        "node_list_path": "1232431.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAsiaticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium asiaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAsiaticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265310.protein.info.v11.5.txt",
		        "node_list_path": "1265310.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesDentalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces dentalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesDentalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120941.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120941.protein.info.v11.5.txt",
		        "node_list_path": "1120941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DiploscapterPachysCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Diploscapter pachys Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiploscapterPachysCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2018661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2018661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2018661.clusters.proteins.v11.5.txt",
		        "sequence_path": "2018661.protein.sequences.v11.5.fa",
		        "enrichment_path": "2018661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2018661.protein.info.v11.5.txt",
		        "node_list_path": "2018661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2018661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusBeijingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus beijingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusBeijingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1126833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1126833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1126833.protein.info.v11.5.txt",
		        "node_list_path": "1126833.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseochromogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseochromogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseochromogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68214.protein.sequences.v11.5.fa",
		        "enrichment_path": "68214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68214.protein.info.v11.5.txt",
		        "node_list_path": "68214.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseatelesSpYr242(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseateles sp. YR242 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseatelesSpYr242", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855305.protein.info.v11.5.txt",
		        "node_list_path": "1855305.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumAcidiphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium acidiphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumAcidiphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122612.protein.info.v11.5.txt",
		        "node_list_path": "1122612.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumAe2021(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium AE2021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumAe2021", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392491.protein.info.v11.5.txt",
		        "node_list_path": "1392491.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlautiaWexleraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia wexlerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaWexleraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121115.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121115.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121115.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121115.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121115.protein.info.v11.5.txt",
		        "node_list_path": "1121115.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121115.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioDesulfuricansDsm642(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans DSM642 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioDesulfuricansDsm642", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121445.protein.info.v11.5.txt",
		        "node_list_path": "1121445.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurovumSpFs083(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum sp. FS08-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurovumSpFs083", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1539065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1539065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1539065.protein.info.v11.5.txt",
		        "node_list_path": "1539065.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpCcge510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. CCGE510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpCcge510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1132836.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1132836.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1132836.clusters.proteins.v11.5.txt",
		        "sequence_path": "1132836.protein.sequences.v11.5.fa",
		        "enrichment_path": "1132836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1132836.protein.info.v11.5.txt",
		        "node_list_path": "1132836.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1132836.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomicrostromaGlucosiphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomicrostroma glucosiphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomicrostromaGlucosiphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1684307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1684307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1684307.protein.info.v11.5.txt",
		        "node_list_path": "1684307.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinifilumFragileJcm15579(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinifilum fragile JCM 15579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinifilumFragileJcm15579", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236979.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236979.protein.info.v11.5.txt",
		        "node_list_path": "1236979.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillibacterSpKle1728(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. KLE1728 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSpKle1728", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1226322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1226322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1226322.protein.info.v11.5.txt",
		        "node_list_path": "1226322.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpStm4661(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. STM4661 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpStm4661", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1297570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297570.protein.info.v11.5.txt",
		        "node_list_path": "1297570.protein.complete.v11.5.txt"
		    }
		]
    )()

def GillisiaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gillisia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GillisiaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1167637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1167637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1167637.protein.info.v11.5.txt",
		        "node_list_path": "1167637.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronorubrumSulfidifaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronorubrum sulfidifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronorubrumSulfidifaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230460.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230460.protein.info.v11.5.txt",
		        "node_list_path": "1230460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudophaeobacterLeonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudophaeobacter leonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudophaeobacterLeonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144477.protein.info.v11.5.txt",
		        "node_list_path": "1144477.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpRoot241Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root241 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpRoot241Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736501.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736501.protein.info.v11.5.txt",
		        "node_list_path": "1736501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AfifellaMarinaDsm2698Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Afifella marina DSM 2698 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfifellaMarinaDsm2698Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120955.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120955.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120955.protein.info.v11.5.txt",
		        "node_list_path": "1120955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterAsymbioticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter asymbioticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterAsymbioticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "576611.clusters.info.v11.5.txt",
		        "cluster_tree_path": "576611.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "576611.clusters.proteins.v11.5.txt",
		        "sequence_path": "576611.protein.sequences.v11.5.fa",
		        "enrichment_path": "576611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "576611.protein.info.v11.5.txt",
		        "node_list_path": "576611.cluster.nodes.v11.5.txt",
		        "edge_list_path": "576611.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSolincolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium solincola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSolincolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "510955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "510955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "510955.clusters.proteins.v11.5.txt",
		        "sequence_path": "510955.protein.sequences.v11.5.fa",
		        "enrichment_path": "510955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "510955.protein.info.v11.5.txt",
		        "node_list_path": "510955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "510955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1291743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291743.protein.info.v11.5.txt",
		        "node_list_path": "1291743.protein.complete.v11.5.txt"
		    }
		]
    )()

def SiccibacterColletisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Siccibacter colletis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SiccibacterColletisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1505757.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1505757.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1505757.clusters.proteins.v11.5.txt",
		        "sequence_path": "1505757.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505757.protein.info.v11.5.txt",
		        "node_list_path": "1505757.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1505757.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalipigerMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salipiger marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalipigerMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "555512.protein.sequences.v11.5.fa",
		        "enrichment_path": "555512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555512.protein.info.v11.5.txt",
		        "node_list_path": "555512.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusChromogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus chromogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusChromogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220551.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220551.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220551.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220551.protein.info.v11.5.txt",
		        "node_list_path": "1220551.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220551.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerinicoccusProfundi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serinicoccus profundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerinicoccusProfundi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1043205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1043205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1043205.protein.info.v11.5.txt",
		        "node_list_path": "1043205.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaballeroniaPtereochthonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia ptereochthonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaPtereochthonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777144.protein.info.v11.5.txt",
		        "node_list_path": "1777144.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumGa0077540(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077540 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077540", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752202.protein.info.v11.5.txt",
		        "node_list_path": "1752202.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPseudoalcaligenesCect5344Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes CECT5344 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPseudoalcaligenesCect5344Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1182590.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1182590.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1182590.clusters.proteins.v11.5.txt",
		        "sequence_path": "1182590.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182590.protein.info.v11.5.txt",
		        "node_list_path": "1182590.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1182590.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpApr13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. APR13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpApr13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1356852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1356852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1356852.protein.info.v11.5.txt",
		        "node_list_path": "1356852.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumOceanicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium oceanicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumOceanicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1670800.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1670800.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1670800.clusters.proteins.v11.5.txt",
		        "sequence_path": "1670800.protein.sequences.v11.5.fa",
		        "enrichment_path": "1670800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1670800.protein.info.v11.5.txt",
		        "node_list_path": "1670800.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1670800.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho201Full4012Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_40_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full4012Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801737.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801737.protein.info.v11.5.txt",
		        "node_list_path": "1801737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeobacterInhibens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter inhibens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterInhibens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391619.protein.sequences.v11.5.fa",
		        "enrichment_path": "391619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391619.protein.info.v11.5.txt",
		        "node_list_path": "391619.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodovibrioSalinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodovibrio salinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovibrioSalinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089552.protein.info.v11.5.txt",
		        "node_list_path": "1089552.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSoil763Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil763 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSoil763Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736402.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736402.protein.info.v11.5.txt",
		        "node_list_path": "1736402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusVillosusKin24T80Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus villosus KIN24-T80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusVillosusKin24T80Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1069083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1069083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1069083.clusters.proteins.v11.5.txt",
		        "sequence_path": "1069083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069083.protein.info.v11.5.txt",
		        "node_list_path": "1069083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1069083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGlaucescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces glaucescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGlaucescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907.protein.info.v11.5.txt",
		        "node_list_path": "1907.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteimonasSpFcs9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas sp. FCS-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteimonasSpFcs9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1547516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1547516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1547516.clusters.proteins.v11.5.txt",
		        "sequence_path": "1547516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1547516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1547516.protein.info.v11.5.txt",
		        "node_list_path": "1547516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1547516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiK12SubstrW3110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli K12 substr. W3110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiK12SubstrW3110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316407.clusters.proteins.v11.5.txt",
		        "sequence_path": "316407.protein.sequences.v11.5.fa",
		        "enrichment_path": "316407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316407.protein.info.v11.5.txt",
		        "node_list_path": "316407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DiaphorinaCitriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Diaphorina citri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiaphorinaCitriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "121845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "121845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "121845.clusters.proteins.v11.5.txt",
		        "sequence_path": "121845.protein.sequences.v11.5.fa",
		        "enrichment_path": "121845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121845.protein.info.v11.5.txt",
		        "node_list_path": "121845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "121845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PonticoccusMarisrubriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ponticoccus marisrubri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PonticoccusMarisrubriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1685382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1685382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1685382.clusters.proteins.v11.5.txt",
		        "sequence_path": "1685382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685382.protein.info.v11.5.txt",
		        "node_list_path": "1685382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1685382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SodalisPierantonius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sodalis pierantonius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SodalisPierantonius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2342.protein.sequences.v11.5.fa",
		        "enrichment_path": "2342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2342.protein.info.v11.5.txt",
		        "node_list_path": "2342.protein.complete.v11.5.txt"
		    }
		]
    )()

def EntomoplasmaMelaleucaeAtcc49191(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Entomoplasma melaleucae ATCC 49191 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EntomoplasmaMelaleucaeAtcc49191", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408435.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408435.protein.info.v11.5.txt",
		        "node_list_path": "1408435.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumPalustre(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium palustre graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumPalustre", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121288.protein.info.v11.5.txt",
		        "node_list_path": "1121288.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusChagannorensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus chagannorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusChagannorensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121087.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121087.protein.info.v11.5.txt",
		        "node_list_path": "1121087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OligellaUreolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oligella ureolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OligellaUreolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122619.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122619.protein.info.v11.5.txt",
		        "node_list_path": "1122619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumGw2011Gwc13712Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWC1_37_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwc13712Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618483.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618483.protein.info.v11.5.txt",
		        "node_list_path": "1618483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillatoriaAcuminata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoria acuminata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillatoriaAcuminata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56110.protein.sequences.v11.5.fa",
		        "enrichment_path": "56110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56110.protein.info.v11.5.txt",
		        "node_list_path": "56110.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsplowo202Full4018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_02_FULL_40_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo202Full4018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798632.protein.info.v11.5.txt",
		        "node_list_path": "1798632.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpCc9902(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9902 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpCc9902", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316279.protein.sequences.v11.5.fa",
		        "enrichment_path": "316279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316279.protein.info.v11.5.txt",
		        "node_list_path": "316279.protein.complete.v11.5.txt"
		    }
		]
    )()

def IlumatobacterCoccineus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ilumatobacter coccineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IlumatobacterCoccineus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1313172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313172.protein.info.v11.5.txt",
		        "node_list_path": "1313172.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudosphingobacteriumDomesticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudosphingobacterium domesticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudosphingobacteriumDomesticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "407022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "407022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "407022.clusters.proteins.v11.5.txt",
		        "sequence_path": "407022.protein.sequences.v11.5.fa",
		        "enrichment_path": "407022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "407022.protein.info.v11.5.txt",
		        "node_list_path": "407022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "407022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerolineaeBacteriumUtcfx2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium UTCFX2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaeBacteriumUtcfx2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1961101.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1961101.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1961101.clusters.proteins.v11.5.txt",
		        "sequence_path": "1961101.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961101.protein.info.v11.5.txt",
		        "node_list_path": "1961101.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1961101.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumMinutumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium minutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumMinutumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381.protein.info.v11.5.txt",
		        "node_list_path": "1381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag786(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:786 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag786", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262893.protein.info.v11.5.txt",
		        "node_list_path": "1262893.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporolactobacillusInulinusCasd(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus inulinus CASD graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolactobacillusInulinusCasd", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1069536.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069536.protein.info.v11.5.txt",
		        "node_list_path": "1069536.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaSpYr573Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga sp. YR573 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaSpYr573Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881040.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881040.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881040.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881040.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881040.protein.info.v11.5.txt",
		        "node_list_path": "1881040.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881040.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusMucosaeLm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mucosae LM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMucosaeLm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1130798.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1130798.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1130798.clusters.proteins.v11.5.txt",
		        "sequence_path": "1130798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1130798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1130798.protein.info.v11.5.txt",
		        "node_list_path": "1130798.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1130798.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterKookiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter kookii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterKookiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1226327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1226327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1226327.clusters.proteins.v11.5.txt",
		        "sequence_path": "1226327.protein.sequences.v11.5.fa",
		        "enrichment_path": "1226327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1226327.protein.info.v11.5.txt",
		        "node_list_path": "1226327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1226327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnabaenaSpPcc7108(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anabaena sp. PCC7108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabaenaSpPcc7108", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "163908.protein.sequences.v11.5.fa",
		        "enrichment_path": "163908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "163908.protein.info.v11.5.txt",
		        "node_list_path": "163908.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaGallinacea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia gallinacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaGallinacea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1143323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1143323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1143323.protein.info.v11.5.txt",
		        "node_list_path": "1143323.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpEhn03Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. EhN03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpEhn03Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849358.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849358.protein.info.v11.5.txt",
		        "node_list_path": "1849358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConexibacterWoeseiIso977n(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Conexibacter woesei Iso977N graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConexibacterWoeseiIso977n", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1283299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283299.protein.info.v11.5.txt",
		        "node_list_path": "1283299.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesSpHgb5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. HGB5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpHgb5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "908612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "908612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "908612.clusters.proteins.v11.5.txt",
		        "sequence_path": "908612.protein.sequences.v11.5.fa",
		        "enrichment_path": "908612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908612.protein.info.v11.5.txt",
		        "node_list_path": "908612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "908612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpKo116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. KO116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpKo116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1504981.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1504981.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1504981.clusters.proteins.v11.5.txt",
		        "sequence_path": "1504981.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504981.protein.info.v11.5.txt",
		        "node_list_path": "1504981.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1504981.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaSpR4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. R4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpR4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "928210.clusters.info.v11.5.txt",
		        "cluster_tree_path": "928210.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "928210.clusters.proteins.v11.5.txt",
		        "sequence_path": "928210.protein.sequences.v11.5.fa",
		        "enrichment_path": "928210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "928210.protein.info.v11.5.txt",
		        "node_list_path": "928210.cluster.nodes.v11.5.txt",
		        "edge_list_path": "928210.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BerkelbacteriaBacteriumGw2011Gwa2359(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011_GWA2_35_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BerkelbacteriaBacteriumGw2011Gwa2359", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618333.protein.info.v11.5.txt",
		        "node_list_path": "1618333.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetivibrioCellulolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetivibrio cellulolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetivibrioCellulolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "509191.protein.sequences.v11.5.fa",
		        "enrichment_path": "509191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "509191.protein.info.v11.5.txt",
		        "node_list_path": "509191.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27986(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27986 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27986", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1743146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743146.protein.info.v11.5.txt",
		        "node_list_path": "1743146.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsaccharosporaIrregularisDsm2635Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asaccharospora irregularis DSM 2635 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsaccharosporaIrregularisDsm2635Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121321.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121321.protein.info.v11.5.txt",
		        "node_list_path": "1121321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EmmonsiaCrescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Emmonsia crescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmmonsiaCrescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "73230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "73230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "73230.clusters.proteins.v11.5.txt",
		        "sequence_path": "73230.protein.sequences.v11.5.fa",
		        "enrichment_path": "73230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "73230.protein.info.v11.5.txt",
		        "node_list_path": "73230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "73230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium637Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 63-7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium637Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895813.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895813.protein.info.v11.5.txt",
		        "node_list_path": "1895813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfitobacteriumMetallireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium metallireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitobacteriumMetallireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "871968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "871968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "871968.clusters.proteins.v11.5.txt",
		        "sequence_path": "871968.protein.sequences.v11.5.fa",
		        "enrichment_path": "871968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871968.protein.info.v11.5.txt",
		        "node_list_path": "871968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "871968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSuwonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter suwonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSuwonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "332999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "332999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "332999.clusters.proteins.v11.5.txt",
		        "sequence_path": "332999.protein.sequences.v11.5.fa",
		        "enrichment_path": "332999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332999.protein.info.v11.5.txt",
		        "node_list_path": "332999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "332999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LawsonellaClevelandensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lawsonella clevelandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LawsonellaClevelandensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1528099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1528099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1528099.protein.info.v11.5.txt",
		        "node_list_path": "1528099.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpTne862Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. TNe-862 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpTne862Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "416944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "416944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "416944.clusters.proteins.v11.5.txt",
		        "sequence_path": "416944.protein.sequences.v11.5.fa",
		        "enrichment_path": "416944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416944.protein.info.v11.5.txt",
		        "node_list_path": "416944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "416944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusNidulansFgscA4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus nidulans FGSC A4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusNidulansFgscA4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "227321.protein.sequences.v11.5.fa",
		        "enrichment_path": "227321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227321.protein.info.v11.5.txt",
		        "node_list_path": "227321.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpErmr104Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. ERMR1:04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpErmr104Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1705393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1705393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1705393.clusters.proteins.v11.5.txt",
		        "sequence_path": "1705393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705393.protein.info.v11.5.txt",
		        "node_list_path": "1705393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1705393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClavicepsPurpurea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Claviceps purpurea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavicepsPurpurea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5111.protein.sequences.v11.5.fa",
		        "enrichment_path": "5111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5111.protein.info.v11.5.txt",
		        "node_list_path": "5111.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesOdontolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces odontolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesOdontolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411466.protein.sequences.v11.5.fa",
		        "enrichment_path": "411466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411466.protein.info.v11.5.txt",
		        "node_list_path": "411466.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaSpBmg51109(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia sp. BMG51109 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSpBmg51109", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1056816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1056816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1056816.protein.info.v11.5.txt",
		        "node_list_path": "1056816.protein.complete.v11.5.txt"
		    }
		]
    )()

def MangrovimonasSpSt2l15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. ST2L15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MangrovimonasSpSt2l15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1645916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1645916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1645916.clusters.proteins.v11.5.txt",
		        "sequence_path": "1645916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1645916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1645916.protein.info.v11.5.txt",
		        "node_list_path": "1645916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1645916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KosakoniaRadicincitans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kosakonia radicincitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KosakoniaRadicincitans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "283686.protein.sequences.v11.5.fa",
		        "enrichment_path": "283686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283686.protein.info.v11.5.txt",
		        "node_list_path": "283686.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "260554.clusters.info.v11.5.txt",
		        "cluster_tree_path": "260554.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "260554.clusters.proteins.v11.5.txt",
		        "sequence_path": "260554.protein.sequences.v11.5.fa",
		        "enrichment_path": "260554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "260554.protein.info.v11.5.txt",
		        "node_list_path": "260554.cluster.nodes.v11.5.txt",
		        "edge_list_path": "260554.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusCristatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus cristatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusCristatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "889201.protein.sequences.v11.5.fa",
		        "enrichment_path": "889201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "889201.protein.info.v11.5.txt",
		        "node_list_path": "889201.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAureocirculatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aureocirculatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAureocirculatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67275.clusters.proteins.v11.5.txt",
		        "sequence_path": "67275.protein.sequences.v11.5.fa",
		        "enrichment_path": "67275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67275.protein.info.v11.5.txt",
		        "node_list_path": "67275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UreaplasmaDiversumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ureaplasma diversum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UreaplasmaDiversumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1188241.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1188241.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1188241.clusters.proteins.v11.5.txt",
		        "sequence_path": "1188241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188241.protein.info.v11.5.txt",
		        "node_list_path": "1188241.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1188241.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumTyrobutyricum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tyrobutyricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTyrobutyricum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121342.protein.info.v11.5.txt",
		        "node_list_path": "1121342.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensQ287Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Q287 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensQ287Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1038922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1038922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1038922.clusters.proteins.v11.5.txt",
		        "sequence_path": "1038922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038922.protein.info.v11.5.txt",
		        "node_list_path": "1038922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1038922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CamelusDromedariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Camelus dromedarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CamelusDromedariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9838.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9838.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9838.clusters.proteins.v11.5.txt",
		        "sequence_path": "9838.protein.sequences.v11.5.fa",
		        "enrichment_path": "9838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9838.protein.info.v11.5.txt",
		        "node_list_path": "9838.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9838.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophomonasWolfeiSubspMethylbutyraticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei subsp. methylbutyratica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophomonasWolfeiSubspMethylbutyraticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "378794.clusters.info.v11.5.txt",
		        "cluster_tree_path": "378794.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "378794.clusters.proteins.v11.5.txt",
		        "sequence_path": "378794.protein.sequences.v11.5.fa",
		        "enrichment_path": "378794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "378794.protein.info.v11.5.txt",
		        "node_list_path": "378794.cluster.nodes.v11.5.txt",
		        "edge_list_path": "378794.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinarchaeumSpHarchtbsk1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinarchaeum sp. HarchtBsk1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinarchaeumSpHarchtbsk1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1333523.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1333523.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1333523.clusters.proteins.v11.5.txt",
		        "sequence_path": "1333523.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333523.protein.info.v11.5.txt",
		        "node_list_path": "1333523.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1333523.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5126(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5126", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463857.protein.info.v11.5.txt",
		        "node_list_path": "1463857.protein.complete.v11.5.txt"
		    }
		]
    )()

def RattusNorvegicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rattus norvegicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RattusNorvegicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10116.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10116.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10116.clusters.proteins.v11.5.txt",
		        "sequence_path": "10116.protein.sequences.v11.5.fa",
		        "enrichment_path": "10116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10116.protein.info.v11.5.txt",
		        "node_list_path": "10116.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10116.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParasitellaParasitica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parasitella parasitica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParasitellaParasitica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35722.protein.sequences.v11.5.fa",
		        "enrichment_path": "35722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35722.protein.info.v11.5.txt",
		        "node_list_path": "35722.protein.complete.v11.5.txt"
		    }
		]
    )()

def RosenbergiellaNectareaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rosenbergiella nectarea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RosenbergiellaNectareaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "988801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "988801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "988801.clusters.proteins.v11.5.txt",
		        "sequence_path": "988801.protein.sequences.v11.5.fa",
		        "enrichment_path": "988801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "988801.protein.info.v11.5.txt",
		        "node_list_path": "988801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "988801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho202Full4118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_41_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full4118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801754.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801754.protein.info.v11.5.txt",
		        "node_list_path": "1801754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaCinaraStrobi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara strobi) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaCinaraStrobi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1921549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921549.protein.info.v11.5.txt",
		        "node_list_path": "1921549.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumGwa2509(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium GWA2_50_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumGwa2509", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798474.protein.info.v11.5.txt",
		        "node_list_path": "1798474.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaParapsilosisCdc317(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida parapsilosis CDC317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaParapsilosisCdc317", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "578454.protein.sequences.v11.5.fa",
		        "enrichment_path": "578454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578454.protein.info.v11.5.txt",
		        "node_list_path": "578454.protein.complete.v11.5.txt"
		    }
		]
    )()

def RugamonasRubra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rugamonas rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RugamonasRubra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "758825.protein.sequences.v11.5.fa",
		        "enrichment_path": "758825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758825.protein.info.v11.5.txt",
		        "node_list_path": "758825.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumRaac4Od11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium RAAC4_OD1_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumRaac4Od11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1394712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394712.protein.info.v11.5.txt",
		        "node_list_path": "1394712.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalotheceSpPcc7418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halothece sp. PCC7418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalotheceSpPcc7418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "65093.protein.sequences.v11.5.fa",
		        "enrichment_path": "65093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65093.protein.info.v11.5.txt",
		        "node_list_path": "65093.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrotetrasporaNiveoalba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microtetraspora niveoalba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrotetrasporaNiveoalba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46175.protein.sequences.v11.5.fa",
		        "enrichment_path": "46175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46175.protein.info.v11.5.txt",
		        "node_list_path": "46175.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumEtliCfn42Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli CFN42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumEtliCfn42Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "347834.clusters.info.v11.5.txt",
		        "cluster_tree_path": "347834.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "347834.clusters.proteins.v11.5.txt",
		        "sequence_path": "347834.protein.sequences.v11.5.fa",
		        "enrichment_path": "347834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "347834.protein.info.v11.5.txt",
		        "node_list_path": "347834.cluster.nodes.v11.5.txt",
		        "edge_list_path": "347834.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumHydrogeniformansDsm21757(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium hydrogeniformans DSM 21757 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumHydrogeniformansDsm21757", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121319.protein.info.v11.5.txt",
		        "node_list_path": "1121319.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastomycesParvusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces parvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomycesParvusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2060905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2060905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2060905.clusters.proteins.v11.5.txt",
		        "sequence_path": "2060905.protein.sequences.v11.5.fa",
		        "enrichment_path": "2060905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2060905.protein.info.v11.5.txt",
		        "node_list_path": "2060905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2060905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CobetiaSpUcd24c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cobetia sp. UCD-24C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CobetiaSpUcd24c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1716176.protein.sequences.v11.5.fa",
		        "enrichment_path": "1716176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1716176.protein.info.v11.5.txt",
		        "node_list_path": "1716176.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCoatesbacteriaBacteriumRbg136614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Coatesbacteria bacterium RBG_13_66_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCoatesbacteriaBacteriumRbg136614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817816.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817816.protein.info.v11.5.txt",
		        "node_list_path": "1817816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumKluyveriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium kluyveri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumKluyveriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "431943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "431943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "431943.clusters.proteins.v11.5.txt",
		        "sequence_path": "431943.protein.sequences.v11.5.fa",
		        "enrichment_path": "431943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431943.protein.info.v11.5.txt",
		        "node_list_path": "431943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "431943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumInfirmumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium infirmum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumInfirmumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883109.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883109.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883109.clusters.proteins.v11.5.txt",
		        "sequence_path": "883109.protein.sequences.v11.5.fa",
		        "enrichment_path": "883109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883109.protein.info.v11.5.txt",
		        "node_list_path": "883109.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883109.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusUberis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus uberis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusUberis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "218495.protein.sequences.v11.5.fa",
		        "enrichment_path": "218495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218495.protein.info.v11.5.txt",
		        "node_list_path": "218495.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeadbetterellaByssophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leadbetterella byssophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeadbetterellaByssophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649349.protein.sequences.v11.5.fa",
		        "enrichment_path": "649349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649349.protein.info.v11.5.txt",
		        "node_list_path": "649349.protein.complete.v11.5.txt"
		    }
		]
    )()

def JannaschiaRubra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaRubra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "282197.protein.sequences.v11.5.fa",
		        "enrichment_path": "282197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "282197.protein.info.v11.5.txt",
		        "node_list_path": "282197.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumSoil82Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium SOIL82 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumSoil82Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1655312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1655312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1655312.clusters.proteins.v11.5.txt",
		        "sequence_path": "1655312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655312.protein.info.v11.5.txt",
		        "node_list_path": "1655312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1655312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProsthecochlorisSpCib2401(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prosthecochloris sp. CIB 2401 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProsthecochlorisSpCib2401", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1868325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1868325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1868325.protein.info.v11.5.txt",
		        "node_list_path": "1868325.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasUenonisDsm23387Jcm13868(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis DSM 23387 JCM 13868 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasUenonisDsm23387Jcm13868", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122976.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122976.protein.info.v11.5.txt",
		        "node_list_path": "1122976.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumArcisJcm13916Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum arcis JCM 13916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumArcisJcm13916Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230455.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230455.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230455.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230455.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230455.protein.info.v11.5.txt",
		        "node_list_path": "1230455.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230455.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCb01580(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB01580 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCb01580", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703933.protein.info.v11.5.txt",
		        "node_list_path": "1703933.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85201350091Sch5140682(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852013-50091_SCH5140682 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85201350091Sch5140682", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834109.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834109.protein.info.v11.5.txt",
		        "node_list_path": "1834109.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumOlb11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumOlb11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617422.protein.info.v11.5.txt",
		        "node_list_path": "1617422.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumDigitatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium digitatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumDigitatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36651.protein.sequences.v11.5.fa",
		        "enrichment_path": "36651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36651.protein.info.v11.5.txt",
		        "node_list_path": "36651.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusKefiranofaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kefiranofaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKefiranofaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033837.protein.info.v11.5.txt",
		        "node_list_path": "1033837.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumSpMes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. MES graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumSpMes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1565314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1565314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1565314.protein.info.v11.5.txt",
		        "node_list_path": "1565314.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaCaldariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema caldaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaCaldariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "744872.clusters.info.v11.5.txt",
		        "cluster_tree_path": "744872.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "744872.clusters.proteins.v11.5.txt",
		        "sequence_path": "744872.protein.sequences.v11.5.fa",
		        "enrichment_path": "744872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "744872.protein.info.v11.5.txt",
		        "node_list_path": "744872.cluster.nodes.v11.5.txt",
		        "edge_list_path": "744872.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolirubrumPuertoriconensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solirubrum puertoriconensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolirubrumPuertoriconensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1751427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1751427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1751427.clusters.proteins.v11.5.txt",
		        "sequence_path": "1751427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1751427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1751427.protein.info.v11.5.txt",
		        "node_list_path": "1751427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1751427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DialisterInvisus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dialister invisus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterInvisus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "592028.protein.sequences.v11.5.fa",
		        "enrichment_path": "592028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592028.protein.info.v11.5.txt",
		        "node_list_path": "592028.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpCmf222(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Cmf 22.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpCmf222", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926478.protein.info.v11.5.txt",
		        "node_list_path": "1926478.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumRifcsplowo201Full3811(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPLOWO2_01_FULL_38_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsplowo201Full3811", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802556.protein.info.v11.5.txt",
		        "node_list_path": "1802556.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumKht7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KHT7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumKht7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855373.protein.info.v11.5.txt",
		        "node_list_path": "1855373.protein.complete.v11.5.txt"
		    }
		]
    )()

def TolypocladiumParadoxumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tolypocladium paradoxum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolypocladiumParadoxumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "94208.clusters.info.v11.5.txt",
		        "cluster_tree_path": "94208.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "94208.clusters.proteins.v11.5.txt",
		        "sequence_path": "94208.protein.sequences.v11.5.fa",
		        "enrichment_path": "94208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94208.protein.info.v11.5.txt",
		        "node_list_path": "94208.cluster.nodes.v11.5.txt",
		        "edge_list_path": "94208.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlobisporangiumUltimumDaomBr144Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Globisporangium ultimum DAOM BR144 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlobisporangiumUltimumDaomBr144Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "431595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "431595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "431595.clusters.proteins.v11.5.txt",
		        "sequence_path": "431595.protein.sequences.v11.5.fa",
		        "enrichment_path": "431595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431595.protein.info.v11.5.txt",
		        "node_list_path": "431595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "431595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraSpB5022Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira sp. B5-022 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraSpB5022Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1242992.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1242992.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1242992.clusters.proteins.v11.5.txt",
		        "sequence_path": "1242992.protein.sequences.v11.5.fa",
		        "enrichment_path": "1242992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1242992.protein.info.v11.5.txt",
		        "node_list_path": "1242992.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1242992.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynchytriumEndobioticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synchytrium endobioticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynchytriumEndobioticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "286115.protein.sequences.v11.5.fa",
		        "enrichment_path": "286115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "286115.protein.info.v11.5.txt",
		        "node_list_path": "286115.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemellaSpOralTaxon928Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella sp. oral taxon 928 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaSpOralTaxon928Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1785995.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1785995.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1785995.clusters.proteins.v11.5.txt",
		        "sequence_path": "1785995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1785995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1785995.protein.info.v11.5.txt",
		        "node_list_path": "1785995.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1785995.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho202Full3718Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_37_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full3718Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798603.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798603.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798603.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798603.protein.info.v11.5.txt",
		        "node_list_path": "1798603.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798603.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaSpAap35(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. AAP35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpAap35", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523417.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523417.protein.info.v11.5.txt",
		        "node_list_path": "1523417.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumHerbicidovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium herbicidovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumHerbicidovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219045.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219045.protein.info.v11.5.txt",
		        "node_list_path": "1219045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquaspirillumSerpens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquaspirillum serpens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquaspirillumSerpens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121004.protein.info.v11.5.txt",
		        "node_list_path": "1121004.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwf13410(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWF1_34_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwf13410", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618715.protein.info.v11.5.txt",
		        "node_list_path": "1618715.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesnuesiellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desnuesiella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesnuesiellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1650662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1650662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1650662.clusters.proteins.v11.5.txt",
		        "sequence_path": "1650662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1650662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1650662.protein.info.v11.5.txt",
		        "node_list_path": "1650662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1650662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium659(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 65-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium659", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895816.protein.info.v11.5.txt",
		        "node_list_path": "1895816.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasAustralicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas australica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasAustralicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "589873.clusters.info.v11.5.txt",
		        "cluster_tree_path": "589873.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "589873.clusters.proteins.v11.5.txt",
		        "sequence_path": "589873.protein.sequences.v11.5.fa",
		        "enrichment_path": "589873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "589873.protein.info.v11.5.txt",
		        "node_list_path": "589873.cluster.nodes.v11.5.txt",
		        "edge_list_path": "589873.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacteriaBacteriumGut307Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacteria bacterium GUT307 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacteriaBacteriumGut307Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1704281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1704281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1704281.clusters.proteins.v11.5.txt",
		        "sequence_path": "1704281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1704281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1704281.protein.info.v11.5.txt",
		        "node_list_path": "1704281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1704281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSiamensisKctc13613Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus siamensis KCTC 13613 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSiamensisKctc13613Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1177185.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1177185.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1177185.clusters.proteins.v11.5.txt",
		        "sequence_path": "1177185.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177185.protein.info.v11.5.txt",
		        "node_list_path": "1177185.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1177185.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DehalococcoidesMccartyi195(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi 195 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalococcoidesMccartyi195", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243164.protein.sequences.v11.5.fa",
		        "enrichment_path": "243164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243164.protein.info.v11.5.txt",
		        "node_list_path": "243164.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusXylosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus xylosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusXylosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288.protein.info.v11.5.txt",
		        "node_list_path": "1288.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylocystisSpSc2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylocystis sp. SC2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocystisSpSc2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "187303.protein.sequences.v11.5.fa",
		        "enrichment_path": "187303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "187303.protein.info.v11.5.txt",
		        "node_list_path": "187303.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminobacterSpRm87(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminobacter sp. RM87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminobacterSpRm87", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1200567.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200567.protein.info.v11.5.txt",
		        "node_list_path": "1200567.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumArsenophilumNbrc109478(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum arsenophilum NBRC 109478 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumArsenophilumNbrc109478", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349789.protein.info.v11.5.txt",
		        "node_list_path": "1349789.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumScgcAaa278O22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA278-O22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumScgcAaa278O22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "932044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "932044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "932044.clusters.proteins.v11.5.txt",
		        "sequence_path": "932044.protein.sequences.v11.5.fa",
		        "enrichment_path": "932044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932044.protein.info.v11.5.txt",
		        "node_list_path": "932044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "932044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesMerus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles merus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesMerus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "30066.protein.sequences.v11.5.fa",
		        "enrichment_path": "30066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30066.protein.info.v11.5.txt",
		        "node_list_path": "30066.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellvibrioSpPsbb023(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio sp. PSBB023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioSpPsbb023", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945512.protein.info.v11.5.txt",
		        "node_list_path": "1945512.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaViswanathii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida viswanathii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaViswanathii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5486.protein.sequences.v11.5.fa",
		        "enrichment_path": "5486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5486.protein.info.v11.5.txt",
		        "node_list_path": "5486.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHaemocanisStrIllinois(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma haemocanis str. Illinois graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHaemocanisStrIllinois", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111676.protein.info.v11.5.txt",
		        "node_list_path": "1111676.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaceaeBacteriumRedseaS32B1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxellaceae bacterium REDSEA-S32_B1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaceaeBacteriumRedseaS32B1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811612.protein.info.v11.5.txt",
		        "node_list_path": "1811612.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChristensenellaSpAf7305cm02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Christensenella sp. AF73-05CM02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChristensenellaSpAf7305cm02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1851429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1851429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1851429.clusters.proteins.v11.5.txt",
		        "sequence_path": "1851429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1851429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1851429.protein.info.v11.5.txt",
		        "node_list_path": "1851429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1851429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaSpAt9bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. At9b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpAt9bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "592316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "592316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "592316.clusters.proteins.v11.5.txt",
		        "sequence_path": "592316.protein.sequences.v11.5.fa",
		        "enrichment_path": "592316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592316.protein.info.v11.5.txt",
		        "node_list_path": "592316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "592316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpQxt31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. QXT-31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpQxt31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1357916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1357916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1357916.clusters.proteins.v11.5.txt",
		        "sequence_path": "1357916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357916.protein.info.v11.5.txt",
		        "node_list_path": "1357916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1357916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAntriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus antri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAntriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525309.clusters.proteins.v11.5.txt",
		        "sequence_path": "525309.protein.sequences.v11.5.fa",
		        "enrichment_path": "525309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525309.protein.info.v11.5.txt",
		        "node_list_path": "525309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusGaemokensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus gaemokensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGaemokensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "574375.protein.sequences.v11.5.fa",
		        "enrichment_path": "574375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574375.protein.info.v11.5.txt",
		        "node_list_path": "574375.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag762Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:762 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag762Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262837.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262837.protein.info.v11.5.txt",
		        "node_list_path": "1262837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PucciniaCoronataVarAvenaeFSpAvenaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Puccinia coronata var. avenae f. sp. avenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PucciniaCoronataVarAvenaeFSpAvenaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "200324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "200324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "200324.clusters.proteins.v11.5.txt",
		        "sequence_path": "200324.protein.sequences.v11.5.fa",
		        "enrichment_path": "200324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200324.protein.info.v11.5.txt",
		        "node_list_path": "200324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "200324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusViniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus vini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusViniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1133569.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1133569.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1133569.clusters.proteins.v11.5.txt",
		        "sequence_path": "1133569.protein.sequences.v11.5.fa",
		        "enrichment_path": "1133569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1133569.protein.info.v11.5.txt",
		        "node_list_path": "1133569.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1133569.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpCiat894(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. CIAT894 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpCiat894", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2020312.protein.sequences.v11.5.fa",
		        "enrichment_path": "2020312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2020312.protein.info.v11.5.txt",
		        "node_list_path": "2020312.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpEm1308(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. EM1308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpEm1308", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1492737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1492737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1492737.protein.info.v11.5.txt",
		        "node_list_path": "1492737.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpGw2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. GW2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpGw2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211114.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211114.protein.info.v11.5.txt",
		        "node_list_path": "1211114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacillusChungwhensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacillus chungwhensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacillusChungwhensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385513.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385513.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385513.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385513.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385513.protein.info.v11.5.txt",
		        "node_list_path": "1385513.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385513.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MegasphaeraSpNm10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. NM10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraSpNm10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1273103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1273103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1273103.protein.info.v11.5.txt",
		        "node_list_path": "1273103.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumDg741(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_74_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumDg741", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703765.protein.info.v11.5.txt",
		        "node_list_path": "1703765.protein.complete.v11.5.txt"
		    }
		]
    )()

def MadurellaMycetomatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Madurella mycetomatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MadurellaMycetomatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "100816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "100816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "100816.clusters.proteins.v11.5.txt",
		        "sequence_path": "100816.protein.sequences.v11.5.fa",
		        "enrichment_path": "100816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "100816.protein.info.v11.5.txt",
		        "node_list_path": "100816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "100816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiocapsaRoseopersicina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiocapsa roseopersicina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiocapsaRoseopersicina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1058.protein.info.v11.5.txt",
		        "node_list_path": "1058.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumXinjiangense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium xinjiangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumXinjiangense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "178356.protein.sequences.v11.5.fa",
		        "enrichment_path": "178356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178356.protein.info.v11.5.txt",
		        "node_list_path": "178356.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasKnackmussiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas knackmussii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasKnackmussiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1301098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1301098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1301098.clusters.proteins.v11.5.txt",
		        "sequence_path": "1301098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1301098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1301098.protein.info.v11.5.txt",
		        "node_list_path": "1301098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1301098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterParvusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter parvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterParvusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "134533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "134533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "134533.clusters.proteins.v11.5.txt",
		        "sequence_path": "134533.protein.sequences.v11.5.fa",
		        "enrichment_path": "134533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134533.protein.info.v11.5.txt",
		        "node_list_path": "134533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "134533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusSphaericusOt4b31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sphaericus OT4b31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusSphaericusOt4b31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1285586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1285586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1285586.protein.info.v11.5.txt",
		        "node_list_path": "1285586.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmatimonadetesBacteriumOlb18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium OLB18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmatimonadetesBacteriumOlb18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617424.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617424.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617424.protein.info.v11.5.txt",
		        "node_list_path": "1617424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterArboriphilusAnor1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter arboriphilus ANOR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterArboriphilusAnor1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1401244.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401244.protein.info.v11.5.txt",
		        "node_list_path": "1401244.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaMelophagi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella melophagi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaMelophagi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094557.protein.info.v11.5.txt",
		        "node_list_path": "1094557.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaucisalibacillusSpEb02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paucisalibacillus sp. EB02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaucisalibacillusSpEb02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1347087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347087.protein.info.v11.5.txt",
		        "node_list_path": "1347087.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylocystisSpSb2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylocystis sp. SB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocystisSpSb2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743836.protein.sequences.v11.5.fa",
		        "enrichment_path": "743836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743836.protein.info.v11.5.txt",
		        "node_list_path": "743836.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeorhizobiumGalegaeBvOrientalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae bv. orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorhizobiumGalegaeBvOrientalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "323655.clusters.info.v11.5.txt",
		        "cluster_tree_path": "323655.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "323655.clusters.proteins.v11.5.txt",
		        "sequence_path": "323655.protein.sequences.v11.5.fa",
		        "enrichment_path": "323655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323655.protein.info.v11.5.txt",
		        "node_list_path": "323655.cluster.nodes.v11.5.txt",
		        "edge_list_path": "323655.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusAgalactiaeLmg14747(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae LMG14747 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAgalactiaeLmg14747", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1154860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1154860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1154860.protein.info.v11.5.txt",
		        "node_list_path": "1154860.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusHordeiDsm19519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hordei DSM 19519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHordeiDsm19519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423759.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423759.protein.info.v11.5.txt",
		        "node_list_path": "1423759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DietziaTimorensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dietzia timorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DietziaTimorensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "499555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "499555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "499555.clusters.proteins.v11.5.txt",
		        "sequence_path": "499555.protein.sequences.v11.5.fa",
		        "enrichment_path": "499555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "499555.protein.info.v11.5.txt",
		        "node_list_path": "499555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "499555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasBromiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas bromi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasBromiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56449.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56449.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56449.clusters.proteins.v11.5.txt",
		        "sequence_path": "56449.protein.sequences.v11.5.fa",
		        "enrichment_path": "56449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56449.protein.info.v11.5.txt",
		        "node_list_path": "56449.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56449.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AggregatibacterActinomycetemcomitansRhaa1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans RhAA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterActinomycetemcomitansRhaa1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089447.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089447.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089447.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089447.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089447.protein.info.v11.5.txt",
		        "node_list_path": "1089447.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089447.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3924(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_39_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3924", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798280.protein.info.v11.5.txt",
		        "node_list_path": "1798280.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumRifoxya2Full4620Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium RIFOXYA2_FULL_46_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumRifoxya2Full4620Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817727.protein.info.v11.5.txt",
		        "node_list_path": "1817727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobacteriovoraxAntillogorgiicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobacteriovorax antillogorgiicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobacteriovoraxAntillogorgiicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1513793.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1513793.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1513793.clusters.proteins.v11.5.txt",
		        "sequence_path": "1513793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1513793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1513793.protein.info.v11.5.txt",
		        "node_list_path": "1513793.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1513793.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapsicumAnnuum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capsicum annuum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsicumAnnuum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4072.protein.sequences.v11.5.fa",
		        "enrichment_path": "4072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4072.protein.info.v11.5.txt",
		        "node_list_path": "4072.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsplowo202Full4813bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_02_FULL_48_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo202Full4813bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802283.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802283.protein.info.v11.5.txt",
		        "node_list_path": "1802283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentzeaGuizhouensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentzea guizhouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentzeaGuizhouensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1586287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1586287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1586287.protein.info.v11.5.txt",
		        "node_list_path": "1586287.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZygosaccharomycesBailiiClib213(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zygosaccharomyces bailii CLIB 213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZygosaccharomycesBailiiClib213", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1333698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333698.protein.info.v11.5.txt",
		        "node_list_path": "1333698.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaJordanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella jordanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaJordanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "456.clusters.info.v11.5.txt",
		        "cluster_tree_path": "456.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "456.clusters.proteins.v11.5.txt",
		        "sequence_path": "456.protein.sequences.v11.5.fa",
		        "enrichment_path": "456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "456.protein.info.v11.5.txt",
		        "node_list_path": "456.cluster.nodes.v11.5.txt",
		        "edge_list_path": "456.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSharpeaeJcm1186Dsm20505(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sharpeae JCM 1186 DSM 20505 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSharpeaeJcm1186Dsm20505", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1291052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291052.protein.info.v11.5.txt",
		        "node_list_path": "1291052.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinomonasMesophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinomonas mesophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinomonasMesophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1531955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1531955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1531955.clusters.proteins.v11.5.txt",
		        "sequence_path": "1531955.protein.sequences.v11.5.fa",
		        "enrichment_path": "1531955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1531955.protein.info.v11.5.txt",
		        "node_list_path": "1531955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1531955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioFurnissiiNctc11218(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio furnissii NCTC 11218 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioFurnissiiNctc11218", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "903510.protein.sequences.v11.5.fa",
		        "enrichment_path": "903510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903510.protein.info.v11.5.txt",
		        "node_list_path": "903510.protein.complete.v11.5.txt"
		    }
		]
    )()

def MorganellaPsychrotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Morganella psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MorganellaPsychrotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "368603.protein.sequences.v11.5.fa",
		        "enrichment_path": "368603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "368603.protein.info.v11.5.txt",
		        "node_list_path": "368603.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrioBacteriovorusHd100Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus HD100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrioBacteriovorusHd100Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264462.clusters.proteins.v11.5.txt",
		        "sequence_path": "264462.protein.sequences.v11.5.fa",
		        "enrichment_path": "264462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264462.protein.info.v11.5.txt",
		        "node_list_path": "264462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf208Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf208 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf208Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735679.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735679.protein.info.v11.5.txt",
		        "node_list_path": "1735679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnoclostridiumSpYl32(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnoclostridium sp. YL32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoclostridiumSpYl32", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834196.protein.info.v11.5.txt",
		        "node_list_path": "1834196.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpF0426(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0426 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpF0426", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321786.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321786.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321786.protein.info.v11.5.txt",
		        "node_list_path": "1321786.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanospirillumBeijerinckiiDsm7166Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum beijerinckii DSM 7166 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanospirillumBeijerinckiiDsm7166Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122616.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122616.protein.info.v11.5.txt",
		        "node_list_path": "1122616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MusaBalbisiana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Musa balbisiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusaBalbisiana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52838.protein.sequences.v11.5.fa",
		        "enrichment_path": "52838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52838.protein.info.v11.5.txt",
		        "node_list_path": "52838.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasEuropaea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas europaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasEuropaea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "228410.protein.sequences.v11.5.fa",
		        "enrichment_path": "228410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228410.protein.info.v11.5.txt",
		        "node_list_path": "228410.protein.complete.v11.5.txt"
		    }
		]
    )()

def DechlorosomaSuillum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dechlorosoma suillum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DechlorosomaSuillum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "640081.protein.sequences.v11.5.fa",
		        "enrichment_path": "640081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640081.protein.info.v11.5.txt",
		        "node_list_path": "640081.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpCci3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. CcI3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpCci3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "106370.protein.sequences.v11.5.fa",
		        "enrichment_path": "106370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106370.protein.info.v11.5.txt",
		        "node_list_path": "106370.protein.complete.v11.5.txt"
		    }
		]
    )()

def SediminibacteriumGinsengisoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacteriumGinsengisoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "413434.protein.sequences.v11.5.fa",
		        "enrichment_path": "413434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "413434.protein.info.v11.5.txt",
		        "node_list_path": "413434.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAcrylicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio acrylicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAcrylicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121434.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121434.protein.info.v11.5.txt",
		        "node_list_path": "1121434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalocynthiibacterArcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halocynthiibacter arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalocynthiibacterArcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1579316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1579316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1579316.clusters.proteins.v11.5.txt",
		        "sequence_path": "1579316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579316.protein.info.v11.5.txt",
		        "node_list_path": "1579316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1579316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRifcsplowo202Full6128Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO2_02_FULL_61_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202Full6128Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797180.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797180.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797180.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797180.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797180.protein.info.v11.5.txt",
		        "node_list_path": "1797180.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797180.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasGraminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas graminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasGraminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "158627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "158627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "158627.clusters.proteins.v11.5.txt",
		        "sequence_path": "158627.protein.sequences.v11.5.fa",
		        "enrichment_path": "158627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158627.protein.info.v11.5.txt",
		        "node_list_path": "158627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "158627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlossinaFuscipesFuscipesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glossina fuscipes fuscipes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlossinaFuscipesFuscipesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "201502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "201502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "201502.clusters.proteins.v11.5.txt",
		        "sequence_path": "201502.protein.sequences.v11.5.fa",
		        "enrichment_path": "201502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "201502.protein.info.v11.5.txt",
		        "node_list_path": "201502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "201502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSwezeyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus swezeyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSwezeyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1925020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1925020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1925020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1925020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1925020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1925020.protein.info.v11.5.txt",
		        "node_list_path": "1925020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1925020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NesterenkoniaSpPf2b19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. PF2B19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesterenkoniaSpPf2b19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881858.protein.info.v11.5.txt",
		        "node_list_path": "1881858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpeibonae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces speibonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpeibonae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "195801.protein.sequences.v11.5.fa",
		        "enrichment_path": "195801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195801.protein.info.v11.5.txt",
		        "node_list_path": "195801.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaSuis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia suis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaSuis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1405296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1405296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1405296.protein.info.v11.5.txt",
		        "node_list_path": "1405296.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag251(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag251", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262886.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262886.protein.info.v11.5.txt",
		        "node_list_path": "1262886.protein.complete.v11.5.txt"
		    }
		]
    )()

def WigglesworthiaGlossinidiaEndosymbiontOfGlossinaBrevipalpisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia endosymbiont of Glossina brevipalpis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WigglesworthiaGlossinidiaEndosymbiontOfGlossinaBrevipalpisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36870.clusters.proteins.v11.5.txt",
		        "sequence_path": "36870.protein.sequences.v11.5.fa",
		        "enrichment_path": "36870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36870.protein.info.v11.5.txt",
		        "node_list_path": "36870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioOstreicida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ostreicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioOstreicida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "526588.protein.sequences.v11.5.fa",
		        "enrichment_path": "526588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526588.protein.info.v11.5.txt",
		        "node_list_path": "526588.protein.complete.v11.5.txt"
		    }
		]
    )()

def TieghemosteliumLacteum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tieghemostelium lacteum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TieghemosteliumLacteum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "361077.protein.sequences.v11.5.fa",
		        "enrichment_path": "361077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "361077.protein.info.v11.5.txt",
		        "node_list_path": "361077.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoclostridiumDifficileCd160(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoclostridium difficile CD160 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoclostridiumDifficileCd160", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1151292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151292.protein.info.v11.5.txt",
		        "node_list_path": "1151292.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlochmanniaFloridanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia floridanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlochmanniaFloridanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "203907.protein.sequences.v11.5.fa",
		        "enrichment_path": "203907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203907.protein.info.v11.5.txt",
		        "node_list_path": "203907.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumPhaseoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium phaseoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumPhaseoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "396.protein.sequences.v11.5.fa",
		        "enrichment_path": "396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396.protein.info.v11.5.txt",
		        "node_list_path": "396.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrisomaLimiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrisoma limi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrisomaLimiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1185876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1185876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1185876.clusters.proteins.v11.5.txt",
		        "sequence_path": "1185876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185876.protein.info.v11.5.txt",
		        "node_list_path": "1185876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1185876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "425104.protein.sequences.v11.5.fa",
		        "enrichment_path": "425104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425104.protein.info.v11.5.txt",
		        "node_list_path": "425104.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmazonaAestiva(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amazona aestiva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmazonaAestiva", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "12930.protein.sequences.v11.5.fa",
		        "enrichment_path": "12930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "12930.protein.info.v11.5.txt",
		        "node_list_path": "12930.protein.complete.v11.5.txt"
		    }
		]
    )()

def RaphidiopsisBrookii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Raphidiopsis brookii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RaphidiopsisBrookii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "533247.protein.sequences.v11.5.fa",
		        "enrichment_path": "533247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "533247.protein.info.v11.5.txt",
		        "node_list_path": "533247.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraKmetyiSerovarMalaysiaStrBejoIso9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira kmetyi serovar Malaysia str. Bejo-Iso9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraKmetyiSerovarMalaysiaStrBejoIso9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1049970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1049970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1049970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1049970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1049970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1049970.protein.info.v11.5.txt",
		        "node_list_path": "1049970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1049970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterUraniireducensRf4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter uraniireducens Rf4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterUraniireducensRf4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351605.protein.sequences.v11.5.fa",
		        "enrichment_path": "351605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351605.protein.info.v11.5.txt",
		        "node_list_path": "351605.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaSpF0422Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. F0422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaSpF0422Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "944564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "944564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "944564.clusters.proteins.v11.5.txt",
		        "sequence_path": "944564.protein.sequences.v11.5.fa",
		        "enrichment_path": "944564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944564.protein.info.v11.5.txt",
		        "node_list_path": "944564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "944564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpC448(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. C448 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpC448", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1177594.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177594.protein.info.v11.5.txt",
		        "node_list_path": "1177594.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesFragilisYch46(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis YCH46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFragilisYch46", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "295405.protein.sequences.v11.5.fa",
		        "enrichment_path": "295405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "295405.protein.info.v11.5.txt",
		        "node_list_path": "295405.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogulbenkianiaSpMai1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania sp. MAI-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogulbenkianiaSpMai1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "990370.protein.sequences.v11.5.fa",
		        "enrichment_path": "990370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990370.protein.info.v11.5.txt",
		        "node_list_path": "990370.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSpA16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. A16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpA16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736675.protein.info.v11.5.txt",
		        "node_list_path": "1736675.protein.complete.v11.5.txt"
		    }
		]
    )()

def RikenellaceaeBacteriumM3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium M3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RikenellaceaeBacteriumM3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1433126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1433126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1433126.clusters.proteins.v11.5.txt",
		        "sequence_path": "1433126.protein.sequences.v11.5.fa",
		        "enrichment_path": "1433126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1433126.protein.info.v11.5.txt",
		        "node_list_path": "1433126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1433126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteibacterYeojuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter yeojuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterYeojuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "345309.protein.sequences.v11.5.fa",
		        "enrichment_path": "345309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "345309.protein.info.v11.5.txt",
		        "node_list_path": "345309.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallibacteriumSalpingitidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallibacterium salpingitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallibacteriumSalpingitidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "505341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "505341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "505341.clusters.proteins.v11.5.txt",
		        "sequence_path": "505341.protein.sequences.v11.5.fa",
		        "enrichment_path": "505341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "505341.protein.info.v11.5.txt",
		        "node_list_path": "505341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "505341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HanseniasporaUvarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hanseniaspora uvarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HanseniasporaUvarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29833.clusters.proteins.v11.5.txt",
		        "sequence_path": "29833.protein.sequences.v11.5.fa",
		        "enrichment_path": "29833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29833.protein.info.v11.5.txt",
		        "node_list_path": "29833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalimicrobiumHalophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salimicrobium halophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalimicrobiumHalophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86666.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86666.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86666.clusters.proteins.v11.5.txt",
		        "sequence_path": "86666.protein.sequences.v11.5.fa",
		        "enrichment_path": "86666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86666.protein.info.v11.5.txt",
		        "node_list_path": "86666.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86666.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaCaviaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella caviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaCaviaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34060.clusters.proteins.v11.5.txt",
		        "sequence_path": "34060.protein.sequences.v11.5.fa",
		        "enrichment_path": "34060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34060.protein.info.v11.5.txt",
		        "node_list_path": "34060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TremaOrientaleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trema orientale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TremaOrientaleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "63057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "63057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "63057.clusters.proteins.v11.5.txt",
		        "sequence_path": "63057.protein.sequences.v11.5.fa",
		        "enrichment_path": "63057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63057.protein.info.v11.5.txt",
		        "node_list_path": "63057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "63057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TolypocladiumParadoxum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tolypocladium paradoxum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolypocladiumParadoxum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "94208.protein.sequences.v11.5.fa",
		        "enrichment_path": "94208.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94208.protein.info.v11.5.txt",
		        "node_list_path": "94208.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaSpAngRCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. ANG-R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaSpAngRCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577903.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577903.protein.info.v11.5.txt",
		        "node_list_path": "1577903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaJordanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella jordanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaJordanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "456.protein.sequences.v11.5.fa",
		        "enrichment_path": "456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "456.protein.info.v11.5.txt",
		        "node_list_path": "456.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumGwa15235Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWA1_52_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumGwa15235Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797383.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797383.protein.info.v11.5.txt",
		        "node_list_path": "1797383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KocuriaAtrinaeC38Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kocuria atrinae C3-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaAtrinaeC38Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1179225.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1179225.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1179225.clusters.proteins.v11.5.txt",
		        "sequence_path": "1179225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179225.protein.info.v11.5.txt",
		        "node_list_path": "1179225.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1179225.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JohnsonellaIgnava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Johnsonella ignava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JohnsonellaIgnava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679200.protein.sequences.v11.5.fa",
		        "enrichment_path": "679200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679200.protein.info.v11.5.txt",
		        "node_list_path": "679200.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0386(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0386 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0386", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762963.protein.sequences.v11.5.fa",
		        "enrichment_path": "762963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762963.protein.info.v11.5.txt",
		        "node_list_path": "762963.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcanobacteriumSpS3pf19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcanobacterium sp. S3PF19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcanobacteriumSpS3pf19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219585.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219585.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219585.protein.info.v11.5.txt",
		        "node_list_path": "1219585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudopelagicolaGijangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudopelagicola gijangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudopelagicolaGijangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1470563.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470563.protein.info.v11.5.txt",
		        "node_list_path": "1470563.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirosomaMontaniterraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma montaniterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaMontaniterraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1178516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1178516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1178516.clusters.proteins.v11.5.txt",
		        "sequence_path": "1178516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1178516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1178516.protein.info.v11.5.txt",
		        "node_list_path": "1178516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1178516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpTg39a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. TG39a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpTg39a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415755.protein.info.v11.5.txt",
		        "node_list_path": "1415755.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacteriumWieringaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacterium wieringae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacteriumWieringaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52694.clusters.proteins.v11.5.txt",
		        "sequence_path": "52694.protein.sequences.v11.5.fa",
		        "enrichment_path": "52694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52694.protein.info.v11.5.txt",
		        "node_list_path": "52694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaSubspArizonaeSerovar62Z4Z23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. arizonae serovar 62:z4,z23:- graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaSubspArizonaeSerovar62Z4Z23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "41514.protein.sequences.v11.5.fa",
		        "enrichment_path": "41514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41514.protein.info.v11.5.txt",
		        "node_list_path": "41514.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkiellaAquae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkiella aquae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkiellaAquae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "295108.protein.sequences.v11.5.fa",
		        "enrichment_path": "295108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "295108.protein.info.v11.5.txt",
		        "node_list_path": "295108.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwe24260Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWE2_42_60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwe24260Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619076.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619076.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619076.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619076.protein.info.v11.5.txt",
		        "node_list_path": "1619076.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619076.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeisingeraSpAngM1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leisingera sp. ANG-M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraSpAngM1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577895.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577895.protein.info.v11.5.txt",
		        "node_list_path": "1577895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesNiveusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces niveus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesNiveusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1352941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1352941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1352941.clusters.proteins.v11.5.txt",
		        "sequence_path": "1352941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1352941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1352941.protein.info.v11.5.txt",
		        "node_list_path": "1352941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1352941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophilusSpLeaf414Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. Leaf414 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusSpLeaf414Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736371.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736371.protein.info.v11.5.txt",
		        "node_list_path": "1736371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassospiraSpMccc1a01148(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A01148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraSpMccc1a01148", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "501834.protein.sequences.v11.5.fa",
		        "enrichment_path": "501834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "501834.protein.info.v11.5.txt",
		        "node_list_path": "501834.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcanobacteriumHaemolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcanobacterium haemolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcanobacteriumHaemolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644284.clusters.proteins.v11.5.txt",
		        "sequence_path": "644284.protein.sequences.v11.5.fa",
		        "enrichment_path": "644284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644284.protein.info.v11.5.txt",
		        "node_list_path": "644284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanohalophilusSp2GbenrichCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus sp. 2-GBenrich Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanohalophilusSp2GbenrichCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884871.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884871.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884871.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884871.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884871.protein.info.v11.5.txt",
		        "node_list_path": "1884871.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884871.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSoldanellicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium soldanellicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSoldanellicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "311333.protein.sequences.v11.5.fa",
		        "enrichment_path": "311333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311333.protein.info.v11.5.txt",
		        "node_list_path": "311333.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpAp49(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. AP49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpAp49", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144307.protein.info.v11.5.txt",
		        "node_list_path": "1144307.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndolissoclinumFaulkneriL2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Endolissoclinum faulkneri L2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndolissoclinumFaulkneriL2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193729.protein.info.v11.5.txt",
		        "node_list_path": "1193729.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpSk140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. SK140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpSk140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095726.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095726.protein.info.v11.5.txt",
		        "node_list_path": "1095726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumHiltneriN3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum hiltneri N3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumHiltneriN3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262470.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262470.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262470.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262470.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262470.protein.info.v11.5.txt",
		        "node_list_path": "1262470.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262470.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumIndoltheticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium indoltheticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumIndoltheticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "254.protein.sequences.v11.5.fa",
		        "enrichment_path": "254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "254.protein.info.v11.5.txt",
		        "node_list_path": "254.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumRbg164921(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_16_49_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumRbg164921", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802195.protein.info.v11.5.txt",
		        "node_list_path": "1802195.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasThermotoleransDsm14292(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas thermotolerans DSM 14292 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasThermotoleransDsm14292", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123021.protein.info.v11.5.txt",
		        "node_list_path": "1123021.protein.complete.v11.5.txt"
		    }
		]
    )()

def PontibacterIndicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterIndicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1317125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317125.protein.info.v11.5.txt",
		        "node_list_path": "1317125.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_54_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802390.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802390.protein.info.v11.5.txt",
		        "node_list_path": "1802390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusOralisAtcc49296Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis ATCC49296 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOralisAtcc49296Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888049.clusters.proteins.v11.5.txt",
		        "sequence_path": "888049.protein.sequences.v11.5.fa",
		        "enrichment_path": "888049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888049.protein.info.v11.5.txt",
		        "node_list_path": "888049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesMarseillensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces marseillensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesMarseillensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852376.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852376.protein.info.v11.5.txt",
		        "node_list_path": "1852376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsphigho202Full3913(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_02_FULL_39_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho202Full3913", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802505.protein.info.v11.5.txt",
		        "node_list_path": "1802505.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallionellalesBacteriumRifcsplowo202Full5747Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallionellales bacterium RIFCSPLOWO2_02_FULL_57_47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallionellalesBacteriumRifcsplowo202Full5747Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798254.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798254.protein.info.v11.5.txt",
		        "node_list_path": "1798254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifoxya2Full4315Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYA2_FULL_43_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxya2Full4315Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801648.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801648.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801648.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801648.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801648.protein.info.v11.5.txt",
		        "node_list_path": "1801648.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801648.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaucisalibacillusSpEb02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paucisalibacillus sp. EB02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaucisalibacillusSpEb02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1347087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1347087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1347087.clusters.proteins.v11.5.txt",
		        "sequence_path": "1347087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347087.protein.info.v11.5.txt",
		        "node_list_path": "1347087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1347087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermothielavioidesTerrestrisNrrl8126(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermothielavioides terrestris NRRL 8126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermothielavioidesTerrestrisNrrl8126", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "578455.protein.sequences.v11.5.fa",
		        "enrichment_path": "578455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578455.protein.info.v11.5.txt",
		        "node_list_path": "578455.protein.complete.v11.5.txt"
		    }
		]
    )()

def MobiluncusCurtisiiAtcc43063Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii ATCC43063 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobiluncusCurtisiiAtcc43063Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "548479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "548479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "548479.clusters.proteins.v11.5.txt",
		        "sequence_path": "548479.protein.sequences.v11.5.fa",
		        "enrichment_path": "548479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "548479.protein.info.v11.5.txt",
		        "node_list_path": "548479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "548479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LasiusNiger(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lasius niger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LasiusNiger", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67767.protein.sequences.v11.5.fa",
		        "enrichment_path": "67767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67767.protein.info.v11.5.txt",
		        "node_list_path": "67767.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriaceaeBacteriumP6a17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacteriaceae bacterium P6A17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriaceaeBacteriumP6a17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410634.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410634.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410634.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410634.protein.info.v11.5.txt",
		        "node_list_path": "1410634.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410634.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMinutissimum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium minutissimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMinutissimum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "38301.protein.sequences.v11.5.fa",
		        "enrichment_path": "38301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38301.protein.info.v11.5.txt",
		        "node_list_path": "38301.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaceaeBacteriumBrhC20aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium BRH_c20a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaceaeBacteriumBrhC20aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629719.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629719.protein.info.v11.5.txt",
		        "node_list_path": "1629719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaSpR43Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. R43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpR43Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "269536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "269536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "269536.clusters.proteins.v11.5.txt",
		        "sequence_path": "269536.protein.sequences.v11.5.fa",
		        "enrichment_path": "269536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269536.protein.info.v11.5.txt",
		        "node_list_path": "269536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "269536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaVagansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea vagans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaVagansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "712898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "712898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "712898.clusters.proteins.v11.5.txt",
		        "sequence_path": "712898.protein.sequences.v11.5.fa",
		        "enrichment_path": "712898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712898.protein.info.v11.5.txt",
		        "node_list_path": "712898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "712898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusDelbrueckii2038(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii 2038 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusDelbrueckii2038", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "353496.protein.sequences.v11.0.fa",
		        "enrichment_path": "353496.protein.enrichment.terms.v11.0.txt",
		        "info_path": "353496.protein.info.v11.0.txt",
		        "node_list_path": "353496.protein.complete.v11.0.txt"
		    }
		]
    )()

def SolemyaVelum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solemya velum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolemyaVelum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2340.protein.sequences.v11.5.fa",
		        "enrichment_path": "2340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2340.protein.info.v11.5.txt",
		        "node_list_path": "2340.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSp01251(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 0-1251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSp01251", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895858.protein.info.v11.5.txt",
		        "node_list_path": "1895858.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumHumiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumHumiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "640635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "640635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "640635.clusters.proteins.v11.5.txt",
		        "sequence_path": "640635.protein.sequences.v11.5.fa",
		        "enrichment_path": "640635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640635.protein.info.v11.5.txt",
		        "node_list_path": "640635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "640635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesWuyuanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces wuyuanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesWuyuanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196353.protein.info.v11.5.txt",
		        "node_list_path": "1196353.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulophagaBaltica18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga baltica 18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaBaltica18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348584.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348584.protein.info.v11.5.txt",
		        "node_list_path": "1348584.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeoalkalibacterSubterraneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geoalkalibacter subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeoalkalibacterSubterraneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "483547.protein.sequences.v11.5.fa",
		        "enrichment_path": "483547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483547.protein.info.v11.5.txt",
		        "node_list_path": "483547.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumJkg1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium JKG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumJkg1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1128421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1128421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1128421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1128421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128421.protein.info.v11.5.txt",
		        "node_list_path": "1128421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1128421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeophocaenaAsiaeorientalisAsiaeorientalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neophocaena asiaeorientalis asiaeorientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeophocaenaAsiaeorientalisAsiaeorientalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1706337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1706337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1706337.protein.info.v11.5.txt",
		        "node_list_path": "1706337.protein.complete.v11.5.txt"
		    }
		]
    )()

def RachicladosporiumAntarcticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rachicladosporium antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RachicladosporiumAntarcticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1507870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1507870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1507870.protein.info.v11.5.txt",
		        "node_list_path": "1507870.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodopirellulaSpSwk7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopirellula sp. SWK7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopirellulaSpSwk7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "595460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "595460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "595460.clusters.proteins.v11.5.txt",
		        "sequence_path": "595460.protein.sequences.v11.5.fa",
		        "enrichment_path": "595460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595460.protein.info.v11.5.txt",
		        "node_list_path": "595460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "595460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSpNbs1129(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora sp. NBS 11-29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSpNbs1129", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1960879.protein.sequences.v11.5.fa",
		        "enrichment_path": "1960879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1960879.protein.info.v11.5.txt",
		        "node_list_path": "1960879.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusKuroshimensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus kuroshimensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusKuroshimensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121938.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121938.protein.info.v11.5.txt",
		        "node_list_path": "1121938.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaAmphilectiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina amphilecti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaAmphilectiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1038014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1038014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1038014.clusters.proteins.v11.5.txt",
		        "sequence_path": "1038014.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038014.protein.info.v11.5.txt",
		        "node_list_path": "1038014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1038014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkalitaleaSaponilacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalitalea saponilacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalitaleaSaponilacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "889453.protein.sequences.v11.5.fa",
		        "enrichment_path": "889453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "889453.protein.info.v11.5.txt",
		        "node_list_path": "889453.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanocorpusculumLabreanumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocorpusculum labreanum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocorpusculumLabreanumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "410358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "410358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "410358.clusters.proteins.v11.5.txt",
		        "sequence_path": "410358.protein.sequences.v11.5.fa",
		        "enrichment_path": "410358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "410358.protein.info.v11.5.txt",
		        "node_list_path": "410358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "410358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusAlbus7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Ruminococcus albus 7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusAlbus7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "697329.protein.sequences.v11.0.fa",
		        "enrichment_path": "697329.protein.enrichment.terms.v11.0.txt",
		        "info_path": "697329.protein.info.v11.0.txt",
		        "node_list_path": "697329.protein.complete.v11.0.txt"
		    }
		]
    )()

def IzhakiellaAustraliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Izhakiella australiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IzhakiellaAustraliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926881.protein.info.v11.5.txt",
		        "node_list_path": "1926881.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho202Full4213Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_02_FULL_42_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho202Full4213Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798271.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798271.protein.info.v11.5.txt",
		        "node_list_path": "1798271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BauldiaLitoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bauldia litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BauldiaLitoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665467.clusters.proteins.v11.5.txt",
		        "sequence_path": "665467.protein.sequences.v11.5.fa",
		        "enrichment_path": "665467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665467.protein.info.v11.5.txt",
		        "node_list_path": "665467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrospiraInopinata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira inopinata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrospiraInopinata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1715989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715989.protein.info.v11.5.txt",
		        "node_list_path": "1715989.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlligatorSinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alligator sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlligatorSinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "38654.protein.sequences.v11.5.fa",
		        "enrichment_path": "38654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38654.protein.info.v11.5.txt",
		        "node_list_path": "38654.protein.complete.v11.5.txt"
		    }
		]
    )()

def StrongyloidesRattiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Strongyloides ratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrongyloidesRattiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34506.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34506.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34506.clusters.proteins.v11.5.txt",
		        "sequence_path": "34506.protein.sequences.v11.5.fa",
		        "enrichment_path": "34506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34506.protein.info.v11.5.txt",
		        "node_list_path": "34506.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34506.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSulfidiphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sulfidiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSulfidiphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "396588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "396588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "396588.clusters.proteins.v11.5.txt",
		        "sequence_path": "396588.protein.sequences.v11.5.fa",
		        "enrichment_path": "396588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396588.protein.info.v11.5.txt",
		        "node_list_path": "396588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "396588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PunicaGranatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Punica granatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PunicaGranatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "22663.protein.sequences.v11.5.fa",
		        "enrichment_path": "22663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "22663.protein.info.v11.5.txt",
		        "node_list_path": "22663.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusElongatusPcc7942Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus elongatus PCC7942 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusElongatusPcc7942Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1140.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1140.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1140.clusters.proteins.v11.5.txt",
		        "sequence_path": "1140.protein.sequences.v11.5.fa",
		        "enrichment_path": "1140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1140.protein.info.v11.5.txt",
		        "node_list_path": "1140.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1140.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanospirillalesBacteriumScgcAaa298N10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillales bacterium SCGC AAA298-N10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanospirillalesBacteriumScgcAaa298N10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "939745.clusters.info.v11.5.txt",
		        "cluster_tree_path": "939745.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "939745.clusters.proteins.v11.5.txt",
		        "sequence_path": "939745.protein.sequences.v11.5.fa",
		        "enrichment_path": "939745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939745.protein.info.v11.5.txt",
		        "node_list_path": "939745.cluster.nodes.v11.5.txt",
		        "edge_list_path": "939745.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OchotonaPrinceps(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ochotona princeps graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OchotonaPrinceps", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9978.protein.sequences.v11.5.fa",
		        "enrichment_path": "9978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9978.protein.info.v11.5.txt",
		        "node_list_path": "9978.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArabidopsisThalianaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arabidopsis thaliana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArabidopsisThalianaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3702.clusters.proteins.v11.5.txt",
		        "sequence_path": "3702.protein.sequences.v11.5.fa",
		        "enrichment_path": "3702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3702.protein.info.v11.5.txt",
		        "node_list_path": "3702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaceaeBacteriumL21thd2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium L21THD2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaceaeBacteriumL21thd2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304284.protein.info.v11.5.txt",
		        "node_list_path": "1304284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StereumHirsutum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stereum hirsutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StereumHirsutum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40492.protein.sequences.v11.5.fa",
		        "enrichment_path": "40492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40492.protein.info.v11.5.txt",
		        "node_list_path": "40492.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoselliniaNecatrixCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rosellinia necatrix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoselliniaNecatrixCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "77044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "77044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "77044.clusters.proteins.v11.5.txt",
		        "sequence_path": "77044.protein.sequences.v11.5.fa",
		        "enrichment_path": "77044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77044.protein.info.v11.5.txt",
		        "node_list_path": "77044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "77044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5436(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_54_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5436", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798482.protein.info.v11.5.txt",
		        "node_list_path": "1798482.protein.complete.v11.5.txt"
		    }
		]
    )()

def KangiellaSediminilitoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kangiella sediminilitoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KangiellaSediminilitoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144748.protein.info.v11.5.txt",
		        "node_list_path": "1144748.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifoxyd1Full4821(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFOXYD1_FULL_48_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifoxyd1Full4821", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798368.protein.info.v11.5.txt",
		        "node_list_path": "1798368.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRifoxyd1Full3984(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1_FULL_39_84 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1Full3984", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797401.protein.info.v11.5.txt",
		        "node_list_path": "1797401.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFjat26967Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FJAT-26967 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFjat26967Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729690.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729690.protein.info.v11.5.txt",
		        "node_list_path": "1729690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterDubiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter dubius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterDubiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "218673.clusters.info.v11.5.txt",
		        "cluster_tree_path": "218673.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "218673.clusters.proteins.v11.5.txt",
		        "sequence_path": "218673.protein.sequences.v11.5.fa",
		        "enrichment_path": "218673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218673.protein.info.v11.5.txt",
		        "node_list_path": "218673.cluster.nodes.v11.5.txt",
		        "edge_list_path": "218673.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JannaschiaSeosinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia seosinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaSeosinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313367.protein.sequences.v11.5.fa",
		        "enrichment_path": "313367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313367.protein.info.v11.5.txt",
		        "node_list_path": "313367.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpNfr04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. NFR04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpNfr04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566283.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566283.protein.info.v11.5.txt",
		        "node_list_path": "1566283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActibacteriumMucosumKctc23349Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actibacterium mucosum KCTC 23349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActibacteriumMucosumKctc23349Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1454373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1454373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1454373.clusters.proteins.v11.5.txt",
		        "sequence_path": "1454373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454373.protein.info.v11.5.txt",
		        "node_list_path": "1454373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1454373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterCloacaeJd6301(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae JD6301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterCloacaeJd6301", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1399774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399774.protein.info.v11.5.txt",
		        "node_list_path": "1399774.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "376.protein.sequences.v11.5.fa",
		        "enrichment_path": "376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376.protein.info.v11.5.txt",
		        "node_list_path": "376.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasCannabisPvPhaseoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas cannabis pv. phaseoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCannabisPvPhaseoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1885902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1885902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1885902.clusters.proteins.v11.5.txt",
		        "sequence_path": "1885902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1885902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1885902.protein.info.v11.5.txt",
		        "node_list_path": "1885902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1885902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenihalanaerobacterShriftii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenihalanaerobacter shriftii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenihalanaerobacterShriftii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "142842.protein.sequences.v11.5.fa",
		        "enrichment_path": "142842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "142842.protein.info.v11.5.txt",
		        "node_list_path": "142842.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharopolysporaSpinosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharopolyspora spinosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharopolysporaSpinosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "994479.protein.sequences.v11.5.fa",
		        "enrichment_path": "994479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "994479.protein.info.v11.5.txt",
		        "node_list_path": "994479.protein.complete.v11.5.txt"
		    }
		]
    )()

def CupriavidusOxalaticusNbrc13593Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus oxalaticus NBRC 13593 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusOxalaticusNbrc13593Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349762.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349762.protein.info.v11.5.txt",
		        "node_list_path": "1349762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoplasmaSeiffertiiAtcc49495Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesoplasma seiffertii ATCC 49495 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoplasmaSeiffertiiAtcc49495Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336238.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336238.protein.info.v11.5.txt",
		        "node_list_path": "1336238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full3939Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_39_39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full3939Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802758.protein.info.v11.5.txt",
		        "node_list_path": "1802758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RothiaMucilaginosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rothia mucilaginosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RothiaMucilaginosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "680646.protein.sequences.v11.5.fa",
		        "enrichment_path": "680646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "680646.protein.info.v11.5.txt",
		        "node_list_path": "680646.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucosporidiumCreatinivorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucosporidium creatinivorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucosporidiumCreatinivorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "106004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "106004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "106004.clusters.proteins.v11.5.txt",
		        "sequence_path": "106004.protein.sequences.v11.5.fa",
		        "enrichment_path": "106004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106004.protein.info.v11.5.txt",
		        "node_list_path": "106004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "106004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FelisCatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Felis catus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FelisCatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9685.protein.sequences.v11.5.fa",
		        "enrichment_path": "9685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9685.protein.info.v11.5.txt",
		        "node_list_path": "9685.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumLotiMaff303099(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti MAFF303099 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumLotiMaff303099", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266835.protein.sequences.v11.5.fa",
		        "enrichment_path": "266835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266835.protein.info.v11.5.txt",
		        "node_list_path": "266835.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesStercorirosorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides stercorirosoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesStercorirosorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236514.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236514.protein.info.v11.5.txt",
		        "node_list_path": "1236514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliihoefleaSp2ww(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aliihoeflea sp. 2WW graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliihoefleaSp2ww", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1381123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381123.protein.info.v11.5.txt",
		        "node_list_path": "1381123.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharopolysporaErythraea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharopolyspora erythraea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharopolysporaErythraea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "405948.protein.sequences.v11.5.fa",
		        "enrichment_path": "405948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405948.protein.info.v11.5.txt",
		        "node_list_path": "405948.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusChoshinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus choshinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusChoshinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "54911.protein.sequences.v11.5.fa",
		        "enrichment_path": "54911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54911.protein.info.v11.5.txt",
		        "node_list_path": "54911.protein.complete.v11.5.txt"
		    }
		]
    )()

def PontibacterIndicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterIndicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1317125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1317125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1317125.clusters.proteins.v11.5.txt",
		        "sequence_path": "1317125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317125.protein.info.v11.5.txt",
		        "node_list_path": "1317125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1317125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolobacteriumMooreiF0204Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solobacterium moorei F0204 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolobacteriumMooreiF0204Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "706433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "706433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "706433.clusters.proteins.v11.5.txt",
		        "sequence_path": "706433.protein.sequences.v11.5.fa",
		        "enrichment_path": "706433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706433.protein.info.v11.5.txt",
		        "node_list_path": "706433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "706433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterHeilmanniiAsb14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter heilmannii ASB1.4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterHeilmanniiAsb14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216962.protein.info.v11.5.txt",
		        "node_list_path": "1216962.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSuisYs72(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis YS72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSuisYs72", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1214217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214217.protein.info.v11.5.txt",
		        "node_list_path": "1214217.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaDrancourtii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella drancourtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaDrancourtii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658187.protein.sequences.v11.5.fa",
		        "enrichment_path": "658187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658187.protein.info.v11.5.txt",
		        "node_list_path": "658187.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacterBemidjiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter bemidjiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterBemidjiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "404380.protein.sequences.v11.5.fa",
		        "enrichment_path": "404380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "404380.protein.info.v11.5.txt",
		        "node_list_path": "404380.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusKrulwichiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus krulwichiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusKrulwichiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "199441.clusters.info.v11.5.txt",
		        "cluster_tree_path": "199441.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "199441.clusters.proteins.v11.5.txt",
		        "sequence_path": "199441.protein.sequences.v11.5.fa",
		        "enrichment_path": "199441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "199441.protein.info.v11.5.txt",
		        "node_list_path": "199441.cluster.nodes.v11.5.txt",
		        "edge_list_path": "199441.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusParahaemolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus parahaemolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusParahaemolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "735.clusters.proteins.v11.5.txt",
		        "sequence_path": "735.protein.sequences.v11.5.fa",
		        "enrichment_path": "735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "735.protein.info.v11.5.txt",
		        "node_list_path": "735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaCuniculiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella cuniculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaCuniculiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34061.clusters.proteins.v11.5.txt",
		        "sequence_path": "34061.protein.sequences.v11.5.fa",
		        "enrichment_path": "34061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34061.protein.info.v11.5.txt",
		        "node_list_path": "34061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSpZagget8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. Zagget8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpZagget8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930002.protein.info.v11.5.txt",
		        "node_list_path": "1930002.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusUreasiticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus ureasiticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusUreasiticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "903984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "903984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "903984.clusters.proteins.v11.5.txt",
		        "sequence_path": "903984.protein.sequences.v11.5.fa",
		        "enrichment_path": "903984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903984.protein.info.v11.5.txt",
		        "node_list_path": "903984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "903984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls474Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS474 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls474Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463909.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463909.protein.info.v11.5.txt",
		        "node_list_path": "1463909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSpechtbacteriaBacteriumRifcsplowo201Full4610Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_01_FULL_46_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo201Full4610Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802163.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802163.protein.info.v11.5.txt",
		        "node_list_path": "1802163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevinemaAndersonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevinema andersonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevinemaAndersonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34097.protein.sequences.v11.5.fa",
		        "enrichment_path": "34097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34097.protein.info.v11.5.txt",
		        "node_list_path": "34097.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaNewyorkensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina newyorkensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaNewyorkensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1027292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1027292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1027292.protein.info.v11.5.txt",
		        "node_list_path": "1027292.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpTf25Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. tf2-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpTf25Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761889.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761889.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761889.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761889.protein.info.v11.5.txt",
		        "node_list_path": "1761889.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761889.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAuratusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces auratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAuratusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1160718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1160718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1160718.clusters.proteins.v11.5.txt",
		        "sequence_path": "1160718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160718.protein.info.v11.5.txt",
		        "node_list_path": "1160718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1160718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DuodenibacillusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Duodenibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuodenibacillusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852381.protein.info.v11.5.txt",
		        "node_list_path": "1852381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronincolaFerrireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronincola ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronincolaFerrireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "393762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "393762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "393762.clusters.proteins.v11.5.txt",
		        "sequence_path": "393762.protein.sequences.v11.5.fa",
		        "enrichment_path": "393762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393762.protein.info.v11.5.txt",
		        "node_list_path": "393762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "393762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumVaginaeDsm15829(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium vaginae DSM15829 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumVaginaeDsm15829", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525256.protein.sequences.v11.5.fa",
		        "enrichment_path": "525256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525256.protein.info.v11.5.txt",
		        "node_list_path": "525256.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoplasmatalesArchaeonEPlasma(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon E-plasma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmatalesArchaeonEPlasma", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "667137.protein.sequences.v11.5.fa",
		        "enrichment_path": "667137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667137.protein.info.v11.5.txt",
		        "node_list_path": "667137.protein.complete.v11.5.txt"
		    }
		]
    )()

def SedimenticolaSelenatireducensDsm17993(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sedimenticola selenatireducens DSM 17993 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SedimenticolaSelenatireducensDsm17993", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111735.protein.info.v11.5.txt",
		        "node_list_path": "1111735.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaSpF0381(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0381 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaSpF0381", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1127692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127692.protein.info.v11.5.txt",
		        "node_list_path": "1127692.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPsychrophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPsychrophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211112.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211112.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211112.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211112.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211112.protein.info.v11.5.txt",
		        "node_list_path": "1211112.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211112.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TindalliaMagadiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tindallia magadiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TindalliaMagadiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69895.protein.sequences.v11.5.fa",
		        "enrichment_path": "69895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69895.protein.info.v11.5.txt",
		        "node_list_path": "69895.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpMit0604(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0604 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpMit0604", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1501268.protein.sequences.v11.5.fa",
		        "enrichment_path": "1501268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1501268.protein.info.v11.5.txt",
		        "node_list_path": "1501268.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaproniaCoronataCbs61796(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capronia coronata CBS 617.96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaproniaCoronataCbs61796", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1182541.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182541.protein.info.v11.5.txt",
		        "node_list_path": "1182541.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSulci(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sulci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSulci", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888727.protein.sequences.v11.5.fa",
		        "enrichment_path": "888727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888727.protein.info.v11.5.txt",
		        "node_list_path": "888727.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpNbimcp2c3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. NBIMCP2C3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpNbimcp2c3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1320556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1320556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1320556.clusters.proteins.v11.5.txt",
		        "sequence_path": "1320556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1320556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1320556.protein.info.v11.5.txt",
		        "node_list_path": "1320556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1320556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TannerellaSp6158faaCt1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tannerella sp. 6_1_58FAA_CT1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TannerellaSp6158faaCt1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665949.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665949.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665949.clusters.proteins.v11.5.txt",
		        "sequence_path": "665949.protein.sequences.v11.5.fa",
		        "enrichment_path": "665949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665949.protein.info.v11.5.txt",
		        "node_list_path": "665949.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665949.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudarcicellaHirudinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudarcicella hirudinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudarcicellaHirudinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1079859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1079859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1079859.clusters.proteins.v11.5.txt",
		        "sequence_path": "1079859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1079859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1079859.protein.info.v11.5.txt",
		        "node_list_path": "1079859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1079859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusRambellii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus rambellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusRambellii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "308745.protein.sequences.v11.5.fa",
		        "enrichment_path": "308745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "308745.protein.info.v11.5.txt",
		        "node_list_path": "308745.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumJenseniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium jensenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumJenseniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122997.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122997.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122997.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122997.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122997.protein.info.v11.5.txt",
		        "node_list_path": "1122997.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122997.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FischerellaSpPcc9431(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9431 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FischerellaSpPcc9431", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173023.protein.info.v11.5.txt",
		        "node_list_path": "1173023.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterGlobiformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter globiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterGlobiformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1077972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1077972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1077972.clusters.proteins.v11.5.txt",
		        "sequence_path": "1077972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077972.protein.info.v11.5.txt",
		        "node_list_path": "1077972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1077972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquaspirillumSpLm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquaspirillum sp. LM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquaspirillumSpLm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1938604.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938604.protein.info.v11.5.txt",
		        "node_list_path": "1938604.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumSpUch001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. UCH001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumSpUch001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1581011.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1581011.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1581011.clusters.proteins.v11.5.txt",
		        "sequence_path": "1581011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581011.protein.info.v11.5.txt",
		        "node_list_path": "1581011.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1581011.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpOv329(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. OV329 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpOv329", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882825.protein.info.v11.5.txt",
		        "node_list_path": "1882825.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanopyrusKandleriAv19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanopyrus kandleri AV19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanopyrusKandleriAv19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "190192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "190192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "190192.clusters.proteins.v11.5.txt",
		        "sequence_path": "190192.protein.sequences.v11.5.fa",
		        "enrichment_path": "190192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190192.protein.info.v11.5.txt",
		        "node_list_path": "190192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "190192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterGossypii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter gossypii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterGossypii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "551996.protein.sequences.v11.5.fa",
		        "enrichment_path": "551996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551996.protein.info.v11.5.txt",
		        "node_list_path": "551996.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfatirhabdiumButyrativoransDsm18734(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfatirhabdium butyrativorans DSM 18734 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfatirhabdiumButyrativoransDsm18734", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121394.protein.info.v11.5.txt",
		        "node_list_path": "1121394.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifoxyd2Full5815Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFOXYD2_FULL_58_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifoxyd2Full5815Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801943.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801943.protein.info.v11.5.txt",
		        "node_list_path": "1801943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizophagusIrregularisDaom197198w(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM 197198w graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizophagusIrregularisDaom197198w", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1432141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432141.protein.info.v11.5.txt",
		        "node_list_path": "1432141.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlexibacterLitoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flexibacter litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlexibacterLitoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "880071.clusters.info.v11.5.txt",
		        "cluster_tree_path": "880071.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "880071.clusters.proteins.v11.5.txt",
		        "sequence_path": "880071.protein.sequences.v11.5.fa",
		        "enrichment_path": "880071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880071.protein.info.v11.5.txt",
		        "node_list_path": "880071.cluster.nodes.v11.5.txt",
		        "edge_list_path": "880071.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TissierelliaBacteriumKa00581(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tissierellia bacterium KA00581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TissierelliaBacteriumKa00581", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1588751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588751.protein.info.v11.5.txt",
		        "node_list_path": "1588751.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwf236839(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWF2_36_839 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwf236839", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618723.protein.info.v11.5.txt",
		        "node_list_path": "1618723.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonadalesBacterium66474(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 66-474 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonadalesBacterium66474", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895868.protein.info.v11.5.txt",
		        "node_list_path": "1895868.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrugiaMalayiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brugia malayi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrugiaMalayiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6279.clusters.proteins.v11.5.txt",
		        "sequence_path": "6279.protein.sequences.v11.5.fa",
		        "enrichment_path": "6279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6279.protein.info.v11.5.txt",
		        "node_list_path": "6279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpP4b1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. P4B1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpP4b1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1119533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1119533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1119533.protein.info.v11.5.txt",
		        "node_list_path": "1119533.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusHopiensisKr140Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus hopiensis KR-140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusHopiensisKr140Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "695939.clusters.info.v11.5.txt",
		        "cluster_tree_path": "695939.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "695939.clusters.proteins.v11.5.txt",
		        "sequence_path": "695939.protein.sequences.v11.5.fa",
		        "enrichment_path": "695939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "695939.protein.info.v11.5.txt",
		        "node_list_path": "695939.cluster.nodes.v11.5.txt",
		        "edge_list_path": "695939.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterOkinawensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter okinawensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterOkinawensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236501.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236501.protein.info.v11.5.txt",
		        "node_list_path": "1236501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumVrystaatense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium vrystaatense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumVrystaatense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "307480.protein.sequences.v11.5.fa",
		        "enrichment_path": "307480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "307480.protein.info.v11.5.txt",
		        "node_list_path": "307480.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifoxyd12Full509Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12_FULL_50_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12Full509Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797902.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797902.protein.info.v11.5.txt",
		        "node_list_path": "1797902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4204Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4204 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4204Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977884.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977884.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977884.protein.info.v11.5.txt",
		        "node_list_path": "1977884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwc14615Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWC1_46_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwc14615Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618526.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618526.protein.info.v11.5.txt",
		        "node_list_path": "1618526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioNigripulchritudoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio nigripulchritudo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioNigripulchritudoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1238450.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1238450.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1238450.clusters.proteins.v11.5.txt",
		        "sequence_path": "1238450.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238450.protein.info.v11.5.txt",
		        "node_list_path": "1238450.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1238450.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgromycesAureusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agromyces aureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesAureusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "453304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "453304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "453304.clusters.proteins.v11.5.txt",
		        "sequence_path": "453304.protein.sequences.v11.5.fa",
		        "enrichment_path": "453304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "453304.protein.info.v11.5.txt",
		        "node_list_path": "453304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "453304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DermacoccusSpEllin185Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dermacoccus sp. Ellin185 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DermacoccusSpEllin185Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "188626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "188626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "188626.clusters.proteins.v11.5.txt",
		        "sequence_path": "188626.protein.sequences.v11.5.fa",
		        "enrichment_path": "188626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188626.protein.info.v11.5.txt",
		        "node_list_path": "188626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "188626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumHch1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium HCH-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumHch1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1748249.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1748249.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1748249.clusters.proteins.v11.5.txt",
		        "sequence_path": "1748249.protein.sequences.v11.5.fa",
		        "enrichment_path": "1748249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1748249.protein.info.v11.5.txt",
		        "node_list_path": "1748249.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1748249.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpRoot1304(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root1304 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpRoot1304", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736450.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736450.protein.info.v11.5.txt",
		        "node_list_path": "1736450.protein.complete.v11.5.txt"
		    }
		]
    )()

def NostocPunctiforme(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nostoc punctiforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocPunctiforme", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "63737.protein.sequences.v11.5.fa",
		        "enrichment_path": "63737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63737.protein.info.v11.5.txt",
		        "node_list_path": "63737.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellvibrioMixtus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio mixtus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioMixtus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1209072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1209072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1209072.protein.info.v11.5.txt",
		        "node_list_path": "1209072.protein.complete.v11.5.txt"
		    }
		]
    )()

def CupriavidusTaiwanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusTaiwanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "977880.clusters.info.v11.5.txt",
		        "cluster_tree_path": "977880.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "977880.clusters.proteins.v11.5.txt",
		        "sequence_path": "977880.protein.sequences.v11.5.fa",
		        "enrichment_path": "977880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "977880.protein.info.v11.5.txt",
		        "node_list_path": "977880.cluster.nodes.v11.5.txt",
		        "edge_list_path": "977880.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusUliginisN3975Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus uliginis N3/975 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusUliginisN3975Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1313296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1313296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1313296.clusters.proteins.v11.5.txt",
		        "sequence_path": "1313296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313296.protein.info.v11.5.txt",
		        "node_list_path": "1313296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1313296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaAnisa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella anisa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaAnisa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230343.protein.info.v11.5.txt",
		        "node_list_path": "1230343.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpStflb209(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. StFLB209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpStflb209", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1028989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028989.protein.info.v11.5.txt",
		        "node_list_path": "1028989.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterConcisus13826(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter concisus 13826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterConcisus13826", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "360104.protein.sequences.v11.5.fa",
		        "enrichment_path": "360104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360104.protein.info.v11.5.txt",
		        "node_list_path": "360104.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoruegeriaMarinistellaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoruegeria marinistellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoruegeriaMarinistellaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739787.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739787.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739787.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739787.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739787.protein.info.v11.5.txt",
		        "node_list_path": "1739787.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739787.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaDentalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella dentalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaDentalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "908937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "908937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "908937.clusters.proteins.v11.5.txt",
		        "sequence_path": "908937.protein.sequences.v11.5.fa",
		        "enrichment_path": "908937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908937.protein.info.v11.5.txt",
		        "node_list_path": "908937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "908937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyberlindneraJadiniiNrrlY1542Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyberlindnera jadinii NRRL Y-1542 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyberlindneraJadiniiNrrlY1542Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983966.clusters.proteins.v11.5.txt",
		        "sequence_path": "983966.protein.sequences.v11.5.fa",
		        "enrichment_path": "983966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983966.protein.info.v11.5.txt",
		        "node_list_path": "983966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumNigrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum nigrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumNigrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "696369.protein.sequences.v11.5.fa",
		        "enrichment_path": "696369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696369.protein.info.v11.5.txt",
		        "node_list_path": "696369.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaAlbaNbrc108234Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia alba NBRC 108234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAlbaNbrc108234Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210063.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210063.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210063.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210063.protein.info.v11.5.txt",
		        "node_list_path": "1210063.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210063.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusInfantarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusInfantarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1069533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069533.protein.info.v11.5.txt",
		        "node_list_path": "1069533.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpAb3007(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. AB3007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpAb3007", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392487.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392487.protein.info.v11.5.txt",
		        "node_list_path": "1392487.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusHaemolyticusM21639(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M21639 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusHaemolyticusM21639", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1028806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028806.protein.info.v11.5.txt",
		        "node_list_path": "1028806.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasUreaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas ureae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasUreaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44577.clusters.proteins.v11.5.txt",
		        "sequence_path": "44577.protein.sequences.v11.5.fa",
		        "enrichment_path": "44577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44577.protein.info.v11.5.txt",
		        "node_list_path": "44577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErinaceusEuropaeusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erinaceus europaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErinaceusEuropaeusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9365.clusters.proteins.v11.5.txt",
		        "sequence_path": "9365.protein.sequences.v11.5.fa",
		        "enrichment_path": "9365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9365.protein.info.v11.5.txt",
		        "node_list_path": "9365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesShahiiWal8301(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes shahii WAL 8301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesShahiiWal8301", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717959.protein.sequences.v11.5.fa",
		        "enrichment_path": "717959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717959.protein.info.v11.5.txt",
		        "node_list_path": "717959.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoccidioidesPosadasii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides posadasii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesPosadasii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "199306.protein.sequences.v11.5.fa",
		        "enrichment_path": "199306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "199306.protein.info.v11.5.txt",
		        "node_list_path": "199306.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAld1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALD1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAld1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158150.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158150.protein.info.v11.5.txt",
		        "node_list_path": "1158150.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpRc2dCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Rc2d Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpRc2dCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855321.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855321.protein.info.v11.5.txt",
		        "node_list_path": "1855321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4613Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_46_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4613Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802312.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802312.protein.info.v11.5.txt",
		        "node_list_path": "1802312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaMirobrigensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora mirobrigensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaMirobrigensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262898.protein.sequences.v11.5.fa",
		        "enrichment_path": "262898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262898.protein.info.v11.5.txt",
		        "node_list_path": "262898.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaSpScn7327(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. SCN 73-27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaSpScn7327", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660132.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660132.protein.info.v11.5.txt",
		        "node_list_path": "1660132.protein.complete.v11.5.txt"
		    }
		]
    )()

def MacacaNemestrinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Macaca nemestrina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacacaNemestrinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9545.clusters.proteins.v11.5.txt",
		        "sequence_path": "9545.protein.sequences.v11.5.fa",
		        "enrichment_path": "9545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9545.protein.info.v11.5.txt",
		        "node_list_path": "9545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XylariaHypoxylonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylaria hypoxylon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylariaHypoxylonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37992.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37992.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37992.clusters.proteins.v11.5.txt",
		        "sequence_path": "37992.protein.sequences.v11.5.fa",
		        "enrichment_path": "37992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37992.protein.info.v11.5.txt",
		        "node_list_path": "37992.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37992.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorogloeopsisFritschiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorogloeopsis fritschii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorogloeopsisFritschiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "211165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "211165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "211165.clusters.proteins.v11.5.txt",
		        "sequence_path": "211165.protein.sequences.v11.5.fa",
		        "enrichment_path": "211165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211165.protein.info.v11.5.txt",
		        "node_list_path": "211165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "211165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAlbusJ1074(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces albus J1074 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAlbusJ1074", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "457425.protein.sequences.v11.5.fa",
		        "enrichment_path": "457425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457425.protein.info.v11.5.txt",
		        "node_list_path": "457425.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIs3022(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-3022 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIs3022", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1772277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772277.protein.info.v11.5.txt",
		        "node_list_path": "1772277.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterMacacaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter macacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterMacacaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1357400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1357400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1357400.clusters.proteins.v11.5.txt",
		        "sequence_path": "1357400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357400.protein.info.v11.5.txt",
		        "node_list_path": "1357400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1357400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg165418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_54_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797843.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797843.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797843.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797843.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797843.protein.info.v11.5.txt",
		        "node_list_path": "1797843.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797843.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinococcusLuteusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinococcus luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinococcusLuteusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122204.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122204.protein.info.v11.5.txt",
		        "node_list_path": "1122204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaReesei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma reesei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaReesei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "51453.protein.sequences.v11.5.fa",
		        "enrichment_path": "51453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51453.protein.info.v11.5.txt",
		        "node_list_path": "51453.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacteriaceaeBacteriumB14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium B14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacteriaceaeBacteriumB14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1214065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214065.protein.info.v11.5.txt",
		        "node_list_path": "1214065.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinococcusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinococcus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinococcusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1371.clusters.proteins.v11.5.txt",
		        "sequence_path": "1371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1371.protein.info.v11.5.txt",
		        "node_list_path": "1371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaUbonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia ubonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaUbonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "101571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "101571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "101571.clusters.proteins.v11.5.txt",
		        "sequence_path": "101571.protein.sequences.v11.5.fa",
		        "enrichment_path": "101571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101571.protein.info.v11.5.txt",
		        "node_list_path": "101571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "101571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpLeaf58(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpLeaf58", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736226.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736226.protein.info.v11.5.txt",
		        "node_list_path": "1736226.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSaccharoperbutylacetonicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium saccharoperbutylacetonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSaccharoperbutylacetonicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "931276.protein.sequences.v11.5.fa",
		        "enrichment_path": "931276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "931276.protein.info.v11.5.txt",
		        "node_list_path": "931276.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusVersutus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus versutus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusVersutus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34007.protein.sequences.v11.5.fa",
		        "enrichment_path": "34007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34007.protein.info.v11.5.txt",
		        "node_list_path": "34007.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoplanusLimicolaDsm2279Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoplanus limicola DSM 2279 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoplanusLimicolaDsm2279Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "937775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "937775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "937775.clusters.proteins.v11.5.txt",
		        "sequence_path": "937775.protein.sequences.v11.5.fa",
		        "enrichment_path": "937775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937775.protein.info.v11.5.txt",
		        "node_list_path": "937775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "937775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaritaleaMyrionectaeDsm19524Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maritalea myrionectae DSM 19524 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaritaleaMyrionectaeDsm19524Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122213.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122213.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122213.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122213.protein.info.v11.5.txt",
		        "node_list_path": "1122213.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122213.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumFaecium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium faecium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumFaecium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "446465.protein.sequences.v11.5.fa",
		        "enrichment_path": "446465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446465.protein.info.v11.5.txt",
		        "node_list_path": "446465.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumScgcAaa024D14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA024-D14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumScgcAaa024D14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "932039.protein.sequences.v11.5.fa",
		        "enrichment_path": "932039.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932039.protein.info.v11.5.txt",
		        "node_list_path": "932039.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesOvatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides ovatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesOvatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411476.clusters.proteins.v11.5.txt",
		        "sequence_path": "411476.protein.sequences.v11.5.fa",
		        "enrichment_path": "411476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411476.protein.info.v11.5.txt",
		        "node_list_path": "411476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoniliophthoraRoreriMca2997(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moniliophthora roreri MCA 2997 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoniliophthoraRoreriMca2997", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1381753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381753.protein.info.v11.5.txt",
		        "node_list_path": "1381753.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmodiumKnowlesiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium knowlesi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumKnowlesiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5850.clusters.proteins.v11.5.txt",
		        "sequence_path": "5850.protein.sequences.v11.5.fa",
		        "enrichment_path": "5850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5850.protein.info.v11.5.txt",
		        "node_list_path": "5850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlloactinosynnemaIranicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alloactinosynnema iranicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloactinosynnemaIranicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1271860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1271860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1271860.clusters.proteins.v11.5.txt",
		        "sequence_path": "1271860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1271860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1271860.protein.info.v11.5.txt",
		        "node_list_path": "1271860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1271860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisRemanei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis remanei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisRemanei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "31234.protein.sequences.v11.5.fa",
		        "enrichment_path": "31234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31234.protein.info.v11.5.txt",
		        "node_list_path": "31234.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobellusRufus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobellus rufus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobellusRufus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1448860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448860.protein.info.v11.5.txt",
		        "node_list_path": "1448860.protein.complete.v11.5.txt"
		    }
		]
    )()

def TheobromaCacao(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Theobroma cacao graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheobromaCacao", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3641.protein.sequences.v11.5.fa",
		        "enrichment_path": "3641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3641.protein.info.v11.5.txt",
		        "node_list_path": "3641.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCohniiNbrc15565(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cohnii NBRC 15565 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCohniiNbrc15565", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314751.protein.info.v11.5.txt",
		        "node_list_path": "1314751.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24117(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_41_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24117", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619048.protein.info.v11.5.txt",
		        "node_list_path": "1619048.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseoaurantiacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseoaurantiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseoaurantiacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "996637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "996637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "996637.clusters.proteins.v11.5.txt",
		        "sequence_path": "996637.protein.sequences.v11.5.fa",
		        "enrichment_path": "996637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "996637.protein.info.v11.5.txt",
		        "node_list_path": "996637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "996637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RheinheimeraSpSa1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera sp. SA_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraSpSa1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1827365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1827365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1827365.clusters.proteins.v11.5.txt",
		        "sequence_path": "1827365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827365.protein.info.v11.5.txt",
		        "node_list_path": "1827365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1827365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumBergheiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium berghei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumBergheiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5821.clusters.proteins.v11.5.txt",
		        "sequence_path": "5821.protein.sequences.v11.5.fa",
		        "enrichment_path": "5821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5821.protein.info.v11.5.txt",
		        "node_list_path": "5821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpLeaf48(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpLeaf48", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736221.protein.info.v11.5.txt",
		        "node_list_path": "1736221.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesotogaPrima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesotoga prima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesotogaPrima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "660470.protein.sequences.v11.5.fa",
		        "enrichment_path": "660470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660470.protein.info.v11.5.txt",
		        "node_list_path": "660470.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNiyogibacteriaBacteriumRifcsplowo212Full4113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Niyogibacteria bacterium RIFCSPLOWO2_12_FULL_41_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNiyogibacteriaBacteriumRifcsplowo212Full4113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801726.protein.info.v11.5.txt",
		        "node_list_path": "1801726.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHydrothermarchaeotaArchaeonJdfr18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrothermarchaeota archaeon JdFR-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHydrothermarchaeotaArchaeonJdfr18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935129.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935129.protein.info.v11.5.txt",
		        "node_list_path": "1935129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg135021(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_50_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg135021", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797623.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797623.protein.info.v11.5.txt",
		        "node_list_path": "1797623.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCrk32Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCrk32Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1452535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1452535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1452535.clusters.proteins.v11.5.txt",
		        "sequence_path": "1452535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1452535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1452535.protein.info.v11.5.txt",
		        "node_list_path": "1452535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1452535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JeotgalicoccusMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalicoccus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalicoccusMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122128.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122128.protein.info.v11.5.txt",
		        "node_list_path": "1122128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumLf3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium LF3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumLf3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1504823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1504823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1504823.clusters.proteins.v11.5.txt",
		        "sequence_path": "1504823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504823.protein.info.v11.5.txt",
		        "node_list_path": "1504823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1504823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesVirginiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces virginiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesVirginiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961.protein.info.v11.5.txt",
		        "node_list_path": "1961.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpLappah108(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. LaPpAH108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpLappah108", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1155714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1155714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1155714.protein.info.v11.5.txt",
		        "node_list_path": "1155714.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo212Full4116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_12_FULL_41_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo212Full4116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797736.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797736.protein.info.v11.5.txt",
		        "node_list_path": "1797736.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpUrha0014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. URHA0014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpUrha0014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380372.protein.info.v11.5.txt",
		        "node_list_path": "1380372.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthobacterSp126Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthobacter sp. 126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthobacterSp126Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131814.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131814.protein.info.v11.5.txt",
		        "node_list_path": "1131814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DendroctonusPonderosae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dendroctonus ponderosae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DendroctonusPonderosae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "77166.protein.sequences.v11.5.fa",
		        "enrichment_path": "77166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77166.protein.info.v11.5.txt",
		        "node_list_path": "77166.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfofundulusThermosubterraneusDsm16057Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfofundulus thermosubterraneus DSM 16057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfofundulusThermosubterraneusDsm16057Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121432.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121432.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121432.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121432.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121432.protein.info.v11.5.txt",
		        "node_list_path": "1121432.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121432.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExidiaGlandulosaHhb12029(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exidia glandulosa HHB12029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExidiaGlandulosaHhb12029", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314781.protein.info.v11.5.txt",
		        "node_list_path": "1314781.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraWolffiiSerovarKhoratStrKhoratH2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira wolffii serovar Khorat str. Khorat-H2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraWolffiiSerovarKhoratStrKhoratH2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193069.protein.info.v11.5.txt",
		        "node_list_path": "1193069.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrettanomycesNaardenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brettanomyces naardenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrettanomycesNaardenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13370.clusters.proteins.v11.5.txt",
		        "sequence_path": "13370.protein.sequences.v11.5.fa",
		        "enrichment_path": "13370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13370.protein.info.v11.5.txt",
		        "node_list_path": "13370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CognatiyooniaKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cognatiyoonia koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CognatiyooniaKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "364200.protein.sequences.v11.5.fa",
		        "enrichment_path": "364200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "364200.protein.info.v11.5.txt",
		        "node_list_path": "364200.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacteraceaeBacteriumPmmr1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacteraceae bacterium PMMR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacteraceaeBacteriumPmmr1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1382303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382303.protein.info.v11.5.txt",
		        "node_list_path": "1382303.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioGilichinskyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio gilichinskyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioGilichinskyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1519643.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519643.protein.info.v11.5.txt",
		        "node_list_path": "1519643.protein.complete.v11.5.txt"
		    }
		]
    )()

def JeotgalicoccusSp13mg44airCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalicoccus sp. 13MG44air Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalicoccusSp13mg44airCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461582.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461582.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461582.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461582.protein.info.v11.5.txt",
		        "node_list_path": "1461582.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461582.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodniusProlixus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodnius prolixus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodniusProlixus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13249.protein.sequences.v11.5.fa",
		        "enrichment_path": "13249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13249.protein.info.v11.5.txt",
		        "node_list_path": "13249.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasOligotrophaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas oligotropha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasOligotrophaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42354.clusters.proteins.v11.5.txt",
		        "sequence_path": "42354.protein.sequences.v11.5.fa",
		        "enrichment_path": "42354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42354.protein.info.v11.5.txt",
		        "node_list_path": "42354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusSaccharolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus saccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSaccharolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1139996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1139996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1139996.clusters.proteins.v11.5.txt",
		        "sequence_path": "1139996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1139996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1139996.protein.info.v11.5.txt",
		        "node_list_path": "1139996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1139996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumContaminansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium contaminans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumContaminansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423959.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423959.protein.info.v11.5.txt",
		        "node_list_path": "1423959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasSpartinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas spartinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasSpartinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1792290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1792290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1792290.clusters.proteins.v11.5.txt",
		        "sequence_path": "1792290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792290.protein.info.v11.5.txt",
		        "node_list_path": "1792290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1792290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterCinaediCcug18818(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi CCUG18818 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterCinaediCcug18818", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "537971.protein.sequences.v11.5.fa",
		        "enrichment_path": "537971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537971.protein.info.v11.5.txt",
		        "node_list_path": "537971.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaAzurea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora azurea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaAzurea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1114959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114959.protein.info.v11.5.txt",
		        "node_list_path": "1114959.protein.complete.v11.5.txt"
		    }
		]
    )()

def MangrovimonasSpTpbh4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. TPBH4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MangrovimonasSpTpbh4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1645914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1645914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1645914.protein.info.v11.5.txt",
		        "node_list_path": "1645914.protein.complete.v11.5.txt"
		    }
		]
    )()

def DuganellaSacchariCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Duganella sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSacchariCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "551987.clusters.info.v11.5.txt",
		        "cluster_tree_path": "551987.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "551987.clusters.proteins.v11.5.txt",
		        "sequence_path": "551987.protein.sequences.v11.5.fa",
		        "enrichment_path": "551987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551987.protein.info.v11.5.txt",
		        "node_list_path": "551987.cluster.nodes.v11.5.txt",
		        "edge_list_path": "551987.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpMarseilleP328(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. Marseille-P328 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpMarseilleP328", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816688.protein.info.v11.5.txt",
		        "node_list_path": "1816688.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaucisalibacillusGlobulusDsm18846Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paucisalibacillus globulus DSM 18846 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaucisalibacillusGlobulusDsm18846Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122940.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122940.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122940.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122940.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122940.protein.info.v11.5.txt",
		        "node_list_path": "1122940.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122940.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp4212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 42_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp4212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896983.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896983.protein.info.v11.5.txt",
		        "node_list_path": "1896983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillibacterSp13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. 13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSp13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235797.protein.info.v11.5.txt",
		        "node_list_path": "1235797.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumLongipes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium longipes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumLongipes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "694270.protein.sequences.v11.5.fa",
		        "enrichment_path": "694270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694270.protein.info.v11.5.txt",
		        "node_list_path": "694270.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterovibrioCalviensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio calviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioCalviensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1190606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1190606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1190606.protein.info.v11.5.txt",
		        "node_list_path": "1190606.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpAa4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. AA4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpAa4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "591158.protein.sequences.v11.5.fa",
		        "enrichment_path": "591158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591158.protein.info.v11.5.txt",
		        "node_list_path": "591158.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "490629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "490629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "490629.clusters.proteins.v11.5.txt",
		        "sequence_path": "490629.protein.sequences.v11.5.fa",
		        "enrichment_path": "490629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "490629.protein.info.v11.5.txt",
		        "node_list_path": "490629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "490629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumXbb2008(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBB2008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumXbb2008", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520826.protein.info.v11.5.txt",
		        "node_list_path": "1520826.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag534(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:534 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag534", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263027.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263027.protein.info.v11.5.txt",
		        "node_list_path": "1263027.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCaseiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium casei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCaseiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1285583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1285583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1285583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1285583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1285583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1285583.protein.info.v11.5.txt",
		        "node_list_path": "1285583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1285583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraKernoviaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora kernoviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraKernoviaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "325452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "325452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "325452.clusters.proteins.v11.5.txt",
		        "sequence_path": "325452.protein.sequences.v11.5.fa",
		        "enrichment_path": "325452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "325452.protein.info.v11.5.txt",
		        "node_list_path": "325452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "325452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeptuniibacterPectenicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neptuniibacter pectenicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptuniibacterPectenicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1806669.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1806669.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1806669.clusters.proteins.v11.5.txt",
		        "sequence_path": "1806669.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806669.protein.info.v11.5.txt",
		        "node_list_path": "1806669.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1806669.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpGa2829(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-2829 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpGa2829", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1772283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772283.protein.info.v11.5.txt",
		        "node_list_path": "1772283.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumIndicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium indicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumIndicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094466.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094466.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094466.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094466.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094466.protein.info.v11.5.txt",
		        "node_list_path": "1094466.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094466.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5024Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_50_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5024Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798507.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798507.protein.info.v11.5.txt",
		        "node_list_path": "1798507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloarculaRubripromontoriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula rubripromontorii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaRubripromontoriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1705562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1705562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1705562.clusters.proteins.v11.5.txt",
		        "sequence_path": "1705562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705562.protein.info.v11.5.txt",
		        "node_list_path": "1705562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1705562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCaseiDsm20011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus casei DSM20011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCaseiDsm20011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423732.protein.info.v11.5.txt",
		        "node_list_path": "1423732.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumUniforme(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium uniforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumUniforme", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39495.protein.sequences.v11.5.fa",
		        "enrichment_path": "39495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39495.protein.info.v11.5.txt",
		        "node_list_path": "39495.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusAcidifarinaeDsm19394Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidifarinae DSM 19394 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAcidifarinaeDsm19394Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423715.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423715.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423715.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423715.protein.info.v11.5.txt",
		        "node_list_path": "1423715.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423715.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoflavibacterZeaxanthinifaciensDsm18436(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanthinifaciens DSM 18436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoflavibacterZeaxanthinifaciensDsm18436", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122225.protein.info.v11.5.txt",
		        "node_list_path": "1122225.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSparsogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sparsogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSparsogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67365.protein.sequences.v11.5.fa",
		        "enrichment_path": "67365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67365.protein.info.v11.5.txt",
		        "node_list_path": "67365.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusVerrucosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus verrucosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusVerrucosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "342668.protein.sequences.v11.5.fa",
		        "enrichment_path": "342668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342668.protein.info.v11.5.txt",
		        "node_list_path": "342668.protein.complete.v11.5.txt"
		    }
		]
    )()

def TissierellaPraeacutaDsm18095(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tissierella praeacuta DSM 18095 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TissierellaPraeacutaDsm18095", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123404.protein.info.v11.5.txt",
		        "node_list_path": "1123404.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusMacroides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus macroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusMacroides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33935.protein.sequences.v11.5.fa",
		        "enrichment_path": "33935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33935.protein.info.v11.5.txt",
		        "node_list_path": "33935.protein.complete.v11.5.txt"
		    }
		]
    )()

def RodentibacterSpPpn85Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter sp. Ppn85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterSpPpn85Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1908525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1908525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1908525.clusters.proteins.v11.5.txt",
		        "sequence_path": "1908525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908525.protein.info.v11.5.txt",
		        "node_list_path": "1908525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1908525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusAminophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus aminophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusAminophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1367847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1367847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1367847.protein.info.v11.5.txt",
		        "node_list_path": "1367847.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrinemaVersiformeJcm10478(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrinema versiforme JCM 10478 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrinemaVersiformeJcm10478", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227496.protein.info.v11.5.txt",
		        "node_list_path": "1227496.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaueraSp63(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. 63 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraSp63", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "497321.protein.sequences.v11.5.fa",
		        "enrichment_path": "497321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "497321.protein.info.v11.5.txt",
		        "node_list_path": "497321.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag755(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:755 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag755", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262935.protein.info.v11.5.txt",
		        "node_list_path": "1262935.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChromohalobacterJaponicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chromohalobacter japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromohalobacterJaponicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "223900.protein.sequences.v11.5.fa",
		        "enrichment_path": "223900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223900.protein.info.v11.5.txt",
		        "node_list_path": "223900.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegamonasRupellensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megamonas rupellensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegamonasRupellensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122217.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122217.protein.info.v11.5.txt",
		        "node_list_path": "1122217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumActinocoloniiformeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium actinocoloniiforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumActinocoloniiformeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437605.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437605.protein.info.v11.5.txt",
		        "node_list_path": "1437605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CloacibacillusPorcorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cloacibacillus porcorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CloacibacillusPorcorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1197717.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197717.protein.info.v11.5.txt",
		        "node_list_path": "1197717.protein.complete.v11.5.txt"
		    }
		]
    )()

def MalasseziaVespertilionisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Malassezia vespertilionis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalasseziaVespertilionisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2020962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2020962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2020962.clusters.proteins.v11.5.txt",
		        "sequence_path": "2020962.protein.sequences.v11.5.fa",
		        "enrichment_path": "2020962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2020962.protein.info.v11.5.txt",
		        "node_list_path": "2020962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2020962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumAphoticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium aphoticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumAphoticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "754436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "754436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "754436.clusters.proteins.v11.5.txt",
		        "sequence_path": "754436.protein.sequences.v11.5.fa",
		        "enrichment_path": "754436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754436.protein.info.v11.5.txt",
		        "node_list_path": "754436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "754436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwc23714(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_37_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc23714", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619046.protein.info.v11.5.txt",
		        "node_list_path": "1619046.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033730.protein.info.v11.5.txt",
		        "node_list_path": "1033730.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpDsm18164Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. DSM 18164 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpDsm18164Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881058.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881058.protein.info.v11.5.txt",
		        "node_list_path": "1881058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3811(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_38_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3811", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798278.protein.info.v11.5.txt",
		        "node_list_path": "1798278.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterJohnsoniiXbb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter johnsonii XBB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterJohnsoniiXbb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1242245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1242245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1242245.protein.info.v11.5.txt",
		        "node_list_path": "1242245.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzovibrioRestrictus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azovibrio restrictus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzovibrioRestrictus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121035.protein.info.v11.5.txt",
		        "node_list_path": "1121035.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaOculi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma oculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaOculi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35623.protein.sequences.v11.5.fa",
		        "enrichment_path": "35623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35623.protein.info.v11.5.txt",
		        "node_list_path": "35623.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumMs4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium MS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumMs4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120746.protein.info.v11.5.txt",
		        "node_list_path": "1120746.protein.complete.v11.5.txt"
		    }
		]
    )()

def EikenellaSpNml96A049Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eikenella sp. NML96-A-049 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EikenellaSpNml96A049Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1809061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1809061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1809061.clusters.proteins.v11.5.txt",
		        "sequence_path": "1809061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1809061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1809061.protein.info.v11.5.txt",
		        "node_list_path": "1809061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1809061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudorhodoferaxSpLeaf274(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf274 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodoferaxSpLeaf274", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736318.protein.info.v11.5.txt",
		        "node_list_path": "1736318.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesQaidamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces qaidamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesQaidamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1783515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1783515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1783515.clusters.proteins.v11.5.txt",
		        "sequence_path": "1783515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1783515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1783515.protein.info.v11.5.txt",
		        "node_list_path": "1783515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1783515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkaliphilusPeptidifermentansDsm18978Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkaliphilus peptidifermentans DSM 18978 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkaliphilusPeptidifermentansDsm18978Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120976.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120976.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120976.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120976.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120976.protein.info.v11.5.txt",
		        "node_list_path": "1120976.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120976.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaDenticolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella denticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaDenticolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "767031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "767031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "767031.clusters.proteins.v11.5.txt",
		        "sequence_path": "767031.protein.sequences.v11.5.fa",
		        "enrichment_path": "767031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767031.protein.info.v11.5.txt",
		        "node_list_path": "767031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "767031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTerrybacteriaBacteriumRifcsphigho201Full4817(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPHIGHO2_01_FULL_48_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsphigho201Full4817", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802362.protein.info.v11.5.txt",
		        "node_list_path": "1802362.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoniliophthoraPerniciosaFa553Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moniliophthora perniciosa FA553 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoniliophthoraPerniciosaFa553Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "554373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "554373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "554373.clusters.proteins.v11.5.txt",
		        "sequence_path": "554373.protein.sequences.v11.5.fa",
		        "enrichment_path": "554373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "554373.protein.info.v11.5.txt",
		        "node_list_path": "554373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "554373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordonibacterMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonibacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordonibacterMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841863.protein.info.v11.5.txt",
		        "node_list_path": "1841863.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanospirillumHungateiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanospirillum hungatei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanospirillumHungateiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "323259.clusters.info.v11.5.txt",
		        "cluster_tree_path": "323259.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "323259.clusters.proteins.v11.5.txt",
		        "sequence_path": "323259.protein.sequences.v11.5.fa",
		        "enrichment_path": "323259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323259.protein.info.v11.5.txt",
		        "node_list_path": "323259.cluster.nodes.v11.5.txt",
		        "edge_list_path": "323259.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanohalophilusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanohalophilusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2177.protein.sequences.v11.5.fa",
		        "enrichment_path": "2177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2177.protein.info.v11.5.txt",
		        "node_list_path": "2177.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusGarvieaeDcc43Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae DCC43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusGarvieaeDcc43Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231377.protein.info.v11.5.txt",
		        "node_list_path": "1231377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolimonasFlava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solimonas flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolimonasFlava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123257.protein.info.v11.5.txt",
		        "node_list_path": "1123257.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeferrisomaCamini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deferrisoma camini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeferrisomaCamini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125863.protein.info.v11.5.txt",
		        "node_list_path": "1125863.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumAb4001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium AB4001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumAb4001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410638.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410638.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410638.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410638.protein.info.v11.5.txt",
		        "node_list_path": "1410638.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410638.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaeromyxobacterSpRbg166914Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaeromyxobacter sp. RBG_16_69_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeromyxobacterSpRbg166914Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797238.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797238.protein.info.v11.5.txt",
		        "node_list_path": "1797238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusCuniculiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus cuniculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusCuniculiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1432788.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1432788.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1432788.clusters.proteins.v11.5.txt",
		        "sequence_path": "1432788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432788.protein.info.v11.5.txt",
		        "node_list_path": "1432788.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1432788.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoritellaSpPe36Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moritella sp. PE36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoritellaSpPe36Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "58051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "58051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "58051.clusters.proteins.v11.5.txt",
		        "sequence_path": "58051.protein.sequences.v11.5.fa",
		        "enrichment_path": "58051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58051.protein.info.v11.5.txt",
		        "node_list_path": "58051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "58051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusColeohominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus coleohominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusColeohominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575594.protein.sequences.v11.5.fa",
		        "enrichment_path": "575594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575594.protein.info.v11.5.txt",
		        "node_list_path": "575594.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumFreneyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium freneyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumFreneyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1287475.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287475.protein.info.v11.5.txt",
		        "node_list_path": "1287475.protein.complete.v11.5.txt"
		    }
		]
    )()

def OctadecabacterAntarcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Octadecabacter antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OctadecabacterAntarcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391626.protein.sequences.v11.5.fa",
		        "enrichment_path": "391626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391626.protein.info.v11.5.txt",
		        "node_list_path": "391626.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg2304851(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_48_51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304851", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805320.protein.info.v11.5.txt",
		        "node_list_path": "1805320.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaTypographi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia typographi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaTypographi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "371042.protein.sequences.v11.5.fa",
		        "enrichment_path": "371042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "371042.protein.info.v11.5.txt",
		        "node_list_path": "371042.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatranaerobiusThermophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natranaerobius thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatranaerobiusThermophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "457570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "457570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "457570.clusters.proteins.v11.5.txt",
		        "sequence_path": "457570.protein.sequences.v11.5.fa",
		        "enrichment_path": "457570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457570.protein.info.v11.5.txt",
		        "node_list_path": "457570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "457570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JiangellaMuralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jiangella muralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JiangellaMuralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "702383.protein.sequences.v11.5.fa",
		        "enrichment_path": "702383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702383.protein.info.v11.5.txt",
		        "node_list_path": "702383.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusParauberisNcfd2020(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parauberis NCFD2020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusParauberisNcfd2020", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "873447.protein.sequences.v11.5.fa",
		        "enrichment_path": "873447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "873447.protein.info.v11.5.txt",
		        "node_list_path": "873447.protein.complete.v11.5.txt"
		    }
		]
    )()

def DasaniaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dasania marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DasaniaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121374.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121374.protein.info.v11.5.txt",
		        "node_list_path": "1121374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPsychrotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPsychrotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1112217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1112217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1112217.clusters.proteins.v11.5.txt",
		        "sequence_path": "1112217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112217.protein.info.v11.5.txt",
		        "node_list_path": "1112217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1112217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaVulgaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Beta vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaVulgaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "161934.protein.sequences.v11.5.fa",
		        "enrichment_path": "161934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161934.protein.info.v11.5.txt",
		        "node_list_path": "161934.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpSgBin1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. SG-bin1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpSgBin1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1827376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827376.protein.info.v11.5.txt",
		        "node_list_path": "1827376.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag632(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:632 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag632", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262830.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262830.protein.info.v11.5.txt",
		        "node_list_path": "1262830.protein.complete.v11.5.txt"
		    }
		]
    )()

def HungatellaHathewayiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hungatella hathewayi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HungatellaHathewayiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "154046.clusters.info.v11.5.txt",
		        "cluster_tree_path": "154046.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "154046.clusters.proteins.v11.5.txt",
		        "sequence_path": "154046.protein.sequences.v11.5.fa",
		        "enrichment_path": "154046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "154046.protein.info.v11.5.txt",
		        "node_list_path": "154046.cluster.nodes.v11.5.txt",
		        "edge_list_path": "154046.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpragueaLophii42110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spraguea lophii 42_110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpragueaLophii42110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1358809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1358809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1358809.protein.info.v11.5.txt",
		        "node_list_path": "1358809.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfOnchocerca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Onchocerca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfOnchocerca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "100901.protein.sequences.v11.5.fa",
		        "enrichment_path": "100901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "100901.protein.info.v11.5.txt",
		        "node_list_path": "100901.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumXbb1006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBB1006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumXbb1006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520827.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520827.protein.info.v11.5.txt",
		        "node_list_path": "1520827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfuricurvumSpMlsb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. MLSB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricurvumSpMlsb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1537917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1537917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1537917.protein.info.v11.5.txt",
		        "node_list_path": "1537917.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylibiumSpCf468(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylibium sp. CF468 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylibiumSpCf468", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500262.protein.info.v11.5.txt",
		        "node_list_path": "1500262.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprococcusComesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus comes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprococcusComesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "410072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "410072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "410072.clusters.proteins.v11.5.txt",
		        "sequence_path": "410072.protein.sequences.v11.5.fa",
		        "enrichment_path": "410072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "410072.protein.info.v11.5.txt",
		        "node_list_path": "410072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "410072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentibacterAlgarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentibacter algarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentibacterAlgarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "576131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "576131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "576131.clusters.proteins.v11.5.txt",
		        "sequence_path": "576131.protein.sequences.v11.5.fa",
		        "enrichment_path": "576131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "576131.protein.info.v11.5.txt",
		        "node_list_path": "576131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "576131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumVrystaatenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium vrystaatense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumVrystaatenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "307480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "307480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "307480.clusters.proteins.v11.5.txt",
		        "sequence_path": "307480.protein.sequences.v11.5.fa",
		        "enrichment_path": "307480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "307480.protein.info.v11.5.txt",
		        "node_list_path": "307480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "307480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifoxyd2Full3916Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYD2_FULL_39_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyd2Full3916Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798009.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798009.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798009.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798009.protein.info.v11.5.txt",
		        "node_list_path": "1798009.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798009.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElizabethkingiaMiricolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elizabethkingia miricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElizabethkingiaMiricolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "172045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "172045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "172045.clusters.proteins.v11.5.txt",
		        "sequence_path": "172045.protein.sequences.v11.5.fa",
		        "enrichment_path": "172045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "172045.protein.info.v11.5.txt",
		        "node_list_path": "172045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "172045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumBdw918(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium BDW918 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumBdw918", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1168065.protein.sequences.v11.0.fa",
		        "enrichment_path": "1168065.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1168065.protein.info.v11.0.txt",
		        "node_list_path": "1168065.protein.complete.v11.0.txt"
		    }
		]
    )()

def DeinococcusPeraridilitorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus peraridilitoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusPeraridilitorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "937777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "937777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "937777.clusters.proteins.v11.5.txt",
		        "sequence_path": "937777.protein.sequences.v11.5.fa",
		        "enrichment_path": "937777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937777.protein.info.v11.5.txt",
		        "node_list_path": "937777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "937777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaTobetsuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella tobetsuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaTobetsuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1110546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1110546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1110546.protein.info.v11.5.txt",
		        "node_list_path": "1110546.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaWorsleiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella worsleiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaWorsleiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45076.protein.sequences.v11.5.fa",
		        "enrichment_path": "45076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45076.protein.info.v11.5.txt",
		        "node_list_path": "45076.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusProvidenciaSiddalliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Providencia siddallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusProvidenciaSiddalliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1715285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1715285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1715285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1715285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715285.protein.info.v11.5.txt",
		        "node_list_path": "1715285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1715285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumCommune(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium commune graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumCommune", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1306519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306519.protein.info.v11.5.txt",
		        "node_list_path": "1306519.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwb14314Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_43_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb14314Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618578.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618578.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618578.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618578.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618578.protein.info.v11.5.txt",
		        "node_list_path": "1618578.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618578.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumAo1B(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium AO1-B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumAo1B", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1905358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1905358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1905358.protein.info.v11.5.txt",
		        "node_list_path": "1905358.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumGw2011Gwb1397Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWB1_39_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwb1397Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618464.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618464.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618464.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618464.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618464.protein.info.v11.5.txt",
		        "node_list_path": "1618464.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618464.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TatumellaSaanichensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tatumella saanichensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TatumellaSaanichensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "480813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "480813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "480813.clusters.proteins.v11.5.txt",
		        "sequence_path": "480813.protein.sequences.v11.5.fa",
		        "enrichment_path": "480813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "480813.protein.info.v11.5.txt",
		        "node_list_path": "480813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "480813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BarnesiellaViscericola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Barnesiella viscericola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BarnesiellaViscericola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "880074.protein.sequences.v11.5.fa",
		        "enrichment_path": "880074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880074.protein.info.v11.5.txt",
		        "node_list_path": "880074.protein.complete.v11.5.txt"
		    }
		]
    )()

def DuganellaSpRoot336d2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. Root336D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpRoot336d2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736518.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736518.protein.info.v11.5.txt",
		        "node_list_path": "1736518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IntestinimonasMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Intestinimonas massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntestinimonasMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1673721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1673721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1673721.clusters.proteins.v11.5.txt",
		        "sequence_path": "1673721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673721.protein.info.v11.5.txt",
		        "node_list_path": "1673721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1673721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonCsp11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon CSP1-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonCsp11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1640512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640512.protein.info.v11.5.txt",
		        "node_list_path": "1640512.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumRbg166719(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_16_67_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumRbg166719", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802196.protein.info.v11.5.txt",
		        "node_list_path": "1802196.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpPcc7335(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpPcc7335", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "91464.protein.sequences.v11.5.fa",
		        "enrichment_path": "91464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91464.protein.info.v11.5.txt",
		        "node_list_path": "91464.protein.complete.v11.5.txt"
		    }
		]
    )()

def HathewayaProteolyticaDsm3090Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hathewaya proteolytica DSM 3090 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HathewayaProteolyticaDsm3090Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121331.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121331.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121331.protein.info.v11.5.txt",
		        "node_list_path": "1121331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaeCc1557(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1557 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaeCc1557", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1357279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357279.protein.info.v11.5.txt",
		        "node_list_path": "1357279.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccidioidesBrasiliensisPb18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides brasiliensis Pb18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccidioidesBrasiliensisPb18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "502780.protein.sequences.v11.5.fa",
		        "enrichment_path": "502780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502780.protein.info.v11.5.txt",
		        "node_list_path": "502780.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaMacacae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella macacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaMacacae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230338.protein.info.v11.5.txt",
		        "node_list_path": "1230338.protein.complete.v11.5.txt"
		    }
		]
    )()

def GossypiumRaimondiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gossypium raimondii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GossypiumRaimondiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29730.clusters.proteins.v11.5.txt",
		        "sequence_path": "29730.protein.sequences.v11.5.fa",
		        "enrichment_path": "29730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29730.protein.info.v11.5.txt",
		        "node_list_path": "29730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucorAmbiguus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucor ambiguus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucorAmbiguus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "91626.protein.sequences.v11.5.fa",
		        "enrichment_path": "91626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91626.protein.info.v11.5.txt",
		        "node_list_path": "91626.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumCzechenseLl01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium czechense LL01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumCzechenseLl01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420583.protein.info.v11.5.txt",
		        "node_list_path": "1420583.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaVulneris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia vulneris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaVulneris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1115515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1115515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1115515.protein.info.v11.5.txt",
		        "node_list_path": "1115515.protein.complete.v11.5.txt"
		    }
		]
    )()

def SilicibacterLacuscaerulensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Silicibacter lacuscaerulensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SilicibacterLacuscaerulensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644107.clusters.proteins.v11.5.txt",
		        "sequence_path": "644107.protein.sequences.v11.5.fa",
		        "enrichment_path": "644107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644107.protein.info.v11.5.txt",
		        "node_list_path": "644107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YangiaSpCcbMm3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yangia sp. CCB-MM3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YangiaSpCcbMm3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1792508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792508.protein.info.v11.5.txt",
		        "node_list_path": "1792508.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZymomonasMobilisPomaceae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zymomonas mobilis pomaceae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymomonasMobilisPomaceae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "579138.protein.sequences.v11.5.fa",
		        "enrichment_path": "579138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579138.protein.info.v11.5.txt",
		        "node_list_path": "579138.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumDenitrificansAtcc51888(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium denitrificans ATCC51888 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumDenitrificansAtcc51888", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582899.protein.sequences.v11.5.fa",
		        "enrichment_path": "582899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582899.protein.info.v11.5.txt",
		        "node_list_path": "582899.protein.complete.v11.5.txt"
		    }
		]
    )()

def LobosporangiumTransversaleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lobosporangium transversale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LobosporangiumTransversaleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "64571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "64571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "64571.clusters.proteins.v11.5.txt",
		        "sequence_path": "64571.protein.sequences.v11.5.fa",
		        "enrichment_path": "64571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64571.protein.info.v11.5.txt",
		        "node_list_path": "64571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "64571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenimonasDonghaensisDsm18148Ho3R19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas donghaensis DSM 18148 HO3-R19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenimonasDonghaensisDsm18148Ho3R19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121014.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121014.protein.info.v11.5.txt",
		        "node_list_path": "1121014.protein.complete.v11.5.txt"
		    }
		]
    )()

def BisonBisonBison(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bison bison bison graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BisonBisonBison", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43346.protein.sequences.v11.5.fa",
		        "enrichment_path": "43346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43346.protein.info.v11.5.txt",
		        "node_list_path": "43346.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumAethiopicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum aethiopicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumAethiopicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1758255.protein.sequences.v11.5.fa",
		        "enrichment_path": "1758255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1758255.protein.info.v11.5.txt",
		        "node_list_path": "1758255.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumLimnosediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium limnosediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumLimnosediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1341181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1341181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1341181.clusters.proteins.v11.5.txt",
		        "sequence_path": "1341181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341181.protein.info.v11.5.txt",
		        "node_list_path": "1341181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1341181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobacterSpRoot404Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root404 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobacterSpRoot404Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736528.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736528.protein.info.v11.5.txt",
		        "node_list_path": "1736528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FerriphaselusSpR1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferriphaselus sp. R1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerriphaselusSpR1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1485544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1485544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1485544.protein.info.v11.5.txt",
		        "node_list_path": "1485544.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaLupini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora lupini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaLupini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150864.protein.info.v11.5.txt",
		        "node_list_path": "1150864.protein.complete.v11.5.txt"
		    }
		]
    )()

def SiccibacterTuricensisLmg23730Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Siccibacter turicensis LMG 23730 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SiccibacterTuricensisLmg23730Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1388748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1388748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1388748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1388748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1388748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1388748.protein.info.v11.5.txt",
		        "node_list_path": "1388748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1388748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrassicaRapaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brassica rapa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrassicaRapaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3711.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3711.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3711.clusters.proteins.v11.5.txt",
		        "sequence_path": "3711.protein.sequences.v11.5.fa",
		        "enrichment_path": "3711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3711.protein.info.v11.5.txt",
		        "node_list_path": "3711.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3711.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrypanosomaTheileri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma theileri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrypanosomaTheileri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67003.protein.sequences.v11.5.fa",
		        "enrichment_path": "67003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67003.protein.info.v11.5.txt",
		        "node_list_path": "67003.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanibacterMelonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janibacter melonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterMelonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262209.protein.sequences.v11.5.fa",
		        "enrichment_path": "262209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262209.protein.info.v11.5.txt",
		        "node_list_path": "262209.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCoahuilensisP1143Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coahuilensis p1.1.43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCoahuilensisP1143Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150625.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150625.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150625.protein.info.v11.5.txt",
		        "node_list_path": "1150625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpP6b1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. P6B1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpP6b1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410613.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410613.protein.info.v11.5.txt",
		        "node_list_path": "1410613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolanumTuberosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solanum tuberosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolanumTuberosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4113.protein.sequences.v11.5.fa",
		        "enrichment_path": "4113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4113.protein.info.v11.5.txt",
		        "node_list_path": "4113.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasSpLor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. LOR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasSpLor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1537994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1537994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1537994.protein.info.v11.5.txt",
		        "node_list_path": "1537994.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollimonasSpOk242(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collimonas sp. OK242 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollimonasSpOk242", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798195.protein.info.v11.5.txt",
		        "node_list_path": "1798195.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaMinor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella minor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaMinor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1620.protein.info.v11.5.txt",
		        "node_list_path": "1620.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrospiraPlatensisNies39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrospira platensis NIES39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrospiraPlatensisNies39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "696747.protein.sequences.v11.5.fa",
		        "enrichment_path": "696747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696747.protein.info.v11.5.txt",
		        "node_list_path": "696747.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp2622(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 26_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp2622", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896978.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896978.protein.info.v11.5.txt",
		        "node_list_path": "1896978.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaMaltosaXu316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida maltosa Xu316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaMaltosaXu316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1245528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1245528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1245528.clusters.proteins.v11.5.txt",
		        "sequence_path": "1245528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245528.protein.info.v11.5.txt",
		        "node_list_path": "1245528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1245528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGracilibacteriaBacteriumCg10238174(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gracilibacteria bacterium CG1_02_38_174 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGracilibacteriaBacteriumCg10238174", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805210.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805210.protein.info.v11.5.txt",
		        "node_list_path": "1805210.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumLacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium lacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumLacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "169765.protein.sequences.v11.5.fa",
		        "enrichment_path": "169765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "169765.protein.info.v11.5.txt",
		        "node_list_path": "169765.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4126Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4126Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802661.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802661.protein.info.v11.5.txt",
		        "node_list_path": "1802661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesBingchenggensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces bingchenggensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesBingchenggensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "749414.protein.sequences.v11.5.fa",
		        "enrichment_path": "749414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "749414.protein.info.v11.5.txt",
		        "node_list_path": "749414.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteitaleaPratensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteitalea pratensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteitaleaPratensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855912.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855912.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855912.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855912.protein.info.v11.5.txt",
		        "node_list_path": "1855912.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855912.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag488(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:488 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag488", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262959.protein.info.v11.5.txt",
		        "node_list_path": "1262959.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrettanomycesNaardenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brettanomyces naardenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrettanomycesNaardenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13370.protein.sequences.v11.5.fa",
		        "enrichment_path": "13370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13370.protein.info.v11.5.txt",
		        "node_list_path": "13370.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrnithinibacillusCaliforniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ornithinibacillus californiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithinibacillusCaliforniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "161536.protein.sequences.v11.5.fa",
		        "enrichment_path": "161536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161536.protein.info.v11.5.txt",
		        "node_list_path": "161536.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumGoodii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium goodii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumGoodii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "134601.protein.sequences.v11.5.fa",
		        "enrichment_path": "134601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134601.protein.info.v11.5.txt",
		        "node_list_path": "134601.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidimicrobiiaBacteriumRedseaS09B7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium REDSEA-S09_B7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidimicrobiiaBacteriumRedseaS09B7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811597.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811597.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811597.protein.info.v11.5.txt",
		        "node_list_path": "1811597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumOpportunistum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium opportunistum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumOpportunistum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "536019.protein.sequences.v11.5.fa",
		        "enrichment_path": "536019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "536019.protein.info.v11.5.txt",
		        "node_list_path": "536019.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelobacterSeleniigenesDsm18267Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter seleniigenes DSM 18267 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelobacterSeleniigenesDsm18267Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122946.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122946.protein.info.v11.5.txt",
		        "node_list_path": "1122946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloarculaHispanicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula hispanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaHispanicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634497.clusters.proteins.v11.5.txt",
		        "sequence_path": "634497.protein.sequences.v11.5.fa",
		        "enrichment_path": "634497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634497.protein.info.v11.5.txt",
		        "node_list_path": "634497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc14312(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_43_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc14312", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618909.protein.info.v11.5.txt",
		        "node_list_path": "1618909.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3914Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3914Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798383.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798383.protein.info.v11.5.txt",
		        "node_list_path": "1798383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag884(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:884 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag884", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262990.protein.info.v11.5.txt",
		        "node_list_path": "1262990.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolfiporiaCocosMd104Ss10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolfiporia cocos MD-104 SS10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolfiporiaCocosMd104Ss10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742152.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742152.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742152.clusters.proteins.v11.5.txt",
		        "sequence_path": "742152.protein.sequences.v11.5.fa",
		        "enrichment_path": "742152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742152.protein.info.v11.5.txt",
		        "node_list_path": "742152.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742152.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AllomycesMacrogynus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Allomyces macrogynus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllomycesMacrogynus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28583.protein.sequences.v11.5.fa",
		        "enrichment_path": "28583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28583.protein.info.v11.5.txt",
		        "node_list_path": "28583.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumGambrini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium gambrini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumGambrini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "373672.protein.sequences.v11.5.fa",
		        "enrichment_path": "373672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "373672.protein.info.v11.5.txt",
		        "node_list_path": "373672.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacaAbyssiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibaca abyssi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacaAbyssiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1250539.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1250539.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1250539.clusters.proteins.v11.5.txt",
		        "sequence_path": "1250539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250539.protein.info.v11.5.txt",
		        "node_list_path": "1250539.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1250539.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumXbd2001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBD2001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumXbd2001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520820.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520820.protein.info.v11.5.txt",
		        "node_list_path": "1520820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE2699(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2699 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE2699", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834137.protein.info.v11.5.txt",
		        "node_list_path": "1834137.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusAzorensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius azorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusAzorensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1287727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1287727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1287727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1287727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287727.protein.info.v11.5.txt",
		        "node_list_path": "1287727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1287727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyadobacterTibetensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter tibetensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterTibetensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434325.protein.info.v11.5.txt",
		        "node_list_path": "1434325.protein.complete.v11.5.txt"
		    }
		]
    )()

def RunellaZeaeDsm19591Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Runella zeae DSM 19591 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RunellaZeaeDsm19591Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123078.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123078.protein.info.v11.5.txt",
		        "node_list_path": "1123078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpKw12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. KW12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpKw12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499685.protein.info.v11.5.txt",
		        "node_list_path": "1499685.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpLeaf405(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf405 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpLeaf405", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736367.protein.info.v11.5.txt",
		        "node_list_path": "1736367.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumStriatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium striatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumStriatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525268.protein.sequences.v11.5.fa",
		        "enrichment_path": "525268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525268.protein.info.v11.5.txt",
		        "node_list_path": "525268.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumAustralicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium australicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumAustralicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "754035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "754035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "754035.clusters.proteins.v11.5.txt",
		        "sequence_path": "754035.protein.sequences.v11.5.fa",
		        "enrichment_path": "754035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754035.protein.info.v11.5.txt",
		        "node_list_path": "754035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "754035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpEr2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. ER2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpEr2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1519438.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519438.protein.info.v11.5.txt",
		        "node_list_path": "1519438.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpRs9917(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. RS9917 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpRs9917", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "221360.protein.sequences.v11.5.fa",
		        "enrichment_path": "221360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221360.protein.info.v11.5.txt",
		        "node_list_path": "221360.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarum3841(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum 3841 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarum3841", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216596.protein.sequences.v11.0.fa",
		        "enrichment_path": "216596.protein.enrichment.terms.v11.0.txt",
		        "info_path": "216596.protein.info.v11.0.txt",
		        "node_list_path": "216596.protein.complete.v11.0.txt"
		    }
		]
    )()

def DesulfosporosinusAcididurans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus acididurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusAcididurans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "476652.protein.sequences.v11.5.fa",
		        "enrichment_path": "476652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "476652.protein.info.v11.5.txt",
		        "node_list_path": "476652.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldithrixSpRbg13449(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldithrix sp. RBG_13_44_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldithrixSpRbg13449", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797576.protein.info.v11.5.txt",
		        "node_list_path": "1797576.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumDtu027Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium DTU027 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumDtu027Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671663.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671663.protein.info.v11.5.txt",
		        "node_list_path": "1671663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpUrhb0009Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. URHB0009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpUrhb0009Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298866.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298866.protein.info.v11.5.txt",
		        "node_list_path": "1298866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PercaFlavescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Perca flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PercaFlavescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8167.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8167.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8167.clusters.proteins.v11.5.txt",
		        "sequence_path": "8167.protein.sequences.v11.5.fa",
		        "enrichment_path": "8167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8167.protein.info.v11.5.txt",
		        "node_list_path": "8167.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8167.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanohalophilusMahiiDsm5219(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus mahii DSM 5219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanohalophilusMahiiDsm5219", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "547558.protein.sequences.v11.5.fa",
		        "enrichment_path": "547558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547558.protein.info.v11.5.txt",
		        "node_list_path": "547558.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSalsus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus salsus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSalsus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930152.protein.sequences.v11.5.fa",
		        "enrichment_path": "930152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930152.protein.info.v11.5.txt",
		        "node_list_path": "930152.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaEnoecaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella enoeca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaEnoecaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235815.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235815.protein.info.v11.5.txt",
		        "node_list_path": "1235815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSp3131Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. 3_1_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSp3131Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "457402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "457402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "457402.clusters.proteins.v11.5.txt",
		        "sequence_path": "457402.protein.sequences.v11.5.fa",
		        "enrichment_path": "457402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457402.protein.info.v11.5.txt",
		        "node_list_path": "457402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "457402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionNc10BacteriumCsp15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division NC10 bacterium CSP1-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionNc10BacteriumCsp15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1640516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1640516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1640516.clusters.proteins.v11.5.txt",
		        "sequence_path": "1640516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640516.protein.info.v11.5.txt",
		        "node_list_path": "1640516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1640516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichoplaxSpH2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoplax sp. H2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichoplaxSpH2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "287889.protein.sequences.v11.5.fa",
		        "enrichment_path": "287889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "287889.protein.info.v11.5.txt",
		        "node_list_path": "287889.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermogladiusCellulolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermogladius cellulolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermogladiusCellulolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1184251.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1184251.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1184251.clusters.proteins.v11.5.txt",
		        "sequence_path": "1184251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1184251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1184251.protein.info.v11.5.txt",
		        "node_list_path": "1184251.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1184251.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasSpTw1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. TW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasSpTw1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1561203.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1561203.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1561203.clusters.proteins.v11.5.txt",
		        "sequence_path": "1561203.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561203.protein.info.v11.5.txt",
		        "node_list_path": "1561203.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1561203.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAcetireducensDsm10703Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acetireducens DSM 10703 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAcetireducensDsm10703Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121290.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121290.protein.info.v11.5.txt",
		        "node_list_path": "1121290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSpAsf360(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sp. ASF360 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSpAsf360", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "97137.protein.sequences.v11.5.fa",
		        "enrichment_path": "97137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97137.protein.info.v11.5.txt",
		        "node_list_path": "97137.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgromycesSubbeticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agromyces subbeticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesSubbeticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120960.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120960.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120960.protein.info.v11.5.txt",
		        "node_list_path": "1120960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BipolarisSorokinianaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris sorokiniana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisSorokinianaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45130.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45130.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45130.clusters.proteins.v11.5.txt",
		        "sequence_path": "45130.protein.sequences.v11.5.fa",
		        "enrichment_path": "45130.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45130.protein.info.v11.5.txt",
		        "node_list_path": "45130.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45130.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LepisosteusOculatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lepisosteus oculatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LepisosteusOculatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7918.clusters.proteins.v11.5.txt",
		        "sequence_path": "7918.protein.sequences.v11.5.fa",
		        "enrichment_path": "7918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7918.protein.info.v11.5.txt",
		        "node_list_path": "7918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumAethiopicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium aethiopicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumAethiopicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1138170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1138170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1138170.protein.info.v11.5.txt",
		        "node_list_path": "1138170.protein.complete.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsSinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsSinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "72228.clusters.info.v11.5.txt",
		        "cluster_tree_path": "72228.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "72228.clusters.proteins.v11.5.txt",
		        "sequence_path": "72228.protein.sequences.v11.5.fa",
		        "enrichment_path": "72228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72228.protein.info.v11.5.txt",
		        "node_list_path": "72228.cluster.nodes.v11.5.txt",
		        "edge_list_path": "72228.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCereusRock344(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cereus Rock3-44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCereusRock344", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "526986.protein.sequences.v11.5.fa",
		        "enrichment_path": "526986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526986.protein.info.v11.5.txt",
		        "node_list_path": "526986.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzospirillumBrasilenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum brasilense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumBrasilenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "192.clusters.proteins.v11.5.txt",
		        "sequence_path": "192.protein.sequences.v11.5.fa",
		        "enrichment_path": "192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192.protein.info.v11.5.txt",
		        "node_list_path": "192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaPhytofirmans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phytofirmans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaPhytofirmans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398527.protein.sequences.v11.5.fa",
		        "enrichment_path": "398527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398527.protein.info.v11.5.txt",
		        "node_list_path": "398527.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanibaculumIndicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanibaculum indicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanibaculumIndicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1207063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1207063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1207063.protein.info.v11.5.txt",
		        "node_list_path": "1207063.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpPcc7502(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpPcc7502", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173263.protein.info.v11.5.txt",
		        "node_list_path": "1173263.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzisolibacterPropanilivoraxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryzisolibacter propanilivorax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzisolibacterPropanilivoraxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1527607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1527607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1527607.clusters.proteins.v11.5.txt",
		        "sequence_path": "1527607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1527607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1527607.protein.info.v11.5.txt",
		        "node_list_path": "1527607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1527607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumPsychraerophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium psychraerophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumPsychraerophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "218140.protein.sequences.v11.5.fa",
		        "enrichment_path": "218140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218140.protein.info.v11.5.txt",
		        "node_list_path": "218140.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumGlaciei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium glaciei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumGlaciei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1685010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685010.protein.info.v11.5.txt",
		        "node_list_path": "1685010.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf89Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf89 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf89Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736245.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736245.protein.info.v11.5.txt",
		        "node_list_path": "1736245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotaleaPsychrophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotalea psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotaleaPsychrophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "177439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "177439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "177439.clusters.proteins.v11.5.txt",
		        "sequence_path": "177439.protein.sequences.v11.5.fa",
		        "enrichment_path": "177439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "177439.protein.info.v11.5.txt",
		        "node_list_path": "177439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "177439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "261317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "261317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "261317.clusters.proteins.v11.5.txt",
		        "sequence_path": "261317.protein.sequences.v11.5.fa",
		        "enrichment_path": "261317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "261317.protein.info.v11.5.txt",
		        "node_list_path": "261317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "261317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSuebicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus suebicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSuebicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423807.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423807.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423807.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423807.protein.info.v11.5.txt",
		        "node_list_path": "1423807.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423807.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GrimontiaHollisaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Grimontia hollisae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GrimontiaHollisaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675812.clusters.proteins.v11.5.txt",
		        "sequence_path": "675812.protein.sequences.v11.5.fa",
		        "enrichment_path": "675812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675812.protein.info.v11.5.txt",
		        "node_list_path": "675812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacterium41269Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium 41_269 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacterium41269Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635275.protein.info.v11.5.txt",
		        "node_list_path": "1635275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsphigho201Full4349Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO2_01_FULL_43_49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho201Full4349Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797856.protein.info.v11.5.txt",
		        "node_list_path": "1797856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumRifcsplowo202Full6214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RIFCSPLOWO2_02_FULL_62_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumRifcsplowo202Full6214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801717.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801717.protein.info.v11.5.txt",
		        "node_list_path": "1801717.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumRifcsphigho201Full4710b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPHIGHO2_01_FULL_47_10b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsphigho201Full4710b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817738.protein.info.v11.5.txt",
		        "node_list_path": "1817738.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusXiphinematobacterSpIdahoGrape(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Xiphinematobacter sp. Idaho Grape graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusXiphinematobacterSpIdahoGrape", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1704307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1704307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1704307.protein.info.v11.5.txt",
		        "node_list_path": "1704307.protein.complete.v11.5.txt"
		    }
		]
    )()

def PunctulariaStrigosozonataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Punctularia strigosozonata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PunctulariaStrigosozonataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "202698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "202698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "202698.clusters.proteins.v11.5.txt",
		        "sequence_path": "202698.protein.sequences.v11.5.fa",
		        "enrichment_path": "202698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202698.protein.info.v11.5.txt",
		        "node_list_path": "202698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "202698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EuryarchaeotaArchaeonRbg19ftCombo5621(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_19FT_COMBO_56_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EuryarchaeotaArchaeonRbg19ftCombo5621", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797983.protein.info.v11.5.txt",
		        "node_list_path": "1797983.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParambassisRangaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parambassis ranga Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParambassisRangaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "210632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "210632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "210632.clusters.proteins.v11.5.txt",
		        "sequence_path": "210632.protein.sequences.v11.5.fa",
		        "enrichment_path": "210632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "210632.protein.info.v11.5.txt",
		        "node_list_path": "210632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "210632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerpetosiphonAurantiacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herpetosiphon aurantiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerpetosiphonAurantiacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316274.clusters.proteins.v11.5.txt",
		        "sequence_path": "316274.protein.sequences.v11.5.fa",
		        "enrichment_path": "316274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316274.protein.info.v11.5.txt",
		        "node_list_path": "316274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParvimonasSpF0440(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parvimonas sp. F0440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvimonasSpF0440", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "944565.protein.sequences.v11.5.fa",
		        "enrichment_path": "944565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944565.protein.info.v11.5.txt",
		        "node_list_path": "944565.protein.complete.v11.5.txt"
		    }
		]
    )()

def VirgibacillusDokdonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusDokdonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "302167.protein.sequences.v11.5.fa",
		        "enrichment_path": "302167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "302167.protein.info.v11.5.txt",
		        "node_list_path": "302167.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumBacteremicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium bacteremicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumBacteremicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "564198.protein.sequences.v11.5.fa",
		        "enrichment_path": "564198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "564198.protein.info.v11.5.txt",
		        "node_list_path": "564198.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo212Full4614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_12_FULL_46_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo212Full4614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801797.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801797.protein.info.v11.5.txt",
		        "node_list_path": "1801797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgreiaBicolorata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agreia bicolorata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgreiaBicolorata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "110935.protein.sequences.v11.5.fa",
		        "enrichment_path": "110935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "110935.protein.info.v11.5.txt",
		        "node_list_path": "110935.protein.complete.v11.5.txt"
		    }
		]
    )()

def RahnellaSpY9602Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rahnella sp. Y9602 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RahnellaSpY9602Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "741091.clusters.info.v11.5.txt",
		        "cluster_tree_path": "741091.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "741091.clusters.proteins.v11.5.txt",
		        "sequence_path": "741091.protein.sequences.v11.5.fa",
		        "enrichment_path": "741091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "741091.protein.info.v11.5.txt",
		        "node_list_path": "741091.cluster.nodes.v11.5.txt",
		        "edge_list_path": "741091.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyorhinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyorhinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2100.protein.sequences.v11.5.fa",
		        "enrichment_path": "2100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2100.protein.info.v11.5.txt",
		        "node_list_path": "2100.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSubterraneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSubterraneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "335973.protein.sequences.v11.5.fa",
		        "enrichment_path": "335973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335973.protein.info.v11.5.txt",
		        "node_list_path": "335973.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsaiaBogorensisNbrc16594(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Asaia bogorensis NBRC 16594 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsaiaBogorensisNbrc16594", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231624.protein.info.v11.5.txt",
		        "node_list_path": "1231624.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusWarneriL37603(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus warneri L37603 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusWarneriL37603", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596319.protein.sequences.v11.5.fa",
		        "enrichment_path": "596319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596319.protein.info.v11.5.txt",
		        "node_list_path": "596319.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg134915(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_49_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg134915", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797827.protein.info.v11.5.txt",
		        "node_list_path": "1797827.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenovibrioHalophilusDsm15072(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenovibrio halophilus DSM 15072 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenovibrioHalophilusDsm15072", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123516.protein.info.v11.5.txt",
		        "node_list_path": "1123516.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusGlaucusCbs51665(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus glaucus CBS 516.65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusGlaucusCbs51665", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1160497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160497.protein.info.v11.5.txt",
		        "node_list_path": "1160497.protein.complete.v11.5.txt"
		    }
		]
    )()

def VirgibacillusProomii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus proomii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusProomii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84407.protein.sequences.v11.5.fa",
		        "enrichment_path": "84407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84407.protein.info.v11.5.txt",
		        "node_list_path": "84407.protein.complete.v11.5.txt"
		    }
		]
    )()

def KocuriaRhizophilaDc2201(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kocuria rhizophila DC2201 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaRhizophilaDc2201", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "378753.protein.sequences.v11.5.fa",
		        "enrichment_path": "378753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "378753.protein.info.v11.5.txt",
		        "node_list_path": "378753.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123500.protein.info.v11.5.txt",
		        "node_list_path": "1123500.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumKa00134(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium KA00134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumKa00134", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1588750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588750.protein.info.v11.5.txt",
		        "node_list_path": "1588750.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAegiribacteriaBacteriumMlsCCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aegiribacteria bacterium MLS_C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAegiribacteriaBacteriumMlsCCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1775674.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1775674.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1775674.clusters.proteins.v11.5.txt",
		        "sequence_path": "1775674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775674.protein.info.v11.5.txt",
		        "node_list_path": "1775674.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1775674.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NasoniaVitripennisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nasonia vitripennis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NasoniaVitripennisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7425.clusters.proteins.v11.5.txt",
		        "sequence_path": "7425.protein.sequences.v11.5.fa",
		        "enrichment_path": "7425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7425.protein.info.v11.5.txt",
		        "node_list_path": "7425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusSenegalensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusSenegalensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1936063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1936063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1936063.protein.info.v11.5.txt",
		        "node_list_path": "1936063.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlautiaSpCag52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia sp. CAG:52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaSpCag52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262758.protein.info.v11.5.txt",
		        "node_list_path": "1262758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospirillumFerrooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospirillum ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospirillumFerrooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1162668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1162668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1162668.clusters.proteins.v11.5.txt",
		        "sequence_path": "1162668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1162668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1162668.protein.info.v11.5.txt",
		        "node_list_path": "1162668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1162668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DiversisporaEpigaeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Diversispora epigaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiversisporaEpigaeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348612.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348612.protein.info.v11.5.txt",
		        "node_list_path": "1348612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporomusaSphaeroidesDsm2875(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporomusa sphaeroides DSM 2875 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporomusaSphaeroidesDsm2875", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1337886.protein.sequences.v11.5.fa",
		        "enrichment_path": "1337886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1337886.protein.info.v11.5.txt",
		        "node_list_path": "1337886.protein.complete.v11.5.txt"
		    }
		]
    )()

def WaddliaChondrophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Waddlia chondrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WaddliaChondrophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "716544.clusters.info.v11.5.txt",
		        "cluster_tree_path": "716544.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "716544.clusters.proteins.v11.5.txt",
		        "sequence_path": "716544.protein.sequences.v11.5.fa",
		        "enrichment_path": "716544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "716544.protein.info.v11.5.txt",
		        "node_list_path": "716544.cluster.nodes.v11.5.txt",
		        "edge_list_path": "716544.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMojavensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mojavensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMojavensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1051501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051501.protein.info.v11.5.txt",
		        "node_list_path": "1051501.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslR70337Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSL R7-0337 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslR70337Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926588.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926588.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926588.protein.info.v11.5.txt",
		        "node_list_path": "1926588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaFelisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia felis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaFelisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "315456.clusters.info.v11.5.txt",
		        "cluster_tree_path": "315456.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "315456.clusters.proteins.v11.5.txt",
		        "sequence_path": "315456.protein.sequences.v11.5.fa",
		        "enrichment_path": "315456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "315456.protein.info.v11.5.txt",
		        "node_list_path": "315456.cluster.nodes.v11.5.txt",
		        "edge_list_path": "315456.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full4222(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_42_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full4222", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802207.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802207.protein.info.v11.5.txt",
		        "node_list_path": "1802207.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaUli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella uli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaUli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "633147.protein.sequences.v11.5.fa",
		        "enrichment_path": "633147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633147.protein.info.v11.5.txt",
		        "node_list_path": "633147.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasEchinoidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas echinoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasEchinoidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1112212.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1112212.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1112212.clusters.proteins.v11.5.txt",
		        "sequence_path": "1112212.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112212.protein.info.v11.5.txt",
		        "node_list_path": "1112212.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1112212.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlesiomonasShigelloides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plesiomonas shigelloides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlesiomonasShigelloides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "703.protein.sequences.v11.5.fa",
		        "enrichment_path": "703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "703.protein.info.v11.5.txt",
		        "node_list_path": "703.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomicrobiumPiriforme(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomicrobium piriforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomicrobiumPiriforme", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1576369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1576369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1576369.protein.info.v11.5.txt",
		        "node_list_path": "1576369.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaSp7321Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. 73-21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaSp7321Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895809.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895809.protein.info.v11.5.txt",
		        "node_list_path": "1895809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitreicellaSpSe45(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citreicella sp. SE45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitreicellaSpSe45", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "501479.protein.sequences.v11.5.fa",
		        "enrichment_path": "501479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "501479.protein.info.v11.5.txt",
		        "node_list_path": "501479.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesGordonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides gordonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesGordonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122931.protein.info.v11.5.txt",
		        "node_list_path": "1122931.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCfSaccharolyticumK10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] cf. saccharolyticum K10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCfSaccharolyticumK10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717608.clusters.proteins.v11.5.txt",
		        "sequence_path": "717608.protein.sequences.v11.5.fa",
		        "enrichment_path": "717608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717608.protein.info.v11.5.txt",
		        "node_list_path": "717608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliiroseovariusCrassostreae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aliiroseovarius crassostreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliiroseovariusCrassostreae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "154981.protein.sequences.v11.5.fa",
		        "enrichment_path": "154981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "154981.protein.info.v11.5.txt",
		        "node_list_path": "154981.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichodermaVirensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma virens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaVirensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29875.clusters.proteins.v11.5.txt",
		        "sequence_path": "29875.protein.sequences.v11.5.fa",
		        "enrichment_path": "29875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29875.protein.info.v11.5.txt",
		        "node_list_path": "29875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumBouchesdurhonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium bouchesdurhonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumBouchesdurhonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720192.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720192.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720192.protein.info.v11.5.txt",
		        "node_list_path": "1720192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GracilibacillusBoraciitoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus boraciitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusBoraciitoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298598.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298598.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298598.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298598.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298598.protein.info.v11.5.txt",
		        "node_list_path": "1298598.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298598.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudarthrobacterSiccitolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudarthrobacter siccitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudarthrobacterSiccitolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "861266.protein.sequences.v11.5.fa",
		        "enrichment_path": "861266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861266.protein.info.v11.5.txt",
		        "node_list_path": "861266.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfonatronovibrioHydrogenovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronovibrio hydrogenovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronovibrioHydrogenovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121413.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121413.protein.info.v11.5.txt",
		        "node_list_path": "1121413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExserohilumTurcicaEt28aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exserohilum turcica Et28A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExserohilumTurcicaEt28aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "671987.clusters.info.v11.5.txt",
		        "cluster_tree_path": "671987.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "671987.clusters.proteins.v11.5.txt",
		        "sequence_path": "671987.protein.sequences.v11.5.fa",
		        "enrichment_path": "671987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "671987.protein.info.v11.5.txt",
		        "node_list_path": "671987.cluster.nodes.v11.5.txt",
		        "edge_list_path": "671987.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaAsperellumCbs43397Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma asperellum CBS 433.97 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaAsperellumCbs43397Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1042311.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1042311.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1042311.clusters.proteins.v11.5.txt",
		        "sequence_path": "1042311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042311.protein.info.v11.5.txt",
		        "node_list_path": "1042311.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1042311.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KordiimonasGwangyangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kordiimonas gwangyangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KordiimonasGwangyangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122137.protein.info.v11.5.txt",
		        "node_list_path": "1122137.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassiosiraPseudonana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassiosira pseudonana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassiosiraPseudonana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35128.protein.sequences.v11.5.fa",
		        "enrichment_path": "35128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35128.protein.info.v11.5.txt",
		        "node_list_path": "35128.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpNbimcp2c3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. NBIMCP2C3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpNbimcp2c3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1320556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1320556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1320556.protein.info.v11.5.txt",
		        "node_list_path": "1320556.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrancisellaSpW121067(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella sp. W121067 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaSpW121067", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385420.protein.info.v11.5.txt",
		        "node_list_path": "1385420.protein.complete.v11.5.txt"
		    }
		]
    )()

def CytophagaAurantiacaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cytophaga aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CytophagaAurantiacaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121373.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121373.protein.info.v11.5.txt",
		        "node_list_path": "1121373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaKroppenstedtii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia kroppenstedtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaKroppenstedtii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "468556.protein.sequences.v11.5.fa",
		        "enrichment_path": "468556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "468556.protein.info.v11.5.txt",
		        "node_list_path": "468556.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasAcidaminiphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas acidaminiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasAcidaminiphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "128780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "128780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "128780.clusters.proteins.v11.5.txt",
		        "sequence_path": "128780.protein.sequences.v11.5.fa",
		        "enrichment_path": "128780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "128780.protein.info.v11.5.txt",
		        "node_list_path": "128780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "128780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LonsdaleaPopuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lonsdalea populi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LonsdaleaPopuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1172565.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172565.protein.info.v11.5.txt",
		        "node_list_path": "1172565.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitratiruptorTergarcusDsm16512Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitratiruptor tergarcus DSM 16512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratiruptorTergarcusDsm16512Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1069081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1069081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1069081.clusters.proteins.v11.5.txt",
		        "sequence_path": "1069081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069081.protein.info.v11.5.txt",
		        "node_list_path": "1069081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1069081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3812b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_38_12b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3812b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802214.protein.info.v11.5.txt",
		        "node_list_path": "1802214.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobotryumSaponariaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbotryum saponariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobotryumSaponariaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "289078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "289078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "289078.clusters.proteins.v11.5.txt",
		        "sequence_path": "289078.protein.sequences.v11.5.fa",
		        "enrichment_path": "289078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "289078.protein.info.v11.5.txt",
		        "node_list_path": "289078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "289078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSpBa92Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. BA-92 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSpBa92Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1454003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1454003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1454003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1454003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454003.protein.info.v11.5.txt",
		        "node_list_path": "1454003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1454003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasIndicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasIndicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "137658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "137658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "137658.clusters.proteins.v11.5.txt",
		        "sequence_path": "137658.protein.sequences.v11.5.fa",
		        "enrichment_path": "137658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137658.protein.info.v11.5.txt",
		        "node_list_path": "137658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "137658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ScytonemaSpHk05Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scytonema sp. HK-05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScytonemaSpHk05Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1137095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1137095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1137095.clusters.proteins.v11.5.txt",
		        "sequence_path": "1137095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137095.protein.info.v11.5.txt",
		        "node_list_path": "1137095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1137095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EhrlichiaMurisAs145(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia muris AS145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EhrlichiaMurisAs145", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423892.protein.info.v11.5.txt",
		        "node_list_path": "1423892.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAc3007(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC3007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAc3007", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408322.protein.info.v11.5.txt",
		        "node_list_path": "1408322.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesMassiliensisB84634Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis B84634 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesMassiliensisB84634Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121098.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121098.protein.info.v11.5.txt",
		        "node_list_path": "1121098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicolaSpMctg156(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola sp. MCTG156 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaSpMctg156", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415756.protein.info.v11.5.txt",
		        "node_list_path": "1415756.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSlackiiAtcc49928(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces slackii ATCC 49928 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSlackiiAtcc49928", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278298.protein.info.v11.5.txt",
		        "node_list_path": "1278298.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot708(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root708 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot708", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736592.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736592.protein.info.v11.5.txt",
		        "node_list_path": "1736592.protein.complete.v11.5.txt"
		    }
		]
    )()

def YokenellaRegensburgeiAtcc43003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yokenella regensburgei ATCC 43003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YokenellaRegensburgeiAtcc43003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1002368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1002368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1002368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1002368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002368.protein.info.v11.5.txt",
		        "node_list_path": "1002368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1002368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumTermitidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium termitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTermitidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1195236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1195236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1195236.protein.info.v11.5.txt",
		        "node_list_path": "1195236.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusGrossensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus grossensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusGrossensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1465756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1465756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1465756.protein.info.v11.5.txt",
		        "node_list_path": "1465756.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumGwf24921(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_49_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumGwf24921", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798573.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798573.protein.info.v11.5.txt",
		        "node_list_path": "1798573.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterCelticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter celticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterCelticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1891224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891224.protein.info.v11.5.txt",
		        "node_list_path": "1891224.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGeothermarchaeotaArchaeonJdfr13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Geothermarchaeota archaeon JdFR-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGeothermarchaeotaArchaeonJdfr13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935120.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935120.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935120.protein.info.v11.5.txt",
		        "node_list_path": "1935120.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallibacteriumGenomosp3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. 3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallibacteriumGenomosp3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "505345.protein.sequences.v11.5.fa",
		        "enrichment_path": "505345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "505345.protein.info.v11.5.txt",
		        "node_list_path": "505345.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls474(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS474 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls474", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463909.protein.info.v11.5.txt",
		        "node_list_path": "1463909.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTpA0874(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TP-A0874 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTpA0874", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "549819.protein.sequences.v11.5.fa",
		        "enrichment_path": "549819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "549819.protein.info.v11.5.txt",
		        "node_list_path": "549819.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSimiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium simiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSimiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1784.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1784.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1784.clusters.proteins.v11.5.txt",
		        "sequence_path": "1784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1784.protein.info.v11.5.txt",
		        "node_list_path": "1784.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1784.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumAcapulense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium acapulense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumAcapulense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "114977.protein.sequences.v11.5.fa",
		        "enrichment_path": "114977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "114977.protein.info.v11.5.txt",
		        "node_list_path": "114977.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusObeumAtcc29174Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus obeum ATCC29174 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusObeumAtcc29174Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411459.clusters.proteins.v11.5.txt",
		        "sequence_path": "411459.protein.sequences.v11.5.fa",
		        "enrichment_path": "411459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411459.protein.info.v11.5.txt",
		        "node_list_path": "411459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumPygmaeumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium pygmaeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumPygmaeumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "370764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "370764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "370764.clusters.proteins.v11.5.txt",
		        "sequence_path": "370764.protein.sequences.v11.5.fa",
		        "enrichment_path": "370764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "370764.protein.info.v11.5.txt",
		        "node_list_path": "370764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "370764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusRadiodurans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus radiodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusRadiodurans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243230.protein.sequences.v11.5.fa",
		        "enrichment_path": "243230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243230.protein.info.v11.5.txt",
		        "node_list_path": "243230.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusBorealis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus borealis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusBorealis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "160799.protein.sequences.v11.5.fa",
		        "enrichment_path": "160799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "160799.protein.info.v11.5.txt",
		        "node_list_path": "160799.protein.complete.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterTroitsensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter troitsensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterTroitsensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "292222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "292222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "292222.clusters.proteins.v11.5.txt",
		        "sequence_path": "292222.protein.sequences.v11.5.fa",
		        "enrichment_path": "292222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292222.protein.info.v11.5.txt",
		        "node_list_path": "292222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "292222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriaSymbiontBfo2OfFrankliniellaOccidentalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo2 of Frankliniella occidentalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriaSymbiontBfo2OfFrankliniellaOccidentalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1628856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1628856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1628856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1628856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628856.protein.info.v11.5.txt",
		        "node_list_path": "1628856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1628856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumUliginosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium uliginosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumUliginosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "119641.protein.sequences.v11.5.fa",
		        "enrichment_path": "119641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "119641.protein.info.v11.5.txt",
		        "node_list_path": "119641.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchistosomaJaponicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma japonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaJaponicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6182.protein.sequences.v11.5.fa",
		        "enrichment_path": "6182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6182.protein.info.v11.5.txt",
		        "node_list_path": "6182.protein.complete.v11.5.txt"
		    }
		]
    )()

def AchromobacterSpRoot83(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter sp. Root83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterSpRoot83", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736602.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736602.protein.info.v11.5.txt",
		        "node_list_path": "1736602.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaPestisCo92Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia pestis CO92 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaPestisCo92Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "214092.clusters.info.v11.5.txt",
		        "cluster_tree_path": "214092.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "214092.clusters.proteins.v11.5.txt",
		        "sequence_path": "214092.protein.sequences.v11.5.fa",
		        "enrichment_path": "214092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "214092.protein.info.v11.5.txt",
		        "node_list_path": "214092.cluster.nodes.v11.5.txt",
		        "edge_list_path": "214092.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusAcidiphilusNbrc100859Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidiphilus NBRC 100859 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusAcidiphilusNbrc100859Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1255277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1255277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1255277.clusters.proteins.v11.5.txt",
		        "sequence_path": "1255277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1255277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1255277.protein.info.v11.5.txt",
		        "node_list_path": "1255277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1255277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetragenococcusSolitariusNbrc100494Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetragenococcus solitarius NBRC 100494 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetragenococcusSolitariusNbrc100494Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223494.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223494.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223494.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223494.protein.info.v11.5.txt",
		        "node_list_path": "1223494.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223494.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumPullorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pullorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumPullorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437600.protein.info.v11.5.txt",
		        "node_list_path": "1437600.protein.complete.v11.5.txt"
		    }
		]
    )()

def EutremaSalsugineumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eutrema salsugineum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EutremaSalsugineumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "72664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "72664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "72664.clusters.proteins.v11.5.txt",
		        "sequence_path": "72664.protein.sequences.v11.5.fa",
		        "enrichment_path": "72664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72664.protein.info.v11.5.txt",
		        "node_list_path": "72664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "72664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CharadriusVociferusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Charadrius vociferus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CharadriusVociferusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "50402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "50402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "50402.clusters.proteins.v11.5.txt",
		        "sequence_path": "50402.protein.sequences.v11.5.fa",
		        "enrichment_path": "50402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50402.protein.info.v11.5.txt",
		        "node_list_path": "50402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "50402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumGallinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumGallinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1324352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1324352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1324352.clusters.proteins.v11.5.txt",
		        "sequence_path": "1324352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1324352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1324352.protein.info.v11.5.txt",
		        "node_list_path": "1324352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1324352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaUdeisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia udeis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaUdeisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232866.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232866.protein.info.v11.5.txt",
		        "node_list_path": "1232866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumRbg19ftCombo6530(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_19FT_COMBO_65_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg19ftCombo6530", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797277.protein.info.v11.5.txt",
		        "node_list_path": "1797277.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5620Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_56_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5620Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798652.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798652.protein.info.v11.5.txt",
		        "node_list_path": "1798652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanosalsumZhilinaeDsm4017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosalsum zhilinae DSM 4017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosalsumZhilinaeDsm4017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679901.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679901.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679901.clusters.proteins.v11.5.txt",
		        "sequence_path": "679901.protein.sequences.v11.5.fa",
		        "enrichment_path": "679901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679901.protein.info.v11.5.txt",
		        "node_list_path": "679901.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679901.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AngustibacterSpRoot456Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Angustibacter sp. Root456 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AngustibacterSpRoot456Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736539.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736539.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736539.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736539.protein.info.v11.5.txt",
		        "node_list_path": "1736539.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736539.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MobilicoccusPelagiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobilicoccus pelagius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobilicoccusPelagiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089455.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089455.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089455.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089455.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089455.protein.info.v11.5.txt",
		        "node_list_path": "1089455.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089455.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumMagnetotacticumMs1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum magnetotacticum MS-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumMagnetotacticumMs1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272627.protein.sequences.v11.5.fa",
		        "enrichment_path": "272627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272627.protein.info.v11.5.txt",
		        "node_list_path": "272627.protein.complete.v11.5.txt"
		    }
		]
    )()

def UstilagoHordeiUh48574(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ustilago hordei Uh4857-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UstilagoHordeiUh48574", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1128400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128400.protein.info.v11.5.txt",
		        "node_list_path": "1128400.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallibacteriumGenomosp3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. 3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallibacteriumGenomosp3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "505345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "505345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "505345.clusters.proteins.v11.5.txt",
		        "sequence_path": "505345.protein.sequences.v11.5.fa",
		        "enrichment_path": "505345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "505345.protein.info.v11.5.txt",
		        "node_list_path": "505345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "505345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BombellaIntestiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bombella intestini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BombellaIntestiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1539051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1539051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1539051.clusters.proteins.v11.5.txt",
		        "sequence_path": "1539051.protein.sequences.v11.5.fa",
		        "enrichment_path": "1539051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1539051.protein.info.v11.5.txt",
		        "node_list_path": "1539051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1539051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumSpP610X1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium sp. P6-10-X1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumSpP610X1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1903186.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903186.protein.info.v11.5.txt",
		        "node_list_path": "1903186.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpAb308(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpAb308", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841859.protein.info.v11.5.txt",
		        "node_list_path": "1841859.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaGarinii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia garinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaGarinii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290434.protein.sequences.v11.5.fa",
		        "enrichment_path": "290434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290434.protein.info.v11.5.txt",
		        "node_list_path": "290434.protein.complete.v11.5.txt"
		    }
		]
    )()

def IxodesScapularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ixodes scapularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IxodesScapularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6945.protein.sequences.v11.5.fa",
		        "enrichment_path": "6945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6945.protein.info.v11.5.txt",
		        "node_list_path": "6945.protein.complete.v11.5.txt"
		    }
		]
    )()

def TremellaMesenterica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tremella mesenterica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TremellaMesenterica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5217.protein.sequences.v11.5.fa",
		        "enrichment_path": "5217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5217.protein.info.v11.5.txt",
		        "node_list_path": "5217.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusDextrinicusDsm20335Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus dextrinicus DSM 20335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusDextrinicusDsm20335Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423738.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423738.protein.info.v11.5.txt",
		        "node_list_path": "1423738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasSpNm51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasSpNm51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "133720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "133720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "133720.clusters.proteins.v11.5.txt",
		        "sequence_path": "133720.protein.sequences.v11.5.fa",
		        "enrichment_path": "133720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133720.protein.info.v11.5.txt",
		        "node_list_path": "133720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "133720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaPseudoobscuraPseudoobscura(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila pseudoobscura pseudoobscura graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaPseudoobscuraPseudoobscura", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46245.protein.sequences.v11.5.fa",
		        "enrichment_path": "46245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46245.protein.info.v11.5.txt",
		        "node_list_path": "46245.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacillusSpOk032(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacillus sp. OK032 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacillusSpOk032", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884358.protein.info.v11.5.txt",
		        "node_list_path": "1884358.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillatoriaNigroviridisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoria nigroviridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillatoriaNigroviridisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "179408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "179408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "179408.clusters.proteins.v11.5.txt",
		        "sequence_path": "179408.protein.sequences.v11.5.fa",
		        "enrichment_path": "179408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "179408.protein.info.v11.5.txt",
		        "node_list_path": "179408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "179408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VogesellaSpEbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vogesella sp. EB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VogesellaSpEbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1526735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1526735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1526735.clusters.proteins.v11.5.txt",
		        "sequence_path": "1526735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1526735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1526735.protein.info.v11.5.txt",
		        "node_list_path": "1526735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1526735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RodentibacterMyodis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter myodis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterMyodis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907939.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907939.protein.info.v11.5.txt",
		        "node_list_path": "1907939.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliellaAfzelii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borreliella afzelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliellaAfzelii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29518.protein.sequences.v11.5.fa",
		        "enrichment_path": "29518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29518.protein.info.v11.5.txt",
		        "node_list_path": "29518.protein.complete.v11.5.txt"
		    }
		]
    )()

def LipomycesStarkeyiNrrlY11557(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lipomyces starkeyi NRRL Y-11557 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LipomycesStarkeyiNrrlY11557", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675824.protein.sequences.v11.5.fa",
		        "enrichment_path": "675824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675824.protein.info.v11.5.txt",
		        "node_list_path": "675824.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesXylanisolvens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides xylanisolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesXylanisolvens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "657309.protein.sequences.v11.5.fa",
		        "enrichment_path": "657309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657309.protein.info.v11.5.txt",
		        "node_list_path": "657309.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag58(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag58", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262824.protein.info.v11.5.txt",
		        "node_list_path": "1262824.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhycicoccusDokdonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phycicoccus dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycicoccusDokdonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "443156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "443156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "443156.clusters.proteins.v11.5.txt",
		        "sequence_path": "443156.protein.sequences.v11.5.fa",
		        "enrichment_path": "443156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443156.protein.info.v11.5.txt",
		        "node_list_path": "443156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "443156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4925(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_49_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4925", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802701.protein.info.v11.5.txt",
		        "node_list_path": "1802701.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinokineosporaEnzanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora enzanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinokineosporaEnzanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120934.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120934.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120934.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120934.protein.info.v11.5.txt",
		        "node_list_path": "1120934.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120934.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GloeocapsaSpPcc7428(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gloeocapsa sp. PCC7428 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeocapsaSpPcc7428", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173026.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173026.protein.info.v11.5.txt",
		        "node_list_path": "1173026.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaCrassostreae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia crassostreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaCrassostreae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53428.protein.sequences.v11.5.fa",
		        "enrichment_path": "53428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53428.protein.info.v11.5.txt",
		        "node_list_path": "53428.protein.complete.v11.5.txt"
		    }
		]
    )()

def GluconacetobacterSpSxcc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gluconacetobacter sp. SXCC-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconacetobacterSpSxcc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1004836.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004836.protein.info.v11.5.txt",
		        "node_list_path": "1004836.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusNigerAtcc1015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus niger ATCC 1015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusNigerAtcc1015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "380704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "380704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "380704.clusters.proteins.v11.5.txt",
		        "sequence_path": "380704.protein.sequences.v11.5.fa",
		        "enrichment_path": "380704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380704.protein.info.v11.5.txt",
		        "node_list_path": "380704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "380704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyellaThiooxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyella thiooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaThiooxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445710.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445710.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445710.clusters.proteins.v11.5.txt",
		        "sequence_path": "445710.protein.sequences.v11.5.fa",
		        "enrichment_path": "445710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445710.protein.info.v11.5.txt",
		        "node_list_path": "445710.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445710.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAnatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma anatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAnatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1034808.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1034808.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1034808.clusters.proteins.v11.5.txt",
		        "sequence_path": "1034808.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034808.protein.info.v11.5.txt",
		        "node_list_path": "1034808.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1034808.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiolapillusBrandeum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiolapillus brandeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiolapillusBrandeum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1076588.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076588.protein.info.v11.5.txt",
		        "node_list_path": "1076588.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisJaponicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisJaponicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "208439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "208439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "208439.clusters.proteins.v11.5.txt",
		        "sequence_path": "208439.protein.sequences.v11.5.fa",
		        "enrichment_path": "208439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208439.protein.info.v11.5.txt",
		        "node_list_path": "208439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "208439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaAmmonioxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia ammonioxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaAmmonioxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "260086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "260086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "260086.clusters.proteins.v11.5.txt",
		        "sequence_path": "260086.protein.sequences.v11.5.fa",
		        "enrichment_path": "260086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "260086.protein.info.v11.5.txt",
		        "node_list_path": "260086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "260086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaSalinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina salinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaSalinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "435908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "435908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "435908.clusters.proteins.v11.5.txt",
		        "sequence_path": "435908.protein.sequences.v11.5.fa",
		        "enrichment_path": "435908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435908.protein.info.v11.5.txt",
		        "node_list_path": "435908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "435908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumTardaugens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium tardaugens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumTardaugens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219035.protein.info.v11.5.txt",
		        "node_list_path": "1219035.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasSchubertii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas schubertii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSchubertii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "652.protein.sequences.v11.5.fa",
		        "enrichment_path": "652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "652.protein.info.v11.5.txt",
		        "node_list_path": "652.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpMst1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. MSt1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpMst1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1501230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1501230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1501230.protein.info.v11.5.txt",
		        "node_list_path": "1501230.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusMacquariensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus macquariensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusMacquariensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "948756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "948756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "948756.clusters.proteins.v11.5.txt",
		        "sequence_path": "948756.protein.sequences.v11.5.fa",
		        "enrichment_path": "948756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "948756.protein.info.v11.5.txt",
		        "node_list_path": "948756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "948756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaAsymbiotica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia asymbiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaAsymbiotica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834516.protein.info.v11.5.txt",
		        "node_list_path": "1834516.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseivivaxHaloduransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax halodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxHaloduransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449350.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449350.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449350.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449350.protein.info.v11.5.txt",
		        "node_list_path": "1449350.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449350.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnothrixRoseaIamM220(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnothrix rosea IAM M-220 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnothrixRoseaIamM220", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "454133.protein.sequences.v11.5.fa",
		        "enrichment_path": "454133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454133.protein.info.v11.5.txt",
		        "node_list_path": "454133.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacterium13220cm5827(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_2_20CM_58_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacterium13220cm5827", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803466.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803466.protein.info.v11.5.txt",
		        "node_list_path": "1803466.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrusXBretschneideri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrus x bretschneideri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrusXBretschneideri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "225117.protein.sequences.v11.5.fa",
		        "enrichment_path": "225117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225117.protein.info.v11.5.txt",
		        "node_list_path": "225117.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlantibacterSpLeaf314Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plantibacter sp. Leaf314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlantibacterSpLeaf314Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736333.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736333.protein.info.v11.5.txt",
		        "node_list_path": "1736333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsaiaBogorensisNbrc16594Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asaia bogorensis NBRC 16594 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsaiaBogorensisNbrc16594Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231624.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231624.protein.info.v11.5.txt",
		        "node_list_path": "1231624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807749.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807749.protein.info.v11.5.txt",
		        "node_list_path": "1807749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptococcusGattiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus gattii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptococcusGattiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "552467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "552467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "552467.clusters.proteins.v11.5.txt",
		        "sequence_path": "552467.protein.sequences.v11.5.fa",
		        "enrichment_path": "552467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "552467.protein.info.v11.5.txt",
		        "node_list_path": "552467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "552467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumSpSma27Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium sp. SMA-27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumSpSma27Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1495336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1495336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1495336.clusters.proteins.v11.5.txt",
		        "sequence_path": "1495336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495336.protein.info.v11.5.txt",
		        "node_list_path": "1495336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1495336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiaceaeBacteriumGa0074131Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobiaceae bacterium Ga0074131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiaceaeBacteriumGa0074131Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752203.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752203.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752203.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752203.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752203.protein.info.v11.5.txt",
		        "node_list_path": "1752203.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752203.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusHaemolyticusM19501(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M19501 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusHaemolyticusM19501", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1028803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028803.protein.info.v11.5.txt",
		        "node_list_path": "1028803.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMustelae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium mustelae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMustelae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "571915.protein.sequences.v11.5.fa",
		        "enrichment_path": "571915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571915.protein.info.v11.5.txt",
		        "node_list_path": "571915.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc24417Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC2_44_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc24417Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618929.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618929.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618929.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618929.protein.info.v11.5.txt",
		        "node_list_path": "1618929.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618929.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSp7sr1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. 7SR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSp7sr1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881017.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881017.protein.info.v11.5.txt",
		        "node_list_path": "1881017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerotignumNeopropionicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerotignum neopropionicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerotignumNeopropionicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36847.protein.sequences.v11.5.fa",
		        "enrichment_path": "36847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36847.protein.info.v11.5.txt",
		        "node_list_path": "36847.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulforegulaConservatrix(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulforegula conservatrix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulforegulaConservatrix", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304885.protein.info.v11.5.txt",
		        "node_list_path": "1304885.protein.complete.v11.5.txt"
		    }
		]
    )()

def XiphophorusCouchianus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xiphophorus couchianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XiphophorusCouchianus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32473.protein.sequences.v11.5.fa",
		        "enrichment_path": "32473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32473.protein.info.v11.5.txt",
		        "node_list_path": "32473.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeoasaiaChiangmaiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neoasaia chiangmaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeoasaiaChiangmaiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "320497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "320497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "320497.clusters.proteins.v11.5.txt",
		        "sequence_path": "320497.protein.sequences.v11.5.fa",
		        "enrichment_path": "320497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "320497.protein.info.v11.5.txt",
		        "node_list_path": "320497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "320497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesResistomycificusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces resistomycificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesResistomycificusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67356.clusters.proteins.v11.5.txt",
		        "sequence_path": "67356.protein.sequences.v11.5.fa",
		        "enrichment_path": "67356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67356.protein.info.v11.5.txt",
		        "node_list_path": "67356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchistosomaMattheeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma mattheei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaMattheeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "31246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "31246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "31246.clusters.proteins.v11.5.txt",
		        "sequence_path": "31246.protein.sequences.v11.5.fa",
		        "enrichment_path": "31246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31246.protein.info.v11.5.txt",
		        "node_list_path": "31246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "31246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapitellaTeleta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capitella teleta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapitellaTeleta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "283909.protein.sequences.v11.5.fa",
		        "enrichment_path": "283909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283909.protein.info.v11.5.txt",
		        "node_list_path": "283909.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263017.protein.info.v11.5.txt",
		        "node_list_path": "1263017.protein.complete.v11.5.txt"
		    }
		]
    )()

def CladophialophoraYegresiiCbs114405Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora yegresii CBS 114405 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CladophialophoraYegresiiCbs114405Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1182544.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1182544.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1182544.clusters.proteins.v11.5.txt",
		        "sequence_path": "1182544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182544.protein.info.v11.5.txt",
		        "node_list_path": "1182544.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1182544.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusJohnsonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus johnsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusJohnsonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "257314.protein.sequences.v11.5.fa",
		        "enrichment_path": "257314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "257314.protein.info.v11.5.txt",
		        "node_list_path": "257314.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinococcusHalotoleransDsm16375(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinococcus halotolerans DSM 16375 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinococcusHalotoleransDsm16375", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122203.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122203.protein.info.v11.5.txt",
		        "node_list_path": "1122203.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinum202f(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum 202F graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinum202f", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415774.protein.info.v11.5.txt",
		        "node_list_path": "1415774.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonadalesBacterium66474Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 66-474 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonadalesBacterium66474Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895868.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895868.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895868.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895868.protein.info.v11.5.txt",
		        "node_list_path": "1895868.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895868.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumDiphtheriaeNctc13129(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium diphtheriae NCTC 13129 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumDiphtheriaeNctc13129", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "257309.protein.sequences.v11.5.fa",
		        "enrichment_path": "257309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "257309.protein.info.v11.5.txt",
		        "node_list_path": "257309.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpLeaf183(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. Leaf183 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpLeaf183", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736291.protein.info.v11.5.txt",
		        "node_list_path": "1736291.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpH053Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H053 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpH053Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1759067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1759067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1759067.clusters.proteins.v11.5.txt",
		        "sequence_path": "1759067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759067.protein.info.v11.5.txt",
		        "node_list_path": "1759067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1759067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "397288.protein.sequences.v11.5.fa",
		        "enrichment_path": "397288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397288.protein.info.v11.5.txt",
		        "node_list_path": "397288.protein.complete.v11.5.txt"
		    }
		]
    )()

def CloacimonetesBacteriumScgcAaa252P10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium SCGC AAA252-P10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CloacimonetesBacteriumScgcAaa252P10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1046972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046972.protein.info.v11.5.txt",
		        "node_list_path": "1046972.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumSpNcppb925Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. NCPPB 925 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumSpNcppb925Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1631629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1631629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1631629.clusters.proteins.v11.5.txt",
		        "sequence_path": "1631629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1631629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1631629.protein.info.v11.5.txt",
		        "node_list_path": "1631629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1631629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucorCircinelloidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucorCircinelloidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36080.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36080.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36080.clusters.proteins.v11.5.txt",
		        "sequence_path": "36080.protein.sequences.v11.5.fa",
		        "enrichment_path": "36080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36080.protein.info.v11.5.txt",
		        "node_list_path": "36080.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36080.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNk4a136Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNk4a136Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "877420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "877420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "877420.clusters.proteins.v11.5.txt",
		        "sequence_path": "877420.protein.sequences.v11.5.fa",
		        "enrichment_path": "877420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877420.protein.info.v11.5.txt",
		        "node_list_path": "877420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "877420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumRifcsplowo201Full4818Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPLOWO2_01_FULL_48_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsplowo201Full4818Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817743.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817743.protein.info.v11.5.txt",
		        "node_list_path": "1817743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChristensenellaceaeBacteriumPhil1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Christensenellaceae bacterium Phil1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChristensenellaceaeBacteriumPhil1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930012.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930012.protein.info.v11.5.txt",
		        "node_list_path": "1930012.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemellaAsaccharolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemella asaccharolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaAsaccharolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "502393.protein.sequences.v11.5.fa",
		        "enrichment_path": "502393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502393.protein.info.v11.5.txt",
		        "node_list_path": "502393.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucosisporaSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucosispora sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucosisporaSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "547162.clusters.info.v11.5.txt",
		        "cluster_tree_path": "547162.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "547162.clusters.proteins.v11.5.txt",
		        "sequence_path": "547162.protein.sequences.v11.5.fa",
		        "enrichment_path": "547162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547162.protein.info.v11.5.txt",
		        "node_list_path": "547162.cluster.nodes.v11.5.txt",
		        "edge_list_path": "547162.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRbg165624Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_56_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRbg165624Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797475.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797475.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797475.protein.info.v11.5.txt",
		        "node_list_path": "1797475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaAestuariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaAestuariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "327095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "327095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "327095.clusters.proteins.v11.5.txt",
		        "sequence_path": "327095.protein.sequences.v11.5.fa",
		        "enrichment_path": "327095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "327095.protein.info.v11.5.txt",
		        "node_list_path": "327095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "327095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ValsaSordidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Valsa sordida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ValsaSordidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "252740.clusters.info.v11.5.txt",
		        "cluster_tree_path": "252740.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "252740.clusters.proteins.v11.5.txt",
		        "sequence_path": "252740.protein.sequences.v11.5.fa",
		        "enrichment_path": "252740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "252740.protein.info.v11.5.txt",
		        "node_list_path": "252740.cluster.nodes.v11.5.txt",
		        "edge_list_path": "252740.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GalbibacterMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Galbibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GalbibacterMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "555500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "555500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "555500.clusters.proteins.v11.5.txt",
		        "sequence_path": "555500.protein.sequences.v11.5.fa",
		        "enrichment_path": "555500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555500.protein.info.v11.5.txt",
		        "node_list_path": "555500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "555500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasMandelii36mfcvi11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mandelii 36MFCvi11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMandelii36mfcvi11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1151127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1151127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1151127.clusters.proteins.v11.5.txt",
		        "sequence_path": "1151127.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151127.protein.info.v11.5.txt",
		        "node_list_path": "1151127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1151127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaZhejiangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia zhejiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaZhejiangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "871203.protein.sequences.v11.5.fa",
		        "enrichment_path": "871203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871203.protein.info.v11.5.txt",
		        "node_list_path": "871203.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaLacunaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia lacunae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaLacunaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "417102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "417102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "417102.clusters.proteins.v11.5.txt",
		        "sequence_path": "417102.protein.sequences.v11.5.fa",
		        "enrichment_path": "417102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "417102.protein.info.v11.5.txt",
		        "node_list_path": "417102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "417102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusVogelbacteriaBacteriumRifoxyd1Full5118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_51_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full5118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802440.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802440.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802440.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802440.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802440.protein.info.v11.5.txt",
		        "node_list_path": "1802440.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802440.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumGraminicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum graminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumGraminicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "31870.protein.sequences.v11.5.fa",
		        "enrichment_path": "31870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31870.protein.info.v11.5.txt",
		        "node_list_path": "31870.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesOleiciplenus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides oleiciplenus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesOleiciplenus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742727.protein.sequences.v11.5.fa",
		        "enrichment_path": "742727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742727.protein.info.v11.5.txt",
		        "node_list_path": "742727.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterNanhaiticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter nanhaiticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterNanhaiticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "626887.clusters.info.v11.5.txt",
		        "cluster_tree_path": "626887.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "626887.clusters.proteins.v11.5.txt",
		        "sequence_path": "626887.protein.sequences.v11.5.fa",
		        "enrichment_path": "626887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626887.protein.info.v11.5.txt",
		        "node_list_path": "626887.cluster.nodes.v11.5.txt",
		        "edge_list_path": "626887.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSediminicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora sediminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSediminicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "946078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "946078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "946078.clusters.proteins.v11.5.txt",
		        "sequence_path": "946078.protein.sequences.v11.5.fa",
		        "enrichment_path": "946078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946078.protein.info.v11.5.txt",
		        "node_list_path": "946078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "946078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColibacterMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colibacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColibacterMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852379.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852379.protein.info.v11.5.txt",
		        "node_list_path": "1852379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaIntermedia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia intermedia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaIntermedia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349965.protein.sequences.v11.5.fa",
		        "enrichment_path": "349965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349965.protein.info.v11.5.txt",
		        "node_list_path": "349965.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyadobacterSpSg02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter sp. SG02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterSpSg02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855291.protein.info.v11.5.txt",
		        "node_list_path": "1855291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyadobacterSp5039(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter sp. 50-39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterSp5039", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895756.protein.info.v11.5.txt",
		        "node_list_path": "1895756.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesBacteriumScgcAaa011L6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates bacterium SCGC AAA011-L6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesBacteriumScgcAaa011L6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "699262.protein.sequences.v11.5.fa",
		        "enrichment_path": "699262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "699262.protein.info.v11.5.txt",
		        "node_list_path": "699262.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchaedlerellaArabinosiphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schaedlerella arabinosiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchaedlerellaArabinosiphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2044587.protein.sequences.v11.5.fa",
		        "enrichment_path": "2044587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2044587.protein.info.v11.5.txt",
		        "node_list_path": "2044587.protein.complete.v11.5.txt"
		    }
		]
    )()

def RalstoniaEutrophaH16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia eutropha H16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaEutrophaH16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "381666.protein.sequences.v11.5.fa",
		        "enrichment_path": "381666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381666.protein.info.v11.5.txt",
		        "node_list_path": "381666.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusProteolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus proteolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusProteolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "693977.clusters.info.v11.5.txt",
		        "cluster_tree_path": "693977.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "693977.clusters.proteins.v11.5.txt",
		        "sequence_path": "693977.protein.sequences.v11.5.fa",
		        "enrichment_path": "693977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693977.protein.info.v11.5.txt",
		        "node_list_path": "693977.cluster.nodes.v11.5.txt",
		        "edge_list_path": "693977.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DoreaFormicigeneransAtcc27755Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea formicigenerans ATCC27755 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaFormicigeneransAtcc27755Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411461.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411461.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411461.clusters.proteins.v11.5.txt",
		        "sequence_path": "411461.protein.sequences.v11.5.fa",
		        "enrichment_path": "411461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411461.protein.info.v11.5.txt",
		        "node_list_path": "411461.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411461.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioAnguillarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio anguillarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioAnguillarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "55601.clusters.info.v11.5.txt",
		        "cluster_tree_path": "55601.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "55601.clusters.proteins.v11.5.txt",
		        "sequence_path": "55601.protein.sequences.v11.5.fa",
		        "enrichment_path": "55601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55601.protein.info.v11.5.txt",
		        "node_list_path": "55601.cluster.nodes.v11.5.txt",
		        "edge_list_path": "55601.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeminocystisSpNies3709(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geminocystis sp. NIES-3709 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeminocystisSpNies3709", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617448.protein.info.v11.5.txt",
		        "node_list_path": "1617448.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylacidiphilumKamchatkenseKam1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylacidiphilum kamchatkense Kam1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylacidiphilumKamchatkenseKam1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1202785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202785.protein.info.v11.5.txt",
		        "node_list_path": "1202785.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanotheceSpCcy0110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. CCY0110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanotheceSpCcy0110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391612.clusters.proteins.v11.5.txt",
		        "sequence_path": "391612.protein.sequences.v11.5.fa",
		        "enrichment_path": "391612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391612.protein.info.v11.5.txt",
		        "node_list_path": "391612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EchinococcusMultilocularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Echinococcus multilocularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EchinococcusMultilocularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6211.protein.sequences.v11.5.fa",
		        "enrichment_path": "6211.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6211.protein.info.v11.5.txt",
		        "node_list_path": "6211.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyosynoviae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyosynoviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyosynoviae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29559.protein.sequences.v11.5.fa",
		        "enrichment_path": "29559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29559.protein.info.v11.5.txt",
		        "node_list_path": "29559.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylohalobiusCrimeensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylohalobius crimeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylohalobiusCrimeensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1283300.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1283300.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1283300.clusters.proteins.v11.5.txt",
		        "sequence_path": "1283300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283300.protein.info.v11.5.txt",
		        "node_list_path": "1283300.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1283300.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumOxalicum1142Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium oxalicum 114-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumOxalicum1142Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "933388.clusters.info.v11.5.txt",
		        "cluster_tree_path": "933388.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "933388.clusters.proteins.v11.5.txt",
		        "sequence_path": "933388.protein.sequences.v11.5.fa",
		        "enrichment_path": "933388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933388.protein.info.v11.5.txt",
		        "node_list_path": "933388.cluster.nodes.v11.5.txt",
		        "edge_list_path": "933388.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZymomonasMobilisZm4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymomonas mobilis ZM4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymomonasMobilisZm4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264203.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264203.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264203.clusters.proteins.v11.5.txt",
		        "sequence_path": "264203.protein.sequences.v11.5.fa",
		        "enrichment_path": "264203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264203.protein.info.v11.5.txt",
		        "node_list_path": "264203.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264203.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PirellulaSpShSr6aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pirellula sp. SH-Sr6A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PirellulaSpShSr6aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1632865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1632865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1632865.clusters.proteins.v11.5.txt",
		        "sequence_path": "1632865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1632865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1632865.protein.info.v11.5.txt",
		        "node_list_path": "1632865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1632865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLpu83Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. LPU83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLpu83Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "348824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "348824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "348824.clusters.proteins.v11.5.txt",
		        "sequence_path": "348824.protein.sequences.v11.5.fa",
		        "enrichment_path": "348824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "348824.protein.info.v11.5.txt",
		        "node_list_path": "348824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "348824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusCristatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus cristatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusCristatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573508.protein.sequences.v11.5.fa",
		        "enrichment_path": "573508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573508.protein.info.v11.5.txt",
		        "node_list_path": "573508.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumPseudolongumPv82Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum PV8-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumPseudolongumPv82Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1447715.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1447715.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1447715.clusters.proteins.v11.5.txt",
		        "sequence_path": "1447715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1447715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1447715.protein.info.v11.5.txt",
		        "node_list_path": "1447715.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1447715.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesAtroparvus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles atroparvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesAtroparvus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "41427.protein.sequences.v11.5.fa",
		        "enrichment_path": "41427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41427.protein.info.v11.5.txt",
		        "node_list_path": "41427.protein.complete.v11.5.txt"
		    }
		]
    )()

def MixiaOsmundaeIam14324(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mixia osmundae IAM 14324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MixiaOsmundaeIam14324", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "764103.protein.sequences.v11.5.fa",
		        "enrichment_path": "764103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "764103.protein.info.v11.5.txt",
		        "node_list_path": "764103.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusShapirobacteriaBacteriumGw2011Gwf23720Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium GW2011_GWF2_37_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusShapirobacteriaBacteriumGw2011Gwf23720Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618492.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618492.protein.info.v11.5.txt",
		        "node_list_path": "1618492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3744(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYB1_FULL_37_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3744", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802223.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802223.protein.info.v11.5.txt",
		        "node_list_path": "1802223.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtopococcusTabaciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopococcus tabaci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopococcusTabaciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121024.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121024.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121024.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121024.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121024.protein.info.v11.5.txt",
		        "node_list_path": "1121024.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121024.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GilliamellaIntestiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gilliamella intestini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilliamellaIntestiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798183.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798183.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798183.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798183.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798183.protein.info.v11.5.txt",
		        "node_list_path": "1798183.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798183.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudolabrysSpRoot1462(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudolabrys sp. Root1462 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudolabrysSpRoot1462", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736466.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736466.protein.info.v11.5.txt",
		        "node_list_path": "1736466.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSinaloensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sinaloensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSinaloensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "945550.protein.sequences.v11.5.fa",
		        "enrichment_path": "945550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "945550.protein.info.v11.5.txt",
		        "node_list_path": "945550.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZosteraMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zostera marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZosteraMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29655.protein.sequences.v11.5.fa",
		        "enrichment_path": "29655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29655.protein.info.v11.5.txt",
		        "node_list_path": "29655.protein.complete.v11.5.txt"
		    }
		]
    )()

def MelghirimycesThermohalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Melghirimyces thermohalophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MelghirimycesThermohalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236220.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236220.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236220.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236220.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236220.protein.info.v11.5.txt",
		        "node_list_path": "1236220.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236220.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAcetobutylicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acetobutylicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAcetobutylicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272562.protein.sequences.v11.5.fa",
		        "enrichment_path": "272562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272562.protein.info.v11.5.txt",
		        "node_list_path": "272562.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParasporobacteriumPaucivoransDsm15970Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parasporobacterium paucivorans DSM 15970 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParasporobacteriumPaucivoransDsm15970Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122934.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122934.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122934.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122934.protein.info.v11.5.txt",
		        "node_list_path": "1122934.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122934.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpKbs0703(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. KBS0703 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpKbs0703", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1955698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1955698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1955698.protein.info.v11.5.txt",
		        "node_list_path": "1955698.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpRoot186(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root186 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpRoot186", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736485.protein.info.v11.5.txt",
		        "node_list_path": "1736485.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaElizabethae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella elizabethae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaElizabethae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408427.protein.info.v11.5.txt",
		        "node_list_path": "1408427.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRifcsphigho201Full4029Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFCSPHIGHO2_01_FULL_40_29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRifcsphigho201Full4029Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797389.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797389.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797389.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797389.protein.info.v11.5.txt",
		        "node_list_path": "1797389.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797389.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpXbb1001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. XBB1001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpXbb1001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280682.protein.info.v11.5.txt",
		        "node_list_path": "1280682.protein.complete.v11.5.txt"
		    }
		]
    )()

def PoeciliaMexicana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Poecilia mexicana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PoeciliaMexicana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "48701.protein.sequences.v11.5.fa",
		        "enrichment_path": "48701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48701.protein.info.v11.5.txt",
		        "node_list_path": "48701.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpMed152(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. MED152 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpMed152", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313598.protein.sequences.v11.5.fa",
		        "enrichment_path": "313598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313598.protein.info.v11.5.txt",
		        "node_list_path": "313598.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpBay1663Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BAY1663 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpBay1663Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1439940.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1439940.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1439940.clusters.proteins.v11.5.txt",
		        "sequence_path": "1439940.protein.sequences.v11.5.fa",
		        "enrichment_path": "1439940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1439940.protein.info.v11.5.txt",
		        "node_list_path": "1439940.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1439940.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaBusckiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila busckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaBusckiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "30019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "30019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "30019.clusters.proteins.v11.5.txt",
		        "sequence_path": "30019.protein.sequences.v11.5.fa",
		        "enrichment_path": "30019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30019.protein.info.v11.5.txt",
		        "node_list_path": "30019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "30019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PucciniaGraminisFSpTriticiCrl75367003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Puccinia graminis f. sp. tritici CRL 75-36-700-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PucciniaGraminisFSpTriticiCrl75367003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "418459.protein.sequences.v11.5.fa",
		        "enrichment_path": "418459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "418459.protein.info.v11.5.txt",
		        "node_list_path": "418459.protein.complete.v11.5.txt"
		    }
		]
    )()

def CinnamomumMicranthumFKanehiraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cinnamomum micranthum f. kanehirae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CinnamomumMicranthumFKanehiraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "337451.clusters.info.v11.5.txt",
		        "cluster_tree_path": "337451.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "337451.clusters.proteins.v11.5.txt",
		        "sequence_path": "337451.protein.sequences.v11.5.fa",
		        "enrichment_path": "337451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "337451.protein.info.v11.5.txt",
		        "node_list_path": "337451.cluster.nodes.v11.5.txt",
		        "edge_list_path": "337451.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpAe3006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpAe3006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280673.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280673.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280673.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280673.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280673.protein.info.v11.5.txt",
		        "node_list_path": "1280673.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280673.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AciduliprofundumSpMar08339Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aciduliprofundum sp. MAR08339 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AciduliprofundumSpMar08339Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "673860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "673860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "673860.clusters.proteins.v11.5.txt",
		        "sequence_path": "673860.protein.sequences.v11.5.fa",
		        "enrichment_path": "673860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "673860.protein.info.v11.5.txt",
		        "node_list_path": "673860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "673860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaHarzianumCbs22695(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma harzianum CBS 226.95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaHarzianumCbs22695", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983964.protein.sequences.v11.5.fa",
		        "enrichment_path": "983964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983964.protein.info.v11.5.txt",
		        "node_list_path": "983964.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpNd2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ND2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpNd2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1347366.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1347366.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1347366.clusters.proteins.v11.5.txt",
		        "sequence_path": "1347366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347366.protein.info.v11.5.txt",
		        "node_list_path": "1347366.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1347366.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliagarivoransMarinusDsm23064Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliagarivorans marinus DSM 23064 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliagarivoransMarinusDsm23064Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120969.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120969.protein.info.v11.5.txt",
		        "node_list_path": "1120969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPortieraAleyrodidarumTvCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portiera aleyrodidarum TV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPortieraAleyrodidarumTvCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1297582.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1297582.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1297582.clusters.proteins.v11.5.txt",
		        "sequence_path": "1297582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297582.protein.info.v11.5.txt",
		        "node_list_path": "1297582.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1297582.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumAbikonenseNbrc16140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium abikonense NBRC 16140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumAbikonenseNbrc16140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219036.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219036.protein.info.v11.5.txt",
		        "node_list_path": "1219036.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCb01580Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB01580 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCb01580Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703933.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703933.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703933.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703933.protein.info.v11.5.txt",
		        "node_list_path": "1703933.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703933.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumUmmarienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium ummariense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumUmmarienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "913024.clusters.info.v11.5.txt",
		        "cluster_tree_path": "913024.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "913024.clusters.proteins.v11.5.txt",
		        "sequence_path": "913024.protein.sequences.v11.5.fa",
		        "enrichment_path": "913024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913024.protein.info.v11.5.txt",
		        "node_list_path": "913024.cluster.nodes.v11.5.txt",
		        "edge_list_path": "913024.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoxiellaSpRifcsphigho212Full4215(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coxiella sp. RIFCSPHIGHO2_12_FULL_42_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoxiellaSpRifcsphigho212Full4215", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797696.protein.info.v11.5.txt",
		        "node_list_path": "1797696.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumDeleyianum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum deleyianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumDeleyianum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525898.protein.sequences.v11.5.fa",
		        "enrichment_path": "525898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525898.protein.info.v11.5.txt",
		        "node_list_path": "525898.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpF52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. F52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpF52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1202532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202532.protein.info.v11.5.txt",
		        "node_list_path": "1202532.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumDiazoefficiensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium diazoefficiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumDiazoefficiensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "224911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "224911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "224911.clusters.proteins.v11.5.txt",
		        "sequence_path": "224911.protein.sequences.v11.5.fa",
		        "enrichment_path": "224911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224911.protein.info.v11.5.txt",
		        "node_list_path": "224911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "224911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpJl475Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. JL475 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpJl475Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "383381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "383381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "383381.clusters.proteins.v11.5.txt",
		        "sequence_path": "383381.protein.sequences.v11.5.fa",
		        "enrichment_path": "383381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "383381.protein.info.v11.5.txt",
		        "node_list_path": "383381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "383381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrueperellaPyogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trueperella pyogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrueperellaPyogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661.protein.info.v11.5.txt",
		        "node_list_path": "1661.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacterium4484213(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484213", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1968528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1968528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1968528.protein.info.v11.5.txt",
		        "node_list_path": "1968528.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterLongobardusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter longobardus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterLongobardusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1108812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1108812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1108812.clusters.proteins.v11.5.txt",
		        "sequence_path": "1108812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1108812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1108812.protein.info.v11.5.txt",
		        "node_list_path": "1108812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1108812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaOtitidiscaviarumIfm11049(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia otitidiscaviarum IFM 11049 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaOtitidiscaviarumIfm11049", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1406858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1406858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1406858.protein.info.v11.5.txt",
		        "node_list_path": "1406858.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixibacteriaBacteriumSm23732(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_73_2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm23732", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703426.protein.info.v11.5.txt",
		        "node_list_path": "1703426.protein.complete.v11.5.txt"
		    }
		]
    )()

def StrongyloidesPapillosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Strongyloides papillosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrongyloidesPapillosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "174720.protein.sequences.v11.5.fa",
		        "enrichment_path": "174720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "174720.protein.info.v11.5.txt",
		        "node_list_path": "174720.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesAlpinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides alpinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesAlpinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "748909.protein.sequences.v11.5.fa",
		        "enrichment_path": "748909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748909.protein.info.v11.5.txt",
		        "node_list_path": "748909.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaYangpuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora yangpuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaYangpuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "683228.protein.sequences.v11.5.fa",
		        "enrichment_path": "683228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683228.protein.info.v11.5.txt",
		        "node_list_path": "683228.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyellaJiangningensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyella jiangningensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaJiangningensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379159.protein.info.v11.5.txt",
		        "node_list_path": "1379159.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrocystisAeruginosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microcystis aeruginosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrocystisAeruginosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "449447.protein.sequences.v11.5.fa",
		        "enrichment_path": "449447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "449447.protein.info.v11.5.txt",
		        "node_list_path": "449447.protein.complete.v11.5.txt"
		    }
		]
    )()

def UrocitellusParryiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Urocitellus parryii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UrocitellusParryiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9999.clusters.proteins.v11.5.txt",
		        "sequence_path": "9999.protein.sequences.v11.5.fa",
		        "enrichment_path": "9999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9999.protein.info.v11.5.txt",
		        "node_list_path": "9999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPelagibacterSpRs39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. RS39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPelagibacterSpRs39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977864.protein.info.v11.5.txt",
		        "node_list_path": "1977864.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsphigho202Full3913Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_02_FULL_39_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho202Full3913Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802505.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802505.protein.info.v11.5.txt",
		        "node_list_path": "1802505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrinomonasMethylaliphatogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrinomonas methylaliphatogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrinomonasMethylaliphatogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "454194.protein.sequences.v11.5.fa",
		        "enrichment_path": "454194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454194.protein.info.v11.5.txt",
		        "node_list_path": "454194.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumNodulans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium nodulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumNodulans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "460265.protein.sequences.v11.5.fa",
		        "enrichment_path": "460265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "460265.protein.info.v11.5.txt",
		        "node_list_path": "460265.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBlackburnbacteriaBacteriumRifcsphigho212Full4113b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_12_FULL_41_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho212Full4113b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797517.protein.info.v11.5.txt",
		        "node_list_path": "1797517.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpOv641(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. OV641 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpOv641", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881068.protein.info.v11.5.txt",
		        "node_list_path": "1881068.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaDaqingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena daqingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaDaqingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "588898.protein.sequences.v11.5.fa",
		        "enrichment_path": "588898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "588898.protein.info.v11.5.txt",
		        "node_list_path": "588898.protein.complete.v11.5.txt"
		    }
		]
    )()

def TropicibacterNaphthalenivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tropicibacter naphthalenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TropicibacterNaphthalenivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "441103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "441103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "441103.clusters.proteins.v11.5.txt",
		        "sequence_path": "441103.protein.sequences.v11.5.fa",
		        "enrichment_path": "441103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441103.protein.info.v11.5.txt",
		        "node_list_path": "441103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "441103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262832.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262832.protein.info.v11.5.txt",
		        "node_list_path": "1262832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterGuttiformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter guttiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterGuttiformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1443111.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1443111.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1443111.clusters.proteins.v11.5.txt",
		        "sequence_path": "1443111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443111.protein.info.v11.5.txt",
		        "node_list_path": "1443111.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1443111.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeobacterItalicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter italicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterItalicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "481446.protein.sequences.v11.5.fa",
		        "enrichment_path": "481446.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481446.protein.info.v11.5.txt",
		        "node_list_path": "481446.protein.complete.v11.5.txt"
		    }
		]
    )()

def RattusNorvegicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rattus norvegicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RattusNorvegicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10116.protein.sequences.v11.5.fa",
		        "enrichment_path": "10116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10116.protein.info.v11.5.txt",
		        "node_list_path": "10116.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusCoxiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus coxii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusCoxiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "755172.clusters.info.v11.5.txt",
		        "cluster_tree_path": "755172.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "755172.clusters.proteins.v11.5.txt",
		        "sequence_path": "755172.protein.sequences.v11.5.fa",
		        "enrichment_path": "755172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "755172.protein.info.v11.5.txt",
		        "node_list_path": "755172.cluster.nodes.v11.5.txt",
		        "edge_list_path": "755172.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaSpEi5c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. EI5c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpEi5c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "683316.protein.sequences.v11.5.fa",
		        "enrichment_path": "683316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683316.protein.info.v11.5.txt",
		        "node_list_path": "683316.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaCatarrhalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella catarrhalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaCatarrhalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "857571.protein.sequences.v11.5.fa",
		        "enrichment_path": "857571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857571.protein.info.v11.5.txt",
		        "node_list_path": "857571.protein.complete.v11.5.txt"
		    }
		]
    )()

def CytophagaFermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cytophaga fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CytophagaFermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "869213.clusters.info.v11.5.txt",
		        "cluster_tree_path": "869213.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "869213.clusters.proteins.v11.5.txt",
		        "sequence_path": "869213.protein.sequences.v11.5.fa",
		        "enrichment_path": "869213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869213.protein.info.v11.5.txt",
		        "node_list_path": "869213.cluster.nodes.v11.5.txt",
		        "edge_list_path": "869213.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrinemaPellirubrum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrinema pellirubrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrinemaPellirubrum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "797303.protein.sequences.v11.5.fa",
		        "enrichment_path": "797303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797303.protein.info.v11.5.txt",
		        "node_list_path": "797303.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMargulisbacteriaBacteriumGwf2359Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Margulisbacteria bacterium GWF2_35_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMargulisbacteriaBacteriumGwf2359Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817873.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817873.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817873.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817873.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817873.protein.info.v11.5.txt",
		        "node_list_path": "1817873.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817873.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LabrenziaSpDg1229Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Labrenzia sp. DG1229 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrenziaSpDg1229Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "681847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "681847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "681847.clusters.proteins.v11.5.txt",
		        "sequence_path": "681847.protein.sequences.v11.5.fa",
		        "enrichment_path": "681847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "681847.protein.info.v11.5.txt",
		        "node_list_path": "681847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "681847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpOv700(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. OV700 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpOv700", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882826.protein.info.v11.5.txt",
		        "node_list_path": "1882826.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag780Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:780 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag780Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262839.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262839.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262839.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262839.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262839.protein.info.v11.5.txt",
		        "node_list_path": "1262839.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262839.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaMobileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma mobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaMobileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "267748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "267748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "267748.clusters.proteins.v11.5.txt",
		        "sequence_path": "267748.protein.sequences.v11.5.fa",
		        "enrichment_path": "267748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267748.protein.info.v11.5.txt",
		        "node_list_path": "267748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "267748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExophialaSpiniferaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exophiala spinifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaSpiniferaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "91928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "91928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "91928.clusters.proteins.v11.5.txt",
		        "sequence_path": "91928.protein.sequences.v11.5.fa",
		        "enrichment_path": "91928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91928.protein.info.v11.5.txt",
		        "node_list_path": "91928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "91928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiribacterSalinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiribacter salinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiribacterSalinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1260251.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1260251.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1260251.clusters.proteins.v11.5.txt",
		        "sequence_path": "1260251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1260251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1260251.protein.info.v11.5.txt",
		        "node_list_path": "1260251.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1260251.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpH5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpH5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267973.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267973.protein.info.v11.5.txt",
		        "node_list_path": "1267973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GilvimarinusPolysaccharolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gilvimarinus polysaccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilvimarinusPolysaccharolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "863921.protein.sequences.v11.5.fa",
		        "enrichment_path": "863921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "863921.protein.info.v11.5.txt",
		        "node_list_path": "863921.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusUrinimassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus urinimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusUrinimassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871017.protein.info.v11.5.txt",
		        "node_list_path": "1871017.protein.complete.v11.5.txt"
		    }
		]
    )()

def InediibacteriumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Inediibacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "InediibacteriumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658111.protein.info.v11.5.txt",
		        "node_list_path": "1658111.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumRifoxyb2Full327Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYB2_FULL_32_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxyb2Full327Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801906.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801906.protein.info.v11.5.txt",
		        "node_list_path": "1801906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsplowo212Full4028Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_12_FULL_40_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo212Full4028Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797887.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797887.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797887.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797887.protein.info.v11.5.txt",
		        "node_list_path": "1797887.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797887.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpSt904(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. ST904 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpSt904", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1684385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1684385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1684385.protein.info.v11.5.txt",
		        "node_list_path": "1684385.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF3808(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-3808 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF3808", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1391699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391699.protein.info.v11.5.txt",
		        "node_list_path": "1391699.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalothiobacillusNeapolitanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halothiobacillus neapolitanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalothiobacillusNeapolitanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "555778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "555778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "555778.clusters.proteins.v11.5.txt",
		        "sequence_path": "555778.protein.sequences.v11.5.fa",
		        "enrichment_path": "555778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555778.protein.info.v11.5.txt",
		        "node_list_path": "555778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "555778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyaloscyphaBicolorE(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyaloscypha bicolor E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyaloscyphaBicolorE", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095630.protein.info.v11.5.txt",
		        "node_list_path": "1095630.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfDactylopiusCoccus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Dactylopius coccus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfDactylopiusCoccus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1605993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1605993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1605993.protein.info.v11.5.txt",
		        "node_list_path": "1605993.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterLanienaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter lanienae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterLanienaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "75658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "75658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "75658.clusters.proteins.v11.5.txt",
		        "sequence_path": "75658.protein.sequences.v11.5.fa",
		        "enrichment_path": "75658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75658.protein.info.v11.5.txt",
		        "node_list_path": "75658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "75658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivivaxHalodurans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax halodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxHalodurans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449350.protein.info.v11.5.txt",
		        "node_list_path": "1449350.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalogeometricumRufumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halogeometricum rufum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalogeometricumRufumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553469.clusters.proteins.v11.5.txt",
		        "sequence_path": "553469.protein.sequences.v11.5.fa",
		        "enrichment_path": "553469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553469.protein.info.v11.5.txt",
		        "node_list_path": "553469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpBjgmmb45Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. BJGMMB45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpBjgmmb45Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1178482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1178482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1178482.clusters.proteins.v11.5.txt",
		        "sequence_path": "1178482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1178482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1178482.protein.info.v11.5.txt",
		        "node_list_path": "1178482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1178482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharibacillusKuerlensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharibacillus kuerlensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharibacillusKuerlensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123226.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123226.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123226.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123226.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123226.protein.info.v11.5.txt",
		        "node_list_path": "1123226.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123226.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusAuricularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus auricularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusAuricularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29379.protein.sequences.v11.5.fa",
		        "enrichment_path": "29379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29379.protein.info.v11.5.txt",
		        "node_list_path": "29379.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSp35wCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 35W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSp35wCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1132441.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1132441.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1132441.clusters.proteins.v11.5.txt",
		        "sequence_path": "1132441.protein.sequences.v11.5.fa",
		        "enrichment_path": "1132441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1132441.protein.info.v11.5.txt",
		        "node_list_path": "1132441.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1132441.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlebsiellaAerogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella aerogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaAerogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "548.clusters.proteins.v11.5.txt",
		        "sequence_path": "548.protein.sequences.v11.5.fa",
		        "enrichment_path": "548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "548.protein.info.v11.5.txt",
		        "node_list_path": "548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PodosporaAnserinaSMat(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Podospora anserina S mat+ graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PodosporaAnserinaSMat", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "515849.protein.sequences.v11.5.fa",
		        "enrichment_path": "515849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515849.protein.info.v11.5.txt",
		        "node_list_path": "515849.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpYr096(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. yr096 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpYr096", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761750.protein.info.v11.5.txt",
		        "node_list_path": "1761750.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArenimonasOryziterrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas oryziterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenimonasOryziterrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121015.protein.info.v11.5.txt",
		        "node_list_path": "1121015.protein.complete.v11.5.txt"
		    }
		]
    )()

def KiloniellaLaminariaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kiloniella laminariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KiloniellaLaminariaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122135.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122135.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122135.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122135.protein.info.v11.5.txt",
		        "node_list_path": "1122135.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122135.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OleibacterMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oleibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OleibacterMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "484498.protein.sequences.v11.5.fa",
		        "enrichment_path": "484498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484498.protein.info.v11.5.txt",
		        "node_list_path": "484498.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4217(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_42_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4217", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801780.protein.info.v11.5.txt",
		        "node_list_path": "1801780.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinihabitansFlavidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinihabitans flavidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinihabitansFlavidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "569882.protein.sequences.v11.5.fa",
		        "enrichment_path": "569882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "569882.protein.info.v11.5.txt",
		        "node_list_path": "569882.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanobacillusSpCastelsardoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. Castelsardo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusSpCastelsardoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1851204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1851204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1851204.clusters.proteins.v11.5.txt",
		        "sequence_path": "1851204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1851204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1851204.protein.info.v11.5.txt",
		        "node_list_path": "1851204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1851204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodovulumSpPh10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. PH10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovulumSpPh10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1187851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1187851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1187851.clusters.proteins.v11.5.txt",
		        "sequence_path": "1187851.protein.sequences.v11.5.fa",
		        "enrichment_path": "1187851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1187851.protein.info.v11.5.txt",
		        "node_list_path": "1187851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1187851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoritellaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moritella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoritellaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1202962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1202962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1202962.clusters.proteins.v11.5.txt",
		        "sequence_path": "1202962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202962.protein.info.v11.5.txt",
		        "node_list_path": "1202962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1202962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynergistetesBacteriumJgi0000079D21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synergistetes bacterium JGI 0000079-D21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynergistetesBacteriumJgi0000079D21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1104568.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1104568.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1104568.clusters.proteins.v11.5.txt",
		        "sequence_path": "1104568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104568.protein.info.v11.5.txt",
		        "node_list_path": "1104568.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1104568.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumVincentii3136a2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii 3136A2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumVincentii3136a2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469604.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469604.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469604.clusters.proteins.v11.5.txt",
		        "sequence_path": "469604.protein.sequences.v11.5.fa",
		        "enrichment_path": "469604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469604.protein.info.v11.5.txt",
		        "node_list_path": "469604.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469604.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumPolytrichastri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium polytrichastri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumPolytrichastri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1302687.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302687.protein.info.v11.5.txt",
		        "node_list_path": "1302687.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChondromycesApiculatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chondromyces apiculatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChondromycesApiculatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1192034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1192034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1192034.clusters.proteins.v11.5.txt",
		        "sequence_path": "1192034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192034.protein.info.v11.5.txt",
		        "node_list_path": "1192034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1192034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSp109Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. 109 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSp109Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150399.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150399.protein.info.v11.5.txt",
		        "node_list_path": "1150399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumParaense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium paraense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumParaense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "767916.protein.sequences.v11.5.fa",
		        "enrichment_path": "767916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767916.protein.info.v11.5.txt",
		        "node_list_path": "767916.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurvibacterSpGwa264110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter sp. GWA2_64_110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurvibacterSpGwa264110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797747.protein.info.v11.5.txt",
		        "node_list_path": "1797747.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaitoellaComplicataNrrlY17804(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saitoella complicata NRRL Y-17804 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaitoellaComplicataNrrlY17804", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "698492.protein.sequences.v11.5.fa",
		        "enrichment_path": "698492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698492.protein.info.v11.5.txt",
		        "node_list_path": "698492.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudozymaBrasiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudozymaBrasiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392244.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392244.protein.info.v11.5.txt",
		        "node_list_path": "1392244.protein.complete.v11.5.txt"
		    }
		]
    )()

def GilvimarinusAgarilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gilvimarinus agarilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilvimarinusAgarilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679259.protein.sequences.v11.5.fa",
		        "enrichment_path": "679259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679259.protein.info.v11.5.txt",
		        "node_list_path": "679259.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasOligotropha(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas oligotropha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasOligotropha", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42354.protein.sequences.v11.5.fa",
		        "enrichment_path": "42354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42354.protein.info.v11.5.txt",
		        "node_list_path": "42354.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentzeaJiangxiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentzea jiangxiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentzeaJiangxiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641025.clusters.proteins.v11.5.txt",
		        "sequence_path": "641025.protein.sequences.v11.5.fa",
		        "enrichment_path": "641025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641025.protein.info.v11.5.txt",
		        "node_list_path": "641025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasGraminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas graminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasGraminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "158627.protein.sequences.v11.5.fa",
		        "enrichment_path": "158627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158627.protein.info.v11.5.txt",
		        "node_list_path": "158627.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonosporascusIbericus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus ibericus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusIbericus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "155417.protein.sequences.v11.5.fa",
		        "enrichment_path": "155417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "155417.protein.info.v11.5.txt",
		        "node_list_path": "155417.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarvinbryantiaFormatexigens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marvinbryantia formatexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarvinbryantiaFormatexigens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "478749.protein.sequences.v11.5.fa",
		        "enrichment_path": "478749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "478749.protein.info.v11.5.txt",
		        "node_list_path": "478749.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaCorporis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella corporis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaCorporis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122981.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122981.protein.info.v11.5.txt",
		        "node_list_path": "1122981.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumCorienseDsm10284Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum coriense DSM 10284 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumCorienseDsm10284Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227466.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227466.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227466.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227466.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227466.protein.info.v11.5.txt",
		        "node_list_path": "1227466.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227466.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesLuteusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesLuteusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1844.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1844.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1844.clusters.proteins.v11.5.txt",
		        "sequence_path": "1844.protein.sequences.v11.5.fa",
		        "enrichment_path": "1844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1844.protein.info.v11.5.txt",
		        "node_list_path": "1844.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1844.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporolactobacillusVineaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus vineae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolactobacillusVineaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123284.protein.info.v11.5.txt",
		        "node_list_path": "1123284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CnuellaTakakiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cnuella takakiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CnuellaTakakiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1302690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302690.protein.info.v11.5.txt",
		        "node_list_path": "1302690.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuricibacterSpH121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Turicibacter sp. H121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuricibacterSpH121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1712675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1712675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1712675.clusters.proteins.v11.5.txt",
		        "sequence_path": "1712675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1712675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1712675.protein.info.v11.5.txt",
		        "node_list_path": "1712675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1712675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWs6BacteriumGw2011Gwf23915(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium GW2011_GWF2_39_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWs6BacteriumGw2011Gwf23915", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619100.protein.info.v11.5.txt",
		        "node_list_path": "1619100.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacteriumCg10243210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_43_210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg10243210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805286.protein.info.v11.5.txt",
		        "node_list_path": "1805286.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrobacterSedlakii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sedlakii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterSedlakii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218086.protein.info.v11.5.txt",
		        "node_list_path": "1218086.protein.complete.v11.5.txt"
		    }
		]
    )()

def UncinocarpusReesii1704Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Uncinocarpus reesii 1704 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UncinocarpusReesii1704Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "336963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "336963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "336963.clusters.proteins.v11.5.txt",
		        "sequence_path": "336963.protein.sequences.v11.5.fa",
		        "enrichment_path": "336963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336963.protein.info.v11.5.txt",
		        "node_list_path": "336963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "336963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpLeaf288Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf288 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpLeaf288Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736323.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736323.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736323.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736323.protein.info.v11.5.txt",
		        "node_list_path": "1736323.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736323.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusPyogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pyogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPyogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314.protein.info.v11.5.txt",
		        "node_list_path": "1314.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaMollaretiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia mollaretii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaMollaretiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33060.clusters.proteins.v11.5.txt",
		        "sequence_path": "33060.protein.sequences.v11.5.fa",
		        "enrichment_path": "33060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33060.protein.info.v11.5.txt",
		        "node_list_path": "33060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TolumonasSpBrl61(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tolumonas sp. BRL61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TolumonasSpBrl61", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1283284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283284.protein.info.v11.5.txt",
		        "node_list_path": "1283284.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusAureusSubspAureusNctc8325(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus aureus subsp. aureus NCTC 8325 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusAureusSubspAureusNctc8325", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93061.protein.sequences.v11.5.fa",
		        "enrichment_path": "93061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93061.protein.info.v11.5.txt",
		        "node_list_path": "93061.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpM240(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. M240 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpM240", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216932.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216932.protein.info.v11.5.txt",
		        "node_list_path": "1216932.protein.complete.v11.5.txt"
		    }
		]
    )()

def SediminibacterSpHeli10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacter sp. HelI10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacterSpHeli10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392490.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392490.protein.info.v11.5.txt",
		        "node_list_path": "1392490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BerkelbacteriaBacteriumGw2011Gwb1385(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011_GWB1_38_5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BerkelbacteriaBacteriumGw2011Gwb1385", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618336.protein.info.v11.5.txt",
		        "node_list_path": "1618336.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccidioidesSpLutzii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides sp. lutzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccidioidesSpLutzii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1048829.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048829.protein.info.v11.5.txt",
		        "node_list_path": "1048829.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioclavaPacificaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioclava pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaPacificaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1353537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1353537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1353537.clusters.proteins.v11.5.txt",
		        "sequence_path": "1353537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353537.protein.info.v11.5.txt",
		        "node_list_path": "1353537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1353537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRbg166418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_64_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRbg166418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797477.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797477.protein.info.v11.5.txt",
		        "node_list_path": "1797477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusDakarensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus dakarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusDakarensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926278.protein.info.v11.5.txt",
		        "node_list_path": "1926278.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoactinomycesSpAs95(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. AS95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoactinomycesSpAs95", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811386.protein.info.v11.5.txt",
		        "node_list_path": "1811386.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusCaldoxylosilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus caldoxylosilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusCaldoxylosilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1234664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1234664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1234664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1234664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234664.protein.info.v11.5.txt",
		        "node_list_path": "1234664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1234664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAlligatoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma alligatoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAlligatoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "747682.protein.sequences.v11.5.fa",
		        "enrichment_path": "747682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747682.protein.info.v11.5.txt",
		        "node_list_path": "747682.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpMcba15012Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpMcba15012Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1898738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1898738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1898738.clusters.proteins.v11.5.txt",
		        "sequence_path": "1898738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898738.protein.info.v11.5.txt",
		        "node_list_path": "1898738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1898738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFlavescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFlavescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29435.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29435.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29435.clusters.proteins.v11.5.txt",
		        "sequence_path": "29435.protein.sequences.v11.5.fa",
		        "enrichment_path": "29435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29435.protein.info.v11.5.txt",
		        "node_list_path": "29435.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29435.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SiansivirgaZeaxanthinifaciensCcSamt1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Siansivirga zeaxanthinifaciens CC-SAMT-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SiansivirgaZeaxanthinifaciensCcSamt1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1454006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1454006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1454006.clusters.proteins.v11.5.txt",
		        "sequence_path": "1454006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454006.protein.info.v11.5.txt",
		        "node_list_path": "1454006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1454006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GracilibacillusOrientalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusOrientalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "334253.protein.sequences.v11.5.fa",
		        "enrichment_path": "334253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334253.protein.info.v11.5.txt",
		        "node_list_path": "334253.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanomassiliicoccalesArchaeonRumenM2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanomassiliicoccales archaeon RumEn M2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomassiliicoccalesArchaeonRumenM2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1713725.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1713725.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1713725.clusters.proteins.v11.5.txt",
		        "sequence_path": "1713725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1713725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1713725.protein.info.v11.5.txt",
		        "node_list_path": "1713725.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1713725.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LonchuraStriataDomestica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lonchura striata domestica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LonchuraStriataDomestica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "299123.protein.sequences.v11.5.fa",
		        "enrichment_path": "299123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299123.protein.info.v11.5.txt",
		        "node_list_path": "299123.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusGarvieaeLg2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae Lg2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusGarvieaeLg2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "420890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "420890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "420890.clusters.proteins.v11.5.txt",
		        "sequence_path": "420890.protein.sequences.v11.5.fa",
		        "enrichment_path": "420890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420890.protein.info.v11.5.txt",
		        "node_list_path": "420890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "420890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSacchariCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSacchariCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1399419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1399419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1399419.clusters.proteins.v11.5.txt",
		        "sequence_path": "1399419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399419.protein.info.v11.5.txt",
		        "node_list_path": "1399419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1399419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AminicenantesBacteriumScgcAaa252a02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium SCGC AAA252A02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminicenantesBacteriumScgcAaa252a02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1047013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1047013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1047013.clusters.proteins.v11.5.txt",
		        "sequence_path": "1047013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1047013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1047013.protein.info.v11.5.txt",
		        "node_list_path": "1047013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1047013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesOrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces oris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesOrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "544580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "544580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "544580.clusters.proteins.v11.5.txt",
		        "sequence_path": "544580.protein.sequences.v11.5.fa",
		        "enrichment_path": "544580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "544580.protein.info.v11.5.txt",
		        "node_list_path": "544580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "544580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioDechloracetivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio dechloracetivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioDechloracetivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "117209.protein.sequences.v11.5.fa",
		        "enrichment_path": "117209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "117209.protein.info.v11.5.txt",
		        "node_list_path": "117209.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236542.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236542.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236542.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236542.protein.info.v11.5.txt",
		        "node_list_path": "1236542.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236542.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetalesBacteriumSpiro02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetalesBacteriumSpiro02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674858.protein.info.v11.5.txt",
		        "node_list_path": "1674858.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpTcm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. TCM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpTcm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "453246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "453246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "453246.clusters.proteins.v11.5.txt",
		        "sequence_path": "453246.protein.sequences.v11.5.fa",
		        "enrichment_path": "453246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "453246.protein.info.v11.5.txt",
		        "node_list_path": "453246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "453246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlareaLozoyensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glarea lozoyensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlareaLozoyensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "101852.protein.sequences.v11.5.fa",
		        "enrichment_path": "101852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101852.protein.info.v11.5.txt",
		        "node_list_path": "101852.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaMonticolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia monticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaMonticolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1399968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1399968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1399968.clusters.proteins.v11.5.txt",
		        "sequence_path": "1399968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399968.protein.info.v11.5.txt",
		        "node_list_path": "1399968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1399968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusFischeriNrrl181Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus fischeri NRRL 181 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusFischeriNrrl181Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "331117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "331117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "331117.clusters.proteins.v11.5.txt",
		        "sequence_path": "331117.protein.sequences.v11.5.fa",
		        "enrichment_path": "331117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331117.protein.info.v11.5.txt",
		        "node_list_path": "331117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "331117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrenophoraTeresFTeres01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora teres f. teres 0-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrenophoraTeresFTeres01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "861557.protein.sequences.v11.5.fa",
		        "enrichment_path": "861557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861557.protein.info.v11.5.txt",
		        "node_list_path": "861557.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaAzotonutricium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema azotonutricium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaAzotonutricium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "545695.protein.sequences.v11.5.fa",
		        "enrichment_path": "545695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545695.protein.info.v11.5.txt",
		        "node_list_path": "545695.protein.complete.v11.5.txt"
		    }
		]
    )()

def AestuariivitaBoseongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aestuariivita boseongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AestuariivitaBoseongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1470562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470562.protein.info.v11.5.txt",
		        "node_list_path": "1470562.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeosporobacterFerrireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geosporobacter ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeosporobacterFerrireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1424294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1424294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1424294.protein.info.v11.5.txt",
		        "node_list_path": "1424294.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusUrinaehominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus urinaehominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusUrinaehominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "128944.protein.sequences.v11.5.fa",
		        "enrichment_path": "128944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "128944.protein.info.v11.5.txt",
		        "node_list_path": "128944.protein.complete.v11.5.txt"
		    }
		]
    )()

def TorulasporaDelbrueckiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Torulaspora delbrueckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TorulasporaDelbrueckiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4950.clusters.proteins.v11.5.txt",
		        "sequence_path": "4950.protein.sequences.v11.5.fa",
		        "enrichment_path": "4950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4950.protein.info.v11.5.txt",
		        "node_list_path": "4950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusSpKu2611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. KU2-6(11) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusSpKu2611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1535751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1535751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1535751.protein.info.v11.5.txt",
		        "node_list_path": "1535751.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpOv322(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. OV322 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpOv322", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882764.protein.info.v11.5.txt",
		        "node_list_path": "1882764.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumGa0074141(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0074141 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumGa0074141", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752182.protein.info.v11.5.txt",
		        "node_list_path": "1752182.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCarsonellaRuddiiCsIsolateThao2000Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii CS isolate Thao2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCarsonellaRuddiiCsIsolateThao2000Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1202537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1202537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1202537.clusters.proteins.v11.5.txt",
		        "sequence_path": "1202537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202537.protein.info.v11.5.txt",
		        "node_list_path": "1202537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1202537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnabaenaCylindrica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anabaena cylindrica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabaenaCylindrica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272123.protein.sequences.v11.5.fa",
		        "enrichment_path": "272123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272123.protein.info.v11.5.txt",
		        "node_list_path": "272123.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterAcetiAtcc23746Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter aceti ATCC23746 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterAcetiAtcc23746Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "663932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "663932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "663932.clusters.proteins.v11.5.txt",
		        "sequence_path": "663932.protein.sequences.v11.5.fa",
		        "enrichment_path": "663932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663932.protein.info.v11.5.txt",
		        "node_list_path": "663932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "663932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumLubricantis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium lubricantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumLubricantis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121363.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121363.protein.info.v11.5.txt",
		        "node_list_path": "1121363.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoplanesFriuliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes friuliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesFriuliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246995.protein.info.v11.5.txt",
		        "node_list_path": "1246995.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc29g08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC29G08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc29g08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1581069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581069.protein.info.v11.5.txt",
		        "node_list_path": "1581069.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParamaledivibacterCaminithermalisDsm15212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paramaledivibacter caminithermalis DSM 15212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParamaledivibacterCaminithermalisDsm15212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121301.protein.info.v11.5.txt",
		        "node_list_path": "1121301.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumP7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium P7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumP7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1200751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1200751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1200751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1200751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200751.protein.info.v11.5.txt",
		        "node_list_path": "1200751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1200751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoflavibacterZeaxanthinifaciensS86(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanthinifaciens S86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoflavibacterZeaxanthinifaciensS86", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1004149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004149.protein.info.v11.5.txt",
		        "node_list_path": "1004149.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanofastidiosumMethylthiophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanofastidiosum methylthiophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanofastidiosumMethylthiophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1705564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705564.protein.info.v11.5.txt",
		        "node_list_path": "1705564.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaPhenoliruptrix(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phenoliruptrix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaPhenoliruptrix", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229205.protein.info.v11.5.txt",
		        "node_list_path": "1229205.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumRbg136414(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_13_64_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg136414", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797271.protein.info.v11.5.txt",
		        "node_list_path": "1797271.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgromycesSpNdb4y10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agromyces sp. NDB4Y10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesSpNdb4y10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1775951.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775951.protein.info.v11.5.txt",
		        "node_list_path": "1775951.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpLc363Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LC363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpLc363Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120705.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120705.protein.info.v11.5.txt",
		        "node_list_path": "1120705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumNygamai(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium nygamai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumNygamai", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42673.protein.sequences.v11.5.fa",
		        "enrichment_path": "42673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42673.protein.info.v11.5.txt",
		        "node_list_path": "42673.protein.complete.v11.5.txt"
		    }
		]
    )()

def EmergenciaTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Emergencia timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmergenciaTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776384.protein.info.v11.5.txt",
		        "node_list_path": "1776384.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonasPusillaCcmp1545Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonas pusilla CCMP1545 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonasPusillaCcmp1545Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "564608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "564608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "564608.clusters.proteins.v11.5.txt",
		        "sequence_path": "564608.protein.sequences.v11.5.fa",
		        "enrichment_path": "564608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "564608.protein.info.v11.5.txt",
		        "node_list_path": "564608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "564608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumMor1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Mor1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumMor1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660251.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660251.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660251.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660251.protein.info.v11.5.txt",
		        "node_list_path": "1660251.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660251.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AscoideaRubescensDsm1968(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ascoidea rubescens DSM 1968 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AscoideaRubescensDsm1968", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1344418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1344418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1344418.protein.info.v11.5.txt",
		        "node_list_path": "1344418.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumMantenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium mantenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumMantenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "560555.protein.sequences.v11.5.fa",
		        "enrichment_path": "560555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "560555.protein.info.v11.5.txt",
		        "node_list_path": "560555.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiothrixNivea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix nivea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiothrixNivea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "870187.protein.sequences.v11.5.fa",
		        "enrichment_path": "870187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "870187.protein.info.v11.5.txt",
		        "node_list_path": "870187.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumTegetincolaDsm22377Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium tegetincola DSM 22377 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumTegetincolaDsm22377Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121901.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121901.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121901.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121901.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121901.protein.info.v11.5.txt",
		        "node_list_path": "1121901.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121901.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PanPaniscusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pan paniscus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PanPaniscusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9597.clusters.proteins.v11.5.txt",
		        "sequence_path": "9597.protein.sequences.v11.5.fa",
		        "enrichment_path": "9597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9597.protein.info.v11.5.txt",
		        "node_list_path": "9597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemellaMorbillorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella morbillorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaMorbillorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "562982.clusters.info.v11.5.txt",
		        "cluster_tree_path": "562982.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "562982.clusters.proteins.v11.5.txt",
		        "sequence_path": "562982.protein.sequences.v11.5.fa",
		        "enrichment_path": "562982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562982.protein.info.v11.5.txt",
		        "node_list_path": "562982.cluster.nodes.v11.5.txt",
		        "edge_list_path": "562982.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumOlb16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium OLB16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumOlb16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617433.protein.info.v11.5.txt",
		        "node_list_path": "1617433.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasEutrophaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas eutropha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasEutrophaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "335283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "335283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "335283.clusters.proteins.v11.5.txt",
		        "sequence_path": "335283.protein.sequences.v11.5.fa",
		        "enrichment_path": "335283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335283.protein.info.v11.5.txt",
		        "node_list_path": "335283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "335283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GranulicatellaElegans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Granulicatella elegans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicatellaElegans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "626369.protein.sequences.v11.5.fa",
		        "enrichment_path": "626369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626369.protein.info.v11.5.txt",
		        "node_list_path": "626369.protein.complete.v11.5.txt"
		    }
		]
    )()

def BavariicoccusSeileri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bavariicoccus seileri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BavariicoccusSeileri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121105.protein.info.v11.5.txt",
		        "node_list_path": "1121105.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusErythropolis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus erythropolis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusErythropolis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "234621.protein.sequences.v11.5.fa",
		        "enrichment_path": "234621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "234621.protein.info.v11.5.txt",
		        "node_list_path": "234621.protein.complete.v11.5.txt"
		    }
		]
    )()

def GluconacetobacterDiazotrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gluconacetobacter diazotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconacetobacterDiazotrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272568.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272568.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272568.clusters.proteins.v11.5.txt",
		        "sequence_path": "272568.protein.sequences.v11.5.fa",
		        "enrichment_path": "272568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272568.protein.info.v11.5.txt",
		        "node_list_path": "272568.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272568.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpVcd2006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. VCD2006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpVcd2006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280664.protein.info.v11.5.txt",
		        "node_list_path": "1280664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumUreicelerivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium ureicelerivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumUreicelerivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "401472.clusters.info.v11.5.txt",
		        "cluster_tree_path": "401472.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "401472.clusters.proteins.v11.5.txt",
		        "sequence_path": "401472.protein.sequences.v11.5.fa",
		        "enrichment_path": "401472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "401472.protein.info.v11.5.txt",
		        "node_list_path": "401472.cluster.nodes.v11.5.txt",
		        "edge_list_path": "401472.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DanausPlexippusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Danaus plexippus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DanausPlexippusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13037.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13037.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13037.clusters.proteins.v11.5.txt",
		        "sequence_path": "13037.protein.sequences.v11.5.fa",
		        "enrichment_path": "13037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13037.protein.info.v11.5.txt",
		        "node_list_path": "13037.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13037.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesFlavovariabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavovariabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesFlavovariabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "284031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "284031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "284031.clusters.proteins.v11.5.txt",
		        "sequence_path": "284031.protein.sequences.v11.5.fa",
		        "enrichment_path": "284031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284031.protein.info.v11.5.txt",
		        "node_list_path": "284031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "284031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AustwickiaChelonaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Austwickia chelonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AustwickiaChelonaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1184607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1184607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1184607.clusters.proteins.v11.5.txt",
		        "sequence_path": "1184607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1184607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1184607.protein.info.v11.5.txt",
		        "node_list_path": "1184607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1184607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumParaffinicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium paraffinicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumParaffinicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53378.protein.sequences.v11.5.fa",
		        "enrichment_path": "53378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53378.protein.info.v11.5.txt",
		        "node_list_path": "53378.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaAgarivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaAgarivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1911682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1911682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1911682.protein.info.v11.5.txt",
		        "node_list_path": "1911682.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaZimbabwensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichinella zimbabwensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaZimbabwensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "268475.protein.sequences.v11.5.fa",
		        "enrichment_path": "268475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "268475.protein.info.v11.5.txt",
		        "node_list_path": "268475.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp12451111Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1245111.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp12451111Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834073.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834073.protein.info.v11.5.txt",
		        "node_list_path": "1834073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UstilagoMaydis521Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ustilago maydis 521 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UstilagoMaydis521Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "237631.clusters.info.v11.5.txt",
		        "cluster_tree_path": "237631.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "237631.clusters.proteins.v11.5.txt",
		        "sequence_path": "237631.protein.sequences.v11.5.fa",
		        "enrichment_path": "237631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237631.protein.info.v11.5.txt",
		        "node_list_path": "237631.cluster.nodes.v11.5.txt",
		        "edge_list_path": "237631.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumKyorinenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kyorinense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumKyorinenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "487514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "487514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "487514.clusters.proteins.v11.5.txt",
		        "sequence_path": "487514.protein.sequences.v11.5.fa",
		        "enrichment_path": "487514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487514.protein.info.v11.5.txt",
		        "node_list_path": "487514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "487514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SteinernemaCarpocapsae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Steinernema carpocapsae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SteinernemaCarpocapsae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34508.protein.sequences.v11.5.fa",
		        "enrichment_path": "34508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34508.protein.info.v11.5.txt",
		        "node_list_path": "34508.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumUc512e3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-2E3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumUc512e3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1697781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1697781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1697781.protein.info.v11.5.txt",
		        "node_list_path": "1697781.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpIbvhs2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. IBVHS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpIbvhs2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1985170.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1985170.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1985170.clusters.proteins.v11.5.txt",
		        "sequence_path": "1985170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1985170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1985170.protein.info.v11.5.txt",
		        "node_list_path": "1985170.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1985170.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRifcsplowo202Full6415(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO2_02_FULL_64_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202Full6415", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797181.protein.info.v11.5.txt",
		        "node_list_path": "1797181.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumImcc3088Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium IMCC3088 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumImcc3088Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "876044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "876044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "876044.clusters.proteins.v11.5.txt",
		        "sequence_path": "876044.protein.sequences.v11.5.fa",
		        "enrichment_path": "876044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "876044.protein.info.v11.5.txt",
		        "node_list_path": "876044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "876044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioOrientalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioOrientalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675816.clusters.proteins.v11.5.txt",
		        "sequence_path": "675816.protein.sequences.v11.5.fa",
		        "enrichment_path": "675816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675816.protein.info.v11.5.txt",
		        "node_list_path": "675816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrechmeriaConiospora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drechmeria coniospora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrechmeriaConiospora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "98403.protein.sequences.v11.5.fa",
		        "enrichment_path": "98403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "98403.protein.info.v11.5.txt",
		        "node_list_path": "98403.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaGrandensisFslF60971(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria grandensis FSL F6-0971 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaGrandensisFslF60971", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265819.protein.info.v11.5.txt",
		        "node_list_path": "1265819.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChristensenellaMinutaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Christensenella minuta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChristensenellaMinutaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "626937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "626937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "626937.clusters.proteins.v11.5.txt",
		        "sequence_path": "626937.protein.sequences.v11.5.fa",
		        "enrichment_path": "626937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626937.protein.info.v11.5.txt",
		        "node_list_path": "626937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "626937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermobifidaCellulosilyticaTb100Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermobifida cellulosilytica TB100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobifidaCellulosilyticaTb100Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665004.clusters.proteins.v11.5.txt",
		        "sequence_path": "665004.protein.sequences.v11.5.fa",
		        "enrichment_path": "665004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665004.protein.info.v11.5.txt",
		        "node_list_path": "665004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaProducta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blautia producta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaProducta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33035.protein.sequences.v11.5.fa",
		        "enrichment_path": "33035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33035.protein.info.v11.5.txt",
		        "node_list_path": "33035.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaTamurae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia tamurae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaTamurae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "334545.protein.sequences.v11.5.fa",
		        "enrichment_path": "334545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334545.protein.info.v11.5.txt",
		        "node_list_path": "334545.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArtemisiaAnnuaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Artemisia annua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArtemisiaAnnuaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35608.clusters.proteins.v11.5.txt",
		        "sequence_path": "35608.protein.sequences.v11.5.fa",
		        "enrichment_path": "35608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35608.protein.info.v11.5.txt",
		        "node_list_path": "35608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionimicrobiumLymphophilumAcs093VSch5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionimicrobium lymphophilum ACS-093-V-SCH5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionimicrobiumLymphophilumAcs093VSch5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883161.protein.sequences.v11.5.fa",
		        "enrichment_path": "883161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883161.protein.info.v11.5.txt",
		        "node_list_path": "883161.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMycoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mycoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMycoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1405.protein.info.v11.5.txt",
		        "node_list_path": "1405.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpL77(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. L77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpL77", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1496689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1496689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1496689.protein.info.v11.5.txt",
		        "node_list_path": "1496689.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaFerrariae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia ferrariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaFerrariae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218076.protein.info.v11.5.txt",
		        "node_list_path": "1218076.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumGubbeenense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium gubbeenense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumGubbeenense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122237.protein.info.v11.5.txt",
		        "node_list_path": "1122237.protein.complete.v11.5.txt"
		    }
		]
    )()

def WigglesworthiaGlossinidiaEndosymbiontOfGlossinaMorsitans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia endosymbiont of Glossina morsitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WigglesworthiaGlossinidiaEndosymbiontOfGlossinaMorsitans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1142511.protein.sequences.v11.5.fa",
		        "enrichment_path": "1142511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1142511.protein.info.v11.5.txt",
		        "node_list_path": "1142511.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtopobacterPhocae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobacter phocae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobacterPhocae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336234.protein.info.v11.5.txt",
		        "node_list_path": "1336234.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumTropicaleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum tropicale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumTropicaleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1765655.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1765655.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1765655.clusters.proteins.v11.5.txt",
		        "sequence_path": "1765655.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765655.protein.info.v11.5.txt",
		        "node_list_path": "1765655.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1765655.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidaminococcusFermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidaminococcus fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminococcusFermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "591001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "591001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "591001.clusters.proteins.v11.5.txt",
		        "sequence_path": "591001.protein.sequences.v11.5.fa",
		        "enrichment_path": "591001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591001.protein.info.v11.5.txt",
		        "node_list_path": "591001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "591001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaludibacterSp4717Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paludibacter sp. 47-17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaludibacterSp4717Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895899.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895899.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895899.protein.info.v11.5.txt",
		        "node_list_path": "1895899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioBizertensisDsm18034(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio bizertensis DSM 18034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioBizertensisDsm18034", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121442.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121442.protein.info.v11.5.txt",
		        "node_list_path": "1121442.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptosporangiumAmethystogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptosporangium amethystogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptosporangiumAmethystogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2002.clusters.proteins.v11.5.txt",
		        "sequence_path": "2002.protein.sequences.v11.5.fa",
		        "enrichment_path": "2002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2002.protein.info.v11.5.txt",
		        "node_list_path": "2002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZymoseptoriaTriticiIpo323Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici IPO323 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymoseptoriaTriticiIpo323Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "336722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "336722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "336722.clusters.proteins.v11.5.txt",
		        "sequence_path": "336722.protein.sequences.v11.5.fa",
		        "enrichment_path": "336722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336722.protein.info.v11.5.txt",
		        "node_list_path": "336722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "336722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_40_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802064.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802064.protein.info.v11.5.txt",
		        "node_list_path": "1802064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpSyk6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. SYK6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpSyk6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "627192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "627192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "627192.clusters.proteins.v11.5.txt",
		        "sequence_path": "627192.protein.sequences.v11.5.fa",
		        "enrichment_path": "627192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "627192.protein.info.v11.5.txt",
		        "node_list_path": "627192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "627192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicoccusHalodurans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus halodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusHalodurans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "407035.protein.sequences.v11.5.fa",
		        "enrichment_path": "407035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "407035.protein.info.v11.5.txt",
		        "node_list_path": "407035.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusGarvieaeI113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae I113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusGarvieaeI113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229517.protein.info.v11.5.txt",
		        "node_list_path": "1229517.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumSpMh3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. MH3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumSpMh3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1399115.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399115.protein.info.v11.5.txt",
		        "node_list_path": "1399115.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusVulcani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus vulcani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusVulcani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1382315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382315.protein.info.v11.5.txt",
		        "node_list_path": "1382315.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusZeae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus zeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusZeae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423816.protein.info.v11.5.txt",
		        "node_list_path": "1423816.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpPcc6312Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC6312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpPcc6312Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "195253.clusters.info.v11.5.txt",
		        "cluster_tree_path": "195253.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "195253.clusters.proteins.v11.5.txt",
		        "sequence_path": "195253.protein.sequences.v11.5.fa",
		        "enrichment_path": "195253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195253.protein.info.v11.5.txt",
		        "node_list_path": "195253.cluster.nodes.v11.5.txt",
		        "edge_list_path": "195253.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusBathoardescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus bathoardescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusBathoardescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1301915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1301915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1301915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1301915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1301915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1301915.protein.info.v11.5.txt",
		        "node_list_path": "1301915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1301915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClavicepsPurpureaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Claviceps purpurea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavicepsPurpureaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5111.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5111.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5111.clusters.proteins.v11.5.txt",
		        "sequence_path": "5111.protein.sequences.v11.5.fa",
		        "enrichment_path": "5111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5111.protein.info.v11.5.txt",
		        "node_list_path": "5111.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5111.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumMedpeSwsndG2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium MedPE-SWsnd-G2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumMedpeSwsndG2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1860095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1860095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1860095.clusters.proteins.v11.5.txt",
		        "sequence_path": "1860095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860095.protein.info.v11.5.txt",
		        "node_list_path": "1860095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1860095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacillusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacillusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385510.protein.info.v11.5.txt",
		        "node_list_path": "1385510.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAgglomeratus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces agglomeratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAgglomeratus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "285458.protein.sequences.v11.5.fa",
		        "enrichment_path": "285458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285458.protein.info.v11.5.txt",
		        "node_list_path": "285458.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterSpHl46(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. HL46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterSpHl46", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1479239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479239.protein.info.v11.5.txt",
		        "node_list_path": "1479239.protein.complete.v11.5.txt"
		    }
		]
    )()

def HistoplasmaCapsulatumH143(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum H143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HistoplasmaCapsulatumH143", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "544712.protein.sequences.v11.5.fa",
		        "enrichment_path": "544712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "544712.protein.info.v11.5.txt",
		        "node_list_path": "544712.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifoxyd12Full3317(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD12_FULL_33_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd12Full3317", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798706.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798706.protein.info.v11.5.txt",
		        "node_list_path": "1798706.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaballeroniaPtereochthonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia ptereochthonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaPtereochthonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777144.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777144.protein.info.v11.5.txt",
		        "node_list_path": "1777144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaprospiraGrandisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saprospira grandis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaprospiraGrandisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "984262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "984262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "984262.clusters.proteins.v11.5.txt",
		        "sequence_path": "984262.protein.sequences.v11.5.fa",
		        "enrichment_path": "984262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "984262.protein.info.v11.5.txt",
		        "node_list_path": "984262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "984262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAmyloliquefaciensDsm7Atcc23350Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens DSM 7 ATCC 23350 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAmyloliquefaciensDsm7Atcc23350Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "692420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "692420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "692420.clusters.proteins.v11.5.txt",
		        "sequence_path": "692420.protein.sequences.v11.5.fa",
		        "enrichment_path": "692420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "692420.protein.info.v11.5.txt",
		        "node_list_path": "692420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "692420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCapillatusDsm19910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus capillatus DSM 19910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCapillatusDsm19910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423731.protein.info.v11.5.txt",
		        "node_list_path": "1423731.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusDakarensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus dakarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusDakarensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926278.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926278.protein.info.v11.5.txt",
		        "node_list_path": "1926278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumSpMesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. MES Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumSpMesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1565314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1565314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1565314.clusters.proteins.v11.5.txt",
		        "sequence_path": "1565314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1565314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1565314.protein.info.v11.5.txt",
		        "node_list_path": "1565314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1565314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpJs666(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. JS666 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpJs666", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "296591.protein.sequences.v11.5.fa",
		        "enrichment_path": "296591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "296591.protein.info.v11.5.txt",
		        "node_list_path": "296591.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinopolysporaRighensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora righensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolysporaRighensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "995060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "995060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "995060.clusters.proteins.v11.5.txt",
		        "sequence_path": "995060.protein.sequences.v11.5.fa",
		        "enrichment_path": "995060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "995060.protein.info.v11.5.txt",
		        "node_list_path": "995060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "995060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CronobacterDublinensisSubspLausannensisLmg23824(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. lausannensis LMG 23824 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CronobacterDublinensisSubspLausannensisLmg23824", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1159560.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159560.protein.info.v11.5.txt",
		        "node_list_path": "1159560.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusCrustorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus crustorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCrustorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "392416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "392416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "392416.clusters.proteins.v11.5.txt",
		        "sequence_path": "392416.protein.sequences.v11.5.fa",
		        "enrichment_path": "392416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392416.protein.info.v11.5.txt",
		        "node_list_path": "392416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "392416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaParaffinivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia paraffinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaParaffinivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223543.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223543.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223543.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223543.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223543.protein.info.v11.5.txt",
		        "node_list_path": "1223543.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223543.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MegasphaeraSpUpii135e(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. UPII135E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraSpUpii135e", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1000569.protein.sequences.v11.5.fa",
		        "enrichment_path": "1000569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1000569.protein.info.v11.5.txt",
		        "node_list_path": "1000569.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusPeptonophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus peptonophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusPeptonophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53952.clusters.proteins.v11.5.txt",
		        "sequence_path": "53952.protein.sequences.v11.5.fa",
		        "enrichment_path": "53952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53952.protein.info.v11.5.txt",
		        "node_list_path": "53952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloceanibacterSteviniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloceanibacter stevinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloceanibacterSteviniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1774970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1774970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1774970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1774970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1774970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1774970.protein.info.v11.5.txt",
		        "node_list_path": "1774970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1774970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumHerbicidovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium herbicidovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumHerbicidovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219045.protein.info.v11.5.txt",
		        "node_list_path": "1219045.protein.complete.v11.5.txt"
		    }
		]
    )()

def SarcinaSpDsm11001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sarcina sp. DSM 11001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SarcinaSpDsm11001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798184.protein.info.v11.5.txt",
		        "node_list_path": "1798184.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSyngnathidarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium syngnathidarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSyngnathidarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1908205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908205.protein.info.v11.5.txt",
		        "node_list_path": "1908205.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaTamuraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia tamurae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaTamuraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "334545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "334545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "334545.clusters.proteins.v11.5.txt",
		        "sequence_path": "334545.protein.sequences.v11.5.fa",
		        "enrichment_path": "334545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334545.protein.info.v11.5.txt",
		        "node_list_path": "334545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "334545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusSpJdfr02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sp. JdFR-02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSpJdfr02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935003.protein.info.v11.5.txt",
		        "node_list_path": "1935003.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpLeaf394Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf394 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpLeaf394Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736361.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736361.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736361.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736361.protein.info.v11.5.txt",
		        "node_list_path": "1736361.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736361.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaTuberolachnusSalignusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Tuberolachnus salignus) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaTuberolachnusSalignusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "98804.clusters.info.v11.5.txt",
		        "cluster_tree_path": "98804.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "98804.clusters.proteins.v11.5.txt",
		        "sequence_path": "98804.protein.sequences.v11.5.fa",
		        "enrichment_path": "98804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "98804.protein.info.v11.5.txt",
		        "node_list_path": "98804.cluster.nodes.v11.5.txt",
		        "edge_list_path": "98804.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JaculusJaculus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jaculus jaculus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JaculusJaculus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "51337.protein.sequences.v11.5.fa",
		        "enrichment_path": "51337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51337.protein.info.v11.5.txt",
		        "node_list_path": "51337.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlumeriaGraminisFSpHordeiDh14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blumeria graminis f. sp. hordei DH14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlumeriaGraminisFSpHordeiDh14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546991.protein.sequences.v11.5.fa",
		        "enrichment_path": "546991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546991.protein.info.v11.5.txt",
		        "node_list_path": "546991.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedCoprococcusSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Coprococcus sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedCoprococcusSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "458253.protein.sequences.v11.5.fa",
		        "enrichment_path": "458253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "458253.protein.info.v11.5.txt",
		        "node_list_path": "458253.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp14822926Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1482292.6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp14822926Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834081.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834081.protein.info.v11.5.txt",
		        "node_list_path": "1834081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaWeaveri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria weaveri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaWeaveri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1051985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051985.protein.info.v11.5.txt",
		        "node_list_path": "1051985.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrametesCinnabarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trametes cinnabarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrametesCinnabarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5643.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5643.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5643.clusters.proteins.v11.5.txt",
		        "sequence_path": "5643.protein.sequences.v11.5.fa",
		        "enrichment_path": "5643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5643.protein.info.v11.5.txt",
		        "node_list_path": "5643.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5643.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastococcusSaxobsidensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus saxobsidens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusSaxobsidensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1146883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1146883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1146883.clusters.proteins.v11.5.txt",
		        "sequence_path": "1146883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1146883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1146883.protein.info.v11.5.txt",
		        "node_list_path": "1146883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1146883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpPcc7376(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC7376 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpPcc7376", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "111781.protein.sequences.v11.5.fa",
		        "enrichment_path": "111781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "111781.protein.info.v11.5.txt",
		        "node_list_path": "111781.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaAcidipaludis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia acidipaludis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaAcidipaludis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218074.protein.info.v11.5.txt",
		        "node_list_path": "1218074.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpSoil538(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Soil538 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpSoil538", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736391.protein.info.v11.5.txt",
		        "node_list_path": "1736391.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelomonasSpRoot1444Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1444 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelomonasSpRoot1444Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736464.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736464.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736464.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736464.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736464.protein.info.v11.5.txt",
		        "node_list_path": "1736464.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736464.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHtcc2143(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2143", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "247633.protein.sequences.v11.0.fa",
		        "enrichment_path": "247633.protein.enrichment.terms.v11.0.txt",
		        "info_path": "247633.protein.info.v11.0.txt",
		        "node_list_path": "247633.protein.complete.v11.0.txt"
		    }
		]
    )()

def MongoliimonasTerrestrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mongoliimonas terrestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MongoliimonasTerrestrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1709001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1709001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1709001.clusters.proteins.v11.5.txt",
		        "sequence_path": "1709001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1709001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1709001.protein.info.v11.5.txt",
		        "node_list_path": "1709001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1709001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg165711Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_57_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg165711Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797651.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797651.protein.info.v11.5.txt",
		        "node_list_path": "1797651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf2890(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF2890 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf2890", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463845.protein.info.v11.5.txt",
		        "node_list_path": "1463845.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4620(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_FULL_46_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4620", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798338.protein.info.v11.5.txt",
		        "node_list_path": "1798338.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermonemaRossianumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermonema rossianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermonemaRossianumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1313301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1313301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1313301.clusters.proteins.v11.5.txt",
		        "sequence_path": "1313301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313301.protein.info.v11.5.txt",
		        "node_list_path": "1313301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1313301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BesnoitiaBesnoiti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Besnoitia besnoiti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BesnoitiaBesnoiti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "94643.protein.sequences.v11.5.fa",
		        "enrichment_path": "94643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94643.protein.info.v11.5.txt",
		        "node_list_path": "94643.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusAwamori(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus awamori graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusAwamori", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "105351.protein.sequences.v11.5.fa",
		        "enrichment_path": "105351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105351.protein.info.v11.5.txt",
		        "node_list_path": "105351.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterWuhouensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter wuhouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterWuhouensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1879050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1879050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1879050.clusters.proteins.v11.5.txt",
		        "sequence_path": "1879050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1879050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1879050.protein.info.v11.5.txt",
		        "node_list_path": "1879050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1879050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCoagulans26(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coagulans 26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCoagulans26", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "941639.protein.sequences.v11.5.fa",
		        "enrichment_path": "941639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "941639.protein.info.v11.5.txt",
		        "node_list_path": "941639.protein.complete.v11.5.txt"
		    }
		]
    )()

def InquilinusLimosusDsm16000Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Inquilinus limosus DSM 16000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "InquilinusLimosusDsm16000Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122125.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122125.protein.info.v11.5.txt",
		        "node_list_path": "1122125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusChisholmbacteriaBacteriumRifcsplowo201Full4914Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPLOWO2_01_FULL_49_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsplowo201Full4914Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797593.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797593.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797593.protein.info.v11.5.txt",
		        "node_list_path": "1797593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo212Full4116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_12_FULL_41_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo212Full4116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797736.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797736.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797736.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797736.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797736.protein.info.v11.5.txt",
		        "node_list_path": "1797736.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797736.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EmmonsiaSpCac2015a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Emmonsia sp. CAC-2015a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmmonsiaSpCac2015a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658172.protein.info.v11.5.txt",
		        "node_list_path": "1658172.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag345(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:345 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag345", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263020.protein.info.v11.5.txt",
		        "node_list_path": "1263020.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarssoninaBrunneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marssonina brunnea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarssoninaBrunneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "698440.clusters.info.v11.5.txt",
		        "cluster_tree_path": "698440.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "698440.clusters.proteins.v11.5.txt",
		        "sequence_path": "698440.protein.sequences.v11.5.fa",
		        "enrichment_path": "698440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698440.protein.info.v11.5.txt",
		        "node_list_path": "698440.cluster.nodes.v11.5.txt",
		        "edge_list_path": "698440.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HippeaAlviniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hippea alviniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HippeaAlviniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "944480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "944480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "944480.clusters.proteins.v11.5.txt",
		        "sequence_path": "944480.protein.sequences.v11.5.fa",
		        "enrichment_path": "944480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944480.protein.info.v11.5.txt",
		        "node_list_path": "944480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "944480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioXylanivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio xylanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioXylanivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "185007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "185007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "185007.clusters.proteins.v11.5.txt",
		        "sequence_path": "185007.protein.sequences.v11.5.fa",
		        "enrichment_path": "185007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "185007.protein.info.v11.5.txt",
		        "node_list_path": "185007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "185007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorhabdusUtahensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorhabdus utahensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorhabdusUtahensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "519442.protein.sequences.v11.5.fa",
		        "enrichment_path": "519442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519442.protein.info.v11.5.txt",
		        "node_list_path": "519442.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaSpH1nCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. H1n Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpH1nCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397284.protein.info.v11.5.txt",
		        "node_list_path": "1397284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanosarcinalesArchaeonMethan01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcinales archaeon Methan_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinalesArchaeonMethan01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674798.protein.info.v11.5.txt",
		        "node_list_path": "1674798.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudocercosporaFijiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudocercospora fijiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudocercosporaFijiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83344.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83344.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83344.clusters.proteins.v11.5.txt",
		        "sequence_path": "83344.protein.sequences.v11.5.fa",
		        "enrichment_path": "83344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83344.protein.info.v11.5.txt",
		        "node_list_path": "83344.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83344.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag914Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:914 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag914Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262846.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262846.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262846.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262846.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262846.protein.info.v11.5.txt",
		        "node_list_path": "1262846.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262846.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpWb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. WB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpWb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1685380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685380.protein.info.v11.5.txt",
		        "node_list_path": "1685380.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsplowo201Full5024(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO2_01_FULL_50_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo201Full5024", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801829.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801829.protein.info.v11.5.txt",
		        "node_list_path": "1801829.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillibacterSp13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. 13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSp13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235797.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235797.protein.info.v11.5.txt",
		        "node_list_path": "1235797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaribacterSpHtcc2170(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter sp. HTCC2170 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterSpHtcc2170", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313603.protein.sequences.v11.5.fa",
		        "enrichment_path": "313603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313603.protein.info.v11.5.txt",
		        "node_list_path": "313603.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumZor0006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium ZOR0006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumZor0006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1339252.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1339252.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1339252.clusters.proteins.v11.5.txt",
		        "sequence_path": "1339252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1339252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1339252.protein.info.v11.5.txt",
		        "node_list_path": "1339252.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1339252.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSp37zxx(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 37zxx graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSp37zxx", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1550073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550073.protein.info.v11.5.txt",
		        "node_list_path": "1550073.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioPanuliri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio panuliri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioPanuliri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1381081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381081.protein.info.v11.5.txt",
		        "node_list_path": "1381081.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerinicoccusChungangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serinicoccus chungangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerinicoccusChungangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "767452.protein.sequences.v11.5.fa",
		        "enrichment_path": "767452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767452.protein.info.v11.5.txt",
		        "node_list_path": "767452.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChytriomycesConfervae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chytriomyces confervae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChytriomycesConfervae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246404.protein.sequences.v11.5.fa",
		        "enrichment_path": "246404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246404.protein.info.v11.5.txt",
		        "node_list_path": "246404.protein.complete.v11.5.txt"
		    }
		]
    )()

def CulexQuinquefasciatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Culex quinquefasciatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CulexQuinquefasciatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7176.clusters.proteins.v11.5.txt",
		        "sequence_path": "7176.protein.sequences.v11.5.fa",
		        "enrichment_path": "7176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7176.protein.info.v11.5.txt",
		        "node_list_path": "7176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CloacimonasAcidaminovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cloacimonas acidaminovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CloacimonasAcidaminovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "459349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "459349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "459349.clusters.proteins.v11.5.txt",
		        "sequence_path": "459349.protein.sequences.v11.5.fa",
		        "enrichment_path": "459349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "459349.protein.info.v11.5.txt",
		        "node_list_path": "459349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "459349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCb03234Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB03234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCb03234Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703937.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703937.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703937.protein.info.v11.5.txt",
		        "node_list_path": "1703937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSoil761Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil761 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSoil761Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736400.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736400.protein.info.v11.5.txt",
		        "node_list_path": "1736400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterAntarcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterAntarcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "564117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "564117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "564117.clusters.proteins.v11.5.txt",
		        "sequence_path": "564117.protein.sequences.v11.5.fa",
		        "enrichment_path": "564117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "564117.protein.info.v11.5.txt",
		        "node_list_path": "564117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "564117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobiBacteriumOlb4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobi bacterium OLB4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiBacteriumOlb4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617411.protein.info.v11.5.txt",
		        "node_list_path": "1617411.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermovirgaLieniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermovirga lienii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermovirgaLieniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "580340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "580340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "580340.clusters.proteins.v11.5.txt",
		        "sequence_path": "580340.protein.sequences.v11.5.fa",
		        "enrichment_path": "580340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "580340.protein.info.v11.5.txt",
		        "node_list_path": "580340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "580340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidiferrobacterThiooxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidiferrobacter thiooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidiferrobacterThiooxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "163359.protein.sequences.v11.5.fa",
		        "enrichment_path": "163359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "163359.protein.info.v11.5.txt",
		        "node_list_path": "163359.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasUenonisDsm23387Jcm13868Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis DSM 23387 JCM 13868 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasUenonisDsm23387Jcm13868Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122976.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122976.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122976.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122976.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122976.protein.info.v11.5.txt",
		        "node_list_path": "1122976.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122976.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpWmma185Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. WMMA185 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpWmma185Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679318.clusters.proteins.v11.5.txt",
		        "sequence_path": "679318.protein.sequences.v11.5.fa",
		        "enrichment_path": "679318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679318.protein.info.v11.5.txt",
		        "node_list_path": "679318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GloeobacterViolaceusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gloeobacter violaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeobacterViolaceusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "251221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "251221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "251221.clusters.proteins.v11.5.txt",
		        "sequence_path": "251221.protein.sequences.v11.5.fa",
		        "enrichment_path": "251221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "251221.protein.info.v11.5.txt",
		        "node_list_path": "251221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "251221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteusVulgaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteus vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteusVulgaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585.protein.sequences.v11.5.fa",
		        "enrichment_path": "585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585.protein.info.v11.5.txt",
		        "node_list_path": "585.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldithrixAbyssiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldithrix abyssi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldithrixAbyssiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "880073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "880073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "880073.clusters.proteins.v11.5.txt",
		        "sequence_path": "880073.protein.sequences.v11.5.fa",
		        "enrichment_path": "880073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880073.protein.info.v11.5.txt",
		        "node_list_path": "880073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "880073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CriibacteriumBergeroniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Criibacterium bergeronii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CriibacteriumBergeroniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871336.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871336.protein.info.v11.5.txt",
		        "node_list_path": "1871336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DuganellaZoogloeoidesAtcc25935(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Duganella zoogloeoides ATCC 25935 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaZoogloeoidesAtcc25935", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1261617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261617.protein.info.v11.5.txt",
		        "node_list_path": "1261617.protein.complete.v11.5.txt"
		    }
		]
    )()

def SediminimonasQiaohouensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sediminimonas qiaohouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminimonasQiaohouensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123247.protein.info.v11.5.txt",
		        "node_list_path": "1123247.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSp31syn3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. 31syn3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSp31syn3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "457398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "457398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "457398.clusters.proteins.v11.5.txt",
		        "sequence_path": "457398.protein.sequences.v11.5.fa",
		        "enrichment_path": "457398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457398.protein.info.v11.5.txt",
		        "node_list_path": "457398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "457398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4249Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_42_49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4249Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802694.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802694.protein.info.v11.5.txt",
		        "node_list_path": "1802694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCellulolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cellulolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCellulolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "394503.clusters.info.v11.5.txt",
		        "cluster_tree_path": "394503.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "394503.clusters.proteins.v11.5.txt",
		        "sequence_path": "394503.protein.sequences.v11.5.fa",
		        "enrichment_path": "394503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394503.protein.info.v11.5.txt",
		        "node_list_path": "394503.cluster.nodes.v11.5.txt",
		        "edge_list_path": "394503.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaSpAbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. aB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpAbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "517433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "517433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "517433.clusters.proteins.v11.5.txt",
		        "sequence_path": "517433.protein.sequences.v11.5.fa",
		        "enrichment_path": "517433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "517433.protein.info.v11.5.txt",
		        "node_list_path": "517433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "517433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpCag956(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:956 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpCag956", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262908.protein.info.v11.5.txt",
		        "node_list_path": "1262908.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusHunanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus hunanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusHunanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "578214.protein.sequences.v11.5.fa",
		        "enrichment_path": "578214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578214.protein.info.v11.5.txt",
		        "node_list_path": "578214.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasAxonopodisVasculorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis vasculorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasAxonopodisVasculorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "325777.protein.sequences.v11.5.fa",
		        "enrichment_path": "325777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "325777.protein.info.v11.5.txt",
		        "node_list_path": "325777.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHarrisonbacteriaBacteriumRifcsphigho212Full4816(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPHIGHO2_12_FULL_48_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsphigho212Full4816", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798405.protein.info.v11.5.txt",
		        "node_list_path": "1798405.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwa24319(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_43_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa24319", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797804.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797804.protein.info.v11.5.txt",
		        "node_list_path": "1797804.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls237Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS237 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls237Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463895.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463895.protein.info.v11.5.txt",
		        "node_list_path": "1463895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumGa0074139Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium Ga0074139 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumGa0074139Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752196.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752196.protein.info.v11.5.txt",
		        "node_list_path": "1752196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasLuteoviolaceaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas luteoviolacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasLuteoviolaceaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43657.clusters.proteins.v11.5.txt",
		        "sequence_path": "43657.protein.sequences.v11.5.fa",
		        "enrichment_path": "43657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43657.protein.info.v11.5.txt",
		        "node_list_path": "43657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalogranumRubrumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halogranum rubrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalogranumRubrumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553466.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553466.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553466.clusters.proteins.v11.5.txt",
		        "sequence_path": "553466.protein.sequences.v11.5.fa",
		        "enrichment_path": "553466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553466.protein.info.v11.5.txt",
		        "node_list_path": "553466.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553466.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenibacillusSchlegeliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenibacillus schlegelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenibacillusSchlegeliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1484.clusters.proteins.v11.5.txt",
		        "sequence_path": "1484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484.protein.info.v11.5.txt",
		        "node_list_path": "1484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpF0295(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0295 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpF0295", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "619693.protein.sequences.v11.5.fa",
		        "enrichment_path": "619693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "619693.protein.info.v11.5.txt",
		        "node_list_path": "619693.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpDabAl43bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. DAB_AL43B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpDabAl43bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1028416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1028416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1028416.clusters.proteins.v11.5.txt",
		        "sequence_path": "1028416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028416.protein.info.v11.5.txt",
		        "node_list_path": "1028416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1028416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacillusEquuliSubspEquuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus equuli subsp. equuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusEquuliSubspEquuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "202947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "202947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "202947.clusters.proteins.v11.5.txt",
		        "sequence_path": "202947.protein.sequences.v11.5.fa",
		        "enrichment_path": "202947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202947.protein.info.v11.5.txt",
		        "node_list_path": "202947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "202947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusFlavefaciens007cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens 007c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusFlavefaciens007cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1341157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1341157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1341157.clusters.proteins.v11.5.txt",
		        "sequence_path": "1341157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341157.protein.info.v11.5.txt",
		        "node_list_path": "1341157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1341157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprinellusMicaceusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprinellus micaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprinellusMicaceusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "71717.clusters.info.v11.5.txt",
		        "cluster_tree_path": "71717.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "71717.clusters.proteins.v11.5.txt",
		        "sequence_path": "71717.protein.sequences.v11.5.fa",
		        "enrichment_path": "71717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "71717.protein.info.v11.5.txt",
		        "node_list_path": "71717.cluster.nodes.v11.5.txt",
		        "edge_list_path": "71717.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AggregatibacterAphrophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter aphrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterAphrophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634176.protein.sequences.v11.5.fa",
		        "enrichment_path": "634176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634176.protein.info.v11.5.txt",
		        "node_list_path": "634176.protein.complete.v11.5.txt"
		    }
		]
    )()

def DomibacillusEpiphyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus epiphyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusEpiphyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1714355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1714355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1714355.clusters.proteins.v11.5.txt",
		        "sequence_path": "1714355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714355.protein.info.v11.5.txt",
		        "node_list_path": "1714355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1714355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaGenomosp8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaGenomosp8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1416806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1416806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1416806.clusters.proteins.v11.5.txt",
		        "sequence_path": "1416806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416806.protein.info.v11.5.txt",
		        "node_list_path": "1416806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1416806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EhrlichiaRuminantiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia ruminantium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EhrlichiaRuminantiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "254945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "254945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "254945.clusters.proteins.v11.5.txt",
		        "sequence_path": "254945.protein.sequences.v11.5.fa",
		        "enrichment_path": "254945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "254945.protein.info.v11.5.txt",
		        "node_list_path": "254945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "254945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaladaptatusCibariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haladaptatus cibarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaladaptatusCibariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1455608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1455608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1455608.clusters.proteins.v11.5.txt",
		        "sequence_path": "1455608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1455608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1455608.protein.info.v11.5.txt",
		        "node_list_path": "1455608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1455608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychroflexusSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychroflexus sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroflexusSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "470826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "470826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "470826.clusters.proteins.v11.5.txt",
		        "sequence_path": "470826.protein.sequences.v11.5.fa",
		        "enrichment_path": "470826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "470826.protein.info.v11.5.txt",
		        "node_list_path": "470826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "470826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpCnj954Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. CNJ-954 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpCnj954Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1904962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1904962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1904962.clusters.proteins.v11.5.txt",
		        "sequence_path": "1904962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904962.protein.info.v11.5.txt",
		        "node_list_path": "1904962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1904962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AciduliprofundumBoonei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aciduliprofundum boonei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AciduliprofundumBoonei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "439481.protein.sequences.v11.5.fa",
		        "enrichment_path": "439481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439481.protein.info.v11.5.txt",
		        "node_list_path": "439481.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaceaeBacteriumMarseilleP2826(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotellaceae bacterium Marseille-P2826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaceaeBacteriumMarseilleP2826", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852368.protein.info.v11.5.txt",
		        "node_list_path": "1852368.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioDiazotrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio diazotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioDiazotrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348635.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348635.protein.info.v11.5.txt",
		        "node_list_path": "1348635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterSpAap82Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. AAP82 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterSpAap82Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1248917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1248917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1248917.clusters.proteins.v11.5.txt",
		        "sequence_path": "1248917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1248917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1248917.protein.info.v11.5.txt",
		        "node_list_path": "1248917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1248917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PavoCristatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pavo cristatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PavoCristatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9049.protein.sequences.v11.5.fa",
		        "enrichment_path": "9049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9049.protein.info.v11.5.txt",
		        "node_list_path": "9049.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusDentisani7746(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dentisani 7746 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDentisani7746", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1297534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297534.protein.info.v11.5.txt",
		        "node_list_path": "1297534.protein.complete.v11.5.txt"
		    }
		]
    )()

def Sar92BacteriumBacl16Mag120619Bin48(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return SAR92 bacterium BACL16 MAG-120619-bin48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar92BacteriumBacl16Mag120619Bin48", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1655625.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655625.protein.info.v11.5.txt",
		        "node_list_path": "1655625.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoculleusBourgensisMs2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus bourgensis MS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusBourgensisMs2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1201294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1201294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1201294.protein.info.v11.5.txt",
		        "node_list_path": "1201294.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerobrancaGottschalkiiDsm13577(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobranca gottschalkii DSM 13577 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobrancaGottschalkiiDsm13577", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120990.protein.info.v11.5.txt",
		        "node_list_path": "1120990.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxya2Full5338Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2_FULL_53_38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2Full5338Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797961.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797961.protein.info.v11.5.txt",
		        "node_list_path": "1797961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfolobusSpA20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus sp. A20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusSpA20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1891280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891280.protein.info.v11.5.txt",
		        "node_list_path": "1891280.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryptococcusNeoformansVarNeoformansJec21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus neoformans var. neoformans JEC21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptococcusNeoformansVarNeoformansJec21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "214684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "214684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "214684.clusters.proteins.v11.5.txt",
		        "sequence_path": "214684.protein.sequences.v11.5.fa",
		        "enrichment_path": "214684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "214684.protein.info.v11.5.txt",
		        "node_list_path": "214684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "214684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalolaminaRubraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halolamina rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolaminaRubraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380430.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380430.protein.info.v11.5.txt",
		        "node_list_path": "1380430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumRhizosphaeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumRhizosphaeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1672749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1672749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1672749.clusters.proteins.v11.5.txt",
		        "sequence_path": "1672749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1672749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1672749.protein.info.v11.5.txt",
		        "node_list_path": "1672749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1672749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumCamembertiFm013Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium camemberti FM 013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumCamembertiFm013Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1429867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1429867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1429867.clusters.proteins.v11.5.txt",
		        "sequence_path": "1429867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1429867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1429867.protein.info.v11.5.txt",
		        "node_list_path": "1429867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1429867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GorillibacteriumTimonenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gorillibacterium timonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GorillibacteriumTimonenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1689269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1689269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1689269.clusters.proteins.v11.5.txt",
		        "sequence_path": "1689269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1689269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1689269.protein.info.v11.5.txt",
		        "node_list_path": "1689269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1689269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaFelis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia felis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaFelis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "315456.protein.sequences.v11.5.fa",
		        "enrichment_path": "315456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "315456.protein.info.v11.5.txt",
		        "node_list_path": "315456.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrnithinibacillusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ornithinibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithinibacillusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930117.protein.sequences.v11.5.fa",
		        "enrichment_path": "930117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930117.protein.info.v11.5.txt",
		        "node_list_path": "930117.protein.complete.v11.5.txt"
		    }
		]
    )()

def TalaromycesStipitatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces stipitatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesStipitatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28564.protein.sequences.v11.5.fa",
		        "enrichment_path": "28564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28564.protein.info.v11.5.txt",
		        "node_list_path": "28564.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChiloSuppressalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chilo suppressalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChiloSuppressalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "168631.clusters.info.v11.5.txt",
		        "cluster_tree_path": "168631.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "168631.clusters.proteins.v11.5.txt",
		        "sequence_path": "168631.protein.sequences.v11.5.fa",
		        "enrichment_path": "168631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "168631.protein.info.v11.5.txt",
		        "node_list_path": "168631.cluster.nodes.v11.5.txt",
		        "edge_list_path": "168631.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonScgcAaa282K18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon SCGC AAA282-K18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonScgcAaa282K18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298885.protein.info.v11.5.txt",
		        "node_list_path": "1298885.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaWeaveriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria weaveri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaWeaveriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1051985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1051985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1051985.clusters.proteins.v11.5.txt",
		        "sequence_path": "1051985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051985.protein.info.v11.5.txt",
		        "node_list_path": "1051985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1051985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterCinaediCcug18818Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi CCUG18818 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterCinaediCcug18818Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "537971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "537971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "537971.clusters.proteins.v11.5.txt",
		        "sequence_path": "537971.protein.sequences.v11.5.fa",
		        "enrichment_path": "537971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537971.protein.info.v11.5.txt",
		        "node_list_path": "537971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "537971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromatiaceaeBacterium2141tStbd0c01aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chromatiaceae bacterium 2141T.STBD.0c.01a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromatiaceaeBacterium2141tStbd0c01aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1978339.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1978339.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1978339.clusters.proteins.v11.5.txt",
		        "sequence_path": "1978339.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978339.protein.info.v11.5.txt",
		        "node_list_path": "1978339.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1978339.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomaduraFlavalba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura flavalba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraFlavalba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "561175.protein.sequences.v11.5.fa",
		        "enrichment_path": "561175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561175.protein.info.v11.5.txt",
		        "node_list_path": "561175.protein.complete.v11.5.txt"
		    }
		]
    )()

def VirgibacillusAlimentariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus alimentarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusAlimentariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "698769.clusters.info.v11.5.txt",
		        "cluster_tree_path": "698769.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "698769.clusters.proteins.v11.5.txt",
		        "sequence_path": "698769.protein.sequences.v11.5.fa",
		        "enrichment_path": "698769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698769.protein.info.v11.5.txt",
		        "node_list_path": "698769.cluster.nodes.v11.5.txt",
		        "edge_list_path": "698769.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusBvHnlc2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus bv. HNLC2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusBvHnlc2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041939.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041939.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041939.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041939.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041939.protein.info.v11.5.txt",
		        "node_list_path": "1041939.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041939.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterRoseosalivariusDsm11622(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter roseosalivarius DSM 11622 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterRoseosalivariusDsm11622", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "645990.protein.sequences.v11.5.fa",
		        "enrichment_path": "645990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645990.protein.info.v11.5.txt",
		        "node_list_path": "645990.protein.complete.v11.5.txt"
		    }
		]
    )()

def FontibacillusPanacisegetis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fontibacillus panacisegetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FontibacillusPanacisegetis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "670482.protein.sequences.v11.5.fa",
		        "enrichment_path": "670482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670482.protein.info.v11.5.txt",
		        "node_list_path": "670482.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaSediminicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina sediminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSediminicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095026.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095026.protein.info.v11.5.txt",
		        "node_list_path": "1095026.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasFlueggeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas flueggei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasFlueggeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "638302.clusters.info.v11.5.txt",
		        "cluster_tree_path": "638302.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "638302.clusters.proteins.v11.5.txt",
		        "sequence_path": "638302.protein.sequences.v11.5.fa",
		        "enrichment_path": "638302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "638302.protein.info.v11.5.txt",
		        "node_list_path": "638302.cluster.nodes.v11.5.txt",
		        "edge_list_path": "638302.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpHot20860m813o14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. HOT208_60m_813O14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpHot20860m813o14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1961094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1961094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1961094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1961094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961094.protein.info.v11.5.txt",
		        "node_list_path": "1961094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1961094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidithiobacillusFerrooxidansAtcc53993(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans ATCC53993 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithiobacillusFerrooxidansAtcc53993", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "380394.protein.sequences.v11.5.fa",
		        "enrichment_path": "380394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380394.protein.info.v11.5.txt",
		        "node_list_path": "380394.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumBrhC0(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium BRH_c0 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumBrhC0", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629722.protein.info.v11.5.txt",
		        "node_list_path": "1629722.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMarithrixSpCanyon246(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Marithrix sp. Canyon 246 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMarithrixSpCanyon246", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1827136.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827136.protein.info.v11.5.txt",
		        "node_list_path": "1827136.protein.complete.v11.5.txt"
		    }
		]
    )()

def OpisthorchisViverrini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Opisthorchis viverrini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpisthorchisViverrini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6198.protein.sequences.v11.5.fa",
		        "enrichment_path": "6198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6198.protein.info.v11.5.txt",
		        "node_list_path": "6198.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpScn6822(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. SCN 68-22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpScn6822", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660087.protein.info.v11.5.txt",
		        "node_list_path": "1660087.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetarhiziumAcridum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium acridum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetarhiziumAcridum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "92637.protein.sequences.v11.5.fa",
		        "enrichment_path": "92637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92637.protein.info.v11.5.txt",
		        "node_list_path": "92637.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioDesulfuricansDsm642Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans DSM642 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioDesulfuricansDsm642Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121445.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121445.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121445.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121445.protein.info.v11.5.txt",
		        "node_list_path": "1121445.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121445.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaueraPhenolivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera phenolivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraPhenolivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1792543.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1792543.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1792543.clusters.proteins.v11.5.txt",
		        "sequence_path": "1792543.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792543.protein.info.v11.5.txt",
		        "node_list_path": "1792543.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1792543.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaSpHmsc071c03Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC071C03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSpHmsc071c03Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739257.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739257.protein.info.v11.5.txt",
		        "node_list_path": "1739257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpH053(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H053 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpH053", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1759067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759067.protein.info.v11.5.txt",
		        "node_list_path": "1759067.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusNidulans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus nidulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusNidulans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "162425.protein.sequences.v11.5.fa",
		        "enrichment_path": "162425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "162425.protein.info.v11.5.txt",
		        "node_list_path": "162425.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusReuteriDsm20016(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri DSM20016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusReuteriDsm20016", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "557436.protein.sequences.v11.5.fa",
		        "enrichment_path": "557436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "557436.protein.info.v11.5.txt",
		        "node_list_path": "557436.protein.complete.v11.5.txt"
		    }
		]
    )()

def JeotgalicoccusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalicoccus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalicoccusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "586411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "586411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "586411.clusters.proteins.v11.5.txt",
		        "sequence_path": "586411.protein.sequences.v11.5.fa",
		        "enrichment_path": "586411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "586411.protein.info.v11.5.txt",
		        "node_list_path": "586411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "586411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EzakiellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ezakiella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EzakiellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852374.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852374.protein.info.v11.5.txt",
		        "node_list_path": "1852374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzospirillumSpB510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum sp. B510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumSpB510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "137722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "137722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "137722.clusters.proteins.v11.5.txt",
		        "sequence_path": "137722.protein.sequences.v11.5.fa",
		        "enrichment_path": "137722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137722.protein.info.v11.5.txt",
		        "node_list_path": "137722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "137722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwc25546(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_55_46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc25546", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797818.protein.info.v11.5.txt",
		        "node_list_path": "1797818.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurimonasSpRifoxyb12Full359Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFOXYB12_FULL_35_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasSpRifoxyb12Full359Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802256.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802256.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802256.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802256.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802256.protein.info.v11.5.txt",
		        "node_list_path": "1802256.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802256.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlsenellaTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805478.protein.info.v11.5.txt",
		        "node_list_path": "1805478.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumPhyllostachyosCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium phyllostachyos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumPhyllostachyosCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582672.clusters.proteins.v11.5.txt",
		        "sequence_path": "582672.protein.sequences.v11.5.fa",
		        "enrichment_path": "582672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582672.protein.info.v11.5.txt",
		        "node_list_path": "582672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanothermobacterMarburgensisStrMarburg(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter marburgensis str. Marburg graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermobacterMarburgensisStrMarburg", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "79929.protein.sequences.v11.5.fa",
		        "enrichment_path": "79929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79929.protein.info.v11.5.txt",
		        "node_list_path": "79929.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaAmarae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia amarae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaAmarae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1075090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1075090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1075090.protein.info.v11.5.txt",
		        "node_list_path": "1075090.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumFlavescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumFlavescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28028.protein.sequences.v11.5.fa",
		        "enrichment_path": "28028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28028.protein.info.v11.5.txt",
		        "node_list_path": "28028.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasLutea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas lutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasLutea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121943.protein.info.v11.5.txt",
		        "node_list_path": "1121943.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLc145(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. LC145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLc145", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120688.protein.info.v11.5.txt",
		        "node_list_path": "1120688.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaPaucivoransNbrc100373(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia paucivorans NBRC 100373 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaPaucivoransNbrc100373", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206734.protein.info.v11.5.txt",
		        "node_list_path": "1206734.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxValerianellae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax valerianellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxValerianellae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "187868.protein.sequences.v11.5.fa",
		        "enrichment_path": "187868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "187868.protein.info.v11.5.txt",
		        "node_list_path": "187868.protein.complete.v11.5.txt"
		    }
		]
    )()

def TupaiaBelangeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tupaia belangeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TupaiaBelangeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37347.protein.sequences.v11.5.fa",
		        "enrichment_path": "37347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37347.protein.info.v11.5.txt",
		        "node_list_path": "37347.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanotheceSpAtcc51142(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. ATCC51142 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanotheceSpAtcc51142", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43989.protein.sequences.v11.5.fa",
		        "enrichment_path": "43989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43989.protein.info.v11.5.txt",
		        "node_list_path": "43989.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichodermaLongibrachiatumAtcc18648Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma longibrachiatum ATCC 18648 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaLongibrachiatumAtcc18648Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983965.clusters.proteins.v11.5.txt",
		        "sequence_path": "983965.protein.sequences.v11.5.fa",
		        "enrichment_path": "983965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983965.protein.info.v11.5.txt",
		        "node_list_path": "983965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CanisLupusDingo(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Canis lupus dingo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CanisLupusDingo", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "286419.protein.sequences.v11.5.fa",
		        "enrichment_path": "286419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "286419.protein.info.v11.5.txt",
		        "node_list_path": "286419.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag631Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:631 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag631Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262996.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262996.protein.info.v11.5.txt",
		        "node_list_path": "1262996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterGottschalkii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter gottschalkii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterGottschalkii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "190974.protein.sequences.v11.5.fa",
		        "enrichment_path": "190974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190974.protein.info.v11.5.txt",
		        "node_list_path": "190974.protein.complete.v11.5.txt"
		    }
		]
    )()

def AliicoccusPersicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliicoccus persicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliicoccusPersicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930138.clusters.proteins.v11.5.txt",
		        "sequence_path": "930138.protein.sequences.v11.5.fa",
		        "enrichment_path": "930138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930138.protein.info.v11.5.txt",
		        "node_list_path": "930138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StrongyloidesStercoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Strongyloides stercoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrongyloidesStercoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6248.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6248.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6248.clusters.proteins.v11.5.txt",
		        "sequence_path": "6248.protein.sequences.v11.5.fa",
		        "enrichment_path": "6248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6248.protein.info.v11.5.txt",
		        "node_list_path": "6248.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6248.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichococcusIlyis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichococcus ilyis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichococcusIlyis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "640938.protein.sequences.v11.5.fa",
		        "enrichment_path": "640938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640938.protein.info.v11.5.txt",
		        "node_list_path": "640938.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumCaeni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumCaeni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "490189.protein.sequences.v11.5.fa",
		        "enrichment_path": "490189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "490189.protein.info.v11.5.txt",
		        "node_list_path": "490189.protein.complete.v11.5.txt"
		    }
		]
    )()

def SecondaryEndosymbiontOfTrabutinaMannipara(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Trabutina mannipara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SecondaryEndosymbiontOfTrabutinaMannipara", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1835721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1835721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1835721.protein.info.v11.5.txt",
		        "node_list_path": "1835721.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1934979.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1934979.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1934979.clusters.proteins.v11.5.txt",
		        "sequence_path": "1934979.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934979.protein.info.v11.5.txt",
		        "node_list_path": "1934979.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1934979.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpUrhb0015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. URHB0015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpUrhb0015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380376.protein.info.v11.5.txt",
		        "node_list_path": "1380376.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumMerdae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium merdae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumMerdae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1958780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1958780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1958780.protein.info.v11.5.txt",
		        "node_list_path": "1958780.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr37Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr37Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1934994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1934994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1934994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1934994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934994.protein.info.v11.5.txt",
		        "node_list_path": "1934994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1934994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAnimalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus animalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAnimalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1605.protein.info.v11.5.txt",
		        "node_list_path": "1605.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasLionensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas lionensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasLionensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144478.protein.info.v11.5.txt",
		        "node_list_path": "1144478.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoclostridiumDifficile630Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoclostridium difficile 630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoclostridiumDifficile630Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272563.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272563.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272563.clusters.proteins.v11.5.txt",
		        "sequence_path": "272563.protein.sequences.v11.5.fa",
		        "enrichment_path": "272563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272563.protein.info.v11.5.txt",
		        "node_list_path": "272563.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272563.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioMediterranei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio mediterranei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioMediterranei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "689.protein.sequences.v11.5.fa",
		        "enrichment_path": "689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "689.protein.info.v11.5.txt",
		        "node_list_path": "689.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpSgBin1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. SG-bin1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpSgBin1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1827376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1827376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1827376.clusters.proteins.v11.5.txt",
		        "sequence_path": "1827376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827376.protein.info.v11.5.txt",
		        "node_list_path": "1827376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1827376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasMuralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas muralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasMuralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "119000.protein.sequences.v11.5.fa",
		        "enrichment_path": "119000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "119000.protein.info.v11.5.txt",
		        "node_list_path": "119000.protein.complete.v11.5.txt"
		    }
		]
    )()

def PuniceibacteriumSpImcc21224Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Puniceibacterium sp. IMCC21224 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PuniceibacteriumSpImcc21224Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618204.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618204.protein.info.v11.5.txt",
		        "node_list_path": "1618204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSuwonensis111Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis 111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSuwonensis111Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743721.clusters.proteins.v11.5.txt",
		        "sequence_path": "743721.protein.sequences.v11.5.fa",
		        "enrichment_path": "743721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743721.protein.info.v11.5.txt",
		        "node_list_path": "743721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumParascrofulaceumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium parascrofulaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumParascrofulaceumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525368.clusters.proteins.v11.5.txt",
		        "sequence_path": "525368.protein.sequences.v11.5.fa",
		        "enrichment_path": "525368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525368.protein.info.v11.5.txt",
		        "node_list_path": "525368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MacacaMulatta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Macaca mulatta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacacaMulatta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9544.protein.sequences.v11.5.fa",
		        "enrichment_path": "9544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9544.protein.info.v11.5.txt",
		        "node_list_path": "9544.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_40_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801773.protein.info.v11.5.txt",
		        "node_list_path": "1801773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKerfeldbacteriaBacteriumRifcsphigho212Full4817(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPHIGHO2_12_FULL_48_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsphigho212Full4817", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798542.protein.info.v11.5.txt",
		        "node_list_path": "1798542.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobaculumParvumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobaculum parvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobaculumParvumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "517417.clusters.info.v11.5.txt",
		        "cluster_tree_path": "517417.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "517417.clusters.proteins.v11.5.txt",
		        "sequence_path": "517417.protein.sequences.v11.5.fa",
		        "enrichment_path": "517417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "517417.protein.info.v11.5.txt",
		        "node_list_path": "517417.cluster.nodes.v11.5.txt",
		        "edge_list_path": "517417.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSpHmsc075b08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. HMSC075B08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSpHmsc075b08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739525.protein.info.v11.5.txt",
		        "node_list_path": "1739525.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumTf0111Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium TF01-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumTf0111Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703332.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703332.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703332.protein.info.v11.5.txt",
		        "node_list_path": "1703332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusPhenolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus phenolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusPhenolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "263849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "263849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "263849.clusters.proteins.v11.5.txt",
		        "sequence_path": "263849.protein.sequences.v11.5.fa",
		        "enrichment_path": "263849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263849.protein.info.v11.5.txt",
		        "node_list_path": "263849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "263849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1205683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1205683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1205683.protein.info.v11.5.txt",
		        "node_list_path": "1205683.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumTakakiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium takakiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumTakakiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1302685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1302685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1302685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1302685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302685.protein.info.v11.5.txt",
		        "node_list_path": "1302685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1302685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumOlb15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumOlb15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617416.protein.info.v11.5.txt",
		        "node_list_path": "1617416.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxya2Full4753Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2_FULL_47_53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2Full4753Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797959.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797959.protein.info.v11.5.txt",
		        "node_list_path": "1797959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AneurinibacillusAneurinilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aneurinibacillus aneurinilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AneurinibacillusAneurinilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649747.clusters.proteins.v11.5.txt",
		        "sequence_path": "649747.protein.sequences.v11.5.fa",
		        "enrichment_path": "649747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649747.protein.info.v11.5.txt",
		        "node_list_path": "649747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlaciecolaSpHtcc2999(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola sp. HTCC2999 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaSpHtcc2999", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "455436.protein.sequences.v11.5.fa",
		        "enrichment_path": "455436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "455436.protein.info.v11.5.txt",
		        "node_list_path": "455436.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumScgcAaa168P09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA168-P09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumScgcAaa168P09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1009426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009426.protein.info.v11.5.txt",
		        "node_list_path": "1009426.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioRuminisAd2017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis AD2017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioRuminisAd2017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280694.protein.info.v11.5.txt",
		        "node_list_path": "1280694.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShigellaSonnei53g(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shigella sonnei 53G graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShigellaSonnei53g", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216599.protein.sequences.v11.5.fa",
		        "enrichment_path": "216599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216599.protein.info.v11.5.txt",
		        "node_list_path": "216599.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaSpRoot136(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia sp. Root136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSpRoot136", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736458.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736458.protein.info.v11.5.txt",
		        "node_list_path": "1736458.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinilyticumAquatileDsm21506(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinilyticum aquatile DSM 21506 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinilyticumAquatileDsm21506", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121275.protein.info.v11.5.txt",
		        "node_list_path": "1121275.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusFlavithermusWk1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus WK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusFlavithermusWk1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "491915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "491915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "491915.clusters.proteins.v11.5.txt",
		        "sequence_path": "491915.protein.sequences.v11.5.fa",
		        "enrichment_path": "491915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "491915.protein.info.v11.5.txt",
		        "node_list_path": "491915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "491915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DebaryomycesHanseniiCbs767Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Debaryomyces hansenii CBS767 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DebaryomycesHanseniiCbs767Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "284592.clusters.info.v11.5.txt",
		        "cluster_tree_path": "284592.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "284592.clusters.proteins.v11.5.txt",
		        "sequence_path": "284592.protein.sequences.v11.5.fa",
		        "enrichment_path": "284592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284592.protein.info.v11.5.txt",
		        "node_list_path": "284592.cluster.nodes.v11.5.txt",
		        "edge_list_path": "284592.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SlackiaHeliotrinireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Slackia heliotrinireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SlackiaHeliotrinireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471855.protein.sequences.v11.5.fa",
		        "enrichment_path": "471855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471855.protein.info.v11.5.txt",
		        "node_list_path": "471855.protein.complete.v11.5.txt"
		    }
		]
    )()

def TistrellaMobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tistrella mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TistrellaMobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1110502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1110502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1110502.protein.info.v11.5.txt",
		        "node_list_path": "1110502.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterCinaediPagu611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi PAGU611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterCinaediPagu611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1172562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172562.protein.info.v11.5.txt",
		        "node_list_path": "1172562.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumGbs2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium GBS-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumGbs2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1662109.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1662109.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1662109.clusters.proteins.v11.5.txt",
		        "sequence_path": "1662109.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662109.protein.info.v11.5.txt",
		        "node_list_path": "1662109.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1662109.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusBromiiL263(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus bromii L2-63 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusBromiiL263", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "657321.protein.sequences.v11.5.fa",
		        "enrichment_path": "657321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657321.protein.info.v11.5.txt",
		        "node_list_path": "657321.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrunusMume(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prunus mume graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrunusMume", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "102107.protein.sequences.v11.5.fa",
		        "enrichment_path": "102107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102107.protein.info.v11.5.txt",
		        "node_list_path": "102107.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaCaribensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia caribensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaCaribensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "75105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "75105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "75105.clusters.proteins.v11.5.txt",
		        "sequence_path": "75105.protein.sequences.v11.5.fa",
		        "enrichment_path": "75105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75105.protein.info.v11.5.txt",
		        "node_list_path": "75105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "75105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisRifamycinica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis rifamycinica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisRifamycinica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "287986.protein.sequences.v11.5.fa",
		        "enrichment_path": "287986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "287986.protein.info.v11.5.txt",
		        "node_list_path": "287986.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParusMajorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parus major Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParusMajorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9157.clusters.proteins.v11.5.txt",
		        "sequence_path": "9157.protein.sequences.v11.5.fa",
		        "enrichment_path": "9157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9157.protein.info.v11.5.txt",
		        "node_list_path": "9157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrososphaeraViennensisEn76(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrososphaera viennensis EN76 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrososphaeraViennensisEn76", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926571.protein.sequences.v11.5.fa",
		        "enrichment_path": "926571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926571.protein.info.v11.5.txt",
		        "node_list_path": "926571.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpC03Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpC03Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945858.protein.info.v11.5.txt",
		        "node_list_path": "1945858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAcidicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus acidicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAcidicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "209389.protein.sequences.v11.5.fa",
		        "enrichment_path": "209389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "209389.protein.info.v11.5.txt",
		        "node_list_path": "209389.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasSpNm51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasSpNm51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "133720.protein.sequences.v11.5.fa",
		        "enrichment_path": "133720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133720.protein.info.v11.5.txt",
		        "node_list_path": "133720.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPorcinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus porcinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPorcinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "873448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "873448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "873448.clusters.proteins.v11.5.txt",
		        "sequence_path": "873448.protein.sequences.v11.5.fa",
		        "enrichment_path": "873448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "873448.protein.info.v11.5.txt",
		        "node_list_path": "873448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "873448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GallusGallus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallus gallus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallusGallus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9031.protein.sequences.v11.5.fa",
		        "enrichment_path": "9031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9031.protein.info.v11.5.txt",
		        "node_list_path": "9031.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudobacteroidesCellulosolvensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobacteroides cellulosolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobacteroidesCellulosolvensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398512.clusters.proteins.v11.5.txt",
		        "sequence_path": "398512.protein.sequences.v11.5.fa",
		        "enrichment_path": "398512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398512.protein.info.v11.5.txt",
		        "node_list_path": "398512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XylophilusSpLeaf220Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylophilus sp. Leaf220 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylophilusSpLeaf220Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735686.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735686.protein.info.v11.5.txt",
		        "node_list_path": "1735686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacterRoseusDsm17521(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter roseus DSM 17521 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterRoseusDsm17521", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122967.protein.info.v11.5.txt",
		        "node_list_path": "1122967.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSherrisiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sherrisii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSherrisiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243061.clusters.proteins.v11.5.txt",
		        "sequence_path": "243061.protein.sequences.v11.5.fa",
		        "enrichment_path": "243061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243061.protein.info.v11.5.txt",
		        "node_list_path": "243061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwe23928Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_39_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwe23928Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797333.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797333.protein.info.v11.5.txt",
		        "node_list_path": "1797333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifoxyb1Full3816Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYB1_FULL_38_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyb1Full3816Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802538.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802538.protein.info.v11.5.txt",
		        "node_list_path": "1802538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpCf122Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF122 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpCf122Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144312.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144312.protein.info.v11.5.txt",
		        "node_list_path": "1144312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKomeilibacteriaBacteriumRifoxyc2Full4512(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFOXYC2_FULL_45_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifoxyc2Full4512", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798556.protein.info.v11.5.txt",
		        "node_list_path": "1798556.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaPertussisTohama(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella pertussis Tohama graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaPertussisTohama", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "257313.protein.sequences.v11.5.fa",
		        "enrichment_path": "257313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "257313.protein.info.v11.5.txt",
		        "node_list_path": "257313.protein.complete.v11.5.txt"
		    }
		]
    )()

def AggregatibacterSpOralTaxon458StrW10330(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter sp. oral taxon 458 str. W10330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterSpOralTaxon458StrW10330", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321772.protein.info.v11.5.txt",
		        "node_list_path": "1321772.protein.complete.v11.5.txt"
		    }
		]
    )()

def BotryobasidiumBotryosumFd172Ss1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Botryobasidium botryosum FD-172 SS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotryobasidiumBotryosumFd172Ss1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930990.protein.sequences.v11.5.fa",
		        "enrichment_path": "930990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930990.protein.info.v11.5.txt",
		        "node_list_path": "930990.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesUrogenitalisS6c4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis S6C4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesUrogenitalisS6c4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1284679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284679.protein.info.v11.5.txt",
		        "node_list_path": "1284679.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpLeaf344(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. Leaf344 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpLeaf344", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736346.protein.info.v11.5.txt",
		        "node_list_path": "1736346.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobotrysOligosporaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobotrys oligospora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobotrysOligosporaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13349.clusters.proteins.v11.5.txt",
		        "sequence_path": "13349.protein.sequences.v11.5.fa",
		        "enrichment_path": "13349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13349.protein.info.v11.5.txt",
		        "node_list_path": "13349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesGoldsteiniiDsm19448Wal12034Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides goldsteinii DSM 19448 WAL 12034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesGoldsteiniiDsm19448Wal12034Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "927665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "927665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "927665.clusters.proteins.v11.5.txt",
		        "sequence_path": "927665.protein.sequences.v11.5.fa",
		        "enrichment_path": "927665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927665.protein.info.v11.5.txt",
		        "node_list_path": "927665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "927665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospirillumFerrooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospirillum ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospirillumFerrooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1162668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1162668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1162668.protein.info.v11.5.txt",
		        "node_list_path": "1162668.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaAmnii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella amnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaAmnii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679191.protein.sequences.v11.5.fa",
		        "enrichment_path": "679191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679191.protein.info.v11.5.txt",
		        "node_list_path": "679191.protein.complete.v11.5.txt"
		    }
		]
    )()

def CatellicoccusMarimammalium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catellicoccus marimammalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatellicoccusMarimammalium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1234409.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234409.protein.info.v11.5.txt",
		        "node_list_path": "1234409.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzospirillumOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "286727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "286727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "286727.clusters.proteins.v11.5.txt",
		        "sequence_path": "286727.protein.sequences.v11.5.fa",
		        "enrichment_path": "286727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "286727.protein.info.v11.5.txt",
		        "node_list_path": "286727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "286727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusBovisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusBovisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1616788.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1616788.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1616788.clusters.proteins.v11.5.txt",
		        "sequence_path": "1616788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1616788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1616788.protein.info.v11.5.txt",
		        "node_list_path": "1616788.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1616788.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalvatorMerianaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salvator merianae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalvatorMerianaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "96440.clusters.info.v11.5.txt",
		        "cluster_tree_path": "96440.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "96440.clusters.proteins.v11.5.txt",
		        "sequence_path": "96440.protein.sequences.v11.5.fa",
		        "enrichment_path": "96440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "96440.protein.info.v11.5.txt",
		        "node_list_path": "96440.cluster.nodes.v11.5.txt",
		        "edge_list_path": "96440.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaOralTaxonTm7x(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria oral taxon TM7x graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaOralTaxonTm7x", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1476577.protein.sequences.v11.5.fa",
		        "enrichment_path": "1476577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1476577.protein.info.v11.5.txt",
		        "node_list_path": "1476577.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1638987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638987.protein.info.v11.5.txt",
		        "node_list_path": "1638987.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumJdfr77(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr77", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935107.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935107.protein.info.v11.5.txt",
		        "node_list_path": "1935107.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterDaqiaonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter daqiaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterDaqiaonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "650891.clusters.info.v11.5.txt",
		        "cluster_tree_path": "650891.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "650891.clusters.proteins.v11.5.txt",
		        "sequence_path": "650891.protein.sequences.v11.5.fa",
		        "enrichment_path": "650891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "650891.protein.info.v11.5.txt",
		        "node_list_path": "650891.cluster.nodes.v11.5.txt",
		        "edge_list_path": "650891.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRoot190Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root190 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRoot190Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736488.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736488.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736488.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736488.protein.info.v11.5.txt",
		        "node_list_path": "1736488.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736488.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonlabensDokdonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensDokdonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "592029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "592029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "592029.clusters.proteins.v11.5.txt",
		        "sequence_path": "592029.protein.sequences.v11.5.fa",
		        "enrichment_path": "592029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592029.protein.info.v11.5.txt",
		        "node_list_path": "592029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "592029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParageobacillusThermantarcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parageobacillus thermantarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParageobacillusThermantarcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "186116.protein.sequences.v11.5.fa",
		        "enrichment_path": "186116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "186116.protein.info.v11.5.txt",
		        "node_list_path": "186116.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaTimonae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia timonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaTimonae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883126.protein.sequences.v11.5.fa",
		        "enrichment_path": "883126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883126.protein.info.v11.5.txt",
		        "node_list_path": "883126.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcticibacterSvalbardensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcticibacter svalbardensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcticibacterSvalbardensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150600.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150600.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150600.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150600.protein.info.v11.5.txt",
		        "node_list_path": "1150600.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150600.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterSp6612Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. 66-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterSp6612Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895714.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895714.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895714.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895714.protein.info.v11.5.txt",
		        "node_list_path": "1895714.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895714.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusIainarchaeumAndersoniiScgcAaa011E11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Iainarchaeum andersonii SCGC AAA011-E11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusIainarchaeumAndersoniiScgcAaa011E11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1104576.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1104576.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1104576.clusters.proteins.v11.5.txt",
		        "sequence_path": "1104576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104576.protein.info.v11.5.txt",
		        "node_list_path": "1104576.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1104576.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarisediminitaleaAggregata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marisediminitalea aggregata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarisediminitaleaAggregata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634436.protein.sequences.v11.5.fa",
		        "enrichment_path": "634436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634436.protein.info.v11.5.txt",
		        "node_list_path": "634436.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinisphaeraHydrothermalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinisphaera hydrothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisphaeraHydrothermalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304275.protein.info.v11.5.txt",
		        "node_list_path": "1304275.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasBennonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas bennonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasBennonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122971.protein.info.v11.5.txt",
		        "node_list_path": "1122971.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumSpRifcsphigho201Full6931Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. RIFCSPHIGHO2_01_FULL_69_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumSpRifcsphigho201Full6931Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801944.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801944.protein.info.v11.5.txt",
		        "node_list_path": "1801944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasLuteola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas luteola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasLuteola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1207076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1207076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1207076.protein.info.v11.5.txt",
		        "node_list_path": "1207076.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrancisellaTularensisHolarctica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella tularensis holarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaTularensisHolarctica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "376619.protein.sequences.v11.5.fa",
		        "enrichment_path": "376619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376619.protein.info.v11.5.txt",
		        "node_list_path": "376619.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSecaliphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus secaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSecaliphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "396268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "396268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "396268.clusters.proteins.v11.5.txt",
		        "sequence_path": "396268.protein.sequences.v11.5.fa",
		        "enrichment_path": "396268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396268.protein.info.v11.5.txt",
		        "node_list_path": "396268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "396268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasAxonopodisVasculorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis vasculorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasAxonopodisVasculorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "325777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "325777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "325777.clusters.proteins.v11.5.txt",
		        "sequence_path": "325777.protein.sequences.v11.5.fa",
		        "enrichment_path": "325777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "325777.protein.info.v11.5.txt",
		        "node_list_path": "325777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "325777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218084.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218084.protein.info.v11.5.txt",
		        "node_list_path": "1218084.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumLentiflavum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium lentiflavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumLentiflavum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "141349.protein.sequences.v11.5.fa",
		        "enrichment_path": "141349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "141349.protein.info.v11.5.txt",
		        "node_list_path": "141349.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfuricurvumSpPc0866(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. PC08-66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricurvumSpPc0866", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1539066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1539066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1539066.protein.info.v11.5.txt",
		        "node_list_path": "1539066.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumScgcAaa028A23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA028-A23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumScgcAaa028A23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "932036.protein.sequences.v11.5.fa",
		        "enrichment_path": "932036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932036.protein.info.v11.5.txt",
		        "node_list_path": "932036.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpE14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. e14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpE14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "645465.protein.sequences.v11.5.fa",
		        "enrichment_path": "645465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645465.protein.info.v11.5.txt",
		        "node_list_path": "645465.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAle23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAle23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265495.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265495.protein.info.v11.5.txt",
		        "node_list_path": "1265495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full3910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_39_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full3910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798375.protein.info.v11.5.txt",
		        "node_list_path": "1798375.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetalesBacterium7110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 71-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetalesBacterium7110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895807.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895807.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895807.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895807.protein.info.v11.5.txt",
		        "node_list_path": "1895807.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895807.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarmoricolaSpLeaf446Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marmoricola sp. Leaf446 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarmoricolaSpLeaf446Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736379.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736379.protein.info.v11.5.txt",
		        "node_list_path": "1736379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacillusPsychrodurans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacillus psychrodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacillusPsychrodurans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "126157.protein.sequences.v11.5.fa",
		        "enrichment_path": "126157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "126157.protein.info.v11.5.txt",
		        "node_list_path": "126157.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgibacterPectinivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algibacter pectinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgibacterPectinivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "870482.protein.sequences.v11.5.fa",
		        "enrichment_path": "870482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "870482.protein.info.v11.5.txt",
		        "node_list_path": "870482.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlomusCerebriformeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glomus cerebriforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlomusCerebriformeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658196.clusters.proteins.v11.5.txt",
		        "sequence_path": "658196.protein.sequences.v11.5.fa",
		        "enrichment_path": "658196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658196.protein.info.v11.5.txt",
		        "node_list_path": "658196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpUnc279mftsu51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. UNC279MFTsu5.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpUnc279mftsu51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502775.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502775.protein.info.v11.5.txt",
		        "node_list_path": "1502775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSpHk10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora sp. HK10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSpHk10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1538294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1538294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1538294.protein.info.v11.5.txt",
		        "node_list_path": "1538294.protein.complete.v11.5.txt"
		    }
		]
    )()

def CrenothrixSpD3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crenothrix sp. D3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenothrixSpD3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1880899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1880899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1880899.clusters.proteins.v11.5.txt",
		        "sequence_path": "1880899.protein.sequences.v11.5.fa",
		        "enrichment_path": "1880899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1880899.protein.info.v11.5.txt",
		        "node_list_path": "1880899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1880899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaLacunata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella lacunata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaLacunata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "477.protein.sequences.v11.5.fa",
		        "enrichment_path": "477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "477.protein.info.v11.5.txt",
		        "node_list_path": "477.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioNereisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio nereis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioNereisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "693.clusters.proteins.v11.5.txt",
		        "sequence_path": "693.protein.sequences.v11.5.fa",
		        "enrichment_path": "693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693.protein.info.v11.5.txt",
		        "node_list_path": "693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptococcusNeoformansVarNeoformansJec21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus neoformans var. neoformans JEC21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptococcusNeoformansVarNeoformansJec21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "214684.protein.sequences.v11.5.fa",
		        "enrichment_path": "214684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "214684.protein.info.v11.5.txt",
		        "node_list_path": "214684.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasPhaseoliPvDieffenbachiaeLmg695(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas phaseoli pv. dieffenbachiae LMG 695 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasPhaseoliPvDieffenbachiaeLmg695", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437877.protein.info.v11.5.txt",
		        "node_list_path": "1437877.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpPhil15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. Phil15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpPhil15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930000.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930000.protein.info.v11.5.txt",
		        "node_list_path": "1930000.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoregulaBoonei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanoregula boonei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoregulaBoonei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "456442.protein.sequences.v11.5.fa",
		        "enrichment_path": "456442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "456442.protein.info.v11.5.txt",
		        "node_list_path": "456442.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5424(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5424", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798515.protein.info.v11.5.txt",
		        "node_list_path": "1798515.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSp161mfsha21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 161MFSha21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSp161mfsha21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1151118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151118.protein.info.v11.5.txt",
		        "node_list_path": "1151118.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptobacillusRatti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptobacillus ratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptobacillusRatti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720557.protein.info.v11.5.txt",
		        "node_list_path": "1720557.protein.complete.v11.5.txt"
		    }
		]
    )()

def SnodgrassellaAlviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Snodgrassella alvi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SnodgrassellaAlviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196083.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196083.protein.info.v11.5.txt",
		        "node_list_path": "1196083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumPuteiDsm12395Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum putei DSM 12395 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumPuteiDsm12395Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121429.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121429.protein.info.v11.5.txt",
		        "node_list_path": "1121429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpLeaf307(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Leaf307 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpLeaf307", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736331.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736331.protein.info.v11.5.txt",
		        "node_list_path": "1736331.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterSpAf1440(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. AF1440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSpAf1440", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1355374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1355374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1355374.protein.info.v11.5.txt",
		        "node_list_path": "1355374.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumPrunaredense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium prunaredense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumPrunaredense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1631249.protein.sequences.v11.5.fa",
		        "enrichment_path": "1631249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1631249.protein.info.v11.5.txt",
		        "node_list_path": "1631249.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzoarcusSpCibCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azoarcus sp. CIB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzoarcusSpCibCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "198107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "198107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "198107.clusters.proteins.v11.5.txt",
		        "sequence_path": "198107.protein.sequences.v11.5.fa",
		        "enrichment_path": "198107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198107.protein.info.v11.5.txt",
		        "node_list_path": "198107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "198107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfolobusMetallicusDsm6482Jcm9184(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus metallicus DSM 6482 JCM 9184 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusMetallicusDsm6482Jcm9184", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "523847.protein.sequences.v11.5.fa",
		        "enrichment_path": "523847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523847.protein.info.v11.5.txt",
		        "node_list_path": "523847.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfolobusTokodaii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus tokodaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusTokodaii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "273063.protein.sequences.v11.5.fa",
		        "enrichment_path": "273063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273063.protein.info.v11.5.txt",
		        "node_list_path": "273063.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumHaoraniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium haoranii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumHaoraniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "683124.clusters.info.v11.5.txt",
		        "cluster_tree_path": "683124.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "683124.clusters.proteins.v11.5.txt",
		        "sequence_path": "683124.protein.sequences.v11.5.fa",
		        "enrichment_path": "683124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683124.protein.info.v11.5.txt",
		        "node_list_path": "683124.cluster.nodes.v11.5.txt",
		        "edge_list_path": "683124.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSp6626Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. 66-26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSp6626Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895689.protein.info.v11.5.txt",
		        "node_list_path": "1895689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAle19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAle19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1266909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266909.protein.info.v11.5.txt",
		        "node_list_path": "1266909.protein.complete.v11.5.txt"
		    }
		]
    )()

def CrocinitomixAlgicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crocinitomix algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrocinitomixAlgicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1740263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1740263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1740263.clusters.proteins.v11.5.txt",
		        "sequence_path": "1740263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1740263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1740263.protein.info.v11.5.txt",
		        "node_list_path": "1740263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1740263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalolaminaSpCba1230Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halolamina sp. CBA1230 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolaminaSpCba1230Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1853690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1853690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1853690.clusters.proteins.v11.5.txt",
		        "sequence_path": "1853690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1853690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1853690.protein.info.v11.5.txt",
		        "node_list_path": "1853690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1853690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifcsphigho201Full63240(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPHIGHO2_01_FULL_63_240 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifcsphigho201Full63240", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797552.protein.info.v11.5.txt",
		        "node_list_path": "1797552.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterHepaticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter hepaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterHepaticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "235279.protein.sequences.v11.5.fa",
		        "enrichment_path": "235279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "235279.protein.info.v11.5.txt",
		        "node_list_path": "235279.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporothrixSchenckiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporothrix schenckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporothrixSchenckiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29908.clusters.proteins.v11.5.txt",
		        "sequence_path": "29908.protein.sequences.v11.5.fa",
		        "enrichment_path": "29908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29908.protein.info.v11.5.txt",
		        "node_list_path": "29908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAespoeensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio aespoeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAespoeensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "643562.protein.sequences.v11.5.fa",
		        "enrichment_path": "643562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "643562.protein.info.v11.5.txt",
		        "node_list_path": "643562.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylomicrobiumBuryatense5gCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomicrobium buryatense 5G Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomicrobiumBuryatense5gCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675511.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675511.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675511.clusters.proteins.v11.5.txt",
		        "sequence_path": "675511.protein.sequences.v11.5.fa",
		        "enrichment_path": "675511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675511.protein.info.v11.5.txt",
		        "node_list_path": "675511.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675511.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BoseaSpBiwako01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. BIWAKO-01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpBiwako01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "506668.protein.sequences.v11.5.fa",
		        "enrichment_path": "506668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "506668.protein.info.v11.5.txt",
		        "node_list_path": "506668.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaSpPamc21821Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia sp. PAMC 21821 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaSpPamc21821Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816219.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816219.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816219.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816219.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816219.protein.info.v11.5.txt",
		        "node_list_path": "1816219.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816219.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpRifcsphigho212Full6519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. RIFCSPHIGHO2_12_FULL_65_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpRifcsphigho212Full6519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802172.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802172.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802172.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802172.protein.info.v11.5.txt",
		        "node_list_path": "1802172.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802172.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArmatimonadetesBacteriumDcCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium DC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmatimonadetesBacteriumDcCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1661583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1661583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1661583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1661583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661583.protein.info.v11.5.txt",
		        "node_list_path": "1661583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1661583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoelleriellaLiberaRcef2490Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moelleriella libera RCEF 2490 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoelleriellaLiberaRcef2490Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1081109.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1081109.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1081109.clusters.proteins.v11.5.txt",
		        "sequence_path": "1081109.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081109.protein.info.v11.5.txt",
		        "node_list_path": "1081109.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1081109.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesFunestus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles funestus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesFunestus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "62324.protein.sequences.v11.5.fa",
		        "enrichment_path": "62324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62324.protein.info.v11.5.txt",
		        "node_list_path": "62324.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaHirsutaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia hirsuta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaHirsutaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121927.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121927.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121927.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121927.protein.info.v11.5.txt",
		        "node_list_path": "1121927.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121927.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VitreoscillaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vitreoscilla massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VitreoscillaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1689272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1689272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1689272.clusters.proteins.v11.5.txt",
		        "sequence_path": "1689272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1689272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1689272.protein.info.v11.5.txt",
		        "node_list_path": "1689272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1689272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumGilvumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium gilvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumGilvumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "350054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "350054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "350054.clusters.proteins.v11.5.txt",
		        "sequence_path": "350054.protein.sequences.v11.5.fa",
		        "enrichment_path": "350054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "350054.protein.info.v11.5.txt",
		        "node_list_path": "350054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "350054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinopolymorphaAlbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinopolymorpha alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolymorphaAlbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120950.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120950.protein.info.v11.5.txt",
		        "node_list_path": "1120950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacterMarinusA45(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacter marinus A45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacterMarinusA45", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "674036.protein.sequences.v11.5.fa",
		        "enrichment_path": "674036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "674036.protein.info.v11.5.txt",
		        "node_list_path": "674036.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaMaltophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema maltophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaMaltophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125699.protein.info.v11.5.txt",
		        "node_list_path": "1125699.protein.complete.v11.5.txt"
		    }
		]
    )()

def CordycepsMilitaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps militaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CordycepsMilitaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "73501.protein.sequences.v11.5.fa",
		        "enrichment_path": "73501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "73501.protein.info.v11.5.txt",
		        "node_list_path": "73501.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacterium3913(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 39-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacterium3913", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895767.protein.info.v11.5.txt",
		        "node_list_path": "1895767.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSwingsiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium swingsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSwingsiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "498292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "498292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "498292.clusters.proteins.v11.5.txt",
		        "sequence_path": "498292.protein.sequences.v11.5.fa",
		        "enrichment_path": "498292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498292.protein.info.v11.5.txt",
		        "node_list_path": "498292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "498292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobiumSpKb01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium sp. KB01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumSpKb01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1917528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1917528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1917528.clusters.proteins.v11.5.txt",
		        "sequence_path": "1917528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917528.protein.info.v11.5.txt",
		        "node_list_path": "1917528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1917528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusFastidiosusNbrc101226(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus fastidiosus NBRC 101226 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusFastidiosusNbrc101226", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348628.protein.info.v11.5.txt",
		        "node_list_path": "1348628.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLeaf371(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf371 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLeaf371", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736355.protein.info.v11.5.txt",
		        "node_list_path": "1736355.protein.complete.v11.5.txt"
		    }
		]
    )()

def PostiaPlacentaMad698RSb12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Postia placenta MAD-698-R-SB12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PostiaPlacentaMad698RSb12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "670580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "670580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "670580.clusters.proteins.v11.5.txt",
		        "sequence_path": "670580.protein.sequences.v11.5.fa",
		        "enrichment_path": "670580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670580.protein.info.v11.5.txt",
		        "node_list_path": "670580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "670580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpFl(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Fl graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpFl", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1506583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1506583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1506583.protein.info.v11.5.txt",
		        "node_list_path": "1506583.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScheffersomycesStipitisCbs6054(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scheffersomyces stipitis CBS 6054 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScheffersomycesStipitisCbs6054", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "322104.protein.sequences.v11.5.fa",
		        "enrichment_path": "322104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "322104.protein.info.v11.5.txt",
		        "node_list_path": "322104.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactucaSativa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactuca sativa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactucaSativa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4236.protein.sequences.v11.5.fa",
		        "enrichment_path": "4236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4236.protein.info.v11.5.txt",
		        "node_list_path": "4236.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusJidaibacterAcanthamoebaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jidaibacter acanthamoeba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJidaibacterAcanthamoebaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86105.clusters.proteins.v11.5.txt",
		        "sequence_path": "86105.protein.sequences.v11.5.fa",
		        "enrichment_path": "86105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86105.protein.info.v11.5.txt",
		        "node_list_path": "86105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumCuniculi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium cuniculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumCuniculi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1688.protein.info.v11.5.txt",
		        "node_list_path": "1688.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSp6754(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. 67-54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSp6754", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895754.protein.info.v11.5.txt",
		        "node_list_path": "1895754.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho202Full4219(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_42_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full4219", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801756.protein.info.v11.5.txt",
		        "node_list_path": "1801756.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalapricumSalinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halapricum salinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalapricumSalinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1457250.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1457250.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1457250.clusters.proteins.v11.5.txt",
		        "sequence_path": "1457250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1457250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1457250.protein.info.v11.5.txt",
		        "node_list_path": "1457250.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1457250.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumSpLf3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. LF3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumSpLf3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1504823.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1504823.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1504823.clusters.proteins.v11.0.txt",
		        "sequence_path": "1504823.protein.sequences.v11.0.fa",
		        "enrichment_path": "1504823.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1504823.protein.info.v11.0.txt",
		        "node_list_path": "1504823.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1504823.protein.cluster.v11.0.txt"
		    }
		]
    )()

def PrevotellaSp10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. 10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSp10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158294.protein.info.v11.5.txt",
		        "node_list_path": "1158294.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasSpAap120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas sp. AAP120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasSpAap120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523430.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523430.protein.info.v11.5.txt",
		        "node_list_path": "1523430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumLaevaniformans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium laevaniformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumLaevaniformans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36807.protein.sequences.v11.5.fa",
		        "enrichment_path": "36807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36807.protein.info.v11.5.txt",
		        "node_list_path": "36807.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterOleivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter oleivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterOleivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "436717.protein.sequences.v11.5.fa",
		        "enrichment_path": "436717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436717.protein.info.v11.5.txt",
		        "node_list_path": "436717.protein.complete.v11.5.txt"
		    }
		]
    )()

def NicotianaTabacum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nicotiana tabacum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NicotianaTabacum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4097.protein.sequences.v11.5.fa",
		        "enrichment_path": "4097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4097.protein.info.v11.5.txt",
		        "node_list_path": "4097.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumSpAk22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium sp. AK22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumSpAk22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229520.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229520.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229520.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229520.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229520.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229520.protein.info.v11.5.txt",
		        "node_list_path": "1229520.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229520.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCaseiBl23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus casei BL23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCaseiBl23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "543734.protein.sequences.v11.5.fa",
		        "enrichment_path": "543734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543734.protein.info.v11.5.txt",
		        "node_list_path": "543734.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasLionensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas lionensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasLionensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144478.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144478.protein.info.v11.5.txt",
		        "node_list_path": "1144478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlexibacterFlexilisDsm6793Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flexibacter flexilis DSM 6793 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlexibacterFlexilisDsm6793Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "927664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "927664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "927664.clusters.proteins.v11.5.txt",
		        "sequence_path": "927664.protein.sequences.v11.5.fa",
		        "enrichment_path": "927664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927664.protein.info.v11.5.txt",
		        "node_list_path": "927664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "927664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedArchaeonA07hr60(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HR60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedArchaeonA07hr60", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1412874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1412874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1412874.protein.info.v11.5.txt",
		        "node_list_path": "1412874.protein.complete.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpNTMorphotypeBCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. N.t. morphotype B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpNTMorphotypeBCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "420336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "420336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "420336.clusters.proteins.v11.5.txt",
		        "sequence_path": "420336.protein.sequences.v11.5.fa",
		        "enrichment_path": "420336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420336.protein.info.v11.5.txt",
		        "node_list_path": "420336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "420336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAkl11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. AKL11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAkl11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "545264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "545264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "545264.clusters.proteins.v11.5.txt",
		        "sequence_path": "545264.protein.sequences.v11.5.fa",
		        "enrichment_path": "545264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545264.protein.info.v11.5.txt",
		        "node_list_path": "545264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "545264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaNavojoaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila navojoa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaNavojoaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7232.clusters.proteins.v11.5.txt",
		        "sequence_path": "7232.protein.sequences.v11.5.fa",
		        "enrichment_path": "7232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7232.protein.info.v11.5.txt",
		        "node_list_path": "7232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcanthochromisPolyacanthus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acanthochromis polyacanthus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcanthochromisPolyacanthus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "80966.protein.sequences.v11.5.fa",
		        "enrichment_path": "80966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80966.protein.info.v11.5.txt",
		        "node_list_path": "80966.protein.complete.v11.5.txt"
		    }
		]
    )()

def SecondaryEndosymbiontOfHeteropsyllaCubana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Heteropsylla cubana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SecondaryEndosymbiontOfHeteropsyllaCubana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "134287.protein.sequences.v11.5.fa",
		        "enrichment_path": "134287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134287.protein.info.v11.5.txt",
		        "node_list_path": "134287.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusPallens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus pallens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusPallens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158607.protein.info.v11.5.txt",
		        "node_list_path": "1158607.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaSp3andimar09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella sp. 3ANDIMAR09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaSp3andimar09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1225657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1225657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1225657.clusters.proteins.v11.5.txt",
		        "sequence_path": "1225657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225657.protein.info.v11.5.txt",
		        "node_list_path": "1225657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1225657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag38Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag38Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262889.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262889.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262889.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262889.protein.info.v11.5.txt",
		        "node_list_path": "1262889.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262889.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumJeonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium jeonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumJeonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266749.protein.sequences.v11.5.fa",
		        "enrichment_path": "266749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266749.protein.info.v11.5.txt",
		        "node_list_path": "266749.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHdn1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HdN1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHdn1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83406.protein.sequences.v11.0.fa",
		        "enrichment_path": "83406.protein.enrichment.terms.v11.0.txt",
		        "info_path": "83406.protein.info.v11.0.txt",
		        "node_list_path": "83406.protein.complete.v11.0.txt"
		    }
		]
    )()

def StreptococcusOligofermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oligofermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOligofermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1302863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1302863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1302863.clusters.proteins.v11.5.txt",
		        "sequence_path": "1302863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302863.protein.info.v11.5.txt",
		        "node_list_path": "1302863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1302863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioclavaSpSk1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. SK-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaSpSk1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1889770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1889770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1889770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1889770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889770.protein.info.v11.5.txt",
		        "node_list_path": "1889770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1889770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpibacteriumMultivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epibacterium multivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpibacteriumMultivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "928856.protein.sequences.v11.5.fa",
		        "enrichment_path": "928856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "928856.protein.info.v11.5.txt",
		        "node_list_path": "928856.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSuis05zyh33(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis 05ZYH33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSuis05zyh33", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391295.protein.sequences.v11.5.fa",
		        "enrichment_path": "391295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391295.protein.info.v11.5.txt",
		        "node_list_path": "391295.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc3862Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC3862 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc3862Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217705.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217705.protein.info.v11.5.txt",
		        "node_list_path": "1217705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RheinheimeraSpKl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera sp. KL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraSpKl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635005.protein.info.v11.5.txt",
		        "node_list_path": "1635005.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeisingeraSpAng1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leisingera sp. ANG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraSpAng1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1002340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1002340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1002340.clusters.proteins.v11.5.txt",
		        "sequence_path": "1002340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002340.protein.info.v11.5.txt",
		        "node_list_path": "1002340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1002340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumSpRoot1290(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. Root1290 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumSpRoot1290", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736445.protein.info.v11.5.txt",
		        "node_list_path": "1736445.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaSpHmsc062g07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella sp. HMSC062G07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaSpHmsc062g07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739330.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739330.protein.info.v11.5.txt",
		        "node_list_path": "1739330.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852364.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852364.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852364.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852364.protein.info.v11.5.txt",
		        "node_list_path": "1852364.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852364.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaSpYqh10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. YQH10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSpYqh10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1515746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1515746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1515746.protein.info.v11.5.txt",
		        "node_list_path": "1515746.protein.complete.v11.5.txt"
		    }
		]
    )()

def SoonwooaBuanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Soonwooa buanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SoonwooaBuanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "619805.protein.sequences.v11.5.fa",
		        "enrichment_path": "619805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "619805.protein.info.v11.5.txt",
		        "node_list_path": "619805.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaSpSw150(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina sp. SW150 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaSpSw150", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1296415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296415.protein.info.v11.5.txt",
		        "node_list_path": "1296415.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHdn1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HdN1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHdn1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83406.clusters.info.v11.0.txt",
		        "cluster_tree_path": "83406.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "83406.clusters.proteins.v11.0.txt",
		        "sequence_path": "83406.protein.sequences.v11.0.fa",
		        "enrichment_path": "83406.protein.enrichment.terms.v11.0.txt",
		        "info_path": "83406.protein.info.v11.0.txt",
		        "node_list_path": "83406.cluster.nodes.v11.0.txt",
		        "edge_list_path": "83406.protein.cluster.v11.0.txt"
		    }
		]
    )()

def GeobacterSpM18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter sp. M18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterSpM18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "443143.protein.sequences.v11.5.fa",
		        "enrichment_path": "443143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443143.protein.info.v11.5.txt",
		        "node_list_path": "443143.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaloceraCorneaHhb12733Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Calocera cornea HHB12733 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloceraCorneaHhb12733Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1353952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1353952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1353952.clusters.proteins.v11.5.txt",
		        "sequence_path": "1353952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353952.protein.info.v11.5.txt",
		        "node_list_path": "1353952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1353952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumRifcsplowo212Full317(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium RIFCSPLOWO2_12_FULL_31_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumRifcsplowo212Full317", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798015.protein.info.v11.5.txt",
		        "node_list_path": "1798015.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumHochsteniumAtcc700873Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum hochstenium ATCC 700873 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumHochsteniumAtcc700873Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227481.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227481.protein.info.v11.5.txt",
		        "node_list_path": "1227481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "574651.protein.sequences.v11.5.fa",
		        "enrichment_path": "574651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574651.protein.info.v11.5.txt",
		        "node_list_path": "574651.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumHomopropionicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium homopropionicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumHomopropionicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36844.protein.sequences.v11.5.fa",
		        "enrichment_path": "36844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36844.protein.info.v11.5.txt",
		        "node_list_path": "36844.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRoot240Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root240 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRoot240Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736500.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736500.protein.info.v11.5.txt",
		        "node_list_path": "1736500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioSpLb2011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. LB2011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioSpLb2011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408312.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408312.protein.info.v11.5.txt",
		        "node_list_path": "1408312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumGw2011Gwe24535(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_45_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24535", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618993.protein.info.v11.5.txt",
		        "node_list_path": "1618993.protein.complete.v11.5.txt"
		    }
		]
    )()

def RiesiaPediculicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Riesia pediculicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RiesiaPediculicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "515618.protein.sequences.v11.5.fa",
		        "enrichment_path": "515618.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515618.protein.info.v11.5.txt",
		        "node_list_path": "515618.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumItalicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium italicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumItalicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40296.protein.sequences.v11.5.fa",
		        "enrichment_path": "40296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40296.protein.info.v11.5.txt",
		        "node_list_path": "40296.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaMontpellierensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella montpellierensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaMontpellierensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1401067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1401067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1401067.clusters.proteins.v11.5.txt",
		        "sequence_path": "1401067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401067.protein.info.v11.5.txt",
		        "node_list_path": "1401067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1401067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanococcusVersutusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planococcus versutus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusVersutusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1302659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1302659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1302659.clusters.proteins.v11.5.txt",
		        "sequence_path": "1302659.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302659.protein.info.v11.5.txt",
		        "node_list_path": "1302659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1302659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusArsenophonusTriatominarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arsenophonus triatominarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusArsenophonusTriatominarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "57911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "57911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "57911.clusters.proteins.v11.5.txt",
		        "sequence_path": "57911.protein.sequences.v11.5.fa",
		        "enrichment_path": "57911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "57911.protein.info.v11.5.txt",
		        "node_list_path": "57911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "57911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumIranicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium iranicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumIranicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "912594.clusters.info.v11.5.txt",
		        "cluster_tree_path": "912594.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "912594.clusters.proteins.v11.5.txt",
		        "sequence_path": "912594.protein.sequences.v11.5.fa",
		        "enrichment_path": "912594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "912594.protein.info.v11.5.txt",
		        "node_list_path": "912594.cluster.nodes.v11.5.txt",
		        "edge_list_path": "912594.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinosporangiumSpNrrlb3428Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinosporangium sp. NRRLB3428 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinosporangiumSpNrrlb3428Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463820.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463820.protein.info.v11.5.txt",
		        "node_list_path": "1463820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpFuku2Iso50Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Fuku2-ISO-50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpFuku2Iso50Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739114.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739114.protein.info.v11.5.txt",
		        "node_list_path": "1739114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpF0040(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0040 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpF0040", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035197.protein.info.v11.5.txt",
		        "node_list_path": "1035197.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesFradiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces fradiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesFradiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906.protein.info.v11.5.txt",
		        "node_list_path": "1906.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusAureusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus aureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusAureusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280.protein.info.v11.5.txt",
		        "node_list_path": "1280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesotogaPrimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesotoga prima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesotogaPrimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "660470.clusters.info.v11.5.txt",
		        "cluster_tree_path": "660470.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "660470.clusters.proteins.v11.5.txt",
		        "sequence_path": "660470.protein.sequences.v11.5.fa",
		        "enrichment_path": "660470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660470.protein.info.v11.5.txt",
		        "node_list_path": "660470.cluster.nodes.v11.5.txt",
		        "edge_list_path": "660470.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobisporaRoseaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbispora rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobisporaRoseaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "58117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "58117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "58117.clusters.proteins.v11.5.txt",
		        "sequence_path": "58117.protein.sequences.v11.5.fa",
		        "enrichment_path": "58117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58117.protein.info.v11.5.txt",
		        "node_list_path": "58117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "58117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifcsphigho212Full6320Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPHIGHO2_12_FULL_63_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifcsphigho212Full6320Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797558.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797558.protein.info.v11.5.txt",
		        "node_list_path": "1797558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NiabellaAurantiacaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Niabella aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiabellaAurantiacaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122605.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122605.protein.info.v11.5.txt",
		        "node_list_path": "1122605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoellerellaWisconsensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moellerella wisconsensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoellerellaWisconsensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "158849.protein.sequences.v11.5.fa",
		        "enrichment_path": "158849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158849.protein.info.v11.5.txt",
		        "node_list_path": "158849.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalalkalibacillusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halalkalibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalalkalibacillusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121936.protein.info.v11.5.txt",
		        "node_list_path": "1121936.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaceaeBacteriumDtu054(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU054 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaceaeBacteriumDtu054", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671643.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671643.protein.info.v11.5.txt",
		        "node_list_path": "1671643.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusGordoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus gordonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusGordoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "467705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "467705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "467705.clusters.proteins.v11.5.txt",
		        "sequence_path": "467705.protein.sequences.v11.5.fa",
		        "enrichment_path": "467705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "467705.protein.info.v11.5.txt",
		        "node_list_path": "467705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "467705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusMarmorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus marmoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusMarmorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121381.protein.info.v11.5.txt",
		        "node_list_path": "1121381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "376.clusters.proteins.v11.5.txt",
		        "sequence_path": "376.protein.sequences.v11.5.fa",
		        "enrichment_path": "376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376.protein.info.v11.5.txt",
		        "node_list_path": "376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobiformaLacisalsi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobiforma lacisalsi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobiformaLacisalsi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "358396.protein.sequences.v11.5.fa",
		        "enrichment_path": "358396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "358396.protein.info.v11.5.txt",
		        "node_list_path": "358396.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaSpEur3222Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina sp. EUR3222 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaSpEur3222Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1305836.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1305836.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1305836.clusters.proteins.v11.5.txt",
		        "sequence_path": "1305836.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305836.protein.info.v11.5.txt",
		        "node_list_path": "1305836.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1305836.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumRifoxya2Full4118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYA2_FULL_41_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxya2Full4118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801904.protein.info.v11.5.txt",
		        "node_list_path": "1801904.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusBoraciitolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus boraciitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusBoraciitolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298598.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298598.protein.info.v11.5.txt",
		        "node_list_path": "1298598.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpMaepy2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. MAEPY2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpMaepy2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1395587.protein.sequences.v11.5.fa",
		        "enrichment_path": "1395587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1395587.protein.info.v11.5.txt",
		        "node_list_path": "1395587.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterFetusSubspTestudinumSp3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. testudinum Sp3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterFetusSubspTestudinumSp3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1244529.protein.sequences.v11.5.fa",
		        "enrichment_path": "1244529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1244529.protein.info.v11.5.txt",
		        "node_list_path": "1244529.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSpHv1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. Hv1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpHv1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1740090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1740090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1740090.clusters.proteins.v11.5.txt",
		        "sequence_path": "1740090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1740090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1740090.protein.info.v11.5.txt",
		        "node_list_path": "1740090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1740090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhascolarctobacteriumSpCag266(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phascolarctobacterium sp. CAG266 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhascolarctobacteriumSpCag266", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262915.protein.info.v11.5.txt",
		        "node_list_path": "1262915.protein.complete.v11.5.txt"
		    }
		]
    )()

def BathycoccusPrasinos(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bathycoccus prasinos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BathycoccusPrasinos", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "41875.protein.sequences.v11.5.fa",
		        "enrichment_path": "41875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41875.protein.info.v11.5.txt",
		        "node_list_path": "41875.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSubtilisSubspSpizizeniiTuB10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. spizizenii TU-B-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSubtilisSubspSpizizeniiTuB10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1052585.protein.sequences.v11.5.fa",
		        "enrichment_path": "1052585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1052585.protein.info.v11.5.txt",
		        "node_list_path": "1052585.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpongiibacterTropicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spongiibacter tropicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpongiibacterTropicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123279.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123279.protein.info.v11.5.txt",
		        "node_list_path": "1123279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCylindrosporumDsm605(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cylindrosporum DSM 605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCylindrosporumDsm605", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121307.protein.info.v11.5.txt",
		        "node_list_path": "1121307.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteralesBacterium6551Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium 65-51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteralesBacterium6551Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895824.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895824.protein.info.v11.5.txt",
		        "node_list_path": "1895824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaledivibacterHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maledivibacter halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaledivibacterHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36842.protein.sequences.v11.5.fa",
		        "enrichment_path": "36842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36842.protein.info.v11.5.txt",
		        "node_list_path": "36842.protein.complete.v11.5.txt"
		    }
		]
    )()

def KineosporiaAurantiaca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kineosporia aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KineosporiaAurantiaca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1306174.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306174.protein.info.v11.5.txt",
		        "node_list_path": "1306174.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraMesophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira mesophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraMesophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293891.protein.info.v11.5.txt",
		        "node_list_path": "1293891.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasUenonis603Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis 603 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasUenonis603Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596327.clusters.proteins.v11.5.txt",
		        "sequence_path": "596327.protein.sequences.v11.5.fa",
		        "enrichment_path": "596327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596327.protein.info.v11.5.txt",
		        "node_list_path": "596327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorMorganiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor morganii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorMorganiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1387555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1387555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1387555.clusters.proteins.v11.5.txt",
		        "sequence_path": "1387555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387555.protein.info.v11.5.txt",
		        "node_list_path": "1387555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1387555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParamormyropsKingsleyaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paramormyrops kingsleyae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParamormyropsKingsleyaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1676925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1676925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1676925.clusters.proteins.v11.5.txt",
		        "sequence_path": "1676925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676925.protein.info.v11.5.txt",
		        "node_list_path": "1676925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1676925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterHimalayensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter himalayensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterHimalayensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1591088.protein.sequences.v11.5.fa",
		        "enrichment_path": "1591088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1591088.protein.info.v11.5.txt",
		        "node_list_path": "1591088.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusLautusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus lautus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusLautusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1401.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1401.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1401.clusters.proteins.v11.5.txt",
		        "sequence_path": "1401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401.protein.info.v11.5.txt",
		        "node_list_path": "1401.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1401.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EremotheciumGossypiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium gossypii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremotheciumGossypiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33169.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33169.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33169.clusters.proteins.v11.5.txt",
		        "sequence_path": "33169.protein.sequences.v11.5.fa",
		        "enrichment_path": "33169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33169.protein.info.v11.5.txt",
		        "node_list_path": "33169.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33169.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixibacteriaBacterium448493(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium 4484_93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixibacteriaBacterium448493", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1970780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970780.protein.info.v11.5.txt",
		        "node_list_path": "1970780.protein.complete.v11.5.txt"
		    }
		]
    )()

def EpsilonproteobacteriaBacteriumTcs49Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epsilonproteobacteria bacterium tcs-49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpsilonproteobacteriaBacteriumTcs49Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1742865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1742865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1742865.clusters.proteins.v11.5.txt",
		        "sequence_path": "1742865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742865.protein.info.v11.5.txt",
		        "node_list_path": "1742865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1742865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarivirgaSericeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marivirga sericea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivirgaSericeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1028.clusters.proteins.v11.5.txt",
		        "sequence_path": "1028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028.protein.info.v11.5.txt",
		        "node_list_path": "1028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycetaceaeBacteriumMp11305(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomycetaceae bacterium MP113-05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycetaceaeBacteriumMp11305", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380770.protein.info.v11.5.txt",
		        "node_list_path": "1380770.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusAcidocaldariusLaa1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius LAA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusAcidocaldariusLaa1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "543302.protein.sequences.v11.5.fa",
		        "enrichment_path": "543302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543302.protein.info.v11.5.txt",
		        "node_list_path": "543302.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterNonchromogenicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter nonchromogenicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterNonchromogenicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1782.protein.info.v11.5.txt",
		        "node_list_path": "1782.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemellaHaemolysansAtcc10379(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemella haemolysans ATCC10379 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaHaemolysansAtcc10379", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546270.protein.sequences.v11.5.fa",
		        "enrichment_path": "546270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546270.protein.info.v11.5.txt",
		        "node_list_path": "546270.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaCopriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella copri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaCopriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "537011.clusters.info.v11.5.txt",
		        "cluster_tree_path": "537011.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "537011.clusters.proteins.v11.5.txt",
		        "sequence_path": "537011.protein.sequences.v11.5.fa",
		        "enrichment_path": "537011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537011.protein.info.v11.5.txt",
		        "node_list_path": "537011.cluster.nodes.v11.5.txt",
		        "edge_list_path": "537011.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasSpMor2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. Mor2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSpMor2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906738.protein.info.v11.5.txt",
		        "node_list_path": "1906738.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaMallotivoraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia mallotivora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaMallotivoraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69222.clusters.proteins.v11.5.txt",
		        "sequence_path": "69222.protein.sequences.v11.5.fa",
		        "enrichment_path": "69222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69222.protein.info.v11.5.txt",
		        "node_list_path": "69222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpS718Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. S718 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpS718Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1284775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1284775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1284775.clusters.proteins.v11.5.txt",
		        "sequence_path": "1284775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284775.protein.info.v11.5.txt",
		        "node_list_path": "1284775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1284775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpBa1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. ba1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpBa1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1522072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1522072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1522072.clusters.proteins.v11.5.txt",
		        "sequence_path": "1522072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522072.protein.info.v11.5.txt",
		        "node_list_path": "1522072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1522072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PasteurellaMultocida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaMultocida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "747.protein.sequences.v11.5.fa",
		        "enrichment_path": "747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747.protein.info.v11.5.txt",
		        "node_list_path": "747.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDri13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DRI13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDri13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449126.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449126.protein.info.v11.5.txt",
		        "node_list_path": "1449126.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumPopuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium populi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumPopuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "441620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "441620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "441620.clusters.proteins.v11.5.txt",
		        "sequence_path": "441620.protein.sequences.v11.5.fa",
		        "enrichment_path": "441620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441620.protein.info.v11.5.txt",
		        "node_list_path": "441620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "441620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag161(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:161 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag161", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262881.protein.info.v11.5.txt",
		        "node_list_path": "1262881.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaprolegniaDiclina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saprolegnia diclina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaprolegniaDiclina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "112098.protein.sequences.v11.5.fa",
		        "enrichment_path": "112098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112098.protein.info.v11.5.txt",
		        "node_list_path": "112098.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf33Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf33Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736215.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736215.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736215.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736215.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736215.protein.info.v11.5.txt",
		        "node_list_path": "1736215.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736215.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiopsisPrasina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis prasina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisPrasina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1245475.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245475.protein.info.v11.5.txt",
		        "node_list_path": "1245475.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryomorphaceaeBacteriumBacl21Mag121220Bin10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL21 MAG-121220-bin10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryomorphaceaeBacteriumBacl21Mag121220Bin10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1655592.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1655592.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1655592.clusters.proteins.v11.5.txt",
		        "sequence_path": "1655592.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655592.protein.info.v11.5.txt",
		        "node_list_path": "1655592.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1655592.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterWoluwensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter woluwensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterWoluwensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "156980.clusters.info.v11.5.txt",
		        "cluster_tree_path": "156980.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "156980.clusters.proteins.v11.5.txt",
		        "sequence_path": "156980.protein.sequences.v11.5.fa",
		        "enrichment_path": "156980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156980.protein.info.v11.5.txt",
		        "node_list_path": "156980.cluster.nodes.v11.5.txt",
		        "edge_list_path": "156980.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumFaniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium faniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumFaniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "570446.clusters.info.v11.5.txt",
		        "cluster_tree_path": "570446.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "570446.clusters.proteins.v11.5.txt",
		        "sequence_path": "570446.protein.sequences.v11.5.fa",
		        "enrichment_path": "570446.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570446.protein.info.v11.5.txt",
		        "node_list_path": "570446.cluster.nodes.v11.5.txt",
		        "edge_list_path": "570446.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinopolysporaRighensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora righensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolysporaRighensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "995060.protein.sequences.v11.5.fa",
		        "enrichment_path": "995060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "995060.protein.info.v11.5.txt",
		        "node_list_path": "995060.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpWsm2793Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM2793 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpWsm2793Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1038866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1038866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1038866.clusters.proteins.v11.5.txt",
		        "sequence_path": "1038866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038866.protein.info.v11.5.txt",
		        "node_list_path": "1038866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1038866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaMtcc5279(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida MTCC5279 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaMtcc5279", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1240350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1240350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1240350.protein.info.v11.5.txt",
		        "node_list_path": "1240350.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaBryantii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema bryantii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaBryantii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "877418.protein.sequences.v11.5.fa",
		        "enrichment_path": "877418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877418.protein.info.v11.5.txt",
		        "node_list_path": "877418.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfuricellaSpT08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricella sp. T08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricellaSpT08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1632857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1632857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1632857.clusters.proteins.v11.5.txt",
		        "sequence_path": "1632857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1632857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1632857.protein.info.v11.5.txt",
		        "node_list_path": "1632857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1632857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShuttleworthiaSatelles(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shuttleworthia satelles graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShuttleworthiaSatelles", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "626523.protein.sequences.v11.5.fa",
		        "enrichment_path": "626523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626523.protein.info.v11.5.txt",
		        "node_list_path": "626523.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterSpA7a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter sp. A7A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterSpA7a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1350366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1350366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1350366.protein.info.v11.5.txt",
		        "node_list_path": "1350366.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraSantarosaiSerovarShermaniStrLt821Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira santarosai serovar Shermani str. LT 821 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraSantarosaiSerovarShermaniStrLt821Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "758847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "758847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "758847.clusters.proteins.v11.5.txt",
		        "sequence_path": "758847.protein.sequences.v11.5.fa",
		        "enrichment_path": "758847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758847.protein.info.v11.5.txt",
		        "node_list_path": "758847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "758847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesUrogenitalisS6c4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis S6C4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesUrogenitalisS6c4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1284679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1284679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1284679.clusters.proteins.v11.5.txt",
		        "sequence_path": "1284679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284679.protein.info.v11.5.txt",
		        "node_list_path": "1284679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1284679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrovirgaLotononidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microvirga lotononidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaLotononidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "864069.protein.sequences.v11.5.fa",
		        "enrichment_path": "864069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864069.protein.info.v11.5.txt",
		        "node_list_path": "864069.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpCra2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. CRA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpCra2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1955620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1955620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1955620.protein.info.v11.5.txt",
		        "node_list_path": "1955620.protein.complete.v11.5.txt"
		    }
		]
    )()

def KosmotogaOleariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kosmotoga olearia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KosmotogaOleariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521045.clusters.proteins.v11.5.txt",
		        "sequence_path": "521045.protein.sequences.v11.5.fa",
		        "enrichment_path": "521045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521045.protein.info.v11.5.txt",
		        "node_list_path": "521045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylacidiphilumFumariolicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylacidiphilum fumariolicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylacidiphilumFumariolicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1156937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1156937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1156937.clusters.proteins.v11.5.txt",
		        "sequence_path": "1156937.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156937.protein.info.v11.5.txt",
		        "node_list_path": "1156937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1156937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ScytonemaHofmanniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scytonema hofmanni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScytonemaHofmanniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1469607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1469607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1469607.clusters.proteins.v11.5.txt",
		        "sequence_path": "1469607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469607.protein.info.v11.5.txt",
		        "node_list_path": "1469607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1469607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumUasb270(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacterium UASB270 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumUasb270", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499967.protein.info.v11.5.txt",
		        "node_list_path": "1499967.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterHiberniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter hiberniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterHiberniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29314.clusters.proteins.v11.5.txt",
		        "sequence_path": "29314.protein.sequences.v11.5.fa",
		        "enrichment_path": "29314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29314.protein.info.v11.5.txt",
		        "node_list_path": "29314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MariniphagaAnaerophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mariniphaga anaerophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MariniphagaAnaerophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1484053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1484053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1484053.clusters.proteins.v11.5.txt",
		        "sequence_path": "1484053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484053.protein.info.v11.5.txt",
		        "node_list_path": "1484053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1484053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfuricellaSpT08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricella sp. T08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricellaSpT08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1632857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1632857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1632857.protein.info.v11.5.txt",
		        "node_list_path": "1632857.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobisporaSpGmku363(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbispora sp. GMKU363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobisporaSpGmku363", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "718014.protein.sequences.v11.5.fa",
		        "enrichment_path": "718014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "718014.protein.info.v11.5.txt",
		        "node_list_path": "718014.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidianusManzaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidianus manzaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidianusManzaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "282676.protein.sequences.v11.5.fa",
		        "enrichment_path": "282676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "282676.protein.info.v11.5.txt",
		        "node_list_path": "282676.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSuncheonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium suncheonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSuncheonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121899.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121899.protein.info.v11.5.txt",
		        "node_list_path": "1121899.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumMf105b01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium Mf 105b01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumMf105b01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1282876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282876.protein.info.v11.5.txt",
		        "node_list_path": "1282876.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonB25(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB25", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1779369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1779369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1779369.protein.info.v11.5.txt",
		        "node_list_path": "1779369.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesProvencensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes provencensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesProvencensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816676.protein.info.v11.5.txt",
		        "node_list_path": "1816676.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaTerricola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia terricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaTerricola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "169427.protein.sequences.v11.5.fa",
		        "enrichment_path": "169427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "169427.protein.info.v11.5.txt",
		        "node_list_path": "169427.protein.complete.v11.5.txt"
		    }
		]
    )()

def PediculusHumanusCorporisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pediculus humanus corporis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediculusHumanusCorporisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "121224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "121224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "121224.clusters.proteins.v11.5.txt",
		        "sequence_path": "121224.protein.sequences.v11.5.fa",
		        "enrichment_path": "121224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121224.protein.info.v11.5.txt",
		        "node_list_path": "121224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "121224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobialesBacteriumClorobi01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobiales bacterium Clorobi_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobialesBacteriumClorobi01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674889.protein.info.v11.5.txt",
		        "node_list_path": "1674889.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumPhleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium phlei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumPhleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150599.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150599.protein.info.v11.5.txt",
		        "node_list_path": "1150599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpC100(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. C100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpC100", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1207055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1207055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1207055.protein.info.v11.5.txt",
		        "node_list_path": "1207055.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusChondroitinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus chondroitinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusChondroitinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59842.protein.sequences.v11.5.fa",
		        "enrichment_path": "59842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59842.protein.info.v11.5.txt",
		        "node_list_path": "59842.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusVitulinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus vitulinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusVitulinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1167632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1167632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1167632.clusters.proteins.v11.5.txt",
		        "sequence_path": "1167632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1167632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1167632.protein.info.v11.5.txt",
		        "node_list_path": "1167632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1167632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacteralesBacteriumCg2306027(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium CG2_30_60_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteralesBacteriumCg2306027", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805129.protein.info.v11.5.txt",
		        "node_list_path": "1805129.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterGummosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter gummosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterGummosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262324.protein.sequences.v11.5.fa",
		        "enrichment_path": "262324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262324.protein.info.v11.5.txt",
		        "node_list_path": "262324.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudopodocesHumilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudopodoces humilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudopodocesHumilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "181119.clusters.info.v11.5.txt",
		        "cluster_tree_path": "181119.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "181119.clusters.proteins.v11.5.txt",
		        "sequence_path": "181119.protein.sequences.v11.5.fa",
		        "enrichment_path": "181119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "181119.protein.info.v11.5.txt",
		        "node_list_path": "181119.cluster.nodes.v11.5.txt",
		        "edge_list_path": "181119.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaOklahomensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia oklahomensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaOklahomensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "342113.clusters.info.v11.5.txt",
		        "cluster_tree_path": "342113.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "342113.clusters.proteins.v11.5.txt",
		        "sequence_path": "342113.protein.sequences.v11.5.fa",
		        "enrichment_path": "342113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342113.protein.info.v11.5.txt",
		        "node_list_path": "342113.cluster.nodes.v11.5.txt",
		        "edge_list_path": "342113.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubeoparvulumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubeoparvulum massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubeoparvulumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1631346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1631346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1631346.protein.info.v11.5.txt",
		        "node_list_path": "1631346.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusHyicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus hyicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusHyicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284.protein.info.v11.5.txt",
		        "node_list_path": "1284.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasIlicicolaDsm19980Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas ilicicola DSM 19980 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasIlicicolaDsm19980Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121942.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121942.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121942.protein.info.v11.5.txt",
		        "node_list_path": "1121942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumCg23070394(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_70_394 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumCg23070394", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805279.protein.info.v11.5.txt",
		        "node_list_path": "1805279.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusSpAm4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sp. AM4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSpAm4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246969.protein.sequences.v11.5.fa",
		        "enrichment_path": "246969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246969.protein.info.v11.5.txt",
		        "node_list_path": "246969.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioOstreicidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ostreicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioOstreicidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "526588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "526588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "526588.clusters.proteins.v11.5.txt",
		        "sequence_path": "526588.protein.sequences.v11.5.fa",
		        "enrichment_path": "526588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526588.protein.info.v11.5.txt",
		        "node_list_path": "526588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "526588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnobacterSpCaciam66h1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnobacter sp. CACIAM 66H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnobacterSpCaciam66h1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1813033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1813033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1813033.protein.info.v11.5.txt",
		        "node_list_path": "1813033.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioGalatheae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio galatheae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioGalatheae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "579748.protein.sequences.v11.5.fa",
		        "enrichment_path": "579748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579748.protein.info.v11.5.txt",
		        "node_list_path": "579748.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillospiraceaeBacteriumZagget12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillospiraceae bacterium Zagget12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillospiraceaeBacteriumZagget12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930020.protein.info.v11.5.txt",
		        "node_list_path": "1930020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioProteoclasticusP6b7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus P6B7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioProteoclasticusP6b7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410650.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410650.protein.info.v11.5.txt",
		        "node_list_path": "1410650.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusSpOt(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. OT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusSpOt", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "913865.protein.sequences.v11.5.fa",
		        "enrichment_path": "913865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913865.protein.info.v11.5.txt",
		        "node_list_path": "913865.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRoot180Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root180 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRoot180Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736483.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736483.protein.info.v11.5.txt",
		        "node_list_path": "1736483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfobacillusThermosulfidooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfobacillus thermosulfidooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfobacillusThermosulfidooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28034.protein.sequences.v11.5.fa",
		        "enrichment_path": "28034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28034.protein.info.v11.5.txt",
		        "node_list_path": "28034.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraAustralicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira australica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraAustralicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1528106.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1528106.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1528106.clusters.proteins.v11.5.txt",
		        "sequence_path": "1528106.protein.sequences.v11.5.fa",
		        "enrichment_path": "1528106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1528106.protein.info.v11.5.txt",
		        "node_list_path": "1528106.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1528106.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85201450255Sch5639931(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852014-50255_SCH5639931 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85201450255Sch5639931", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834112.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834112.protein.info.v11.5.txt",
		        "node_list_path": "1834112.protein.complete.v11.5.txt"
		    }
		]
    )()

def XiangellaPhaseoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xiangella phaseoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XiangellaPhaseoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144548.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144548.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144548.protein.info.v11.5.txt",
		        "node_list_path": "1144548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospinaeBacteriumRifcsplowo2123915Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospinae bacterium RIFCSPLOWO2_12_39_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospinaeBacteriumRifcsplowo2123915Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801689.protein.info.v11.5.txt",
		        "node_list_path": "1801689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full4934(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_49_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full4934", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798491.protein.info.v11.5.txt",
		        "node_list_path": "1798491.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterConcretionis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter concretionis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterConcretionis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122185.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122185.protein.info.v11.5.txt",
		        "node_list_path": "1122185.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAviumParatuberculosis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium avium paratuberculosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAviumParatuberculosis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262316.protein.sequences.v11.5.fa",
		        "enrichment_path": "262316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262316.protein.info.v11.5.txt",
		        "node_list_path": "262316.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarineBacteriumAo1C(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return marine bacterium AO1-C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineBacteriumAo1C", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1905359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1905359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1905359.protein.info.v11.5.txt",
		        "node_list_path": "1905359.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaenimonasSpSl110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caenimonas sp. SL110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenimonasSpSl110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1450524.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450524.protein.info.v11.5.txt",
		        "node_list_path": "1450524.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCalifornicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces californicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCalifornicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67281.clusters.proteins.v11.5.txt",
		        "sequence_path": "67281.protein.sequences.v11.5.fa",
		        "enrichment_path": "67281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67281.protein.info.v11.5.txt",
		        "node_list_path": "67281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBeckwithbacteriaBacteriumGw2011Gwc14916Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium GW2011_GWC1_49_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumGw2011Gwc14916Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618372.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618372.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618372.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618372.protein.info.v11.5.txt",
		        "node_list_path": "1618372.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618372.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EuryarchaeotaArchaeonRbg166727(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_16_67_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EuryarchaeotaArchaeonRbg166727", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797980.protein.info.v11.5.txt",
		        "node_list_path": "1797980.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumGw2011Gwb14719Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWB1_47_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwb14719Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618360.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618360.protein.info.v11.5.txt",
		        "node_list_path": "1618360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaSpWd162(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. WD16.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpWd162", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1933904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933904.protein.info.v11.5.txt",
		        "node_list_path": "1933904.protein.complete.v11.5.txt"
		    }
		]
    )()

def TarsiusSyrichta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tarsius syrichta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TarsiusSyrichta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9478.protein.sequences.v11.5.fa",
		        "enrichment_path": "9478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9478.protein.info.v11.5.txt",
		        "node_list_path": "9478.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioBrasiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioBrasiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "945543.clusters.info.v11.5.txt",
		        "cluster_tree_path": "945543.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "945543.clusters.proteins.v11.5.txt",
		        "sequence_path": "945543.protein.sequences.v11.5.fa",
		        "enrichment_path": "945543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "945543.protein.info.v11.5.txt",
		        "node_list_path": "945543.cluster.nodes.v11.5.txt",
		        "edge_list_path": "945543.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporisoriumScitamineumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporisorium scitamineum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporisoriumScitamineumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "49012.clusters.info.v11.5.txt",
		        "cluster_tree_path": "49012.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "49012.clusters.proteins.v11.5.txt",
		        "sequence_path": "49012.protein.sequences.v11.5.fa",
		        "enrichment_path": "49012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "49012.protein.info.v11.5.txt",
		        "node_list_path": "49012.cluster.nodes.v11.5.txt",
		        "edge_list_path": "49012.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasSpNm33(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasSpNm33", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "133724.protein.sequences.v11.5.fa",
		        "enrichment_path": "133724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133724.protein.info.v11.5.txt",
		        "node_list_path": "133724.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpM1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpM1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "95619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "95619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "95619.clusters.proteins.v11.5.txt",
		        "sequence_path": "95619.protein.sequences.v11.5.fa",
		        "enrichment_path": "95619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "95619.protein.info.v11.5.txt",
		        "node_list_path": "95619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "95619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosococcusWatsoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosococcus watsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosococcusWatsoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "105559.clusters.info.v11.5.txt",
		        "cluster_tree_path": "105559.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "105559.clusters.proteins.v11.5.txt",
		        "sequence_path": "105559.protein.sequences.v11.5.fa",
		        "enrichment_path": "105559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105559.protein.info.v11.5.txt",
		        "node_list_path": "105559.cluster.nodes.v11.5.txt",
		        "edge_list_path": "105559.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumYoeliiYoelii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium yoelii yoelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumYoeliiYoelii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "73239.protein.sequences.v11.5.fa",
		        "enrichment_path": "73239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "73239.protein.info.v11.5.txt",
		        "node_list_path": "73239.protein.complete.v11.5.txt"
		    }
		]
    )()

def GadusMorhuaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gadus morhua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GadusMorhuaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8049.clusters.proteins.v11.5.txt",
		        "sequence_path": "8049.protein.sequences.v11.5.fa",
		        "enrichment_path": "8049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8049.protein.info.v11.5.txt",
		        "node_list_path": "8049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DielmaFastidiosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dielma fastidiosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DielmaFastidiosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1034346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034346.protein.info.v11.5.txt",
		        "node_list_path": "1034346.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSp2kl27Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 2KL-27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSp2kl27Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1100705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1100705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1100705.clusters.proteins.v11.5.txt",
		        "sequence_path": "1100705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1100705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1100705.protein.info.v11.5.txt",
		        "node_list_path": "1100705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1100705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumSit11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium SIT11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumSit11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1673726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673726.protein.info.v11.5.txt",
		        "node_list_path": "1673726.protein.complete.v11.5.txt"
		    }
		]
    )()

def KurthiaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kurthia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KurthiaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033739.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033739.protein.info.v11.5.txt",
		        "node_list_path": "1033739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaTyphimurium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica Typhimurium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaTyphimurium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "90371.protein.sequences.v11.5.fa",
		        "enrichment_path": "90371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90371.protein.info.v11.5.txt",
		        "node_list_path": "90371.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanococcoidesBurtoniiDsm6242(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanococcoides burtonii DSM 6242 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcoidesBurtoniiDsm6242", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "259564.protein.sequences.v11.5.fa",
		        "enrichment_path": "259564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "259564.protein.info.v11.5.txt",
		        "node_list_path": "259564.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsplowo202Full519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_02_FULL_51_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo202Full519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802410.protein.info.v11.5.txt",
		        "node_list_path": "1802410.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterDaepoensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter daepoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterDaepoensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122197.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122197.protein.info.v11.5.txt",
		        "node_list_path": "1122197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermovibrioAmmonificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermovibrio ammonificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermovibrioAmmonificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "648996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "648996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "648996.clusters.proteins.v11.5.txt",
		        "sequence_path": "648996.protein.sequences.v11.5.fa",
		        "enrichment_path": "648996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "648996.protein.info.v11.5.txt",
		        "node_list_path": "648996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "648996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusPseudalcaliphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus pseudalcaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPseudalcaliphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "79884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "79884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "79884.clusters.proteins.v11.5.txt",
		        "sequence_path": "79884.protein.sequences.v11.5.fa",
		        "enrichment_path": "79884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79884.protein.info.v11.5.txt",
		        "node_list_path": "79884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "79884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium6322(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 63-22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium6322", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895812.protein.info.v11.5.txt",
		        "node_list_path": "1895812.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisSpNrrlB16309(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. NRRL B-16309 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisSpNrrlB16309", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1519494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519494.protein.info.v11.5.txt",
		        "node_list_path": "1519494.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumNamnetense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Propionibacterium] namnetense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumNamnetense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1574624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1574624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1574624.protein.info.v11.5.txt",
		        "node_list_path": "1574624.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpNbrc111131Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. NBRC 111131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpNbrc111131Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1661046.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1661046.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1661046.clusters.proteins.v11.5.txt",
		        "sequence_path": "1661046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661046.protein.info.v11.5.txt",
		        "node_list_path": "1661046.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1661046.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrigoribacteriumSpLeaf415(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf415 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrigoribacteriumSpLeaf415", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736372.protein.info.v11.5.txt",
		        "node_list_path": "1736372.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasCellaseaDsm20118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas cellasea DSM 20118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasCellaseaDsm20118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408250.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408250.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408250.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408250.protein.info.v11.5.txt",
		        "node_list_path": "1408250.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408250.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpAe3006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpAe3006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280673.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280673.protein.info.v11.5.txt",
		        "node_list_path": "1280673.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesPuniciscabiei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces puniciscabiei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPuniciscabiei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "164348.protein.sequences.v11.5.fa",
		        "enrichment_path": "164348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "164348.protein.info.v11.5.txt",
		        "node_list_path": "164348.protein.complete.v11.5.txt"
		    }
		]
    )()

def VaginellaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vaginella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaginellaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816680.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816680.protein.info.v11.5.txt",
		        "node_list_path": "1816680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SandarakinorhabdusSpAap62Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sandarakinorhabdus sp. AAP62 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SandarakinorhabdusSpAap62Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1248916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1248916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1248916.clusters.proteins.v11.5.txt",
		        "sequence_path": "1248916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1248916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1248916.protein.info.v11.5.txt",
		        "node_list_path": "1248916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1248916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmoebophilusAsiaticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amoebophilus asiaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmoebophilusAsiaticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "452471.protein.sequences.v11.5.fa",
		        "enrichment_path": "452471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452471.protein.info.v11.5.txt",
		        "node_list_path": "452471.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasLipolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas lipolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasLipolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1856405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1856405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1856405.clusters.proteins.v11.5.txt",
		        "sequence_path": "1856405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1856405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1856405.protein.info.v11.5.txt",
		        "node_list_path": "1856405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1856405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaVulgarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Beta vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaVulgarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "161934.clusters.info.v11.5.txt",
		        "cluster_tree_path": "161934.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "161934.clusters.proteins.v11.5.txt",
		        "sequence_path": "161934.protein.sequences.v11.5.fa",
		        "enrichment_path": "161934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161934.protein.info.v11.5.txt",
		        "node_list_path": "161934.cluster.nodes.v11.5.txt",
		        "edge_list_path": "161934.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptobacillusNotomytisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptobacillus notomytis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptobacillusNotomytisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1712031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1712031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1712031.clusters.proteins.v11.5.txt",
		        "sequence_path": "1712031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1712031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1712031.protein.info.v11.5.txt",
		        "node_list_path": "1712031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1712031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacterialesBacteriumBrhC54Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriales bacterium BRH_c54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacterialesBacteriumBrhC54Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629721.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629721.protein.info.v11.5.txt",
		        "node_list_path": "1629721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp32146Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3214.6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp32146Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882757.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882757.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882757.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882757.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882757.protein.info.v11.5.txt",
		        "node_list_path": "1882757.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882757.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasAtlanticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasAtlanticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "342610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "342610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "342610.clusters.proteins.v11.5.txt",
		        "sequence_path": "342610.protein.sequences.v11.5.fa",
		        "enrichment_path": "342610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342610.protein.info.v11.5.txt",
		        "node_list_path": "342610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "342610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosovibrioSpNv6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosovibrio sp. Nv6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosovibrioSpNv6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855340.protein.info.v11.5.txt",
		        "node_list_path": "1855340.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpHel13378(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel1_33_78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpHel13378", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336804.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336804.protein.info.v11.5.txt",
		        "node_list_path": "1336804.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalophilicArchaeonDl31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return halophilic archaeon DL31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalophilicArchaeonDl31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "756883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "756883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "756883.clusters.proteins.v11.5.txt",
		        "sequence_path": "756883.protein.sequences.v11.5.fa",
		        "enrichment_path": "756883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "756883.protein.info.v11.5.txt",
		        "node_list_path": "756883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "756883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlammeovirgaPacificaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flammeovirga pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlammeovirgaPacificaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "915059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "915059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "915059.clusters.proteins.v11.5.txt",
		        "sequence_path": "915059.protein.sequences.v11.5.fa",
		        "enrichment_path": "915059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "915059.protein.info.v11.5.txt",
		        "node_list_path": "915059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "915059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlochmanniaEndosymbiontOfPolyrhachisHedomyrmaTurneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Polyrhachis (Hedomyrma) turneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlochmanniaEndosymbiontOfPolyrhachisHedomyrmaTurneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1505596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1505596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1505596.clusters.proteins.v11.5.txt",
		        "sequence_path": "1505596.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505596.protein.info.v11.5.txt",
		        "node_list_path": "1505596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1505596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibularhizoctoniaSpCbs109695(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibularhizoctonia sp. CBS 109695 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibularhizoctoniaSpCbs109695", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "436010.protein.sequences.v11.5.fa",
		        "enrichment_path": "436010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436010.protein.info.v11.5.txt",
		        "node_list_path": "436010.protein.complete.v11.5.txt"
		    }
		]
    )()

def LonsdaleaQuercina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lonsdalea quercina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LonsdaleaQuercina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1082705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1082705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1082705.protein.info.v11.5.txt",
		        "node_list_path": "1082705.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerovoraxOdorimutans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerovorax odorimutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerovoraxOdorimutans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120998.protein.info.v11.5.txt",
		        "node_list_path": "1120998.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag288Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:288 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag288Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262791.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262791.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262791.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262791.protein.info.v11.5.txt",
		        "node_list_path": "1262791.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262791.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicractiniumConductrix(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micractinium conductrix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicractiniumConductrix", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "554055.protein.sequences.v11.5.fa",
		        "enrichment_path": "554055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "554055.protein.info.v11.5.txt",
		        "node_list_path": "554055.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospiraTrueperiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospira trueperi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospiraTrueperiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69960.clusters.proteins.v11.5.txt",
		        "sequence_path": "69960.protein.sequences.v11.5.fa",
		        "enrichment_path": "69960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69960.protein.info.v11.5.txt",
		        "node_list_path": "69960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterHepaticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter hepaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterHepaticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "235279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "235279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "235279.clusters.proteins.v11.5.txt",
		        "sequence_path": "235279.protein.sequences.v11.5.fa",
		        "enrichment_path": "235279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "235279.protein.info.v11.5.txt",
		        "node_list_path": "235279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "235279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSuwonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter suwonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSuwonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "332999.protein.sequences.v11.5.fa",
		        "enrichment_path": "332999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332999.protein.info.v11.5.txt",
		        "node_list_path": "332999.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalpingoecaRosetta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salpingoeca rosetta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalpingoecaRosetta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "946362.protein.sequences.v11.5.fa",
		        "enrichment_path": "946362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946362.protein.info.v11.5.txt",
		        "node_list_path": "946362.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHarrisonbacteriaBacteriumRifcsphigho212Full4816Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPHIGHO2_12_FULL_48_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsphigho212Full4816Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798405.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798405.protein.info.v11.5.txt",
		        "node_list_path": "1798405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPratensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces pratensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPratensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "591167.protein.sequences.v11.5.fa",
		        "enrichment_path": "591167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "591167.protein.info.v11.5.txt",
		        "node_list_path": "591167.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "468059.protein.sequences.v11.5.fa",
		        "enrichment_path": "468059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "468059.protein.info.v11.5.txt",
		        "node_list_path": "468059.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5062.protein.sequences.v11.5.fa",
		        "enrichment_path": "5062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5062.protein.info.v11.5.txt",
		        "node_list_path": "5062.protein.complete.v11.5.txt"
		    }
		]
    )()

def TerrabacterSpRoot85(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terrabacter sp. Root85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrabacterSpRoot85", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736603.protein.info.v11.5.txt",
		        "node_list_path": "1736603.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgibacterPectinivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algibacter pectinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgibacterPectinivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "870482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "870482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "870482.clusters.proteins.v11.5.txt",
		        "sequence_path": "870482.protein.sequences.v11.5.fa",
		        "enrichment_path": "870482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "870482.protein.info.v11.5.txt",
		        "node_list_path": "870482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "870482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DolosigranulumPigrum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dolosigranulum pigrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DolosigranulumPigrum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883103.protein.sequences.v11.5.fa",
		        "enrichment_path": "883103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883103.protein.info.v11.5.txt",
		        "node_list_path": "883103.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhinopithecusBietiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhinopithecus bieti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhinopithecusBietiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61621.clusters.proteins.v11.5.txt",
		        "sequence_path": "61621.protein.sequences.v11.5.fa",
		        "enrichment_path": "61621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61621.protein.info.v11.5.txt",
		        "node_list_path": "61621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DromaiusNovaehollandiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dromaius novaehollandiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DromaiusNovaehollandiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8790.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8790.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8790.clusters.proteins.v11.5.txt",
		        "sequence_path": "8790.protein.sequences.v11.5.fa",
		        "enrichment_path": "8790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8790.protein.info.v11.5.txt",
		        "node_list_path": "8790.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8790.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulforegulaConservatrixCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulforegula conservatrix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulforegulaConservatrixCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304885.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304885.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304885.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304885.protein.info.v11.5.txt",
		        "node_list_path": "1304885.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304885.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusTengchongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus tengchongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusTengchongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "368812.protein.sequences.v11.5.fa",
		        "enrichment_path": "368812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "368812.protein.info.v11.5.txt",
		        "node_list_path": "368812.protein.complete.v11.5.txt"
		    }
		]
    )()

def GluconobacterOxydansH24(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans H24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterOxydansH24", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1224746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224746.protein.info.v11.5.txt",
		        "node_list_path": "1224746.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsphigho201Full4098(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_01_FULL_40_98 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho201Full4098", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802034.protein.info.v11.5.txt",
		        "node_list_path": "1802034.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillibacterSp5720(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. 57_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSp5720", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897011.protein.info.v11.5.txt",
		        "node_list_path": "1897011.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtelocyanobacteriumThalassaSio64986Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atelocyanobacterium thalassa SIO64986 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtelocyanobacteriumThalassaSio64986Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1527444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1527444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1527444.clusters.proteins.v11.5.txt",
		        "sequence_path": "1527444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1527444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1527444.protein.info.v11.5.txt",
		        "node_list_path": "1527444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1527444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisTropicalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis tropicalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisTropicalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1561998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561998.protein.info.v11.5.txt",
		        "node_list_path": "1561998.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioProteoclasticusB316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus B316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioProteoclasticusB316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "515622.protein.sequences.v11.5.fa",
		        "enrichment_path": "515622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515622.protein.info.v11.5.txt",
		        "node_list_path": "515622.protein.complete.v11.5.txt"
		    }
		]
    )()

def DuganellaSpRoot1480d1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. Root1480D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpRoot1480d1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736471.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736471.protein.info.v11.5.txt",
		        "node_list_path": "1736471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClavicepsPurpurea201Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Claviceps purpurea 20.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavicepsPurpurea201Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111077.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111077.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111077.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111077.protein.info.v11.5.txt",
		        "node_list_path": "1111077.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111077.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusSp217Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius sp. 217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusSp217Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314264.clusters.proteins.v11.5.txt",
		        "sequence_path": "314264.protein.sequences.v11.5.fa",
		        "enrichment_path": "314264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314264.protein.info.v11.5.txt",
		        "node_list_path": "314264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlenkiaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klenkia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlenkiaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1960309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1960309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1960309.clusters.proteins.v11.5.txt",
		        "sequence_path": "1960309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1960309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1960309.protein.info.v11.5.txt",
		        "node_list_path": "1960309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1960309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerofustisStercorihominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerofustis stercorihominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerofustisStercorihominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445971.clusters.proteins.v11.5.txt",
		        "sequence_path": "445971.protein.sequences.v11.5.fa",
		        "enrichment_path": "445971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445971.protein.info.v11.5.txt",
		        "node_list_path": "445971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYonathbacteriaBacteriumRifcsphigho201Full4441(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPHIGHO2_01_FULL_44_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsphigho201Full4441", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802722.protein.info.v11.5.txt",
		        "node_list_path": "1802722.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesGraminisolvens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides graminisolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesGraminisolvens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121097.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121097.protein.info.v11.5.txt",
		        "node_list_path": "1121097.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraSpMccc1a01428Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A01428 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraSpMccc1a01428Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1470575.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1470575.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1470575.clusters.proteins.v11.5.txt",
		        "sequence_path": "1470575.protein.sequences.v11.5.fa",
		        "enrichment_path": "1470575.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1470575.protein.info.v11.5.txt",
		        "node_list_path": "1470575.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1470575.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DuganellaSpRoot1480d1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. Root1480D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpRoot1480d1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736471.protein.info.v11.5.txt",
		        "node_list_path": "1736471.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChoiromycesVenosus1206131Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Choiromyces venosus 120613-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChoiromycesVenosus1206131Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336337.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336337.protein.info.v11.5.txt",
		        "node_list_path": "1336337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioTasmaniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio tasmaniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioTasmaniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575788.protein.sequences.v11.5.fa",
		        "enrichment_path": "575788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575788.protein.info.v11.5.txt",
		        "node_list_path": "575788.protein.complete.v11.5.txt"
		    }
		]
    )()

def FranconibacterPulverisDsm19144(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Franconibacter pulveris DSM 19144 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FranconibacterPulverisDsm19144", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121863.protein.info.v11.5.txt",
		        "node_list_path": "1121863.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterSpRm6137Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM6137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSpRm6137Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660073.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660073.protein.info.v11.5.txt",
		        "node_list_path": "1660073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpCc9616Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9616 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpCc9616Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "110663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "110663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "110663.clusters.proteins.v11.5.txt",
		        "sequence_path": "110663.protein.sequences.v11.5.fa",
		        "enrichment_path": "110663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "110663.protein.info.v11.5.txt",
		        "node_list_path": "110663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "110663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusPeptonophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus peptonophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusPeptonophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53952.protein.sequences.v11.5.fa",
		        "enrichment_path": "53952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53952.protein.info.v11.5.txt",
		        "node_list_path": "53952.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusRossiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rossiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusRossiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1114972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114972.protein.info.v11.5.txt",
		        "node_list_path": "1114972.protein.complete.v11.5.txt"
		    }
		]
    )()

def KibdelosporangiumSpMj126Nf4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kibdelosporangium sp. MJ126-NF4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KibdelosporangiumSpMj126Nf4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "703222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "703222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "703222.clusters.proteins.v11.5.txt",
		        "sequence_path": "703222.protein.sequences.v11.5.fa",
		        "enrichment_path": "703222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "703222.protein.info.v11.5.txt",
		        "node_list_path": "703222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "703222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo212Full6258(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_12_FULL_62_58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212Full6258", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797497.protein.info.v11.5.txt",
		        "node_list_path": "1797497.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp15544247(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1554424.7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp15544247", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834082.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834082.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834082.protein.info.v11.5.txt",
		        "node_list_path": "1834082.protein.complete.v11.5.txt"
		    }
		]
    )()

def JuglansRegia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Juglans regia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JuglansRegia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "51240.protein.sequences.v11.5.fa",
		        "enrichment_path": "51240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51240.protein.info.v11.5.txt",
		        "node_list_path": "51240.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanothermobacterWolfeiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter wolfeii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermobacterWolfeiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "145261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "145261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "145261.clusters.proteins.v11.5.txt",
		        "sequence_path": "145261.protein.sequences.v11.5.fa",
		        "enrichment_path": "145261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "145261.protein.info.v11.5.txt",
		        "node_list_path": "145261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "145261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusCriceti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus criceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusCriceti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "873449.protein.sequences.v11.5.fa",
		        "enrichment_path": "873449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "873449.protein.info.v11.5.txt",
		        "node_list_path": "873449.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpWg21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. WG21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpWg21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229487.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229487.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229487.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229487.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229487.protein.info.v11.5.txt",
		        "node_list_path": "1229487.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229487.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MelampsoraLariciPopulina98ag31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Melampsora larici-populina 98AG31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MelampsoraLariciPopulina98ag31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "747676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "747676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "747676.clusters.proteins.v11.5.txt",
		        "sequence_path": "747676.protein.sequences.v11.5.fa",
		        "enrichment_path": "747676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747676.protein.info.v11.5.txt",
		        "node_list_path": "747676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "747676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasTurrisvirgatae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas turrisvirgatae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasTurrisvirgatae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1888892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1888892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1888892.protein.info.v11.5.txt",
		        "node_list_path": "1888892.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTectomicrobiaBacteriumRifcsplowo202Full7019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tectomicrobia bacterium RIFCSPLOWO2_02_FULL_70_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTectomicrobiaBacteriumRifcsplowo202Full7019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802342.protein.info.v11.5.txt",
		        "node_list_path": "1802342.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusFleurettiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus fleurettii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusFleurettiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "150056.clusters.info.v11.5.txt",
		        "cluster_tree_path": "150056.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "150056.clusters.proteins.v11.5.txt",
		        "sequence_path": "150056.protein.sequences.v11.5.fa",
		        "enrichment_path": "150056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150056.protein.info.v11.5.txt",
		        "node_list_path": "150056.cluster.nodes.v11.5.txt",
		        "edge_list_path": "150056.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeonGw2011Ar20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return archaeon GW2011_AR20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeonGw2011Ar20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1579378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1579378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1579378.clusters.proteins.v11.5.txt",
		        "sequence_path": "1579378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579378.protein.info.v11.5.txt",
		        "node_list_path": "1579378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1579378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumEbm40Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium EBM-40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumEbm40Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1918508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1918508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1918508.clusters.proteins.v11.5.txt",
		        "sequence_path": "1918508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918508.protein.info.v11.5.txt",
		        "node_list_path": "1918508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1918508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpIs2118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. IS2118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpIs2118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1505605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505605.protein.info.v11.5.txt",
		        "node_list_path": "1505605.protein.complete.v11.5.txt"
		    }
		]
    )()

def CytosporaLeucostoma(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cytospora leucostoma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CytosporaLeucostoma", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230097.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230097.protein.info.v11.5.txt",
		        "node_list_path": "1230097.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerrimicrobiumAcidiphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrimicrobium acidiphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrimicrobiumAcidiphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121877.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121877.protein.info.v11.5.txt",
		        "node_list_path": "1121877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BizioniaArgentinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bizionia argentinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BizioniaArgentinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1046627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046627.protein.info.v11.5.txt",
		        "node_list_path": "1046627.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesCaecimuris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides caecimuris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCaecimuris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1796613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796613.protein.info.v11.5.txt",
		        "node_list_path": "1796613.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpCl6col(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. cl6col graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpCl6col", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761878.protein.info.v11.5.txt",
		        "node_list_path": "1761878.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaucibacterSpKctc42545(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paucibacter sp. KCTC 42545 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaucibacterSpKctc42545", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1768242.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768242.protein.info.v11.5.txt",
		        "node_list_path": "1768242.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusParaburkholderiaKirkiiUzhbot1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Paraburkholderia kirkii UZHbot1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusParaburkholderiaKirkiiUzhbot1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1055526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1055526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1055526.clusters.proteins.v11.5.txt",
		        "sequence_path": "1055526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1055526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1055526.protein.info.v11.5.txt",
		        "node_list_path": "1055526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1055526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaEndosymbiontOfOrnithodorosMoubata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella endosymbiont of Ornithodoros moubata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaEndosymbiontOfOrnithodorosMoubata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1981171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1981171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1981171.protein.info.v11.5.txt",
		        "node_list_path": "1981171.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyaloscyphaVariabilisF(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyaloscypha variabilis F graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyaloscyphaVariabilisF", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1149755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1149755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1149755.protein.info.v11.5.txt",
		        "node_list_path": "1149755.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg166443(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_64_43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg166443", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797659.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797659.protein.info.v11.5.txt",
		        "node_list_path": "1797659.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAcrylicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio acrylicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAcrylicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121434.protein.info.v11.5.txt",
		        "node_list_path": "1121434.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumCg23041165Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium CG2_30_41_165 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumCg23041165Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805254.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805254.protein.info.v11.5.txt",
		        "node_list_path": "1805254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KosmotogaArenicorallinaS304Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kosmotoga arenicorallina S304 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KosmotogaArenicorallinaS304Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1453497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1453497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1453497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1453497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453497.protein.info.v11.5.txt",
		        "node_list_path": "1453497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1453497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IntrasporangiaceaeBacteriumUrhb0013Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Intrasporangiaceae bacterium URHB0013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntrasporangiaceaeBacteriumUrhb0013Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380370.protein.info.v11.5.txt",
		        "node_list_path": "1380370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1898203.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1898203.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1898203.clusters.proteins.v11.5.txt",
		        "sequence_path": "1898203.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898203.protein.info.v11.5.txt",
		        "node_list_path": "1898203.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1898203.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpMn802workerCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Mn802worker Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpMn802workerCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "629773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "629773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "629773.clusters.proteins.v11.5.txt",
		        "sequence_path": "629773.protein.sequences.v11.5.fa",
		        "enrichment_path": "629773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "629773.protein.info.v11.5.txt",
		        "node_list_path": "629773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "629773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StappiaSpEs058(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stappia sp. ES.058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StappiaSpEs058", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881061.protein.info.v11.5.txt",
		        "node_list_path": "1881061.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpF0473Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0473 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpF0473Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999423.clusters.proteins.v11.5.txt",
		        "sequence_path": "999423.protein.sequences.v11.5.fa",
		        "enrichment_path": "999423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999423.protein.info.v11.5.txt",
		        "node_list_path": "999423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumVe20218Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20218 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumVe20218Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232446.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232446.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232446.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232446.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232446.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232446.protein.info.v11.5.txt",
		        "node_list_path": "1232446.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232446.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumOlb17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium OLB17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumOlb17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617423.protein.info.v11.5.txt",
		        "node_list_path": "1617423.protein.complete.v11.5.txt"
		    }
		]
    )()

def IchthyophthiriusMultifiliisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ichthyophthirius multifiliis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IchthyophthiriusMultifiliisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5932.clusters.proteins.v11.5.txt",
		        "sequence_path": "5932.protein.sequences.v11.5.fa",
		        "enrichment_path": "5932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5932.protein.info.v11.5.txt",
		        "node_list_path": "5932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KaistiaSoliDsm19436(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kaistia soli DSM 19436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KaistiaSoliDsm19436", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122133.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122133.protein.info.v11.5.txt",
		        "node_list_path": "1122133.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusFrigensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus frigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusFrigensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121380.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121380.protein.info.v11.5.txt",
		        "node_list_path": "1121380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpKpl1859(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1859 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpKpl1859", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203566.protein.info.v11.5.txt",
		        "node_list_path": "1203566.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalopelagiusInordinatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halopelagius inordinatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalopelagiusInordinatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553467.clusters.proteins.v11.5.txt",
		        "sequence_path": "553467.protein.sequences.v11.5.fa",
		        "enrichment_path": "553467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553467.protein.info.v11.5.txt",
		        "node_list_path": "553467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterJejuni414Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter jejuni 414 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterJejuni414Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "683083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "683083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "683083.clusters.proteins.v11.5.txt",
		        "sequence_path": "683083.protein.sequences.v11.5.fa",
		        "enrichment_path": "683083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683083.protein.info.v11.5.txt",
		        "node_list_path": "683083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "683083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhormidesmisPriestleyiUlc007Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi ULC007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhormidesmisPriestleyiUlc007Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1920490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1920490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1920490.clusters.proteins.v11.5.txt",
		        "sequence_path": "1920490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920490.protein.info.v11.5.txt",
		        "node_list_path": "1920490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1920490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprothermobacterProteolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprothermobacter proteolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprothermobacterProteolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "309798.clusters.info.v11.5.txt",
		        "cluster_tree_path": "309798.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "309798.clusters.proteins.v11.5.txt",
		        "sequence_path": "309798.protein.sequences.v11.5.fa",
		        "enrichment_path": "309798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "309798.protein.info.v11.5.txt",
		        "node_list_path": "309798.cluster.nodes.v11.5.txt",
		        "edge_list_path": "309798.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IntrasporangiumCalvumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Intrasporangium calvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntrasporangiumCalvumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "710696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "710696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "710696.clusters.proteins.v11.5.txt",
		        "sequence_path": "710696.protein.sequences.v11.5.fa",
		        "enrichment_path": "710696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710696.protein.info.v11.5.txt",
		        "node_list_path": "710696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "710696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPluripotensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces pluripotens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPluripotensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1355015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1355015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1355015.clusters.proteins.v11.5.txt",
		        "sequence_path": "1355015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1355015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1355015.protein.info.v11.5.txt",
		        "node_list_path": "1355015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1355015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumProteolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium proteolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumProteolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1903952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1903952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1903952.clusters.proteins.v11.5.txt",
		        "sequence_path": "1903952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903952.protein.info.v11.5.txt",
		        "node_list_path": "1903952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1903952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OryziasLatipesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryzias latipes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryziasLatipesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8090.clusters.proteins.v11.5.txt",
		        "sequence_path": "8090.protein.sequences.v11.5.fa",
		        "enrichment_path": "8090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8090.protein.info.v11.5.txt",
		        "node_list_path": "8090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCirculans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus circulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCirculans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397.protein.info.v11.5.txt",
		        "node_list_path": "1397.protein.complete.v11.5.txt"
		    }
		]
    )()

def TorulasporaDelbrueckiiCbs1146Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Torulaspora delbrueckii CBS 1146 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TorulasporaDelbrueckiiCbs1146Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1076872.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1076872.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1076872.clusters.proteins.v11.5.txt",
		        "sequence_path": "1076872.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076872.protein.info.v11.5.txt",
		        "node_list_path": "1076872.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1076872.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSp5139bfaa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. 5139BFAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSp5139bfaa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "457412.protein.sequences.v11.5.fa",
		        "enrichment_path": "457412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457412.protein.info.v11.5.txt",
		        "node_list_path": "457412.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrnithorhynchusAnatinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ornithorhynchus anatinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithorhynchusAnatinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9258.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9258.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9258.clusters.proteins.v11.5.txt",
		        "sequence_path": "9258.protein.sequences.v11.5.fa",
		        "enrichment_path": "9258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9258.protein.info.v11.5.txt",
		        "node_list_path": "9258.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9258.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterGangjinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter gangjinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterGangjinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "502682.protein.sequences.v11.5.fa",
		        "enrichment_path": "502682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502682.protein.info.v11.5.txt",
		        "node_list_path": "502682.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurimonasDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326298.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326298.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326298.clusters.proteins.v11.5.txt",
		        "sequence_path": "326298.protein.sequences.v11.5.fa",
		        "enrichment_path": "326298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326298.protein.info.v11.5.txt",
		        "node_list_path": "326298.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326298.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaTaiwanense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma taiwanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaTaiwanense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1276220.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276220.protein.info.v11.5.txt",
		        "node_list_path": "1276220.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisKunsanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis kunsanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisKunsanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246445.protein.info.v11.5.txt",
		        "node_list_path": "1246445.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlj7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlj7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158756.protein.info.v11.5.txt",
		        "node_list_path": "1158756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodospirillalesBacteriumRifcsplowo202Full5816Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium RIFCSPLOWO2_02_FULL_58_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillalesBacteriumRifcsplowo202Full5816Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802021.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802021.protein.info.v11.5.txt",
		        "node_list_path": "1802021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaRhizoxinicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia rhizoxinica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaRhizoxinicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "882378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "882378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "882378.clusters.proteins.v11.5.txt",
		        "sequence_path": "882378.protein.sequences.v11.5.fa",
		        "enrichment_path": "882378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882378.protein.info.v11.5.txt",
		        "node_list_path": "882378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "882378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumSm2361(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium SM23_61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumSm2361", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703399.protein.info.v11.5.txt",
		        "node_list_path": "1703399.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifcsphigho202Full3936Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPHIGHO2_02_FULL_39_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifcsphigho202Full3936Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797942.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797942.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797942.protein.info.v11.5.txt",
		        "node_list_path": "1797942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StrigamiaMaritima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Strigamia maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrigamiaMaritima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "126957.protein.sequences.v11.5.fa",
		        "enrichment_path": "126957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "126957.protein.info.v11.5.txt",
		        "node_list_path": "126957.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzoarcusSpBh72Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azoarcus sp. BH72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzoarcusSpBh72Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "62928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "62928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "62928.clusters.proteins.v11.5.txt",
		        "sequence_path": "62928.protein.sequences.v11.5.fa",
		        "enrichment_path": "62928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62928.protein.info.v11.5.txt",
		        "node_list_path": "62928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "62928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesBingchenggensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces bingchenggensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesBingchenggensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "749414.clusters.info.v11.5.txt",
		        "cluster_tree_path": "749414.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "749414.clusters.proteins.v11.5.txt",
		        "sequence_path": "749414.protein.sequences.v11.5.fa",
		        "enrichment_path": "749414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "749414.protein.info.v11.5.txt",
		        "node_list_path": "749414.cluster.nodes.v11.5.txt",
		        "edge_list_path": "749414.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaSalmonicidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia salmonicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSalmonicidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53431.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53431.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53431.clusters.proteins.v11.5.txt",
		        "sequence_path": "53431.protein.sequences.v11.5.fa",
		        "enrichment_path": "53431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53431.protein.info.v11.5.txt",
		        "node_list_path": "53431.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53431.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93064.protein.sequences.v11.5.fa",
		        "enrichment_path": "93064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93064.protein.info.v11.5.txt",
		        "node_list_path": "93064.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellvibrionaceaeBacteriumBs12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrionaceae bacterium Bs12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrionaceaeBacteriumBs12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304902.protein.info.v11.5.txt",
		        "node_list_path": "1304902.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropithecusCoquereliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propithecus coquereli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropithecusCoquereliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "379532.clusters.info.v11.5.txt",
		        "cluster_tree_path": "379532.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "379532.clusters.proteins.v11.5.txt",
		        "sequence_path": "379532.protein.sequences.v11.5.fa",
		        "enrichment_path": "379532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "379532.protein.info.v11.5.txt",
		        "node_list_path": "379532.cluster.nodes.v11.5.txt",
		        "edge_list_path": "379532.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasHistidinilytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas histidinilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasHistidinilytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "439228.protein.sequences.v11.5.fa",
		        "enrichment_path": "439228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439228.protein.info.v11.5.txt",
		        "node_list_path": "439228.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusEisenbacteriaBacteriumRbg167146Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Eisenbacteria bacterium RBG_16_71_46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusEisenbacteriaBacteriumRbg167146Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817856.protein.info.v11.5.txt",
		        "node_list_path": "1817856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasMelonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas melonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasMelonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1090320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1090320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1090320.protein.info.v11.5.txt",
		        "node_list_path": "1090320.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaladaptatusPaucihalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haladaptatus paucihalophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaladaptatusPaucihalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "797209.protein.sequences.v11.5.fa",
		        "enrichment_path": "797209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797209.protein.info.v11.5.txt",
		        "node_list_path": "797209.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf469Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf469 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf469Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736387.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736387.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736387.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736387.protein.info.v11.5.txt",
		        "node_list_path": "1736387.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736387.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusRuberCbs135680(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ruber CBS 135680 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusRuberCbs135680", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1388766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1388766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1388766.protein.info.v11.5.txt",
		        "node_list_path": "1388766.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusHyicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus hyicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusHyicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284.protein.info.v11.5.txt",
		        "node_list_path": "1284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusCarnosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus carnosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusCarnosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "396513.protein.sequences.v11.5.fa",
		        "enrichment_path": "396513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396513.protein.info.v11.5.txt",
		        "node_list_path": "396513.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetrapisisporaBlattaeCbs6284(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora blattae CBS 6284 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrapisisporaBlattaeCbs6284", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071380.protein.info.v11.5.txt",
		        "node_list_path": "1071380.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumGw2011Gwa1409(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium GW2011_GWA1_40_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumGw2011Gwa1409", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618408.protein.info.v11.5.txt",
		        "node_list_path": "1618408.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalispirochaetaAlkalicaDsm8900(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalispirochaeta alkalica DSM 8900 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalispirochaetaAlkalicaDsm8900", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "942938.protein.sequences.v11.5.fa",
		        "enrichment_path": "942938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "942938.protein.info.v11.5.txt",
		        "node_list_path": "942938.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShimiaAestuariiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shimia aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShimiaAestuariiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "254406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "254406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "254406.clusters.proteins.v11.5.txt",
		        "sequence_path": "254406.protein.sequences.v11.5.fa",
		        "enrichment_path": "254406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "254406.protein.info.v11.5.txt",
		        "node_list_path": "254406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "254406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetascardoviaCriceti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Metascardovia criceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetascardoviaCriceti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122228.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122228.protein.info.v11.5.txt",
		        "node_list_path": "1122228.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumRifcsphigho212Full4510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RIFCSPHIGHO2_12_FULL_45_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRifcsphigho212Full4510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802603.protein.info.v11.5.txt",
		        "node_list_path": "1802603.protein.complete.v11.5.txt"
		    }
		]
    )()

def CrucibulumLaeveCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crucibulum laeve Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrucibulumLaeveCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68775.clusters.proteins.v11.5.txt",
		        "sequence_path": "68775.protein.sequences.v11.5.fa",
		        "enrichment_path": "68775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68775.protein.info.v11.5.txt",
		        "node_list_path": "68775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumBranderi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium branderi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumBranderi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43348.protein.sequences.v11.5.fa",
		        "enrichment_path": "43348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43348.protein.info.v11.5.txt",
		        "node_list_path": "43348.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasTunicataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas tunicata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasTunicataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "87626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "87626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "87626.clusters.proteins.v11.5.txt",
		        "sequence_path": "87626.protein.sequences.v11.5.fa",
		        "enrichment_path": "87626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "87626.protein.info.v11.5.txt",
		        "node_list_path": "87626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "87626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSp01251Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 0-1251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSp01251Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895858.protein.info.v11.5.txt",
		        "node_list_path": "1895858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasSpBhbn044Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. BHBN044 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSpBhbn044Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280947.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280947.protein.info.v11.5.txt",
		        "node_list_path": "1280947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesGambiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles gambiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesGambiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7165.clusters.proteins.v11.5.txt",
		        "sequence_path": "7165.protein.sequences.v11.5.fa",
		        "enrichment_path": "7165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7165.protein.info.v11.5.txt",
		        "node_list_path": "7165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronobacteriumGregoryi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronobacterium gregoryi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronobacteriumGregoryi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "797304.protein.sequences.v11.5.fa",
		        "enrichment_path": "797304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797304.protein.info.v11.5.txt",
		        "node_list_path": "797304.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterovibrioCoralii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio coralii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioCoralii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "294935.protein.sequences.v11.5.fa",
		        "enrichment_path": "294935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294935.protein.info.v11.5.txt",
		        "node_list_path": "294935.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpNciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Nci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpNciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1316444.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1316444.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1316444.clusters.proteins.v11.0.txt",
		        "sequence_path": "1316444.protein.sequences.v11.0.fa",
		        "enrichment_path": "1316444.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1316444.protein.info.v11.0.txt",
		        "node_list_path": "1316444.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1316444.protein.cluster.v11.0.txt"
		    }
		]
    )()

def SchizosaccharomycesPombeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces pombe Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesPombeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4896.clusters.proteins.v11.5.txt",
		        "sequence_path": "4896.protein.sequences.v11.5.fa",
		        "enrichment_path": "4896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4896.protein.info.v11.5.txt",
		        "node_list_path": "4896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasLuteolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas luteola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasLuteolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1207076.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1207076.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1207076.clusters.proteins.v11.5.txt",
		        "sequence_path": "1207076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1207076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1207076.protein.info.v11.5.txt",
		        "node_list_path": "1207076.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1207076.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaMediumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema medium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaMediumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1125700.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1125700.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1125700.clusters.proteins.v11.5.txt",
		        "sequence_path": "1125700.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125700.protein.info.v11.5.txt",
		        "node_list_path": "1125700.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1125700.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AminobacteriumMobileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aminobacterium mobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminobacteriumMobileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304875.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304875.protein.info.v11.5.txt",
		        "node_list_path": "1304875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfolobusSpJcm16833Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus sp. JCM 16833 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusSpJcm16833Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1294262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1294262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1294262.clusters.proteins.v11.5.txt",
		        "sequence_path": "1294262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294262.protein.info.v11.5.txt",
		        "node_list_path": "1294262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1294262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrobacterYoungaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter youngae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterYoungaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "500640.clusters.info.v11.5.txt",
		        "cluster_tree_path": "500640.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "500640.clusters.proteins.v11.5.txt",
		        "sequence_path": "500640.protein.sequences.v11.5.fa",
		        "enrichment_path": "500640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500640.protein.info.v11.5.txt",
		        "node_list_path": "500640.cluster.nodes.v11.5.txt",
		        "edge_list_path": "500640.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg164923Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_49_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg164923Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797840.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797840.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797840.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797840.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797840.protein.info.v11.5.txt",
		        "node_list_path": "1797840.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797840.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusParacuniculusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus paracuniculus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusParacuniculusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "734.clusters.proteins.v11.5.txt",
		        "sequence_path": "734.protein.sequences.v11.5.fa",
		        "enrichment_path": "734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "734.protein.info.v11.5.txt",
		        "node_list_path": "734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LatimeriaChalumnaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Latimeria chalumnae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LatimeriaChalumnaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7897.clusters.proteins.v11.5.txt",
		        "sequence_path": "7897.protein.sequences.v11.5.fa",
		        "enrichment_path": "7897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7897.protein.info.v11.5.txt",
		        "node_list_path": "7897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpRoot135Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Root135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpRoot135Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736457.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736457.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736457.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736457.protein.info.v11.5.txt",
		        "node_list_path": "1736457.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736457.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CucumisMelo(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cucumis melo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CucumisMelo", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3656.protein.sequences.v11.5.fa",
		        "enrichment_path": "3656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3656.protein.info.v11.5.txt",
		        "node_list_path": "3656.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShimiaAestuarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shimia aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShimiaAestuarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "254406.protein.sequences.v11.5.fa",
		        "enrichment_path": "254406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "254406.protein.info.v11.5.txt",
		        "node_list_path": "254406.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa23813bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_38_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa23813bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618780.protein.info.v11.5.txt",
		        "node_list_path": "1618780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassilibacteriumSenegalense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilibacterium senegalense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassilibacteriumSenegalense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1632858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1632858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1632858.protein.info.v11.5.txt",
		        "node_list_path": "1632858.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalegentibacterEchinorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter echinorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterEchinorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1073325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073325.protein.info.v11.5.txt",
		        "node_list_path": "1073325.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumScgcAaa288G21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA288-G21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumScgcAaa288G21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "939324.protein.sequences.v11.5.fa",
		        "enrichment_path": "939324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939324.protein.info.v11.5.txt",
		        "node_list_path": "939324.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrodochiumBolleyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microdochium bolleyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrodochiumBolleyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "196109.clusters.info.v11.5.txt",
		        "cluster_tree_path": "196109.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "196109.clusters.proteins.v11.5.txt",
		        "sequence_path": "196109.protein.sequences.v11.5.fa",
		        "enrichment_path": "196109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "196109.protein.info.v11.5.txt",
		        "node_list_path": "196109.cluster.nodes.v11.5.txt",
		        "edge_list_path": "196109.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GiardiaLambliaP15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Giardia lamblia P15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GiardiaLambliaP15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658858.clusters.proteins.v11.5.txt",
		        "sequence_path": "658858.protein.sequences.v11.5.fa",
		        "enrichment_path": "658858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658858.protein.info.v11.5.txt",
		        "node_list_path": "658858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulosimicrobiumCellulansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulosimicrobium cellulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulosimicrobiumCellulansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935839.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935839.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935839.clusters.proteins.v11.5.txt",
		        "sequence_path": "935839.protein.sequences.v11.5.fa",
		        "enrichment_path": "935839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935839.protein.info.v11.5.txt",
		        "node_list_path": "935839.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935839.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSp651059(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-1059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSp651059", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895860.protein.info.v11.5.txt",
		        "node_list_path": "1895860.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaGenomosp9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaGenomosp9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1416803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416803.protein.info.v11.5.txt",
		        "node_list_path": "1416803.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrauserellaRugosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prauserella rugosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrauserellaRugosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43354.clusters.proteins.v11.5.txt",
		        "sequence_path": "43354.protein.sequences.v11.5.fa",
		        "enrichment_path": "43354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43354.protein.info.v11.5.txt",
		        "node_list_path": "43354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterSpM21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter sp. M21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterSpM21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "443144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "443144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "443144.clusters.proteins.v11.5.txt",
		        "sequence_path": "443144.protein.sequences.v11.5.fa",
		        "enrichment_path": "443144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443144.protein.info.v11.5.txt",
		        "node_list_path": "443144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "443144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24227(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_42_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24227", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619049.protein.info.v11.5.txt",
		        "node_list_path": "1619049.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquidulcibacterPaucihalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquidulcibacter paucihalophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquidulcibacterPaucihalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1978549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1978549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1978549.clusters.proteins.v11.5.txt",
		        "sequence_path": "1978549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978549.protein.info.v11.5.txt",
		        "node_list_path": "1978549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1978549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusUreilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus ureilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusUreilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131292.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131292.protein.info.v11.5.txt",
		        "node_list_path": "1131292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesOris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces oris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesOris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "544580.protein.sequences.v11.5.fa",
		        "enrichment_path": "544580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "544580.protein.info.v11.5.txt",
		        "node_list_path": "544580.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaSpCag878Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma sp. CAG:878 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaSpCag878Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262686.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262686.protein.info.v11.5.txt",
		        "node_list_path": "1262686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumNeoaurum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium neoaurum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumNeoaurum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "700508.protein.sequences.v11.5.fa",
		        "enrichment_path": "700508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "700508.protein.info.v11.5.txt",
		        "node_list_path": "700508.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidaceaeBacteriumMs4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidaceae bacterium MS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidaceaeBacteriumMs4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1347393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1347393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1347393.clusters.proteins.v11.5.txt",
		        "sequence_path": "1347393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347393.protein.info.v11.5.txt",
		        "node_list_path": "1347393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1347393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpeibonaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces speibonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpeibonaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "195801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "195801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "195801.clusters.proteins.v11.5.txt",
		        "sequence_path": "195801.protein.sequences.v11.5.fa",
		        "enrichment_path": "195801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195801.protein.info.v11.5.txt",
		        "node_list_path": "195801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "195801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfolobalesArchaeonAcd1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobales archaeon Acd1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobalesArchaeonAcd1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1294123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294123.protein.info.v11.5.txt",
		        "node_list_path": "1294123.protein.complete.v11.5.txt"
		    }
		]
    )()

def GranulicoccusPhenolivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Granulicoccus phenolivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicoccusPhenolivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121933.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121933.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121933.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121933.protein.info.v11.5.txt",
		        "node_list_path": "1121933.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121933.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlishewanellaJeotgali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alishewanella jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlishewanellaJeotgali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1129374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1129374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1129374.protein.info.v11.5.txt",
		        "node_list_path": "1129374.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasCompostiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas composti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCompostiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658457.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658457.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658457.clusters.proteins.v11.5.txt",
		        "sequence_path": "658457.protein.sequences.v11.5.fa",
		        "enrichment_path": "658457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658457.protein.info.v11.5.txt",
		        "node_list_path": "658457.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658457.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGilvosporeusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces gilvosporeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGilvosporeusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553510.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553510.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553510.clusters.proteins.v11.5.txt",
		        "sequence_path": "553510.protein.sequences.v11.5.fa",
		        "enrichment_path": "553510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553510.protein.info.v11.5.txt",
		        "node_list_path": "553510.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553510.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfitobacteriumDehalogenans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium dehalogenans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitobacteriumDehalogenans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "756499.protein.sequences.v11.5.fa",
		        "enrichment_path": "756499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "756499.protein.info.v11.5.txt",
		        "node_list_path": "756499.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfuromonasSoudanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromonas soudanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromonasSoudanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1603606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603606.protein.info.v11.5.txt",
		        "node_list_path": "1603606.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaBoevrei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella boevrei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaBoevrei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122243.protein.info.v11.5.txt",
		        "node_list_path": "1122243.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloglobulusMorosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloglobulus morosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloglobulusMorosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1116472.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1116472.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1116472.clusters.proteins.v11.5.txt",
		        "sequence_path": "1116472.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116472.protein.info.v11.5.txt",
		        "node_list_path": "1116472.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1116472.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TannerellaForsythiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tannerella forsythia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TannerellaForsythiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "203275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "203275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "203275.clusters.proteins.v11.5.txt",
		        "sequence_path": "203275.protein.sequences.v11.5.fa",
		        "enrichment_path": "203275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203275.protein.info.v11.5.txt",
		        "node_list_path": "203275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "203275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpMi1205(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. MI1205 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpMi1205", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "407020.protein.sequences.v11.5.fa",
		        "enrichment_path": "407020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "407020.protein.info.v11.5.txt",
		        "node_list_path": "407020.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumJannaschiiDsm6295(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium jannaschii DSM 6295 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumJannaschiiDsm6295", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122200.protein.info.v11.5.txt",
		        "node_list_path": "1122200.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCarsonellaRuddiiPvCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii PV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCarsonellaRuddiiPvCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "387662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "387662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "387662.clusters.proteins.v11.5.txt",
		        "sequence_path": "387662.protein.sequences.v11.5.fa",
		        "enrichment_path": "387662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "387662.protein.info.v11.5.txt",
		        "node_list_path": "387662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "387662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaSpHmsc072f04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC072F04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSpHmsc072f04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739348.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739348.protein.info.v11.5.txt",
		        "node_list_path": "1739348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumCg104938Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium CG10_49_38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumCg104938Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1911687.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1911687.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1911687.clusters.proteins.v11.5.txt",
		        "sequence_path": "1911687.protein.sequences.v11.5.fa",
		        "enrichment_path": "1911687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1911687.protein.info.v11.5.txt",
		        "node_list_path": "1911687.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1911687.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeiothermusSilvanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus silvanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusSilvanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "526227.clusters.info.v11.5.txt",
		        "cluster_tree_path": "526227.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "526227.clusters.proteins.v11.5.txt",
		        "sequence_path": "526227.protein.sequences.v11.5.fa",
		        "enrichment_path": "526227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526227.protein.info.v11.5.txt",
		        "node_list_path": "526227.cluster.nodes.v11.5.txt",
		        "edge_list_path": "526227.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumIners(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium iners graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumIners", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1073423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073423.protein.info.v11.5.txt",
		        "node_list_path": "1073423.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevirhabdusPacificaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevirhabdus pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevirhabdusPacificaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267768.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267768.protein.info.v11.5.txt",
		        "node_list_path": "1267768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusGrossensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus grossensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusGrossensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1465756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1465756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1465756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1465756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1465756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1465756.protein.info.v11.5.txt",
		        "node_list_path": "1465756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1465756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasOtitidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas otitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasOtitidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "319939.protein.sequences.v11.5.fa",
		        "enrichment_path": "319939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319939.protein.info.v11.5.txt",
		        "node_list_path": "319939.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseburiaIntestinalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseburia intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaIntestinalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "166486.protein.sequences.v11.5.fa",
		        "enrichment_path": "166486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "166486.protein.info.v11.5.txt",
		        "node_list_path": "166486.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobacterVibrioformisDsm8776(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacter vibrioformis DSM 8776 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacterVibrioformisDsm8776", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121398.protein.info.v11.5.txt",
		        "node_list_path": "1121398.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasCaeniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCaeniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521719.clusters.proteins.v11.5.txt",
		        "sequence_path": "521719.protein.sequences.v11.5.fa",
		        "enrichment_path": "521719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521719.protein.info.v11.5.txt",
		        "node_list_path": "521719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpVlb120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. VLB120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpVlb120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69328.protein.sequences.v11.5.fa",
		        "enrichment_path": "69328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69328.protein.info.v11.5.txt",
		        "node_list_path": "69328.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcaricomesPhytoseiuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acaricomes phytoseiuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcaricomesPhytoseiuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120917.protein.info.v11.5.txt",
		        "node_list_path": "1120917.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapsicumChinense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capsicum chinense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsicumChinense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "80379.protein.sequences.v11.5.fa",
		        "enrichment_path": "80379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80379.protein.info.v11.5.txt",
		        "node_list_path": "80379.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterovibrioPacificusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioPacificusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1080227.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1080227.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1080227.clusters.proteins.v11.5.txt",
		        "sequence_path": "1080227.protein.sequences.v11.5.fa",
		        "enrichment_path": "1080227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1080227.protein.info.v11.5.txt",
		        "node_list_path": "1080227.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1080227.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaPyrifoliae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia pyrifoliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaPyrifoliae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634499.protein.sequences.v11.5.fa",
		        "enrichment_path": "634499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634499.protein.info.v11.5.txt",
		        "node_list_path": "634499.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocPseudomesenteroides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc pseudomesenteroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocPseudomesenteroides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1154757.protein.sequences.v11.5.fa",
		        "enrichment_path": "1154757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1154757.protein.info.v11.5.txt",
		        "node_list_path": "1154757.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCellulosaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces cellulosae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCellulosaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1968.clusters.proteins.v11.5.txt",
		        "sequence_path": "1968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1968.protein.info.v11.5.txt",
		        "node_list_path": "1968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeorickettsiaHelminthoecaStrOregon(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neorickettsia helminthoeca str. Oregon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorickettsiaHelminthoecaStrOregon", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1286528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286528.protein.info.v11.5.txt",
		        "node_list_path": "1286528.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaRattimassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella rattimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaRattimassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094556.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094556.protein.info.v11.5.txt",
		        "node_list_path": "1094556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterOlleyae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter olleyae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterOlleyae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "294671.protein.sequences.v11.5.fa",
		        "enrichment_path": "294671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294671.protein.info.v11.5.txt",
		        "node_list_path": "294671.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpU41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. U41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpU41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849032.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849032.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849032.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849032.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849032.protein.info.v11.5.txt",
		        "node_list_path": "1849032.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849032.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4432(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_12_FULL_44_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4432", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798366.protein.info.v11.5.txt",
		        "node_list_path": "1798366.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacterium13140cm6517(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 13_1_40CM_65_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacterium13140cm6517", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805080.protein.info.v11.5.txt",
		        "node_list_path": "1805080.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlS350Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL S-350 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlS350Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463902.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463902.protein.info.v11.5.txt",
		        "node_list_path": "1463902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPeoriaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus peoriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPeoriaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1087481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1087481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1087481.clusters.proteins.v11.5.txt",
		        "sequence_path": "1087481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1087481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1087481.protein.info.v11.5.txt",
		        "node_list_path": "1087481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1087481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermosiphoSp1063(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermosipho sp. 1063 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosiphoSp1063", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1462747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462747.protein.info.v11.5.txt",
		        "node_list_path": "1462747.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpBg2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. Bg2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpBg2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1784823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1784823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1784823.clusters.proteins.v11.5.txt",
		        "sequence_path": "1784823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1784823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1784823.protein.info.v11.5.txt",
		        "node_list_path": "1784823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1784823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAc2014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAc2014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408320.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408320.protein.info.v11.5.txt",
		        "node_list_path": "1408320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WickerhamiellaSorbophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamiella sorbophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WickerhamiellaSorbophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45607.protein.sequences.v11.5.fa",
		        "enrichment_path": "45607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45607.protein.info.v11.5.txt",
		        "node_list_path": "45607.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSalinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter salinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSalinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1874317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1874317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1874317.protein.info.v11.5.txt",
		        "node_list_path": "1874317.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRifoxyd1Full5311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1_FULL_53_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1Full5311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797403.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797403.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797403.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797403.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797403.protein.info.v11.5.txt",
		        "node_list_path": "1797403.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797403.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubrivivaxBenzoatilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubrivivax benzoatilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrivivaxBenzoatilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "987059.protein.sequences.v11.5.fa",
		        "enrichment_path": "987059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "987059.protein.info.v11.5.txt",
		        "node_list_path": "987059.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27916Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27916Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1679169.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1679169.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1679169.clusters.proteins.v11.5.txt",
		        "sequence_path": "1679169.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679169.protein.info.v11.5.txt",
		        "node_list_path": "1679169.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1679169.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSulciaMuelleriGwss(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri GWSS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSulciaMuelleriGwss", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "444179.protein.sequences.v11.5.fa",
		        "enrichment_path": "444179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444179.protein.info.v11.5.txt",
		        "node_list_path": "444179.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfipiaSpGas231(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. GAS231 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaSpGas231", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882747.protein.info.v11.5.txt",
		        "node_list_path": "1882747.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospirillumPhotometricum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillum photometricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillumPhotometricum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150469.protein.info.v11.5.txt",
		        "node_list_path": "1150469.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfatatorAutotrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfatator autotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfatatorAutotrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1795632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1795632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1795632.clusters.proteins.v11.5.txt",
		        "sequence_path": "1795632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795632.protein.info.v11.5.txt",
		        "node_list_path": "1795632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1795632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KuraishiaCapsulataCbs1993(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kuraishia capsulata CBS 1993 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KuraishiaCapsulataCbs1993", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1382522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382522.protein.info.v11.5.txt",
		        "node_list_path": "1382522.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg2303621Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_36_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2303621Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805315.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805315.protein.info.v11.5.txt",
		        "node_list_path": "1805315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriumSpPmmr2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacterium sp. PMMR2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriumSpPmmr2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1382359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1382359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1382359.clusters.proteins.v11.5.txt",
		        "sequence_path": "1382359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382359.protein.info.v11.5.txt",
		        "node_list_path": "1382359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1382359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusYeei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus yeei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusYeei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1446473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1446473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1446473.protein.info.v11.5.txt",
		        "node_list_path": "1446473.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463881.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463881.protein.info.v11.5.txt",
		        "node_list_path": "1463881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaSpEcsmb14101Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. ECSMB14101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSpEcsmb14101Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1565129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1565129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1565129.clusters.proteins.v11.5.txt",
		        "sequence_path": "1565129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1565129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1565129.protein.info.v11.5.txt",
		        "node_list_path": "1565129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1565129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NostocPiscinaleCena21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nostoc piscinale CENA21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocPiscinaleCena21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "224013.protein.sequences.v11.5.fa",
		        "enrichment_path": "224013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224013.protein.info.v11.5.txt",
		        "node_list_path": "224013.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaXinjiangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaXinjiangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "882086.protein.sequences.v11.5.fa",
		        "enrichment_path": "882086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882086.protein.info.v11.5.txt",
		        "node_list_path": "882086.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpMb200Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. MB200 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpMb200Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "648885.clusters.info.v11.5.txt",
		        "cluster_tree_path": "648885.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "648885.clusters.proteins.v11.5.txt",
		        "sequence_path": "648885.protein.sequences.v11.5.fa",
		        "enrichment_path": "648885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "648885.protein.info.v11.5.txt",
		        "node_list_path": "648885.cluster.nodes.v11.5.txt",
		        "edge_list_path": "648885.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MusaAcuminata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Musa acuminata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusaAcuminata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4641.protein.sequences.v11.5.fa",
		        "enrichment_path": "4641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4641.protein.info.v11.5.txt",
		        "node_list_path": "4641.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaPutidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema putidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPutidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "221027.protein.sequences.v11.5.fa",
		        "enrichment_path": "221027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221027.protein.info.v11.5.txt",
		        "node_list_path": "221027.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusThermophilusJl18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus JL-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusThermophilusJl18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "798128.protein.sequences.v11.5.fa",
		        "enrichment_path": "798128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "798128.protein.info.v11.5.txt",
		        "node_list_path": "798128.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRoot166(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root166 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRoot166", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736478.protein.info.v11.5.txt",
		        "node_list_path": "1736478.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlleyaSpVcsa23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olleya sp. VCSA23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlleyaSpVcsa23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "745717.clusters.info.v11.5.txt",
		        "cluster_tree_path": "745717.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "745717.clusters.proteins.v11.5.txt",
		        "sequence_path": "745717.protein.sequences.v11.5.fa",
		        "enrichment_path": "745717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745717.protein.info.v11.5.txt",
		        "node_list_path": "745717.cluster.nodes.v11.5.txt",
		        "edge_list_path": "745717.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCoryniformisKctc3167(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis KCTC3167 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCoryniformisKctc3167", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "913848.protein.sequences.v11.5.fa",
		        "enrichment_path": "913848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913848.protein.info.v11.5.txt",
		        "node_list_path": "913848.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlexibacterFlexilisDsm6793(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flexibacter flexilis DSM 6793 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlexibacterFlexilisDsm6793", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "927664.protein.sequences.v11.5.fa",
		        "enrichment_path": "927664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927664.protein.info.v11.5.txt",
		        "node_list_path": "927664.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphaerochaetaPleomorpha(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphaerochaeta pleomorpha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerochaetaPleomorpha", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "158190.protein.sequences.v11.5.fa",
		        "enrichment_path": "158190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158190.protein.info.v11.5.txt",
		        "node_list_path": "158190.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophilusSp1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusSp1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1112273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1112273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1112273.clusters.proteins.v11.5.txt",
		        "sequence_path": "1112273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112273.protein.info.v11.5.txt",
		        "node_list_path": "1112273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1112273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaOvisStrMichiganCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma ovis str. Michigan Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaOvisStrMichiganCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415773.protein.info.v11.5.txt",
		        "node_list_path": "1415773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifoxyc2Full4228Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYC2_FULL_42_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyc2Full4228Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798704.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798704.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798704.protein.info.v11.5.txt",
		        "node_list_path": "1798704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaSpW9775Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. W9775 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaSpW9775Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321779.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321779.protein.info.v11.5.txt",
		        "node_list_path": "1321779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiaceaeBacteriumL21thd2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium L21THD2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaceaeBacteriumL21thd2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304284.protein.info.v11.5.txt",
		        "node_list_path": "1304284.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpRuh2624(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. RUH2624 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpRuh2624", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575564.protein.sequences.v11.5.fa",
		        "enrichment_path": "575564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575564.protein.info.v11.5.txt",
		        "node_list_path": "575564.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsphigho212Full439Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_43_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho212Full439Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797867.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797867.protein.info.v11.5.txt",
		        "node_list_path": "1797867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HolophagaFoetida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Holophaga foetida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HolophagaFoetida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "903818.protein.sequences.v11.5.fa",
		        "enrichment_path": "903818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903818.protein.info.v11.5.txt",
		        "node_list_path": "903818.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumGastri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium gastri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumGastri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777.protein.info.v11.5.txt",
		        "node_list_path": "1777.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevinemaAndersoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevinema andersonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevinemaAndersoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34097.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34097.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34097.clusters.proteins.v11.5.txt",
		        "sequence_path": "34097.protein.sequences.v11.5.fa",
		        "enrichment_path": "34097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34097.protein.info.v11.5.txt",
		        "node_list_path": "34097.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34097.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpF0262(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0262 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpF0262", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "608534.protein.sequences.v11.5.fa",
		        "enrichment_path": "608534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "608534.protein.info.v11.5.txt",
		        "node_list_path": "608534.protein.complete.v11.5.txt"
		    }
		]
    )()

def InediibacteriumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Inediibacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "InediibacteriumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658111.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658111.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658111.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658111.protein.info.v11.5.txt",
		        "node_list_path": "1658111.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658111.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsphigho202Full5118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO2_02_FULL_51_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202Full5118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801823.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801823.protein.info.v11.5.txt",
		        "node_list_path": "1801823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrenochaetaSpDs3say3a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrenochaeta sp. DS3sAY3a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrenochaetaSpDs3say3a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765867.protein.sequences.v11.5.fa",
		        "enrichment_path": "765867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765867.protein.info.v11.5.txt",
		        "node_list_path": "765867.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag841(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:841 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag841", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262894.protein.info.v11.5.txt",
		        "node_list_path": "1262894.protein.complete.v11.5.txt"
		    }
		]
    )()

def CycloclasticusZancles(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus zancles graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CycloclasticusZancles", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1198232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198232.protein.info.v11.5.txt",
		        "node_list_path": "1198232.protein.complete.v11.5.txt"
		    }
		]
    )()

def AttaCephalotesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atta cephalotes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AttaCephalotesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "12957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "12957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "12957.clusters.proteins.v11.5.txt",
		        "sequence_path": "12957.protein.sequences.v11.5.fa",
		        "enrichment_path": "12957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "12957.protein.info.v11.5.txt",
		        "node_list_path": "12957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "12957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CucumisSativus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cucumis sativus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CucumisSativus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3659.protein.sequences.v11.5.fa",
		        "enrichment_path": "3659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3659.protein.info.v11.5.txt",
		        "node_list_path": "3659.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumArenaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium arenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumArenaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1856850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1856850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1856850.clusters.proteins.v11.5.txt",
		        "sequence_path": "1856850.protein.sequences.v11.5.fa",
		        "enrichment_path": "1856850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1856850.protein.info.v11.5.txt",
		        "node_list_path": "1856850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1856850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumGwa1448Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium GWA1_44_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumGwa1448Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802591.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802591.protein.info.v11.5.txt",
		        "node_list_path": "1802591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusPneumoniaeD39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae D39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPneumoniaeD39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "373153.protein.sequences.v11.5.fa",
		        "enrichment_path": "373153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "373153.protein.info.v11.5.txt",
		        "node_list_path": "373153.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag1058Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag1058Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262918.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262918.protein.info.v11.5.txt",
		        "node_list_path": "1262918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSp6021061333(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 6021061333 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSp6021061333", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816690.protein.info.v11.5.txt",
		        "node_list_path": "1816690.protein.complete.v11.5.txt"
		    }
		]
    )()

def KibdelosporangiumPhytohabitansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kibdelosporangium phytohabitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KibdelosporangiumPhytohabitansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "860235.clusters.info.v11.5.txt",
		        "cluster_tree_path": "860235.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "860235.clusters.proteins.v11.5.txt",
		        "sequence_path": "860235.protein.sequences.v11.5.fa",
		        "enrichment_path": "860235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "860235.protein.info.v11.5.txt",
		        "node_list_path": "860235.cluster.nodes.v11.5.txt",
		        "edge_list_path": "860235.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PerlucidibacaAquatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Perlucidibaca aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PerlucidibacaAquatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852776.protein.info.v11.5.txt",
		        "node_list_path": "1852776.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldanaerobiusPolysaccharolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldanaerobius polysaccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldanaerobiusPolysaccharolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935948.clusters.proteins.v11.5.txt",
		        "sequence_path": "935948.protein.sequences.v11.5.fa",
		        "enrichment_path": "935948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935948.protein.info.v11.5.txt",
		        "node_list_path": "935948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumUlcerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium ulcerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumUlcerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "945712.protein.sequences.v11.5.fa",
		        "enrichment_path": "945712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "945712.protein.info.v11.5.txt",
		        "node_list_path": "945712.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiIai39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli IAI39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiIai39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585057.clusters.proteins.v11.5.txt",
		        "sequence_path": "585057.protein.sequences.v11.5.fa",
		        "enrichment_path": "585057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585057.protein.info.v11.5.txt",
		        "node_list_path": "585057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRbg134110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RBG_13_41_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRbg134110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801849.protein.info.v11.5.txt",
		        "node_list_path": "1801849.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpIbvss2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. IBVSS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpIbvss2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1985172.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1985172.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1985172.clusters.proteins.v11.5.txt",
		        "sequence_path": "1985172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1985172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1985172.protein.info.v11.5.txt",
		        "node_list_path": "1985172.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1985172.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OnchocercaFlexuosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Onchocerca flexuosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OnchocercaFlexuosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "387005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "387005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "387005.clusters.proteins.v11.5.txt",
		        "sequence_path": "387005.protein.sequences.v11.5.fa",
		        "enrichment_path": "387005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "387005.protein.info.v11.5.txt",
		        "node_list_path": "387005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "387005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF3557(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-3557 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF3557", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437433.protein.info.v11.5.txt",
		        "node_list_path": "1437433.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrobacterAmalonaticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter amalonaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterAmalonaticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35703.protein.sequences.v11.5.fa",
		        "enrichment_path": "35703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35703.protein.info.v11.5.txt",
		        "node_list_path": "35703.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeptunicoccusSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neptunicoccus sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptunicoccusSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1892596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1892596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1892596.clusters.proteins.v11.5.txt",
		        "sequence_path": "1892596.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892596.protein.info.v11.5.txt",
		        "node_list_path": "1892596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1892596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterNataicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter nataicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterNataicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "265960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "265960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "265960.clusters.proteins.v11.5.txt",
		        "sequence_path": "265960.protein.sequences.v11.5.fa",
		        "enrichment_path": "265960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265960.protein.info.v11.5.txt",
		        "node_list_path": "265960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "265960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMarmotae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus marmotae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMarmotae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1825069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1825069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1825069.protein.info.v11.5.txt",
		        "node_list_path": "1825069.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc13410Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_34_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc13410Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618891.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618891.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618891.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618891.protein.info.v11.5.txt",
		        "node_list_path": "1618891.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618891.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaSpF0557(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. F0557 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaSpF0557", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227268.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227268.protein.info.v11.5.txt",
		        "node_list_path": "1227268.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumFallax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium fallax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumFallax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1533.protein.info.v11.5.txt",
		        "node_list_path": "1533.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaPleuritidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella pleuritidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaPleuritidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236494.protein.info.v11.5.txt",
		        "node_list_path": "1236494.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophilusRhizosphaerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusRhizosphaerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "492660.protein.sequences.v11.5.fa",
		        "enrichment_path": "492660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "492660.protein.info.v11.5.txt",
		        "node_list_path": "492660.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurimonasSpRifcsplowo2123612Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFCSPLOWO2_12_36_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasSpRifcsplowo2123612Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802253.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802253.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802253.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802253.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802253.protein.info.v11.5.txt",
		        "node_list_path": "1802253.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802253.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterPasteurianusIfo328301(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus IFO328301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterPasteurianusIfo328301", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634452.protein.sequences.v11.5.fa",
		        "enrichment_path": "634452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634452.protein.info.v11.5.txt",
		        "node_list_path": "634452.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusParcubacteriaBacterium4484255(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Parcubacteria bacterium 4484_255 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusParcubacteriaBacterium4484255", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1970769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970769.protein.info.v11.5.txt",
		        "node_list_path": "1970769.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDesantisbacteriaBacteriumCg1024989(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG1_02_49_89 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg1024989", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817894.protein.info.v11.5.txt",
		        "node_list_path": "1817894.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpLmtr3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LMTR 3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpLmtr3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "189873.protein.sequences.v11.5.fa",
		        "enrichment_path": "189873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189873.protein.info.v11.5.txt",
		        "node_list_path": "189873.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSalsusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus salsus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSalsusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930152.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930152.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930152.clusters.proteins.v11.5.txt",
		        "sequence_path": "930152.protein.sequences.v11.5.fa",
		        "enrichment_path": "930152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930152.protein.info.v11.5.txt",
		        "node_list_path": "930152.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930152.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4027(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_40_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4027", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797788.protein.info.v11.5.txt",
		        "node_list_path": "1797788.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumRifcsphigho202Full4613Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO2_02_FULL_46_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho202Full4613Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797220.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797220.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797220.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797220.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797220.protein.info.v11.5.txt",
		        "node_list_path": "1797220.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797220.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrucellaMelitensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brucella melitensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrucellaMelitensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "224914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "224914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "224914.clusters.proteins.v11.5.txt",
		        "sequence_path": "224914.protein.sequences.v11.5.fa",
		        "enrichment_path": "224914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224914.protein.info.v11.5.txt",
		        "node_list_path": "224914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "224914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylovorusGlucosetrophusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylovorus glucosetrophus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylovorusGlucosetrophusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582744.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582744.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582744.clusters.proteins.v11.5.txt",
		        "sequence_path": "582744.protein.sequences.v11.5.fa",
		        "enrichment_path": "582744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582744.protein.info.v11.5.txt",
		        "node_list_path": "582744.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582744.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHaemocanisStrIllinoisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma haemocanis str. Illinois Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHaemocanisStrIllinoisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111676.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111676.protein.info.v11.5.txt",
		        "node_list_path": "1111676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpJdr2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JDR2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpJdr2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "324057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "324057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "324057.clusters.proteins.v11.5.txt",
		        "sequence_path": "324057.protein.sequences.v11.5.fa",
		        "enrichment_path": "324057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "324057.protein.info.v11.5.txt",
		        "node_list_path": "324057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "324057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp14657030(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1465703.0 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp14657030", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834078.protein.info.v11.5.txt",
		        "node_list_path": "1834078.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf24317Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_43_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf24317Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619085.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619085.protein.info.v11.5.txt",
		        "node_list_path": "1619085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxyd2Full3415(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYD2_FULL_34_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyd2Full3415", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797973.protein.info.v11.5.txt",
		        "node_list_path": "1797973.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTsri0281Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TSRI0281 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTsri0281Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1718998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1718998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1718998.clusters.proteins.v11.5.txt",
		        "sequence_path": "1718998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1718998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1718998.protein.info.v11.5.txt",
		        "node_list_path": "1718998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1718998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeotogaPetraeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geotoga petraea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeotogaPetraeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28234.clusters.proteins.v11.5.txt",
		        "sequence_path": "28234.protein.sequences.v11.5.fa",
		        "enrichment_path": "28234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28234.protein.info.v11.5.txt",
		        "node_list_path": "28234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArmillariaSolidipesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Armillaria solidipes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmillariaSolidipesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1076256.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1076256.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1076256.clusters.proteins.v11.5.txt",
		        "sequence_path": "1076256.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076256.protein.info.v11.5.txt",
		        "node_list_path": "1076256.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1076256.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacterium13120cm5428Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium 13_1_20CM_54_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacterium13120cm5428Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805411.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805411.protein.info.v11.5.txt",
		        "node_list_path": "1805411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumGw2011Gwf24242(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011_GWF2_42_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011Gwf24242", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619142.protein.info.v11.5.txt",
		        "node_list_path": "1619142.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlaviramulusBasaltisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flaviramulus basaltis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlaviramulusBasaltisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "369401.clusters.info.v11.5.txt",
		        "cluster_tree_path": "369401.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "369401.clusters.proteins.v11.5.txt",
		        "sequence_path": "369401.protein.sequences.v11.5.fa",
		        "enrichment_path": "369401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "369401.protein.info.v11.5.txt",
		        "node_list_path": "369401.cluster.nodes.v11.5.txt",
		        "edge_list_path": "369401.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSp651402(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-1402 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSp651402", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895861.protein.info.v11.5.txt",
		        "node_list_path": "1895861.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfallasArcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfallas arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfallasArcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "341036.protein.sequences.v11.5.fa",
		        "enrichment_path": "341036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "341036.protein.info.v11.5.txt",
		        "node_list_path": "341036.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusKorlensisNbrc107688(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus korlensis NBRC 107688 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusKorlensisNbrc107688", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348629.protein.info.v11.5.txt",
		        "node_list_path": "1348629.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusVietnamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus vietnamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusVietnamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351656.clusters.proteins.v11.5.txt",
		        "sequence_path": "351656.protein.sequences.v11.5.fa",
		        "enrichment_path": "351656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351656.protein.info.v11.5.txt",
		        "node_list_path": "351656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfofustisGlycolicusDsm9705(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfofustis glycolicus DSM 9705 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfofustisGlycolicusDsm9705", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121409.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121409.protein.info.v11.5.txt",
		        "node_list_path": "1121409.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallaecimonasXiamenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallaecimonas xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallaecimonasXiamenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "745411.protein.sequences.v11.5.fa",
		        "enrichment_path": "745411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745411.protein.info.v11.5.txt",
		        "node_list_path": "745411.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwe132154Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWE1_32_154 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwe132154Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802184.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802184.protein.info.v11.5.txt",
		        "node_list_path": "1802184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumMfb021Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MFB021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumMfb021Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1492922.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1492922.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1492922.clusters.proteins.v11.5.txt",
		        "sequence_path": "1492922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1492922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1492922.protein.info.v11.5.txt",
		        "node_list_path": "1492922.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1492922.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenirhodobacterEnshiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenirhodobacter enshiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenirhodobacterEnshiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1105367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1105367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1105367.protein.info.v11.5.txt",
		        "node_list_path": "1105367.protein.complete.v11.5.txt"
		    }
		]
    )()

def TsukamurellaTyrosinosolvens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tsukamurella tyrosinosolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TsukamurellaTyrosinosolvens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "57704.protein.sequences.v11.5.fa",
		        "enrichment_path": "57704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "57704.protein.info.v11.5.txt",
		        "node_list_path": "57704.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmorphothecaResinaeAtcc22711Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amorphotheca resinae ATCC 22711 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmorphothecaResinaeAtcc22711Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "857342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "857342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "857342.clusters.proteins.v11.5.txt",
		        "sequence_path": "857342.protein.sequences.v11.5.fa",
		        "enrichment_path": "857342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "857342.protein.info.v11.5.txt",
		        "node_list_path": "857342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "857342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronorubrumThiooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronorubrum thiooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronorubrumThiooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "308853.clusters.info.v11.5.txt",
		        "cluster_tree_path": "308853.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "308853.clusters.proteins.v11.5.txt",
		        "sequence_path": "308853.protein.sequences.v11.5.fa",
		        "enrichment_path": "308853.protein.enrichment.terms.v11.5.txt",
		        "info_path": "308853.protein.info.v11.5.txt",
		        "node_list_path": "308853.cluster.nodes.v11.5.txt",
		        "edge_list_path": "308853.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrassicaOleraceaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brassica oleracea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrassicaOleraceaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3712.clusters.proteins.v11.5.txt",
		        "sequence_path": "3712.protein.sequences.v11.5.fa",
		        "enrichment_path": "3712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3712.protein.info.v11.5.txt",
		        "node_list_path": "3712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasMaltophilia5bai2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia 5BAI2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasMaltophilia5bai2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1429851.protein.sequences.v11.5.fa",
		        "enrichment_path": "1429851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1429851.protein.info.v11.5.txt",
		        "node_list_path": "1429851.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterNitrophenolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter nitrophenolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterNitrophenolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "683150.clusters.info.v11.5.txt",
		        "cluster_tree_path": "683150.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "683150.clusters.proteins.v11.5.txt",
		        "sequence_path": "683150.protein.sequences.v11.5.fa",
		        "enrichment_path": "683150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683150.protein.info.v11.5.txt",
		        "node_list_path": "683150.cluster.nodes.v11.5.txt",
		        "edge_list_path": "683150.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrocinitomixCatalasiticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crocinitomix catalasitica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrocinitomixCatalasiticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408433.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408433.protein.info.v11.5.txt",
		        "node_list_path": "1408433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaTyphiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia typhi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaTyphiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "257363.clusters.info.v11.5.txt",
		        "cluster_tree_path": "257363.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "257363.clusters.proteins.v11.5.txt",
		        "sequence_path": "257363.protein.sequences.v11.5.fa",
		        "enrichment_path": "257363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "257363.protein.info.v11.5.txt",
		        "node_list_path": "257363.cluster.nodes.v11.5.txt",
		        "edge_list_path": "257363.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliopsisZonataCbs50665Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicilliopsis zonata CBS 506.65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliopsisZonataCbs50665Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1073090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1073090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1073090.clusters.proteins.v11.5.txt",
		        "sequence_path": "1073090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073090.protein.info.v11.5.txt",
		        "node_list_path": "1073090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1073090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrobacterFreundiiCfnih1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter freundii CFNIH1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterFreundiiCfnih1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1333848.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1333848.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1333848.clusters.proteins.v11.5.txt",
		        "sequence_path": "1333848.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333848.protein.info.v11.5.txt",
		        "node_list_path": "1333848.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1333848.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophomonasWolfeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophomonasWolfeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "335541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "335541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "335541.clusters.proteins.v11.5.txt",
		        "sequence_path": "335541.protein.sequences.v11.5.fa",
		        "enrichment_path": "335541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "335541.protein.info.v11.5.txt",
		        "node_list_path": "335541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "335541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LiberibacterAsiaticusPsy62Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus psy62 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LiberibacterAsiaticusPsy62Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "537021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "537021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "537021.clusters.proteins.v11.5.txt",
		        "sequence_path": "537021.protein.sequences.v11.5.fa",
		        "enrichment_path": "537021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537021.protein.info.v11.5.txt",
		        "node_list_path": "537021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "537021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusQuebecensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus quebecensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusQuebecensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "903983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "903983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "903983.clusters.proteins.v11.5.txt",
		        "sequence_path": "903983.protein.sequences.v11.5.fa",
		        "enrichment_path": "903983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903983.protein.info.v11.5.txt",
		        "node_list_path": "903983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "903983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpFc2001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FC2001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpFc2001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280671.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280671.protein.info.v11.5.txt",
		        "node_list_path": "1280671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DethiosulfovibrioPeptidovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dethiosulfovibrio peptidovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DethiosulfovibrioPeptidovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469381.protein.sequences.v11.5.fa",
		        "enrichment_path": "469381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469381.protein.info.v11.5.txt",
		        "node_list_path": "469381.protein.complete.v11.5.txt"
		    }
		]
    )()

def GluconacetobacterSpSxcc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gluconacetobacter sp. SXCC-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconacetobacterSpSxcc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1004836.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1004836.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1004836.clusters.proteins.v11.5.txt",
		        "sequence_path": "1004836.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004836.protein.info.v11.5.txt",
		        "node_list_path": "1004836.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1004836.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumSpCp1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium sp. CP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumSpCp1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1564681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1564681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1564681.clusters.proteins.v11.5.txt",
		        "sequence_path": "1564681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1564681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1564681.protein.info.v11.5.txt",
		        "node_list_path": "1564681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1564681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpAc4496Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. AC44/96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpAc4496Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841654.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841654.protein.info.v11.5.txt",
		        "node_list_path": "1841654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpOk909Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ok909 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpOk909Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761746.protein.info.v11.5.txt",
		        "node_list_path": "1761746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusArachidicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus arachidicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusArachidicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "656916.protein.sequences.v11.5.fa",
		        "enrichment_path": "656916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656916.protein.info.v11.5.txt",
		        "node_list_path": "656916.protein.complete.v11.5.txt"
		    }
		]
    )()

def PersicobacterSpJzb09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Persicobacter sp. JZB09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PersicobacterSpJzb09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1085624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1085624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1085624.clusters.proteins.v11.5.txt",
		        "sequence_path": "1085624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1085624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1085624.protein.info.v11.5.txt",
		        "node_list_path": "1085624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1085624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RobiginitaleaBiformata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Robiginitalea biformata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RobiginitaleaBiformata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313596.protein.sequences.v11.5.fa",
		        "enrichment_path": "313596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313596.protein.info.v11.5.txt",
		        "node_list_path": "313596.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaRettgeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia rettgeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaRettgeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "587.clusters.proteins.v11.5.txt",
		        "sequence_path": "587.protein.sequences.v11.5.fa",
		        "enrichment_path": "587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "587.protein.info.v11.5.txt",
		        "node_list_path": "587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesOlindensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces olindensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesOlindensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "358823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "358823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "358823.clusters.proteins.v11.5.txt",
		        "sequence_path": "358823.protein.sequences.v11.5.fa",
		        "enrichment_path": "358823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "358823.protein.info.v11.5.txt",
		        "node_list_path": "358823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "358823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumMurisUcdAy4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium muris UCD-AY4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumMurisUcdAy4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1249481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249481.protein.info.v11.5.txt",
		        "node_list_path": "1249481.protein.complete.v11.5.txt"
		    }
		]
    )()

def AustrofundulusLimnaeusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Austrofundulus limnaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AustrofundulusLimnaeusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52670.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52670.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52670.clusters.proteins.v11.5.txt",
		        "sequence_path": "52670.protein.sequences.v11.5.fa",
		        "enrichment_path": "52670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52670.protein.info.v11.5.txt",
		        "node_list_path": "52670.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52670.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSp2kl3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 2KL-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSp2kl3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1100700.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1100700.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1100700.clusters.proteins.v11.5.txt",
		        "sequence_path": "1100700.protein.sequences.v11.5.fa",
		        "enrichment_path": "1100700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1100700.protein.info.v11.5.txt",
		        "node_list_path": "1100700.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1100700.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisBisb5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisB5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisBisb5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316057.protein.sequences.v11.5.fa",
		        "enrichment_path": "316057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316057.protein.info.v11.5.txt",
		        "node_list_path": "316057.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMannanilyticusJcm10596Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mannanilyticus JCM 10596 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMannanilyticusJcm10596Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236954.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236954.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236954.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236954.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236954.protein.info.v11.5.txt",
		        "node_list_path": "1236954.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236954.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumAcnesHl037pa2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes HL037PA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumAcnesHl037pa2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765123.protein.sequences.v11.5.fa",
		        "enrichment_path": "765123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765123.protein.info.v11.5.txt",
		        "node_list_path": "765123.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrolobusFumarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrolobus fumarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrolobusFumarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "694429.protein.sequences.v11.5.fa",
		        "enrichment_path": "694429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694429.protein.info.v11.5.txt",
		        "node_list_path": "694429.protein.complete.v11.5.txt"
		    }
		]
    )()

def YersiniaEnterocolitica8081(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica 8081 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaEnterocolitica8081", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "393305.protein.sequences.v11.5.fa",
		        "enrichment_path": "393305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393305.protein.info.v11.5.txt",
		        "node_list_path": "393305.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumChilense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium chilense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumChilense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "946677.protein.sequences.v11.5.fa",
		        "enrichment_path": "946677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946677.protein.info.v11.5.txt",
		        "node_list_path": "946677.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumEtliMimosae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli mimosae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumEtliMimosae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1432050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432050.protein.info.v11.5.txt",
		        "node_list_path": "1432050.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaProvencensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella provencensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaProvencensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852386.protein.info.v11.5.txt",
		        "node_list_path": "1852386.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPelagibacterSpRs40(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. RS40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPelagibacterSpRs40", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977865.protein.info.v11.5.txt",
		        "node_list_path": "1977865.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavonifractorPlautii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavonifractor plautii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavonifractorPlautii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "292800.protein.sequences.v11.5.fa",
		        "enrichment_path": "292800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292800.protein.info.v11.5.txt",
		        "node_list_path": "292800.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpJahCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. JAH Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpJahCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1742858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1742858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1742858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1742858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742858.protein.info.v11.5.txt",
		        "node_list_path": "1742858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1742858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachymonasChironomiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachymonas chironomi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachymonasChironomiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121116.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121116.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121116.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121116.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121116.protein.info.v11.5.txt",
		        "node_list_path": "1121116.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121116.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumUasb340Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium UASB340 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumUasb340Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1655310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1655310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1655310.clusters.proteins.v11.5.txt",
		        "sequence_path": "1655310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655310.protein.info.v11.5.txt",
		        "node_list_path": "1655310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1655310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PasteurellaSkyensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella skyensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaSkyensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "97481.protein.sequences.v11.5.fa",
		        "enrichment_path": "97481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97481.protein.info.v11.5.txt",
		        "node_list_path": "97481.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaVerecundum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma verecundum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaVerecundum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "171291.protein.sequences.v11.5.fa",
		        "enrichment_path": "171291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "171291.protein.info.v11.5.txt",
		        "node_list_path": "171291.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalalkalicoccusJeotgali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halalkalicoccus jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalalkalicoccusJeotgali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "795797.protein.sequences.v11.5.fa",
		        "enrichment_path": "795797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "795797.protein.info.v11.5.txt",
		        "node_list_path": "795797.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlloscardoviaOmnicolensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alloscardovia omnicolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloscardoviaOmnicolensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120979.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120979.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120979.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120979.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120979.protein.info.v11.5.txt",
		        "node_list_path": "1120979.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120979.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonomuraeaWenchangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea wenchangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaWenchangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "568860.protein.sequences.v11.5.fa",
		        "enrichment_path": "568860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568860.protein.info.v11.5.txt",
		        "node_list_path": "568860.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterSpBisph1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter sp. Bisph1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterSpBisph1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1274399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274399.protein.info.v11.5.txt",
		        "node_list_path": "1274399.protein.complete.v11.5.txt"
		    }
		]
    )()

def KnoelliaSubterraneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Knoellia subterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KnoelliaSubterraneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385521.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385521.protein.info.v11.5.txt",
		        "node_list_path": "1385521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801775.protein.info.v11.5.txt",
		        "node_list_path": "1801775.protein.complete.v11.5.txt"
		    }
		]
    )()

def TanticharoeniaSakaeratensisNbrc103193Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tanticharoenia sakaeratensis NBRC 103193 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TanticharoeniaSakaeratensisNbrc103193Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231623.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231623.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231623.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231623.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231623.protein.info.v11.5.txt",
		        "node_list_path": "1231623.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231623.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumSpAf8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumSpAf8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1325734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325734.protein.info.v11.5.txt",
		        "node_list_path": "1325734.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyroidesOdoratus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myroides odoratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyroidesOdoratus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "929704.protein.sequences.v11.5.fa",
		        "enrichment_path": "929704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929704.protein.info.v11.5.txt",
		        "node_list_path": "929704.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucoagaricusSpSymcCos(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucoagaricus sp. SymC.cos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucoagaricusSpSymcCos", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1714833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714833.protein.info.v11.5.txt",
		        "node_list_path": "1714833.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoesziomycesAntarcticusT34Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moesziomyces antarcticus T-34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoesziomycesAntarcticusT34Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1151754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1151754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1151754.clusters.proteins.v11.5.txt",
		        "sequence_path": "1151754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151754.protein.info.v11.5.txt",
		        "node_list_path": "1151754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1151754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloteneraMobilis13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera mobilis 13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraMobilis13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1132855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1132855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1132855.protein.info.v11.5.txt",
		        "node_list_path": "1132855.protein.complete.v11.5.txt"
		    }
		]
    )()

def KiloniellaMajaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kiloniella majae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KiloniellaMajaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1938558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1938558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1938558.clusters.proteins.v11.5.txt",
		        "sequence_path": "1938558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938558.protein.info.v11.5.txt",
		        "node_list_path": "1938558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1938558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag624(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:624 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag624", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262965.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262965.protein.info.v11.5.txt",
		        "node_list_path": "1262965.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeishmaniaMajor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leishmania major graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeishmaniaMajor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5664.protein.sequences.v11.5.fa",
		        "enrichment_path": "5664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5664.protein.info.v11.5.txt",
		        "node_list_path": "5664.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumViolaceumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium violaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumViolaceumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243365.clusters.proteins.v11.5.txt",
		        "sequence_path": "243365.protein.sequences.v11.5.fa",
		        "enrichment_path": "243365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243365.protein.info.v11.5.txt",
		        "node_list_path": "243365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaPseudobrasiliensisNbrc108224Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia pseudobrasiliensis NBRC 108224 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaPseudobrasiliensisNbrc108224Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210086.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210086.protein.info.v11.5.txt",
		        "node_list_path": "1210086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisTaihuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis taihuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisTaihuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "260084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "260084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "260084.clusters.proteins.v11.5.txt",
		        "sequence_path": "260084.protein.sequences.v11.5.fa",
		        "enrichment_path": "260084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "260084.protein.info.v11.5.txt",
		        "node_list_path": "260084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "260084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumSpSd626rCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum sp. SD626R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumSpSd626rCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1419722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1419722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1419722.clusters.proteins.v11.5.txt",
		        "sequence_path": "1419722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1419722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1419722.protein.info.v11.5.txt",
		        "node_list_path": "1419722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1419722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaPhytofirmansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phytofirmans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaPhytofirmansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "398527.clusters.info.v11.5.txt",
		        "cluster_tree_path": "398527.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "398527.clusters.proteins.v11.5.txt",
		        "sequence_path": "398527.protein.sequences.v11.5.fa",
		        "enrichment_path": "398527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398527.protein.info.v11.5.txt",
		        "node_list_path": "398527.cluster.nodes.v11.5.txt",
		        "edge_list_path": "398527.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusCaprae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus caprae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusCaprae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525378.protein.sequences.v11.5.fa",
		        "enrichment_path": "525378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525378.protein.info.v11.5.txt",
		        "node_list_path": "525378.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumVariabileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium variabile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumVariabileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "858619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "858619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "858619.clusters.proteins.v11.5.txt",
		        "sequence_path": "858619.protein.sequences.v11.5.fa",
		        "enrichment_path": "858619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "858619.protein.info.v11.5.txt",
		        "node_list_path": "858619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "858619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrococcusSpMarseilleP2731(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrococcus sp. Marseille-P2731 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrococcusSpMarseilleP2731", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841862.protein.info.v11.5.txt",
		        "node_list_path": "1841862.protein.complete.v11.5.txt"
		    }
		]
    )()

def BombusImpatiens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bombus impatiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BombusImpatiens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "132113.protein.sequences.v11.5.fa",
		        "enrichment_path": "132113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "132113.protein.info.v11.5.txt",
		        "node_list_path": "132113.protein.complete.v11.5.txt"
		    }
		]
    )()

def LabrusBergyltaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Labrus bergylta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrusBergyltaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56723.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56723.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56723.clusters.proteins.v11.5.txt",
		        "sequence_path": "56723.protein.sequences.v11.5.fa",
		        "enrichment_path": "56723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56723.protein.info.v11.5.txt",
		        "node_list_path": "56723.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56723.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaFelis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila felis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaFelis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264202.protein.sequences.v11.5.fa",
		        "enrichment_path": "264202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264202.protein.info.v11.5.txt",
		        "node_list_path": "264202.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasCampestris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCampestris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "340.protein.sequences.v11.5.fa",
		        "enrichment_path": "340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340.protein.info.v11.5.txt",
		        "node_list_path": "340.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNc2004Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NC2004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNc2004Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410626.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410626.protein.info.v11.5.txt",
		        "node_list_path": "1410626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterCibarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter cibarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterCibarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1442598.protein.sequences.v11.5.fa",
		        "enrichment_path": "1442598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1442598.protein.info.v11.5.txt",
		        "node_list_path": "1442598.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoflavonifractorSpMarseilleP3106(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoflavonifractor sp. Marseille-P3106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoflavonifractorSpMarseilleP3106", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871015.protein.info.v11.5.txt",
		        "node_list_path": "1871015.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychromonasIngrahamii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas ingrahamii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychromonasIngrahamii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "357804.protein.sequences.v11.5.fa",
		        "enrichment_path": "357804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357804.protein.info.v11.5.txt",
		        "node_list_path": "357804.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanomethylovoransHollandicaDsm15978Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanomethylovorans hollandica DSM 15978 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomethylovoransHollandicaDsm15978Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "867904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "867904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "867904.clusters.proteins.v11.5.txt",
		        "sequence_path": "867904.protein.sequences.v11.5.fa",
		        "enrichment_path": "867904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867904.protein.info.v11.5.txt",
		        "node_list_path": "867904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "867904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaTularensisSchus4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella tularensis SCHUS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaTularensisSchus4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "177416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "177416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "177416.clusters.proteins.v11.5.txt",
		        "sequence_path": "177416.protein.sequences.v11.5.fa",
		        "enrichment_path": "177416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "177416.protein.info.v11.5.txt",
		        "node_list_path": "177416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "177416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterKobei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter kobei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterKobei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "208224.protein.sequences.v11.5.fa",
		        "enrichment_path": "208224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208224.protein.info.v11.5.txt",
		        "node_list_path": "208224.protein.complete.v11.5.txt"
		    }
		]
    )()

def StegastesPartitus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stegastes partitus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StegastesPartitus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "144197.protein.sequences.v11.5.fa",
		        "enrichment_path": "144197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "144197.protein.info.v11.5.txt",
		        "node_list_path": "144197.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimnohabitansPlanktonicusIiD5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans planktonicus II-D5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansPlanktonicusIiD5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293045.protein.info.v11.5.txt",
		        "node_list_path": "1293045.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSteynii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter steynii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSteynii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "430522.protein.sequences.v11.5.fa",
		        "enrichment_path": "430522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "430522.protein.info.v11.5.txt",
		        "node_list_path": "430522.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumSpScadc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. SCADC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumSpScadc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1537915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1537915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1537915.protein.info.v11.5.txt",
		        "node_list_path": "1537915.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillibacterValericigenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter valericigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterValericigenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "693746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "693746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "693746.clusters.proteins.v11.5.txt",
		        "sequence_path": "693746.protein.sequences.v11.5.fa",
		        "enrichment_path": "693746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "693746.protein.info.v11.5.txt",
		        "node_list_path": "693746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "693746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharothrixSpNrrlB16348Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharothrix sp. NRRL B-16348 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharothrixSpNrrlB16348Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415542.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415542.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415542.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415542.protein.info.v11.5.txt",
		        "node_list_path": "1415542.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415542.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpicoccumNigrum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epicoccum nigrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpicoccumNigrum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "105696.protein.sequences.v11.5.fa",
		        "enrichment_path": "105696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105696.protein.info.v11.5.txt",
		        "node_list_path": "105696.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioAlginolyticusNbrc15630(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus NBRC15630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioAlginolyticusNbrc15630", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219076.protein.info.v11.5.txt",
		        "node_list_path": "1219076.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaCynodegmi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga cynodegmi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaCynodegmi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926551.protein.sequences.v11.5.fa",
		        "enrichment_path": "926551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926551.protein.info.v11.5.txt",
		        "node_list_path": "926551.protein.complete.v11.5.txt"
		    }
		]
    )()

def DermatophilusCongolensisDsm44180Nbrc105199(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dermatophilus congolensis DSM 44180 NBRC 105199 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DermatophilusCongolensisDsm44180Nbrc105199", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121387.protein.info.v11.5.txt",
		        "node_list_path": "1121387.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterSpAap60Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. AAP60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterSpAap60Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523423.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523423.protein.info.v11.5.txt",
		        "node_list_path": "1523423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSubtilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSubtilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "224308.protein.sequences.v11.5.fa",
		        "enrichment_path": "224308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224308.protein.info.v11.5.txt",
		        "node_list_path": "224308.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumRifcsplowo202Full4710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPLOWO2_02_FULL_47_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsplowo202Full4710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802465.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802465.protein.info.v11.5.txt",
		        "node_list_path": "1802465.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_50_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798662.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798662.protein.info.v11.5.txt",
		        "node_list_path": "1798662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumSalicis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum salicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumSalicis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1209931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1209931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1209931.protein.info.v11.5.txt",
		        "node_list_path": "1209931.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHlucca08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCA08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHlucca08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1666913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1666913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1666913.clusters.proteins.v11.5.txt",
		        "sequence_path": "1666913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666913.protein.info.v11.5.txt",
		        "node_list_path": "1666913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1666913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FournierellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fournierella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FournierellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1650663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1650663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1650663.protein.info.v11.5.txt",
		        "node_list_path": "1650663.protein.complete.v11.5.txt"
		    }
		]
    )()

def LaceyellaSacchariCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Laceyella sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LaceyellaSacchariCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1341151.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1341151.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1341151.clusters.proteins.v11.5.txt",
		        "sequence_path": "1341151.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341151.protein.info.v11.5.txt",
		        "node_list_path": "1341151.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1341151.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKuenenbacteriaBacteriumCg2303924Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium CG2_30_39_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumCg2303924Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805236.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805236.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805236.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805236.protein.info.v11.5.txt",
		        "node_list_path": "1805236.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805236.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusSuryakundensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus suryakundensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusSuryakundensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1325335.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1325335.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1325335.clusters.proteins.v11.5.txt",
		        "sequence_path": "1325335.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325335.protein.info.v11.5.txt",
		        "node_list_path": "1325335.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1325335.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumOrbiculare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum orbiculare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumOrbiculare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5465.protein.sequences.v11.5.fa",
		        "enrichment_path": "5465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5465.protein.info.v11.5.txt",
		        "node_list_path": "5465.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaVacuolataZ761Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina vacuolata Z-761 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaVacuolataZ761Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434123.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434123.protein.info.v11.5.txt",
		        "node_list_path": "1434123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterNecessariusStir1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius STIR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterNecessariusStir1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "452638.clusters.info.v11.5.txt",
		        "cluster_tree_path": "452638.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "452638.clusters.proteins.v11.5.txt",
		        "sequence_path": "452638.protein.sequences.v11.5.fa",
		        "enrichment_path": "452638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452638.protein.info.v11.5.txt",
		        "node_list_path": "452638.cluster.nodes.v11.5.txt",
		        "edge_list_path": "452638.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioSpVpap30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. VPAP30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpVpap30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1647102.protein.sequences.v11.5.fa",
		        "enrichment_path": "1647102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1647102.protein.info.v11.5.txt",
		        "node_list_path": "1647102.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaloranaerobacterFerrireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caloranaerobacter ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloranaerobacterFerrireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1323370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1323370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1323370.protein.info.v11.5.txt",
		        "node_list_path": "1323370.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSp2136faaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. 2136FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSp2136faaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469609.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469609.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469609.clusters.proteins.v11.5.txt",
		        "sequence_path": "469609.protein.sequences.v11.5.fa",
		        "enrichment_path": "469609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469609.protein.info.v11.5.txt",
		        "node_list_path": "469609.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469609.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumReichenbachiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium reichenbachii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumReichenbachiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "362418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "362418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "362418.clusters.proteins.v11.5.txt",
		        "sequence_path": "362418.protein.sequences.v11.5.fa",
		        "enrichment_path": "362418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362418.protein.info.v11.5.txt",
		        "node_list_path": "362418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "362418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRiesiaSpGbbuCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia sp. GBBU Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRiesiaSpGbbuCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1719125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1719125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1719125.clusters.proteins.v11.5.txt",
		        "sequence_path": "1719125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1719125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1719125.protein.info.v11.5.txt",
		        "node_list_path": "1719125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1719125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumResistensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium resistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumResistensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "662755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "662755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "662755.clusters.proteins.v11.5.txt",
		        "sequence_path": "662755.protein.sequences.v11.5.fa",
		        "enrichment_path": "662755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "662755.protein.info.v11.5.txt",
		        "node_list_path": "662755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "662755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoactinosporaRubraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoactinospora rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoactinosporaRubraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1088767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1088767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1088767.clusters.proteins.v11.5.txt",
		        "sequence_path": "1088767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1088767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1088767.protein.info.v11.5.txt",
		        "node_list_path": "1088767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1088767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKomeilibacteriaBacteriumRifcsplowo202Full4811(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_02_FULL_48_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo202Full4811", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798553.protein.info.v11.5.txt",
		        "node_list_path": "1798553.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesRoseochromogenusSubspOscitansDs12976(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces roseochromogenus subsp. oscitans DS 12.976 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRoseochromogenusSubspOscitansDs12976", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1352936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1352936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1352936.protein.info.v11.5.txt",
		        "node_list_path": "1352936.protein.complete.v11.5.txt"
		    }
		]
    )()

def CosenzaeaMyxofaciensAtcc19692(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cosenzaea myxofaciens ATCC 19692 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CosenzaeaMyxofaciensAtcc19692", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354337.protein.info.v11.5.txt",
		        "node_list_path": "1354337.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinilyticumLitopenaeiDsm21440(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinilyticum litopenaei DSM 21440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinilyticumLitopenaeiDsm21440", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "529086.protein.sequences.v11.5.fa",
		        "enrichment_path": "529086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "529086.protein.info.v11.5.txt",
		        "node_list_path": "529086.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumF0540(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium F0540 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumF0540", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321778.protein.info.v11.5.txt",
		        "node_list_path": "1321778.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacterBemidjiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter bemidjiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterBemidjiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "404380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "404380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "404380.clusters.proteins.v11.5.txt",
		        "sequence_path": "404380.protein.sequences.v11.5.fa",
		        "enrichment_path": "404380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "404380.protein.info.v11.5.txt",
		        "node_list_path": "404380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "404380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaGuancheCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila guanche Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaGuancheCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7266.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7266.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7266.clusters.proteins.v11.5.txt",
		        "sequence_path": "7266.protein.sequences.v11.5.fa",
		        "enrichment_path": "7266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7266.protein.info.v11.5.txt",
		        "node_list_path": "7266.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7266.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrateuriaAurantia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frateuria aurantia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrateuriaAurantia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "767434.protein.sequences.v11.5.fa",
		        "enrichment_path": "767434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "767434.protein.info.v11.5.txt",
		        "node_list_path": "767434.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusCastoreusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus castoreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusCastoreusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123299.protein.info.v11.5.txt",
		        "node_list_path": "1123299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlsenellaTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805478.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805478.protein.info.v11.5.txt",
		        "node_list_path": "1805478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesExalbidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides exalbidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesExalbidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "402596.clusters.info.v11.5.txt",
		        "cluster_tree_path": "402596.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "402596.clusters.proteins.v11.5.txt",
		        "sequence_path": "402596.protein.sequences.v11.5.fa",
		        "enrichment_path": "402596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402596.protein.info.v11.5.txt",
		        "node_list_path": "402596.cluster.nodes.v11.5.txt",
		        "edge_list_path": "402596.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTuberculosisVariantCapraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant caprae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTuberculosisVariantCapraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "115862.clusters.info.v11.5.txt",
		        "cluster_tree_path": "115862.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "115862.clusters.proteins.v11.5.txt",
		        "sequence_path": "115862.protein.sequences.v11.5.fa",
		        "enrichment_path": "115862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115862.protein.info.v11.5.txt",
		        "node_list_path": "115862.cluster.nodes.v11.5.txt",
		        "edge_list_path": "115862.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanofollisEthanolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanofollis ethanolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanofollisEthanolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "488124.clusters.info.v11.5.txt",
		        "cluster_tree_path": "488124.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "488124.clusters.proteins.v11.5.txt",
		        "sequence_path": "488124.protein.sequences.v11.5.fa",
		        "enrichment_path": "488124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "488124.protein.info.v11.5.txt",
		        "node_list_path": "488124.cluster.nodes.v11.5.txt",
		        "edge_list_path": "488124.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterKobeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter kobei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterKobeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "208224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "208224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "208224.clusters.proteins.v11.5.txt",
		        "sequence_path": "208224.protein.sequences.v11.5.fa",
		        "enrichment_path": "208224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208224.protein.info.v11.5.txt",
		        "node_list_path": "208224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "208224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KryptolebiasMarmoratusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kryptolebias marmoratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KryptolebiasMarmoratusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37003.clusters.proteins.v11.5.txt",
		        "sequence_path": "37003.protein.sequences.v11.5.fa",
		        "enrichment_path": "37003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37003.protein.info.v11.5.txt",
		        "node_list_path": "37003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaStagnalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia stagnalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaStagnalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1503054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1503054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1503054.clusters.proteins.v11.5.txt",
		        "sequence_path": "1503054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1503054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1503054.protein.info.v11.5.txt",
		        "node_list_path": "1503054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1503054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacterPostgatei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacter postgatei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacterPostgatei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "879212.protein.sequences.v11.5.fa",
		        "enrichment_path": "879212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879212.protein.info.v11.5.txt",
		        "node_list_path": "879212.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasCitrea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas citrea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasCitrea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117314.protein.info.v11.5.txt",
		        "node_list_path": "1117314.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag452Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:452 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag452Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262810.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262810.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262810.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262810.protein.info.v11.5.txt",
		        "node_list_path": "1262810.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262810.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterSpOr1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter sp. OR-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterSpOr1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1266765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266765.protein.info.v11.5.txt",
		        "node_list_path": "1266765.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferSpQ7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer sp. Q7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferSpQ7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1785091.protein.sequences.v11.5.fa",
		        "enrichment_path": "1785091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1785091.protein.info.v11.5.txt",
		        "node_list_path": "1785091.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNealsonbacteriaBacteriumRbg133615(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RBG_13_36_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRbg133615", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801660.protein.info.v11.5.txt",
		        "node_list_path": "1801660.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndosymbiontOfBathymodiolusSeptemdierumStrMyojinKnollCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Bathymodiolus septemdierum str. Myojin knoll Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndosymbiontOfBathymodiolusSeptemdierumStrMyojinKnollCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1303921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1303921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1303921.clusters.proteins.v11.5.txt",
		        "sequence_path": "1303921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1303921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1303921.protein.info.v11.5.txt",
		        "node_list_path": "1303921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1303921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat18017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-18017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat18017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1705566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1705566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1705566.clusters.proteins.v11.5.txt",
		        "sequence_path": "1705566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705566.protein.info.v11.5.txt",
		        "node_list_path": "1705566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1705566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanifilumFulgidumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planifilum fulgidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanifilumFulgidumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "201973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "201973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "201973.clusters.proteins.v11.5.txt",
		        "sequence_path": "201973.protein.sequences.v11.5.fa",
		        "enrichment_path": "201973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "201973.protein.info.v11.5.txt",
		        "node_list_path": "201973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "201973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumSpRac02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. RAC02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumSpRac02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1842534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1842534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1842534.clusters.proteins.v11.5.txt",
		        "sequence_path": "1842534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842534.protein.info.v11.5.txt",
		        "node_list_path": "1842534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1842534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiumSpinosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobium spinosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiumSpinosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "240016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "240016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "240016.clusters.proteins.v11.5.txt",
		        "sequence_path": "240016.protein.sequences.v11.5.fa",
		        "enrichment_path": "240016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240016.protein.info.v11.5.txt",
		        "node_list_path": "240016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "240016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaPrimitiaZas1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema primitia ZAS-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPrimitiaZas1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717227.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717227.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717227.clusters.proteins.v11.5.txt",
		        "sequence_path": "717227.protein.sequences.v11.5.fa",
		        "enrichment_path": "717227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717227.protein.info.v11.5.txt",
		        "node_list_path": "717227.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717227.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChroogloeocystisSiderophila52SC1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chroogloeocystis siderophila 5.2 s.c.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChroogloeocystisSiderophila52SC1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "247279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "247279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "247279.clusters.proteins.v11.5.txt",
		        "sequence_path": "247279.protein.sequences.v11.5.fa",
		        "enrichment_path": "247279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247279.protein.info.v11.5.txt",
		        "node_list_path": "247279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "247279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotorhabdusAsymbiotica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photorhabdus asymbiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotorhabdusAsymbiotica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "291112.protein.sequences.v11.5.fa",
		        "enrichment_path": "291112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "291112.protein.info.v11.5.txt",
		        "node_list_path": "291112.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsphigho201Full4110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_01_FULL_41_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho201Full4110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802500.protein.info.v11.5.txt",
		        "node_list_path": "1802500.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterActinosclerusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter actinosclerus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterActinosclerusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "82805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "82805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "82805.clusters.proteins.v11.5.txt",
		        "sequence_path": "82805.protein.sequences.v11.5.fa",
		        "enrichment_path": "82805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82805.protein.info.v11.5.txt",
		        "node_list_path": "82805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "82805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcaceaeBacteriumVa2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium VA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcaceaeBacteriumVa2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1476973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1476973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1476973.clusters.proteins.v11.5.txt",
		        "sequence_path": "1476973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1476973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1476973.protein.info.v11.5.txt",
		        "node_list_path": "1476973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1476973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpOv174(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. OV174 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpOv174", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855300.protein.info.v11.5.txt",
		        "node_list_path": "1855300.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusAquatilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus aquatilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusAquatilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121378.protein.info.v11.5.txt",
		        "node_list_path": "1121378.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychroflexusTropicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychroflexus tropicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroflexusTropicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123035.protein.info.v11.5.txt",
		        "node_list_path": "1123035.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoplanesPhilippinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes philippinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesPhilippinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35752.protein.sequences.v11.5.fa",
		        "enrichment_path": "35752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35752.protein.info.v11.5.txt",
		        "node_list_path": "35752.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParapedobacterComposti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parapedobacter composti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParapedobacterComposti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "623281.protein.sequences.v11.5.fa",
		        "enrichment_path": "623281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "623281.protein.info.v11.5.txt",
		        "node_list_path": "623281.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeeiaOryzaeDsm17879Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leeia oryzae DSM 17879 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeeiaOryzaeDsm17879Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122158.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122158.protein.info.v11.5.txt",
		        "node_list_path": "1122158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisVancoresmycinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis vancoresmycina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisVancoresmycinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "208444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "208444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "208444.clusters.proteins.v11.5.txt",
		        "sequence_path": "208444.protein.sequences.v11.5.fa",
		        "enrichment_path": "208444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208444.protein.info.v11.5.txt",
		        "node_list_path": "208444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "208444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAnthracisAmes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis Ames graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAnthracisAmes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "198094.protein.sequences.v11.5.fa",
		        "enrichment_path": "198094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198094.protein.info.v11.5.txt",
		        "node_list_path": "198094.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumBact10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumBact10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674824.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674824.protein.info.v11.5.txt",
		        "node_list_path": "1674824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaSpDsi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Dsi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaSpDsi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236908.protein.sequences.v11.0.fa",
		        "enrichment_path": "1236908.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1236908.protein.info.v11.0.txt",
		        "node_list_path": "1236908.protein.complete.v11.0.txt"
		    }
		]
    )()

def NovosphingobiumSpCf614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. CF614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpCf614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884364.protein.info.v11.5.txt",
		        "node_list_path": "1884364.protein.complete.v11.5.txt"
		    }
		]
    )()

def IctidomysTridecemlineatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ictidomys tridecemlineatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IctidomysTridecemlineatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43179.protein.sequences.v11.5.fa",
		        "enrichment_path": "43179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43179.protein.info.v11.5.txt",
		        "node_list_path": "43179.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumVerticillioides7600(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium verticillioides 7600 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumVerticillioides7600", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "334819.protein.sequences.v11.5.fa",
		        "enrichment_path": "334819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "334819.protein.info.v11.5.txt",
		        "node_list_path": "334819.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraMultiparaAtcc19207(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospira multipara ATCC19207 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraMultiparaAtcc19207", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1282887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282887.protein.info.v11.5.txt",
		        "node_list_path": "1282887.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium6217(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 62-17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium6217", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895810.protein.info.v11.5.txt",
		        "node_list_path": "1895810.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumArsenophilumNbrc109478Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum arsenophilum NBRC 109478 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumArsenophilumNbrc109478Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349789.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349789.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349789.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349789.protein.info.v11.5.txt",
		        "node_list_path": "1349789.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349789.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpAr710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. AR7-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpAr710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1891970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891970.protein.info.v11.5.txt",
		        "node_list_path": "1891970.protein.complete.v11.5.txt"
		    }
		]
    )()

def TerrimonasFerrugineaDsm30193(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terrimonas ferruginea DSM 30193 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrimonasFerrugineaDsm30193", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123356.protein.info.v11.5.txt",
		        "node_list_path": "1123356.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisPretoriensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis pretoriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisPretoriensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "218821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "218821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "218821.clusters.proteins.v11.5.txt",
		        "sequence_path": "218821.protein.sequences.v11.5.fa",
		        "enrichment_path": "218821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218821.protein.info.v11.5.txt",
		        "node_list_path": "218821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "218821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumOxidoreducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium oxidoreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumOxidoreducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1732.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1732.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1732.clusters.proteins.v11.5.txt",
		        "sequence_path": "1732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1732.protein.info.v11.5.txt",
		        "node_list_path": "1732.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1732.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeucobacterCelerSubspAstrifaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter celer subsp. astrifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterCelerSubspAstrifaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461260.protein.info.v11.5.txt",
		        "node_list_path": "1461260.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwe24063Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_40_63 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwe24063Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797335.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797335.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797335.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797335.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797335.protein.info.v11.5.txt",
		        "node_list_path": "1797335.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797335.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpAe3004Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpAe3004Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1506994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1506994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1506994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1506994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1506994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1506994.protein.info.v11.5.txt",
		        "node_list_path": "1506994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1506994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicoccusRoseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusRoseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45670.protein.sequences.v11.5.fa",
		        "enrichment_path": "45670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45670.protein.info.v11.5.txt",
		        "node_list_path": "45670.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAgalactiae2603vR(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae 2603V/R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAgalactiae2603vR", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "208435.protein.sequences.v11.5.fa",
		        "enrichment_path": "208435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "208435.protein.info.v11.5.txt",
		        "node_list_path": "208435.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumSpMaddingley(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium sp. Maddingley graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumSpMaddingley", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220534.protein.info.v11.5.txt",
		        "node_list_path": "1220534.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonRbg13389(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_38_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg13389", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797377.protein.info.v11.5.txt",
		        "node_list_path": "1797377.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusPiezophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus piezophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusPiezophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1712654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1712654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1712654.protein.info.v11.5.txt",
		        "node_list_path": "1712654.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaDisparCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma dispar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaDisparCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86660.clusters.proteins.v11.5.txt",
		        "sequence_path": "86660.protein.sequences.v11.5.fa",
		        "enrichment_path": "86660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86660.protein.info.v11.5.txt",
		        "node_list_path": "86660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpG2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. G2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpG2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1243664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1243664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1243664.protein.info.v11.5.txt",
		        "node_list_path": "1243664.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpK24(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. K24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpK24", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1472716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1472716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1472716.protein.info.v11.5.txt",
		        "node_list_path": "1472716.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpApr13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. APR13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpApr13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1356852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1356852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1356852.clusters.proteins.v11.5.txt",
		        "sequence_path": "1356852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1356852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1356852.protein.info.v11.5.txt",
		        "node_list_path": "1356852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1356852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NumidaMeleagris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Numida meleagris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NumidaMeleagris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8996.protein.sequences.v11.5.fa",
		        "enrichment_path": "8996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8996.protein.info.v11.5.txt",
		        "node_list_path": "8996.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusRadioduransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus radiodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusRadioduransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243230.clusters.proteins.v11.5.txt",
		        "sequence_path": "243230.protein.sequences.v11.5.fa",
		        "enrichment_path": "243230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243230.protein.info.v11.5.txt",
		        "node_list_path": "243230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosarchaeumKoreenseMy1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosarchaeum koreense MY1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosarchaeumKoreenseMy1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1001994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1001994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1001994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1001994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001994.protein.info.v11.5.txt",
		        "node_list_path": "1001994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1001994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumGw2011Gwc23423Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWC2_34_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwc23423Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618484.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618484.protein.info.v11.5.txt",
		        "node_list_path": "1618484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraBiflexaSerovarPatocStrainPatoc1Paris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira biflexa serovar Patoc strain Patoc 1 (Paris) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraBiflexaSerovarPatocStrainPatoc1Paris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "456481.protein.sequences.v11.5.fa",
		        "enrichment_path": "456481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "456481.protein.info.v11.5.txt",
		        "node_list_path": "456481.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumCulicis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium culicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumCulicis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "680127.protein.sequences.v11.5.fa",
		        "enrichment_path": "680127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "680127.protein.info.v11.5.txt",
		        "node_list_path": "680127.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaBryophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia bryophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaBryophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1169143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1169143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1169143.clusters.proteins.v11.5.txt",
		        "sequence_path": "1169143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169143.protein.info.v11.5.txt",
		        "node_list_path": "1169143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1169143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColumbaLivia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Columba livia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColumbaLivia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8932.protein.sequences.v11.5.fa",
		        "enrichment_path": "8932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8932.protein.info.v11.5.txt",
		        "node_list_path": "8932.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifoxyd2Full4310Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFOXYD2_FULL_43_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifoxyd2Full4310Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802782.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802782.protein.info.v11.5.txt",
		        "node_list_path": "1802782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CytophagaceaeBacteriumScn5212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cytophagaceae bacterium SCN 52-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CytophagaceaeBacteriumScn5212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660162.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660162.protein.info.v11.5.txt",
		        "node_list_path": "1660162.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterPsychrophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter psychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterPsychrophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "330734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "330734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "330734.clusters.proteins.v11.5.txt",
		        "sequence_path": "330734.protein.sequences.v11.5.fa",
		        "enrichment_path": "330734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "330734.protein.info.v11.5.txt",
		        "node_list_path": "330734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "330734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumLubricantisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium lubricantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumLubricantisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121363.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121363.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121363.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121363.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121363.protein.info.v11.5.txt",
		        "node_list_path": "1121363.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121363.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DomibacillusRobiginosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus robiginosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusRobiginosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071054.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071054.protein.info.v11.5.txt",
		        "node_list_path": "1071054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaSpCag471Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:471 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSpCag471Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262948.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262948.protein.info.v11.5.txt",
		        "node_list_path": "1262948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CystobacterFuscus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cystobacter fuscus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CystobacterFuscus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1242864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1242864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1242864.protein.info.v11.5.txt",
		        "node_list_path": "1242864.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasCitronellolis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas citronellolis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCitronellolis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53408.protein.sequences.v11.5.fa",
		        "enrichment_path": "53408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53408.protein.info.v11.5.txt",
		        "node_list_path": "53408.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaSpDnf00869Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. DNF00869 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaSpDnf00869Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1384081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1384081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1384081.clusters.proteins.v11.5.txt",
		        "sequence_path": "1384081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384081.protein.info.v11.5.txt",
		        "node_list_path": "1384081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1384081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumCaspAlpha6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium casp-alpha6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumCaspAlpha6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1656909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1656909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1656909.clusters.proteins.v11.5.txt",
		        "sequence_path": "1656909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1656909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1656909.protein.info.v11.5.txt",
		        "node_list_path": "1656909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1656909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumJaponicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumJaponicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "375.protein.sequences.v11.5.fa",
		        "enrichment_path": "375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375.protein.info.v11.5.txt",
		        "node_list_path": "375.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaNodosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia nodosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaNodosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "392320.protein.sequences.v11.5.fa",
		        "enrichment_path": "392320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392320.protein.info.v11.5.txt",
		        "node_list_path": "392320.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium659Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 65-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium659Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895816.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895816.protein.info.v11.5.txt",
		        "node_list_path": "1895816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpD14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. D14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpD14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "621372.clusters.info.v11.5.txt",
		        "cluster_tree_path": "621372.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "621372.clusters.proteins.v11.5.txt",
		        "sequence_path": "621372.protein.sequences.v11.5.fa",
		        "enrichment_path": "621372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "621372.protein.info.v11.5.txt",
		        "node_list_path": "621372.cluster.nodes.v11.5.txt",
		        "edge_list_path": "621372.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusGhanensisDsm18630Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ghanensis DSM 18630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGhanensisDsm18630Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423750.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423750.protein.info.v11.5.txt",
		        "node_list_path": "1423750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpAnt303(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Ant303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpAnt303", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1488328.protein.sequences.v11.5.fa",
		        "enrichment_path": "1488328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1488328.protein.info.v11.5.txt",
		        "node_list_path": "1488328.protein.complete.v11.5.txt"
		    }
		]
    )()

def HarpegnathosSaltator(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Harpegnathos saltator graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HarpegnathosSaltator", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "610380.protein.sequences.v11.5.fa",
		        "enrichment_path": "610380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "610380.protein.info.v11.5.txt",
		        "node_list_path": "610380.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpA12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. A12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpA12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1759399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759399.protein.info.v11.5.txt",
		        "node_list_path": "1759399.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachanceaThermotoleransCbs6340(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachancea thermotolerans CBS 6340 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachanceaThermotoleransCbs6340", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "559295.protein.sequences.v11.5.fa",
		        "enrichment_path": "559295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559295.protein.info.v11.5.txt",
		        "node_list_path": "559295.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrancisellaPhilomiragia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella philomiragia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaPhilomiragia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "484022.protein.sequences.v11.5.fa",
		        "enrichment_path": "484022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "484022.protein.info.v11.5.txt",
		        "node_list_path": "484022.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumLoti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumLoti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "381.protein.sequences.v11.5.fa",
		        "enrichment_path": "381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381.protein.info.v11.5.txt",
		        "node_list_path": "381.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpNt26(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. NT-26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpNt26", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125847.protein.info.v11.5.txt",
		        "node_list_path": "1125847.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusWulumuqiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus wulumuqiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusWulumuqiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288484.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288484.protein.info.v11.5.txt",
		        "node_list_path": "1288484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpCb0205Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. CB0205 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpCb0205Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "232363.clusters.info.v11.5.txt",
		        "cluster_tree_path": "232363.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "232363.clusters.proteins.v11.5.txt",
		        "sequence_path": "232363.protein.sequences.v11.5.fa",
		        "enrichment_path": "232363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "232363.protein.info.v11.5.txt",
		        "node_list_path": "232363.cluster.nodes.v11.5.txt",
		        "edge_list_path": "232363.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SodiomycesAlkalinusF11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sodiomyces alkalinus F11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SodiomycesAlkalinusF11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314773.protein.info.v11.5.txt",
		        "node_list_path": "1314773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrientiaChutoStrDubai(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Orientia chuto str. Dubai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrientiaChutoStrDubai", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1359168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1359168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1359168.protein.info.v11.5.txt",
		        "node_list_path": "1359168.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConfluentimicrobiumSpEmb200Ns6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Confluentimicrobium sp. EMB200-NS6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConfluentimicrobiumSpEmb200Ns6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1609966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1609966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1609966.protein.info.v11.5.txt",
		        "node_list_path": "1609966.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFryxellicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium fryxellicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFryxellicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "249352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "249352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "249352.clusters.proteins.v11.5.txt",
		        "sequence_path": "249352.protein.sequences.v11.5.fa",
		        "enrichment_path": "249352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "249352.protein.info.v11.5.txt",
		        "node_list_path": "249352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "249352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpLtsp885(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LTSP885 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpLtsp885", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619232.protein.info.v11.5.txt",
		        "node_list_path": "1619232.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptosphaeriaMaculans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptosphaeria maculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptosphaeriaMaculans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5022.protein.sequences.v11.5.fa",
		        "enrichment_path": "5022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5022.protein.info.v11.5.txt",
		        "node_list_path": "5022.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSimulansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus simulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSimulansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1405498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1405498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1405498.clusters.proteins.v11.5.txt",
		        "sequence_path": "1405498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1405498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1405498.protein.info.v11.5.txt",
		        "node_list_path": "1405498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1405498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaCypripediiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea cypripedii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaCypripediiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "55209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "55209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "55209.clusters.proteins.v11.5.txt",
		        "sequence_path": "55209.protein.sequences.v11.5.fa",
		        "enrichment_path": "55209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55209.protein.info.v11.5.txt",
		        "node_list_path": "55209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "55209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusAmylolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus amylolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusAmylolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "294699.protein.sequences.v11.5.fa",
		        "enrichment_path": "294699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294699.protein.info.v11.5.txt",
		        "node_list_path": "294699.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanktothrixAgardhii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planktothrix agardhii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktothrixAgardhii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "388467.protein.sequences.v11.5.fa",
		        "enrichment_path": "388467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388467.protein.info.v11.5.txt",
		        "node_list_path": "388467.protein.complete.v11.5.txt"
		    }
		]
    )()

def FormosaAlgaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Formosa algae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaAlgaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "225843.clusters.info.v11.5.txt",
		        "cluster_tree_path": "225843.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "225843.clusters.proteins.v11.5.txt",
		        "sequence_path": "225843.protein.sequences.v11.5.fa",
		        "enrichment_path": "225843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225843.protein.info.v11.5.txt",
		        "node_list_path": "225843.cluster.nodes.v11.5.txt",
		        "edge_list_path": "225843.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpYt30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. YT30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpYt30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735012.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735012.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735012.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735012.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735012.protein.info.v11.5.txt",
		        "node_list_path": "1735012.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735012.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumLimosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium limosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumLimosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "903814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "903814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "903814.clusters.proteins.v11.5.txt",
		        "sequence_path": "903814.protein.sequences.v11.5.fa",
		        "enrichment_path": "903814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903814.protein.info.v11.5.txt",
		        "node_list_path": "903814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "903814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VagococcusLutraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vagococcus lutrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VagococcusLutraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408226.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408226.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408226.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408226.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408226.protein.info.v11.5.txt",
		        "node_list_path": "1408226.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408226.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrolunatusPhosphovorusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microlunatus phosphovorus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrolunatusPhosphovorusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1032480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1032480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1032480.clusters.proteins.v11.5.txt",
		        "sequence_path": "1032480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1032480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1032480.protein.info.v11.5.txt",
		        "node_list_path": "1032480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1032480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalococcusSaccharolyticusDsm5350(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halococcus saccharolyticus DSM 5350 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusSaccharolyticusDsm5350", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227455.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227455.protein.info.v11.5.txt",
		        "node_list_path": "1227455.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaCyriacigeorgicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia cyriacigeorgica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaCyriacigeorgicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1127134.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1127134.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1127134.clusters.proteins.v11.5.txt",
		        "sequence_path": "1127134.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127134.protein.info.v11.5.txt",
		        "node_list_path": "1127134.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1127134.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LabilithrixLuteolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Labilithrix luteola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabilithrixLuteolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1391654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1391654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1391654.clusters.proteins.v11.5.txt",
		        "sequence_path": "1391654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391654.protein.info.v11.5.txt",
		        "node_list_path": "1391654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1391654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "487316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "487316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "487316.clusters.proteins.v11.5.txt",
		        "sequence_path": "487316.protein.sequences.v11.5.fa",
		        "enrichment_path": "487316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487316.protein.info.v11.5.txt",
		        "node_list_path": "487316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "487316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumCellulosolvens6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens 6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumCellulosolvens6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "633697.clusters.info.v11.5.txt",
		        "cluster_tree_path": "633697.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "633697.clusters.proteins.v11.5.txt",
		        "sequence_path": "633697.protein.sequences.v11.5.fa",
		        "enrichment_path": "633697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633697.protein.info.v11.5.txt",
		        "node_list_path": "633697.cluster.nodes.v11.5.txt",
		        "edge_list_path": "633697.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumGa0074139(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium Ga0074139 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumGa0074139", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752196.protein.info.v11.5.txt",
		        "node_list_path": "1752196.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaTropica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia tropica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaTropica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "92647.protein.sequences.v11.5.fa",
		        "enrichment_path": "92647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92647.protein.info.v11.5.txt",
		        "node_list_path": "92647.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnaporthiopsisPoae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnaporthiopsis poae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnaporthiopsisPoae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "148304.protein.sequences.v11.5.fa",
		        "enrichment_path": "148304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "148304.protein.info.v11.5.txt",
		        "node_list_path": "148304.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumRenaleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium renale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumRenaleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1724.clusters.proteins.v11.5.txt",
		        "sequence_path": "1724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1724.protein.info.v11.5.txt",
		        "node_list_path": "1724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrososphaeraEvergladensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrososphaera evergladensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrososphaeraEvergladensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1459636.protein.sequences.v11.5.fa",
		        "enrichment_path": "1459636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1459636.protein.info.v11.5.txt",
		        "node_list_path": "1459636.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterCastelliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter castelli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterCastelliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121019.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121019.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121019.protein.info.v11.5.txt",
		        "node_list_path": "1121019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesCaeruleatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces caeruleatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCaeruleatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "661399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "661399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "661399.clusters.proteins.v11.5.txt",
		        "sequence_path": "661399.protein.sequences.v11.5.fa",
		        "enrichment_path": "661399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "661399.protein.info.v11.5.txt",
		        "node_list_path": "661399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "661399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg135021Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_50_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg135021Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797623.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797623.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797623.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797623.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797623.protein.info.v11.5.txt",
		        "node_list_path": "1797623.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797623.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CutibacteriumAcnes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cutibacterium acnes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CutibacteriumAcnes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1747.protein.info.v11.5.txt",
		        "node_list_path": "1747.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanktomarinaTemperata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planktomarina temperata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktomarinaTemperata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "666509.protein.sequences.v11.5.fa",
		        "enrichment_path": "666509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "666509.protein.info.v11.5.txt",
		        "node_list_path": "666509.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRifoxyd1Full3984Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1_FULL_39_84 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1Full3984Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797401.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797401.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797401.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797401.protein.info.v11.5.txt",
		        "node_list_path": "1797401.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797401.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoruegeriaSabulilitoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoruegeria sabulilitoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoruegeriaSabulilitoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1510458.protein.sequences.v11.5.fa",
		        "enrichment_path": "1510458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1510458.protein.info.v11.5.txt",
		        "node_list_path": "1510458.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFf9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FF9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFf9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1527293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1527293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1527293.clusters.proteins.v11.5.txt",
		        "sequence_path": "1527293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1527293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1527293.protein.info.v11.5.txt",
		        "node_list_path": "1527293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1527293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsialesBacteriumAc37bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium Ac37b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsialesBacteriumAc37bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1528098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1528098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1528098.clusters.proteins.v11.5.txt",
		        "sequence_path": "1528098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1528098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1528098.protein.info.v11.5.txt",
		        "node_list_path": "1528098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1528098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumGjE10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GJ-E10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumGjE10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1469502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469502.protein.info.v11.5.txt",
		        "node_list_path": "1469502.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusFelis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Haemophilus] felis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusFelis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "123822.protein.sequences.v11.5.fa",
		        "enrichment_path": "123822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "123822.protein.info.v11.5.txt",
		        "node_list_path": "123822.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZymobacterPalmaeDsm10491(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zymobacter palmae DSM 10491 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymobacterPalmaeDsm10491", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123510.protein.info.v11.5.txt",
		        "node_list_path": "1123510.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSpOk098Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK098 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSpOk098Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855297.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855297.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855297.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855297.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855297.protein.info.v11.5.txt",
		        "node_list_path": "1855297.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855297.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerolineaceaeBacterium4572322Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium 4572_32.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaceaeBacterium4572322Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1971624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1971624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1971624.clusters.proteins.v11.5.txt",
		        "sequence_path": "1971624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971624.protein.info.v11.5.txt",
		        "node_list_path": "1971624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1971624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumRifoxyc2Full3825(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYC2_FULL_38_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyc2Full3825", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798453.protein.info.v11.5.txt",
		        "node_list_path": "1798453.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSp21mfcrub11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. 21MFCrub1.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSp21mfcrub11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798223.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798223.protein.info.v11.5.txt",
		        "node_list_path": "1798223.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpTb15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. TB15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpTb15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "494416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "494416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "494416.clusters.proteins.v11.5.txt",
		        "sequence_path": "494416.protein.sequences.v11.5.fa",
		        "enrichment_path": "494416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "494416.protein.info.v11.5.txt",
		        "node_list_path": "494416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "494416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnoclostridiumSpYl32Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnoclostridium sp. YL32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoclostridiumSpYl32Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834196.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834196.protein.info.v11.5.txt",
		        "node_list_path": "1834196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAgarici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas agarici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAgarici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46677.protein.sequences.v11.5.fa",
		        "enrichment_path": "46677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46677.protein.info.v11.5.txt",
		        "node_list_path": "46677.protein.complete.v11.5.txt"
		    }
		]
    )()

def PuniceicoccalesBacteriumVerruco02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Puniceicoccales bacterium Verruco_02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PuniceicoccalesBacteriumVerruco02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674913.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674913.protein.info.v11.5.txt",
		        "node_list_path": "1674913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaBiviaJcvihmp010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bivia JCVIHMP010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBiviaJcvihmp010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553171.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553171.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553171.clusters.proteins.v11.5.txt",
		        "sequence_path": "553171.protein.sequences.v11.5.fa",
		        "enrichment_path": "553171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553171.protein.info.v11.5.txt",
		        "node_list_path": "553171.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553171.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulophagaBaltica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga baltica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaBaltica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348583.protein.info.v11.5.txt",
		        "node_list_path": "1348583.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807751.protein.info.v11.5.txt",
		        "node_list_path": "1807751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumEnshiense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium enshiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumEnshiense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1107311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1107311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1107311.protein.info.v11.5.txt",
		        "node_list_path": "1107311.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSynechococcusSpongiarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Synechococcus spongiarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSynechococcusSpongiarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "431041.clusters.info.v11.5.txt",
		        "cluster_tree_path": "431041.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "431041.clusters.proteins.v11.5.txt",
		        "sequence_path": "431041.protein.sequences.v11.5.fa",
		        "enrichment_path": "431041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431041.protein.info.v11.5.txt",
		        "node_list_path": "431041.cluster.nodes.v11.5.txt",
		        "edge_list_path": "431041.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsplowo202Full4337Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_02_FULL_43_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo202Full4337Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798357.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798357.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798357.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798357.protein.info.v11.5.txt",
		        "node_list_path": "1798357.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798357.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc13410(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_34_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc13410", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618891.protein.info.v11.5.txt",
		        "node_list_path": "1618891.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumJdfr88(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-88 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumJdfr88", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935149.protein.info.v11.5.txt",
		        "node_list_path": "1935149.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpSm9913Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. SM9913 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpSm9913Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "234831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "234831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "234831.clusters.proteins.v11.5.txt",
		        "sequence_path": "234831.protein.sequences.v11.5.fa",
		        "enrichment_path": "234831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "234831.protein.info.v11.5.txt",
		        "node_list_path": "234831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "234831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmataSpIil30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmata sp. IIL30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmataSpIil30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210884.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210884.protein.info.v11.5.txt",
		        "node_list_path": "1210884.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSilvensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces silvensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSilvensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1765722.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1765722.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1765722.clusters.proteins.v11.5.txt",
		        "sequence_path": "1765722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1765722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1765722.protein.info.v11.5.txt",
		        "node_list_path": "1765722.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1765722.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BariatricusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bariatricus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BariatricusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1745713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1745713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1745713.clusters.proteins.v11.5.txt",
		        "sequence_path": "1745713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1745713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1745713.protein.info.v11.5.txt",
		        "node_list_path": "1745713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1745713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasCaeni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCaeni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521719.protein.sequences.v11.5.fa",
		        "enrichment_path": "521719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521719.protein.info.v11.5.txt",
		        "node_list_path": "521719.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg2304851Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_48_51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304851Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805320.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805320.protein.info.v11.5.txt",
		        "node_list_path": "1805320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpTkpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TKP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpTkpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415630.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415630.protein.info.v11.5.txt",
		        "node_list_path": "1415630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSuwonensisJ42Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis J42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSuwonensisJ42Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935566.clusters.proteins.v11.5.txt",
		        "sequence_path": "935566.protein.sequences.v11.5.fa",
		        "enrichment_path": "935566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935566.protein.info.v11.5.txt",
		        "node_list_path": "935566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuegeriaHalocynthiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria halocynthiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaHalocynthiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "985054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "985054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "985054.clusters.proteins.v11.5.txt",
		        "sequence_path": "985054.protein.sequences.v11.5.fa",
		        "enrichment_path": "985054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985054.protein.info.v11.5.txt",
		        "node_list_path": "985054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "985054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GloeophyllumTrabeum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gloeophyllum trabeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeophyllumTrabeum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "104355.protein.sequences.v11.5.fa",
		        "enrichment_path": "104355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104355.protein.info.v11.5.txt",
		        "node_list_path": "104355.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerocolumnaXylanovoransDsm12503(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerocolumna xylanovorans DSM 12503 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerocolumnaXylanovoransDsm12503", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121345.protein.info.v11.5.txt",
		        "node_list_path": "1121345.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesTogonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides togonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesTogonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1917883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1917883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1917883.clusters.proteins.v11.5.txt",
		        "sequence_path": "1917883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917883.protein.info.v11.5.txt",
		        "node_list_path": "1917883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1917883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AncylostomaCaninumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ancylostoma caninum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AncylostomaCaninumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29170.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29170.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29170.clusters.proteins.v11.5.txt",
		        "sequence_path": "29170.protein.sequences.v11.5.fa",
		        "enrichment_path": "29170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29170.protein.info.v11.5.txt",
		        "node_list_path": "29170.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29170.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZymoseptoriaTritici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymoseptoriaTritici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1047171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1047171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1047171.protein.info.v11.5.txt",
		        "node_list_path": "1047171.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacteriumRifcsplowo202Full7356Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium RIFCSPLOWO2_02_FULL_73_56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacteriumRifcsplowo202Full7356Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802107.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802107.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802107.protein.info.v11.5.txt",
		        "node_list_path": "1802107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusNodensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nodensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusNodensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423775.protein.info.v11.5.txt",
		        "node_list_path": "1423775.protein.complete.v11.5.txt"
		    }
		]
    )()

def TepidanaerobacterAcetatoxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tepidanaerobacter acetatoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidanaerobacterAcetatoxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1209989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1209989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1209989.clusters.proteins.v11.5.txt",
		        "sequence_path": "1209989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1209989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1209989.protein.info.v11.5.txt",
		        "node_list_path": "1209989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1209989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpSoil538Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Soil538 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpSoil538Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736391.protein.info.v11.5.txt",
		        "node_list_path": "1736391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaSucciniciproducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia succiniciproducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaSucciniciproducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "221988.protein.sequences.v11.5.fa",
		        "enrichment_path": "221988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221988.protein.info.v11.5.txt",
		        "node_list_path": "221988.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelodiscusSinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelodiscus sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelodiscusSinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13735.clusters.proteins.v11.5.txt",
		        "sequence_path": "13735.protein.sequences.v11.5.fa",
		        "enrichment_path": "13735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13735.protein.info.v11.5.txt",
		        "node_list_path": "13735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusClausiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus clausii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusClausiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66692.clusters.proteins.v11.5.txt",
		        "sequence_path": "66692.protein.sequences.v11.5.fa",
		        "enrichment_path": "66692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66692.protein.info.v11.5.txt",
		        "node_list_path": "66692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PogonaVitticeps(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pogona vitticeps graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PogonaVitticeps", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "103695.protein.sequences.v11.5.fa",
		        "enrichment_path": "103695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103695.protein.info.v11.5.txt",
		        "node_list_path": "103695.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaArthritidisNbrc100137Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia arthritidis NBRC 100137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaArthritidisNbrc100137Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210067.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210067.protein.info.v11.5.txt",
		        "node_list_path": "1210067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKimbladii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kimbladii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKimbladii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218506.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218506.protein.info.v11.5.txt",
		        "node_list_path": "1218506.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrenophoraTeresCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora teres Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrenophoraTeresCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53485.clusters.proteins.v11.5.txt",
		        "sequence_path": "53485.protein.sequences.v11.5.fa",
		        "enrichment_path": "53485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53485.protein.info.v11.5.txt",
		        "node_list_path": "53485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSeleniipraecipitansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas seleniipraecipitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSeleniipraecipitansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "640205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "640205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "640205.clusters.proteins.v11.5.txt",
		        "sequence_path": "640205.protein.sequences.v11.5.fa",
		        "enrichment_path": "640205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640205.protein.info.v11.5.txt",
		        "node_list_path": "640205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "640205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaHaliotis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella haliotis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaHaliotis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236541.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236541.protein.info.v11.5.txt",
		        "node_list_path": "1236541.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaMayonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia mayonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaMayonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674146.protein.info.v11.5.txt",
		        "node_list_path": "1674146.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpJdm601Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JDM601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpJdm601Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "875328.clusters.info.v11.5.txt",
		        "cluster_tree_path": "875328.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "875328.clusters.proteins.v11.5.txt",
		        "sequence_path": "875328.protein.sequences.v11.5.fa",
		        "enrichment_path": "875328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "875328.protein.info.v11.5.txt",
		        "node_list_path": "875328.cluster.nodes.v11.5.txt",
		        "edge_list_path": "875328.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TheileriaAnnulata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Theileria annulata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheileriaAnnulata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5874.protein.sequences.v11.5.fa",
		        "enrichment_path": "5874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5874.protein.info.v11.5.txt",
		        "node_list_path": "5874.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusTengchongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus tengchongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusTengchongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449357.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449357.protein.info.v11.5.txt",
		        "node_list_path": "1449357.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronohydrobacterThiooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronohydrobacter thiooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronohydrobacterThiooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "87172.clusters.info.v11.5.txt",
		        "cluster_tree_path": "87172.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "87172.clusters.proteins.v11.5.txt",
		        "sequence_path": "87172.protein.sequences.v11.5.fa",
		        "enrichment_path": "87172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "87172.protein.info.v11.5.txt",
		        "node_list_path": "87172.cluster.nodes.v11.5.txt",
		        "edge_list_path": "87172.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaBuccaeAtcc33574Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccae ATCC33574 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBuccaeAtcc33574Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "873513.clusters.info.v11.5.txt",
		        "cluster_tree_path": "873513.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "873513.clusters.proteins.v11.5.txt",
		        "sequence_path": "873513.protein.sequences.v11.5.fa",
		        "enrichment_path": "873513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "873513.protein.info.v11.5.txt",
		        "node_list_path": "873513.cluster.nodes.v11.5.txt",
		        "edge_list_path": "873513.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedSup05ClusterBacterium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured SUP05 cluster bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedSup05ClusterBacterium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655186.protein.sequences.v11.5.fa",
		        "enrichment_path": "655186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655186.protein.info.v11.5.txt",
		        "node_list_path": "655186.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaSaccharophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema saccharophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSaccharophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "907348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "907348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "907348.clusters.proteins.v11.5.txt",
		        "sequence_path": "907348.protein.sequences.v11.5.fa",
		        "enrichment_path": "907348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "907348.protein.info.v11.5.txt",
		        "node_list_path": "907348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "907348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesAtroparvusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles atroparvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesAtroparvusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "41427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "41427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "41427.clusters.proteins.v11.5.txt",
		        "sequence_path": "41427.protein.sequences.v11.5.fa",
		        "enrichment_path": "41427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41427.protein.info.v11.5.txt",
		        "node_list_path": "41427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "41427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuegeriaProfundi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria profundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaProfundi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1685378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685378.protein.info.v11.5.txt",
		        "node_list_path": "1685378.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumObuenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium obuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumObuenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807.protein.info.v11.5.txt",
		        "node_list_path": "1807.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PuniceispirillumMarinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Puniceispirillum marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PuniceispirillumMarinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "488538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "488538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "488538.clusters.proteins.v11.5.txt",
		        "sequence_path": "488538.protein.sequences.v11.5.fa",
		        "enrichment_path": "488538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "488538.protein.info.v11.5.txt",
		        "node_list_path": "488538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "488538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full379(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_37_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full379", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797724.protein.info.v11.5.txt",
		        "node_list_path": "1797724.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaMarshii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella marshii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMarshii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "862515.protein.sequences.v11.5.fa",
		        "enrichment_path": "862515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862515.protein.info.v11.5.txt",
		        "node_list_path": "862515.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpYr266Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. YR266 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpYr266Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884386.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884386.protein.info.v11.5.txt",
		        "node_list_path": "1884386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterPseudethanolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter pseudethanolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterPseudethanolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "340099.protein.sequences.v11.5.fa",
		        "enrichment_path": "340099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340099.protein.info.v11.5.txt",
		        "node_list_path": "340099.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262998.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262998.protein.info.v11.5.txt",
		        "node_list_path": "1262998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BdellovibrioBacteriovorusW(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrioBacteriovorusW", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765869.protein.sequences.v11.5.fa",
		        "enrichment_path": "765869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765869.protein.info.v11.5.txt",
		        "node_list_path": "765869.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidithrixFerrooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidithrix ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithrixFerrooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280514.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280514.protein.info.v11.5.txt",
		        "node_list_path": "1280514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu083Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu083Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671660.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671660.protein.info.v11.5.txt",
		        "node_list_path": "1671660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaOnionYellows(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma onion yellows graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaOnionYellows", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262768.protein.sequences.v11.0.fa",
		        "enrichment_path": "262768.protein.enrichment.terms.v11.0.txt",
		        "info_path": "262768.protein.info.v11.0.txt",
		        "node_list_path": "262768.protein.complete.v11.0.txt"
		    }
		]
    )()

def MycoplasmaParvumStrIndiana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma parvum str. Indiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaParvumStrIndiana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1403316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403316.protein.info.v11.5.txt",
		        "node_list_path": "1403316.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaSyrphidicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma syrphidicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaSyrphidicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1276229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276229.protein.info.v11.5.txt",
		        "node_list_path": "1276229.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSaccharobutylicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium saccharobutylicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSaccharobutylicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1345695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1345695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1345695.protein.info.v11.5.txt",
		        "node_list_path": "1345695.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrioBacteriovorusHd100(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus HD100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrioBacteriovorusHd100", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "264462.protein.sequences.v11.5.fa",
		        "enrichment_path": "264462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264462.protein.info.v11.5.txt",
		        "node_list_path": "264462.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaAtlanticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaAtlanticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "81569.clusters.info.v11.5.txt",
		        "cluster_tree_path": "81569.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "81569.clusters.proteins.v11.5.txt",
		        "sequence_path": "81569.protein.sequences.v11.5.fa",
		        "enrichment_path": "81569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81569.protein.info.v11.5.txt",
		        "node_list_path": "81569.cluster.nodes.v11.5.txt",
		        "edge_list_path": "81569.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FinegoldiaMagnaAtcc53516(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Finegoldia magna ATCC53516 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FinegoldiaMagnaAtcc53516", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525282.protein.sequences.v11.5.fa",
		        "enrichment_path": "525282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525282.protein.info.v11.5.txt",
		        "node_list_path": "525282.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumPasteurianumBc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum BC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPasteurianumBc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86416.protein.sequences.v11.5.fa",
		        "enrichment_path": "86416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86416.protein.info.v11.5.txt",
		        "node_list_path": "86416.protein.complete.v11.5.txt"
		    }
		]
    )()

def OtolemurGarnettii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Otolemur garnettii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OtolemurGarnettii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "30611.protein.sequences.v11.5.fa",
		        "enrichment_path": "30611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30611.protein.info.v11.5.txt",
		        "node_list_path": "30611.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4327Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_01_FULL_43_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4327Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802735.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802735.protein.info.v11.5.txt",
		        "node_list_path": "1802735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillatoriaSpPcc10802(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoria sp. PCC10802 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillatoriaSpPcc10802", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173028.protein.info.v11.5.txt",
		        "node_list_path": "1173028.protein.complete.v11.5.txt"
		    }
		]
    )()

def DictyosteliumDiscoideum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dictyostelium discoideum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DictyosteliumDiscoideum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44689.protein.sequences.v11.5.fa",
		        "enrichment_path": "44689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44689.protein.info.v11.5.txt",
		        "node_list_path": "44689.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZobelliaGalactanivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zobellia galactanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZobelliaGalactanivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "63186.clusters.info.v11.5.txt",
		        "cluster_tree_path": "63186.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "63186.clusters.proteins.v11.5.txt",
		        "sequence_path": "63186.protein.sequences.v11.5.fa",
		        "enrichment_path": "63186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63186.protein.info.v11.5.txt",
		        "node_list_path": "63186.cluster.nodes.v11.5.txt",
		        "edge_list_path": "63186.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PanicumHalliiVarHalliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Panicum hallii var. hallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PanicumHalliiVarHalliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1504633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1504633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1504633.clusters.proteins.v11.5.txt",
		        "sequence_path": "1504633.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504633.protein.info.v11.5.txt",
		        "node_list_path": "1504633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1504633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterUpsaliensisJv21(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter upsaliensis JV21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterUpsaliensisJv21", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888826.protein.sequences.v11.5.fa",
		        "enrichment_path": "888826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888826.protein.info.v11.5.txt",
		        "node_list_path": "888826.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobiumLuteolumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium luteolum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumLuteolumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "319225.clusters.info.v11.5.txt",
		        "cluster_tree_path": "319225.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "319225.clusters.proteins.v11.5.txt",
		        "sequence_path": "319225.protein.sequences.v11.5.fa",
		        "enrichment_path": "319225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "319225.protein.info.v11.5.txt",
		        "node_list_path": "319225.cluster.nodes.v11.5.txt",
		        "edge_list_path": "319225.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeleribacterEthanolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Celeribacter ethanolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeleribacterEthanolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1758178.protein.sequences.v11.5.fa",
		        "enrichment_path": "1758178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1758178.protein.info.v11.5.txt",
		        "node_list_path": "1758178.protein.complete.v11.5.txt"
		    }
		]
    )()

def SutterellaWadsworthensisHga0223(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis HGA0223 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SutterellaWadsworthensisHga0223", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203554.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203554.protein.info.v11.5.txt",
		        "node_list_path": "1203554.protein.complete.v11.5.txt"
		    }
		]
    )()

def AbsidiaGlauca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Absidia glauca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AbsidiaGlauca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4829.protein.sequences.v11.5.fa",
		        "enrichment_path": "4829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4829.protein.info.v11.5.txt",
		        "node_list_path": "4829.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat29814(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-29814 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat29814", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729688.protein.info.v11.5.txt",
		        "node_list_path": "1729688.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwf23876(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWF2_38_76 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwf23876", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618960.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618960.protein.info.v11.5.txt",
		        "node_list_path": "1618960.protein.complete.v11.5.txt"
		    }
		]
    )()

def IdiomarinaZobellii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina zobellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaZobellii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86103.protein.sequences.v11.5.fa",
		        "enrichment_path": "86103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86103.protein.info.v11.5.txt",
		        "node_list_path": "86103.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaTrevisaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia trevisanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaTrevisaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122173.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122173.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122173.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122173.protein.info.v11.5.txt",
		        "node_list_path": "1122173.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122173.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GambusiaAffinis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gambusia affinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GambusiaAffinis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33528.protein.sequences.v11.5.fa",
		        "enrichment_path": "33528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33528.protein.info.v11.5.txt",
		        "node_list_path": "33528.protein.complete.v11.5.txt"
		    }
		]
    )()

def HeterobasidionIrregulareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Heterobasidion irregulare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeterobasidionIrregulareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "984962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "984962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "984962.clusters.proteins.v11.5.txt",
		        "sequence_path": "984962.protein.sequences.v11.5.fa",
		        "enrichment_path": "984962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "984962.protein.info.v11.5.txt",
		        "node_list_path": "984962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "984962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanobacteriumStanieriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanobacterium stanieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobacteriumStanieriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "292563.clusters.info.v11.5.txt",
		        "cluster_tree_path": "292563.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "292563.clusters.proteins.v11.5.txt",
		        "sequence_path": "292563.protein.sequences.v11.5.fa",
		        "enrichment_path": "292563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292563.protein.info.v11.5.txt",
		        "node_list_path": "292563.cluster.nodes.v11.5.txt",
		        "edge_list_path": "292563.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerovoraxOdorimutansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerovorax odorimutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerovoraxOdorimutansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120998.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120998.protein.info.v11.5.txt",
		        "node_list_path": "1120998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4332b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_43_32b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4332b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802306.protein.info.v11.5.txt",
		        "node_list_path": "1802306.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpYr221(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR221 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpYr221", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500293.protein.info.v11.5.txt",
		        "node_list_path": "1500293.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusHippeiDsm8344Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus hippei DSM 8344 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusHippeiDsm8344Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121419.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121419.protein.info.v11.5.txt",
		        "node_list_path": "1121419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusAlginolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alginolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusAlginolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122915.protein.info.v11.5.txt",
		        "node_list_path": "1122915.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRbg19ftCombo5311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RBG_19FT_COMBO_53_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRbg19ftCombo5311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802613.protein.info.v11.5.txt",
		        "node_list_path": "1802613.protein.complete.v11.5.txt"
		    }
		]
    )()

def MusaAcuminataSubspMalaccensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Musa acuminata subsp. malaccensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusaAcuminataSubspMalaccensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "214687.protein.sequences.v11.5.fa",
		        "enrichment_path": "214687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "214687.protein.info.v11.5.txt",
		        "node_list_path": "214687.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpOv279Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. OV279 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpOv279Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500285.protein.info.v11.5.txt",
		        "node_list_path": "1500285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpHl48Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. HL48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpHl48Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1479235.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1479235.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1479235.clusters.proteins.v11.5.txt",
		        "sequence_path": "1479235.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479235.protein.info.v11.5.txt",
		        "node_list_path": "1479235.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1479235.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TatumellaSpNml063099Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tatumella sp. NML063099 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TatumellaSpNml063099Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1344012.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1344012.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1344012.clusters.proteins.v11.5.txt",
		        "sequence_path": "1344012.protein.sequences.v11.5.fa",
		        "enrichment_path": "1344012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1344012.protein.info.v11.5.txt",
		        "node_list_path": "1344012.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1344012.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonlabensSpHel13355(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens sp. Hel1_33_55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensSpHel13355", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336802.protein.info.v11.5.txt",
		        "node_list_path": "1336802.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPseudopneumoniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pseudopneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPseudopneumoniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1054460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1054460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1054460.clusters.proteins.v11.5.txt",
		        "sequence_path": "1054460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1054460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1054460.protein.info.v11.5.txt",
		        "node_list_path": "1054460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1054460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JeotgalibacillusSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalibacillus soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalibacillusSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "889306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "889306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "889306.clusters.proteins.v11.5.txt",
		        "sequence_path": "889306.protein.sequences.v11.5.fa",
		        "enrichment_path": "889306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "889306.protein.info.v11.5.txt",
		        "node_list_path": "889306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "889306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomonasKoyamaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas koyamae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasKoyamaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "702114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "702114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "702114.clusters.proteins.v11.5.txt",
		        "sequence_path": "702114.protein.sequences.v11.5.fa",
		        "enrichment_path": "702114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702114.protein.info.v11.5.txt",
		        "node_list_path": "702114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "702114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinimonasKoreensisDsm17726Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinimonas koreensis DSM 17726 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinimonasKoreensisDsm17726Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121278.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121278.protein.info.v11.5.txt",
		        "node_list_path": "1121278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusLactis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus lactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusLactis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743719.protein.sequences.v11.5.fa",
		        "enrichment_path": "743719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743719.protein.info.v11.5.txt",
		        "node_list_path": "743719.protein.complete.v11.5.txt"
		    }
		]
    )()

def HeliothisVirescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Heliothis virescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeliothisVirescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7102.clusters.proteins.v11.5.txt",
		        "sequence_path": "7102.protein.sequences.v11.5.fa",
		        "enrichment_path": "7102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7102.protein.info.v11.5.txt",
		        "node_list_path": "7102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeorickettsiaSp179522(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neorickettsia sp. 179522 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorickettsiaSp179522", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1714371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714371.protein.info.v11.5.txt",
		        "node_list_path": "1714371.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfurivibrioAlkaliphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurivibrio alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurivibrioAlkaliphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "589865.protein.sequences.v11.5.fa",
		        "enrichment_path": "589865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "589865.protein.info.v11.5.txt",
		        "node_list_path": "589865.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaPluranimalium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella pluranimalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaPluranimalium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "470453.protein.sequences.v11.5.fa",
		        "enrichment_path": "470453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "470453.protein.info.v11.5.txt",
		        "node_list_path": "470453.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidaceaeBacteriumMs4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidaceae bacterium MS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidaceaeBacteriumMs4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1347393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347393.protein.info.v11.5.txt",
		        "node_list_path": "1347393.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSclerotialus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sclerotialus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSclerotialus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1957.protein.sequences.v11.5.fa",
		        "enrichment_path": "1957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1957.protein.info.v11.5.txt",
		        "node_list_path": "1957.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacterium2w06Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 2W06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacterium2w06Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1838287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1838287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1838287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1838287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1838287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1838287.protein.info.v11.5.txt",
		        "node_list_path": "1838287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1838287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsSpCamponotiSaundersi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps sp. camponoti-saundersi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsSpCamponotiSaundersi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2039874.protein.sequences.v11.5.fa",
		        "enrichment_path": "2039874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2039874.protein.info.v11.5.txt",
		        "node_list_path": "2039874.protein.complete.v11.5.txt"
		    }
		]
    )()

def OenococcusKitaharae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oenococcus kitaharae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OenococcusKitaharae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1045004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045004.protein.info.v11.5.txt",
		        "node_list_path": "1045004.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterPinnipediorumSubspPinnipediorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter pinnipediorum subsp. pinnipediorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterPinnipediorumSubspPinnipediorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660067.protein.info.v11.5.txt",
		        "node_list_path": "1660067.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErysipelotrichaceaeBacteriumI46Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium I46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelotrichaceaeBacteriumI46Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834207.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834207.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834207.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834207.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834207.protein.info.v11.5.txt",
		        "node_list_path": "1834207.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834207.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasEndodontalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas endodontalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasEndodontalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553175.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553175.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553175.clusters.proteins.v11.5.txt",
		        "sequence_path": "553175.protein.sequences.v11.5.fa",
		        "enrichment_path": "553175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553175.protein.info.v11.5.txt",
		        "node_list_path": "553175.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553175.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SimkaniaNegevensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Simkania negevensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SimkaniaNegevensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "331113.protein.sequences.v11.5.fa",
		        "enrichment_path": "331113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331113.protein.info.v11.5.txt",
		        "node_list_path": "331113.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4215(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_42_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4215", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797716.protein.info.v11.5.txt",
		        "node_list_path": "1797716.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumC7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium C7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumC7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1792306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792306.protein.info.v11.5.txt",
		        "node_list_path": "1792306.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpK90mix(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. K90mix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpK90mix", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "396595.protein.sequences.v11.5.fa",
		        "enrichment_path": "396595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396595.protein.info.v11.5.txt",
		        "node_list_path": "396595.protein.complete.v11.5.txt"
		    }
		]
    )()

def AccumulibacterPhosphatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Accumulibacter phosphatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AccumulibacterPhosphatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "522306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "522306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "522306.clusters.proteins.v11.5.txt",
		        "sequence_path": "522306.protein.sequences.v11.5.fa",
		        "enrichment_path": "522306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "522306.protein.info.v11.5.txt",
		        "node_list_path": "522306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "522306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonadaceaeBacteriumT822Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonadaceae bacterium T82-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonadaceaeBacteriumT822Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1783518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1783518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1783518.clusters.proteins.v11.5.txt",
		        "sequence_path": "1783518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1783518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1783518.protein.info.v11.5.txt",
		        "node_list_path": "1783518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1783518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSelangorensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus selangorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSelangorensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "81857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "81857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "81857.clusters.proteins.v11.5.txt",
		        "sequence_path": "81857.protein.sequences.v11.5.fa",
		        "enrichment_path": "81857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81857.protein.info.v11.5.txt",
		        "node_list_path": "81857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "81857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumGlucuronolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium glucuronolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumGlucuronolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "548477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "548477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "548477.clusters.proteins.v11.5.txt",
		        "sequence_path": "548477.protein.sequences.v11.5.fa",
		        "enrichment_path": "548477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "548477.protein.info.v11.5.txt",
		        "node_list_path": "548477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "548477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumScgcAaa168P09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA168-P09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumScgcAaa168P09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1009426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1009426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1009426.clusters.proteins.v11.5.txt",
		        "sequence_path": "1009426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009426.protein.info.v11.5.txt",
		        "node_list_path": "1009426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1009426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpNfr16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. NFR16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpNfr16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566248.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566248.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566248.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566248.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566248.protein.info.v11.5.txt",
		        "node_list_path": "1566248.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566248.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelianthusAnnuusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helianthus annuus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelianthusAnnuusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4232.clusters.proteins.v11.5.txt",
		        "sequence_path": "4232.protein.sequences.v11.5.fa",
		        "enrichment_path": "4232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4232.protein.info.v11.5.txt",
		        "node_list_path": "4232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSpRoot685Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. Root685 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpRoot685Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736587.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736587.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736587.protein.info.v11.5.txt",
		        "node_list_path": "1736587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesMisionensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces misionensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesMisionensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67331.clusters.proteins.v11.5.txt",
		        "sequence_path": "67331.protein.sequences.v11.5.fa",
		        "enrichment_path": "67331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67331.protein.info.v11.5.txt",
		        "node_list_path": "67331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaTropicalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida tropicalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaTropicalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5482.clusters.proteins.v11.5.txt",
		        "sequence_path": "5482.protein.sequences.v11.5.fa",
		        "enrichment_path": "5482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5482.protein.info.v11.5.txt",
		        "node_list_path": "5482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GulosibacterMolinativorax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gulosibacter molinativorax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GulosibacterMolinativorax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121934.protein.info.v11.5.txt",
		        "node_list_path": "1121934.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylocystisParvus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylocystis parvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocystisParvus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1134912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134912.protein.info.v11.5.txt",
		        "node_list_path": "1134912.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5008(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5008", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463853.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463853.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463853.protein.info.v11.5.txt",
		        "node_list_path": "1463853.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterLipolyticusBf04cf4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter lipolyticus BF04CF4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterLipolyticusBf04cf4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1046724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1046724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1046724.clusters.proteins.v11.5.txt",
		        "sequence_path": "1046724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046724.protein.info.v11.5.txt",
		        "node_list_path": "1046724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1046724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumClostridioforme(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Clostridium clostridioforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumClostridioforme", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742735.protein.sequences.v11.0.fa",
		        "enrichment_path": "742735.protein.enrichment.terms.v11.0.txt",
		        "info_path": "742735.protein.info.v11.0.txt",
		        "node_list_path": "742735.protein.complete.v11.0.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNk4a179(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A179 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNk4a179", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "877424.protein.sequences.v11.5.fa",
		        "enrichment_path": "877424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877424.protein.info.v11.5.txt",
		        "node_list_path": "877424.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4024Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4024Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798385.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798385.protein.info.v11.5.txt",
		        "node_list_path": "1798385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldisericumExileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldisericum exile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldisericumExileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "511051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "511051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "511051.clusters.proteins.v11.5.txt",
		        "sequence_path": "511051.protein.sequences.v11.5.fa",
		        "enrichment_path": "511051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511051.protein.info.v11.5.txt",
		        "node_list_path": "511051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "511051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumGlutamicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium glutamicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumGlutamicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "196627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "196627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "196627.clusters.proteins.v11.5.txt",
		        "sequence_path": "196627.protein.sequences.v11.5.fa",
		        "enrichment_path": "196627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "196627.protein.info.v11.5.txt",
		        "node_list_path": "196627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "196627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFlevense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium flevense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFlevense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983.protein.sequences.v11.5.fa",
		        "enrichment_path": "983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983.protein.info.v11.5.txt",
		        "node_list_path": "983.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaKt2440Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida KT2440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaKt2440Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "160488.clusters.info.v11.5.txt",
		        "cluster_tree_path": "160488.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "160488.clusters.proteins.v11.5.txt",
		        "sequence_path": "160488.protein.sequences.v11.5.fa",
		        "enrichment_path": "160488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "160488.protein.info.v11.5.txt",
		        "node_list_path": "160488.cluster.nodes.v11.5.txt",
		        "edge_list_path": "160488.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovermiculusHalophilusDsm18834Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovermiculus halophilus DSM 18834 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovermiculusHalophilusDsm18834Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121433.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121433.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121433.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121433.protein.info.v11.5.txt",
		        "node_list_path": "1121433.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121433.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicoccusSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1432562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1432562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1432562.clusters.proteins.v11.5.txt",
		        "sequence_path": "1432562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432562.protein.info.v11.5.txt",
		        "node_list_path": "1432562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1432562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaKroppenstedtiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia kroppenstedtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaKroppenstedtiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "468556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "468556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "468556.clusters.proteins.v11.5.txt",
		        "sequence_path": "468556.protein.sequences.v11.5.fa",
		        "enrichment_path": "468556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "468556.protein.info.v11.5.txt",
		        "node_list_path": "468556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "468556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteibacterSp329mfshaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter sp. 329MFSha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterSp329mfshaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798239.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798239.protein.info.v11.5.txt",
		        "node_list_path": "1798239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasJaponicaNbrc103040Dsm22348Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas japonica NBRC 103040 DSM 22348 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasJaponicaNbrc103040Dsm22348Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1215104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1215104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1215104.clusters.proteins.v11.5.txt",
		        "sequence_path": "1215104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215104.protein.info.v11.5.txt",
		        "node_list_path": "1215104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1215104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa2499(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_49_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa2499", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618852.protein.info.v11.5.txt",
		        "node_list_path": "1618852.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalosimplexCarlsbadense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halosimplex carlsbadense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalosimplexCarlsbadense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "797114.protein.sequences.v11.5.fa",
		        "enrichment_path": "797114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797114.protein.info.v11.5.txt",
		        "node_list_path": "797114.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusFaeciumNrrlb2354(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecium NRRLB2354 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusFaeciumNrrlb2354", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1104325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104325.protein.info.v11.5.txt",
		        "node_list_path": "1104325.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg135152(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_51_52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg135152", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797626.protein.info.v11.5.txt",
		        "node_list_path": "1797626.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3925(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_01_FULL_39_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3925", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802202.protein.info.v11.5.txt",
		        "node_list_path": "1802202.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWallbacteriaBacteriumGwc24935(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wallbacteria bacterium GWC2_49_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWallbacteriaBacteriumGwc24935", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817813.protein.info.v11.5.txt",
		        "node_list_path": "1817813.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumCch3A5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium CCH3-A5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumCch3A5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1768796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768796.protein.info.v11.5.txt",
		        "node_list_path": "1768796.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpS9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. S9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpS9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "686578.protein.sequences.v11.5.fa",
		        "enrichment_path": "686578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686578.protein.info.v11.5.txt",
		        "node_list_path": "686578.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpYt30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. YT30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpYt30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735012.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735012.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735012.protein.info.v11.5.txt",
		        "node_list_path": "1735012.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpTksCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. TKS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpTksCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1315974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1315974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1315974.clusters.proteins.v11.5.txt",
		        "sequence_path": "1315974.protein.sequences.v11.5.fa",
		        "enrichment_path": "1315974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1315974.protein.info.v11.5.txt",
		        "node_list_path": "1315974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1315974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwe13724(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_37_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe13724", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618709.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618709.protein.info.v11.5.txt",
		        "node_list_path": "1618709.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanospirillalesBacteriumScgcAaa298N10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillales bacterium SCGC AAA298-N10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanospirillalesBacteriumScgcAaa298N10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "939745.protein.sequences.v11.5.fa",
		        "enrichment_path": "939745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939745.protein.info.v11.5.txt",
		        "node_list_path": "939745.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpSoil772Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. Soil772 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpSoil772Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736406.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736406.protein.info.v11.5.txt",
		        "node_list_path": "1736406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusAnginosusSk52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus SK52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAnginosusSk52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1000570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1000570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1000570.clusters.proteins.v11.5.txt",
		        "sequence_path": "1000570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1000570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1000570.protein.info.v11.5.txt",
		        "node_list_path": "1000570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1000570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DokdoniaSpPro95Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dokdonia sp. PRO95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DokdoniaSpPro95Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1239415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1239415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1239415.clusters.proteins.v11.5.txt",
		        "sequence_path": "1239415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1239415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1239415.protein.info.v11.5.txt",
		        "node_list_path": "1239415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1239415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaSihwensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sihwensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSihwensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223544.protein.info.v11.5.txt",
		        "node_list_path": "1223544.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaLupiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora lupini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaLupiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150864.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150864.protein.info.v11.5.txt",
		        "node_list_path": "1150864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollimonasArenaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collimonas arenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollimonasArenaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "279058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "279058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "279058.clusters.proteins.v11.5.txt",
		        "sequence_path": "279058.protein.sequences.v11.5.fa",
		        "enrichment_path": "279058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279058.protein.info.v11.5.txt",
		        "node_list_path": "279058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "279058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AuraticoccusMonumentiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Auraticoccus monumenti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AuraticoccusMonumentiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675864.clusters.proteins.v11.5.txt",
		        "sequence_path": "675864.protein.sequences.v11.5.fa",
		        "enrichment_path": "675864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675864.protein.info.v11.5.txt",
		        "node_list_path": "675864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidilobusSaccharovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidilobus saccharovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidilobusSaccharovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "666510.clusters.info.v11.5.txt",
		        "cluster_tree_path": "666510.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "666510.clusters.proteins.v11.5.txt",
		        "sequence_path": "666510.protein.sequences.v11.5.fa",
		        "enrichment_path": "666510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "666510.protein.info.v11.5.txt",
		        "node_list_path": "666510.cluster.nodes.v11.5.txt",
		        "edge_list_path": "666510.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysobacterSpRoot604Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root604 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterSpRoot604Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736568.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736568.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736568.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736568.protein.info.v11.5.txt",
		        "node_list_path": "1736568.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736568.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrotetrasporaNiveoalbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microtetraspora niveoalba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrotetrasporaNiveoalbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46175.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46175.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46175.clusters.proteins.v11.5.txt",
		        "sequence_path": "46175.protein.sequences.v11.5.fa",
		        "enrichment_path": "46175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46175.protein.info.v11.5.txt",
		        "node_list_path": "46175.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46175.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumNoviomagenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium noviomagense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumNoviomagenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "459858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "459858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "459858.clusters.proteins.v11.5.txt",
		        "sequence_path": "459858.protein.sequences.v11.5.fa",
		        "enrichment_path": "459858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "459858.protein.info.v11.5.txt",
		        "node_list_path": "459858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "459858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalothermothrixOreniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halothermothrix orenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalothermothrixOreniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "373903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "373903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "373903.clusters.proteins.v11.5.txt",
		        "sequence_path": "373903.protein.sequences.v11.5.fa",
		        "enrichment_path": "373903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "373903.protein.info.v11.5.txt",
		        "node_list_path": "373903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "373903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaBovisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaBovisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "476.clusters.proteins.v11.5.txt",
		        "sequence_path": "476.protein.sequences.v11.5.fa",
		        "enrichment_path": "476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "476.protein.info.v11.5.txt",
		        "node_list_path": "476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterBilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter bilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterBilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "613026.protein.sequences.v11.5.fa",
		        "enrichment_path": "613026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "613026.protein.info.v11.5.txt",
		        "node_list_path": "613026.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioNatriegensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio natriegens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioNatriegensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "691.clusters.info.v11.5.txt",
		        "cluster_tree_path": "691.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "691.clusters.proteins.v11.5.txt",
		        "sequence_path": "691.protein.sequences.v11.5.fa",
		        "enrichment_path": "691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "691.protein.info.v11.5.txt",
		        "node_list_path": "691.cluster.nodes.v11.5.txt",
		        "edge_list_path": "691.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacillusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "866895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "866895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "866895.clusters.proteins.v11.5.txt",
		        "sequence_path": "866895.protein.sequences.v11.5.fa",
		        "enrichment_path": "866895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866895.protein.info.v11.5.txt",
		        "node_list_path": "866895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "866895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraSpKp2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. Kp2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraSpKp2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123518.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123518.protein.info.v11.5.txt",
		        "node_list_path": "1123518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusVulcanalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus vulcanalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusVulcanalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "252246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "252246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "252246.clusters.proteins.v11.5.txt",
		        "sequence_path": "252246.protein.sequences.v11.5.fa",
		        "enrichment_path": "252246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "252246.protein.info.v11.5.txt",
		        "node_list_path": "252246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "252246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaeromassilibacillusSenegalensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaeromassilibacillus senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeromassilibacillusSenegalensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1673717.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1673717.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1673717.clusters.proteins.v11.5.txt",
		        "sequence_path": "1673717.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673717.protein.info.v11.5.txt",
		        "node_list_path": "1673717.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1673717.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumPolytrichastriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium polytrichastri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumPolytrichastriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1302687.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1302687.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1302687.clusters.proteins.v11.5.txt",
		        "sequence_path": "1302687.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302687.protein.info.v11.5.txt",
		        "node_list_path": "1302687.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1302687.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FerrovumSpZ31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferrovum sp. Z-31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrovumSpZ31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1789004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1789004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1789004.protein.info.v11.5.txt",
		        "node_list_path": "1789004.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesPaucisporeus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces paucisporeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPaucisporeus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "310782.protein.sequences.v11.5.fa",
		        "enrichment_path": "310782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "310782.protein.info.v11.5.txt",
		        "node_list_path": "310782.protein.complete.v11.5.txt"
		    }
		]
    )()

def IdeonellaSakaiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ideonella sakaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdeonellaSakaiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1547922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1547922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1547922.protein.info.v11.5.txt",
		        "node_list_path": "1547922.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAkl19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. AKL19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAkl19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1266914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1266914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1266914.clusters.proteins.v11.5.txt",
		        "sequence_path": "1266914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266914.protein.info.v11.5.txt",
		        "node_list_path": "1266914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1266914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSimilisDsm23365Jcm2765Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus similis DSM 23365 JCM 2765 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSimilisDsm23365Jcm2765Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423804.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423804.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423804.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423804.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423804.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423804.protein.info.v11.5.txt",
		        "node_list_path": "1423804.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423804.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu069Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU069 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu069Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671654.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671654.protein.info.v11.5.txt",
		        "node_list_path": "1671654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PleomorphomonasOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pleomorphomonas oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PleomorphomonasOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122963.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122963.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122963.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122963.protein.info.v11.5.txt",
		        "node_list_path": "1122963.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122963.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteiniborusEthanoligenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteiniborus ethanoligenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteiniborusEthanoligenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "415015.protein.sequences.v11.5.fa",
		        "enrichment_path": "415015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "415015.protein.info.v11.5.txt",
		        "node_list_path": "415015.protein.complete.v11.5.txt"
		    }
		]
    )()

def DomibacillusTundrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus tundrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusTundrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1587527.protein.sequences.v11.5.fa",
		        "enrichment_path": "1587527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1587527.protein.info.v11.5.txt",
		        "node_list_path": "1587527.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTa06BacteriumDg24(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TA06 bacterium DG_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTa06BacteriumDg24", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703770.protein.info.v11.5.txt",
		        "node_list_path": "1703770.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasSpMex14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. Mex14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasSpMex14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1917157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917157.protein.info.v11.5.txt",
		        "node_list_path": "1917157.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaOrthopsilosis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida orthopsilosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaOrthopsilosis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "273371.protein.sequences.v11.5.fa",
		        "enrichment_path": "273371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273371.protein.info.v11.5.txt",
		        "node_list_path": "273371.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophobacteralesBacteriumDelta02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophobacterales bacterium Delta_02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophobacteralesBacteriumDelta02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674896.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674896.protein.info.v11.5.txt",
		        "node_list_path": "1674896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaHispanicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena hispanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaHispanicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "392421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "392421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "392421.clusters.proteins.v11.5.txt",
		        "sequence_path": "392421.protein.sequences.v11.5.fa",
		        "enrichment_path": "392421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392421.protein.info.v11.5.txt",
		        "node_list_path": "392421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "392421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpUrhd0025Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. URHD0025 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpUrhd0025Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298864.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298864.protein.info.v11.5.txt",
		        "node_list_path": "1298864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NaemateliaEncephala(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Naematelia encephala graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NaemateliaEncephala", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "71784.protein.sequences.v11.5.fa",
		        "enrichment_path": "71784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "71784.protein.info.v11.5.txt",
		        "node_list_path": "71784.protein.complete.v11.5.txt"
		    }
		]
    )()

def TigriopusCalifornicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tigriopus californicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TigriopusCalifornicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6832.protein.sequences.v11.5.fa",
		        "enrichment_path": "6832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6832.protein.info.v11.5.txt",
		        "node_list_path": "6832.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrocarboniphagaEffusaAp103Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga effusa AP103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrocarboniphagaEffusaAp103Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1172194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1172194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1172194.clusters.proteins.v11.5.txt",
		        "sequence_path": "1172194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172194.protein.info.v11.5.txt",
		        "node_list_path": "1172194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1172194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpCiat894Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. CIAT894 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpCiat894Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2020312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2020312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2020312.clusters.proteins.v11.5.txt",
		        "sequence_path": "2020312.protein.sequences.v11.5.fa",
		        "enrichment_path": "2020312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2020312.protein.info.v11.5.txt",
		        "node_list_path": "2020312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2020312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesIncarnatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces incarnatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesIncarnatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665007.protein.sequences.v11.5.fa",
		        "enrichment_path": "665007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665007.protein.info.v11.5.txt",
		        "node_list_path": "665007.protein.complete.v11.5.txt"
		    }
		]
    )()

def HoefleaSpBrhC9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hoeflea sp. BRH_c9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoefleaSpBrhC9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629712.protein.info.v11.5.txt",
		        "node_list_path": "1629712.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulforhabdusNorvegicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulforhabdus norvegica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulforhabdusNorvegicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39841.clusters.proteins.v11.5.txt",
		        "sequence_path": "39841.protein.sequences.v11.5.fa",
		        "enrichment_path": "39841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39841.protein.info.v11.5.txt",
		        "node_list_path": "39841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumElkaniiWsm1741Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii WSM1741 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumElkaniiWsm1741Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1038859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1038859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1038859.clusters.proteins.v11.5.txt",
		        "sequence_path": "1038859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038859.protein.info.v11.5.txt",
		        "node_list_path": "1038859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1038859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumGuttoideumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum guttoideum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumGuttoideumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298920.protein.info.v11.5.txt",
		        "node_list_path": "1298920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesGerencseriaeDsm6844(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces gerencseriae DSM 6844 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesGerencseriaeDsm6844", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120943.protein.info.v11.5.txt",
		        "node_list_path": "1120943.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaOvipneumoniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma ovipneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaOvipneumoniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1188239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188239.protein.info.v11.5.txt",
		        "node_list_path": "1188239.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumGw2011Gwa24711bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWA2_47_11b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwa24711bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618358.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618358.protein.info.v11.5.txt",
		        "node_list_path": "1618358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag43(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag43", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262805.protein.info.v11.5.txt",
		        "node_list_path": "1262805.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHodgkiniaCicadicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hodgkinia cicadicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHodgkiniaCicadicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573658.clusters.proteins.v11.5.txt",
		        "sequence_path": "573658.protein.sequences.v11.5.fa",
		        "enrichment_path": "573658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573658.protein.info.v11.5.txt",
		        "node_list_path": "573658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumYsd2013(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium YSD2013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumYsd2013", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520828.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520828.protein.info.v11.5.txt",
		        "node_list_path": "1520828.protein.complete.v11.5.txt"
		    }
		]
    )()

def KlebsiellaPneumoniaeSubspPneumoniaeMgh78578Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. pneumoniae MGH 78578 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaPneumoniaeSubspPneumoniaeMgh78578Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272620.clusters.proteins.v11.5.txt",
		        "sequence_path": "272620.protein.sequences.v11.5.fa",
		        "enrichment_path": "272620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272620.protein.info.v11.5.txt",
		        "node_list_path": "272620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumGwf25820Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium GWF2_58_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumGwf25820Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797213.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797213.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797213.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797213.protein.info.v11.5.txt",
		        "node_list_path": "1797213.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797213.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_42_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618820.protein.info.v11.5.txt",
		        "node_list_path": "1618820.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumGwf23885(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWF2_38_85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumGwf23885", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797683.protein.info.v11.5.txt",
		        "node_list_path": "1797683.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinimonasChungwhensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinimonas chungwhensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinimonasChungwhensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123236.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123236.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123236.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123236.protein.info.v11.5.txt",
		        "node_list_path": "1123236.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123236.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PetromyzonMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Petromyzon marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PetromyzonMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7757.protein.sequences.v11.5.fa",
		        "enrichment_path": "7757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7757.protein.info.v11.5.txt",
		        "node_list_path": "7757.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusGelatini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus gelatini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGelatini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121091.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121091.protein.info.v11.5.txt",
		        "node_list_path": "1121091.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaMarcescensFgi94(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia marcescens FGI94 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaMarcescensFgi94", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1249634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249634.protein.info.v11.5.txt",
		        "node_list_path": "1249634.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrunusPersica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prunus persica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrunusPersica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3760.protein.sequences.v11.5.fa",
		        "enrichment_path": "3760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3760.protein.info.v11.5.txt",
		        "node_list_path": "3760.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenovibrioHalophilusDsm15072Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenovibrio halophilus DSM 15072 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenovibrioHalophilusDsm15072Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123516.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123516.protein.info.v11.5.txt",
		        "node_list_path": "1123516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaJamestowniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella jamestowniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaJamestowniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "455.protein.sequences.v11.5.fa",
		        "enrichment_path": "455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "455.protein.info.v11.5.txt",
		        "node_list_path": "455.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumTsurumienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium tsurumiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumTsurumienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "356829.clusters.info.v11.5.txt",
		        "cluster_tree_path": "356829.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "356829.clusters.proteins.v11.5.txt",
		        "sequence_path": "356829.protein.sequences.v11.5.fa",
		        "enrichment_path": "356829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "356829.protein.info.v11.5.txt",
		        "node_list_path": "356829.cluster.nodes.v11.5.txt",
		        "edge_list_path": "356829.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumItalicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium italicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumItalicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40296.clusters.proteins.v11.5.txt",
		        "sequence_path": "40296.protein.sequences.v11.5.fa",
		        "enrichment_path": "40296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40296.protein.info.v11.5.txt",
		        "node_list_path": "40296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHlucco18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCO18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHlucco18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1666917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1666917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1666917.clusters.proteins.v11.5.txt",
		        "sequence_path": "1666917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666917.protein.info.v11.5.txt",
		        "node_list_path": "1666917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1666917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "199136.clusters.info.v11.5.txt",
		        "cluster_tree_path": "199136.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "199136.clusters.proteins.v11.5.txt",
		        "sequence_path": "199136.protein.sequences.v11.5.fa",
		        "enrichment_path": "199136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "199136.protein.info.v11.5.txt",
		        "node_list_path": "199136.cluster.nodes.v11.5.txt",
		        "edge_list_path": "199136.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumGrahamii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium grahamii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumGrahamii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "990285.protein.sequences.v11.5.fa",
		        "enrichment_path": "990285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990285.protein.info.v11.5.txt",
		        "node_list_path": "990285.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpJs211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. JS21-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpJs211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855283.protein.info.v11.5.txt",
		        "node_list_path": "1855283.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumGwd23259(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWD2_32_59 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumGwd23259", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797680.protein.info.v11.5.txt",
		        "node_list_path": "1797680.protein.complete.v11.5.txt"
		    }
		]
    )()

def PontibacillusLitoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacillus litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacillusLitoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385512.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385512.protein.info.v11.5.txt",
		        "node_list_path": "1385512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CroceibacteriumMercurialeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Croceibacterium mercuriale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CroceibacteriumMercurialeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1572751.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1572751.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1572751.clusters.proteins.v11.5.txt",
		        "sequence_path": "1572751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1572751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1572751.protein.info.v11.5.txt",
		        "node_list_path": "1572751.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1572751.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPseudotuberculosisC231(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pseudotuberculosis C231 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPseudotuberculosisC231", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "681645.protein.sequences.v11.5.fa",
		        "enrichment_path": "681645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "681645.protein.info.v11.5.txt",
		        "node_list_path": "681645.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaAnaemiaeNbrc100462(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia anaemiae NBRC 100462 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAnaemiaeNbrc100462", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210065.protein.info.v11.5.txt",
		        "node_list_path": "1210065.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCibi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cibi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCibi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "265729.protein.sequences.v11.5.fa",
		        "enrichment_path": "265729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265729.protein.info.v11.5.txt",
		        "node_list_path": "265729.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaPurisNbrc108233(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia puris NBRC 108233 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaPurisNbrc108233", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210090.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210090.protein.info.v11.5.txt",
		        "node_list_path": "1210090.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollimonasSpOk412Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collimonas sp. OK412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollimonasSpOk412Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801619.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801619.protein.info.v11.5.txt",
		        "node_list_path": "1801619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodothermaceaeBacteriumTcBr11B2g67Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodothermaceae bacterium Tc-Br11_B2g6_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodothermaceaeBacteriumTcBr11B2g67Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729468.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729468.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729468.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729468.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729468.protein.info.v11.5.txt",
		        "node_list_path": "1729468.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729468.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinophytocolaXanthii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinophytocola xanthii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinophytocolaXanthii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1912961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912961.protein.info.v11.5.txt",
		        "node_list_path": "1912961.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterColi76339(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter coli 76339 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterColi76339", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1367491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1367491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1367491.protein.info.v11.5.txt",
		        "node_list_path": "1367491.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcaligenaceaeBacteriumDtu041Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcaligenaceae bacterium DTU041 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcaligenaceaeBacteriumDtu041Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671635.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671635.protein.info.v11.5.txt",
		        "node_list_path": "1671635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CronobacterDublinensisSubspDublinensisLmg23823(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. dublinensis LMG 23823 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CronobacterDublinensisSubspDublinensisLmg23823", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1159554.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159554.protein.info.v11.5.txt",
		        "node_list_path": "1159554.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrobaculumIslandicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum islandicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumIslandicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "384616.protein.sequences.v11.5.fa",
		        "enrichment_path": "384616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "384616.protein.info.v11.5.txt",
		        "node_list_path": "384616.protein.complete.v11.5.txt"
		    }
		]
    )()

def AequorivitaCapsosiphonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aequorivita capsosiphonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AequorivitaCapsosiphonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120951.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120951.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120951.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120951.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120951.protein.info.v11.5.txt",
		        "node_list_path": "1120951.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120951.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpOrs3324(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpOrs3324", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "408180.protein.sequences.v11.5.fa",
		        "enrichment_path": "408180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408180.protein.info.v11.5.txt",
		        "node_list_path": "408180.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumRifcsplowo202Full4019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPLOWO2_02_FULL_40_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsplowo202Full4019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797229.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797229.protein.info.v11.5.txt",
		        "node_list_path": "1797229.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSp73145(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. 73-145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSp73145", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895739.protein.info.v11.5.txt",
		        "node_list_path": "1895739.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusAcidocaldariusLaa1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius LAA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusAcidocaldariusLaa1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "543302.clusters.info.v11.5.txt",
		        "cluster_tree_path": "543302.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "543302.clusters.proteins.v11.5.txt",
		        "sequence_path": "543302.protein.sequences.v11.5.fa",
		        "enrichment_path": "543302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543302.protein.info.v11.5.txt",
		        "node_list_path": "543302.cluster.nodes.v11.5.txt",
		        "edge_list_path": "543302.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterPametensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pametensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterPametensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408442.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408442.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408442.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408442.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408442.protein.info.v11.5.txt",
		        "node_list_path": "1408442.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408442.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMarinumDsm44953(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium marinum DSM 44953 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMarinumDsm44953", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1224162.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224162.protein.info.v11.5.txt",
		        "node_list_path": "1224162.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudozymaFlocculosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma flocculosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudozymaFlocculosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84751.protein.sequences.v11.5.fa",
		        "enrichment_path": "84751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84751.protein.info.v11.5.txt",
		        "node_list_path": "84751.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusWentiiDto134e9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus wentii DTO 134E9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusWentiiDto134e9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1073089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1073089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1073089.clusters.proteins.v11.5.txt",
		        "sequence_path": "1073089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073089.protein.info.v11.5.txt",
		        "node_list_path": "1073089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1073089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumSpA39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium sp. A39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumSpA39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1860100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860100.protein.info.v11.5.txt",
		        "node_list_path": "1860100.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaSpKimCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. KIM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpKimCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1955422.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1955422.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1955422.clusters.proteins.v11.5.txt",
		        "sequence_path": "1955422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1955422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1955422.protein.info.v11.5.txt",
		        "node_list_path": "1955422.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1955422.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShinellaSpGws1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shinella sp. GWS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShinellaSpGws1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1692240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1692240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1692240.clusters.proteins.v11.5.txt",
		        "sequence_path": "1692240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1692240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1692240.protein.info.v11.5.txt",
		        "node_list_path": "1692240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1692240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavihumibacterSolisilvae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavihumibacter solisilvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavihumibacterSolisilvae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349421.protein.info.v11.5.txt",
		        "node_list_path": "1349421.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaCenocepacia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia cenocepacia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaCenocepacia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216591.protein.sequences.v11.5.fa",
		        "enrichment_path": "216591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216591.protein.info.v11.5.txt",
		        "node_list_path": "216591.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHoaglandellaEndobia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hoaglandella endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHoaglandellaEndobia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1778263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1778263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1778263.protein.info.v11.5.txt",
		        "node_list_path": "1778263.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyriculariaOryzae7015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyricularia oryzae 70-15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyriculariaOryzae7015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "242507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "242507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "242507.clusters.proteins.v11.5.txt",
		        "sequence_path": "242507.protein.sequences.v11.5.fa",
		        "enrichment_path": "242507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "242507.protein.info.v11.5.txt",
		        "node_list_path": "242507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "242507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusJostiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus jostii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusJostiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "101510.clusters.info.v11.5.txt",
		        "cluster_tree_path": "101510.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "101510.clusters.proteins.v11.5.txt",
		        "sequence_path": "101510.protein.sequences.v11.5.fa",
		        "enrichment_path": "101510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "101510.protein.info.v11.5.txt",
		        "node_list_path": "101510.cluster.nodes.v11.5.txt",
		        "edge_list_path": "101510.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BabelaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Babela massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BabelaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "673862.protein.sequences.v11.5.fa",
		        "enrichment_path": "673862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "673862.protein.info.v11.5.txt",
		        "node_list_path": "673862.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumAngstadtiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium angstadtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumAngstadtiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "558151.clusters.info.v11.5.txt",
		        "cluster_tree_path": "558151.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "558151.clusters.proteins.v11.5.txt",
		        "sequence_path": "558151.protein.sequences.v11.5.fa",
		        "enrichment_path": "558151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558151.protein.info.v11.5.txt",
		        "node_list_path": "558151.cluster.nodes.v11.5.txt",
		        "edge_list_path": "558151.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAnthracisStrAmesAncestor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis str. Ames Ancestor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAnthracisStrAmesAncestor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "261594.protein.sequences.v11.5.fa",
		        "enrichment_path": "261594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "261594.protein.info.v11.5.txt",
		        "node_list_path": "261594.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumMesophilicumSr166(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium mesophilicum SR1.6/6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumMesophilicumSr166", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "908290.protein.sequences.v11.5.fa",
		        "enrichment_path": "908290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908290.protein.info.v11.5.txt",
		        "node_list_path": "908290.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93059.clusters.proteins.v11.5.txt",
		        "sequence_path": "93059.protein.sequences.v11.5.fa",
		        "enrichment_path": "93059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93059.protein.info.v11.5.txt",
		        "node_list_path": "93059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanomethylophilusAlvusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanomethylophilus alvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomethylophilusAlvusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236689.protein.info.v11.5.txt",
		        "node_list_path": "1236689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumOlb8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumOlb8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617419.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617419.protein.info.v11.5.txt",
		        "node_list_path": "1617419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusLacrimalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus lacrimalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusLacrimalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596330.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596330.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596330.clusters.proteins.v11.5.txt",
		        "sequence_path": "596330.protein.sequences.v11.5.fa",
		        "enrichment_path": "596330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596330.protein.info.v11.5.txt",
		        "node_list_path": "596330.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596330.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpNfr04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. NFR04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpNfr04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566283.protein.info.v11.5.txt",
		        "node_list_path": "1566283.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyricimonasSpMarseilleP2440(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyricimonas sp. Marseille-P2440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyricimonasSpMarseilleP2440", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816677.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816677.protein.info.v11.5.txt",
		        "node_list_path": "1816677.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumDaeguense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium daeguense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumDaeguense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121286.protein.info.v11.5.txt",
		        "node_list_path": "1121286.protein.complete.v11.5.txt"
		    }
		]
    )()

def EudoraeaAdriaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eudoraea adriatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EudoraeaAdriaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121875.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121875.protein.info.v11.5.txt",
		        "node_list_path": "1121875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SclerotiniaSclerotiorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sclerotinia sclerotiorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SclerotiniaSclerotiorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5180.protein.sequences.v11.5.fa",
		        "enrichment_path": "5180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5180.protein.info.v11.5.txt",
		        "node_list_path": "5180.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1715692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715692.protein.info.v11.5.txt",
		        "node_list_path": "1715692.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedBacteroidesSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Bacteroides sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedBacteroidesSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "162156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "162156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "162156.clusters.proteins.v11.5.txt",
		        "sequence_path": "162156.protein.sequences.v11.5.fa",
		        "enrichment_path": "162156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "162156.protein.info.v11.5.txt",
		        "node_list_path": "162156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "162156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioNavarrensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio navarrensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioNavarrensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29495.clusters.proteins.v11.5.txt",
		        "sequence_path": "29495.protein.sequences.v11.5.fa",
		        "enrichment_path": "29495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29495.protein.info.v11.5.txt",
		        "node_list_path": "29495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusAquimarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus aquimarinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusAquimarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "328396.clusters.info.v11.5.txt",
		        "cluster_tree_path": "328396.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "328396.clusters.proteins.v11.5.txt",
		        "sequence_path": "328396.protein.sequences.v11.5.fa",
		        "enrichment_path": "328396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "328396.protein.info.v11.5.txt",
		        "node_list_path": "328396.cluster.nodes.v11.5.txt",
		        "edge_list_path": "328396.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusPuniceus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus puniceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusPuniceus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1182568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182568.protein.info.v11.5.txt",
		        "node_list_path": "1182568.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslh70737Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70737 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslh70737Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1536775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1536775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1536775.clusters.proteins.v11.5.txt",
		        "sequence_path": "1536775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536775.protein.info.v11.5.txt",
		        "node_list_path": "1536775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1536775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpX12014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. X1(2014) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpX12014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1565991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1565991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1565991.clusters.proteins.v11.5.txt",
		        "sequence_path": "1565991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1565991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1565991.protein.info.v11.5.txt",
		        "node_list_path": "1565991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1565991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaMiyamotoi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia miyamotoi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaMiyamotoi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1302858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302858.protein.info.v11.5.txt",
		        "node_list_path": "1302858.protein.complete.v11.5.txt"
		    }
		]
    )()

def SymbiobacterMobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Symbiobacter mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SymbiobacterMobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "946483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "946483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "946483.clusters.proteins.v11.5.txt",
		        "sequence_path": "946483.protein.sequences.v11.5.fa",
		        "enrichment_path": "946483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946483.protein.info.v11.5.txt",
		        "node_list_path": "946483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "946483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCaseiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus casei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCaseiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1582.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1582.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1582.clusters.proteins.v11.5.txt",
		        "sequence_path": "1582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1582.protein.info.v11.5.txt",
		        "node_list_path": "1582.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1582.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopirellulaBalticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopirellula baltica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopirellulaBalticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243090.clusters.proteins.v11.5.txt",
		        "sequence_path": "243090.protein.sequences.v11.5.fa",
		        "enrichment_path": "243090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243090.protein.info.v11.5.txt",
		        "node_list_path": "243090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitratireductorIndicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitratireductor indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratireductorIndicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231190.protein.info.v11.5.txt",
		        "node_list_path": "1231190.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumRifcsplowo201Full4710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RIFCSPLOWO2_01_FULL_47_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumRifcsplowo201Full4710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817751.protein.info.v11.5.txt",
		        "node_list_path": "1817751.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfonatronumLacustreDsm10312Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronum lacustre DSM 10312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronumLacustreDsm10312Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935942.clusters.proteins.v11.5.txt",
		        "sequence_path": "935942.protein.sequences.v11.5.fa",
		        "enrichment_path": "935942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935942.protein.info.v11.5.txt",
		        "node_list_path": "935942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldimonasManganoxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldimonas manganoxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldimonasManganoxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265502.protein.info.v11.5.txt",
		        "node_list_path": "1265502.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRbg165624(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_56_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRbg165624", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797475.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797475.protein.info.v11.5.txt",
		        "node_list_path": "1797475.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpMb2021(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MB2021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpMb2021", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408303.protein.info.v11.5.txt",
		        "node_list_path": "1408303.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSp162mfsha11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 162MFSha11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSp162mfsha11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1151119.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1151119.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1151119.clusters.proteins.v11.5.txt",
		        "sequence_path": "1151119.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151119.protein.info.v11.5.txt",
		        "node_list_path": "1151119.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1151119.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWalczuchellaMonophlebidarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Walczuchella monophlebidarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWalczuchellaMonophlebidarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415657.protein.info.v11.5.txt",
		        "node_list_path": "1415657.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndozoicomonasAscidiicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas ascidiicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndozoicomonasAscidiicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1698521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1698521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1698521.protein.info.v11.5.txt",
		        "node_list_path": "1698521.protein.complete.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterSp6612(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. 66-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterSp6612", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895714.protein.info.v11.5.txt",
		        "node_list_path": "1895714.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumMedpeSwsndG1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium MedPE-SWsnd-G1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumMedpeSwsndG1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1860094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860094.protein.info.v11.5.txt",
		        "node_list_path": "1860094.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp11649663(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1164966.3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp11649663", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1856861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1856861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1856861.protein.info.v11.5.txt",
		        "node_list_path": "1856861.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlochmanniaEndosymbiontOfCamponotusColobopsisObliquusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Camponotus (Colobopsis) obliquus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlochmanniaEndosymbiontOfCamponotusColobopsisObliquusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1505597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1505597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1505597.clusters.proteins.v11.5.txt",
		        "sequence_path": "1505597.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505597.protein.info.v11.5.txt",
		        "node_list_path": "1505597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1505597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesLydicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces lydicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesLydicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47763.protein.sequences.v11.5.fa",
		        "enrichment_path": "47763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47763.protein.info.v11.5.txt",
		        "node_list_path": "47763.protein.complete.v11.5.txt"
		    }
		]
    )()

def EctothiorhodospiraMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ectothiorhodospira marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctothiorhodospiraMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1396821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1396821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1396821.clusters.proteins.v11.5.txt",
		        "sequence_path": "1396821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1396821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1396821.protein.info.v11.5.txt",
		        "node_list_path": "1396821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1396821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpSat1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. SAT1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpSat1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849967.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849967.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849967.protein.info.v11.5.txt",
		        "node_list_path": "1849967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSp2mfcol31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. 2MFCol31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSp2mfcol31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246459.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246459.protein.info.v11.5.txt",
		        "node_list_path": "1246459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrialbaceaeArchaeonTcBr11E2g8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon Tc-Br11_E2g8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaceaeArchaeonTcBr11E2g8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729464.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729464.protein.info.v11.5.txt",
		        "node_list_path": "1729464.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusFerrooxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus ferrooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusFerrooxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "471514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "471514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "471514.clusters.proteins.v11.5.txt",
		        "sequence_path": "471514.protein.sequences.v11.5.fa",
		        "enrichment_path": "471514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471514.protein.info.v11.5.txt",
		        "node_list_path": "471514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "471514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BatrachochytriumDendrobatidisJam81(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis JAM81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BatrachochytriumDendrobatidisJam81", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "684364.protein.sequences.v11.5.fa",
		        "enrichment_path": "684364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "684364.protein.info.v11.5.txt",
		        "node_list_path": "684364.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucosisporaMarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucosispora maris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucosisporaMarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "263358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "263358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "263358.clusters.proteins.v11.5.txt",
		        "sequence_path": "263358.protein.sequences.v11.5.fa",
		        "enrichment_path": "263358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263358.protein.info.v11.5.txt",
		        "node_list_path": "263358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "263358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasSpBrhC22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. BRH_c22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSpBrhC22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629710.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629710.protein.info.v11.5.txt",
		        "node_list_path": "1629710.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full4934Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_49_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full4934Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798491.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798491.protein.info.v11.5.txt",
		        "node_list_path": "1798491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioVulgarisMiyazakiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio vulgaris Miyazaki Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioVulgarisMiyazakiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883.clusters.proteins.v11.5.txt",
		        "sequence_path": "883.protein.sequences.v11.5.fa",
		        "enrichment_path": "883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883.protein.info.v11.5.txt",
		        "node_list_path": "883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeiothermusCerbereus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus cerbereus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusCerbereus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122221.protein.info.v11.5.txt",
		        "node_list_path": "1122221.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumYuanmingenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium yuanmingense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumYuanmingenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "108015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "108015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "108015.clusters.proteins.v11.5.txt",
		        "sequence_path": "108015.protein.sequences.v11.5.fa",
		        "enrichment_path": "108015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "108015.protein.info.v11.5.txt",
		        "node_list_path": "108015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "108015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasJeddahensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas jeddahensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasJeddahensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1915074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915074.protein.info.v11.5.txt",
		        "node_list_path": "1915074.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalimonasAmylolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalimonas amylolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalimonasAmylolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "152573.clusters.info.v11.5.txt",
		        "cluster_tree_path": "152573.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "152573.clusters.proteins.v11.5.txt",
		        "sequence_path": "152573.protein.sequences.v11.5.fa",
		        "enrichment_path": "152573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "152573.protein.info.v11.5.txt",
		        "node_list_path": "152573.cluster.nodes.v11.5.txt",
		        "edge_list_path": "152573.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeolamprologusBrichardi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neolamprologus brichardi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeolamprologusBrichardi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32507.protein.sequences.v11.5.fa",
		        "enrichment_path": "32507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32507.protein.info.v11.5.txt",
		        "node_list_path": "32507.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasHortorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas hortorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasHortorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "863365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "863365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "863365.clusters.proteins.v11.5.txt",
		        "sequence_path": "863365.protein.sequences.v11.5.fa",
		        "enrichment_path": "863365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "863365.protein.info.v11.5.txt",
		        "node_list_path": "863365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "863365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AllosalinactinosporaLopnorensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Allosalinactinospora lopnorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllosalinactinosporaLopnorensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1352348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1352348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1352348.protein.info.v11.5.txt",
		        "node_list_path": "1352348.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCarsonellaRuddiiHtIsolateThao2000Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii HT isolate Thao2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCarsonellaRuddiiHtIsolateThao2000Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1202539.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1202539.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1202539.clusters.proteins.v11.5.txt",
		        "sequence_path": "1202539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202539.protein.info.v11.5.txt",
		        "node_list_path": "1202539.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1202539.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrobaculumOgunienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum oguniense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumOgunienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "698757.clusters.info.v11.5.txt",
		        "cluster_tree_path": "698757.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "698757.clusters.proteins.v11.5.txt",
		        "sequence_path": "698757.protein.sequences.v11.5.fa",
		        "enrichment_path": "698757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698757.protein.info.v11.5.txt",
		        "node_list_path": "698757.cluster.nodes.v11.5.txt",
		        "edge_list_path": "698757.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaHaemulonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Candida] haemulonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaHaemulonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45357.protein.sequences.v11.5.fa",
		        "enrichment_path": "45357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45357.protein.info.v11.5.txt",
		        "node_list_path": "45357.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorSaccharolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor saccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorSaccharolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351627.protein.sequences.v11.5.fa",
		        "enrichment_path": "351627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351627.protein.info.v11.5.txt",
		        "node_list_path": "351627.protein.complete.v11.5.txt"
		    }
		]
    )()

def MixiaOsmundaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mixia osmundae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MixiaOsmundaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34349.clusters.proteins.v11.5.txt",
		        "sequence_path": "34349.protein.sequences.v11.5.fa",
		        "enrichment_path": "34349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34349.protein.info.v11.5.txt",
		        "node_list_path": "34349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf23338(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_33_38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf23338", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797342.protein.info.v11.5.txt",
		        "node_list_path": "1797342.protein.complete.v11.5.txt"
		    }
		]
    )()

def DasypusNovemcinctus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dasypus novemcinctus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DasypusNovemcinctus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9361.protein.sequences.v11.5.fa",
		        "enrichment_path": "9361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9361.protein.info.v11.5.txt",
		        "node_list_path": "9361.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasEuvesicatoriaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas euvesicatoria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasEuvesicatoriaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "456327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "456327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "456327.clusters.proteins.v11.5.txt",
		        "sequence_path": "456327.protein.sequences.v11.5.fa",
		        "enrichment_path": "456327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "456327.protein.info.v11.5.txt",
		        "node_list_path": "456327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "456327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParageobacillusCaldoxylosilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parageobacillus caldoxylosilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParageobacillusCaldoxylosilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "81408.protein.sequences.v11.5.fa",
		        "enrichment_path": "81408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81408.protein.info.v11.5.txt",
		        "node_list_path": "81408.protein.complete.v11.5.txt"
		    }
		]
    )()

def DechlorosomaSuillumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dechlorosoma suillum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DechlorosomaSuillumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "640081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "640081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "640081.clusters.proteins.v11.5.txt",
		        "sequence_path": "640081.protein.sequences.v11.5.fa",
		        "enrichment_path": "640081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640081.protein.info.v11.5.txt",
		        "node_list_path": "640081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "640081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumLitoraleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium litorale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumLitoraleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "758802.clusters.info.v11.5.txt",
		        "cluster_tree_path": "758802.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "758802.clusters.proteins.v11.5.txt",
		        "sequence_path": "758802.protein.sequences.v11.5.fa",
		        "enrichment_path": "758802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "758802.protein.info.v11.5.txt",
		        "node_list_path": "758802.cluster.nodes.v11.5.txt",
		        "edge_list_path": "758802.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumUlceribovis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium ulceribovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumUlceribovis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121370.protein.info.v11.5.txt",
		        "node_list_path": "1121370.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRbg164011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_40_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802483.protein.info.v11.5.txt",
		        "node_list_path": "1802483.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaSpDd3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. DD3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpDd3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410619.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410619.protein.info.v11.5.txt",
		        "node_list_path": "1410619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpRoot135(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Root135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpRoot135", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736457.protein.info.v11.5.txt",
		        "node_list_path": "1736457.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumMageritense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium mageritense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumMageritense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1209984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1209984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1209984.protein.info.v11.5.txt",
		        "node_list_path": "1209984.protein.complete.v11.5.txt"
		    }
		]
    )()

def MelampsoraLariciPopulina98ag31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Melampsora larici-populina 98AG31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MelampsoraLariciPopulina98ag31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "747676.protein.sequences.v11.5.fa",
		        "enrichment_path": "747676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747676.protein.info.v11.5.txt",
		        "node_list_path": "747676.protein.complete.v11.5.txt"
		    }
		]
    )()

def DermacoccusNishinomiyaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dermacoccus nishinomiyaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DermacoccusNishinomiyaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1274.clusters.proteins.v11.5.txt",
		        "sequence_path": "1274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274.protein.info.v11.5.txt",
		        "node_list_path": "1274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinophagaTerraeKimAndJung2007Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga terrae Kim and Jung 2007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaTerraeKimAndJung2007Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "408074.clusters.info.v11.5.txt",
		        "cluster_tree_path": "408074.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "408074.clusters.proteins.v11.5.txt",
		        "sequence_path": "408074.protein.sequences.v11.5.fa",
		        "enrichment_path": "408074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408074.protein.info.v11.5.txt",
		        "node_list_path": "408074.cluster.nodes.v11.5.txt",
		        "edge_list_path": "408074.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumLentumNbrc107847(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium lentum NBRC 107847 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumLentumNbrc107847", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219033.protein.info.v11.5.txt",
		        "node_list_path": "1219033.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaSpRoot335Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. Root335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpRoot335Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736517.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736517.protein.info.v11.5.txt",
		        "node_list_path": "1736517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KosakoniaRadicincitansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kosakonia radicincitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KosakoniaRadicincitansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "283686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "283686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "283686.clusters.proteins.v11.5.txt",
		        "sequence_path": "283686.protein.sequences.v11.5.fa",
		        "enrichment_path": "283686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "283686.protein.info.v11.5.txt",
		        "node_list_path": "283686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "283686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VulcanibacillusModesticaldus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vulcanibacillus modesticaldus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulcanibacillusModesticaldus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "337097.protein.sequences.v11.5.fa",
		        "enrichment_path": "337097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "337097.protein.info.v11.5.txt",
		        "node_list_path": "337097.protein.complete.v11.5.txt"
		    }
		]
    )()

def RheinheimeraSalexigensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera salexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraSalexigensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1628148.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1628148.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1628148.clusters.proteins.v11.5.txt",
		        "sequence_path": "1628148.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628148.protein.info.v11.5.txt",
		        "node_list_path": "1628148.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1628148.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalophilicArchaeonJ07hx64(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return halophilic archaeon J07HX64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalophilicArchaeonJ07hx64", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1085028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1085028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1085028.protein.info.v11.5.txt",
		        "node_list_path": "1085028.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumScn6937(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium SCN 69-37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumScn6937", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660160.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660160.protein.info.v11.5.txt",
		        "node_list_path": "1660160.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusLactisCremoris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus lactis cremoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusLactisCremoris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "416870.protein.sequences.v11.5.fa",
		        "enrichment_path": "416870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416870.protein.info.v11.5.txt",
		        "node_list_path": "416870.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWs6BacteriumGw2011Gwf23915Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium GW2011_GWF2_39_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWs6BacteriumGw2011Gwf23915Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619100.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619100.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619100.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619100.protein.info.v11.5.txt",
		        "node_list_path": "1619100.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619100.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AkkermansiaGlycaniphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Akkermansia glycaniphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AkkermansiaGlycaniphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1679444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679444.protein.info.v11.5.txt",
		        "node_list_path": "1679444.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrobacterSp302(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sp. 302 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterSp302", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469595.protein.sequences.v11.5.fa",
		        "enrichment_path": "469595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469595.protein.info.v11.5.txt",
		        "node_list_path": "469595.protein.complete.v11.5.txt"
		    }
		]
    )()

def HippeaMaritimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hippea maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HippeaMaritimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "760142.clusters.info.v11.5.txt",
		        "cluster_tree_path": "760142.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "760142.clusters.proteins.v11.5.txt",
		        "sequence_path": "760142.protein.sequences.v11.5.fa",
		        "enrichment_path": "760142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "760142.protein.info.v11.5.txt",
		        "node_list_path": "760142.cluster.nodes.v11.5.txt",
		        "edge_list_path": "760142.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaSpTu14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma sp. TU-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaSpTu14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1898044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1898044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1898044.clusters.proteins.v11.5.txt",
		        "sequence_path": "1898044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898044.protein.info.v11.5.txt",
		        "node_list_path": "1898044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1898044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasOryzaePvOryzaeKacc10331Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae pv. oryzae KACC 10331 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasOryzaePvOryzaeKacc10331Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "291331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "291331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "291331.clusters.proteins.v11.5.txt",
		        "sequence_path": "291331.protein.sequences.v11.5.fa",
		        "enrichment_path": "291331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "291331.protein.info.v11.5.txt",
		        "node_list_path": "291331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "291331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumTrifoliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum trifolii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumTrifoliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5466.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5466.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5466.clusters.proteins.v11.5.txt",
		        "sequence_path": "5466.protein.sequences.v11.5.fa",
		        "enrichment_path": "5466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5466.protein.info.v11.5.txt",
		        "node_list_path": "5466.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5466.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSchleiferi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus schleiferi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSchleiferi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1295.protein.info.v11.5.txt",
		        "node_list_path": "1295.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpRoot483d1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. Root483D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpRoot483d1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736544.protein.info.v11.5.txt",
		        "node_list_path": "1736544.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27225(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27225 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27225", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1743144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743144.protein.info.v11.5.txt",
		        "node_list_path": "1743144.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSolventivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus solventivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSolventivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53463.clusters.proteins.v11.5.txt",
		        "sequence_path": "53463.protein.sequences.v11.5.fa",
		        "enrichment_path": "53463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53463.protein.info.v11.5.txt",
		        "node_list_path": "53463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesIakyrusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces iakyrus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesIakyrusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68219.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68219.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68219.clusters.proteins.v11.5.txt",
		        "sequence_path": "68219.protein.sequences.v11.5.fa",
		        "enrichment_path": "68219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68219.protein.info.v11.5.txt",
		        "node_list_path": "68219.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68219.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho202Full4212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_42_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full4212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798607.protein.info.v11.5.txt",
		        "node_list_path": "1798607.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpKle1280(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. KLE1280 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpKle1280", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "997829.protein.sequences.v11.5.fa",
		        "enrichment_path": "997829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997829.protein.info.v11.5.txt",
		        "node_list_path": "997829.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusJorgensenbacteriaBacteriumRifcsphigho202Full4520Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPHIGHO2_02_FULL_45_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsphigho202Full4520Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798470.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798470.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798470.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798470.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798470.protein.info.v11.5.txt",
		        "node_list_path": "1798470.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798470.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaceaeBacteriumUrhe0068(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium URHE0068 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaceaeBacteriumUrhe0068", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380348.protein.info.v11.5.txt",
		        "node_list_path": "1380348.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag1219(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag1219", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262772.protein.info.v11.5.txt",
		        "node_list_path": "1262772.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasBrassicacearumSubspBrassicacearumNfm421(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas brassicacearum subsp. brassicacearum NFM421 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBrassicacearumSubspBrassicacearumNfm421", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "994484.protein.sequences.v11.5.fa",
		        "enrichment_path": "994484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "994484.protein.info.v11.5.txt",
		        "node_list_path": "994484.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzotobacterChroococcumNcimb8003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azotobacter chroococcum NCIMB 8003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzotobacterChroococcumNcimb8003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1328314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1328314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1328314.clusters.proteins.v11.5.txt",
		        "sequence_path": "1328314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1328314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1328314.protein.info.v11.5.txt",
		        "node_list_path": "1328314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1328314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusKawachiiIfo4308Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus kawachii IFO 4308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusKawachiiIfo4308Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033177.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033177.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033177.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033177.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033177.protein.info.v11.5.txt",
		        "node_list_path": "1033177.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033177.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriovoraxSpMedpeSwdeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. MedPE-SWde Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriovoraxSpMedpeSwdeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1860085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1860085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1860085.clusters.proteins.v11.5.txt",
		        "sequence_path": "1860085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860085.protein.info.v11.5.txt",
		        "node_list_path": "1860085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1860085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisBaekryungensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis baekryungensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisBaekryungensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123270.protein.info.v11.5.txt",
		        "node_list_path": "1123270.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaCt18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Salmonella enterica CT18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaCt18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "220341.clusters.info.v11.0.txt",
		        "cluster_tree_path": "220341.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "220341.clusters.proteins.v11.0.txt",
		        "sequence_path": "220341.protein.sequences.v11.0.fa",
		        "enrichment_path": "220341.protein.enrichment.terms.v11.0.txt",
		        "info_path": "220341.protein.info.v11.0.txt",
		        "node_list_path": "220341.cluster.nodes.v11.0.txt",
		        "edge_list_path": "220341.protein.cluster.v11.0.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacterium4019(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 40-19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacterium4019", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895705.protein.info.v11.5.txt",
		        "node_list_path": "1895705.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpMcba15012(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpMcba15012", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1898738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898738.protein.info.v11.5.txt",
		        "node_list_path": "1898738.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiAtcc8739(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli ATCC8739 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiAtcc8739", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "481805.protein.sequences.v11.5.fa",
		        "enrichment_path": "481805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481805.protein.info.v11.5.txt",
		        "node_list_path": "481805.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSp166amftsu(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 166amftsu graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp166amftsu", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761753.protein.info.v11.5.txt",
		        "node_list_path": "1761753.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumDg23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium DG_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumDg23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703414.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703414.protein.info.v11.5.txt",
		        "node_list_path": "1703414.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumTwa4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium TWA4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumTwa4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392836.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392836.protein.info.v11.5.txt",
		        "node_list_path": "1392836.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarboxydothermusPertinaxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carboxydothermus pertinax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarboxydothermusPertinaxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "870242.clusters.info.v11.5.txt",
		        "cluster_tree_path": "870242.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "870242.clusters.proteins.v11.5.txt",
		        "sequence_path": "870242.protein.sequences.v11.5.fa",
		        "enrichment_path": "870242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "870242.protein.info.v11.5.txt",
		        "node_list_path": "870242.cluster.nodes.v11.5.txt",
		        "edge_list_path": "870242.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumGw2011Gwa24416Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011_GWA2_44_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011Gwa24416Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619110.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619110.protein.info.v11.5.txt",
		        "node_list_path": "1619110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivivaxIsoporae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax isoporae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxIsoporae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449351.protein.info.v11.5.txt",
		        "node_list_path": "1449351.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoplanesSpTfc3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes sp. TFC3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesSpTfc3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1710355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1710355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1710355.protein.info.v11.5.txt",
		        "node_list_path": "1710355.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAdlerbacteriaBacteriumRifoxyc1Full4826Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFOXYC1_FULL_48_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifoxyc1Full4826Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797247.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797247.protein.info.v11.5.txt",
		        "node_list_path": "1797247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerpentinomonasMccroryi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serpentinomonas mccroryi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerpentinomonasMccroryi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1458426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458426.protein.info.v11.5.txt",
		        "node_list_path": "1458426.protein.complete.v11.5.txt"
		    }
		]
    )()

def RobiginitaleaMyxolifaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Robiginitalea myxolifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RobiginitaleaMyxolifaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "400055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "400055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "400055.clusters.proteins.v11.5.txt",
		        "sequence_path": "400055.protein.sequences.v11.5.fa",
		        "enrichment_path": "400055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400055.protein.info.v11.5.txt",
		        "node_list_path": "400055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "400055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusAnaerobiusVpi4330Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius VPI4330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusAnaerobiusVpi4330Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035196.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035196.protein.info.v11.5.txt",
		        "node_list_path": "1035196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc04h06Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC04H06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc04h06Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1581050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1581050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1581050.clusters.proteins.v11.5.txt",
		        "sequence_path": "1581050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581050.protein.info.v11.5.txt",
		        "node_list_path": "1581050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1581050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaUa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaUa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005057.protein.info.v11.5.txt",
		        "node_list_path": "1005057.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaViridis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora viridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaViridis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "471857.protein.sequences.v11.5.fa",
		        "enrichment_path": "471857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "471857.protein.info.v11.5.txt",
		        "node_list_path": "471857.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusLitoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLitoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "152268.protein.sequences.v11.5.fa",
		        "enrichment_path": "152268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "152268.protein.info.v11.5.txt",
		        "node_list_path": "152268.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotogaPetrophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga petrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaPetrophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "390874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "390874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "390874.clusters.proteins.v11.5.txt",
		        "sequence_path": "390874.protein.sequences.v11.5.fa",
		        "enrichment_path": "390874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390874.protein.info.v11.5.txt",
		        "node_list_path": "390874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "390874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusGlycinifermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus glycinifermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGlycinifermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1664069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1664069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1664069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1664069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1664069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1664069.protein.info.v11.5.txt",
		        "node_list_path": "1664069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1664069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpExBiomphalariaGlabrataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. (ex Biomphalaria glabrata) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpExBiomphalariaGlabrataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1749074.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1749074.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1749074.clusters.proteins.v11.5.txt",
		        "sequence_path": "1749074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1749074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1749074.protein.info.v11.5.txt",
		        "node_list_path": "1749074.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1749074.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfamplusMagnetovallimortis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfamplus magnetovallimortis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfamplusMagnetovallimortis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246637.protein.info.v11.5.txt",
		        "node_list_path": "1246637.protein.complete.v11.5.txt"
		    }
		]
    )()

def GloeophyllumTrabeumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gloeophyllum trabeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeophyllumTrabeumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "104355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "104355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "104355.clusters.proteins.v11.5.txt",
		        "sequence_path": "104355.protein.sequences.v11.5.fa",
		        "enrichment_path": "104355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104355.protein.info.v11.5.txt",
		        "node_list_path": "104355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "104355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MadurellaMycetomatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Madurella mycetomatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MadurellaMycetomatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "100816.protein.sequences.v11.5.fa",
		        "enrichment_path": "100816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "100816.protein.info.v11.5.txt",
		        "node_list_path": "100816.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrnithobacteriumRhinotracheale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ornithobacterium rhinotracheale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithobacteriumRhinotracheale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "867902.protein.sequences.v11.5.fa",
		        "enrichment_path": "867902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867902.protein.info.v11.5.txt",
		        "node_list_path": "867902.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag161Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:161 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag161Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262881.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262881.protein.info.v11.5.txt",
		        "node_list_path": "1262881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosopumilusSpAr2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. AR2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopumilusSpAr2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229909.protein.info.v11.5.txt",
		        "node_list_path": "1229909.protein.complete.v11.5.txt"
		    }
		]
    )()

def DiplorickettsiaMassiliensis20bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Diplorickettsia massiliensis 20B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiplorickettsiaMassiliensis20bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1156986.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1156986.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1156986.clusters.proteins.v11.5.txt",
		        "sequence_path": "1156986.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156986.protein.info.v11.5.txt",
		        "node_list_path": "1156986.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1156986.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCns606Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNS606 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCns606Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1305837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1305837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1305837.clusters.proteins.v11.5.txt",
		        "sequence_path": "1305837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305837.protein.info.v11.5.txt",
		        "node_list_path": "1305837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1305837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacterium3919Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 39-19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacterium3919Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895834.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895834.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895834.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895834.protein.info.v11.5.txt",
		        "node_list_path": "1895834.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895834.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumHaoranii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium haoranii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumHaoranii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "683124.protein.sequences.v11.5.fa",
		        "enrichment_path": "683124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683124.protein.info.v11.5.txt",
		        "node_list_path": "683124.protein.complete.v11.5.txt"
		    }
		]
    )()

def HeliconiusMelpomeneCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Heliconius melpomene Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeliconiusMelpomeneCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34740.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34740.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34740.clusters.proteins.v11.5.txt",
		        "sequence_path": "34740.protein.sequences.v11.5.fa",
		        "enrichment_path": "34740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34740.protein.info.v11.5.txt",
		        "node_list_path": "34740.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34740.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DasaniaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dasania marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DasaniaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121374.protein.info.v11.5.txt",
		        "node_list_path": "1121374.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1024126(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_41_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024126", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805308.protein.info.v11.5.txt",
		        "node_list_path": "1805308.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot274Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root274 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot274Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736507.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736507.protein.info.v11.5.txt",
		        "node_list_path": "1736507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CastellaniellaCaeniNbrc101664(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Castellaniella caeni NBRC 101664 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CastellaniellaCaeniNbrc101664", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349760.protein.info.v11.5.txt",
		        "node_list_path": "1349760.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytophthoraSojaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora sojae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraSojaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67593.clusters.proteins.v11.5.txt",
		        "sequence_path": "67593.protein.sequences.v11.5.fa",
		        "enrichment_path": "67593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67593.protein.info.v11.5.txt",
		        "node_list_path": "67593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasAxonopodisCitriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis citri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasAxonopodisCitriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "190486.clusters.info.v11.5.txt",
		        "cluster_tree_path": "190486.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "190486.clusters.proteins.v11.5.txt",
		        "sequence_path": "190486.protein.sequences.v11.5.fa",
		        "enrichment_path": "190486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190486.protein.info.v11.5.txt",
		        "node_list_path": "190486.cluster.nodes.v11.5.txt",
		        "edge_list_path": "190486.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumBal38(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium BAL38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumBal38", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391598.protein.sequences.v11.5.fa",
		        "enrichment_path": "391598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391598.protein.info.v11.5.txt",
		        "node_list_path": "391598.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumGw2011Gwb1446(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB1_44_6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb1446", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618384.protein.info.v11.5.txt",
		        "node_list_path": "1618384.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaLongicatenaAgr2136(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dorea longicatena AGR2136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaLongicatenaAgr2136", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280698.protein.info.v11.5.txt",
		        "node_list_path": "1280698.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharopolysporaAntimicrobicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharopolyspora antimicrobica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharopolysporaAntimicrobicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "455193.clusters.info.v11.5.txt",
		        "cluster_tree_path": "455193.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "455193.clusters.proteins.v11.5.txt",
		        "sequence_path": "455193.protein.sequences.v11.5.fa",
		        "enrichment_path": "455193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "455193.protein.info.v11.5.txt",
		        "node_list_path": "455193.cluster.nodes.v11.5.txt",
		        "edge_list_path": "455193.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TropicimonasIsoalkanivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tropicimonas isoalkanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TropicimonasIsoalkanivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "441112.protein.sequences.v11.5.fa",
		        "enrichment_path": "441112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441112.protein.info.v11.5.txt",
		        "node_list_path": "441112.protein.complete.v11.5.txt"
		    }
		]
    )()

def EuryarchaeotaArchaeonRbg19ftCombo6917Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_19FT_COMBO_69_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EuryarchaeotaArchaeonRbg19ftCombo6917Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797984.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797984.protein.info.v11.5.txt",
		        "node_list_path": "1797984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeitlerinemaSpPcc7407(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC7407 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeitlerinemaSpPcc7407", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173025.protein.info.v11.5.txt",
		        "node_list_path": "1173025.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaCaviae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila caviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaCaviae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "227941.protein.sequences.v11.5.fa",
		        "enrichment_path": "227941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227941.protein.info.v11.5.txt",
		        "node_list_path": "227941.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosococcusWatsonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosococcus watsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosococcusWatsonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "105559.protein.sequences.v11.5.fa",
		        "enrichment_path": "105559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105559.protein.info.v11.5.txt",
		        "node_list_path": "105559.protein.complete.v11.5.txt"
		    }
		]
    )()

def LabilibacterAurantiacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Labilibacter aurantiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabilibacterAurantiacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849719.protein.info.v11.5.txt",
		        "node_list_path": "1849719.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurimonasAutotrophica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas autotrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasAutotrophica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "563040.protein.sequences.v11.5.fa",
		        "enrichment_path": "563040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563040.protein.info.v11.5.txt",
		        "node_list_path": "563040.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetalesBacteriumSpiro09(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetalesBacteriumSpiro09", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674865.protein.info.v11.5.txt",
		        "node_list_path": "1674865.protein.complete.v11.5.txt"
		    }
		]
    )()

def TepidimonasFonticaldi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tepidimonas fonticaldi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidimonasFonticaldi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1101373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101373.protein.info.v11.5.txt",
		        "node_list_path": "1101373.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifoxyc1Full3814Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFOXYC1_FULL_38_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifoxyc1Full3814Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802089.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802089.protein.info.v11.5.txt",
		        "node_list_path": "1802089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfobiumNarugense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfobium narugense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfobiumNarugense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "747365.protein.sequences.v11.5.fa",
		        "enrichment_path": "747365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747365.protein.info.v11.5.txt",
		        "node_list_path": "747365.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhinopithecusRoxellana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhinopithecus roxellana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhinopithecusRoxellana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61622.protein.sequences.v11.5.fa",
		        "enrichment_path": "61622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61622.protein.info.v11.5.txt",
		        "node_list_path": "61622.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTuberculosisVariantCaprae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant caprae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTuberculosisVariantCaprae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "115862.protein.sequences.v11.5.fa",
		        "enrichment_path": "115862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115862.protein.info.v11.5.txt",
		        "node_list_path": "115862.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParvimonasSpKa00067(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parvimonas sp. KA00067 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvimonasSpKa00067", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1588755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588755.protein.info.v11.5.txt",
		        "node_list_path": "1588755.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasBrassicacearum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas brassicacearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBrassicacearum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930166.protein.sequences.v11.5.fa",
		        "enrichment_path": "930166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930166.protein.info.v11.5.txt",
		        "node_list_path": "930166.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp2915Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 29_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp2915Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896982.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896982.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896982.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896982.protein.info.v11.5.txt",
		        "node_list_path": "1896982.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896982.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodoferaxSaidenbachensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodoferax saidenbachensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodoferaxSaidenbachensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1484693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484693.protein.info.v11.5.txt",
		        "node_list_path": "1484693.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumXpb1003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XPB1003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumXpb1003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520825.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520825.protein.info.v11.5.txt",
		        "node_list_path": "1520825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorhodospiraHalochlorisStrA(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorhodospira halochloris str. A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorhodospiraHalochlorisStrA", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354791.protein.info.v11.5.txt",
		        "node_list_path": "1354791.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanicoccusSagamiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicoccus sagamiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicoccusSagamiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "716816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "716816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "716816.clusters.proteins.v11.5.txt",
		        "sequence_path": "716816.protein.sequences.v11.5.fa",
		        "enrichment_path": "716816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "716816.protein.info.v11.5.txt",
		        "node_list_path": "716816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "716816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4204(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4204 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4204", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977884.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977884.protein.info.v11.5.txt",
		        "node_list_path": "1977884.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterUpsaliensisJv21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter upsaliensis JV21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterUpsaliensisJv21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888826.clusters.proteins.v11.5.txt",
		        "sequence_path": "888826.protein.sequences.v11.5.fa",
		        "enrichment_path": "888826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888826.protein.info.v11.5.txt",
		        "node_list_path": "888826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CytophagaceaeBacteriumScn5212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cytophagaceae bacterium SCN 52-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CytophagaceaeBacteriumScn5212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660162.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660162.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660162.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660162.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660162.protein.info.v11.5.txt",
		        "node_list_path": "1660162.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660162.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquimonasVoraii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquimonas voraii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimonasVoraii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "265719.protein.sequences.v11.5.fa",
		        "enrichment_path": "265719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "265719.protein.info.v11.5.txt",
		        "node_list_path": "265719.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesSpCag409(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides sp. CAG:409 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesSpCag409", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262913.protein.info.v11.5.txt",
		        "node_list_path": "1262913.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumMalmoenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium malmoense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumMalmoenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780.protein.info.v11.5.txt",
		        "node_list_path": "1780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfatitaleaTepidiphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfatitalea tepidiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfatitaleaTepidiphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1185843.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185843.protein.info.v11.5.txt",
		        "node_list_path": "1185843.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumChlorophenolicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum chlorophenolicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumChlorophenolicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "211589.clusters.info.v11.5.txt",
		        "cluster_tree_path": "211589.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "211589.clusters.proteins.v11.5.txt",
		        "sequence_path": "211589.protein.sequences.v11.5.fa",
		        "enrichment_path": "211589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211589.protein.info.v11.5.txt",
		        "node_list_path": "211589.cluster.nodes.v11.5.txt",
		        "edge_list_path": "211589.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParachlamydiaSpC2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parachlamydia sp. C2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParachlamydiaSpC2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1414722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414722.protein.info.v11.5.txt",
		        "node_list_path": "1414722.protein.complete.v11.5.txt"
		    }
		]
    )()

def GramellaPortivictoriaeDsm23547Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gramella portivictoriae DSM 23547 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaPortivictoriaeDsm23547Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121932.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121932.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121932.protein.info.v11.5.txt",
		        "node_list_path": "1121932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VittaformaCorneaeAtcc50505(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vittaforma corneae ATCC 50505 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VittaformaCorneaeAtcc50505", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "993615.protein.sequences.v11.5.fa",
		        "enrichment_path": "993615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "993615.protein.info.v11.5.txt",
		        "node_list_path": "993615.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfomicrobiumBaculatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium baculatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfomicrobiumBaculatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525897.clusters.proteins.v11.5.txt",
		        "sequence_path": "525897.protein.sequences.v11.5.fa",
		        "enrichment_path": "525897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525897.protein.info.v11.5.txt",
		        "node_list_path": "525897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpLc363(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LC363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpLc363", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120705.protein.info.v11.5.txt",
		        "node_list_path": "1120705.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpLeaf58Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpLeaf58Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736226.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736226.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736226.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736226.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736226.protein.info.v11.5.txt",
		        "node_list_path": "1736226.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736226.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioFischeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio fischeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioFischeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "312309.protein.sequences.v11.5.fa",
		        "enrichment_path": "312309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "312309.protein.info.v11.5.txt",
		        "node_list_path": "312309.protein.complete.v11.5.txt"
		    }
		]
    )()

def MortierellaVerticillataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mortierella verticillata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MortierellaVerticillataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "78898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "78898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "78898.clusters.proteins.v11.5.txt",
		        "sequence_path": "78898.protein.sequences.v11.5.fa",
		        "enrichment_path": "78898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78898.protein.info.v11.5.txt",
		        "node_list_path": "78898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "78898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GopherusAgassiziiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gopherus agassizii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GopherusAgassiziiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "38772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "38772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "38772.clusters.proteins.v11.5.txt",
		        "sequence_path": "38772.protein.sequences.v11.5.fa",
		        "enrichment_path": "38772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38772.protein.info.v11.5.txt",
		        "node_list_path": "38772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "38772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidocellaSpMxAz02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidocella sp. MX-AZ02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidocellaSpMxAz02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1214225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214225.protein.info.v11.5.txt",
		        "node_list_path": "1214225.protein.complete.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterXylinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterXylinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1296990.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1296990.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1296990.clusters.proteins.v11.5.txt",
		        "sequence_path": "1296990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296990.protein.info.v11.5.txt",
		        "node_list_path": "1296990.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1296990.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalidrisPygmaeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Calidris pygmaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalidrisPygmaeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "425635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "425635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "425635.clusters.proteins.v11.5.txt",
		        "sequence_path": "425635.protein.sequences.v11.5.fa",
		        "enrichment_path": "425635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425635.protein.info.v11.5.txt",
		        "node_list_path": "425635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "425635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifoxyd2Full369Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFOXYD2_FULL_36_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifoxyd2Full369Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802338.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802338.protein.info.v11.5.txt",
		        "node_list_path": "1802338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpMs1601Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. MS1601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpMs1601Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1936029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1936029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1936029.clusters.proteins.v11.5.txt",
		        "sequence_path": "1936029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1936029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1936029.protein.info.v11.5.txt",
		        "node_list_path": "1936029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1936029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerovibrioSpJc8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerovibrio sp. JC8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerovibrioSpJc8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1240085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1240085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1240085.clusters.proteins.v11.5.txt",
		        "sequence_path": "1240085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1240085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1240085.protein.info.v11.5.txt",
		        "node_list_path": "1240085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1240085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhyllobacteriumSpYr531(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. YR531 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhyllobacteriumSpYr531", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144343.protein.info.v11.5.txt",
		        "node_list_path": "1144343.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsplowo212Full4028(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_12_FULL_40_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo212Full4028", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797887.protein.info.v11.5.txt",
		        "node_list_path": "1797887.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonasJohnsonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas johnsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasJohnsonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280950.protein.info.v11.5.txt",
		        "node_list_path": "1280950.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMjm8645Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MJM8645 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMjm8645Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120523.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120523.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120523.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120523.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120523.protein.info.v11.5.txt",
		        "node_list_path": "1120523.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120523.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsplowo201Full4534(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_01_FULL_45_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo201Full4534", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798351.protein.info.v11.5.txt",
		        "node_list_path": "1798351.protein.complete.v11.5.txt"
		    }
		]
    )()

def GilliamellaSpNG2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gilliamella sp. N-G2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilliamellaSpNG2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1970471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1970471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1970471.clusters.proteins.v11.5.txt",
		        "sequence_path": "1970471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970471.protein.info.v11.5.txt",
		        "node_list_path": "1970471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1970471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterCryoconitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter cryoconitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterCryoconitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "188932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "188932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "188932.clusters.proteins.v11.5.txt",
		        "sequence_path": "188932.protein.sequences.v11.5.fa",
		        "enrichment_path": "188932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188932.protein.info.v11.5.txt",
		        "node_list_path": "188932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "188932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinimonasTaiwanensisDsm18899(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinimonas taiwanensis DSM 18899 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinimonasTaiwanensisDsm18899", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121279.protein.info.v11.5.txt",
		        "node_list_path": "1121279.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4924(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_02_FULL_49_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4924", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817834.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817834.protein.info.v11.5.txt",
		        "node_list_path": "1817834.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaedibacterAcanthamoebae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caedibacter acanthamoebae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaedibacterAcanthamoebae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "244581.protein.sequences.v11.5.fa",
		        "enrichment_path": "244581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244581.protein.info.v11.5.txt",
		        "node_list_path": "244581.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4241Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_42_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4241Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802759.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802759.protein.info.v11.5.txt",
		        "node_list_path": "1802759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanomassiliicoccusIntestinalisIssoireMx1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomassiliicoccus intestinalis Issoire-Mx1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanomassiliicoccusIntestinalisIssoireMx1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1295009.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1295009.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1295009.clusters.proteins.v11.5.txt",
		        "sequence_path": "1295009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1295009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1295009.protein.info.v11.5.txt",
		        "node_list_path": "1295009.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1295009.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AromatoleumAromaticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aromatoleum aromaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AromatoleumAromaticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "76114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "76114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "76114.clusters.proteins.v11.5.txt",
		        "sequence_path": "76114.protein.sequences.v11.5.fa",
		        "enrichment_path": "76114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76114.protein.info.v11.5.txt",
		        "node_list_path": "76114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "76114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumSpZwu0009Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. ZWU0009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumSpZwu0009Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1224749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1224749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1224749.clusters.proteins.v11.5.txt",
		        "sequence_path": "1224749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224749.protein.info.v11.5.txt",
		        "node_list_path": "1224749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1224749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VulcanisaetaSpJchs4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vulcanisaeta sp. JCHS_4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulcanisaetaSpJchs4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1714253.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1714253.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1714253.clusters.proteins.v11.5.txt",
		        "sequence_path": "1714253.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714253.protein.info.v11.5.txt",
		        "node_list_path": "1714253.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1714253.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpLeaf139(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. Leaf139 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpLeaf139", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736272.protein.info.v11.5.txt",
		        "node_list_path": "1736272.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerobiospirillumSucciniciproducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobiospirillum succiniciproducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobiospirillumSucciniciproducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120988.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120988.protein.info.v11.5.txt",
		        "node_list_path": "1120988.protein.complete.v11.5.txt"
		    }
		]
    )()

def GramellaPortivictoriaeDsm23547(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gramella portivictoriae DSM 23547 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaPortivictoriaeDsm23547", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121932.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121932.protein.info.v11.5.txt",
		        "node_list_path": "1121932.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeorhizobiumGalegaeBvOfficinalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae bv. officinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorhizobiumGalegaeBvOfficinalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "323656.protein.sequences.v11.5.fa",
		        "enrichment_path": "323656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323656.protein.info.v11.5.txt",
		        "node_list_path": "323656.protein.complete.v11.5.txt"
		    }
		]
    )()

def LiberibacterCrescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter crescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LiberibacterCrescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1215343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215343.protein.info.v11.5.txt",
		        "node_list_path": "1215343.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaLongicatenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea longicatena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaLongicatenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "88431.clusters.info.v11.5.txt",
		        "cluster_tree_path": "88431.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "88431.clusters.proteins.v11.5.txt",
		        "sequence_path": "88431.protein.sequences.v11.5.fa",
		        "enrichment_path": "88431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "88431.protein.info.v11.5.txt",
		        "node_list_path": "88431.cluster.nodes.v11.5.txt",
		        "edge_list_path": "88431.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusZopfiiNbrc100606Jcm9919(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus zopfii NBRC 100606 JCM 9919 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusZopfiiNbrc100606Jcm9919", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219030.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219030.protein.info.v11.5.txt",
		        "node_list_path": "1219030.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSpPpcgb2223(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. PPCGB 2223 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSpPpcgb2223", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1886027.protein.sequences.v11.5.fa",
		        "enrichment_path": "1886027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1886027.protein.info.v11.5.txt",
		        "node_list_path": "1886027.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusMulundensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus mulundensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusMulundensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1810919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1810919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1810919.clusters.proteins.v11.5.txt",
		        "sequence_path": "1810919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1810919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1810919.protein.info.v11.5.txt",
		        "node_list_path": "1810919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1810919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FalsirhodobacterSpAlg1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Falsirhodobacter sp. alg1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FalsirhodobacterSpAlg1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1472418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1472418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1472418.protein.info.v11.5.txt",
		        "node_list_path": "1472418.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterLwoffiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterLwoffiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28090.clusters.proteins.v11.5.txt",
		        "sequence_path": "28090.protein.sequences.v11.5.fa",
		        "enrichment_path": "28090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28090.protein.info.v11.5.txt",
		        "node_list_path": "28090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumSaccharovorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum saccharovorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumSaccharovorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227484.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227484.protein.info.v11.5.txt",
		        "node_list_path": "1227484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpEs1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. ES1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpEs1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1396858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1396858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1396858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1396858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1396858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1396858.protein.info.v11.5.txt",
		        "node_list_path": "1396858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1396858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumCg1023572(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG1_02_35_72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumCg1023572", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805158.protein.info.v11.5.txt",
		        "node_list_path": "1805158.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachyspiraAlvinipulliAtcc51933(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira alvinipulli ATCC 51933 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraAlvinipulliAtcc51933", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408430.protein.info.v11.5.txt",
		        "node_list_path": "1408430.protein.complete.v11.5.txt"
		    }
		]
    )()

def KazachstaniaNaganishiiCbs8797Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania naganishii CBS 8797 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KazachstaniaNaganishiiCbs8797Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071383.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071383.protein.info.v11.5.txt",
		        "node_list_path": "1071383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaAlkanivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia alkanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaAlkanivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1027371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1027371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1027371.clusters.proteins.v11.5.txt",
		        "sequence_path": "1027371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1027371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1027371.protein.info.v11.5.txt",
		        "node_list_path": "1027371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1027371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoplasmaChauliocolaAtcc49578(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesoplasma chauliocola ATCC 49578 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoplasmaChauliocolaAtcc49578", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336232.protein.info.v11.5.txt",
		        "node_list_path": "1336232.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwf24618Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWF2_46_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwf24618Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618540.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618540.protein.info.v11.5.txt",
		        "node_list_path": "1618540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisTerraeSubspTerraeNbrc15098Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis terrae subsp. terrae NBRC 15098 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisTerraeSubspTerraeNbrc15098Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219058.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219058.protein.info.v11.5.txt",
		        "node_list_path": "1219058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaEutrophaH16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia eutropha H16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaEutrophaH16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "381666.clusters.info.v11.5.txt",
		        "cluster_tree_path": "381666.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "381666.clusters.proteins.v11.5.txt",
		        "sequence_path": "381666.protein.sequences.v11.5.fa",
		        "enrichment_path": "381666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381666.protein.info.v11.5.txt",
		        "node_list_path": "381666.cluster.nodes.v11.5.txt",
		        "edge_list_path": "381666.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurovumSpEnrichmentCultureCloneC5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum sp. enrichment culture clone C5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurovumSpEnrichmentCultureCloneC5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "497650.protein.sequences.v11.5.fa",
		        "enrichment_path": "497650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "497650.protein.info.v11.5.txt",
		        "node_list_path": "497650.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasEnteropelogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas enteropelogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasEnteropelogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29489.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29489.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29489.clusters.proteins.v11.5.txt",
		        "sequence_path": "29489.protein.sequences.v11.5.fa",
		        "enrichment_path": "29489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29489.protein.info.v11.5.txt",
		        "node_list_path": "29489.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29489.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAfricanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio africanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAfricanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "690850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "690850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "690850.clusters.proteins.v11.5.txt",
		        "sequence_path": "690850.protein.sequences.v11.5.fa",
		        "enrichment_path": "690850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690850.protein.info.v11.5.txt",
		        "node_list_path": "690850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "690850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EhrlichiaCanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EhrlichiaCanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "269484.protein.sequences.v11.5.fa",
		        "enrichment_path": "269484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269484.protein.info.v11.5.txt",
		        "node_list_path": "269484.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusOceanisediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus oceanisediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusOceanisediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196031.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196031.protein.info.v11.5.txt",
		        "node_list_path": "1196031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumAgaricidamnosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium agaricidamnosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumAgaricidamnosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349767.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349767.protein.info.v11.5.txt",
		        "node_list_path": "1349767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumIntestinaleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium intestinale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumIntestinaleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1294142.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1294142.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1294142.clusters.proteins.v11.5.txt",
		        "sequence_path": "1294142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294142.protein.info.v11.5.txt",
		        "node_list_path": "1294142.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1294142.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalothrixSpPcc7103Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC7103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalothrixSpPcc7103Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32057.clusters.proteins.v11.5.txt",
		        "sequence_path": "32057.protein.sequences.v11.5.fa",
		        "enrichment_path": "32057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32057.protein.info.v11.5.txt",
		        "node_list_path": "32057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurihydrogenibiumSubterraneumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium subterraneum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurihydrogenibiumSubterraneumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123325.protein.info.v11.5.txt",
		        "node_list_path": "1123325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasBenzenivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas benzenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBenzenivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "556533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "556533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "556533.clusters.proteins.v11.5.txt",
		        "sequence_path": "556533.protein.sequences.v11.5.fa",
		        "enrichment_path": "556533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556533.protein.info.v11.5.txt",
		        "node_list_path": "556533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "556533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumRifoxyb1Full4423(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFOXYB1_FULL_44_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifoxyb1Full4423", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797263.protein.info.v11.5.txt",
		        "node_list_path": "1797263.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumPiperiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium piperi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumPiperiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "558152.clusters.info.v11.5.txt",
		        "cluster_tree_path": "558152.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "558152.clusters.proteins.v11.5.txt",
		        "sequence_path": "558152.protein.sequences.v11.5.fa",
		        "enrichment_path": "558152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558152.protein.info.v11.5.txt",
		        "node_list_path": "558152.cluster.nodes.v11.5.txt",
		        "edge_list_path": "558152.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyaloperonosporaArabidopsidisEmoy2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyaloperonospora arabidopsidis Emoy2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyaloperonosporaArabidopsidisEmoy2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "559515.protein.sequences.v11.5.fa",
		        "enrichment_path": "559515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559515.protein.info.v11.5.txt",
		        "node_list_path": "559515.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumNctc2916(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum NCTC2916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumNctc2916", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445335.protein.sequences.v11.5.fa",
		        "enrichment_path": "445335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445335.protein.info.v11.5.txt",
		        "node_list_path": "445335.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaAlcalifaciensDsm30120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens DSM 30120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaAlcalifaciensDsm30120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "520999.protein.sequences.v11.5.fa",
		        "enrichment_path": "520999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "520999.protein.info.v11.5.txt",
		        "node_list_path": "520999.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumDg72(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumDg72", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703764.protein.info.v11.5.txt",
		        "node_list_path": "1703764.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9312Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9312Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "74546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "74546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "74546.clusters.proteins.v11.5.txt",
		        "sequence_path": "74546.protein.sequences.v11.5.fa",
		        "enrichment_path": "74546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74546.protein.info.v11.5.txt",
		        "node_list_path": "74546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "74546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SeriolaDumerili(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Seriola dumerili graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SeriolaDumerili", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "41447.protein.sequences.v11.5.fa",
		        "enrichment_path": "41447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41447.protein.info.v11.5.txt",
		        "node_list_path": "41447.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioCrossotus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio crossotus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioCrossotus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "511680.protein.sequences.v11.5.fa",
		        "enrichment_path": "511680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511680.protein.info.v11.5.txt",
		        "node_list_path": "511680.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsplowo201Full5024Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO2_01_FULL_50_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo201Full5024Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801829.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801829.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801829.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801829.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801829.protein.info.v11.5.txt",
		        "node_list_path": "1801829.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801829.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp11mfCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 11MF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp11mfCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1169146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1169146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1169146.clusters.proteins.v11.5.txt",
		        "sequence_path": "1169146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169146.protein.info.v11.5.txt",
		        "node_list_path": "1169146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1169146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptobacillusHongkongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptobacillus hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptobacillusHongkongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1162717.protein.sequences.v11.5.fa",
		        "enrichment_path": "1162717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1162717.protein.info.v11.5.txt",
		        "node_list_path": "1162717.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumGw2011Gwb14311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWB1_43_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwb14311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618446.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618446.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618446.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618446.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618446.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618446.protein.info.v11.5.txt",
		        "node_list_path": "1618446.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618446.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesLianchengensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides lianchengensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesLianchengensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1045774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045774.protein.info.v11.5.txt",
		        "node_list_path": "1045774.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenedentesBacteriumJgi0000039J10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenedentes bacterium JGI 0000039-J10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenedentesBacteriumJgi0000039J10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1046982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046982.protein.info.v11.5.txt",
		        "node_list_path": "1046982.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmodiumVivaxSal1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium vivax Sal-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumVivaxSal1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "126793.protein.sequences.v11.5.fa",
		        "enrichment_path": "126793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "126793.protein.info.v11.5.txt",
		        "node_list_path": "126793.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterUrsingii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter ursingii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterUrsingii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "981336.protein.sequences.v11.5.fa",
		        "enrichment_path": "981336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981336.protein.info.v11.5.txt",
		        "node_list_path": "981336.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenolepisDiminutaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenolepis diminuta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenolepisDiminutaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6216.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6216.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6216.clusters.proteins.v11.5.txt",
		        "sequence_path": "6216.protein.sequences.v11.5.fa",
		        "enrichment_path": "6216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6216.protein.info.v11.5.txt",
		        "node_list_path": "6216.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6216.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpHmp27Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. HMP27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpHmp27Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1487921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1487921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1487921.clusters.proteins.v11.5.txt",
		        "sequence_path": "1487921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1487921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1487921.protein.info.v11.5.txt",
		        "node_list_path": "1487921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1487921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MahellaAustraliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mahella australiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MahellaAustraliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "697281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "697281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "697281.clusters.proteins.v11.5.txt",
		        "sequence_path": "697281.protein.sequences.v11.5.fa",
		        "enrichment_path": "697281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "697281.protein.info.v11.5.txt",
		        "node_list_path": "697281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "697281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrapisisporaBlattaeCbs6284Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora blattae CBS 6284 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrapisisporaBlattaeCbs6284Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071380.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071380.protein.info.v11.5.txt",
		        "node_list_path": "1071380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumRm5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium RM5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumRm5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1200721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200721.protein.info.v11.5.txt",
		        "node_list_path": "1200721.protein.complete.v11.5.txt"
		    }
		]
    )()

def CloacimonetesBacteriumWwei01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium WWEI_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CloacimonetesBacteriumWwei01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674914.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674914.protein.info.v11.5.txt",
		        "node_list_path": "1674914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusGnavusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus gnavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusGnavusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411470.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411470.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411470.clusters.proteins.v11.5.txt",
		        "sequence_path": "411470.protein.sequences.v11.5.fa",
		        "enrichment_path": "411470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411470.protein.info.v11.5.txt",
		        "node_list_path": "411470.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411470.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpEp60837(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. EP60837 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpEp60837", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855519.protein.info.v11.5.txt",
		        "node_list_path": "1855519.protein.complete.v11.5.txt"
		    }
		]
    )()

def SedimenticolaThiotaurini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sedimenticola thiotaurini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SedimenticolaThiotaurini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1543721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1543721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1543721.protein.info.v11.5.txt",
		        "node_list_path": "1543721.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumCzechenseLl01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium czechense LL01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumCzechenseLl01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1420583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1420583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1420583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1420583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420583.protein.info.v11.5.txt",
		        "node_list_path": "1420583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1420583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaFrigiditurris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella frigiditurris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaFrigiditurris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1542390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1542390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1542390.protein.info.v11.5.txt",
		        "node_list_path": "1542390.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumTermitidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium termitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTermitidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1195236.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1195236.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1195236.clusters.proteins.v11.5.txt",
		        "sequence_path": "1195236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1195236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1195236.protein.info.v11.5.txt",
		        "node_list_path": "1195236.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1195236.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat27445Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27445 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat27445Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1679166.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1679166.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1679166.clusters.proteins.v11.5.txt",
		        "sequence_path": "1679166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679166.protein.info.v11.5.txt",
		        "node_list_path": "1679166.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1679166.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgromycesCerinusSubspCerinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agromyces cerinus subsp. cerinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgromycesCerinusSubspCerinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "232089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "232089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "232089.clusters.proteins.v11.5.txt",
		        "sequence_path": "232089.protein.sequences.v11.5.fa",
		        "enrichment_path": "232089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "232089.protein.info.v11.5.txt",
		        "node_list_path": "232089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "232089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BelnapiaSpF41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Belnapia sp. F-4-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BelnapiaSpF41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1545443.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1545443.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1545443.clusters.proteins.v11.5.txt",
		        "sequence_path": "1545443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545443.protein.info.v11.5.txt",
		        "node_list_path": "1545443.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1545443.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasAgarivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasAgarivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1307437.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1307437.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1307437.clusters.proteins.v11.5.txt",
		        "sequence_path": "1307437.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307437.protein.info.v11.5.txt",
		        "node_list_path": "1307437.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1307437.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioclavaNitratireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioclava nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaNitratireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1915078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915078.protein.info.v11.5.txt",
		        "node_list_path": "1915078.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpMl96(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ML96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpMl96", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523503.protein.info.v11.5.txt",
		        "node_list_path": "1523503.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag768Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:768 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag768Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262838.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262838.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262838.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262838.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262838.protein.info.v11.5.txt",
		        "node_list_path": "1262838.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262838.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9301(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9301", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "167546.protein.sequences.v11.5.fa",
		        "enrichment_path": "167546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167546.protein.info.v11.5.txt",
		        "node_list_path": "167546.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSharpeaeJcm1186Dsm20505Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sharpeae JCM 1186 DSM 20505 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSharpeaeJcm1186Dsm20505Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1291052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1291052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1291052.clusters.proteins.v11.5.txt",
		        "sequence_path": "1291052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1291052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1291052.protein.info.v11.5.txt",
		        "node_list_path": "1291052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1291052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesMarimammaliumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces marimammalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesMarimammaliumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "156892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "156892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "156892.clusters.proteins.v11.5.txt",
		        "sequence_path": "156892.protein.sequences.v11.5.fa",
		        "enrichment_path": "156892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156892.protein.info.v11.5.txt",
		        "node_list_path": "156892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "156892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlS1022(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL S-1022 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlS1022", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463880.protein.info.v11.5.txt",
		        "node_list_path": "1463880.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumNematocida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium nematocida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumNematocida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1513896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1513896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1513896.protein.info.v11.5.txt",
		        "node_list_path": "1513896.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerrovumSpPnJ185(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferrovum sp. PN-J185 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrovumSpPnJ185", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1356306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1356306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1356306.protein.info.v11.5.txt",
		        "node_list_path": "1356306.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpTrp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. TRP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpTrp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "412597.protein.sequences.v11.5.fa",
		        "enrichment_path": "412597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "412597.protein.info.v11.5.txt",
		        "node_list_path": "412597.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaeBacteriumRifcsplowo212Full4520(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPLOWO2_12_FULL_45_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaeBacteriumRifcsplowo212Full4520", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797610.protein.info.v11.5.txt",
		        "node_list_path": "1797610.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterArboriphilusAnor1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter arboriphilus ANOR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterArboriphilusAnor1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1401244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1401244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1401244.clusters.proteins.v11.5.txt",
		        "sequence_path": "1401244.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401244.protein.info.v11.5.txt",
		        "node_list_path": "1401244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1401244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumZagget2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Zagget2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumZagget2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930015.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930015.protein.info.v11.5.txt",
		        "node_list_path": "1930015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaLoihicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella loihica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaLoihicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "323850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "323850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "323850.clusters.proteins.v11.5.txt",
		        "sequence_path": "323850.protein.sequences.v11.5.fa",
		        "enrichment_path": "323850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323850.protein.info.v11.5.txt",
		        "node_list_path": "323850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "323850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactococcusLactisIl1403Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus lactis Il1403 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusLactisIl1403Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272623.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272623.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272623.clusters.proteins.v11.5.txt",
		        "sequence_path": "272623.protein.sequences.v11.5.fa",
		        "enrichment_path": "272623.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272623.protein.info.v11.5.txt",
		        "node_list_path": "272623.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272623.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag594(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:594 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag594", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262826.protein.info.v11.5.txt",
		        "node_list_path": "1262826.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesSpCag435(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:435 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpCag435", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262695.protein.info.v11.5.txt",
		        "node_list_path": "1262695.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaPseudomalleiAbcpw111Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei ABCPW111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaPseudomalleiAbcpw111Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434929.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434929.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434929.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434929.protein.info.v11.5.txt",
		        "node_list_path": "1434929.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434929.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAc3007Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC3007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAc3007Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408322.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408322.protein.info.v11.5.txt",
		        "node_list_path": "1408322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumIranicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium iranicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumIranicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1370125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1370125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1370125.clusters.proteins.v11.5.txt",
		        "sequence_path": "1370125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1370125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1370125.protein.info.v11.5.txt",
		        "node_list_path": "1370125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1370125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpJ14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. J14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpJ14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935845.protein.sequences.v11.5.fa",
		        "enrichment_path": "935845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935845.protein.info.v11.5.txt",
		        "node_list_path": "935845.protein.complete.v11.5.txt"
		    }
		]
    )()

def FaecalibacteriumSpCag1138Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium sp. CAG:1138 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibacteriumSpCag1138Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262896.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262896.protein.info.v11.5.txt",
		        "node_list_path": "1262896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomonasDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1538553.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1538553.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1538553.clusters.proteins.v11.5.txt",
		        "sequence_path": "1538553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1538553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1538553.protein.info.v11.5.txt",
		        "node_list_path": "1538553.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1538553.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterCurvatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter curvatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterCurvatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "49547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "49547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "49547.clusters.proteins.v11.5.txt",
		        "sequence_path": "49547.protein.sequences.v11.5.fa",
		        "enrichment_path": "49547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "49547.protein.info.v11.5.txt",
		        "node_list_path": "49547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "49547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomonosporaAlba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomonospora alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomonosporaAlba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "183763.protein.sequences.v11.5.fa",
		        "enrichment_path": "183763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "183763.protein.info.v11.5.txt",
		        "node_list_path": "183763.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumActinocoloniiforme(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium actinocoloniiforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumActinocoloniiforme", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437605.protein.info.v11.5.txt",
		        "node_list_path": "1437605.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpRoot112d2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root112D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpRoot112d2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736426.protein.info.v11.5.txt",
		        "node_list_path": "1736426.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSpMarseilleP3519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sp. Marseille-P3519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSpMarseilleP3519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926284.protein.info.v11.5.txt",
		        "node_list_path": "1926284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpMc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. MC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpMc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1174684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1174684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1174684.protein.info.v11.5.txt",
		        "node_list_path": "1174684.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentinulaEdodesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentinula edodes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentinulaEdodesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5353.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5353.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5353.clusters.proteins.v11.5.txt",
		        "sequence_path": "5353.protein.sequences.v11.5.fa",
		        "enrichment_path": "5353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5353.protein.info.v11.5.txt",
		        "node_list_path": "5353.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5353.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpUrmo17wk12i8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. URMO17WK12I8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpUrmo17wk12i8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265490.protein.info.v11.5.txt",
		        "node_list_path": "1265490.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusParasiticusSu1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus parasiticus SU-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusParasiticusSu1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1403190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1403190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1403190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1403190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403190.protein.info.v11.5.txt",
		        "node_list_path": "1403190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1403190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpPh1bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. PH1b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpPh1bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397282.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397282.protein.info.v11.5.txt",
		        "node_list_path": "1397282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VombatusUrsinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vombatus ursinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VombatusUrsinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29139.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29139.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29139.clusters.proteins.v11.5.txt",
		        "sequence_path": "29139.protein.sequences.v11.5.fa",
		        "enrichment_path": "29139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29139.protein.info.v11.5.txt",
		        "node_list_path": "29139.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29139.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaDisparCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella dispar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaDisparCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546273.clusters.proteins.v11.5.txt",
		        "sequence_path": "546273.protein.sequences.v11.5.fa",
		        "enrichment_path": "546273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546273.protein.info.v11.5.txt",
		        "node_list_path": "546273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaSpVc33Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytoplasma sp. Vc33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaSpVc33Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1836886.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1836886.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1836886.clusters.proteins.v11.5.txt",
		        "sequence_path": "1836886.protein.sequences.v11.5.fa",
		        "enrichment_path": "1836886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1836886.protein.info.v11.5.txt",
		        "node_list_path": "1836886.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1836886.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PasteurellaBettyaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella bettyae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaBettyaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095749.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095749.protein.info.v11.5.txt",
		        "node_list_path": "1095749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTremblayaPhenacolaPave(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tremblaya phenacola PAVE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTremblayaPhenacolaPave", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1266371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266371.protein.info.v11.5.txt",
		        "node_list_path": "1266371.protein.complete.v11.5.txt"
		    }
		]
    )()

def JannaschiaAquimarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia aquimarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaAquimarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935700.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935700.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935700.clusters.proteins.v11.5.txt",
		        "sequence_path": "935700.protein.sequences.v11.5.fa",
		        "enrichment_path": "935700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935700.protein.info.v11.5.txt",
		        "node_list_path": "935700.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935700.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloteneraMobilisJlw8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera mobilis JLW8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraMobilisJlw8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "583345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "583345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "583345.clusters.proteins.v11.5.txt",
		        "sequence_path": "583345.protein.sequences.v11.5.fa",
		        "enrichment_path": "583345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "583345.protein.info.v11.5.txt",
		        "node_list_path": "583345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "583345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TalaromycesAmestolkiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces amestolkiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesAmestolkiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1196081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196081.protein.info.v11.5.txt",
		        "node_list_path": "1196081.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlautiaProductaAtcc27340Dsm2950(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blautia producta ATCC 27340 DSM 2950 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaProductaAtcc27340Dsm2950", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121114.protein.info.v11.5.txt",
		        "node_list_path": "1121114.protein.complete.v11.5.txt"
		    }
		]
    )()

def SagittulaStellata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sagittula stellata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SagittulaStellata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "388399.protein.sequences.v11.5.fa",
		        "enrichment_path": "388399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388399.protein.info.v11.5.txt",
		        "node_list_path": "388399.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusTepidamansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus tepidamans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusTepidamansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1382358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1382358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1382358.clusters.proteins.v11.5.txt",
		        "sequence_path": "1382358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382358.protein.info.v11.5.txt",
		        "node_list_path": "1382358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1382358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinilactibacillusPiezotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinilactibacillus piezotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinilactibacillusPiezotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "258723.protein.sequences.v11.5.fa",
		        "enrichment_path": "258723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "258723.protein.info.v11.5.txt",
		        "node_list_path": "258723.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb243498i20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB243_498I20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb243498i20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1471493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471493.protein.info.v11.5.txt",
		        "node_list_path": "1471493.protein.complete.v11.5.txt"
		    }
		]
    )()

def PleurocapsaSpPcc7327(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pleurocapsa sp. PCC7327 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PleurocapsaSpPcc7327", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118163.protein.sequences.v11.5.fa",
		        "enrichment_path": "118163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118163.protein.info.v11.5.txt",
		        "node_list_path": "118163.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusParasanguinisFw213(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis FW213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusParasanguinisFw213", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1114965.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114965.protein.info.v11.5.txt",
		        "node_list_path": "1114965.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospirillumCentenum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillum centenum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillumCentenum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "414684.protein.sequences.v11.5.fa",
		        "enrichment_path": "414684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "414684.protein.info.v11.5.txt",
		        "node_list_path": "414684.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDadabacteriaBacteriumRifcsphigho212Full5321(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dadabacteria bacterium RIFCSPHIGHO2_12_FULL_53_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDadabacteriaBacteriumRifcsphigho212Full5321", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797756.protein.info.v11.5.txt",
		        "node_list_path": "1797756.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurvibacterSpGwa26395(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter sp. GWA2_63_95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurvibacterSpGwa26395", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797746.protein.info.v11.5.txt",
		        "node_list_path": "1797746.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeefgeaRivuliDsm18356Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deefgea rivuli DSM 18356 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeefgeaRivuliDsm18356Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121375.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121375.protein.info.v11.5.txt",
		        "node_list_path": "1121375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AequorivitaViscosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aequorivita viscosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AequorivitaViscosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "797419.protein.sequences.v11.5.fa",
		        "enrichment_path": "797419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797419.protein.info.v11.5.txt",
		        "node_list_path": "797419.protein.complete.v11.5.txt"
		    }
		]
    )()

def BipolarisOryzaeAtcc44560Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris oryzae ATCC 44560 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisOryzaeAtcc44560Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930090.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930090.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930090.clusters.proteins.v11.5.txt",
		        "sequence_path": "930090.protein.sequences.v11.5.fa",
		        "enrichment_path": "930090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930090.protein.info.v11.5.txt",
		        "node_list_path": "930090.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930090.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaSpGwc16184Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema sp. GWC1_61_84 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSpGwc16184Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802380.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802380.protein.info.v11.5.txt",
		        "node_list_path": "1802380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusThermophilusHb8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus HB8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusThermophilusHb8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "300852.clusters.info.v11.5.txt",
		        "cluster_tree_path": "300852.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "300852.clusters.proteins.v11.5.txt",
		        "sequence_path": "300852.protein.sequences.v11.5.fa",
		        "enrichment_path": "300852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "300852.protein.info.v11.5.txt",
		        "node_list_path": "300852.cluster.nodes.v11.5.txt",
		        "edge_list_path": "300852.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaSpAr153Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. AR 15-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpAr153Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "545617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "545617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "545617.clusters.proteins.v11.5.txt",
		        "sequence_path": "545617.protein.sequences.v11.5.fa",
		        "enrichment_path": "545617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545617.protein.info.v11.5.txt",
		        "node_list_path": "545617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "545617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RamulariaColloCygniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ramularia collo-cygni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RamulariaColloCygniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "112498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "112498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "112498.clusters.proteins.v11.5.txt",
		        "sequence_path": "112498.protein.sequences.v11.5.fa",
		        "enrichment_path": "112498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112498.protein.info.v11.5.txt",
		        "node_list_path": "112498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "112498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BeggiatoaAlbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Beggiatoa alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeggiatoaAlbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "395493.clusters.info.v11.5.txt",
		        "cluster_tree_path": "395493.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "395493.clusters.proteins.v11.5.txt",
		        "sequence_path": "395493.protein.sequences.v11.5.fa",
		        "enrichment_path": "395493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395493.protein.info.v11.5.txt",
		        "node_list_path": "395493.cluster.nodes.v11.5.txt",
		        "edge_list_path": "395493.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacteralesBacteriumS7086c20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium S7086C20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteralesBacteriumS7086c20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1869302.protein.sequences.v11.5.fa",
		        "enrichment_path": "1869302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1869302.protein.info.v11.5.txt",
		        "node_list_path": "1869302.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumHaemophilumDsm44634(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium haemophilum DSM 44634 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumHaemophilumDsm44634", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1202450.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202450.protein.info.v11.5.txt",
		        "node_list_path": "1202450.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldanaerovirgaAcetigignens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldanaerovirga acetigignens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldanaerovirgaAcetigignens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "447595.protein.sequences.v11.5.fa",
		        "enrichment_path": "447595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "447595.protein.info.v11.5.txt",
		        "node_list_path": "447595.protein.complete.v11.5.txt"
		    }
		]
    )()

def FructobacillusPseudoficulneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fructobacillus pseudoficulneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FructobacillusPseudoficulneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "220714.protein.sequences.v11.5.fa",
		        "enrichment_path": "220714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220714.protein.info.v11.5.txt",
		        "node_list_path": "220714.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19059(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19059", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1481929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1481929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1481929.protein.info.v11.5.txt",
		        "node_list_path": "1481929.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanomicrobiaArchaeonJdfr19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanomicrobia archaeon JdFR-19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomicrobiaArchaeonJdfr19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935140.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935140.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935140.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935140.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935140.protein.info.v11.5.txt",
		        "node_list_path": "1935140.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935140.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAdlerbacteriaBacteriumGw2011Gwb1547Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium GW2011_GWB1_54_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumGw2011Gwb1547Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618607.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618607.protein.info.v11.5.txt",
		        "node_list_path": "1618607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TriticumUrartu(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Triticum urartu graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TriticumUrartu", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4572.protein.sequences.v11.5.fa",
		        "enrichment_path": "4572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4572.protein.info.v11.5.txt",
		        "node_list_path": "4572.protein.complete.v11.5.txt"
		    }
		]
    )()

def CytophagaHutchinsonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cytophaga hutchinsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CytophagaHutchinsonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "269798.protein.sequences.v11.5.fa",
		        "enrichment_path": "269798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269798.protein.info.v11.5.txt",
		        "node_list_path": "269798.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalanaerobiumSalsuginis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halanaerobium salsuginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaerobiumSalsuginis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29563.protein.sequences.v11.5.fa",
		        "enrichment_path": "29563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29563.protein.info.v11.5.txt",
		        "node_list_path": "29563.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaSpTw09308Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia sp. TW09308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaSpTw09308Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "754331.clusters.info.v11.5.txt",
		        "cluster_tree_path": "754331.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "754331.clusters.proteins.v11.5.txt",
		        "sequence_path": "754331.protein.sequences.v11.5.fa",
		        "enrichment_path": "754331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754331.protein.info.v11.5.txt",
		        "node_list_path": "754331.cluster.nodes.v11.5.txt",
		        "edge_list_path": "754331.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrolunatusPhosphovorus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microlunatus phosphovorus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrolunatusPhosphovorus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1032480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1032480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1032480.protein.info.v11.5.txt",
		        "node_list_path": "1032480.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacteriumRifcsphigho202Full3412Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFCSPHIGHO2_02_FULL_34_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifcsphigho202Full3412Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801607.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801607.protein.info.v11.5.txt",
		        "node_list_path": "1801607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterAilurogastricus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter ailurogastricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterAilurogastricus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1578720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1578720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1578720.protein.info.v11.5.txt",
		        "node_list_path": "1578720.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylacidiphilumInfernorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylacidiphilum infernorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylacidiphilumInfernorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "481448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "481448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "481448.clusters.proteins.v11.5.txt",
		        "sequence_path": "481448.protein.sequences.v11.5.fa",
		        "enrichment_path": "481448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481448.protein.info.v11.5.txt",
		        "node_list_path": "481448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "481448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraAlstonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira alstonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraAlstonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28452.protein.sequences.v11.5.fa",
		        "enrichment_path": "28452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28452.protein.info.v11.5.txt",
		        "node_list_path": "28452.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetospiraSpQh2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospira sp. QH-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospiraSpQh2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288970.protein.info.v11.5.txt",
		        "node_list_path": "1288970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfCulex(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Culex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfCulex", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "570417.protein.sequences.v11.5.fa",
		        "enrichment_path": "570417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570417.protein.info.v11.5.txt",
		        "node_list_path": "570417.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumUltunenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium ultunense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumUltunenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "865861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "865861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "865861.clusters.proteins.v11.5.txt",
		        "sequence_path": "865861.protein.sequences.v11.5.fa",
		        "enrichment_path": "865861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "865861.protein.info.v11.5.txt",
		        "node_list_path": "865861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "865861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumAcidipropionici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acidipropionici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumAcidipropionici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1171373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1171373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1171373.protein.info.v11.5.txt",
		        "node_list_path": "1171373.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzospirillumSp5120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum sp. 51_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumSp5120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896972.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896972.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896972.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896972.protein.info.v11.5.txt",
		        "node_list_path": "1896972.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896972.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SubdoligranulumSp4354a2faa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Subdoligranulum sp. 4354A2FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SubdoligranulumSp4354a2faa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665956.protein.sequences.v11.5.fa",
		        "enrichment_path": "665956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665956.protein.info.v11.5.txt",
		        "node_list_path": "665956.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaHaemulonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Candida] haemulonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaHaemulonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45357.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45357.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45357.clusters.proteins.v11.5.txt",
		        "sequence_path": "45357.protein.sequences.v11.5.fa",
		        "enrichment_path": "45357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45357.protein.info.v11.5.txt",
		        "node_list_path": "45357.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45357.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SubdoligranulumVariabile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Subdoligranulum variabile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SubdoligranulumVariabile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411471.protein.sequences.v11.5.fa",
		        "enrichment_path": "411471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411471.protein.info.v11.5.txt",
		        "node_list_path": "411471.protein.complete.v11.5.txt"
		    }
		]
    )()

def FructobacillusPseudoficulneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fructobacillus pseudoficulneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FructobacillusPseudoficulneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "220714.clusters.info.v11.5.txt",
		        "cluster_tree_path": "220714.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "220714.clusters.proteins.v11.5.txt",
		        "sequence_path": "220714.protein.sequences.v11.5.fa",
		        "enrichment_path": "220714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220714.protein.info.v11.5.txt",
		        "node_list_path": "220714.cluster.nodes.v11.5.txt",
		        "edge_list_path": "220714.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusWarneriL37603Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus warneri L37603 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusWarneriL37603Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596319.clusters.proteins.v11.5.txt",
		        "sequence_path": "596319.protein.sequences.v11.5.fa",
		        "enrichment_path": "596319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596319.protein.info.v11.5.txt",
		        "node_list_path": "596319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAlkalitoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio alkalitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAlkalitoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121439.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121439.protein.info.v11.5.txt",
		        "node_list_path": "1121439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsphigho201Full4023(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO2_01_FULL_40_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201Full4023", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802616.protein.info.v11.5.txt",
		        "node_list_path": "1802616.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumGa0077555(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077555 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumGa0077555", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752228.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752228.protein.info.v11.5.txt",
		        "node_list_path": "1752228.protein.complete.v11.5.txt"
		    }
		]
    )()

def TerasakiellaPusilla(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terasakiella pusilla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerasakiellaPusilla", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123355.protein.info.v11.5.txt",
		        "node_list_path": "1123355.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSpScn65179Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. SCN 65-179 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSpScn65179Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660144.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660144.protein.info.v11.5.txt",
		        "node_list_path": "1660144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThamnocephalisSphaerospora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thamnocephalis sphaerospora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThamnocephalisSphaerospora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "78915.protein.sequences.v11.5.fa",
		        "enrichment_path": "78915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78915.protein.info.v11.5.txt",
		        "node_list_path": "78915.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeropyrumCamini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeropyrum camini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeropyrumCamini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1198449.protein.sequences.v11.5.fa",
		        "enrichment_path": "1198449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1198449.protein.info.v11.5.txt",
		        "node_list_path": "1198449.protein.complete.v11.5.txt"
		    }
		]
    )()

def CenarchaeumSymbiosumA(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cenarchaeum symbiosum A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CenarchaeumSymbiosumA", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "414004.protein.sequences.v11.5.fa",
		        "enrichment_path": "414004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "414004.protein.info.v11.5.txt",
		        "node_list_path": "414004.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaAgarivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaAgarivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1911682.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1911682.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1911682.clusters.proteins.v11.5.txt",
		        "sequence_path": "1911682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1911682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1911682.protein.info.v11.5.txt",
		        "node_list_path": "1911682.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1911682.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumManausense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium manausense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumManausense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "989370.protein.sequences.v11.5.fa",
		        "enrichment_path": "989370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "989370.protein.info.v11.5.txt",
		        "node_list_path": "989370.protein.complete.v11.5.txt"
		    }
		]
    )()

def MannheimiaVarigenaUsdaarsusmarc1261(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia varigena USDAARSUSMARC1261 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaVarigenaUsdaarsusmarc1261", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1432056.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432056.protein.info.v11.5.txt",
		        "node_list_path": "1432056.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpScgcAg212E16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. SCGC AG-212-E16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpScgcAg212E16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1799664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1799664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1799664.protein.info.v11.5.txt",
		        "node_list_path": "1799664.protein.complete.v11.5.txt"
		    }
		]
    )()

def GasterosteusAculeatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gasterosteus aculeatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GasterosteusAculeatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69293.protein.sequences.v11.5.fa",
		        "enrichment_path": "69293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69293.protein.info.v11.5.txt",
		        "node_list_path": "69293.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifoxyd2Full3512Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYD2_FULL_35_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyd2Full3512Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801812.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801812.protein.info.v11.5.txt",
		        "node_list_path": "1801812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu073Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU073 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu073Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671657.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671657.protein.info.v11.5.txt",
		        "node_list_path": "1671657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrococcalesBacterium7313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 73-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcalesBacterium7313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895791.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895791.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895791.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895791.protein.info.v11.5.txt",
		        "node_list_path": "1895791.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895791.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrobaculumAerophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum aerophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumAerophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "178306.protein.sequences.v11.5.fa",
		        "enrichment_path": "178306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178306.protein.info.v11.5.txt",
		        "node_list_path": "178306.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAtcc27244(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ATCC27244 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAtcc27244", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525244.protein.sequences.v11.5.fa",
		        "enrichment_path": "525244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525244.protein.info.v11.5.txt",
		        "node_list_path": "525244.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumGa0077545(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077545 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumGa0077545", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752225.protein.info.v11.5.txt",
		        "node_list_path": "1752225.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumResinovorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium resinovorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumResinovorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "158500.protein.sequences.v11.5.fa",
		        "enrichment_path": "158500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158500.protein.info.v11.5.txt",
		        "node_list_path": "158500.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifoxyb2Full5012Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2_FULL_50_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2Full5012Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797969.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797969.protein.info.v11.5.txt",
		        "node_list_path": "1797969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferSpZgt114Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer sp. ZGT114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferSpZgt114Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1685377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1685377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1685377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1685377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685377.protein.info.v11.5.txt",
		        "node_list_path": "1685377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1685377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GramellaSalexigensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gramella salexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GramellaSalexigensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1913577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1913577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1913577.clusters.proteins.v11.5.txt",
		        "sequence_path": "1913577.protein.sequences.v11.5.fa",
		        "enrichment_path": "1913577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1913577.protein.info.v11.5.txt",
		        "node_list_path": "1913577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1913577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumGw2011Gwb14719(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWB1_47_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwb14719", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618360.protein.info.v11.5.txt",
		        "node_list_path": "1618360.protein.complete.v11.5.txt"
		    }
		]
    )()

def TulasnellaCalosporaMut4182(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tulasnella calospora MUT 4182 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TulasnellaCalosporaMut4182", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1051891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051891.protein.info.v11.5.txt",
		        "node_list_path": "1051891.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRoot682(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root682 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRoot682", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736586.protein.info.v11.5.txt",
		        "node_list_path": "1736586.protein.complete.v11.5.txt"
		    }
		]
    )()

def KangiellaKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kangiella koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KangiellaKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "523791.clusters.info.v11.5.txt",
		        "cluster_tree_path": "523791.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "523791.clusters.proteins.v11.5.txt",
		        "sequence_path": "523791.protein.sequences.v11.5.fa",
		        "enrichment_path": "523791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523791.protein.info.v11.5.txt",
		        "node_list_path": "523791.cluster.nodes.v11.5.txt",
		        "edge_list_path": "523791.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLeaf262(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf262 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLeaf262", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736312.protein.info.v11.5.txt",
		        "node_list_path": "1736312.protein.complete.v11.5.txt"
		    }
		]
    )()

def SegniliparusRugosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Segniliparus rugosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SegniliparusRugosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679197.protein.sequences.v11.5.fa",
		        "enrichment_path": "679197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679197.protein.info.v11.5.txt",
		        "node_list_path": "679197.protein.complete.v11.5.txt"
		    }
		]
    )()

def PectobacteriumParmentieri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium parmentieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumParmentieri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1905730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1905730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1905730.protein.info.v11.5.txt",
		        "node_list_path": "1905730.protein.complete.v11.5.txt"
		    }
		]
    )()

def HoefleaSp108Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hoeflea sp. 108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoefleaSp108Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1116369.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1116369.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1116369.clusters.proteins.v11.5.txt",
		        "sequence_path": "1116369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116369.protein.info.v11.5.txt",
		        "node_list_path": "1116369.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1116369.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfobacteriumThermophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfobacteriumThermophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123373.protein.info.v11.5.txt",
		        "node_list_path": "1123373.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc3789Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC3789 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc3789Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217714.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217714.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217714.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217714.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217714.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217714.protein.info.v11.5.txt",
		        "node_list_path": "1217714.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217714.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesExfoliatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces exfoliatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesExfoliatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1905.clusters.proteins.v11.5.txt",
		        "sequence_path": "1905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1905.protein.info.v11.5.txt",
		        "node_list_path": "1905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VirgibacillusDokdonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusDokdonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "302167.clusters.info.v11.5.txt",
		        "cluster_tree_path": "302167.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "302167.clusters.proteins.v11.5.txt",
		        "sequence_path": "302167.protein.sequences.v11.5.fa",
		        "enrichment_path": "302167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "302167.protein.info.v11.5.txt",
		        "node_list_path": "302167.cluster.nodes.v11.5.txt",
		        "edge_list_path": "302167.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MobiluncusMulierisAtcc35239(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris ATCC 35239 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobiluncusMulierisAtcc35239", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "871571.protein.sequences.v11.5.fa",
		        "enrichment_path": "871571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871571.protein.info.v11.5.txt",
		        "node_list_path": "871571.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasComposti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas composti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasComposti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658457.protein.sequences.v11.5.fa",
		        "enrichment_path": "658457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658457.protein.info.v11.5.txt",
		        "node_list_path": "658457.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpB72017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. B7(2017) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpB72017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1981712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1981712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1981712.clusters.proteins.v11.5.txt",
		        "sequence_path": "1981712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1981712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1981712.protein.info.v11.5.txt",
		        "node_list_path": "1981712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1981712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTpA0874Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TP-A0874 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTpA0874Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "549819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "549819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "549819.clusters.proteins.v11.5.txt",
		        "sequence_path": "549819.protein.sequences.v11.5.fa",
		        "enrichment_path": "549819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "549819.protein.info.v11.5.txt",
		        "node_list_path": "549819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "549819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLindowbacteriaBacteriumRifcsplowo212Full6227Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lindowbacteria bacterium RIFCSPLOWO2_12_FULL_62_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLindowbacteriaBacteriumRifcsplowo212Full6227Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817870.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817870.protein.info.v11.5.txt",
		        "node_list_path": "1817870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShigellaBoydiiCdc308394(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shigella boydii CDC 3083-94 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShigellaBoydiiCdc308394", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "344609.protein.sequences.v11.5.fa",
		        "enrichment_path": "344609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "344609.protein.info.v11.5.txt",
		        "node_list_path": "344609.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNc2004(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NC2004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNc2004", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410626.protein.info.v11.5.txt",
		        "node_list_path": "1410626.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermobaculumTerrenumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermobaculum terrenum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobaculumTerrenumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525904.clusters.proteins.v11.5.txt",
		        "sequence_path": "525904.protein.sequences.v11.5.fa",
		        "enrichment_path": "525904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525904.protein.info.v11.5.txt",
		        "node_list_path": "525904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapsicumBaccatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capsicum baccatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsicumBaccatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33114.clusters.proteins.v11.5.txt",
		        "sequence_path": "33114.protein.sequences.v11.5.fa",
		        "enrichment_path": "33114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33114.protein.info.v11.5.txt",
		        "node_list_path": "33114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DysgonomonasSpBgc7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas sp. BGC7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasSpBgc7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658008.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658008.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658008.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658008.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658008.protein.info.v11.5.txt",
		        "node_list_path": "1658008.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658008.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisBrenneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis brenneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisBrenneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "135651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "135651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "135651.clusters.proteins.v11.5.txt",
		        "sequence_path": "135651.protein.sequences.v11.5.fa",
		        "enrichment_path": "135651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "135651.protein.info.v11.5.txt",
		        "node_list_path": "135651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "135651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColeophomaCylindrosporaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coleophoma cylindrospora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColeophomaCylindrosporaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849047.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849047.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849047.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849047.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849047.protein.info.v11.5.txt",
		        "node_list_path": "1849047.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849047.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpMarseilleP328Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. Marseille-P328 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpMarseilleP328Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816688.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816688.protein.info.v11.5.txt",
		        "node_list_path": "1816688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumUkl133(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium UKL13-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumUkl133", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1690483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690483.protein.info.v11.5.txt",
		        "node_list_path": "1690483.protein.complete.v11.5.txt"
		    }
		]
    )()

def RodentolepisNanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rodentolepis nana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentolepisNanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "102285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "102285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "102285.clusters.proteins.v11.5.txt",
		        "sequence_path": "102285.protein.sequences.v11.5.fa",
		        "enrichment_path": "102285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102285.protein.info.v11.5.txt",
		        "node_list_path": "102285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "102285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusRapiDsm19907Jcm15042(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rapi DSM 19907 JCM 15042 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusRapiDsm19907Jcm15042", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423795.protein.info.v11.5.txt",
		        "node_list_path": "1423795.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaSpielmaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia spielmanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaSpielmaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "498742.clusters.info.v11.5.txt",
		        "cluster_tree_path": "498742.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "498742.clusters.proteins.v11.5.txt",
		        "sequence_path": "498742.protein.sequences.v11.5.fa",
		        "enrichment_path": "498742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "498742.protein.info.v11.5.txt",
		        "node_list_path": "498742.cluster.nodes.v11.5.txt",
		        "edge_list_path": "498742.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium101(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium101", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235800.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235800.protein.info.v11.5.txt",
		        "node_list_path": "1235800.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalosarcinaPallida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halosarcina pallida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalosarcinaPallida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227487.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227487.protein.info.v11.5.txt",
		        "node_list_path": "1227487.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwe24260(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWE2_42_60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwe24260", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619076.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619076.protein.info.v11.5.txt",
		        "node_list_path": "1619076.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalococcoidesMccartyiCbdb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi CBDB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalococcoidesMccartyiCbdb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "255470.protein.sequences.v11.5.fa",
		        "enrichment_path": "255470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "255470.protein.info.v11.5.txt",
		        "node_list_path": "255470.protein.complete.v11.5.txt"
		    }
		]
    )()

def EchinococcusGranulosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Echinococcus granulosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EchinococcusGranulosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6210.protein.sequences.v11.5.fa",
		        "enrichment_path": "6210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6210.protein.info.v11.5.txt",
		        "node_list_path": "6210.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusNiger(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus niger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusNiger", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5061.protein.sequences.v11.5.fa",
		        "enrichment_path": "5061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5061.protein.info.v11.5.txt",
		        "node_list_path": "5061.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriaceaeBacteriumChkci004Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacteriaceae bacterium CHKCI004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriaceaeBacteriumChkci004Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1780380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1780380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1780380.clusters.proteins.v11.5.txt",
		        "sequence_path": "1780380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780380.protein.info.v11.5.txt",
		        "node_list_path": "1780380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1780380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumFb2012Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium FB2012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumFb2012Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520817.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520817.protein.info.v11.5.txt",
		        "node_list_path": "1520817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobulbusPropionicusDsm2032(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus propionicus DSM 2032 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbusPropionicusDsm2032", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "577650.protein.sequences.v11.5.fa",
		        "enrichment_path": "577650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "577650.protein.info.v11.5.txt",
		        "node_list_path": "577650.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAd3010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AD3010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAd3010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410621.protein.info.v11.5.txt",
		        "node_list_path": "1410621.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanococcusAntarcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planococcus antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusAntarcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1185653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185653.protein.info.v11.5.txt",
		        "node_list_path": "1185653.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLambdaproteobacteriaBacteriumRifoxyd1Full5627Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lambdaproteobacteria bacterium RIFOXYD1_FULL_56_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLambdaproteobacteriaBacteriumRifoxyd1Full5627Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817770.protein.info.v11.5.txt",
		        "node_list_path": "1817770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGastranaerophilalesBacteriumHum1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium HUM_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumHum1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1916322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1916322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1916322.protein.info.v11.5.txt",
		        "node_list_path": "1916322.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpGd11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GD11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpGd11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1274374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1274374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1274374.clusters.proteins.v11.5.txt",
		        "sequence_path": "1274374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274374.protein.info.v11.5.txt",
		        "node_list_path": "1274374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1274374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPseudoalcaligenesKf707Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes KF707 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPseudoalcaligenesKf707Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1149133.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1149133.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1149133.clusters.proteins.v11.5.txt",
		        "sequence_path": "1149133.protein.sequences.v11.5.fa",
		        "enrichment_path": "1149133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1149133.protein.info.v11.5.txt",
		        "node_list_path": "1149133.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1149133.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AscochytaRabieiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ascochyta rabiei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AscochytaRabieiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5454.clusters.proteins.v11.5.txt",
		        "sequence_path": "5454.protein.sequences.v11.5.fa",
		        "enrichment_path": "5454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5454.protein.info.v11.5.txt",
		        "node_list_path": "5454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumFoliorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium foliorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumFoliorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "104336.protein.sequences.v11.5.fa",
		        "enrichment_path": "104336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104336.protein.info.v11.5.txt",
		        "node_list_path": "104336.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlomusCerebriforme(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glomus cerebriforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlomusCerebriforme", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658196.protein.sequences.v11.5.fa",
		        "enrichment_path": "658196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658196.protein.info.v11.5.txt",
		        "node_list_path": "658196.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesVaccimaxillae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces vaccimaxillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesVaccimaxillae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120947.protein.info.v11.5.txt",
		        "node_list_path": "1120947.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidiphiliumAngustumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidiphilium angustum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidiphiliumAngustumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408418.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408418.protein.info.v11.5.txt",
		        "node_list_path": "1408418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumBrhC36Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium BRH_c36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumBrhC36Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1734406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1734406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1734406.clusters.proteins.v11.5.txt",
		        "sequence_path": "1734406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1734406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1734406.protein.info.v11.5.txt",
		        "node_list_path": "1734406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1734406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterLwoffiiWj10621Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii WJ10621 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterLwoffiiWj10621Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1046625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1046625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1046625.clusters.proteins.v11.5.txt",
		        "sequence_path": "1046625.protein.sequences.v11.5.fa",
		        "enrichment_path": "1046625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1046625.protein.info.v11.5.txt",
		        "node_list_path": "1046625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1046625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaPhthalaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia phthalatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaPhthalaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1136941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1136941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1136941.clusters.proteins.v11.5.txt",
		        "sequence_path": "1136941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1136941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1136941.protein.info.v11.5.txt",
		        "node_list_path": "1136941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1136941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumOranimense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium oranimense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumOranimense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1300143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300143.protein.info.v11.5.txt",
		        "node_list_path": "1300143.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaNigrescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella nigrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaNigrescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "997352.protein.sequences.v11.5.fa",
		        "enrichment_path": "997352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997352.protein.info.v11.5.txt",
		        "node_list_path": "997352.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumLipolyticumDsm21995Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum lipolyticum DSM 21995 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumLipolyticumDsm21995Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227482.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227482.protein.info.v11.5.txt",
		        "node_list_path": "1227482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifoxyd1Full4821Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFOXYD1_FULL_48_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifoxyd1Full4821Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798368.protein.info.v11.5.txt",
		        "node_list_path": "1798368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321775.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321775.protein.info.v11.5.txt",
		        "node_list_path": "1321775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeodactylibacterXiamenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeodactylibacter xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeodactylibacterXiamenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1524460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1524460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1524460.clusters.proteins.v11.5.txt",
		        "sequence_path": "1524460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1524460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1524460.protein.info.v11.5.txt",
		        "node_list_path": "1524460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1524460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SistotremastrumNiveocremeumHhb9708(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sistotremastrum niveocremeum HHB9708 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SistotremastrumNiveocremeumHhb9708", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314777.protein.info.v11.5.txt",
		        "node_list_path": "1314777.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumChoanaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium choanae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumChoanaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736691.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736691.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736691.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736691.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736691.protein.info.v11.5.txt",
		        "node_list_path": "1736691.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736691.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusWynnii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus wynnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusWynnii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "268407.protein.sequences.v11.5.fa",
		        "enrichment_path": "268407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "268407.protein.info.v11.5.txt",
		        "node_list_path": "268407.protein.complete.v11.5.txt"
		    }
		]
    )()

def FructobacillusFiculneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fructobacillus ficulneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FructobacillusFiculneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "157463.protein.sequences.v11.5.fa",
		        "enrichment_path": "157463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157463.protein.info.v11.5.txt",
		        "node_list_path": "157463.protein.complete.v11.5.txt"
		    }
		]
    )()

def TamlanaAgarivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tamlana agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TamlanaAgarivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "481183.clusters.info.v11.5.txt",
		        "cluster_tree_path": "481183.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "481183.clusters.proteins.v11.5.txt",
		        "sequence_path": "481183.protein.sequences.v11.5.fa",
		        "enrichment_path": "481183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481183.protein.info.v11.5.txt",
		        "node_list_path": "481183.cluster.nodes.v11.5.txt",
		        "edge_list_path": "481183.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoclavibacterHelvolusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoclavibacter helvolus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoclavibacterHelvolusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "255205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "255205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "255205.clusters.proteins.v11.5.txt",
		        "sequence_path": "255205.protein.sequences.v11.5.fa",
		        "enrichment_path": "255205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "255205.protein.info.v11.5.txt",
		        "node_list_path": "255205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "255205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExophialaMesophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exophiala mesophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaMesophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "212818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "212818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "212818.clusters.proteins.v11.5.txt",
		        "sequence_path": "212818.protein.sequences.v11.5.fa",
		        "enrichment_path": "212818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "212818.protein.info.v11.5.txt",
		        "node_list_path": "212818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "212818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyxococcusStipitatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus stipitatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcusStipitatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278073.protein.info.v11.5.txt",
		        "node_list_path": "1278073.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalviaSplendensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salvia splendens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalviaSplendensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "180675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "180675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "180675.clusters.proteins.v11.5.txt",
		        "sequence_path": "180675.protein.sequences.v11.5.fa",
		        "enrichment_path": "180675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180675.protein.info.v11.5.txt",
		        "node_list_path": "180675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "180675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGilvigriseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces gilvigriseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGilvigriseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1428644.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1428644.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1428644.clusters.proteins.v11.5.txt",
		        "sequence_path": "1428644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1428644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1428644.protein.info.v11.5.txt",
		        "node_list_path": "1428644.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1428644.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAle31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAle31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158182.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158182.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158182.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158182.protein.info.v11.5.txt",
		        "node_list_path": "1158182.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158182.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpKpl2004(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL2004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpKpl2004", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203632.protein.info.v11.5.txt",
		        "node_list_path": "1203632.protein.complete.v11.5.txt"
		    }
		]
    )()

def RiemerellaColumbina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Riemerella columbina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RiemerellaColumbina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123058.protein.info.v11.5.txt",
		        "node_list_path": "1123058.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirosomaLuteum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma luteum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaLuteum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123276.protein.info.v11.5.txt",
		        "node_list_path": "1123276.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhialophoraAttae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phialophora attae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhialophoraAttae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1664694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1664694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1664694.protein.info.v11.5.txt",
		        "node_list_path": "1664694.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpP18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. P1.8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpP18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1699310.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1699310.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1699310.clusters.proteins.v11.5.txt",
		        "sequence_path": "1699310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1699310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1699310.protein.info.v11.5.txt",
		        "node_list_path": "1699310.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1699310.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTachikawaeaGelatinosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tachikawaea gelatinosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTachikawaeaGelatinosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410383.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410383.protein.info.v11.5.txt",
		        "node_list_path": "1410383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaDonghaiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina donghaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaDonghaiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "519452.protein.sequences.v11.5.fa",
		        "enrichment_path": "519452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519452.protein.info.v11.5.txt",
		        "node_list_path": "519452.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusPasteuriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pasteurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPasteuriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423790.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423790.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423790.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423790.protein.info.v11.5.txt",
		        "node_list_path": "1423790.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423790.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrocoleusSpPcc7113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microcoleus sp. PCC7113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrocoleusSpPcc7113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173027.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173027.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173027.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173027.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173027.protein.info.v11.5.txt",
		        "node_list_path": "1173027.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173027.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StrongyloidesStercoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Strongyloides stercoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrongyloidesStercoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6248.protein.sequences.v11.5.fa",
		        "enrichment_path": "6248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6248.protein.info.v11.5.txt",
		        "node_list_path": "6248.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptosporangiumRoseumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptosporangium roseum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptosporangiumRoseumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "479432.clusters.info.v11.5.txt",
		        "cluster_tree_path": "479432.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "479432.clusters.proteins.v11.5.txt",
		        "sequence_path": "479432.protein.sequences.v11.5.fa",
		        "enrichment_path": "479432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479432.protein.info.v11.5.txt",
		        "node_list_path": "479432.cluster.nodes.v11.5.txt",
		        "edge_list_path": "479432.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteibacterSpUncmf366tsu51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter sp. UNCMF366Tsu5.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterSpUncmf366tsu51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502758.protein.info.v11.5.txt",
		        "node_list_path": "1502758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GranulicellaMallensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Granulicella mallensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicellaMallensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "682795.protein.sequences.v11.5.fa",
		        "enrichment_path": "682795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "682795.protein.info.v11.5.txt",
		        "node_list_path": "682795.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumSalinitoleransStrHayward0363Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium salinitolerans str. Hayward 0363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumSalinitoleransStrHayward0363Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1183434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1183434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1183434.clusters.proteins.v11.5.txt",
		        "sequence_path": "1183434.protein.sequences.v11.5.fa",
		        "enrichment_path": "1183434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1183434.protein.info.v11.5.txt",
		        "node_list_path": "1183434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1183434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloferaxMediterraneiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloferax mediterranei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloferaxMediterraneiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "523841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "523841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "523841.clusters.proteins.v11.5.txt",
		        "sequence_path": "523841.protein.sequences.v11.5.fa",
		        "enrichment_path": "523841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523841.protein.info.v11.5.txt",
		        "node_list_path": "523841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "523841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospinaSpScgcAaa288L16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospina sp. SCGC AAA288-L16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospinaSpScgcAaa288L16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "913337.protein.sequences.v11.5.fa",
		        "enrichment_path": "913337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913337.protein.info.v11.5.txt",
		        "node_list_path": "913337.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryptosporidiumParvumIowaIi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporidium parvum Iowa II graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptosporidiumParvumIowaIi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "353152.protein.sequences.v11.5.fa",
		        "enrichment_path": "353152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "353152.protein.info.v11.5.txt",
		        "node_list_path": "353152.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasCedrinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas cedrina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCedrinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "651740.clusters.info.v11.5.txt",
		        "cluster_tree_path": "651740.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "651740.clusters.proteins.v11.5.txt",
		        "sequence_path": "651740.protein.sequences.v11.5.fa",
		        "enrichment_path": "651740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "651740.protein.info.v11.5.txt",
		        "node_list_path": "651740.cluster.nodes.v11.5.txt",
		        "edge_list_path": "651740.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonasTestosteroniKf1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas testosteroni KF1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasTestosteroniKf1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "399795.protein.sequences.v11.5.fa",
		        "enrichment_path": "399795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399795.protein.info.v11.5.txt",
		        "node_list_path": "399795.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytophthoraRamorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora ramorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraRamorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "164328.clusters.info.v11.5.txt",
		        "cluster_tree_path": "164328.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "164328.clusters.proteins.v11.5.txt",
		        "sequence_path": "164328.protein.sequences.v11.5.fa",
		        "enrichment_path": "164328.protein.enrichment.terms.v11.5.txt",
		        "info_path": "164328.protein.info.v11.5.txt",
		        "node_list_path": "164328.cluster.nodes.v11.5.txt",
		        "edge_list_path": "164328.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerpulaLacrymans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serpula lacrymans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerpulaLacrymans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "85982.protein.sequences.v11.5.fa",
		        "enrichment_path": "85982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85982.protein.info.v11.5.txt",
		        "node_list_path": "85982.protein.complete.v11.5.txt"
		    }
		]
    )()

def FervidicoccusFontisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fervidicoccus fontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidicoccusFontisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1163730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1163730.clusters.proteins.v11.5.txt",
		        "sequence_path": "1163730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163730.protein.info.v11.5.txt",
		        "node_list_path": "1163730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1163730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusPsittaci(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus psittaci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPsittaci", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122152.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122152.protein.info.v11.5.txt",
		        "node_list_path": "1122152.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemmatimonadetesBacterium13220cm2657(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium 13_2_20CM_2_65_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonadetesBacterium13220cm2657", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805202.protein.info.v11.5.txt",
		        "node_list_path": "1805202.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSuimastitidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces suimastitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSuimastitidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120946.protein.info.v11.5.txt",
		        "node_list_path": "1120946.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalodesulfovibrioMarinisediminisDsm17456Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halodesulfovibrio marinisediminis DSM 17456 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalodesulfovibrioMarinisediminisDsm17456Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121457.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121457.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121457.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121457.protein.info.v11.5.txt",
		        "node_list_path": "1121457.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121457.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterDaltonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter daltonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterDaltonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316067.protein.sequences.v11.5.fa",
		        "enrichment_path": "316067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316067.protein.info.v11.5.txt",
		        "node_list_path": "316067.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumWsm2304Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum WSM2304 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumWsm2304Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "395492.clusters.info.v11.0.txt",
		        "cluster_tree_path": "395492.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "395492.clusters.proteins.v11.0.txt",
		        "sequence_path": "395492.protein.sequences.v11.0.fa",
		        "enrichment_path": "395492.protein.enrichment.terms.v11.0.txt",
		        "info_path": "395492.protein.info.v11.0.txt",
		        "node_list_path": "395492.cluster.nodes.v11.0.txt",
		        "edge_list_path": "395492.protein.cluster.v11.0.txt"
		    }
		]
    )()

def BacteroidesSpGa6a2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. Ga6A2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpGa6a2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410608.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410608.protein.info.v11.5.txt",
		        "node_list_path": "1410608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaDenticariosiJcm15641Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella denticariosi JCM 15641 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaDenticariosiJcm15641Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298594.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298594.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298594.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298594.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298594.protein.info.v11.5.txt",
		        "node_list_path": "1298594.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298594.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCacaonumDsm21116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus cacaonum DSM 21116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCacaonumDsm21116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423729.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423729.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423729.protein.info.v11.5.txt",
		        "node_list_path": "1423729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrachipleistophoraHominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trachipleistophora hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrachipleistophoraHominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "72359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "72359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "72359.clusters.proteins.v11.5.txt",
		        "sequence_path": "72359.protein.sequences.v11.5.fa",
		        "enrichment_path": "72359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72359.protein.info.v11.5.txt",
		        "node_list_path": "72359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "72359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlebsormidiumNitensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsormidium nitens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsormidiumNitensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "105231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "105231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "105231.clusters.proteins.v11.5.txt",
		        "sequence_path": "105231.protein.sequences.v11.5.fa",
		        "enrichment_path": "105231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105231.protein.info.v11.5.txt",
		        "node_list_path": "105231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "105231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumRbg135518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_13_55_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumRbg135518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797197.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797197.protein.info.v11.5.txt",
		        "node_list_path": "1797197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaHarenaeNbrc108248(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia harenae NBRC 108248 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaHarenaeNbrc108248", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210074.protein.info.v11.5.txt",
		        "node_list_path": "1210074.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioAnguillarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio anguillarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioAnguillarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "55601.protein.sequences.v11.5.fa",
		        "enrichment_path": "55601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55601.protein.info.v11.5.txt",
		        "node_list_path": "55601.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusMangrovi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus mangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusMangrovi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "402384.protein.sequences.v11.5.fa",
		        "enrichment_path": "402384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402384.protein.info.v11.5.txt",
		        "node_list_path": "402384.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiabellaSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Niabella soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiabellaSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "929713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "929713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "929713.clusters.proteins.v11.5.txt",
		        "sequence_path": "929713.protein.sequences.v11.5.fa",
		        "enrichment_path": "929713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929713.protein.info.v11.5.txt",
		        "node_list_path": "929713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "929713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumMarinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumMarinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1159016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1159016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1159016.clusters.proteins.v11.5.txt",
		        "sequence_path": "1159016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159016.protein.info.v11.5.txt",
		        "node_list_path": "1159016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1159016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumTusciae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium tusciae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumTusciae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "75922.protein.sequences.v11.5.fa",
		        "enrichment_path": "75922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75922.protein.info.v11.5.txt",
		        "node_list_path": "75922.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpBtai1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. BTAi1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpBtai1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "288000.protein.sequences.v11.5.fa",
		        "enrichment_path": "288000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "288000.protein.info.v11.5.txt",
		        "node_list_path": "288000.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNanopusillusAcidilobi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nanopusillus acidilobi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNanopusillusAcidilobi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577684.protein.info.v11.5.txt",
		        "node_list_path": "1577684.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacterium51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 5-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacterium51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1962178.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1962178.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1962178.clusters.proteins.v11.5.txt",
		        "sequence_path": "1962178.protein.sequences.v11.5.fa",
		        "enrichment_path": "1962178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1962178.protein.info.v11.5.txt",
		        "node_list_path": "1962178.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1962178.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmobacterMegateriumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmobacter megaterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmobacterMegateriumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1086013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1086013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1086013.clusters.proteins.v11.5.txt",
		        "sequence_path": "1086013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1086013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1086013.protein.info.v11.5.txt",
		        "node_list_path": "1086013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1086013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaWadsworthii9715Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria wadsworthii 9715 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaWadsworthii9715Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1030841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1030841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1030841.clusters.proteins.v11.5.txt",
		        "sequence_path": "1030841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1030841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1030841.protein.info.v11.5.txt",
		        "node_list_path": "1030841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1030841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpAb57(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB57 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpAb57", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841860.protein.info.v11.5.txt",
		        "node_list_path": "1841860.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurimonasSpAst10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. AST10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasSpAst10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1172190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172190.protein.info.v11.5.txt",
		        "node_list_path": "1172190.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterHeparinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter heparinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterHeparinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "485917.protein.sequences.v11.5.fa",
		        "enrichment_path": "485917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485917.protein.info.v11.5.txt",
		        "node_list_path": "485917.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf2580(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF2580 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf2580", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463841.protein.info.v11.5.txt",
		        "node_list_path": "1463841.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb14510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_45_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb14510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618877.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618877.protein.info.v11.5.txt",
		        "node_list_path": "1618877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisXylanica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis xylanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisXylanica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "589385.protein.sequences.v11.5.fa",
		        "enrichment_path": "589385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "589385.protein.info.v11.5.txt",
		        "node_list_path": "589385.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpLappah95(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. LaPpAH95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpLappah95", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157632.protein.info.v11.5.txt",
		        "node_list_path": "1157632.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "882083.protein.sequences.v11.5.fa",
		        "enrichment_path": "882083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882083.protein.info.v11.5.txt",
		        "node_list_path": "882083.protein.complete.v11.5.txt"
		    }
		]
    )()

def TerrabacterSp28Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terrabacter sp. 28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrabacterSp28Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619947.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619947.protein.info.v11.5.txt",
		        "node_list_path": "1619947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermobrachiumCelere(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermobrachium celere graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobrachiumCelere", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "941824.protein.sequences.v11.5.fa",
		        "enrichment_path": "941824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "941824.protein.info.v11.5.txt",
		        "node_list_path": "941824.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwe24116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWE2_41_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwe24116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619075.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619075.protein.info.v11.5.txt",
		        "node_list_path": "1619075.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriAtcc14405Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri ATCC14405 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriAtcc14405Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32042.clusters.proteins.v11.5.txt",
		        "sequence_path": "32042.protein.sequences.v11.5.fa",
		        "enrichment_path": "32042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32042.protein.info.v11.5.txt",
		        "node_list_path": "32042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumPeriodonticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium periodonticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumPeriodonticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546275.protein.sequences.v11.5.fa",
		        "enrichment_path": "546275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546275.protein.info.v11.5.txt",
		        "node_list_path": "546275.protein.complete.v11.5.txt"
		    }
		]
    )()

def PythonBivittatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Python bivittatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PythonBivittatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "176946.protein.sequences.v11.5.fa",
		        "enrichment_path": "176946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "176946.protein.info.v11.5.txt",
		        "node_list_path": "176946.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpCot290oh860(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT290OH860 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpCot290oh860", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1515615.protein.sequences.v11.5.fa",
		        "enrichment_path": "1515615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1515615.protein.info.v11.5.txt",
		        "node_list_path": "1515615.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaZoodegmatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria zoodegmatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaZoodegmatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326523.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326523.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326523.clusters.proteins.v11.5.txt",
		        "sequence_path": "326523.protein.sequences.v11.5.fa",
		        "enrichment_path": "326523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326523.protein.info.v11.5.txt",
		        "node_list_path": "326523.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326523.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSpg23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SPG23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSpg23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1610703.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1610703.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1610703.clusters.proteins.v11.5.txt",
		        "sequence_path": "1610703.protein.sequences.v11.5.fa",
		        "enrichment_path": "1610703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1610703.protein.info.v11.5.txt",
		        "node_list_path": "1610703.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1610703.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1301100.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1301100.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1301100.clusters.proteins.v11.5.txt",
		        "sequence_path": "1301100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1301100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1301100.protein.info.v11.5.txt",
		        "node_list_path": "1301100.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1301100.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAtribacteriaBacteriumCg2303313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atribacteria bacterium CG2_30_33_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAtribacteriaBacteriumCg2303313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805029.protein.info.v11.5.txt",
		        "node_list_path": "1805029.protein.complete.v11.5.txt"
		    }
		]
    )()

def UstilagoHordei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ustilago hordei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UstilagoHordei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "120017.protein.sequences.v11.5.fa",
		        "enrichment_path": "120017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "120017.protein.info.v11.5.txt",
		        "node_list_path": "120017.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinisphaeraShabanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinisphaera shabanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisphaeraShabanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033802.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033802.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033802.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033802.protein.info.v11.5.txt",
		        "node_list_path": "1033802.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033802.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaWorsleiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella worsleiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaWorsleiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45076.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45076.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45076.clusters.proteins.v11.5.txt",
		        "sequence_path": "45076.protein.sequences.v11.5.fa",
		        "enrichment_path": "45076.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45076.protein.info.v11.5.txt",
		        "node_list_path": "45076.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45076.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiK12SubstrW3110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli K12 substr. W3110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiK12SubstrW3110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316407.protein.sequences.v11.5.fa",
		        "enrichment_path": "316407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316407.protein.info.v11.5.txt",
		        "node_list_path": "316407.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumEligens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium eligens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumEligens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "515620.protein.sequences.v11.5.fa",
		        "enrichment_path": "515620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515620.protein.info.v11.5.txt",
		        "node_list_path": "515620.protein.complete.v11.5.txt"
		    }
		]
    )()

def HugenholtziaRoseolaDsm9546(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hugenholtzia roseola DSM 9546 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HugenholtziaRoseolaDsm9546", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121903.protein.info.v11.5.txt",
		        "node_list_path": "1121903.protein.complete.v11.5.txt"
		    }
		]
    )()

def GloeocapsaSpPcc73106Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gloeocapsa sp. PCC73106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeocapsaSpPcc73106Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "102232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "102232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "102232.clusters.proteins.v11.5.txt",
		        "sequence_path": "102232.protein.sequences.v11.5.fa",
		        "enrichment_path": "102232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102232.protein.info.v11.5.txt",
		        "node_list_path": "102232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "102232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrenarchaeotaArchaeon13120cm25314Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_20CM_2_53_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenarchaeotaArchaeon13120cm25314Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805094.protein.info.v11.5.txt",
		        "node_list_path": "1805094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphaerulinaMusivaSo2202Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaerulina musiva SO2202 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerulinaMusivaSo2202Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "692275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "692275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "692275.clusters.proteins.v11.5.txt",
		        "sequence_path": "692275.protein.sequences.v11.5.fa",
		        "enrichment_path": "692275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "692275.protein.info.v11.5.txt",
		        "node_list_path": "692275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "692275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubrivivaxGelatinosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubrivivax gelatinosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubrivivaxGelatinosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983917.clusters.proteins.v11.5.txt",
		        "sequence_path": "983917.protein.sequences.v11.5.fa",
		        "enrichment_path": "983917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983917.protein.info.v11.5.txt",
		        "node_list_path": "983917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4281Fw2241(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4281 (FW-2241) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4281Fw2241", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420906.protein.info.v11.5.txt",
		        "node_list_path": "1420906.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteralesBacteriumAlpha01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium Alpha_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteralesBacteriumAlpha01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674810.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674810.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674810.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674810.protein.info.v11.5.txt",
		        "node_list_path": "1674810.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674810.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1023713(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_37_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023713", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805302.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805302.protein.info.v11.5.txt",
		        "node_list_path": "1805302.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa1478(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA1_47_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa1478", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618793.protein.info.v11.5.txt",
		        "node_list_path": "1618793.protein.complete.v11.5.txt"
		    }
		]
    )()

def CionaIntestinalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ciona intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CionaIntestinalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7719.protein.sequences.v11.5.fa",
		        "enrichment_path": "7719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7719.protein.info.v11.5.txt",
		        "node_list_path": "7719.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinicoccusSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1432562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432562.protein.info.v11.5.txt",
		        "node_list_path": "1432562.protein.complete.v11.5.txt"
		    }
		]
    )()

def NakamurellaLacteaDsm19367(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nakamurella lactea DSM 19367 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NakamurellaLacteaDsm19367", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123241.protein.info.v11.5.txt",
		        "node_list_path": "1123241.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesGeorgiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces georgiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesGeorgiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120942.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120942.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120942.protein.info.v11.5.txt",
		        "node_list_path": "1120942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GluconobacterOxydans621hCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans 621H Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterOxydans621hCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290633.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290633.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290633.clusters.proteins.v11.5.txt",
		        "sequence_path": "290633.protein.sequences.v11.5.fa",
		        "enrichment_path": "290633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290633.protein.info.v11.5.txt",
		        "node_list_path": "290633.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290633.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhaeospirillumMolischianumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeospirillum molischianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeospirillumMolischianumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150626.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150626.protein.info.v11.5.txt",
		        "node_list_path": "1150626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NotechisScutatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Notechis scutatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NotechisScutatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8663.clusters.proteins.v11.5.txt",
		        "sequence_path": "8663.protein.sequences.v11.5.fa",
		        "enrichment_path": "8663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8663.protein.info.v11.5.txt",
		        "node_list_path": "8663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacterIcosiumassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter icosiumassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterIcosiumassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1792835.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1792835.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1792835.clusters.proteins.v11.5.txt",
		        "sequence_path": "1792835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792835.protein.info.v11.5.txt",
		        "node_list_path": "1792835.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1792835.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumGw2011Gwe24058Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_40_58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24058Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618991.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618991.protein.info.v11.5.txt",
		        "node_list_path": "1618991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaPsittaci10139811Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia psittaci 10139811 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaPsittaci10139811Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1238237.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1238237.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1238237.clusters.proteins.v11.5.txt",
		        "sequence_path": "1238237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238237.protein.info.v11.5.txt",
		        "node_list_path": "1238237.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1238237.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumCg1025621(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_56_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumCg1025621", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805132.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805132.protein.info.v11.5.txt",
		        "node_list_path": "1805132.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCaeruleatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces caeruleatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCaeruleatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "661399.protein.sequences.v11.5.fa",
		        "enrichment_path": "661399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "661399.protein.info.v11.5.txt",
		        "node_list_path": "661399.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeosartoryaFischeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neosartorya fischeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeosartoryaFischeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36630.clusters.proteins.v11.5.txt",
		        "sequence_path": "36630.protein.sequences.v11.5.fa",
		        "enrichment_path": "36630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36630.protein.info.v11.5.txt",
		        "node_list_path": "36630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicolaSp22iis11g(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola sp. 22IIS11g graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaSp22iis11g", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461694.protein.info.v11.5.txt",
		        "node_list_path": "1461694.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasCupidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas cupida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasCupidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44933.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44933.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44933.clusters.proteins.v11.5.txt",
		        "sequence_path": "44933.protein.sequences.v11.5.fa",
		        "enrichment_path": "44933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44933.protein.info.v11.5.txt",
		        "node_list_path": "44933.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44933.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumGeorgienseDsm11526Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium georgiense DSM 11526 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumGeorgienseDsm11526Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122198.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122198.protein.info.v11.5.txt",
		        "node_list_path": "1122198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrodictiumOccultumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrodictium occultum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrodictiumOccultumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2309.clusters.proteins.v11.5.txt",
		        "sequence_path": "2309.protein.sequences.v11.5.fa",
		        "enrichment_path": "2309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2309.protein.info.v11.5.txt",
		        "node_list_path": "2309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporothrixInsectorumRcef264(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporothrix insectorum RCEF 264 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporothrixInsectorumRcef264", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1081102.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081102.protein.info.v11.5.txt",
		        "node_list_path": "1081102.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpJs614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. JS614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpJs614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "196162.protein.sequences.v11.5.fa",
		        "enrichment_path": "196162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "196162.protein.info.v11.5.txt",
		        "node_list_path": "196162.protein.complete.v11.5.txt"
		    }
		]
    )()

def ReichenbachiellaFaecimarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Reichenbachiella faecimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ReichenbachiellaFaecimarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "692418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "692418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "692418.clusters.proteins.v11.5.txt",
		        "sequence_path": "692418.protein.sequences.v11.5.fa",
		        "enrichment_path": "692418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "692418.protein.info.v11.5.txt",
		        "node_list_path": "692418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "692418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfuricurvumKujienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfuricurvum kujiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuricurvumKujienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "709032.clusters.info.v11.5.txt",
		        "cluster_tree_path": "709032.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "709032.clusters.proteins.v11.5.txt",
		        "sequence_path": "709032.protein.sequences.v11.5.fa",
		        "enrichment_path": "709032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709032.protein.info.v11.5.txt",
		        "node_list_path": "709032.cluster.nodes.v11.5.txt",
		        "edge_list_path": "709032.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfarculaceaeBacteriumJdfr97(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfarculaceae bacterium JdFR-97 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfarculaceaeBacteriumJdfr97", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935136.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935136.protein.info.v11.5.txt",
		        "node_list_path": "1935136.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc29g08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC29G08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc29g08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1581069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1581069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1581069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1581069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581069.protein.info.v11.5.txt",
		        "node_list_path": "1581069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1581069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusModuliflexusFlocculans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moduliflexus flocculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusModuliflexusFlocculans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499966.protein.info.v11.5.txt",
		        "node_list_path": "1499966.protein.complete.v11.5.txt"
		    }
		]
    )()

def TropherymaWhipplei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tropheryma whipplei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TropherymaWhipplei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "203267.protein.sequences.v11.5.fa",
		        "enrichment_path": "203267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203267.protein.info.v11.5.txt",
		        "node_list_path": "203267.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolobacteriumMooreiDsm22971(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solobacterium moorei DSM22971 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolobacteriumMooreiDsm22971", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123263.protein.info.v11.5.txt",
		        "node_list_path": "1123263.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasAquamarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas aquamarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasAquamarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "77097.clusters.info.v11.5.txt",
		        "cluster_tree_path": "77097.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "77097.clusters.proteins.v11.5.txt",
		        "sequence_path": "77097.protein.sequences.v11.5.fa",
		        "enrichment_path": "77097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "77097.protein.info.v11.5.txt",
		        "node_list_path": "77097.cluster.nodes.v11.5.txt",
		        "edge_list_path": "77097.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusHelveticusCnrz32Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus CNRZ32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHelveticusCnrz32Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326425.clusters.proteins.v11.5.txt",
		        "sequence_path": "326425.protein.sequences.v11.5.fa",
		        "enrichment_path": "326425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326425.protein.info.v11.5.txt",
		        "node_list_path": "326425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GabonibacterMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gabonibacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GabonibacterMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720195.protein.info.v11.5.txt",
		        "node_list_path": "1720195.protein.complete.v11.5.txt"
		    }
		]
    )()

def AminobacteriumColombienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aminobacterium colombiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminobacteriumColombienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "572547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "572547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "572547.clusters.proteins.v11.5.txt",
		        "sequence_path": "572547.protein.sequences.v11.5.fa",
		        "enrichment_path": "572547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572547.protein.info.v11.5.txt",
		        "node_list_path": "572547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "572547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusRuberCbs135680Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ruber CBS 135680 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusRuberCbs135680Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1388766.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1388766.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1388766.clusters.proteins.v11.5.txt",
		        "sequence_path": "1388766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1388766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1388766.protein.info.v11.5.txt",
		        "node_list_path": "1388766.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1388766.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FloricoccusTropicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Floricoccus tropicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FloricoccusTropicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1859473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1859473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1859473.protein.info.v11.5.txt",
		        "node_list_path": "1859473.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScyliorhinusTorazameCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scyliorhinus torazame Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScyliorhinusTorazameCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "75743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "75743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "75743.clusters.proteins.v11.5.txt",
		        "sequence_path": "75743.protein.sequences.v11.5.fa",
		        "enrichment_path": "75743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75743.protein.info.v11.5.txt",
		        "node_list_path": "75743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "75743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatrinemaVersiformeJcm10478Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrinema versiforme JCM 10478 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrinemaVersiformeJcm10478Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227496.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227496.protein.info.v11.5.txt",
		        "node_list_path": "1227496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumGw2011Gwb14311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWB1_43_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwb14311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618446.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618446.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618446.protein.info.v11.5.txt",
		        "node_list_path": "1618446.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumSg847Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium SG8_47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumSg847Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703406.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703406.protein.info.v11.5.txt",
		        "node_list_path": "1703406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSiraeumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Eubacterium] siraeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSiraeumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39492.clusters.proteins.v11.5.txt",
		        "sequence_path": "39492.protein.sequences.v11.5.fa",
		        "enrichment_path": "39492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39492.protein.info.v11.5.txt",
		        "node_list_path": "39492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaAlhagi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea alhagi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaAlhagi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1891675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891675.protein.info.v11.5.txt",
		        "node_list_path": "1891675.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpRoot487d2y(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root487D2Y graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpRoot487d2y", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736547.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736547.protein.info.v11.5.txt",
		        "node_list_path": "1736547.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_41_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797727.protein.info.v11.5.txt",
		        "node_list_path": "1797727.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumMoukalabense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium moukalabense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumMoukalabense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1435051.protein.sequences.v11.5.fa",
		        "enrichment_path": "1435051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1435051.protein.info.v11.5.txt",
		        "node_list_path": "1435051.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpY412mc10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Y412MC10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpY412mc10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "481743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "481743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "481743.clusters.proteins.v11.5.txt",
		        "sequence_path": "481743.protein.sequences.v11.5.fa",
		        "enrichment_path": "481743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481743.protein.info.v11.5.txt",
		        "node_list_path": "481743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "481743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumSanguinicancri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium sanguinicancri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumSanguinicancri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "875932.protein.sequences.v11.5.fa",
		        "enrichment_path": "875932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "875932.protein.info.v11.5.txt",
		        "node_list_path": "875932.protein.complete.v11.5.txt"
		    }
		]
    )()

def TaeniopygiaGuttataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Taeniopygia guttata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TaeniopygiaGuttataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59729.clusters.proteins.v11.5.txt",
		        "sequence_path": "59729.protein.sequences.v11.5.fa",
		        "enrichment_path": "59729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59729.protein.info.v11.5.txt",
		        "node_list_path": "59729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacterium4484171Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_171 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484171Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1956173.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1956173.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1956173.clusters.proteins.v11.5.txt",
		        "sequence_path": "1956173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1956173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1956173.protein.info.v11.5.txt",
		        "node_list_path": "1956173.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1956173.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpRoot630(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. Root630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpRoot630", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736574.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736574.protein.info.v11.5.txt",
		        "node_list_path": "1736574.protein.complete.v11.5.txt"
		    }
		]
    )()

def RathayibacterSpLeaf185Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rathayibacter sp. Leaf185 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RathayibacterSpLeaf185Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736292.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736292.protein.info.v11.5.txt",
		        "node_list_path": "1736292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterAceti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter aceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterAceti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "435.protein.sequences.v11.5.fa",
		        "enrichment_path": "435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435.protein.info.v11.5.txt",
		        "node_list_path": "435.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpCc9902Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9902 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpCc9902Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316279.clusters.proteins.v11.5.txt",
		        "sequence_path": "316279.protein.sequences.v11.5.fa",
		        "enrichment_path": "316279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316279.protein.info.v11.5.txt",
		        "node_list_path": "316279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusSp4557Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sp. 4557 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSp4557Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1042877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1042877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1042877.clusters.proteins.v11.5.txt",
		        "sequence_path": "1042877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042877.protein.info.v11.5.txt",
		        "node_list_path": "1042877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1042877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumFe2018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium FE2018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumFe2018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410624.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410624.protein.info.v11.5.txt",
		        "node_list_path": "1410624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlautiaHydrogenotrophicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia hydrogenotrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlautiaHydrogenotrophicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "476272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "476272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "476272.clusters.proteins.v11.5.txt",
		        "sequence_path": "476272.protein.sequences.v11.5.fa",
		        "enrichment_path": "476272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "476272.protein.info.v11.5.txt",
		        "node_list_path": "476272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "476272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpAsbs410Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ASBs410 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpAsbs410Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304866.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304866.protein.info.v11.5.txt",
		        "node_list_path": "1304866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZymoseptoriaBrevisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymoseptoria brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymoseptoriaBrevisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1047168.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1047168.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1047168.clusters.proteins.v11.5.txt",
		        "sequence_path": "1047168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1047168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1047168.protein.info.v11.5.txt",
		        "node_list_path": "1047168.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1047168.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumSpAf6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumSpAf6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1325737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1325737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1325737.clusters.proteins.v11.5.txt",
		        "sequence_path": "1325737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325737.protein.info.v11.5.txt",
		        "node_list_path": "1325737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1325737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanibacterSpSoil728Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janibacter sp. Soil728 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterSpSoil728Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736393.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736393.protein.info.v11.5.txt",
		        "node_list_path": "1736393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwd23614Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWD2_36_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwd23614Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618758.protein.info.v11.5.txt",
		        "node_list_path": "1618758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaMirobrigensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora mirobrigensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaMirobrigensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "262898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "262898.clusters.proteins.v11.5.txt",
		        "sequence_path": "262898.protein.sequences.v11.5.fa",
		        "enrichment_path": "262898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262898.protein.info.v11.5.txt",
		        "node_list_path": "262898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "262898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesNdongoniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides ndongoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesNdongoniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1903262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903262.protein.info.v11.5.txt",
		        "node_list_path": "1903262.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasRuminantiumAc2024Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium AC2024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasRuminantiumAc2024Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392501.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392501.protein.info.v11.5.txt",
		        "node_list_path": "1392501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BeauveriaBassianaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Beauveria bassiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeauveriaBassianaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "176275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "176275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "176275.clusters.proteins.v11.5.txt",
		        "sequence_path": "176275.protein.sequences.v11.5.fa",
		        "enrichment_path": "176275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "176275.protein.info.v11.5.txt",
		        "node_list_path": "176275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "176275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonScgcAaa282K18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon SCGC AAA282-K18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonScgcAaa282K18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298885.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298885.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298885.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298885.protein.info.v11.5.txt",
		        "node_list_path": "1298885.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298885.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaTrematumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella trematum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaTrematumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "123899.clusters.info.v11.5.txt",
		        "cluster_tree_path": "123899.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "123899.clusters.proteins.v11.5.txt",
		        "sequence_path": "123899.protein.sequences.v11.5.fa",
		        "enrichment_path": "123899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "123899.protein.info.v11.5.txt",
		        "node_list_path": "123899.cluster.nodes.v11.5.txt",
		        "edge_list_path": "123899.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaSpSos3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia sp. SOS3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaSpSos3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1926494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926494.protein.info.v11.5.txt",
		        "node_list_path": "1926494.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterDefluvii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter defluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterDefluvii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385515.protein.info.v11.5.txt",
		        "node_list_path": "1385515.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumBrhC4a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRH_c4a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumBrhC4a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629716.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629716.protein.info.v11.5.txt",
		        "node_list_path": "1629716.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasBovis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasBovis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123250.protein.info.v11.5.txt",
		        "node_list_path": "1123250.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionKsb1Bacterium448487(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division KSB1 bacterium 4484_87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionKsb1Bacterium448487", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1970772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970772.protein.info.v11.5.txt",
		        "node_list_path": "1970772.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaSpPsnih2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. PSNIH2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpPsnih2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1484157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1484157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1484157.clusters.proteins.v11.5.txt",
		        "sequence_path": "1484157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484157.protein.info.v11.5.txt",
		        "node_list_path": "1484157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1484157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumDg743(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_74_3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumDg743", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703767.protein.info.v11.5.txt",
		        "node_list_path": "1703767.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobiBacteriumOlb7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobi bacterium OLB7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiBacteriumOlb7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619898.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619898.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619898.protein.info.v11.5.txt",
		        "node_list_path": "1619898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DanioRerio(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Danio rerio graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DanioRerio", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7955.protein.sequences.v11.5.fa",
		        "enrichment_path": "7955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7955.protein.info.v11.5.txt",
		        "node_list_path": "7955.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpLeaf325Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf325 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpLeaf325Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736337.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736337.protein.info.v11.5.txt",
		        "node_list_path": "1736337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaBrennaborense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema brennaborense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaBrennaborense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "906968.protein.sequences.v11.5.fa",
		        "enrichment_path": "906968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "906968.protein.info.v11.5.txt",
		        "node_list_path": "906968.protein.complete.v11.5.txt"
		    }
		]
    )()

def SutterellaWadsworthensisHga0223Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis HGA0223 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SutterellaWadsworthensisHga0223Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203554.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203554.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203554.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203554.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203554.protein.info.v11.5.txt",
		        "node_list_path": "1203554.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203554.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumA37t11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium A37T11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumA37t11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855384.protein.info.v11.5.txt",
		        "node_list_path": "1855384.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanogenicArchaeonMixedCultureIso4G1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return methanogenic archaeon mixed culture ISO4-G1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanogenicArchaeonMixedCultureIso4G1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1452364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1452364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1452364.protein.info.v11.5.txt",
		        "node_list_path": "1452364.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesThermoautotrophicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces thermoautotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesThermoautotrophicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1469144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469144.protein.info.v11.5.txt",
		        "node_list_path": "1469144.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinomonasSpSbi22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. SBI22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasSpSbi22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1561206.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561206.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561206.protein.info.v11.5.txt",
		        "node_list_path": "1561206.protein.complete.v11.5.txt"
		    }
		]
    )()

def FicedulaAlbicollisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ficedula albicollis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FicedulaAlbicollisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59894.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59894.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59894.clusters.proteins.v11.5.txt",
		        "sequence_path": "59894.protein.sequences.v11.5.fa",
		        "enrichment_path": "59894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59894.protein.info.v11.5.txt",
		        "node_list_path": "59894.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59894.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HolophagaFoetidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Holophaga foetida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HolophagaFoetidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "903818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "903818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "903818.clusters.proteins.v11.5.txt",
		        "sequence_path": "903818.protein.sequences.v11.5.fa",
		        "enrichment_path": "903818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "903818.protein.info.v11.5.txt",
		        "node_list_path": "903818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "903818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrospiraPlatensisNies39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrospira platensis NIES39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrospiraPlatensisNies39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "696747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "696747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "696747.clusters.proteins.v11.5.txt",
		        "sequence_path": "696747.protein.sequences.v11.5.fa",
		        "enrichment_path": "696747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696747.protein.info.v11.5.txt",
		        "node_list_path": "696747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "696747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CroceicoccusPelagius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Croceicoccus pelagius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CroceicoccusPelagius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703341.protein.info.v11.5.txt",
		        "node_list_path": "1703341.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraSpMccc1a02491(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A02491 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraSpMccc1a02491", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1769751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1769751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1769751.protein.info.v11.5.txt",
		        "node_list_path": "1769751.protein.complete.v11.5.txt"
		    }
		]
    )()

def CeraceosorusBombacis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ceraceosorus bombacis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeraceosorusBombacis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "401625.protein.sequences.v11.5.fa",
		        "enrichment_path": "401625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "401625.protein.info.v11.5.txt",
		        "node_list_path": "401625.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosaetaHarundinacea6ac(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosaeta harundinacea 6Ac graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosaetaHarundinacea6ac", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1110509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1110509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1110509.protein.info.v11.5.txt",
		        "node_list_path": "1110509.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusTolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius tolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusTolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "74031.protein.sequences.v11.5.fa",
		        "enrichment_path": "74031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74031.protein.info.v11.5.txt",
		        "node_list_path": "74031.protein.complete.v11.5.txt"
		    }
		]
    )()

def PandoraeaPulmonicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea pulmonicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaPulmonicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93221.protein.sequences.v11.5.fa",
		        "enrichment_path": "93221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93221.protein.info.v11.5.txt",
		        "node_list_path": "93221.protein.complete.v11.5.txt"
		    }
		]
    )()

def GiesbergeriaAnulusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Giesbergeria anulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GiesbergeriaAnulusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "180197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "180197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "180197.clusters.proteins.v11.5.txt",
		        "sequence_path": "180197.protein.sequences.v11.5.fa",
		        "enrichment_path": "180197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180197.protein.info.v11.5.txt",
		        "node_list_path": "180197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "180197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumInersCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium iners Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumInersCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1073423.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1073423.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1073423.clusters.proteins.v11.5.txt",
		        "sequence_path": "1073423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073423.protein.info.v11.5.txt",
		        "node_list_path": "1073423.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1073423.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DolosicoccusPaucivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dolosicoccus paucivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DolosicoccusPaucivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84521.protein.sequences.v11.5.fa",
		        "enrichment_path": "84521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84521.protein.info.v11.5.txt",
		        "node_list_path": "84521.protein.complete.v11.5.txt"
		    }
		]
    )()

def PandoraeaFaecigallinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea faecigallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaFaecigallinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "656179.protein.sequences.v11.5.fa",
		        "enrichment_path": "656179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656179.protein.info.v11.5.txt",
		        "node_list_path": "656179.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpLeaf261(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. Leaf261 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpLeaf261", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736311.protein.info.v11.5.txt",
		        "node_list_path": "1736311.protein.complete.v11.5.txt"
		    }
		]
    )()

def LabrysSpWjwCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Labrys sp. WJW Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrysSpWjwCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1737983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1737983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1737983.clusters.proteins.v11.5.txt",
		        "sequence_path": "1737983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1737983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1737983.protein.info.v11.5.txt",
		        "node_list_path": "1737983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1737983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PochoniaChlamydosporia170(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pochonia chlamydosporia 170 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PochoniaChlamydosporia170", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380566.protein.info.v11.5.txt",
		        "node_list_path": "1380566.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumUj101(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium UJ101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumUj101", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150389.protein.info.v11.5.txt",
		        "node_list_path": "1150389.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarineActinobacteriumMedacidiG2bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G2B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineActinobacteriumMedacidiG2bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1550401.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1550401.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1550401.clusters.proteins.v11.5.txt",
		        "sequence_path": "1550401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550401.protein.info.v11.5.txt",
		        "node_list_path": "1550401.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1550401.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusPicturae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus picturae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusPicturae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "171693.protein.sequences.v11.5.fa",
		        "enrichment_path": "171693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "171693.protein.info.v11.5.txt",
		        "node_list_path": "171693.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusRaffinolactisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusRaffinolactisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1215915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1215915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1215915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1215915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215915.protein.info.v11.5.txt",
		        "node_list_path": "1215915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1215915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaPaurometabolicaYim90007(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora paurometabolica YIM 90007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaPaurometabolicaYim90007", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "882084.protein.sequences.v11.5.fa",
		        "enrichment_path": "882084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882084.protein.info.v11.5.txt",
		        "node_list_path": "882084.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteroidesImmunogenum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacteroides immunogenum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteroidesImmunogenum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83262.protein.sequences.v11.5.fa",
		        "enrichment_path": "83262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83262.protein.info.v11.5.txt",
		        "node_list_path": "83262.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphacelomaMurrayaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaceloma murrayae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphacelomaMurrayaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2082308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2082308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2082308.clusters.proteins.v11.5.txt",
		        "sequence_path": "2082308.protein.sequences.v11.5.fa",
		        "enrichment_path": "2082308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2082308.protein.info.v11.5.txt",
		        "node_list_path": "2082308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2082308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SmithellaSpM82Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Smithella sp. M82 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmithellaSpM82Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1678137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1678137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1678137.clusters.proteins.v11.5.txt",
		        "sequence_path": "1678137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678137.protein.info.v11.5.txt",
		        "node_list_path": "1678137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1678137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorellaVariabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorella variabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorellaVariabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "554065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "554065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "554065.clusters.proteins.v11.5.txt",
		        "sequence_path": "554065.protein.sequences.v11.5.fa",
		        "enrichment_path": "554065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "554065.protein.info.v11.5.txt",
		        "node_list_path": "554065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "554065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpF0442(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0442 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpF0442", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999425.protein.sequences.v11.5.fa",
		        "enrichment_path": "999425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999425.protein.info.v11.5.txt",
		        "node_list_path": "999425.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpPanFs17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. PAN_FS17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpPanFs17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855351.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855351.protein.info.v11.5.txt",
		        "node_list_path": "1855351.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAtroolivaceusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces atroolivaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAtroolivaceusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66869.clusters.proteins.v11.5.txt",
		        "sequence_path": "66869.protein.sequences.v11.5.fa",
		        "enrichment_path": "66869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66869.protein.info.v11.5.txt",
		        "node_list_path": "66869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KetogulonicigeniumVulgareY25Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ketogulonicigenium vulgare Y25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KetogulonicigeniumVulgareY25Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "880591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "880591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "880591.clusters.proteins.v11.5.txt",
		        "sequence_path": "880591.protein.sequences.v11.5.fa",
		        "enrichment_path": "880591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880591.protein.info.v11.5.txt",
		        "node_list_path": "880591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "880591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumPeregrinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium peregrinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumPeregrinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43304.clusters.proteins.v11.5.txt",
		        "sequence_path": "43304.protein.sequences.v11.5.fa",
		        "enrichment_path": "43304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43304.protein.info.v11.5.txt",
		        "node_list_path": "43304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpW8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. W8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpW8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "613199.protein.sequences.v11.5.fa",
		        "enrichment_path": "613199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "613199.protein.info.v11.5.txt",
		        "node_list_path": "613199.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumGw2011Gwa2377(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_37_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa2377", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618481.protein.info.v11.5.txt",
		        "node_list_path": "1618481.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaTuronicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma turonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaTuronicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "216946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "216946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "216946.clusters.proteins.v11.5.txt",
		        "sequence_path": "216946.protein.sequences.v11.5.fa",
		        "enrichment_path": "216946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216946.protein.info.v11.5.txt",
		        "node_list_path": "216946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "216946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaWaltersiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella waltersii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaWaltersiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66969.clusters.proteins.v11.5.txt",
		        "sequence_path": "66969.protein.sequences.v11.5.fa",
		        "enrichment_path": "66969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66969.protein.info.v11.5.txt",
		        "node_list_path": "66969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaVervacti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea vervacti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaVervacti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "656178.protein.sequences.v11.5.fa",
		        "enrichment_path": "656178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656178.protein.info.v11.5.txt",
		        "node_list_path": "656178.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosarcinaSpBus5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosarcina sp. BuS5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosarcinaSpBus5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "933262.clusters.info.v11.5.txt",
		        "cluster_tree_path": "933262.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "933262.clusters.proteins.v11.5.txt",
		        "sequence_path": "933262.protein.sequences.v11.5.fa",
		        "enrichment_path": "933262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933262.protein.info.v11.5.txt",
		        "node_list_path": "933262.cluster.nodes.v11.5.txt",
		        "edge_list_path": "933262.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSubterraneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSubterraneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "285983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "285983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "285983.clusters.proteins.v11.5.txt",
		        "sequence_path": "285983.protein.sequences.v11.5.fa",
		        "enrichment_path": "285983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285983.protein.info.v11.5.txt",
		        "node_list_path": "285983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "285983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EthanoligenensHarbinense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ethanoligenens harbinense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EthanoligenensHarbinense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "663278.protein.sequences.v11.5.fa",
		        "enrichment_path": "663278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663278.protein.info.v11.5.txt",
		        "node_list_path": "663278.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusLactolyticusAtcc51172Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus ATCC51172 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusLactolyticusAtcc51172Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525254.clusters.proteins.v11.5.txt",
		        "sequence_path": "525254.protein.sequences.v11.5.fa",
		        "enrichment_path": "525254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525254.protein.info.v11.5.txt",
		        "node_list_path": "525254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinocyclocheilusRhinocerousCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinocyclocheilus rhinocerous Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinocyclocheilusRhinocerousCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "307959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "307959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "307959.clusters.proteins.v11.5.txt",
		        "sequence_path": "307959.protein.sequences.v11.5.fa",
		        "enrichment_path": "307959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "307959.protein.info.v11.5.txt",
		        "node_list_path": "307959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "307959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumPopuletiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] populeti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPopuletiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37658.clusters.proteins.v11.5.txt",
		        "sequence_path": "37658.protein.sequences.v11.5.fa",
		        "enrichment_path": "37658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37658.protein.info.v11.5.txt",
		        "node_list_path": "37658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SorangiineaeBacteriumNic37a2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sorangiineae bacterium NIC37A_2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SorangiineaeBacteriumNic37a2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1970199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1970199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1970199.clusters.proteins.v11.5.txt",
		        "sequence_path": "1970199.protein.sequences.v11.5.fa",
		        "enrichment_path": "1970199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1970199.protein.info.v11.5.txt",
		        "node_list_path": "1970199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1970199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpGxf4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. GXF4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpGxf4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1096546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1096546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1096546.protein.info.v11.5.txt",
		        "node_list_path": "1096546.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinocatenisporaSera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinocatenispora sera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinocatenisporaSera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "390989.protein.sequences.v11.5.fa",
		        "enrichment_path": "390989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390989.protein.info.v11.5.txt",
		        "node_list_path": "390989.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobonumTyrrellensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobonum tyrrellensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobonumTyrrellensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1324957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1324957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1324957.clusters.proteins.v11.5.txt",
		        "sequence_path": "1324957.protein.sequences.v11.5.fa",
		        "enrichment_path": "1324957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1324957.protein.info.v11.5.txt",
		        "node_list_path": "1324957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1324957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EsoxLuciusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Esox lucius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EsoxLuciusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8010.clusters.proteins.v11.5.txt",
		        "sequence_path": "8010.protein.sequences.v11.5.fa",
		        "enrichment_path": "8010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8010.protein.info.v11.5.txt",
		        "node_list_path": "8010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinophagaceaeBacteriumIbvucb2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium IBVUCB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaceaeBacteriumIbvucb2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1985174.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1985174.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1985174.clusters.proteins.v11.5.txt",
		        "sequence_path": "1985174.protein.sequences.v11.5.fa",
		        "enrichment_path": "1985174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1985174.protein.info.v11.5.txt",
		        "node_list_path": "1985174.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1985174.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNecrophorumD12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum D12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNecrophorumD12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "556263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "556263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "556263.clusters.proteins.v11.5.txt",
		        "sequence_path": "556263.protein.sequences.v11.5.fa",
		        "enrichment_path": "556263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556263.protein.info.v11.5.txt",
		        "node_list_path": "556263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "556263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacteriumSp457220(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterium sp. 4572_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteriumSp457220", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1971621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971621.protein.info.v11.5.txt",
		        "node_list_path": "1971621.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmazonaAestivaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amazona aestiva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmazonaAestivaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "12930.clusters.info.v11.5.txt",
		        "cluster_tree_path": "12930.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "12930.clusters.proteins.v11.5.txt",
		        "sequence_path": "12930.protein.sequences.v11.5.fa",
		        "enrichment_path": "12930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "12930.protein.info.v11.5.txt",
		        "node_list_path": "12930.cluster.nodes.v11.5.txt",
		        "edge_list_path": "12930.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwd23811(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWD2_38_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwd23811", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618941.protein.info.v11.5.txt",
		        "node_list_path": "1618941.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaAcaciaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia acaciae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaAcaciaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123023.protein.info.v11.5.txt",
		        "node_list_path": "1123023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HirschiaMaritima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hirschia maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HirschiaMaritima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "551275.protein.sequences.v11.5.fa",
		        "enrichment_path": "551275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551275.protein.info.v11.5.txt",
		        "node_list_path": "551275.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumGw2011Gwa14311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA1_43_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa14311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618436.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618436.protein.info.v11.5.txt",
		        "node_list_path": "1618436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterSpVk13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. VK13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterSpVk13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1938817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1938817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1938817.clusters.proteins.v11.5.txt",
		        "sequence_path": "1938817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938817.protein.info.v11.5.txt",
		        "node_list_path": "1938817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1938817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPactumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces pactum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPactumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68249.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68249.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68249.clusters.proteins.v11.5.txt",
		        "sequence_path": "68249.protein.sequences.v11.5.fa",
		        "enrichment_path": "68249.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68249.protein.info.v11.5.txt",
		        "node_list_path": "68249.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68249.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisHaa2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris HaA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisHaa2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316058.clusters.proteins.v11.5.txt",
		        "sequence_path": "316058.protein.sequences.v11.5.fa",
		        "enrichment_path": "316058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316058.protein.info.v11.5.txt",
		        "node_list_path": "316058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptosporidiumMurisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporidium muris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptosporidiumMurisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5808.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5808.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5808.clusters.proteins.v11.5.txt",
		        "sequence_path": "5808.protein.sequences.v11.5.fa",
		        "enrichment_path": "5808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5808.protein.info.v11.5.txt",
		        "node_list_path": "5808.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5808.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpErgs101Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ERGS1:01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpErgs101Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1704044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1704044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1704044.clusters.proteins.v11.5.txt",
		        "sequence_path": "1704044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1704044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1704044.protein.info.v11.5.txt",
		        "node_list_path": "1704044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1704044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnabaenaSpWa102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anabaena sp. WA102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabaenaSpWa102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1647413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1647413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1647413.protein.info.v11.5.txt",
		        "node_list_path": "1647413.protein.complete.v11.5.txt"
		    }
		]
    )()

def CulturomicaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Culturomica massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CulturomicaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841857.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841857.protein.info.v11.5.txt",
		        "node_list_path": "1841857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAtribacteriaBacteriumRbg19ftCombo3514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atribacteria bacterium RBG_19FT_COMBO_35_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAtribacteriaBacteriumRbg19ftCombo3514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797291.protein.info.v11.5.txt",
		        "node_list_path": "1797291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HippeaMaritima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hippea maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HippeaMaritima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "760142.protein.sequences.v11.5.fa",
		        "enrichment_path": "760142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "760142.protein.info.v11.5.txt",
		        "node_list_path": "760142.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronorubrumBangense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronorubrum bangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronorubrumBangense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227500.protein.info.v11.5.txt",
		        "node_list_path": "1227500.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4518Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_45_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4518Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802707.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802707.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802707.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802707.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802707.protein.info.v11.5.txt",
		        "node_list_path": "1802707.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802707.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VitellibacterAquimaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vitellibacter aquimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VitellibacterAquimaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1548749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548749.protein.info.v11.5.txt",
		        "node_list_path": "1548749.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSpCg3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. CG3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSpCg3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1075768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1075768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1075768.protein.info.v11.5.txt",
		        "node_list_path": "1075768.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarineActinobacteriumMedacidiG3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineActinobacteriumMedacidiG3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1550402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1550402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1550402.clusters.proteins.v11.5.txt",
		        "sequence_path": "1550402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550402.protein.info.v11.5.txt",
		        "node_list_path": "1550402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1550402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassiosiraPseudonanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassiosira pseudonana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassiosiraPseudonanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35128.clusters.proteins.v11.5.txt",
		        "sequence_path": "35128.protein.sequences.v11.5.fa",
		        "enrichment_path": "35128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35128.protein.info.v11.5.txt",
		        "node_list_path": "35128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitratireductorAquibiodomus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitratireductor aquibiodomus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratireductorAquibiodomus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231185.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231185.protein.info.v11.5.txt",
		        "node_list_path": "1231185.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionSr1BacteriumAalborgAaw1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division SR1 bacterium Aalborg_AAW-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionSr1BacteriumAalborgAaw1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1643353.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1643353.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1643353.clusters.proteins.v11.5.txt",
		        "sequence_path": "1643353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643353.protein.info.v11.5.txt",
		        "node_list_path": "1643353.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1643353.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitromicrobiumSpJl477Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citromicrobium sp. JL477 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitromicrobiumSpJl477Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1634516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1634516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1634516.clusters.proteins.v11.5.txt",
		        "sequence_path": "1634516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1634516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1634516.protein.info.v11.5.txt",
		        "node_list_path": "1634516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1634516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriMf28(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri MF28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriMf28", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1333856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333856.protein.info.v11.5.txt",
		        "node_list_path": "1333856.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobulbaceaeBacteriumDb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbaceae bacterium DB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbaceaeBacteriumDb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1920419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1920419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1920419.clusters.proteins.v11.5.txt",
		        "sequence_path": "1920419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920419.protein.info.v11.5.txt",
		        "node_list_path": "1920419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1920419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumMobileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium mobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumMobileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449342.protein.info.v11.5.txt",
		        "node_list_path": "1449342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PocilloporaDamicornis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pocillopora damicornis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PocilloporaDamicornis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46731.protein.sequences.v11.5.fa",
		        "enrichment_path": "46731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46731.protein.info.v11.5.txt",
		        "node_list_path": "46731.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterLudwigiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter ludwigii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterLudwigiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "299767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "299767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "299767.clusters.proteins.v11.5.txt",
		        "sequence_path": "299767.protein.sequences.v11.5.fa",
		        "enrichment_path": "299767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299767.protein.info.v11.5.txt",
		        "node_list_path": "299767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "299767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprococcusCatusGd7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus catus GD/7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprococcusCatusGd7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717962.clusters.proteins.v11.5.txt",
		        "sequence_path": "717962.protein.sequences.v11.5.fa",
		        "enrichment_path": "717962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717962.protein.info.v11.5.txt",
		        "node_list_path": "717962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterNanhaiticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter nanhaiticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterNanhaiticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "626887.protein.sequences.v11.5.fa",
		        "enrichment_path": "626887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "626887.protein.info.v11.5.txt",
		        "node_list_path": "626887.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumSpLf3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. LF3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumSpLf3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1504823.protein.sequences.v11.0.fa",
		        "enrichment_path": "1504823.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1504823.protein.info.v11.0.txt",
		        "node_list_path": "1504823.protein.complete.v11.0.txt"
		    }
		]
    )()

def XenorhabdusKhoisanae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus khoisanae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusKhoisanae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "880157.protein.sequences.v11.5.fa",
		        "enrichment_path": "880157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880157.protein.info.v11.5.txt",
		        "node_list_path": "880157.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfobacteriumGeofontisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium geofontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfobacteriumGeofontisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "795359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "795359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "795359.clusters.proteins.v11.5.txt",
		        "sequence_path": "795359.protein.sequences.v11.5.fa",
		        "enrichment_path": "795359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "795359.protein.info.v11.5.txt",
		        "node_list_path": "795359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "795359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SmithellaSpScadcCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Smithella sp. SCADC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmithellaSpScadcCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499107.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499107.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499107.protein.info.v11.5.txt",
		        "node_list_path": "1499107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacteriumRifoxya2Full329(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFOXYA2_FULL_32_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifoxya2Full329", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801611.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801611.protein.info.v11.5.txt",
		        "node_list_path": "1801611.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSp1501Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. 1501 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSp1501Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1002339.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1002339.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1002339.clusters.proteins.v11.5.txt",
		        "sequence_path": "1002339.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002339.protein.info.v11.5.txt",
		        "node_list_path": "1002339.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1002339.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudanabaenaSpPcc6802Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudanabaena sp. PCC6802 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudanabaenaSpPcc6802Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118173.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118173.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118173.clusters.proteins.v11.5.txt",
		        "sequence_path": "118173.protein.sequences.v11.5.fa",
		        "enrichment_path": "118173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118173.protein.info.v11.5.txt",
		        "node_list_path": "118173.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118173.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShigellaDysenteriaeSd197(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shigella dysenteriae Sd197 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShigellaDysenteriaeSd197", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "300267.protein.sequences.v11.5.fa",
		        "enrichment_path": "300267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "300267.protein.info.v11.5.txt",
		        "node_list_path": "300267.protein.complete.v11.5.txt"
		    }
		]
    )()

def VenturiaNashicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Venturia nashicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VenturiaNashicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86259.protein.sequences.v11.5.fa",
		        "enrichment_path": "86259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86259.protein.info.v11.5.txt",
		        "node_list_path": "86259.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocCitreumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc citreum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocCitreumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349519.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349519.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349519.clusters.proteins.v11.5.txt",
		        "sequence_path": "349519.protein.sequences.v11.5.fa",
		        "enrichment_path": "349519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349519.protein.info.v11.5.txt",
		        "node_list_path": "349519.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349519.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasVancouverensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas vancouverensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasVancouverensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "95300.clusters.info.v11.5.txt",
		        "cluster_tree_path": "95300.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "95300.clusters.proteins.v11.5.txt",
		        "sequence_path": "95300.protein.sequences.v11.5.fa",
		        "enrichment_path": "95300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "95300.protein.info.v11.5.txt",
		        "node_list_path": "95300.cluster.nodes.v11.5.txt",
		        "edge_list_path": "95300.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaOralisAtcc33269(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oralis ATCC33269 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaOralisAtcc33269", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "873533.protein.sequences.v11.5.fa",
		        "enrichment_path": "873533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "873533.protein.info.v11.5.txt",
		        "node_list_path": "873533.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumT5Br10B2g0Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium T5-Br10_B2g0 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumT5Br10B2g0Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729469.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729469.protein.info.v11.5.txt",
		        "node_list_path": "1729469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrolunatusSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microlunatus soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrolunatusSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "630515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "630515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "630515.clusters.proteins.v11.5.txt",
		        "sequence_path": "630515.protein.sequences.v11.5.fa",
		        "enrichment_path": "630515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "630515.protein.info.v11.5.txt",
		        "node_list_path": "630515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "630515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OblitimonasAlkaliphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oblitimonas alkaliphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OblitimonasAlkaliphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1697053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1697053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1697053.clusters.proteins.v11.5.txt",
		        "sequence_path": "1697053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1697053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1697053.protein.info.v11.5.txt",
		        "node_list_path": "1697053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1697053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasCassavae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas cassavae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCassavae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219375.protein.info.v11.5.txt",
		        "node_list_path": "1219375.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonascusPurpureusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monascus purpureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonascusPurpureusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5098.clusters.proteins.v11.5.txt",
		        "sequence_path": "5098.protein.sequences.v11.5.fa",
		        "enrichment_path": "5098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5098.protein.info.v11.5.txt",
		        "node_list_path": "5098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumPaxllaeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium paxllaeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumPaxllaeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "190148.protein.sequences.v11.5.fa",
		        "enrichment_path": "190148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190148.protein.info.v11.5.txt",
		        "node_list_path": "190148.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusFasciansD188(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus fascians D188 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusFasciansD188", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1051973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051973.protein.info.v11.5.txt",
		        "node_list_path": "1051973.protein.complete.v11.5.txt"
		    }
		]
    )()

def FormosaSpAk20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Formosa sp. AK20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaSpAk20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1137281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1137281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1137281.clusters.proteins.v11.5.txt",
		        "sequence_path": "1137281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137281.protein.info.v11.5.txt",
		        "node_list_path": "1137281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1137281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgiphilusAromaticivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algiphilus aromaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgiphilusAromaticivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415780.protein.info.v11.5.txt",
		        "node_list_path": "1415780.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrigoribacteriumSpLeaf186(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf186 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrigoribacteriumSpLeaf186", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736293.protein.info.v11.5.txt",
		        "node_list_path": "1736293.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusAzorensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius azorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusAzorensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1287727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287727.protein.info.v11.5.txt",
		        "node_list_path": "1287727.protein.complete.v11.5.txt"
		    }
		]
    )()

def SclerotiniaBorealisF4128(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sclerotinia borealis F-4128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SclerotiniaBorealisF4128", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1432307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432307.protein.info.v11.5.txt",
		        "node_list_path": "1432307.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5008Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5008Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463853.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463853.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463853.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463853.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463853.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463853.protein.info.v11.5.txt",
		        "node_list_path": "1463853.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463853.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulophagaTyrosinoxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga tyrosinoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaTyrosinoxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "504486.protein.sequences.v11.5.fa",
		        "enrichment_path": "504486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504486.protein.info.v11.5.txt",
		        "node_list_path": "504486.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParastagonosporaNodorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parastagonospora nodorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParastagonosporaNodorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13684.clusters.proteins.v11.5.txt",
		        "sequence_path": "13684.protein.sequences.v11.5.fa",
		        "enrichment_path": "13684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13684.protein.info.v11.5.txt",
		        "node_list_path": "13684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiaBacteriumTcs55(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiaBacteriumTcs55", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1781246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1781246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1781246.protein.info.v11.5.txt",
		        "node_list_path": "1781246.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobaculumSuisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum suis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobaculumSuisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1657.clusters.proteins.v11.5.txt",
		        "sequence_path": "1657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1657.protein.info.v11.5.txt",
		        "node_list_path": "1657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSpechtbacteriaBacteriumRifcsphigho201Full4330Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPHIGHO2_01_FULL_43_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsphigho201Full4330Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802158.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802158.protein.info.v11.5.txt",
		        "node_list_path": "1802158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodotorulaTaiwanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodotorulaTaiwanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "741276.protein.sequences.v11.5.fa",
		        "enrichment_path": "741276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "741276.protein.info.v11.5.txt",
		        "node_list_path": "741276.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenimonasThermophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenimonas thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenimonasThermophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "223786.clusters.info.v11.5.txt",
		        "cluster_tree_path": "223786.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "223786.clusters.proteins.v11.5.txt",
		        "sequence_path": "223786.protein.sequences.v11.5.fa",
		        "enrichment_path": "223786.protein.enrichment.terms.v11.5.txt",
		        "info_path": "223786.protein.info.v11.5.txt",
		        "node_list_path": "223786.cluster.nodes.v11.5.txt",
		        "edge_list_path": "223786.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumSpAk27(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium sp. AK27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumSpAk27", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232683.protein.info.v11.5.txt",
		        "node_list_path": "1232683.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulosimicrobiumSpTh20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulosimicrobium sp. TH-20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulosimicrobiumSpTh20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1980001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1980001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1980001.protein.info.v11.5.txt",
		        "node_list_path": "1980001.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpRoot265(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Root265 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpRoot265", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736504.protein.info.v11.5.txt",
		        "node_list_path": "1736504.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaSpHmsc071c03(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC071C03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSpHmsc071c03", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739257.protein.info.v11.5.txt",
		        "node_list_path": "1739257.protein.complete.v11.5.txt"
		    }
		]
    )()

def DomibacillusAntriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus antri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusAntriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1714264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1714264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1714264.clusters.proteins.v11.5.txt",
		        "sequence_path": "1714264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714264.protein.info.v11.5.txt",
		        "node_list_path": "1714264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1714264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VulcanisaetaThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vulcanisaeta thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulcanisaetaThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "867917.protein.sequences.v11.5.fa",
		        "enrichment_path": "867917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867917.protein.info.v11.5.txt",
		        "node_list_path": "867917.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSp109(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. 109 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSp109", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150399.protein.info.v11.5.txt",
		        "node_list_path": "1150399.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodotorulaDiobovata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula diobovata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodotorulaDiobovata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5288.protein.sequences.v11.5.fa",
		        "enrichment_path": "5288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5288.protein.info.v11.5.txt",
		        "node_list_path": "5288.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpLq44Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. LQ44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpLq44Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1749259.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1749259.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1749259.clusters.proteins.v11.5.txt",
		        "sequence_path": "1749259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1749259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1749259.protein.info.v11.5.txt",
		        "node_list_path": "1749259.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1749259.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JiangellaGansuensisDsm44835(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jiangella gansuensis DSM 44835 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JiangellaGansuensisDsm44835", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "987045.protein.sequences.v11.5.fa",
		        "enrichment_path": "987045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "987045.protein.info.v11.5.txt",
		        "node_list_path": "987045.protein.complete.v11.5.txt"
		    }
		]
    )()

def SlackiaExiguaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Slackia exigua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SlackiaExiguaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649764.clusters.proteins.v11.5.txt",
		        "sequence_path": "649764.protein.sequences.v11.5.fa",
		        "enrichment_path": "649764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649764.protein.info.v11.5.txt",
		        "node_list_path": "649764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4013Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_40_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4013Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802063.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802063.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802063.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802063.protein.info.v11.5.txt",
		        "node_list_path": "1802063.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802063.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermopetrobacterSpTc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermopetrobacter sp. TC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermopetrobacterSpTc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1495045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1495045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1495045.clusters.proteins.v11.5.txt",
		        "sequence_path": "1495045.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495045.protein.info.v11.5.txt",
		        "node_list_path": "1495045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1495045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelodictyonPhaeoclathratiformeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelodictyon phaeoclathratiforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelodictyonPhaeoclathratiformeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "324925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "324925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "324925.clusters.proteins.v11.5.txt",
		        "sequence_path": "324925.protein.sequences.v11.5.fa",
		        "enrichment_path": "324925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "324925.protein.info.v11.5.txt",
		        "node_list_path": "324925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "324925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusParabuchneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus parabuchneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParabuchneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "152331.protein.sequences.v11.5.fa",
		        "enrichment_path": "152331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "152331.protein.info.v11.5.txt",
		        "node_list_path": "152331.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophomonasSpDtu018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas sp. DTU018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophomonasSpDtu018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671629.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671629.protein.info.v11.5.txt",
		        "node_list_path": "1671629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumProfundumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium profundum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumProfundumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "298386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "298386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "298386.clusters.proteins.v11.5.txt",
		        "sequence_path": "298386.protein.sequences.v11.5.fa",
		        "enrichment_path": "298386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "298386.protein.info.v11.5.txt",
		        "node_list_path": "298386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "298386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliellaGariniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borreliella garinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliellaGariniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29519.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29519.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29519.clusters.proteins.v11.5.txt",
		        "sequence_path": "29519.protein.sequences.v11.5.fa",
		        "enrichment_path": "29519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29519.protein.info.v11.5.txt",
		        "node_list_path": "29519.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29519.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudooceanicolaFlagellatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudooceanicola flagellatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudooceanicolaFlagellatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1387277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1387277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1387277.clusters.proteins.v11.5.txt",
		        "sequence_path": "1387277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387277.protein.info.v11.5.txt",
		        "node_list_path": "1387277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1387277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterHormaecheiSubspOharaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. oharae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterHormaecheiSubspOharaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "301102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "301102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "301102.clusters.proteins.v11.5.txt",
		        "sequence_path": "301102.protein.sequences.v11.5.fa",
		        "enrichment_path": "301102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "301102.protein.info.v11.5.txt",
		        "node_list_path": "301102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "301102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaBovisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaBovisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "289397.clusters.info.v11.5.txt",
		        "cluster_tree_path": "289397.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "289397.clusters.proteins.v11.5.txt",
		        "sequence_path": "289397.protein.sequences.v11.5.fa",
		        "enrichment_path": "289397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "289397.protein.info.v11.5.txt",
		        "node_list_path": "289397.cluster.nodes.v11.5.txt",
		        "edge_list_path": "289397.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasZinciduransB6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas zincidurans B6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasZinciduransB6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1446475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1446475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1446475.clusters.proteins.v11.5.txt",
		        "sequence_path": "1446475.protein.sequences.v11.5.fa",
		        "enrichment_path": "1446475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1446475.protein.info.v11.5.txt",
		        "node_list_path": "1446475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1446475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasSpCy54118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. CY54118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSpCy54118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280944.protein.info.v11.5.txt",
		        "node_list_path": "1280944.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumChlorophenolicumL1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium chlorophenolicum L-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumChlorophenolicumL1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "690566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "690566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "690566.clusters.proteins.v11.5.txt",
		        "sequence_path": "690566.protein.sequences.v11.5.fa",
		        "enrichment_path": "690566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690566.protein.info.v11.5.txt",
		        "node_list_path": "690566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "690566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumF0431Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium F0431 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumF0431Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "861454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "861454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "861454.clusters.proteins.v11.5.txt",
		        "sequence_path": "861454.protein.sequences.v11.5.fa",
		        "enrichment_path": "861454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861454.protein.info.v11.5.txt",
		        "node_list_path": "861454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "861454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasEndodontalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas endodontalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasEndodontalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553175.protein.sequences.v11.5.fa",
		        "enrichment_path": "553175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553175.protein.info.v11.5.txt",
		        "node_list_path": "553175.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumDtu084Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU084 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumDtu084Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671642.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671642.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671642.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671642.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671642.protein.info.v11.5.txt",
		        "node_list_path": "1671642.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671642.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaConspicua(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea conspicua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaConspicua", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "472705.protein.sequences.v11.5.fa",
		        "enrichment_path": "472705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472705.protein.info.v11.5.txt",
		        "node_list_path": "472705.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAb2028Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AB2028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAb2028Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408319.protein.info.v11.5.txt",
		        "node_list_path": "1408319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfurococcusKamchatkensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurococcus kamchatkensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurococcusKamchatkensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "490899.protein.sequences.v11.5.fa",
		        "enrichment_path": "490899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "490899.protein.info.v11.5.txt",
		        "node_list_path": "490899.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpLeaf225(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. Leaf225 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpLeaf225", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736300.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736300.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736300.protein.info.v11.5.txt",
		        "node_list_path": "1736300.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumLipophiloflavum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium lipophiloflavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumLipophiloflavum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525263.protein.sequences.v11.5.fa",
		        "enrichment_path": "525263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525263.protein.info.v11.5.txt",
		        "node_list_path": "525263.protein.complete.v11.5.txt"
		    }
		]
    )()

def RobbsiaAndropogonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Robbsia andropogonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RobbsiaAndropogonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28092.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28092.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28092.clusters.proteins.v11.5.txt",
		        "sequence_path": "28092.protein.sequences.v11.5.fa",
		        "enrichment_path": "28092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28092.protein.info.v11.5.txt",
		        "node_list_path": "28092.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28092.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassospiraXiamenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraXiamenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123366.protein.info.v11.5.txt",
		        "node_list_path": "1123366.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumVentriculi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium ventriculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumVentriculi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267.protein.info.v11.5.txt",
		        "node_list_path": "1267.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfonatronospiraThiodismutansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronospira thiodismutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronospiraThiodismutansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "555779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "555779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "555779.clusters.proteins.v11.5.txt",
		        "sequence_path": "555779.protein.sequences.v11.5.fa",
		        "enrichment_path": "555779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555779.protein.info.v11.5.txt",
		        "node_list_path": "555779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "555779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusPacificusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusPacificusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "337701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "337701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "337701.clusters.proteins.v11.5.txt",
		        "sequence_path": "337701.protein.sequences.v11.5.fa",
		        "enrichment_path": "337701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "337701.protein.info.v11.5.txt",
		        "node_list_path": "337701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "337701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeuconostocLactisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc lactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocLactisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1246.clusters.proteins.v11.5.txt",
		        "sequence_path": "1246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246.protein.info.v11.5.txt",
		        "node_list_path": "1246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc3832(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 3832 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc3832", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977874.protein.info.v11.5.txt",
		        "node_list_path": "1977874.protein.complete.v11.5.txt"
		    }
		]
    )()

def AurantimonasSp22ii1619iCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aurantimonas sp. 22II-16-19i Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AurantimonasSp22ii1619iCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1317114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1317114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1317114.clusters.proteins.v11.5.txt",
		        "sequence_path": "1317114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317114.protein.info.v11.5.txt",
		        "node_list_path": "1317114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1317114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusMindensisDsm14500Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mindensis DSM 14500 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMindensisDsm14500Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423770.protein.info.v11.5.txt",
		        "node_list_path": "1423770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlj7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlj7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158756.protein.info.v11.5.txt",
		        "node_list_path": "1158756.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5517(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_55_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5517", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798496.protein.info.v11.5.txt",
		        "node_list_path": "1798496.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumFlavum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium flavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumFlavum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1638981.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638981.protein.info.v11.5.txt",
		        "node_list_path": "1638981.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifoxya1Full4011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYA1_FULL_40_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxya1Full4011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802631.protein.info.v11.5.txt",
		        "node_list_path": "1802631.protein.complete.v11.5.txt"
		    }
		]
    )()

def UstilagoMaydis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ustilago maydis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UstilagoMaydis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5270.protein.sequences.v11.5.fa",
		        "enrichment_path": "5270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5270.protein.info.v11.5.txt",
		        "node_list_path": "5270.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusPantotrophusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus pantotrophus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusPantotrophusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935565.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935565.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935565.clusters.proteins.v11.5.txt",
		        "sequence_path": "935565.protein.sequences.v11.5.fa",
		        "enrichment_path": "935565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935565.protein.info.v11.5.txt",
		        "node_list_path": "935565.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935565.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpKordi49(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpKordi49", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585423.protein.sequences.v11.5.fa",
		        "enrichment_path": "585423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585423.protein.info.v11.5.txt",
		        "node_list_path": "585423.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusFusiformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus fusiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusFusiformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "714961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "714961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "714961.clusters.proteins.v11.5.txt",
		        "sequence_path": "714961.protein.sequences.v11.5.fa",
		        "enrichment_path": "714961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "714961.protein.info.v11.5.txt",
		        "node_list_path": "714961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "714961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKefiriDsm20587Jcm5818Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kefiri DSM 20587 JCM 5818 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKefiriDsm20587Jcm5818Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423764.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423764.protein.info.v11.5.txt",
		        "node_list_path": "1423764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyadobacterCrusticolaDsm16708Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter crusticola DSM 16708 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterCrusticolaDsm16708Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121483.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121483.protein.info.v11.5.txt",
		        "node_list_path": "1121483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GoniumPectorale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gonium pectorale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GoniumPectorale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33097.protein.sequences.v11.5.fa",
		        "enrichment_path": "33097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33097.protein.info.v11.5.txt",
		        "node_list_path": "33097.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaHumiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaHumiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "745366.clusters.info.v11.5.txt",
		        "cluster_tree_path": "745366.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "745366.clusters.proteins.v11.5.txt",
		        "sequence_path": "745366.protein.sequences.v11.5.fa",
		        "enrichment_path": "745366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745366.protein.info.v11.5.txt",
		        "node_list_path": "745366.cluster.nodes.v11.5.txt",
		        "edge_list_path": "745366.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KitasatosporaGriseolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora griseola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaGriseolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2064.clusters.proteins.v11.5.txt",
		        "sequence_path": "2064.protein.sequences.v11.5.fa",
		        "enrichment_path": "2064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2064.protein.info.v11.5.txt",
		        "node_list_path": "2064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WenxiniaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wenxinia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WenxiniaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123501.protein.info.v11.5.txt",
		        "node_list_path": "1123501.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloversatilisDiscipulorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloversatilis discipulorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloversatilisDiscipulorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1119528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1119528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1119528.protein.info.v11.5.txt",
		        "node_list_path": "1119528.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesMinimusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles minimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesMinimusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "112268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "112268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "112268.clusters.proteins.v11.5.txt",
		        "sequence_path": "112268.protein.sequences.v11.5.fa",
		        "enrichment_path": "112268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112268.protein.info.v11.5.txt",
		        "node_list_path": "112268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "112268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumGw2011Gwb24136Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWB2_41_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwb24136Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618982.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618982.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618982.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618982.protein.info.v11.5.txt",
		        "node_list_path": "1618982.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618982.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidithrixFerrooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidithrix ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithrixFerrooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280514.protein.info.v11.5.txt",
		        "node_list_path": "1280514.protein.complete.v11.5.txt"
		    }
		]
    )()

def SodalisPierantoniusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sodalis pierantonius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SodalisPierantoniusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2342.clusters.proteins.v11.5.txt",
		        "sequence_path": "2342.protein.sequences.v11.5.fa",
		        "enrichment_path": "2342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2342.protein.info.v11.5.txt",
		        "node_list_path": "2342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPristinaespiralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces pristinaespiralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPristinaespiralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "457429.protein.sequences.v11.5.fa",
		        "enrichment_path": "457429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457429.protein.info.v11.5.txt",
		        "node_list_path": "457429.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacterium3541(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium 35_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacterium3541", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897008.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897008.protein.info.v11.5.txt",
		        "node_list_path": "1897008.protein.complete.v11.5.txt"
		    }
		]
    )()

def LarimichthysCroceaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Larimichthys crocea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LarimichthysCroceaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "215358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "215358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "215358.clusters.proteins.v11.5.txt",
		        "sequence_path": "215358.protein.sequences.v11.5.fa",
		        "enrichment_path": "215358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215358.protein.info.v11.5.txt",
		        "node_list_path": "215358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "215358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErysipelothrixTonsillarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysipelothrix tonsillarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelothrixTonsillarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121874.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121874.protein.info.v11.5.txt",
		        "node_list_path": "1121874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrilyobacterAtlanticusDsm19335Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrilyobacter atlanticus DSM 19335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrilyobacterAtlanticusDsm19335Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123032.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123032.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123032.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123032.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123032.protein.info.v11.5.txt",
		        "node_list_path": "1123032.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123032.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp3j1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 3J1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp3j1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "861269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "861269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "861269.clusters.proteins.v11.5.txt",
		        "sequence_path": "861269.protein.sequences.v11.5.fa",
		        "enrichment_path": "861269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861269.protein.info.v11.5.txt",
		        "node_list_path": "861269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "861269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesBikiniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces bikiniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesBikiniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896.protein.info.v11.5.txt",
		        "node_list_path": "1896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeofamiliaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neofamilia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeofamiliaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1673724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673724.protein.info.v11.5.txt",
		        "node_list_path": "1673724.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpGa1285(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1285 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpGa1285", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1772282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772282.protein.info.v11.5.txt",
		        "node_list_path": "1772282.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasBivalvium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas bivalvium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasBivalvium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "440079.protein.sequences.v11.5.fa",
		        "enrichment_path": "440079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "440079.protein.info.v11.5.txt",
		        "node_list_path": "440079.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumL41a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium L41A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumL41a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229204.protein.info.v11.5.txt",
		        "node_list_path": "1229204.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionimicrobiumSpBv2f7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionimicrobium sp. BV2F7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionimicrobiumSpBv2f7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111131.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111131.protein.info.v11.5.txt",
		        "node_list_path": "1111131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermophagusXiamenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermophagus xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermophagusXiamenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "385682.protein.sequences.v11.5.fa",
		        "enrichment_path": "385682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "385682.protein.info.v11.5.txt",
		        "node_list_path": "385682.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachyspiraAlvinipulliAtcc51933Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira alvinipulli ATCC 51933 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraAlvinipulliAtcc51933Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408430.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408430.protein.info.v11.5.txt",
		        "node_list_path": "1408430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParasaccharibacterApium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parasaccharibacter apium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParasaccharibacterApium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1510841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1510841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1510841.protein.info.v11.5.txt",
		        "node_list_path": "1510841.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumMagneticumAmb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum magneticum AMB-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumMagneticumAmb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "342108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "342108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "342108.clusters.proteins.v11.5.txt",
		        "sequence_path": "342108.protein.sequences.v11.5.fa",
		        "enrichment_path": "342108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342108.protein.info.v11.5.txt",
		        "node_list_path": "342108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "342108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho201Full4216(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_42_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full4216", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801743.protein.info.v11.5.txt",
		        "node_list_path": "1801743.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumPyruvativoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium pyruvativorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumPyruvativoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "155865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "155865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "155865.clusters.proteins.v11.5.txt",
		        "sequence_path": "155865.protein.sequences.v11.5.fa",
		        "enrichment_path": "155865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "155865.protein.info.v11.5.txt",
		        "node_list_path": "155865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "155865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumGwf24413Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWF2_44_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumGwf24413Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801702.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801702.protein.info.v11.5.txt",
		        "node_list_path": "1801702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumFaniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium faniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumFaniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "570446.protein.sequences.v11.5.fa",
		        "enrichment_path": "570446.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570446.protein.info.v11.5.txt",
		        "node_list_path": "570446.protein.complete.v11.5.txt"
		    }
		]
    )()

def Haloarchaeon3a1dgr(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return haloarchaeon 3A1DGR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Haloarchaeon3a1dgr", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1071085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071085.protein.info.v11.5.txt",
		        "node_list_path": "1071085.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasTelluritireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas telluritireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasTelluritireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "162160.clusters.info.v11.5.txt",
		        "cluster_tree_path": "162160.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "162160.clusters.proteins.v11.5.txt",
		        "sequence_path": "162160.protein.sequences.v11.5.fa",
		        "enrichment_path": "162160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "162160.protein.info.v11.5.txt",
		        "node_list_path": "162160.cluster.nodes.v11.5.txt",
		        "edge_list_path": "162160.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FonticulaAlba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fonticula alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FonticulaAlba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "691883.protein.sequences.v11.5.fa",
		        "enrichment_path": "691883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "691883.protein.info.v11.5.txt",
		        "node_list_path": "691883.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3712(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_37_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3712", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802056.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802056.protein.info.v11.5.txt",
		        "node_list_path": "1802056.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumRifcsplowo201Full4314(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RIFCSPLOWO2_01_FULL_43_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRifcsplowo201Full4314", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802605.protein.info.v11.5.txt",
		        "node_list_path": "1802605.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicycliphilusDenitrificansK601Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans K601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicycliphilusDenitrificansK601Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "596154.clusters.info.v11.5.txt",
		        "cluster_tree_path": "596154.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "596154.clusters.proteins.v11.5.txt",
		        "sequence_path": "596154.protein.sequences.v11.5.fa",
		        "enrichment_path": "596154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596154.protein.info.v11.5.txt",
		        "node_list_path": "596154.cluster.nodes.v11.5.txt",
		        "edge_list_path": "596154.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPacebacteriaBacteriumRifcsphigho201Full4616(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFCSPHIGHO2_01_FULL_46_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifcsphigho201Full4616", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801885.protein.info.v11.5.txt",
		        "node_list_path": "1801885.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag798Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:798 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag798Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262841.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262841.protein.info.v11.5.txt",
		        "node_list_path": "1262841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpUrha0056(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. URHA0056 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpUrha0056", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298858.protein.info.v11.5.txt",
		        "node_list_path": "1298858.protein.complete.v11.5.txt"
		    }
		]
    )()

def BathycoccusPrasinosCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bathycoccus prasinos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BathycoccusPrasinosCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "41875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "41875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "41875.clusters.proteins.v11.5.txt",
		        "sequence_path": "41875.protein.sequences.v11.5.fa",
		        "enrichment_path": "41875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41875.protein.info.v11.5.txt",
		        "node_list_path": "41875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "41875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RufibacterSpDg31d(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rufibacter sp. DG31D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RufibacterSpDg31d", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379910.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379910.protein.info.v11.5.txt",
		        "node_list_path": "1379910.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyellaMarensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyella marensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaMarensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "500610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "500610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "500610.clusters.proteins.v11.5.txt",
		        "sequence_path": "500610.protein.sequences.v11.5.fa",
		        "enrichment_path": "500610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500610.protein.info.v11.5.txt",
		        "node_list_path": "500610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "500610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpMmlr14010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MMLR14_010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpMmlr14010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1898743.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1898743.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1898743.clusters.proteins.v11.5.txt",
		        "sequence_path": "1898743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898743.protein.info.v11.5.txt",
		        "node_list_path": "1898743.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1898743.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EremotheciumGossypiiAtcc10895Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium gossypii ATCC 10895 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremotheciumGossypiiAtcc10895Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "284811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "284811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "284811.clusters.proteins.v11.5.txt",
		        "sequence_path": "284811.protein.sequences.v11.5.fa",
		        "enrichment_path": "284811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284811.protein.info.v11.5.txt",
		        "node_list_path": "284811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "284811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TamlanaAgarivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tamlana agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TamlanaAgarivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "481183.protein.sequences.v11.5.fa",
		        "enrichment_path": "481183.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481183.protein.info.v11.5.txt",
		        "node_list_path": "481183.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpEl159Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. EL159 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpEl159Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566270.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566270.protein.info.v11.5.txt",
		        "node_list_path": "1566270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharopolysporaAntimicrobica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharopolyspora antimicrobica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharopolysporaAntimicrobica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "455193.protein.sequences.v11.5.fa",
		        "enrichment_path": "455193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "455193.protein.info.v11.5.txt",
		        "node_list_path": "455193.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaTerpenicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia terpenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaTerpenicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "455432.clusters.info.v11.5.txt",
		        "cluster_tree_path": "455432.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "455432.clusters.proteins.v11.5.txt",
		        "sequence_path": "455432.protein.sequences.v11.5.fa",
		        "enrichment_path": "455432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "455432.protein.info.v11.5.txt",
		        "node_list_path": "455432.cluster.nodes.v11.5.txt",
		        "edge_list_path": "455432.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasVesicatoriaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas vesicatoria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasVesicatoriaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "925775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "925775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "925775.clusters.proteins.v11.5.txt",
		        "sequence_path": "925775.protein.sequences.v11.5.fa",
		        "enrichment_path": "925775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "925775.protein.info.v11.5.txt",
		        "node_list_path": "925775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "925775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262802.protein.info.v11.5.txt",
		        "node_list_path": "1262802.protein.complete.v11.5.txt"
		    }
		]
    )()

def GluconobacterJaponicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterJaponicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "376620.protein.sequences.v11.5.fa",
		        "enrichment_path": "376620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376620.protein.info.v11.5.txt",
		        "node_list_path": "376620.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu032(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU032 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu032", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671650.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671650.protein.info.v11.5.txt",
		        "node_list_path": "1671650.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpH7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. H7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpH7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882399.protein.info.v11.5.txt",
		        "node_list_path": "1882399.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumWg36Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium WG36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumWg36Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229485.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229485.protein.info.v11.5.txt",
		        "node_list_path": "1229485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KaistiaAdipataDsm17808Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kaistia adipata DSM 17808 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KaistiaAdipataDsm17808Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122131.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122131.protein.info.v11.5.txt",
		        "node_list_path": "1122131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitrusUnshiu(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrus unshiu graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrusUnshiu", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "55188.protein.sequences.v11.5.fa",
		        "enrichment_path": "55188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55188.protein.info.v11.5.txt",
		        "node_list_path": "55188.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpHun102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. HUN102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpHun102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392486.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392486.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392486.protein.info.v11.5.txt",
		        "node_list_path": "1392486.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpM1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpM1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "95619.protein.sequences.v11.5.fa",
		        "enrichment_path": "95619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "95619.protein.info.v11.5.txt",
		        "node_list_path": "95619.protein.complete.v11.5.txt"
		    }
		]
    )()

def PontibacillusMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacillus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacillusMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385511.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385511.protein.info.v11.5.txt",
		        "node_list_path": "1385511.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwc2458Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_45_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc2458Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619050.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619050.protein.info.v11.5.txt",
		        "node_list_path": "1619050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumScgcAaa027J17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA027-J17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumScgcAaa027J17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "932040.clusters.info.v11.5.txt",
		        "cluster_tree_path": "932040.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "932040.clusters.proteins.v11.5.txt",
		        "sequence_path": "932040.protein.sequences.v11.5.fa",
		        "enrichment_path": "932040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932040.protein.info.v11.5.txt",
		        "node_list_path": "932040.cluster.nodes.v11.5.txt",
		        "edge_list_path": "932040.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumBal199(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium BAL199 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumBal199", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "331869.protein.sequences.v11.5.fa",
		        "enrichment_path": "331869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331869.protein.info.v11.5.txt",
		        "node_list_path": "331869.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmatimonadetesBacterium5513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium 55-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmatimonadetesBacterium5513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895717.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895717.protein.info.v11.5.txt",
		        "node_list_path": "1895717.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlammeovirgaSpSjp92(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flammeovirga sp. SJP92 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlammeovirgaSpSjp92", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1775430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775430.protein.info.v11.5.txt",
		        "node_list_path": "1775430.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfuromonasThiophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromonas thiophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromonasThiophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "57664.protein.sequences.v11.5.fa",
		        "enrichment_path": "57664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "57664.protein.info.v11.5.txt",
		        "node_list_path": "57664.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonosporascusSpCrb83Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. CRB-8-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSpCrb83Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2211644.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2211644.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2211644.clusters.proteins.v11.5.txt",
		        "sequence_path": "2211644.protein.sequences.v11.5.fa",
		        "enrichment_path": "2211644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2211644.protein.info.v11.5.txt",
		        "node_list_path": "2211644.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2211644.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpMarseilleP3244Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. Marseille-P3244 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpMarseilleP3244Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871020.protein.info.v11.5.txt",
		        "node_list_path": "1871020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobotryumSilenesDioicae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbotryum silenes-dioicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobotryumSilenesDioicae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "796604.protein.sequences.v11.5.fa",
		        "enrichment_path": "796604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796604.protein.info.v11.5.txt",
		        "node_list_path": "796604.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColeophomaCylindrospora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coleophoma cylindrospora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColeophomaCylindrospora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849047.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849047.protein.info.v11.5.txt",
		        "node_list_path": "1849047.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaPseudomalleiAbcpw111(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei ABCPW111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaPseudomalleiAbcpw111", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434929.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434929.protein.info.v11.5.txt",
		        "node_list_path": "1434929.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSp453mfCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 453mf Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSp453mfCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761874.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761874.protein.info.v11.5.txt",
		        "node_list_path": "1761874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorientalisRegularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorientalis regularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorientalisRegularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "660518.protein.sequences.v11.5.fa",
		        "enrichment_path": "660518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "660518.protein.info.v11.5.txt",
		        "node_list_path": "660518.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaimiriBoliviensisBoliviensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saimiri boliviensis boliviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaimiriBoliviensisBoliviensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39432.protein.sequences.v11.5.fa",
		        "enrichment_path": "39432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39432.protein.info.v11.5.txt",
		        "node_list_path": "39432.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumOligotrophicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium oligotrophicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumOligotrophicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1245469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1245469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1245469.clusters.proteins.v11.5.txt",
		        "sequence_path": "1245469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245469.protein.info.v11.5.txt",
		        "node_list_path": "1245469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1245469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquimarinaAggregataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina aggregata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaAggregataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1642818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1642818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1642818.clusters.proteins.v11.5.txt",
		        "sequence_path": "1642818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1642818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1642818.protein.info.v11.5.txt",
		        "node_list_path": "1642818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1642818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalieaSalexigensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haliea salexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalieaSalexigensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121937.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121937.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121937.protein.info.v11.5.txt",
		        "node_list_path": "1121937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpScgcAaa160P02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. SCGC AAA160-P02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpScgcAaa160P02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1009412.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009412.protein.info.v11.5.txt",
		        "node_list_path": "1009412.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParaglaciecolaHydrolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraglaciecola hydrolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaglaciecolaHydrolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1799789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1799789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1799789.protein.info.v11.5.txt",
		        "node_list_path": "1799789.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalogenimonasLykanthroporepellens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dehalogenimonas lykanthroporepellens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalogenimonasLykanthroporepellens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "552811.protein.sequences.v11.5.fa",
		        "enrichment_path": "552811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "552811.protein.info.v11.5.txt",
		        "node_list_path": "552811.protein.complete.v11.5.txt"
		    }
		]
    )()

def LechevalieriaXinjiangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lechevalieria xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LechevalieriaXinjiangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "402600.clusters.info.v11.5.txt",
		        "cluster_tree_path": "402600.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "402600.clusters.proteins.v11.5.txt",
		        "sequence_path": "402600.protein.sequences.v11.5.fa",
		        "enrichment_path": "402600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402600.protein.info.v11.5.txt",
		        "node_list_path": "402600.cluster.nodes.v11.5.txt",
		        "edge_list_path": "402600.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloquadratumSpJ07hqx50Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloquadratum sp. J07HQX50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloquadratumSpJ07hqx50Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1238426.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1238426.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1238426.clusters.proteins.v11.5.txt",
		        "sequence_path": "1238426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238426.protein.info.v11.5.txt",
		        "node_list_path": "1238426.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1238426.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaValaisianaVs116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia valaisiana VS116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaValaisianaVs116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445987.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445987.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445987.clusters.proteins.v11.5.txt",
		        "sequence_path": "445987.protein.sequences.v11.5.fa",
		        "enrichment_path": "445987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445987.protein.info.v11.5.txt",
		        "node_list_path": "445987.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445987.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OribacteriumParvumAcb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium parvum ACB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumParvumAcb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "796943.protein.sequences.v11.5.fa",
		        "enrichment_path": "796943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796943.protein.info.v11.5.txt",
		        "node_list_path": "796943.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterPsychrophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter psychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterPsychrophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "651662.protein.sequences.v11.5.fa",
		        "enrichment_path": "651662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "651662.protein.info.v11.5.txt",
		        "node_list_path": "651662.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegasphaeraSpNp3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. NP3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraSpNp3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232428.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232428.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232428.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232428.protein.info.v11.5.txt",
		        "node_list_path": "1232428.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232428.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteroidesFranklinii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacteroides franklinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteroidesFranklinii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "948102.protein.sequences.v11.5.fa",
		        "enrichment_path": "948102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "948102.protein.info.v11.5.txt",
		        "node_list_path": "948102.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerinicoccusSpJlt9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serinicoccus sp. JLT9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerinicoccusSpJlt9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1758689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1758689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1758689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1758689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1758689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1758689.protein.info.v11.5.txt",
		        "node_list_path": "1758689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1758689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag582Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:582 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag582Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262997.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262997.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262997.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262997.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262997.protein.info.v11.5.txt",
		        "node_list_path": "1262997.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262997.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenispirillumSalinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caenispirillum salinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenispirillumSalinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1238182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238182.protein.info.v11.5.txt",
		        "node_list_path": "1238182.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumPsychraerophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium psychraerophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumPsychraerophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "218140.clusters.info.v11.5.txt",
		        "cluster_tree_path": "218140.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "218140.clusters.proteins.v11.5.txt",
		        "sequence_path": "218140.protein.sequences.v11.5.fa",
		        "enrichment_path": "218140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218140.protein.info.v11.5.txt",
		        "node_list_path": "218140.cluster.nodes.v11.5.txt",
		        "edge_list_path": "218140.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillibacterRuminantiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter ruminantium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterRuminantiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1007096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1007096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1007096.clusters.proteins.v11.5.txt",
		        "sequence_path": "1007096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007096.protein.info.v11.5.txt",
		        "node_list_path": "1007096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1007096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemellaHaemolysansM341(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemella haemolysans M341 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaHaemolysansM341", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "562981.protein.sequences.v11.5.fa",
		        "enrichment_path": "562981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562981.protein.info.v11.5.txt",
		        "node_list_path": "562981.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot708Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root708 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot708Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736592.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736592.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736592.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736592.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736592.protein.info.v11.5.txt",
		        "node_list_path": "1736592.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736592.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAlgidicarnisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium algidicarnis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAlgidicarnisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37659.clusters.proteins.v11.5.txt",
		        "sequence_path": "37659.protein.sequences.v11.5.fa",
		        "enrichment_path": "37659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37659.protein.info.v11.5.txt",
		        "node_list_path": "37659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph758Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH758 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph758Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217712.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217712.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217712.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217712.protein.info.v11.5.txt",
		        "node_list_path": "1217712.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217712.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulophagaAlgicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaAlgicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "688270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "688270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "688270.clusters.proteins.v11.5.txt",
		        "sequence_path": "688270.protein.sequences.v11.5.fa",
		        "enrichment_path": "688270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688270.protein.info.v11.5.txt",
		        "node_list_path": "688270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "688270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DongiaSpUrhe0060(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dongia sp. URHE0060 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DongiaSpUrhe0060", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380391.protein.info.v11.5.txt",
		        "node_list_path": "1380391.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeothrixFermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geothrix fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeothrixFermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121920.protein.info.v11.5.txt",
		        "node_list_path": "1121920.protein.complete.v11.5.txt"
		    }
		]
    )()

def KlebsiellaPneumoniaeSubspPneumoniaeHs11286(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. pneumoniae HS11286 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaPneumoniaeSubspPneumoniaeHs11286", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125630.protein.info.v11.5.txt",
		        "node_list_path": "1125630.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpYab3001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. YAB3001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpYab3001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520812.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520812.protein.info.v11.5.txt",
		        "node_list_path": "1520812.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonosporascusIbericusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus ibericus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusIbericusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "155417.clusters.info.v11.5.txt",
		        "cluster_tree_path": "155417.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "155417.clusters.proteins.v11.5.txt",
		        "sequence_path": "155417.protein.sequences.v11.5.fa",
		        "enrichment_path": "155417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "155417.protein.info.v11.5.txt",
		        "node_list_path": "155417.cluster.nodes.v11.5.txt",
		        "edge_list_path": "155417.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloquadratumWalsbyiDsm16790(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi DSM16790 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloquadratumWalsbyiDsm16790", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "362976.protein.sequences.v11.5.fa",
		        "enrichment_path": "362976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362976.protein.info.v11.5.txt",
		        "node_list_path": "362976.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaLincolniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella lincolnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaLincolniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "90241.clusters.info.v11.5.txt",
		        "cluster_tree_path": "90241.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "90241.clusters.proteins.v11.5.txt",
		        "sequence_path": "90241.protein.sequences.v11.5.fa",
		        "enrichment_path": "90241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90241.protein.info.v11.5.txt",
		        "node_list_path": "90241.cluster.nodes.v11.5.txt",
		        "edge_list_path": "90241.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarboxydocellaSpUlo1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carboxydocella sp. ULO1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarboxydocellaSpUlo1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926599.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926599.protein.info.v11.5.txt",
		        "node_list_path": "1926599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastopirellulaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastopirellula marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastopirellulaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314230.clusters.proteins.v11.5.txt",
		        "sequence_path": "314230.protein.sequences.v11.5.fa",
		        "enrichment_path": "314230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314230.protein.info.v11.5.txt",
		        "node_list_path": "314230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AbiotrophiaDefectiva(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Abiotrophia defectiva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AbiotrophiaDefectiva", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "592010.protein.sequences.v11.5.fa",
		        "enrichment_path": "592010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592010.protein.info.v11.5.txt",
		        "node_list_path": "592010.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaHalocynthiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria halocynthiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaHalocynthiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "985054.protein.sequences.v11.5.fa",
		        "enrichment_path": "985054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985054.protein.info.v11.5.txt",
		        "node_list_path": "985054.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusVietnamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus vietnamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusVietnamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "218284.protein.sequences.v11.5.fa",
		        "enrichment_path": "218284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218284.protein.info.v11.5.txt",
		        "node_list_path": "218284.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalostagnicolaLarsenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halostagnicola larsenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalostagnicolaLarsenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "797299.protein.sequences.v11.5.fa",
		        "enrichment_path": "797299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797299.protein.info.v11.5.txt",
		        "node_list_path": "797299.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesOleiciplenusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides oleiciplenus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesOleiciplenusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742727.clusters.proteins.v11.5.txt",
		        "sequence_path": "742727.protein.sequences.v11.5.fa",
		        "enrichment_path": "742727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742727.protein.info.v11.5.txt",
		        "node_list_path": "742727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KangiellaGeojedonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kangiella geojedonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KangiellaGeojedonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "914150.clusters.info.v11.5.txt",
		        "cluster_tree_path": "914150.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "914150.clusters.proteins.v11.5.txt",
		        "sequence_path": "914150.protein.sequences.v11.5.fa",
		        "enrichment_path": "914150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "914150.protein.info.v11.5.txt",
		        "node_list_path": "914150.cluster.nodes.v11.5.txt",
		        "edge_list_path": "914150.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpJ54Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. J54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpJ54Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935866.clusters.proteins.v11.5.txt",
		        "sequence_path": "935866.protein.sequences.v11.5.fa",
		        "enrichment_path": "935866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935866.protein.info.v11.5.txt",
		        "node_list_path": "935866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusEntericusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus entericus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusEntericusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123302.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123302.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123302.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123302.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123302.protein.info.v11.5.txt",
		        "node_list_path": "1123302.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123302.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OidiumNeolycopersici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oidium neolycopersici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OidiumNeolycopersici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "212602.protein.sequences.v11.5.fa",
		        "enrichment_path": "212602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "212602.protein.info.v11.5.txt",
		        "node_list_path": "212602.protein.complete.v11.5.txt"
		    }
		]
    )()

def DialisterSuccinatiphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dialister succinatiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterSuccinatiphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742743.protein.sequences.v11.5.fa",
		        "enrichment_path": "742743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742743.protein.info.v11.5.txt",
		        "node_list_path": "742743.protein.complete.v11.5.txt"
		    }
		]
    )()

def MonosigaBrevicollis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monosiga brevicollis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosigaBrevicollis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "81824.protein.sequences.v11.5.fa",
		        "enrichment_path": "81824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81824.protein.info.v11.5.txt",
		        "node_list_path": "81824.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumGw2011Gwc24417(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium GW2011_GWC2_44_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumGw2011Gwc24417", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619070.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619070.protein.info.v11.5.txt",
		        "node_list_path": "1619070.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacteraceaeBacteriumGwc25520Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_55_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacteraceaeBacteriumGwc25520Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798317.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798317.protein.info.v11.5.txt",
		        "node_list_path": "1798317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSanxanigenensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sanxanigenens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSanxanigenensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123269.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123269.protein.info.v11.5.txt",
		        "node_list_path": "1123269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PythiumVexans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pythium vexans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PythiumVexans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42099.protein.sequences.v11.5.fa",
		        "enrichment_path": "42099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42099.protein.info.v11.5.txt",
		        "node_list_path": "42099.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusOralisSk1074Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis SK1074 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOralisSk1074Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095738.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095738.protein.info.v11.5.txt",
		        "node_list_path": "1095738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaSp6418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea sp. 64-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaSp6418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895806.protein.info.v11.5.txt",
		        "node_list_path": "1895806.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaplasmaCentraleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma centrale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaplasmaCentraleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "574556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "574556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "574556.clusters.proteins.v11.5.txt",
		        "sequence_path": "574556.protein.sequences.v11.5.fa",
		        "enrichment_path": "574556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574556.protein.info.v11.5.txt",
		        "node_list_path": "574556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "574556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasMelonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas melonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasMelonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1090320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1090320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1090320.clusters.proteins.v11.5.txt",
		        "sequence_path": "1090320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1090320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1090320.protein.info.v11.5.txt",
		        "node_list_path": "1090320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1090320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCrk32(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCrk32", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1452535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1452535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1452535.protein.info.v11.5.txt",
		        "node_list_path": "1452535.protein.complete.v11.5.txt"
		    }
		]
    )()

def KordiimonasLipolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kordiimonas lipolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KordiimonasLipolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1662421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1662421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1662421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1662421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662421.protein.info.v11.5.txt",
		        "node_list_path": "1662421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1662421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusRubinfantisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus rubinfantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusRubinfantisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720296.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720296.protein.info.v11.5.txt",
		        "node_list_path": "1720296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoaciditogaLauensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesoaciditoga lauensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoaciditogaLauensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150474.protein.info.v11.5.txt",
		        "node_list_path": "1150474.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinomonasHumi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinomonas humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinomonasHumi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1338436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1338436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1338436.protein.info.v11.5.txt",
		        "node_list_path": "1338436.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptococcusNiger(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptococcus niger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcusNiger", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2741.protein.sequences.v11.5.fa",
		        "enrichment_path": "2741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2741.protein.info.v11.5.txt",
		        "node_list_path": "2741.protein.complete.v11.5.txt"
		    }
		]
    )()

def NaumovozymaDairenensisCbs421Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma dairenensis CBS 421 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NaumovozymaDairenensisCbs421Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071378.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071378.protein.info.v11.5.txt",
		        "node_list_path": "1071378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpCch5F6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. CCH5-F6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpCch5F6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1768753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1768753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1768753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1768753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768753.protein.info.v11.5.txt",
		        "node_list_path": "1768753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1768753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumRbg166821Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_16_68_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumRbg166821Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797204.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797204.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797204.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797204.protein.info.v11.5.txt",
		        "node_list_path": "1797204.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797204.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpJgi0001016M12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. JGI 0001016-M12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpJgi0001016M12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1286832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1286832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1286832.clusters.proteins.v11.5.txt",
		        "sequence_path": "1286832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286832.protein.info.v11.5.txt",
		        "node_list_path": "1286832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1286832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumAmorphaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium amorphae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumAmorphaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1082933.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1082933.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1082933.clusters.proteins.v11.5.txt",
		        "sequence_path": "1082933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1082933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1082933.protein.info.v11.5.txt",
		        "node_list_path": "1082933.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1082933.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarineGroupIiiEuryarchaeoteCgEpi1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marine Group III euryarchaeote CG-Epi1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineGroupIiiEuryarchaeoteCgEpi1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1888995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1888995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1888995.protein.info.v11.5.txt",
		        "node_list_path": "1888995.protein.complete.v11.5.txt"
		    }
		]
    )()

def EuryarchaeotaArchaeonRbg135723(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_13_57_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EuryarchaeotaArchaeonRbg135723", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797977.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797977.protein.info.v11.5.txt",
		        "node_list_path": "1797977.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpUrha0002Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. URHA0002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpUrha0002Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298867.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298867.protein.info.v11.5.txt",
		        "node_list_path": "1298867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpD5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. D5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpD5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "556261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "556261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "556261.clusters.proteins.v11.5.txt",
		        "sequence_path": "556261.protein.sequences.v11.5.fa",
		        "enrichment_path": "556261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556261.protein.info.v11.5.txt",
		        "node_list_path": "556261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "556261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RathayibacterToxicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rathayibacter toxicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RathayibacterToxicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123052.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123052.protein.info.v11.5.txt",
		        "node_list_path": "1123052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusMacquariensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus macquariensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusMacquariensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "948756.protein.sequences.v11.5.fa",
		        "enrichment_path": "948756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "948756.protein.info.v11.5.txt",
		        "node_list_path": "948756.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg136510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_65_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg136510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797835.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797835.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797835.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797835.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797835.protein.info.v11.5.txt",
		        "node_list_path": "1797835.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797835.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463881.protein.info.v11.5.txt",
		        "node_list_path": "1463881.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumSenegalense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium senegalense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumSenegalense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796.protein.info.v11.5.txt",
		        "node_list_path": "1796.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocGelidumKctc3527(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum KCTC3527 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocGelidumKctc3527", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "927691.protein.sequences.v11.5.fa",
		        "enrichment_path": "927691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927691.protein.info.v11.5.txt",
		        "node_list_path": "927691.protein.complete.v11.5.txt"
		    }
		]
    )()

def LynxCanadensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lynx canadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LynxCanadensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61383.protein.sequences.v11.5.fa",
		        "enrichment_path": "61383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61383.protein.info.v11.5.txt",
		        "node_list_path": "61383.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag448Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:448 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag448Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262808.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262808.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262808.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262808.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262808.protein.info.v11.5.txt",
		        "node_list_path": "1262808.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262808.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumAntarcticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumAntarcticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111730.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111730.protein.info.v11.5.txt",
		        "node_list_path": "1111730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WaddliaChondrophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Waddlia chondrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WaddliaChondrophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "716544.protein.sequences.v11.5.fa",
		        "enrichment_path": "716544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "716544.protein.info.v11.5.txt",
		        "node_list_path": "716544.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumLuticoctiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium luticocti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumLuticoctiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122239.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122239.protein.info.v11.5.txt",
		        "node_list_path": "1122239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioCholeraeO1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Vibrio cholerae O1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCholeraeO1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243277.protein.sequences.v11.0.fa",
		        "enrichment_path": "243277.protein.enrichment.terms.v11.0.txt",
		        "info_path": "243277.protein.info.v11.0.txt",
		        "node_list_path": "243277.protein.complete.v11.0.txt"
		    }
		]
    )()

def SpiroplasmaTuronicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma turonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaTuronicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216946.protein.sequences.v11.5.fa",
		        "enrichment_path": "216946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216946.protein.info.v11.5.txt",
		        "node_list_path": "216946.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrococcusCarbonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrococcus carbonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrococcusCarbonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "684552.protein.sequences.v11.5.fa",
		        "enrichment_path": "684552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "684552.protein.info.v11.5.txt",
		        "node_list_path": "684552.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674842.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674842.protein.info.v11.5.txt",
		        "node_list_path": "1674842.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollimonasSpOk307(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collimonas sp. OK307 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollimonasSpOk307", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801620.protein.info.v11.5.txt",
		        "node_list_path": "1801620.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumGw2011Gwa24212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWA2_42_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwa24212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618356.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618356.protein.info.v11.5.txt",
		        "node_list_path": "1618356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMassilioanorexius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus massilioanorexius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMassilioanorexius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211814.protein.info.v11.5.txt",
		        "node_list_path": "1211814.protein.complete.v11.5.txt"
		    }
		]
    )()

def DomibacillusAntri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus antri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusAntri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1714264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714264.protein.info.v11.5.txt",
		        "node_list_path": "1714264.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumRhizophilumDsm18822Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium rhizophilum DSM 18822 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumRhizophilumDsm18822Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122202.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122202.protein.info.v11.5.txt",
		        "node_list_path": "1122202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuegeriaAtlantica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaAtlantica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "81569.protein.sequences.v11.5.fa",
		        "enrichment_path": "81569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81569.protein.info.v11.5.txt",
		        "node_list_path": "81569.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterSpHl46Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. HL46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterSpHl46Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1479239.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1479239.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1479239.clusters.proteins.v11.5.txt",
		        "sequence_path": "1479239.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479239.protein.info.v11.5.txt",
		        "node_list_path": "1479239.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1479239.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterAnaerophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter anaerophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterAnaerophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "877500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "877500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "877500.clusters.proteins.v11.5.txt",
		        "sequence_path": "877500.protein.sequences.v11.5.fa",
		        "enrichment_path": "877500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877500.protein.info.v11.5.txt",
		        "node_list_path": "877500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "877500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot274(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root274 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot274", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736507.protein.info.v11.5.txt",
		        "node_list_path": "1736507.protein.complete.v11.5.txt"
		    }
		]
    )()

def OhtaekwangiaKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ohtaekwangia koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OhtaekwangiaKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "688867.protein.sequences.v11.5.fa",
		        "enrichment_path": "688867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688867.protein.info.v11.5.txt",
		        "node_list_path": "688867.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzospirillumSpB510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum sp. B510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumSpB510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "137722.protein.sequences.v11.5.fa",
		        "enrichment_path": "137722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "137722.protein.info.v11.5.txt",
		        "node_list_path": "137722.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinomonasSpD104Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. D104 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasSpD104Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208321.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208321.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208321.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208321.protein.info.v11.5.txt",
		        "node_list_path": "1208321.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208321.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraPectinoschizaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospira pectinoschiza Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraPectinoschizaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28052.clusters.proteins.v11.5.txt",
		        "sequence_path": "28052.protein.sequences.v11.5.fa",
		        "enrichment_path": "28052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28052.protein.info.v11.5.txt",
		        "node_list_path": "28052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonasPusilla(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonas pusilla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonasPusilla", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "38833.protein.sequences.v11.5.fa",
		        "enrichment_path": "38833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38833.protein.info.v11.5.txt",
		        "node_list_path": "38833.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumErythreumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium erythreum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumErythreumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2041.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2041.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2041.clusters.proteins.v11.5.txt",
		        "sequence_path": "2041.protein.sequences.v11.5.fa",
		        "enrichment_path": "2041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2041.protein.info.v11.5.txt",
		        "node_list_path": "2041.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2041.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacinutrixAlgicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixAlgicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "342954.protein.sequences.v11.5.fa",
		        "enrichment_path": "342954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342954.protein.info.v11.5.txt",
		        "node_list_path": "342954.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusSp9402080Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. 9402080 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusSp9402080Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "938293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "938293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "938293.clusters.proteins.v11.5.txt",
		        "sequence_path": "938293.protein.sequences.v11.5.fa",
		        "enrichment_path": "938293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938293.protein.info.v11.5.txt",
		        "node_list_path": "938293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "938293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriovoraxSpBal6x(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. BAL6X graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriovoraxSpBal6x", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1201290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1201290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1201290.protein.info.v11.5.txt",
		        "node_list_path": "1201290.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterColi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter coli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterColi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "195.protein.sequences.v11.5.fa",
		        "enrichment_path": "195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195.protein.info.v11.5.txt",
		        "node_list_path": "195.protein.complete.v11.5.txt"
		    }
		]
    )()

def GaetbulibacterSaemankumensisDsm17032Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gaetbulibacter saemankumensis DSM 17032 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GaetbulibacterSaemankumensisDsm17032Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121909.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121909.protein.info.v11.5.txt",
		        "node_list_path": "1121909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StrongyloidesRatti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Strongyloides ratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrongyloidesRatti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34506.protein.sequences.v11.5.fa",
		        "enrichment_path": "34506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34506.protein.info.v11.5.txt",
		        "node_list_path": "34506.protein.complete.v11.5.txt"
		    }
		]
    )()

def VenturiaEffusa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Venturia effusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VenturiaEffusa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "50376.protein.sequences.v11.5.fa",
		        "enrichment_path": "50376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50376.protein.info.v11.5.txt",
		        "node_list_path": "50376.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHlucca12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCA12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHlucca12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1666916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1666916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1666916.clusters.proteins.v11.5.txt",
		        "sequence_path": "1666916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666916.protein.info.v11.5.txt",
		        "node_list_path": "1666916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1666916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPilosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pilosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPilosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121366.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121366.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121366.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121366.protein.info.v11.5.txt",
		        "node_list_path": "1121366.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121366.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpBr18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Br18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpBr18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1312954.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1312954.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1312954.clusters.proteins.v11.5.txt",
		        "sequence_path": "1312954.protein.sequences.v11.5.fa",
		        "enrichment_path": "1312954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1312954.protein.info.v11.5.txt",
		        "node_list_path": "1312954.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1312954.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpPf153Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Pf153 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpPf153Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1699309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1699309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1699309.clusters.proteins.v11.5.txt",
		        "sequence_path": "1699309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1699309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1699309.protein.info.v11.5.txt",
		        "node_list_path": "1699309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1699309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusDarwinianusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus darwinianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusDarwinianusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380763.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380763.protein.info.v11.5.txt",
		        "node_list_path": "1380763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumJaponicumUt26s(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium japonicum UT26S graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumJaponicumUt26s", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "452662.protein.sequences.v11.5.fa",
		        "enrichment_path": "452662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452662.protein.info.v11.5.txt",
		        "node_list_path": "452662.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwe24224(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_42_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwe24224", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797337.protein.info.v11.5.txt",
		        "node_list_path": "1797337.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full4512Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_45_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full4512Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798288.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798288.protein.info.v11.5.txt",
		        "node_list_path": "1798288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AminobacterSpJ41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aminobacter sp. J41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminobacterSpJ41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935261.clusters.proteins.v11.5.txt",
		        "sequence_path": "935261.protein.sequences.v11.5.fa",
		        "enrichment_path": "935261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935261.protein.info.v11.5.txt",
		        "node_list_path": "935261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpSy8519Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. SY8519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpSy8519Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1042156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1042156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1042156.clusters.proteins.v11.5.txt",
		        "sequence_path": "1042156.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042156.protein.info.v11.5.txt",
		        "node_list_path": "1042156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1042156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4520(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_01_FULL_45_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4520", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802444.protein.info.v11.5.txt",
		        "node_list_path": "1802444.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumGranuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium granuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumGranuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "280093.protein.sequences.v11.5.fa",
		        "enrichment_path": "280093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "280093.protein.info.v11.5.txt",
		        "node_list_path": "280093.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674852.protein.info.v11.5.txt",
		        "node_list_path": "1674852.protein.complete.v11.5.txt"
		    }
		]
    )()

def DomibacillusEpiphyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus epiphyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusEpiphyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1714355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714355.protein.info.v11.5.txt",
		        "node_list_path": "1714355.protein.complete.v11.5.txt"
		    }
		]
    )()

def TursiopsTruncatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tursiops truncatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TursiopsTruncatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9739.protein.sequences.v11.5.fa",
		        "enrichment_path": "9739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9739.protein.info.v11.5.txt",
		        "node_list_path": "9739.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSp9140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. 9140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSp9140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761900.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761900.protein.info.v11.5.txt",
		        "node_list_path": "1761900.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsphigho212Full4412b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_12_FULL_44_12b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho212Full4412b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802755.protein.info.v11.5.txt",
		        "node_list_path": "1802755.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaEpidermidihirudinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia epidermidihirudinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaEpidermidihirudinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293439.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293439.protein.info.v11.5.txt",
		        "node_list_path": "1293439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhycicoccusJejuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phycicoccus jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycicoccusJejuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "367299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "367299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "367299.clusters.proteins.v11.5.txt",
		        "sequence_path": "367299.protein.sequences.v11.5.fa",
		        "enrichment_path": "367299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "367299.protein.info.v11.5.txt",
		        "node_list_path": "367299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "367299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpLeaf395(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Leaf395 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpLeaf395", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736362.protein.info.v11.5.txt",
		        "node_list_path": "1736362.protein.complete.v11.5.txt"
		    }
		]
    )()

def CladophialophoraYegresii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora yegresii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CladophialophoraYegresii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "470704.protein.sequences.v11.5.fa",
		        "enrichment_path": "470704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "470704.protein.info.v11.5.txt",
		        "node_list_path": "470704.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpAcn1ag(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. ACN1ag graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpAcn1ag", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "102891.protein.sequences.v11.5.fa",
		        "enrichment_path": "102891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "102891.protein.info.v11.5.txt",
		        "node_list_path": "102891.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermaerobacterMarianensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermaerobacter marianensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermaerobacterMarianensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644966.clusters.proteins.v11.5.txt",
		        "sequence_path": "644966.protein.sequences.v11.5.fa",
		        "enrichment_path": "644966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644966.protein.info.v11.5.txt",
		        "node_list_path": "644966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminiclostridiumPapyrosolvensC7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminiclostridium papyrosolvens C7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminiclostridiumPapyrosolvensC7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1330534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1330534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1330534.clusters.proteins.v11.5.txt",
		        "sequence_path": "1330534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1330534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1330534.protein.info.v11.5.txt",
		        "node_list_path": "1330534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1330534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasGlacialisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas glacialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasGlacialisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "866564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "866564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "866564.clusters.proteins.v11.5.txt",
		        "sequence_path": "866564.protein.sequences.v11.5.fa",
		        "enrichment_path": "866564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866564.protein.info.v11.5.txt",
		        "node_list_path": "866564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "866564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1934998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1934998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1934998.clusters.proteins.v11.5.txt",
		        "sequence_path": "1934998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934998.protein.info.v11.5.txt",
		        "node_list_path": "1934998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1934998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioSpAcv2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. ACV-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioSpAcv2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520801.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520801.protein.info.v11.5.txt",
		        "node_list_path": "1520801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrovirgaFlocculansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microvirga flocculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaFlocculansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336243.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336243.protein.info.v11.5.txt",
		        "node_list_path": "1336243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpAap93(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpAap93", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523427.protein.info.v11.5.txt",
		        "node_list_path": "1523427.protein.complete.v11.5.txt"
		    }
		]
    )()

def HamiltosporidiumTvaerminnensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hamiltosporidium tvaerminnensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HamiltosporidiumTvaerminnensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1176355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1176355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1176355.protein.info.v11.5.txt",
		        "node_list_path": "1176355.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlishewanellaAgri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alishewanella agri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlishewanellaAgri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1195246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1195246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1195246.protein.info.v11.5.txt",
		        "node_list_path": "1195246.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaCypripedii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea cypripedii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaCypripedii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "55209.protein.sequences.v11.5.fa",
		        "enrichment_path": "55209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55209.protein.info.v11.5.txt",
		        "node_list_path": "55209.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMutansUa159Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mutans UA159 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMutansUa159Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "210007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "210007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "210007.clusters.proteins.v11.5.txt",
		        "sequence_path": "210007.protein.sequences.v11.5.fa",
		        "enrichment_path": "210007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "210007.protein.info.v11.5.txt",
		        "node_list_path": "210007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "210007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumChabaudiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium chabaudi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumChabaudiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5825.clusters.proteins.v11.5.txt",
		        "sequence_path": "5825.protein.sequences.v11.5.fa",
		        "enrichment_path": "5825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5825.protein.info.v11.5.txt",
		        "node_list_path": "5825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterLongusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter longus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterLongusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1044.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1044.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1044.clusters.proteins.v11.5.txt",
		        "sequence_path": "1044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1044.protein.info.v11.5.txt",
		        "node_list_path": "1044.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1044.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAromaticivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium aromaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAromaticivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1440774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1440774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1440774.protein.info.v11.5.txt",
		        "node_list_path": "1440774.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCapitovisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium capitovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCapitovisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121354.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121354.protein.info.v11.5.txt",
		        "node_list_path": "1121354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusOtakiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus otakiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOtakiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423780.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423780.protein.info.v11.5.txt",
		        "node_list_path": "1423780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaHyorhinisSk76Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis SK76 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaHyorhinisSk76Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118964.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118964.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118964.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118964.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118964.protein.info.v11.5.txt",
		        "node_list_path": "1118964.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118964.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusEurythermalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus eurythermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusEurythermalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1505907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505907.protein.info.v11.5.txt",
		        "node_list_path": "1505907.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb245a520k10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a520K10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb245a520k10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1471522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471522.protein.info.v11.5.txt",
		        "node_list_path": "1471522.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaeBacteriumRifcsphigho212Full278(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPHIGHO2_12_FULL_27_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaeBacteriumRifcsphigho212Full278", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797601.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797601.protein.info.v11.5.txt",
		        "node_list_path": "1797601.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full3910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_39_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full3910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798375.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798375.protein.info.v11.5.txt",
		        "node_list_path": "1798375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ScytonemaHofmanniiPcc7110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scytonema hofmannii PCC 7110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScytonemaHofmanniiPcc7110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "128403.protein.sequences.v11.5.fa",
		        "enrichment_path": "128403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "128403.protein.info.v11.5.txt",
		        "node_list_path": "128403.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpRoot209Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. Root209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpRoot209Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736490.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736490.protein.info.v11.5.txt",
		        "node_list_path": "1736490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaSolanacearumPsi07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum PSI07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSolanacearumPsi07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "859657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "859657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "859657.clusters.proteins.v11.5.txt",
		        "sequence_path": "859657.protein.sequences.v11.5.fa",
		        "enrichment_path": "859657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "859657.protein.info.v11.5.txt",
		        "node_list_path": "859657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "859657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaHumi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaHumi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326474.protein.sequences.v11.5.fa",
		        "enrichment_path": "326474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326474.protein.info.v11.5.txt",
		        "node_list_path": "326474.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifoxyd12Full509(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12_FULL_50_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12Full509", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797902.protein.info.v11.5.txt",
		        "node_list_path": "1797902.protein.complete.v11.5.txt"
		    }
		]
    )()

def PleomorphomonasOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pleomorphomonas oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PleomorphomonasOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122963.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122963.protein.info.v11.5.txt",
		        "node_list_path": "1122963.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedRuminococcusSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Ruminococcus sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedRuminococcusSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "165186.clusters.info.v11.5.txt",
		        "cluster_tree_path": "165186.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "165186.clusters.proteins.v11.5.txt",
		        "sequence_path": "165186.protein.sequences.v11.5.fa",
		        "enrichment_path": "165186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "165186.protein.info.v11.5.txt",
		        "node_list_path": "165186.cluster.nodes.v11.5.txt",
		        "edge_list_path": "165186.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FonticulaAlbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fonticula alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FonticulaAlbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "691883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "691883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "691883.clusters.proteins.v11.5.txt",
		        "sequence_path": "691883.protein.sequences.v11.5.fa",
		        "enrichment_path": "691883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "691883.protein.info.v11.5.txt",
		        "node_list_path": "691883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "691883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpAap83(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpAap83", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523425.protein.info.v11.5.txt",
		        "node_list_path": "1523425.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag1024Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag1024Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262770.protein.info.v11.5.txt",
		        "node_list_path": "1262770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NesterenkoniaSpNp1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. NP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesterenkoniaSpNp1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232429.protein.info.v11.5.txt",
		        "node_list_path": "1232429.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110054(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110054 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110054", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1570343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570343.protein.info.v11.5.txt",
		        "node_list_path": "1570343.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf6677(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF6677 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf6677", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463879.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463879.protein.info.v11.5.txt",
		        "node_list_path": "1463879.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYonathbacteriaBacteriumRifcsplowo201Full4733bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPLOWO2_01_FULL_47_33b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsplowo201Full4733bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802727.protein.info.v11.5.txt",
		        "node_list_path": "1802727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesEggerthii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides eggerthii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesEggerthii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "483216.protein.sequences.v11.5.fa",
		        "enrichment_path": "483216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483216.protein.info.v11.5.txt",
		        "node_list_path": "483216.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolemyaElarraichensisGillSymbiont(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solemya elarraichensis gill symbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolemyaElarraichensisGillSymbiont", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1918949.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918949.protein.info.v11.5.txt",
		        "node_list_path": "1918949.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpPbts1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. PBTS 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpPbts1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1653478.protein.sequences.v11.5.fa",
		        "enrichment_path": "1653478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1653478.protein.info.v11.5.txt",
		        "node_list_path": "1653478.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusModuliflexusFlocculansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moduliflexus flocculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusModuliflexusFlocculansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499966.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499966.protein.info.v11.5.txt",
		        "node_list_path": "1499966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumRedseaS02B3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium REDSEA-S02_B3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumRedseaS02B3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811619.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811619.protein.info.v11.5.txt",
		        "node_list_path": "1811619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterLariCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter lari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterLariCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "306263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "306263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "306263.clusters.proteins.v11.5.txt",
		        "sequence_path": "306263.protein.sequences.v11.5.fa",
		        "enrichment_path": "306263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306263.protein.info.v11.5.txt",
		        "node_list_path": "306263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "306263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobaccaAcetoxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacca acetoxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobaccaAcetoxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "880072.protein.sequences.v11.5.fa",
		        "enrichment_path": "880072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880072.protein.info.v11.5.txt",
		        "node_list_path": "880072.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnoclostridiumPhocaeenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnoclostridium phocaeense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoclostridiumPhocaeenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871021.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871021.protein.info.v11.5.txt",
		        "node_list_path": "1871021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolyangiaceaeBacteriumUtpro1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polyangiaceae bacterium UTPRO1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolyangiaceaeBacteriumUtpro1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1961108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1961108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1961108.clusters.proteins.v11.5.txt",
		        "sequence_path": "1961108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961108.protein.info.v11.5.txt",
		        "node_list_path": "1961108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1961108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasRuminantiumAtcc12561Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium ATCC12561 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasRuminantiumAtcc12561Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280706.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280706.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280706.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280706.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280706.protein.info.v11.5.txt",
		        "node_list_path": "1280706.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280706.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PajaroellobacterAbortibovis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pajaroellobacter abortibovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PajaroellobacterAbortibovis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882918.protein.info.v11.5.txt",
		        "node_list_path": "1882918.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioRuminisCf1b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis CF1b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioRuminisCf1b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280688.protein.info.v11.5.txt",
		        "node_list_path": "1280688.protein.complete.v11.5.txt"
		    }
		]
    )()

def BergeyellaZoohelcumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bergeyella zoohelcum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BergeyellaZoohelcumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883096.clusters.proteins.v11.5.txt",
		        "sequence_path": "883096.protein.sequences.v11.5.fa",
		        "enrichment_path": "883096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883096.protein.info.v11.5.txt",
		        "node_list_path": "883096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwe24224Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_42_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwe24224Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797337.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797337.protein.info.v11.5.txt",
		        "node_list_path": "1797337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpJcm18900Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. JCM18900 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpJcm18900Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298608.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298608.protein.info.v11.5.txt",
		        "node_list_path": "1298608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomarinumVadiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomarinum vadi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomarinumVadiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "438855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "438855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "438855.clusters.proteins.v11.5.txt",
		        "sequence_path": "438855.protein.sequences.v11.5.fa",
		        "enrichment_path": "438855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "438855.protein.info.v11.5.txt",
		        "node_list_path": "438855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "438855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaxillusRubicundulusVe082h10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paxillus rubicundulus Ve08.2h10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaxillusRubicundulusVe082h10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930991.clusters.proteins.v11.5.txt",
		        "sequence_path": "930991.protein.sequences.v11.5.fa",
		        "enrichment_path": "930991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930991.protein.info.v11.5.txt",
		        "node_list_path": "930991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSanguinisSk49Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSanguinisSk49Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888808.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888808.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888808.clusters.proteins.v11.5.txt",
		        "sequence_path": "888808.protein.sequences.v11.5.fa",
		        "enrichment_path": "888808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888808.protein.info.v11.5.txt",
		        "node_list_path": "888808.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888808.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSeniorisDsm24302Jcm17472Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus senioris DSM 24302 JCM 17472 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSeniorisDsm24302Jcm17472Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423802.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423802.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423802.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423802.protein.info.v11.5.txt",
		        "node_list_path": "1423802.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423802.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSubtilisSubspInaquosorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. inaquosorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSubtilisSubspInaquosorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "483913.protein.sequences.v11.5.fa",
		        "enrichment_path": "483913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483913.protein.info.v11.5.txt",
		        "node_list_path": "483913.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg166312Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_63_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg166312Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797657.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797657.protein.info.v11.5.txt",
		        "node_list_path": "1797657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSpRim11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSpRim11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1100719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1100719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1100719.protein.info.v11.5.txt",
		        "node_list_path": "1100719.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeurosporaCrassaOr74aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neurospora crassa OR74A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeurosporaCrassaOr74aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "367110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "367110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "367110.clusters.proteins.v11.5.txt",
		        "sequence_path": "367110.protein.sequences.v11.5.fa",
		        "enrichment_path": "367110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "367110.protein.info.v11.5.txt",
		        "node_list_path": "367110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "367110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospinaGracilis3211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospina gracilis 3/211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospinaGracilis3211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1266370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266370.protein.info.v11.5.txt",
		        "node_list_path": "1266370.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminiclostridiumThermocellumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminiclostridium thermocellum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminiclostridiumThermocellumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "203119.clusters.info.v11.5.txt",
		        "cluster_tree_path": "203119.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "203119.clusters.proteins.v11.5.txt",
		        "sequence_path": "203119.protein.sequences.v11.5.fa",
		        "enrichment_path": "203119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203119.protein.info.v11.5.txt",
		        "node_list_path": "203119.cluster.nodes.v11.5.txt",
		        "edge_list_path": "203119.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CohaesibacterMarisflaviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cohaesibacter marisflavi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CohaesibacterMarisflaviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655353.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655353.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655353.clusters.proteins.v11.5.txt",
		        "sequence_path": "655353.protein.sequences.v11.5.fa",
		        "enrichment_path": "655353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655353.protein.info.v11.5.txt",
		        "node_list_path": "655353.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655353.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GorillaGorilla(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gorilla gorilla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GorillaGorilla", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9593.protein.sequences.v11.5.fa",
		        "enrichment_path": "9593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9593.protein.info.v11.5.txt",
		        "node_list_path": "9593.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinoplanesSpSe50110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes sp. SE50110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesSpSe50110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "134676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "134676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "134676.clusters.proteins.v11.5.txt",
		        "sequence_path": "134676.protein.sequences.v11.5.fa",
		        "enrichment_path": "134676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134676.protein.info.v11.5.txt",
		        "node_list_path": "134676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "134676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonasSpLorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. LOR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasSpLorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1537994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1537994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1537994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1537994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1537994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1537994.protein.info.v11.5.txt",
		        "node_list_path": "1537994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1537994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibroporiaRadiculosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibroporia radiculosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibroporiaRadiculosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "599839.protein.sequences.v11.5.fa",
		        "enrichment_path": "599839.protein.enrichment.terms.v11.5.txt",
		        "info_path": "599839.protein.info.v11.5.txt",
		        "node_list_path": "599839.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospirillumCentenumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillum centenum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillumCentenumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "414684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "414684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "414684.clusters.proteins.v11.5.txt",
		        "sequence_path": "414684.protein.sequences.v11.5.fa",
		        "enrichment_path": "414684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "414684.protein.info.v11.5.txt",
		        "node_list_path": "414684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "414684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CionaSavignyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ciona savignyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CionaSavignyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "51511.clusters.info.v11.5.txt",
		        "cluster_tree_path": "51511.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "51511.clusters.proteins.v11.5.txt",
		        "sequence_path": "51511.protein.sequences.v11.5.fa",
		        "enrichment_path": "51511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51511.protein.info.v11.5.txt",
		        "node_list_path": "51511.cluster.nodes.v11.5.txt",
		        "edge_list_path": "51511.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumCommuneCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium commune Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumCommuneCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1306519.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1306519.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1306519.clusters.proteins.v11.5.txt",
		        "sequence_path": "1306519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306519.protein.info.v11.5.txt",
		        "node_list_path": "1306519.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1306519.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumGwe25113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium GWE2_51_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumGwe25113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798010.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798010.protein.info.v11.5.txt",
		        "node_list_path": "1798010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasSpD104(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. D104 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasSpD104", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208321.protein.info.v11.5.txt",
		        "node_list_path": "1208321.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaMucosaC102(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria mucosa C102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaMucosaC102", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "435832.protein.sequences.v11.5.fa",
		        "enrichment_path": "435832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435832.protein.info.v11.5.txt",
		        "node_list_path": "435832.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusPlantarumNbrc100936(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus plantarum NBRC 100936 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusPlantarumNbrc100936", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348632.protein.info.v11.5.txt",
		        "node_list_path": "1348632.protein.complete.v11.5.txt"
		    }
		]
    )()

def DufoureaNovaeangliaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dufourea novaeangliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DufoureaNovaeangliaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "178035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "178035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "178035.clusters.proteins.v11.5.txt",
		        "sequence_path": "178035.protein.sequences.v11.5.fa",
		        "enrichment_path": "178035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178035.protein.info.v11.5.txt",
		        "node_list_path": "178035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "178035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpDd12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpDd12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777880.protein.info.v11.5.txt",
		        "node_list_path": "1777880.protein.complete.v11.5.txt"
		    }
		]
    )()

def MusSpretus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mus spretus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusSpretus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10096.protein.sequences.v11.5.fa",
		        "enrichment_path": "10096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10096.protein.info.v11.5.txt",
		        "node_list_path": "10096.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtopobiumSpF0494(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. F0494 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumSpF0494", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203602.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203602.protein.info.v11.5.txt",
		        "node_list_path": "1203602.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp150fb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 150FB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp150fb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1576605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1576605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1576605.protein.info.v11.5.txt",
		        "node_list_path": "1576605.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaFairfieldensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella fairfieldensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaFairfieldensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408444.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408444.protein.info.v11.5.txt",
		        "node_list_path": "1408444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterSaguini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter saguini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSaguini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1548018.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548018.protein.info.v11.5.txt",
		        "node_list_path": "1548018.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaPhthalatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia phthalatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaPhthalatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1136941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1136941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1136941.protein.info.v11.5.txt",
		        "node_list_path": "1136941.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSeoulensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces seoulensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSeoulensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "73044.protein.sequences.v11.5.fa",
		        "enrichment_path": "73044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "73044.protein.info.v11.5.txt",
		        "node_list_path": "73044.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyxosarcinaSpGi1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myxosarcina sp. GI1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxosarcinaSpGi1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1541065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1541065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1541065.protein.info.v11.5.txt",
		        "node_list_path": "1541065.protein.complete.v11.5.txt"
		    }
		]
    )()

def OdyssellaThessalonicensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Odyssella thessalonicensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OdyssellaThessalonicensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "985867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "985867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "985867.clusters.proteins.v11.5.txt",
		        "sequence_path": "985867.protein.sequences.v11.5.fa",
		        "enrichment_path": "985867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985867.protein.info.v11.5.txt",
		        "node_list_path": "985867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "985867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronococcusOccultusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronococcus occultus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronococcusOccultusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "694430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "694430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "694430.clusters.proteins.v11.5.txt",
		        "sequence_path": "694430.protein.sequences.v11.5.fa",
		        "enrichment_path": "694430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694430.protein.info.v11.5.txt",
		        "node_list_path": "694430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "694430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterInsulae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter insulae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterInsulae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "414048.protein.sequences.v11.5.fa",
		        "enrichment_path": "414048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "414048.protein.info.v11.5.txt",
		        "node_list_path": "414048.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumMarisnigriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum marisnigri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumMarisnigriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1285242.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1285242.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1285242.clusters.proteins.v11.5.txt",
		        "sequence_path": "1285242.protein.sequences.v11.5.fa",
		        "enrichment_path": "1285242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1285242.protein.info.v11.5.txt",
		        "node_list_path": "1285242.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1285242.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldisphaeraLagunensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldisphaera lagunensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldisphaeraLagunensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1056495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1056495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1056495.protein.info.v11.5.txt",
		        "node_list_path": "1056495.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidomycesRichmondensisBfwCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidomyces richmondensis BFW Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidomycesRichmondensisBfwCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "766039.clusters.info.v11.5.txt",
		        "cluster_tree_path": "766039.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "766039.clusters.proteins.v11.5.txt",
		        "sequence_path": "766039.protein.sequences.v11.5.fa",
		        "enrichment_path": "766039.protein.enrichment.terms.v11.5.txt",
		        "info_path": "766039.protein.info.v11.5.txt",
		        "node_list_path": "766039.cluster.nodes.v11.5.txt",
		        "edge_list_path": "766039.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpGp183(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GP183 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpGp183", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882751.protein.info.v11.5.txt",
		        "node_list_path": "1882751.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolinellaSuccinogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wolinella succinogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolinellaSuccinogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "273121.protein.sequences.v11.5.fa",
		        "enrichment_path": "273121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273121.protein.info.v11.5.txt",
		        "node_list_path": "273121.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasBatumici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas batumici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBatumici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "226910.protein.sequences.v11.5.fa",
		        "enrichment_path": "226910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226910.protein.info.v11.5.txt",
		        "node_list_path": "226910.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumSoleae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum soleae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumSoleae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "447689.protein.sequences.v11.5.fa",
		        "enrichment_path": "447689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "447689.protein.info.v11.5.txt",
		        "node_list_path": "447689.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAgalactiaePg2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae PG2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAgalactiaePg2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "347257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "347257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "347257.clusters.proteins.v11.5.txt",
		        "sequence_path": "347257.protein.sequences.v11.5.fa",
		        "enrichment_path": "347257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "347257.protein.info.v11.5.txt",
		        "node_list_path": "347257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "347257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot1334Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1334 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot1334Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736456.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736456.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736456.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736456.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736456.protein.info.v11.5.txt",
		        "node_list_path": "1736456.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736456.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumPerfringensAtcc13124Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium perfringens ATCC13124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPerfringensAtcc13124Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "195103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "195103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "195103.clusters.proteins.v11.5.txt",
		        "sequence_path": "195103.protein.sequences.v11.5.fa",
		        "enrichment_path": "195103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195103.protein.info.v11.5.txt",
		        "node_list_path": "195103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "195103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalipigerThiooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salipiger thiooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalipigerThiooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "282683.protein.sequences.v11.5.fa",
		        "enrichment_path": "282683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "282683.protein.info.v11.5.txt",
		        "node_list_path": "282683.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesViscosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces viscosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesViscosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "562973.protein.sequences.v11.5.fa",
		        "enrichment_path": "562973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562973.protein.info.v11.5.txt",
		        "node_list_path": "562973.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusPacaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus pacaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusPacaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1776390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776390.protein.info.v11.5.txt",
		        "node_list_path": "1776390.protein.complete.v11.5.txt"
		    }
		]
    )()

def CupriavidusSpBis7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. BIS7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusSpBis7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217718.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217718.protein.info.v11.5.txt",
		        "node_list_path": "1217718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BarnesiellaIntestinihominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Barnesiella intestinihominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BarnesiellaIntestinihominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742726.clusters.proteins.v11.5.txt",
		        "sequence_path": "742726.protein.sequences.v11.5.fa",
		        "enrichment_path": "742726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742726.protein.info.v11.5.txt",
		        "node_list_path": "742726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumAquidurenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium aquidurense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumAquidurenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "362413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "362413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "362413.clusters.proteins.v11.5.txt",
		        "sequence_path": "362413.protein.sequences.v11.5.fa",
		        "enrichment_path": "362413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362413.protein.info.v11.5.txt",
		        "node_list_path": "362413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "362413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaJinanensisNbrc108249(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia jinanensis NBRC 108249 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaJinanensisNbrc108249", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210082.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210082.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210082.protein.info.v11.5.txt",
		        "node_list_path": "1210082.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaValaisianaTom4006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia valaisiana Tom4006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaValaisianaTom4006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1398491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1398491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1398491.protein.info.v11.5.txt",
		        "node_list_path": "1398491.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaVeroralisF0319(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella veroralis F0319 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaVeroralisF0319", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649761.protein.sequences.v11.5.fa",
		        "enrichment_path": "649761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649761.protein.info.v11.5.txt",
		        "node_list_path": "649761.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasDiminuta4704(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas diminuta 4704 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasDiminuta4704", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035191.protein.info.v11.5.txt",
		        "node_list_path": "1035191.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpPamc26605(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PAMC26605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpPamc26605", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1112214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112214.protein.info.v11.5.txt",
		        "node_list_path": "1112214.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLambdaproteobacteriaBacteriumRifoxyd2Full5016Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lambdaproteobacteria bacterium RIFOXYD2_FULL_50_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLambdaproteobacteriaBacteriumRifoxyd2Full5016Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817772.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817772.protein.info.v11.5.txt",
		        "node_list_path": "1817772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShigellaDysenteriaeSd197Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shigella dysenteriae Sd197 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShigellaDysenteriaeSd197Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "300267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "300267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "300267.clusters.proteins.v11.5.txt",
		        "sequence_path": "300267.protein.sequences.v11.5.fa",
		        "enrichment_path": "300267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "300267.protein.info.v11.5.txt",
		        "node_list_path": "300267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "300267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidimonasBauzanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidimonas bauzanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidimonasBauzanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658167.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658167.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658167.clusters.proteins.v11.5.txt",
		        "sequence_path": "658167.protein.sequences.v11.5.fa",
		        "enrichment_path": "658167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658167.protein.info.v11.5.txt",
		        "node_list_path": "658167.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658167.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumMa2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium MA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumMa2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1333998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333998.protein.info.v11.5.txt",
		        "node_list_path": "1333998.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumNovyiNtCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium novyi NT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumNovyiNtCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "386415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "386415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "386415.clusters.proteins.v11.5.txt",
		        "sequence_path": "386415.protein.sequences.v11.5.fa",
		        "enrichment_path": "386415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "386415.protein.info.v11.5.txt",
		        "node_list_path": "386415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "386415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterAtlanticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterAtlanticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267766.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267766.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267766.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267766.protein.info.v11.5.txt",
		        "node_list_path": "1267766.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267766.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaGallisepticumS6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum S6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaGallisepticumS6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1006581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1006581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1006581.clusters.proteins.v11.5.txt",
		        "sequence_path": "1006581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1006581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1006581.protein.info.v11.5.txt",
		        "node_list_path": "1006581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1006581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlbugoLaibachii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Albugo laibachii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlbugoLaibachii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "653948.protein.sequences.v11.5.fa",
		        "enrichment_path": "653948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "653948.protein.info.v11.5.txt",
		        "node_list_path": "653948.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaAlkanivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia alkanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaAlkanivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1027371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1027371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1027371.protein.info.v11.5.txt",
		        "node_list_path": "1027371.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisSpTsri0078(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. TSRI0078 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisSpTsri0078", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1718951.protein.sequences.v11.5.fa",
		        "enrichment_path": "1718951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1718951.protein.info.v11.5.txt",
		        "node_list_path": "1718951.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc034a01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC034A01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc034a01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1739295.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1739295.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1739295.clusters.proteins.v11.5.txt",
		        "sequence_path": "1739295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739295.protein.info.v11.5.txt",
		        "node_list_path": "1739295.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1739295.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaSpNb41y(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sp. NB4-1Y graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSpNb41y", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1241906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1241906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1241906.protein.info.v11.5.txt",
		        "node_list_path": "1241906.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumC7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium C7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumC7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1792306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1792306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1792306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1792306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792306.protein.info.v11.5.txt",
		        "node_list_path": "1792306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1792306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumGryphiswaldense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum gryphiswaldense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumGryphiswaldense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1430440.protein.sequences.v11.5.fa",
		        "enrichment_path": "1430440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1430440.protein.info.v11.5.txt",
		        "node_list_path": "1430440.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalispirochaetaAmericanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalispirochaeta americana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalispirochaetaAmericanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "159291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "159291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "159291.clusters.proteins.v11.5.txt",
		        "sequence_path": "159291.protein.sequences.v11.5.fa",
		        "enrichment_path": "159291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "159291.protein.info.v11.5.txt",
		        "node_list_path": "159291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "159291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanococcusRifietoensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planococcus rifietoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusRifietoensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "200991.protein.sequences.v11.5.fa",
		        "enrichment_path": "200991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200991.protein.info.v11.5.txt",
		        "node_list_path": "200991.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaBaroniaeDsm16972Jcm13447(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella baroniae DSM 16972 JCM 13447 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBaroniaeDsm16972Jcm13447", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122980.protein.info.v11.5.txt",
		        "node_list_path": "1122980.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumDtu065(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU065 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumDtu065", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671641.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671641.protein.info.v11.5.txt",
		        "node_list_path": "1671641.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterSpRoot494(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root494 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterSpRoot494", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736549.protein.info.v11.5.txt",
		        "node_list_path": "1736549.protein.complete.v11.5.txt"
		    }
		]
    )()

def GelidibacterAlgensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gelidibacter algens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GelidibacterAlgensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "49280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "49280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "49280.clusters.proteins.v11.5.txt",
		        "sequence_path": "49280.protein.sequences.v11.5.fa",
		        "enrichment_path": "49280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "49280.protein.info.v11.5.txt",
		        "node_list_path": "49280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "49280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EmpedobacterBrevis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Empedobacter brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmpedobacterBrevis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218108.protein.info.v11.5.txt",
		        "node_list_path": "1218108.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifoxya2Full3621Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFOXYA2_FULL_36_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxya2Full3621Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802572.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802572.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802572.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802572.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802572.protein.info.v11.5.txt",
		        "node_list_path": "1802572.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802572.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpIhbB17019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. IHB B 17019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpIhbB17019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1721091.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1721091.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1721091.clusters.proteins.v11.5.txt",
		        "sequence_path": "1721091.protein.sequences.v11.5.fa",
		        "enrichment_path": "1721091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1721091.protein.info.v11.5.txt",
		        "node_list_path": "1721091.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1721091.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaSeeligeri12b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria seeligeri 12b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaSeeligeri12b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "683837.protein.sequences.v11.5.fa",
		        "enrichment_path": "683837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683837.protein.info.v11.5.txt",
		        "node_list_path": "683837.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "390242.protein.sequences.v11.5.fa",
		        "enrichment_path": "390242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390242.protein.info.v11.5.txt",
		        "node_list_path": "390242.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophagaFrappieri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga frappieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaFrappieri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "754477.protein.sequences.v11.5.fa",
		        "enrichment_path": "754477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754477.protein.info.v11.5.txt",
		        "node_list_path": "754477.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSp9mfcol31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 9MFCol31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSp9mfcol31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150398.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150398.protein.info.v11.5.txt",
		        "node_list_path": "1150398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSaccharogumia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium saccharogumia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSaccharogumia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121333.protein.info.v11.5.txt",
		        "node_list_path": "1121333.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpBc26(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. BC26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpBc26", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881032.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881032.protein.info.v11.5.txt",
		        "node_list_path": "1881032.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaricaulisSpJl2009Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maricaulis sp. JL2009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaricaulisSpJl2009Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1161401.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1161401.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1161401.clusters.proteins.v11.5.txt",
		        "sequence_path": "1161401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1161401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1161401.protein.info.v11.5.txt",
		        "node_list_path": "1161401.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1161401.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaMikamiiNbrc108933(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia mikamii NBRC 108933 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaMikamiiNbrc108933", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223548.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223548.protein.info.v11.5.txt",
		        "node_list_path": "1223548.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosotenuisUzonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis uzonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosotenuisUzonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1407055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1407055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1407055.protein.info.v11.5.txt",
		        "node_list_path": "1407055.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasSpNm58(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasSpNm58", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "200126.protein.sequences.v11.5.fa",
		        "enrichment_path": "200126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200126.protein.info.v11.5.txt",
		        "node_list_path": "200126.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlasmodiumBergheiAnka(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium berghei ANKA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumBergheiAnka", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5823.protein.sequences.v11.5.fa",
		        "enrichment_path": "5823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5823.protein.info.v11.5.txt",
		        "node_list_path": "5823.protein.complete.v11.5.txt"
		    }
		]
    )()

def TatlockiaMicdadeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tatlockia micdadei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TatlockiaMicdadeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "451.clusters.info.v11.5.txt",
		        "cluster_tree_path": "451.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "451.clusters.proteins.v11.5.txt",
		        "sequence_path": "451.protein.sequences.v11.5.fa",
		        "enrichment_path": "451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "451.protein.info.v11.5.txt",
		        "node_list_path": "451.cluster.nodes.v11.5.txt",
		        "edge_list_path": "451.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaPseudohaemulonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Candida] pseudohaemulonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaPseudohaemulonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "418784.protein.sequences.v11.5.fa",
		        "enrichment_path": "418784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "418784.protein.info.v11.5.txt",
		        "node_list_path": "418784.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobiumPhaeobacteroidesBs1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium phaeobacteroides BS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumPhaeobacteroidesBs1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "331678.clusters.info.v11.5.txt",
		        "cluster_tree_path": "331678.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "331678.clusters.proteins.v11.5.txt",
		        "sequence_path": "331678.protein.sequences.v11.5.fa",
		        "enrichment_path": "331678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331678.protein.info.v11.5.txt",
		        "node_list_path": "331678.cluster.nodes.v11.5.txt",
		        "edge_list_path": "331678.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfatitaleaSpBrhC12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfatitalea sp. BRH_c12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfatitaleaSpBrhC12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629708.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629708.protein.info.v11.5.txt",
		        "node_list_path": "1629708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NodulariaSpumigena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nodularia spumigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NodulariaSpumigena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313624.protein.sequences.v11.5.fa",
		        "enrichment_path": "313624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313624.protein.info.v11.5.txt",
		        "node_list_path": "313624.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzoarcusSpPa01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azoarcus sp. PA01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzoarcusSpPa01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1637998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1637998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1637998.clusters.proteins.v11.5.txt",
		        "sequence_path": "1637998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1637998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1637998.protein.info.v11.5.txt",
		        "node_list_path": "1637998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1637998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonadaceaeBacteriumFc4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium FC4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonadaceaeBacteriumFc4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720317.protein.info.v11.5.txt",
		        "node_list_path": "1720317.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumAquaticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium aquaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumAquaticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "452084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "452084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "452084.clusters.proteins.v11.5.txt",
		        "sequence_path": "452084.protein.sequences.v11.5.fa",
		        "enrichment_path": "452084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452084.protein.info.v11.5.txt",
		        "node_list_path": "452084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "452084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AscodesmisNigricansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ascodesmis nigricans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AscodesmisNigricansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "341454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "341454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "341454.clusters.proteins.v11.5.txt",
		        "sequence_path": "341454.protein.sequences.v11.5.fa",
		        "enrichment_path": "341454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "341454.protein.info.v11.5.txt",
		        "node_list_path": "341454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "341454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerriglobusSaanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terriglobus saanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerriglobusSaanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "401053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "401053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "401053.clusters.proteins.v11.5.txt",
		        "sequence_path": "401053.protein.sequences.v11.5.fa",
		        "enrichment_path": "401053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "401053.protein.info.v11.5.txt",
		        "node_list_path": "401053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "401053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoxiellaEndosymbiontOfAmblyommaAmericanum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coxiella endosymbiont of Amblyomma americanum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoxiellaEndosymbiontOfAmblyommaAmericanum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "325775.protein.sequences.v11.5.fa",
		        "enrichment_path": "325775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "325775.protein.info.v11.5.txt",
		        "node_list_path": "325775.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAtypicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium atypicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAtypicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "191610.protein.sequences.v11.5.fa",
		        "enrichment_path": "191610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "191610.protein.info.v11.5.txt",
		        "node_list_path": "191610.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumGw2011Gwc24418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWC2_44_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwc24418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618392.protein.info.v11.5.txt",
		        "node_list_path": "1618392.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasBennonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas bennonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasBennonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122971.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122971.protein.info.v11.5.txt",
		        "node_list_path": "1122971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaSp831b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. 831b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSp831b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1261635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261635.protein.info.v11.5.txt",
		        "node_list_path": "1261635.protein.complete.v11.5.txt"
		    }
		]
    )()

def JiangellaAlba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jiangella alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JiangellaAlba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "561176.protein.sequences.v11.5.fa",
		        "enrichment_path": "561176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561176.protein.info.v11.5.txt",
		        "node_list_path": "561176.protein.complete.v11.5.txt"
		    }
		]
    )()

def EchinicolaVietnamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Echinicola vietnamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EchinicolaVietnamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926556.clusters.proteins.v11.5.txt",
		        "sequence_path": "926556.protein.sequences.v11.5.fa",
		        "enrichment_path": "926556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926556.protein.info.v11.5.txt",
		        "node_list_path": "926556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaecibacterMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caecibacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaecibacterMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852378.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852378.protein.info.v11.5.txt",
		        "node_list_path": "1852378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumNamnetenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Propionibacterium] namnetense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumNamnetenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1574624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1574624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1574624.clusters.proteins.v11.5.txt",
		        "sequence_path": "1574624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1574624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1574624.protein.info.v11.5.txt",
		        "node_list_path": "1574624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1574624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasPruniNbrc15498Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas pruni NBRC 15498 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasPruniNbrc15498Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219052.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219052.protein.info.v11.5.txt",
		        "node_list_path": "1219052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KinetoplastibacteriumDesouzaiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium desouzaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KinetoplastibacteriumDesouzaiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208919.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208919.protein.info.v11.5.txt",
		        "node_list_path": "1208919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSingulare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium singulare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSingulare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "161899.protein.sequences.v11.5.fa",
		        "enrichment_path": "161899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161899.protein.info.v11.5.txt",
		        "node_list_path": "161899.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSpBv3c26Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. BV3C26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSpBv3c26Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111134.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111134.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111134.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111134.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111134.protein.info.v11.5.txt",
		        "node_list_path": "1111134.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111134.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DietziaSpUcdthp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dietzia sp. UCDTHP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DietziaSpUcdthp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1292020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292020.protein.info.v11.5.txt",
		        "node_list_path": "1292020.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaSpHh13063007(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. HH130630-07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaSpHh13063007", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1690815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690815.protein.info.v11.5.txt",
		        "node_list_path": "1690815.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterHormaecheiSubspSteigerwaltii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. steigerwaltii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterHormaecheiSubspSteigerwaltii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "299766.protein.sequences.v11.5.fa",
		        "enrichment_path": "299766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299766.protein.info.v11.5.txt",
		        "node_list_path": "299766.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmatimonadetesBacterium13140cm6414Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium 13_1_40CM_64_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmatimonadetesBacterium13140cm6414Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805026.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805026.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805026.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805026.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805026.protein.info.v11.5.txt",
		        "node_list_path": "1805026.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805026.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaSpL21rpuld2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta sp. L21RPulD2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaSpL21rpuld2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1307761.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1307761.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1307761.clusters.proteins.v11.5.txt",
		        "sequence_path": "1307761.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307761.protein.info.v11.5.txt",
		        "node_list_path": "1307761.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1307761.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioSpQd031Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. qd031 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSpQd031Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1603038.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1603038.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1603038.clusters.proteins.v11.5.txt",
		        "sequence_path": "1603038.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603038.protein.info.v11.5.txt",
		        "node_list_path": "1603038.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1603038.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcanobacteriumHaemolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcanobacterium haemolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcanobacteriumHaemolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644284.protein.sequences.v11.5.fa",
		        "enrichment_path": "644284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644284.protein.info.v11.5.txt",
		        "node_list_path": "644284.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarineGroupIThaumarchaeoteScgcAaa799D11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote SCGC AAA799-D11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineGroupIThaumarchaeoteScgcAaa799D11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502291.protein.info.v11.5.txt",
		        "node_list_path": "1502291.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaOtitidiscaviarumIfm11049Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia otitidiscaviarum IFM 11049 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaOtitidiscaviarumIfm11049Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1406858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1406858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1406858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1406858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1406858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1406858.protein.info.v11.5.txt",
		        "node_list_path": "1406858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1406858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag345Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:345 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag345Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1263020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1263020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1263020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1263020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263020.protein.info.v11.5.txt",
		        "node_list_path": "1263020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1263020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinopolysporaHalophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora halophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolysporaHalophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089546.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089546.protein.info.v11.5.txt",
		        "node_list_path": "1089546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpN3cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. N3C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpN3cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776758.protein.info.v11.5.txt",
		        "node_list_path": "1776758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinimicrobiumXinjiangenseDsm19287Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinimicrobium xinjiangense DSM 19287 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinimicrobiumXinjiangenseDsm19287Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123235.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123235.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123235.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123235.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123235.protein.info.v11.5.txt",
		        "node_list_path": "1123235.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123235.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfolobusAcidocaldariusSusazCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius SUSAZ Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusAcidocaldariusSusazCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1435377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1435377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1435377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1435377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1435377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1435377.protein.info.v11.5.txt",
		        "node_list_path": "1435377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1435377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaeromyxobacterSpRbg166914(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaeromyxobacter sp. RBG_16_69_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeromyxobacterSpRbg166914", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797238.protein.info.v11.5.txt",
		        "node_list_path": "1797238.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrachybacteriumSquillarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium squillarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachybacteriumSquillarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1074488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1074488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1074488.protein.info.v11.5.txt",
		        "node_list_path": "1074488.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodothermaceaeBacteriumRa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodothermaceae bacterium RA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodothermaceaeBacteriumRa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1779382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1779382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1779382.protein.info.v11.5.txt",
		        "node_list_path": "1779382.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrassicaNapus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brassica napus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrassicaNapus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3708.protein.sequences.v11.5.fa",
		        "enrichment_path": "3708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3708.protein.info.v11.5.txt",
		        "node_list_path": "3708.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusIshikawaellaCapsulataMpkobeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ishikawaella capsulata Mpkobe Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusIshikawaellaCapsulataMpkobeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "476281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "476281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "476281.clusters.proteins.v11.5.txt",
		        "sequence_path": "476281.protein.sequences.v11.5.fa",
		        "enrichment_path": "476281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "476281.protein.info.v11.5.txt",
		        "node_list_path": "476281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "476281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporosarcinaGlobispora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina globispora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaGlobispora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1459.protein.info.v11.5.txt",
		        "node_list_path": "1459.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasCatoniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas catoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasCatoniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1127696.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1127696.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1127696.clusters.proteins.v11.5.txt",
		        "sequence_path": "1127696.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127696.protein.info.v11.5.txt",
		        "node_list_path": "1127696.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1127696.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterPersicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter persicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterPersicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930118.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930118.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930118.clusters.proteins.v11.5.txt",
		        "sequence_path": "930118.protein.sequences.v11.5.fa",
		        "enrichment_path": "930118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930118.protein.info.v11.5.txt",
		        "node_list_path": "930118.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930118.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquitaleaMagnusoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquitalea magnusonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquitaleaMagnusoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "332411.clusters.info.v11.5.txt",
		        "cluster_tree_path": "332411.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "332411.clusters.proteins.v11.5.txt",
		        "sequence_path": "332411.protein.sequences.v11.5.fa",
		        "enrichment_path": "332411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332411.protein.info.v11.5.txt",
		        "node_list_path": "332411.cluster.nodes.v11.5.txt",
		        "edge_list_path": "332411.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807749.protein.info.v11.5.txt",
		        "node_list_path": "1807749.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClavibacterMichiganensisSubspCapsici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis subsp. capsici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavibacterMichiganensisSubspCapsici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1874630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1874630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1874630.protein.info.v11.5.txt",
		        "node_list_path": "1874630.protein.complete.v11.5.txt"
		    }
		]
    )()

def LabrenziaSpOb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Labrenzia sp. OB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LabrenziaSpOb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1561204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561204.protein.info.v11.5.txt",
		        "node_list_path": "1561204.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpA3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. A3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpA3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "595593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "595593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "595593.clusters.proteins.v11.5.txt",
		        "sequence_path": "595593.protein.sequences.v11.5.fa",
		        "enrichment_path": "595593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "595593.protein.info.v11.5.txt",
		        "node_list_path": "595593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "595593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaloranaerobacterAzorensisH53214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caloranaerobacter azorensis H53214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloranaerobacterAzorensisH53214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1156417.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156417.protein.info.v11.5.txt",
		        "node_list_path": "1156417.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusVaraniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus varani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusVaraniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1608583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1608583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1608583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1608583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608583.protein.info.v11.5.txt",
		        "node_list_path": "1608583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1608583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TriticumAestivum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Triticum aestivum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TriticumAestivum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4565.protein.sequences.v11.5.fa",
		        "enrichment_path": "4565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4565.protein.info.v11.5.txt",
		        "node_list_path": "4565.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumStBin11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium ST_bin11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumStBin11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1978759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978759.protein.info.v11.5.txt",
		        "node_list_path": "1978759.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeiothermusTaiwanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusTaiwanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122222.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122222.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122222.protein.info.v11.5.txt",
		        "node_list_path": "1122222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumThermoresistibileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium thermoresistibile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumThermoresistibileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1078020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1078020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1078020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1078020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078020.protein.info.v11.5.txt",
		        "node_list_path": "1078020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1078020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedArchaeonA07hn63Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HN63 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedArchaeonA07hn63Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1412873.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1412873.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1412873.clusters.proteins.v11.5.txt",
		        "sequence_path": "1412873.protein.sequences.v11.5.fa",
		        "enrichment_path": "1412873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1412873.protein.info.v11.5.txt",
		        "node_list_path": "1412873.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1412873.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChelativoransSpJ32(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chelativorans sp. J32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelativoransSpJ32", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935840.protein.sequences.v11.5.fa",
		        "enrichment_path": "935840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935840.protein.info.v11.5.txt",
		        "node_list_path": "935840.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzoarcusSpPa01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azoarcus sp. PA01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzoarcusSpPa01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1637998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1637998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1637998.protein.info.v11.5.txt",
		        "node_list_path": "1637998.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumHimb5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumHimb5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "859653.protein.sequences.v11.5.fa",
		        "enrichment_path": "859653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "859653.protein.info.v11.5.txt",
		        "node_list_path": "859653.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSanguinisSk355Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK355 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSanguinisSk355Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888816.clusters.proteins.v11.5.txt",
		        "sequence_path": "888816.protein.sequences.v11.5.fa",
		        "enrichment_path": "888816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888816.protein.info.v11.5.txt",
		        "node_list_path": "888816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidaminococcusTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidaminococcus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminococcusTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871002.protein.info.v11.5.txt",
		        "node_list_path": "1871002.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermocrinisSpGbsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermocrinis sp. GBS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocrinisSpGbsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1313265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1313265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1313265.clusters.proteins.v11.5.txt",
		        "sequence_path": "1313265.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313265.protein.info.v11.5.txt",
		        "node_list_path": "1313265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1313265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MariniblastusFucicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mariniblastus fucicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MariniblastusFucicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "980251.protein.sequences.v11.5.fa",
		        "enrichment_path": "980251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "980251.protein.info.v11.5.txt",
		        "node_list_path": "980251.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanomassiliicoccusLuminyensisB10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanomassiliicoccus luminyensis B10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomassiliicoccusLuminyensisB10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1175296.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1175296.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1175296.clusters.proteins.v11.5.txt",
		        "sequence_path": "1175296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1175296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1175296.protein.info.v11.5.txt",
		        "node_list_path": "1175296.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1175296.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasPaucimobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas paucimobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasPaucimobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13689.clusters.proteins.v11.5.txt",
		        "sequence_path": "13689.protein.sequences.v11.5.fa",
		        "enrichment_path": "13689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13689.protein.info.v11.5.txt",
		        "node_list_path": "13689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpBcHCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Bc-h Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpBcHCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1943632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1943632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1943632.clusters.proteins.v11.5.txt",
		        "sequence_path": "1943632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1943632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1943632.protein.info.v11.5.txt",
		        "node_list_path": "1943632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1943632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho2024118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_41_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho2024118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801746.protein.info.v11.5.txt",
		        "node_list_path": "1801746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AdvenellaKashmirensisWt001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Advenella kashmirensis WT001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AdvenellaKashmirensisWt001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1036672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1036672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1036672.clusters.proteins.v11.5.txt",
		        "sequence_path": "1036672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036672.protein.info.v11.5.txt",
		        "node_list_path": "1036672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1036672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterThiogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter thiogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterThiogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "115783.protein.sequences.v11.5.fa",
		        "enrichment_path": "115783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115783.protein.info.v11.5.txt",
		        "node_list_path": "115783.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumGwc27318(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWC2_73_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumGwc27318", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797616.protein.info.v11.5.txt",
		        "node_list_path": "1797616.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAminicenantesBacteriumRbg166630Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_16_66_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg166630Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797274.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797274.protein.info.v11.5.txt",
		        "node_list_path": "1797274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp6717(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 67-17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp6717", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895782.protein.info.v11.5.txt",
		        "node_list_path": "1895782.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryobacteriumRoopkundense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryobacterium roopkundense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryobacteriumRoopkundense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1001240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1001240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1001240.protein.info.v11.5.txt",
		        "node_list_path": "1001240.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwc26444Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWC2_64_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwc26444Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797935.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797935.protein.info.v11.5.txt",
		        "node_list_path": "1797935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpHph0090(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. HPH0090 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpHph0090", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203590.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203590.protein.info.v11.5.txt",
		        "node_list_path": "1203590.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumCaeniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumCaeniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121285.protein.info.v11.5.txt",
		        "node_list_path": "1121285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FerrimonasKyonanensisDsm18153Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas kyonanensis DSM 18153 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrimonasKyonanensisDsm18153Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121879.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121879.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121879.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121879.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121879.protein.info.v11.5.txt",
		        "node_list_path": "1121879.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121879.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelobacterAcetylenicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter acetylenicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelobacterAcetylenicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29542.protein.sequences.v11.5.fa",
		        "enrichment_path": "29542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29542.protein.info.v11.5.txt",
		        "node_list_path": "29542.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaApisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma apis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaApisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1276258.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1276258.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1276258.clusters.proteins.v11.5.txt",
		        "sequence_path": "1276258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276258.protein.info.v11.5.txt",
		        "node_list_path": "1276258.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1276258.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinibacterTainanensisDsm15459(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinibacter tainanensis DSM 15459 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinibacterTainanensisDsm15459", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121274.protein.info.v11.5.txt",
		        "node_list_path": "1121274.protein.complete.v11.5.txt"
		    }
		]
    )()

def RodentibacterRatti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter ratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterRatti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906745.protein.info.v11.5.txt",
		        "node_list_path": "1906745.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylocapsaAcidiphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylocapsa acidiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocapsaAcidiphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "395964.clusters.info.v11.5.txt",
		        "cluster_tree_path": "395964.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "395964.clusters.proteins.v11.5.txt",
		        "sequence_path": "395964.protein.sequences.v11.5.fa",
		        "enrichment_path": "395964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395964.protein.info.v11.5.txt",
		        "node_list_path": "395964.cluster.nodes.v11.5.txt",
		        "edge_list_path": "395964.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5630Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5630Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463864.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463864.protein.info.v11.5.txt",
		        "node_list_path": "1463864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EuryarchaeotaArchaeonRbg19ftCombo6917(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_19FT_COMBO_69_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EuryarchaeotaArchaeonRbg19ftCombo6917", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797984.protein.info.v11.5.txt",
		        "node_list_path": "1797984.protein.complete.v11.5.txt"
		    }
		]
    )()

def LonchuraStriataDomesticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lonchura striata domestica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LonchuraStriataDomesticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "299123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "299123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "299123.clusters.proteins.v11.5.txt",
		        "sequence_path": "299123.protein.sequences.v11.5.fa",
		        "enrichment_path": "299123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "299123.protein.info.v11.5.txt",
		        "node_list_path": "299123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "299123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacaAbyssi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibaca abyssi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacaAbyssi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1250539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250539.protein.info.v11.5.txt",
		        "node_list_path": "1250539.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasTranslucensPvUndulosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas translucens pv. undulosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasTranslucensPvUndulosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "487909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "487909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "487909.clusters.proteins.v11.5.txt",
		        "sequence_path": "487909.protein.sequences.v11.5.fa",
		        "enrichment_path": "487909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487909.protein.info.v11.5.txt",
		        "node_list_path": "487909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "487909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosocosmicusOleophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosocosmicus oleophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosocosmicusOleophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1353260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1353260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1353260.clusters.proteins.v11.5.txt",
		        "sequence_path": "1353260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353260.protein.info.v11.5.txt",
		        "node_list_path": "1353260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1353260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumFuchskuhlenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium fuchskuhlense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumFuchskuhlenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1117702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1117702.clusters.proteins.v11.5.txt",
		        "sequence_path": "1117702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117702.protein.info.v11.5.txt",
		        "node_list_path": "1117702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1117702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSophoraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sophorae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSophoraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1333845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1333845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1333845.clusters.proteins.v11.5.txt",
		        "sequence_path": "1333845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1333845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1333845.protein.info.v11.5.txt",
		        "node_list_path": "1333845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1333845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpKnhs209Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpKnhs209Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1469948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1469948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1469948.clusters.proteins.v11.5.txt",
		        "sequence_path": "1469948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469948.protein.info.v11.5.txt",
		        "node_list_path": "1469948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1469948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocorpusculumBavaricumDsm4179(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanocorpusculum bavaricum DSM 4179 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocorpusculumBavaricumDsm4179", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122230.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122230.protein.info.v11.5.txt",
		        "node_list_path": "1122230.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpLc81(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LC81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpLc81", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502850.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502850.protein.info.v11.5.txt",
		        "node_list_path": "1502850.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumPolonicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium polonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumPolonicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "60169.protein.sequences.v11.5.fa",
		        "enrichment_path": "60169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60169.protein.info.v11.5.txt",
		        "node_list_path": "60169.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasAlcaligenesNbrc14159Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alcaligenes NBRC14159 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAlcaligenesNbrc14159Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1215092.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1215092.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1215092.clusters.proteins.v11.5.txt",
		        "sequence_path": "1215092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215092.protein.info.v11.5.txt",
		        "node_list_path": "1215092.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1215092.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLcm4573Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. LCM 4573 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLcm4573Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1848291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1848291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1848291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1848291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848291.protein.info.v11.5.txt",
		        "node_list_path": "1848291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1848291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpLeaf72(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Leaf72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpLeaf72", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736234.protein.info.v11.5.txt",
		        "node_list_path": "1736234.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusGlucanolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus glucanolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusGlucanolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59843.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59843.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59843.clusters.proteins.v11.5.txt",
		        "sequence_path": "59843.protein.sequences.v11.5.fa",
		        "enrichment_path": "59843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59843.protein.info.v11.5.txt",
		        "node_list_path": "59843.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59843.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag302Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:302 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag302Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262793.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262793.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262793.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262793.protein.info.v11.5.txt",
		        "node_list_path": "1262793.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262793.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumSpF0437Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium sp. F0437 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumSpF0437Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "861452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "861452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "861452.clusters.proteins.v11.5.txt",
		        "sequence_path": "861452.protein.sequences.v11.5.fa",
		        "enrichment_path": "861452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861452.protein.info.v11.5.txt",
		        "node_list_path": "861452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "861452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlF4489Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL F-4489 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlF4489Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1609095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1609095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1609095.clusters.proteins.v11.5.txt",
		        "sequence_path": "1609095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1609095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1609095.protein.info.v11.5.txt",
		        "node_list_path": "1609095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1609095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPLOWO2_01_FULL_51_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797243.protein.info.v11.5.txt",
		        "node_list_path": "1797243.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioCholeraeO395Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cholerae O395 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioCholeraeO395Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "345073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "345073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "345073.clusters.proteins.v11.5.txt",
		        "sequence_path": "345073.protein.sequences.v11.5.fa",
		        "enrichment_path": "345073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "345073.protein.info.v11.5.txt",
		        "node_list_path": "345073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "345073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaribacterReichenbachiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter reichenbachii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterReichenbachiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "996801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "996801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "996801.clusters.proteins.v11.5.txt",
		        "sequence_path": "996801.protein.sequences.v11.5.fa",
		        "enrichment_path": "996801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "996801.protein.info.v11.5.txt",
		        "node_list_path": "996801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "996801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeleagrisGallopavo(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meleagris gallopavo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeleagrisGallopavo", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9103.protein.sequences.v11.5.fa",
		        "enrichment_path": "9103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9103.protein.info.v11.5.txt",
		        "node_list_path": "9103.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinococcusLuteus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinococcus luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinococcusLuteus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122204.protein.info.v11.5.txt",
		        "node_list_path": "1122204.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumDenitrificans1nes1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium denitrificans 1NES1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumDenitrificans1nes1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "670307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "670307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "670307.clusters.proteins.v11.5.txt",
		        "sequence_path": "670307.protein.sequences.v11.5.fa",
		        "enrichment_path": "670307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670307.protein.info.v11.5.txt",
		        "node_list_path": "670307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "670307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobotryumIntermedium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbotryum intermedium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobotryumIntermedium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "269621.protein.sequences.v11.5.fa",
		        "enrichment_path": "269621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269621.protein.info.v11.5.txt",
		        "node_list_path": "269621.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesFaecichinchillaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides faecichinchillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesFaecichinchillaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "871325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "871325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "871325.clusters.proteins.v11.5.txt",
		        "sequence_path": "871325.protein.sequences.v11.5.fa",
		        "enrichment_path": "871325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871325.protein.info.v11.5.txt",
		        "node_list_path": "871325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "871325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpOv329Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. OV329 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpOv329Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882825.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882825.protein.info.v11.5.txt",
		        "node_list_path": "1882825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumGwf16617(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GWF1_66_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumGwf16617", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797551.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797551.protein.info.v11.5.txt",
		        "node_list_path": "1797551.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisTaiwanensisDsm45107(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis taiwanensis DSM 45107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisTaiwanensisDsm45107", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120984.protein.info.v11.5.txt",
		        "node_list_path": "1120984.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocGasicomitatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gasicomitatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocGasicomitatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "762550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "762550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "762550.clusters.proteins.v11.5.txt",
		        "sequence_path": "762550.protein.sequences.v11.5.fa",
		        "enrichment_path": "762550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762550.protein.info.v11.5.txt",
		        "node_list_path": "762550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "762550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4152b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_52b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4152b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801779.protein.info.v11.5.txt",
		        "node_list_path": "1801779.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumGw2011Gwb1378Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWB1_37_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwb1378Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618463.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618463.protein.info.v11.5.txt",
		        "node_list_path": "1618463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNealsonbacteriaBacteriumRifcsphigho202Full4313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFCSPHIGHO2_02_FULL_43_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifcsphigho202Full4313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801668.protein.info.v11.5.txt",
		        "node_list_path": "1801668.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumNovyiBNctc9691Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium novyi B NCTC9691 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumNovyiBNctc9691Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1443122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1443122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1443122.clusters.proteins.v11.5.txt",
		        "sequence_path": "1443122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443122.protein.info.v11.5.txt",
		        "node_list_path": "1443122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1443122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SneathiaSanguinegensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sneathia sanguinegens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SneathiaSanguinegensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40543.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40543.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40543.clusters.proteins.v11.5.txt",
		        "sequence_path": "40543.protein.sequences.v11.5.fa",
		        "enrichment_path": "40543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40543.protein.info.v11.5.txt",
		        "node_list_path": "40543.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40543.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf99Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf99 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf99Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736251.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736251.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736251.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736251.protein.info.v11.5.txt",
		        "node_list_path": "1736251.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736251.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OrycteropusAfer(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Orycteropus afer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrycteropusAfer", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9818.protein.sequences.v11.5.fa",
		        "enrichment_path": "9818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9818.protein.info.v11.5.txt",
		        "node_list_path": "9818.protein.complete.v11.5.txt"
		    }
		]
    )()

def DebaryomycesHansenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Debaryomyces hansenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DebaryomycesHansenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4959.protein.sequences.v11.5.fa",
		        "enrichment_path": "4959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4959.protein.info.v11.5.txt",
		        "node_list_path": "4959.protein.complete.v11.5.txt"
		    }
		]
    )()

def EmergomycesPasteurianusEp9510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Emergomyces pasteurianus Ep9510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmergomycesPasteurianusEp9510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1447872.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1447872.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1447872.clusters.proteins.v11.5.txt",
		        "sequence_path": "1447872.protein.sequences.v11.5.fa",
		        "enrichment_path": "1447872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1447872.protein.info.v11.5.txt",
		        "node_list_path": "1447872.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1447872.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanobiumGracileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanobium gracile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobiumGracileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "292564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "292564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "292564.clusters.proteins.v11.5.txt",
		        "sequence_path": "292564.protein.sequences.v11.5.fa",
		        "enrichment_path": "292564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292564.protein.info.v11.5.txt",
		        "node_list_path": "292564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "292564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumSpT3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum sp. T3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumSpT3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1194088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1194088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1194088.clusters.proteins.v11.5.txt",
		        "sequence_path": "1194088.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194088.protein.info.v11.5.txt",
		        "node_list_path": "1194088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1194088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb14510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_45_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb14510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618877.protein.info.v11.5.txt",
		        "node_list_path": "1618877.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasAtlantica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasAtlantica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "342610.protein.sequences.v11.5.fa",
		        "enrichment_path": "342610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342610.protein.info.v11.5.txt",
		        "node_list_path": "342610.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumGa0074141Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0074141 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumGa0074141Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752182.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752182.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752182.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752182.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752182.protein.info.v11.5.txt",
		        "node_list_path": "1752182.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752182.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaribacterOrientalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterOrientalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "228957.protein.sequences.v11.5.fa",
		        "enrichment_path": "228957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228957.protein.info.v11.5.txt",
		        "node_list_path": "228957.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraProfundimaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira profundimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraProfundimaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1177928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177928.protein.info.v11.5.txt",
		        "node_list_path": "1177928.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidithiobacillusCaldusSm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus caldus SM-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithiobacillusCaldusSm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "990288.protein.sequences.v11.5.fa",
		        "enrichment_path": "990288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990288.protein.info.v11.5.txt",
		        "node_list_path": "990288.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShimiaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shimia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShimiaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "321267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "321267.clusters.proteins.v11.5.txt",
		        "sequence_path": "321267.protein.sequences.v11.5.fa",
		        "enrichment_path": "321267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321267.protein.info.v11.5.txt",
		        "node_list_path": "321267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "321267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpBcIso3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. Bc-iso-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpBcIso3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1848158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1848158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1848158.clusters.proteins.v11.5.txt",
		        "sequence_path": "1848158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848158.protein.info.v11.5.txt",
		        "node_list_path": "1848158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1848158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OchrobactrumAnthropi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum anthropi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OchrobactrumAnthropi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "439375.protein.sequences.v11.5.fa",
		        "enrichment_path": "439375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439375.protein.info.v11.5.txt",
		        "node_list_path": "439375.protein.complete.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsPolyrhachisFurcataBcc54312(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps polyrhachis-furcata BCC 54312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsPolyrhachisFurcataBcc54312", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1330021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1330021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1330021.protein.info.v11.5.txt",
		        "node_list_path": "1330021.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSchleiferiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus schleiferi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSchleiferiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1295.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1295.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1295.clusters.proteins.v11.5.txt",
		        "sequence_path": "1295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1295.protein.info.v11.5.txt",
		        "node_list_path": "1295.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1295.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumTrifoliiCb782Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum trifolii CB782 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumTrifoliiCb782Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033991.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033991.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033991.protein.info.v11.5.txt",
		        "node_list_path": "1033991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumParaoxydans77mftsu32(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium paraoxydans 77MFTsu32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumParaoxydans77mftsu32", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1151126.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151126.protein.info.v11.5.txt",
		        "node_list_path": "1151126.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnisphaeraAggregansDsm17230Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignisphaera aggregans DSM 17230 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnisphaeraAggregansDsm17230Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "583356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "583356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "583356.clusters.proteins.v11.5.txt",
		        "sequence_path": "583356.protein.sequences.v11.5.fa",
		        "enrichment_path": "583356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "583356.protein.info.v11.5.txt",
		        "node_list_path": "583356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "583356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AneurinibacillusSpXh2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aneurinibacillus sp. XH2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AneurinibacillusSpXh2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1450761.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450761.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450761.protein.info.v11.5.txt",
		        "node_list_path": "1450761.protein.complete.v11.5.txt"
		    }
		]
    )()

def CamelusDromedarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Camelus dromedarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CamelusDromedarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9838.protein.sequences.v11.5.fa",
		        "enrichment_path": "9838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9838.protein.info.v11.5.txt",
		        "node_list_path": "9838.protein.complete.v11.5.txt"
		    }
		]
    )()

def EggerthellaceaeBacteriumAt8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eggerthellaceae bacterium AT8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthellaceaeBacteriumAt8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720315.protein.info.v11.5.txt",
		        "node_list_path": "1720315.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetaAfricanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta africana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaAfricanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "889378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "889378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "889378.clusters.proteins.v11.5.txt",
		        "sequence_path": "889378.protein.sequences.v11.5.fa",
		        "enrichment_path": "889378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "889378.protein.info.v11.5.txt",
		        "node_list_path": "889378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "889378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquilegiaCoerulea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquilegia coerulea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquilegiaCoerulea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "218851.protein.sequences.v11.5.fa",
		        "enrichment_path": "218851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218851.protein.info.v11.5.txt",
		        "node_list_path": "218851.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasGingivicanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gingivicanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasGingivicanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "266762.protein.sequences.v11.5.fa",
		        "enrichment_path": "266762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266762.protein.info.v11.5.txt",
		        "node_list_path": "266762.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasZhanjiangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas zhanjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasZhanjiangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "574966.protein.sequences.v11.5.fa",
		        "enrichment_path": "574966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574966.protein.info.v11.5.txt",
		        "node_list_path": "574966.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermogemmatisporaOnikobensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermogemmatispora onikobensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermogemmatisporaOnikobensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "732234.protein.sequences.v11.5.fa",
		        "enrichment_path": "732234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "732234.protein.info.v11.5.txt",
		        "node_list_path": "732234.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonScgcAaa007O23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon SCGC AAA007-O23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonScgcAaa007O23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "913333.protein.sequences.v11.5.fa",
		        "enrichment_path": "913333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913333.protein.info.v11.5.txt",
		        "node_list_path": "913333.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureimonasUreilytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas ureilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasUreilytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121028.protein.info.v11.5.txt",
		        "node_list_path": "1121028.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusBicirculans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus bicirculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusBicirculans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1160721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160721.protein.info.v11.5.txt",
		        "node_list_path": "1160721.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumGa0077560Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium Ga0077560 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumGa0077560Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752190.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752190.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752190.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752190.protein.info.v11.5.txt",
		        "node_list_path": "1752190.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752190.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpKnhs214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpKnhs214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1540257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1540257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1540257.clusters.proteins.v11.5.txt",
		        "sequence_path": "1540257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1540257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1540257.protein.info.v11.5.txt",
		        "node_list_path": "1540257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1540257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterNeustonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter neustonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterNeustonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1112.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1112.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1112.clusters.proteins.v11.5.txt",
		        "sequence_path": "1112.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112.protein.info.v11.5.txt",
		        "node_list_path": "1112.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1112.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumCellulosolvensLd2006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens LD2006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumCellulosolvensLd2006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408436.protein.info.v11.5.txt",
		        "node_list_path": "1408436.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpRoot55Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpRoot55Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736554.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736554.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736554.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736554.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736554.protein.info.v11.5.txt",
		        "node_list_path": "1736554.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736554.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaliobacillusRyukyuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paraliobacillus ryukyuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaliobacillusRyukyuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "200904.protein.sequences.v11.5.fa",
		        "enrichment_path": "200904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200904.protein.info.v11.5.txt",
		        "node_list_path": "200904.protein.complete.v11.5.txt"
		    }
		]
    )()

def CordycepsMilitarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps militaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CordycepsMilitarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "73501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "73501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "73501.clusters.proteins.v11.5.txt",
		        "sequence_path": "73501.protein.sequences.v11.5.fa",
		        "enrichment_path": "73501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "73501.protein.info.v11.5.txt",
		        "node_list_path": "73501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "73501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaOblongaNbrc102422(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella oblonga NBRC 102422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaOblongaNbrc102422", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349775.protein.info.v11.5.txt",
		        "node_list_path": "1349775.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSpLeaf176(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf176 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpLeaf176", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736286.protein.info.v11.5.txt",
		        "node_list_path": "1736286.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumRifoxyb1Full5412Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFOXYB1_FULL_54_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifoxyb1Full5412Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802559.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802559.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802559.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802559.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802559.protein.info.v11.5.txt",
		        "node_list_path": "1802559.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802559.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MelissococcusPlutoniusAtcc35311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Melissococcus plutonius ATCC 35311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MelissococcusPlutoniusAtcc35311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "940190.protein.sequences.v11.5.fa",
		        "enrichment_path": "940190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "940190.protein.info.v11.5.txt",
		        "node_list_path": "940190.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptococcaceaeBacteriumBica18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BICA1-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptococcaceaeBacteriumBica18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1531962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1531962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1531962.protein.info.v11.5.txt",
		        "node_list_path": "1531962.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanicolaNanhaiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola nanhaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicolaNanhaiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122614.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122614.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122614.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122614.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122614.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122614.protein.info.v11.5.txt",
		        "node_list_path": "1122614.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122614.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexusSpY3961(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexus sp. Y3961 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexusSpY3961", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "867845.protein.sequences.v11.5.fa",
		        "enrichment_path": "867845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867845.protein.info.v11.5.txt",
		        "node_list_path": "867845.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumEndosymbiontOfMortierellaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Mortierella Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumEndosymbiontOfMortierellaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1562701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1562701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1562701.clusters.proteins.v11.5.txt",
		        "sequence_path": "1562701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1562701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1562701.protein.info.v11.5.txt",
		        "node_list_path": "1562701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1562701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FulvivirgaImtechensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fulvivirga imtechensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FulvivirgaImtechensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1237149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1237149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1237149.protein.info.v11.5.txt",
		        "node_list_path": "1237149.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaSpYqh10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. YQH10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSpYqh10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1515746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1515746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1515746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1515746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1515746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1515746.protein.info.v11.5.txt",
		        "node_list_path": "1515746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1515746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpKpl1995Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1995 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpKpl1995Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203624.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203624.protein.info.v11.5.txt",
		        "node_list_path": "1203624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrococcusLahaulensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrococcus lahaulensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrococcusLahaulensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120958.protein.info.v11.5.txt",
		        "node_list_path": "1120958.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchizosaccharomycesJaponicusYfs275Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces japonicus yFS275 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchizosaccharomycesJaponicusYfs275Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "402676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "402676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "402676.clusters.proteins.v11.5.txt",
		        "sequence_path": "402676.protein.sequences.v11.5.fa",
		        "enrichment_path": "402676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402676.protein.info.v11.5.txt",
		        "node_list_path": "402676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "402676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumRuminantium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium ruminantium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumRuminantium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42322.protein.sequences.v11.5.fa",
		        "enrichment_path": "42322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42322.protein.info.v11.5.txt",
		        "node_list_path": "42322.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaMimosarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia mimosarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaMimosarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1038869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038869.protein.info.v11.5.txt",
		        "node_list_path": "1038869.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumRosaNbrc15208(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium rosa NBRC 15208 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumRosaNbrc15208", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219053.protein.info.v11.5.txt",
		        "node_list_path": "1219053.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumVeterum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium veterum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumVeterum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "408577.protein.sequences.v11.5.fa",
		        "enrichment_path": "408577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408577.protein.info.v11.5.txt",
		        "node_list_path": "408577.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusHorikoshii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus horikoshii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusHorikoshii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "79883.protein.sequences.v11.5.fa",
		        "enrichment_path": "79883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79883.protein.info.v11.5.txt",
		        "node_list_path": "79883.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaDioxanivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia dioxanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaDioxanivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675635.protein.sequences.v11.5.fa",
		        "enrichment_path": "675635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675635.protein.info.v11.5.txt",
		        "node_list_path": "675635.protein.complete.v11.5.txt"
		    }
		]
    )()

def OnionYellowsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Onion yellows Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OnionYellowsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "262768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "262768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "262768.clusters.proteins.v11.5.txt",
		        "sequence_path": "262768.protein.sequences.v11.5.fa",
		        "enrichment_path": "262768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262768.protein.info.v11.5.txt",
		        "node_list_path": "262768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "262768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaBacilliformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria bacilliformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaBacilliformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "267212.clusters.info.v11.5.txt",
		        "cluster_tree_path": "267212.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "267212.clusters.proteins.v11.5.txt",
		        "sequence_path": "267212.protein.sequences.v11.5.fa",
		        "enrichment_path": "267212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267212.protein.info.v11.5.txt",
		        "node_list_path": "267212.cluster.nodes.v11.5.txt",
		        "edge_list_path": "267212.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsphigho201Full4098Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_01_FULL_40_98 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho201Full4098Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802034.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802034.protein.info.v11.5.txt",
		        "node_list_path": "1802034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3911Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3911Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798382.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798382.protein.info.v11.5.txt",
		        "node_list_path": "1798382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichoplaxAdhaerens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoplax adhaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichoplaxAdhaerens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10228.protein.sequences.v11.5.fa",
		        "enrichment_path": "10228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10228.protein.info.v11.5.txt",
		        "node_list_path": "10228.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaBoevreiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella boevrei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaBoevreiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122243.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122243.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122243.protein.info.v11.5.txt",
		        "node_list_path": "1122243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeleribacterEthanolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Celeribacter ethanolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeleribacterEthanolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1758178.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1758178.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1758178.clusters.proteins.v11.5.txt",
		        "sequence_path": "1758178.protein.sequences.v11.5.fa",
		        "enrichment_path": "1758178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1758178.protein.info.v11.5.txt",
		        "node_list_path": "1758178.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1758178.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumGalatheae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium galatheae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumGalatheae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1654360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1654360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1654360.protein.info.v11.5.txt",
		        "node_list_path": "1654360.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaFidelisAtccBaa318(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella fidelis ATCC BAA-318 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaFidelisAtccBaa318", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336247.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336247.protein.info.v11.5.txt",
		        "node_list_path": "1336247.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpIcm39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. ICM39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpIcm39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1105029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1105029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1105029.protein.info.v11.5.txt",
		        "node_list_path": "1105029.protein.complete.v11.5.txt"
		    }
		]
    )()

def BarnesiellaIntestinihominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Barnesiella intestinihominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BarnesiellaIntestinihominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742726.protein.sequences.v11.5.fa",
		        "enrichment_path": "742726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742726.protein.info.v11.5.txt",
		        "node_list_path": "742726.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulforhopalusSingaporensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulforhopalus singaporensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulforhopalusSingaporensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "91360.protein.sequences.v11.5.fa",
		        "enrichment_path": "91360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91360.protein.info.v11.5.txt",
		        "node_list_path": "91360.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseiflexusSpRs1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseiflexus sp. RS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseiflexusSpRs1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "357808.protein.sequences.v11.5.fa",
		        "enrichment_path": "357808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357808.protein.info.v11.5.txt",
		        "node_list_path": "357808.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaSpeluncaeNbrc108251(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia speluncae NBRC 108251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSpeluncaeNbrc108251", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210094.protein.info.v11.5.txt",
		        "node_list_path": "1210094.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfallasGeothermicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfallas geothermicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfallasGeothermicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39060.clusters.proteins.v11.5.txt",
		        "sequence_path": "39060.protein.sequences.v11.5.fa",
		        "enrichment_path": "39060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39060.protein.info.v11.5.txt",
		        "node_list_path": "39060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifoxyd2Full4310Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYD2_FULL_43_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyd2Full4310Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802653.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802653.protein.info.v11.5.txt",
		        "node_list_path": "1802653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpY412mc10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Y412MC10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpY412mc10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "481743.protein.sequences.v11.5.fa",
		        "enrichment_path": "481743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481743.protein.info.v11.5.txt",
		        "node_list_path": "481743.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurimonasSpRifoxyb12Full359(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFOXYB12_FULL_35_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasSpRifoxyb12Full359", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802256.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802256.protein.info.v11.5.txt",
		        "node_list_path": "1802256.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumM14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumM14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807742.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807742.protein.info.v11.5.txt",
		        "node_list_path": "1807742.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonadaceaeBacteriumT822(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonadaceae bacterium T82-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonadaceaeBacteriumT822", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1783518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1783518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1783518.protein.info.v11.5.txt",
		        "node_list_path": "1783518.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaMacrocephaliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina macrocephali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaMacrocephaliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1443665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1443665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1443665.clusters.proteins.v11.5.txt",
		        "sequence_path": "1443665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443665.protein.info.v11.5.txt",
		        "node_list_path": "1443665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1443665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusFicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus ficus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusFicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "317577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "317577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "317577.clusters.proteins.v11.5.txt",
		        "sequence_path": "317577.protein.sequences.v11.5.fa",
		        "enrichment_path": "317577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317577.protein.info.v11.5.txt",
		        "node_list_path": "317577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "317577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusParafarraginisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus parafarraginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParafarraginisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "797515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "797515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "797515.clusters.proteins.v11.5.txt",
		        "sequence_path": "797515.protein.sequences.v11.5.fa",
		        "enrichment_path": "797515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797515.protein.info.v11.5.txt",
		        "node_list_path": "797515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "797515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaSpHn41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. HN-41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSpHn41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "327275.protein.sequences.v11.5.fa",
		        "enrichment_path": "327275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "327275.protein.info.v11.5.txt",
		        "node_list_path": "327275.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusStoquefichusSpSb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Stoquefichus sp. SB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStoquefichusSpSb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658109.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658109.protein.info.v11.5.txt",
		        "node_list_path": "1658109.protein.complete.v11.5.txt"
		    }
		]
    )()

def LacinutrixMariniflava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix mariniflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacinutrixMariniflava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "342955.protein.sequences.v11.5.fa",
		        "enrichment_path": "342955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342955.protein.info.v11.5.txt",
		        "node_list_path": "342955.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioCuneatusDsm11391(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio cuneatus DSM 11391 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioCuneatusDsm11391", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121443.protein.info.v11.5.txt",
		        "node_list_path": "1121443.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsplowo202Full4018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_02_FULL_40_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo202Full4018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798632.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798632.protein.info.v11.5.txt",
		        "node_list_path": "1798632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusKawachiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus kawachii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusKawachiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40384.clusters.proteins.v11.5.txt",
		        "sequence_path": "40384.protein.sequences.v11.5.fa",
		        "enrichment_path": "40384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40384.protein.info.v11.5.txt",
		        "node_list_path": "40384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanibulbusIndolifex(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanibulbus indolifex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanibulbusIndolifex", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391624.protein.sequences.v11.5.fa",
		        "enrichment_path": "391624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391624.protein.info.v11.5.txt",
		        "node_list_path": "391624.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusConstellatusPharyngisSk1060Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus constellatus pharyngis SK1060 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusConstellatusPharyngisSk1060Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035184.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035184.protein.info.v11.5.txt",
		        "node_list_path": "1035184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermomonasFuscaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermomonas fusca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermomonasFuscaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123377.protein.info.v11.5.txt",
		        "node_list_path": "1123377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalolactibacillusAlkaliphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halolactibacillus alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolactibacillusAlkaliphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "442899.protein.sequences.v11.5.fa",
		        "enrichment_path": "442899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "442899.protein.info.v11.5.txt",
		        "node_list_path": "442899.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag524(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:524 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag524", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262817.protein.info.v11.5.txt",
		        "node_list_path": "1262817.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumE1Bont(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum E1 BoNT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumE1Bont", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "536233.protein.sequences.v11.5.fa",
		        "enrichment_path": "536233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "536233.protein.info.v11.5.txt",
		        "node_list_path": "536233.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinilactibacillusSp15rCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinilactibacillus sp. 15R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinilactibacillusSp15rCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1911586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1911586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1911586.clusters.proteins.v11.5.txt",
		        "sequence_path": "1911586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1911586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1911586.protein.info.v11.5.txt",
		        "node_list_path": "1911586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1911586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicolaSpMh3r31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicola sp. MH3R3-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicolaSpMh3r31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1928762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1928762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1928762.clusters.proteins.v11.5.txt",
		        "sequence_path": "1928762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1928762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1928762.protein.info.v11.5.txt",
		        "node_list_path": "1928762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1928762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporolactobacillusTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolactobacillusTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1444306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1444306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1444306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1444306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444306.protein.info.v11.5.txt",
		        "node_list_path": "1444306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1444306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449353.protein.info.v11.5.txt",
		        "node_list_path": "1449353.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentimicrobiumSaccharophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentimicrobium saccharophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentimicrobiumSaccharophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1678841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678841.protein.info.v11.5.txt",
		        "node_list_path": "1678841.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrdosporaColligataOc4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ordospora colligata OC4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrdosporaColligataOc4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354746.protein.info.v11.5.txt",
		        "node_list_path": "1354746.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumOlb12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumOlb12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619897.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619897.protein.info.v11.5.txt",
		        "node_list_path": "1619897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RufibacterRoseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rufibacter roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RufibacterRoseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1567108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1567108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1567108.protein.info.v11.5.txt",
		        "node_list_path": "1567108.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpSoil777(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil777 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpSoil777", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736409.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736409.protein.info.v11.5.txt",
		        "node_list_path": "1736409.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaproniaEpimycesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capronia epimyces Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaproniaEpimycesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43228.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43228.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43228.clusters.proteins.v11.5.txt",
		        "sequence_path": "43228.protein.sequences.v11.5.fa",
		        "enrichment_path": "43228.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43228.protein.info.v11.5.txt",
		        "node_list_path": "43228.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43228.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa23610(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_36_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa23610", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618808.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618808.protein.info.v11.5.txt",
		        "node_list_path": "1618808.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSaskatchewanenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium saskatchewanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSaskatchewanenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "220927.clusters.info.v11.5.txt",
		        "cluster_tree_path": "220927.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "220927.clusters.proteins.v11.5.txt",
		        "sequence_path": "220927.protein.sequences.v11.5.fa",
		        "enrichment_path": "220927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220927.protein.info.v11.5.txt",
		        "node_list_path": "220927.cluster.nodes.v11.5.txt",
		        "edge_list_path": "220927.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpPstaah124(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. PsTaAH124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpPstaah124", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157638.protein.info.v11.5.txt",
		        "node_list_path": "1157638.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusItalicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus italicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusItalicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888064.protein.sequences.v11.5.fa",
		        "enrichment_path": "888064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888064.protein.info.v11.5.txt",
		        "node_list_path": "888064.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrialbaceaeArchaeonTcBr11E2g1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon Tc-Br11_E2g1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaceaeArchaeonTcBr11E2g1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729461.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729461.protein.info.v11.5.txt",
		        "node_list_path": "1729461.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpUrhb0044Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. URHB0044 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpUrhb0044Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380386.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380386.protein.info.v11.5.txt",
		        "node_list_path": "1380386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HypholomaSublateritiumFd334Ss4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hypholoma sublateritium FD-334 SS-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HypholomaSublateritiumFd334Ss4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "945553.clusters.info.v11.5.txt",
		        "cluster_tree_path": "945553.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "945553.clusters.proteins.v11.5.txt",
		        "sequence_path": "945553.protein.sequences.v11.5.fa",
		        "enrichment_path": "945553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "945553.protein.info.v11.5.txt",
		        "node_list_path": "945553.cluster.nodes.v11.5.txt",
		        "edge_list_path": "945553.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlternariaAlternataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alternaria alternata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlternariaAlternataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5599.clusters.proteins.v11.5.txt",
		        "sequence_path": "5599.protein.sequences.v11.5.fa",
		        "enrichment_path": "5599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5599.protein.info.v11.5.txt",
		        "node_list_path": "5599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiumSpBvorr106(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. BvORR106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiumSpBvorr106", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1403819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403819.protein.info.v11.5.txt",
		        "node_list_path": "1403819.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudanabaenaSpPcc7367Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudanabaena sp. PCC7367 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudanabaenaSpPcc7367Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "82654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "82654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "82654.clusters.proteins.v11.5.txt",
		        "sequence_path": "82654.protein.sequences.v11.5.fa",
		        "enrichment_path": "82654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82654.protein.info.v11.5.txt",
		        "node_list_path": "82654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "82654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FabibacterMisakiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fabibacter misakiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FabibacterMisakiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1563681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1563681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1563681.clusters.proteins.v11.5.txt",
		        "sequence_path": "1563681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1563681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1563681.protein.info.v11.5.txt",
		        "node_list_path": "1563681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1563681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DehalobacterSpFth1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalobacter sp. FTH1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalobacterSpFth1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035308.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035308.protein.info.v11.5.txt",
		        "node_list_path": "1035308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterocytozoonBieneusiH348Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterocytozoon bieneusi H348 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterocytozoonBieneusiH348Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "481877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "481877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "481877.clusters.proteins.v11.5.txt",
		        "sequence_path": "481877.protein.sequences.v11.5.fa",
		        "enrichment_path": "481877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481877.protein.info.v11.5.txt",
		        "node_list_path": "481877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "481877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MelampsoraLaricipopulinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Melampsora laricipopulina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MelampsoraLaricipopulinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "203908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "203908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "203908.clusters.proteins.v11.5.txt",
		        "sequence_path": "203908.protein.sequences.v11.5.fa",
		        "enrichment_path": "203908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203908.protein.info.v11.5.txt",
		        "node_list_path": "203908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "203908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumCuniculiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium cuniculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumCuniculiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1688.clusters.proteins.v11.5.txt",
		        "sequence_path": "1688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1688.protein.info.v11.5.txt",
		        "node_list_path": "1688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesRadiopugnans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces radiopugnans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRadiopugnans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "403935.protein.sequences.v11.5.fa",
		        "enrichment_path": "403935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "403935.protein.info.v11.5.txt",
		        "node_list_path": "403935.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsplowo201Full3654Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_36_54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3654Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798615.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798615.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798615.protein.info.v11.5.txt",
		        "node_list_path": "1798615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFrigidariumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium frigidarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFrigidariumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121890.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121890.protein.info.v11.5.txt",
		        "node_list_path": "1121890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EndozoicomonasMontiporaeCl33(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas montiporae CL-33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndozoicomonasMontiporaeCl33", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "570277.protein.sequences.v11.5.fa",
		        "enrichment_path": "570277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570277.protein.info.v11.5.txt",
		        "node_list_path": "570277.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermosynechococcusElongatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermosynechococcus elongatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermosynechococcusElongatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "197221.protein.sequences.v11.5.fa",
		        "enrichment_path": "197221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "197221.protein.info.v11.5.txt",
		        "node_list_path": "197221.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphaerulinaMusiva(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphaerulina musiva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphaerulinaMusiva", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "85929.protein.sequences.v11.5.fa",
		        "enrichment_path": "85929.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85929.protein.info.v11.5.txt",
		        "node_list_path": "85929.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocMesenteroidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc mesenteroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocMesenteroidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "203120.clusters.info.v11.5.txt",
		        "cluster_tree_path": "203120.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "203120.clusters.proteins.v11.5.txt",
		        "sequence_path": "203120.protein.sequences.v11.5.fa",
		        "enrichment_path": "203120.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203120.protein.info.v11.5.txt",
		        "node_list_path": "203120.cluster.nodes.v11.5.txt",
		        "edge_list_path": "203120.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807752.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807752.protein.info.v11.5.txt",
		        "node_list_path": "1807752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSp1nla3eCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 1NLA3E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp1nla3eCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "666686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "666686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "666686.clusters.proteins.v11.5.txt",
		        "sequence_path": "666686.protein.sequences.v11.5.fa",
		        "enrichment_path": "666686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "666686.protein.info.v11.5.txt",
		        "node_list_path": "666686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "666686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermobifidaCellulosilyticaTb100(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermobifida cellulosilytica TB100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobifidaCellulosilyticaTb100", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665004.protein.sequences.v11.5.fa",
		        "enrichment_path": "665004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665004.protein.info.v11.5.txt",
		        "node_list_path": "665004.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpWsf3629(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. WSF 3629 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpWsf3629", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1622147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622147.protein.info.v11.5.txt",
		        "node_list_path": "1622147.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterRudisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter rudis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterRudisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "632955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "632955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "632955.clusters.proteins.v11.5.txt",
		        "sequence_path": "632955.protein.sequences.v11.5.fa",
		        "enrichment_path": "632955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "632955.protein.info.v11.5.txt",
		        "node_list_path": "632955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "632955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeosynechococcusSphagnicolaSy1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neosynechococcus sphagnicola sy1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeosynechococcusSphagnicolaSy1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1497020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1497020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1497020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1497020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1497020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1497020.protein.info.v11.5.txt",
		        "node_list_path": "1497020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1497020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusMontanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus montanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusMontanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1830138.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1830138.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1830138.clusters.proteins.v11.5.txt",
		        "sequence_path": "1830138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1830138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1830138.protein.info.v11.5.txt",
		        "node_list_path": "1830138.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1830138.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSpechtbacteriaBacteriumRifcsplowo212Full3822Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_12_FULL_38_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo212Full3822Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802165.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802165.protein.info.v11.5.txt",
		        "node_list_path": "1802165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PodosporaAnserina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Podospora anserina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PodosporaAnserina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5145.protein.sequences.v11.5.fa",
		        "enrichment_path": "5145.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5145.protein.info.v11.5.txt",
		        "node_list_path": "5145.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumGa0077534Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0077534 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumGa0077534Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752184.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752184.protein.info.v11.5.txt",
		        "node_list_path": "1752184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MuribacterMuris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Muribacter muris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuribacterMuris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67855.protein.sequences.v11.5.fa",
		        "enrichment_path": "67855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67855.protein.info.v11.5.txt",
		        "node_list_path": "67855.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpLf2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. LF2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpLf2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499689.protein.info.v11.5.txt",
		        "node_list_path": "1499689.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanomicrobiumGlaciei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planomicrobium glaciei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanomicrobiumGlaciei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1273538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1273538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1273538.protein.info.v11.5.txt",
		        "node_list_path": "1273538.protein.complete.v11.5.txt"
		    }
		]
    )()

def DictyoglomusTurgidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dictyoglomus turgidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DictyoglomusTurgidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "515635.protein.sequences.v11.5.fa",
		        "enrichment_path": "515635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515635.protein.info.v11.5.txt",
		        "node_list_path": "515635.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCc53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CC53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCc53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906740.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906740.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906740.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906740.protein.info.v11.5.txt",
		        "node_list_path": "1906740.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906740.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioMagneticusIfrc170(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio magneticus IFRC170 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioMagneticusIfrc170", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304872.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304872.protein.info.v11.5.txt",
		        "node_list_path": "1304872.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProfftellaArmatura(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Profftella armatura graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProfftellaArmatura", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "669502.protein.sequences.v11.5.fa",
		        "enrichment_path": "669502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "669502.protein.info.v11.5.txt",
		        "node_list_path": "669502.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesTurgidiscabiesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces turgidiscabies Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesTurgidiscabiesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "85558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "85558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "85558.clusters.proteins.v11.5.txt",
		        "sequence_path": "85558.protein.sequences.v11.5.fa",
		        "enrichment_path": "85558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85558.protein.info.v11.5.txt",
		        "node_list_path": "85558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "85558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudozymaHubeiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma hubeiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudozymaHubeiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "327079.clusters.info.v11.5.txt",
		        "cluster_tree_path": "327079.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "327079.clusters.proteins.v11.5.txt",
		        "sequence_path": "327079.protein.sequences.v11.5.fa",
		        "enrichment_path": "327079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "327079.protein.info.v11.5.txt",
		        "node_list_path": "327079.cluster.nodes.v11.5.txt",
		        "edge_list_path": "327079.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPortnoybacteriaBacteriumRbg13408(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RBG_13_40_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRbg13408", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801990.protein.info.v11.5.txt",
		        "node_list_path": "1801990.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinisporaArenicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinispora arenicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisporaArenicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391037.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391037.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391037.clusters.proteins.v11.5.txt",
		        "sequence_path": "391037.protein.sequences.v11.5.fa",
		        "enrichment_path": "391037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391037.protein.info.v11.5.txt",
		        "node_list_path": "391037.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391037.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HylemonellaGracilisNiagaraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hylemonella gracilis Niagara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HylemonellaGracilisNiagaraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1458275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1458275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1458275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1458275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458275.protein.info.v11.5.txt",
		        "node_list_path": "1458275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1458275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumHimb11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HIMB11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumHimb11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1366046.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1366046.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1366046.clusters.proteins.v11.5.txt",
		        "sequence_path": "1366046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1366046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1366046.protein.info.v11.5.txt",
		        "node_list_path": "1366046.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1366046.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporobacterTermitidisDsm10068(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporobacter termitidis DSM 10068 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporobacterTermitidisDsm10068", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123282.protein.info.v11.5.txt",
		        "node_list_path": "1123282.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerohalosphaeraLusitanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerohalosphaera lusitana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerohalosphaeraLusitanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1936003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1936003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1936003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1936003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1936003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1936003.protein.info.v11.5.txt",
		        "node_list_path": "1936003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1936003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumBdw918Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium BDW918 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumBdw918Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1168065.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1168065.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1168065.clusters.proteins.v11.0.txt",
		        "sequence_path": "1168065.protein.sequences.v11.0.fa",
		        "enrichment_path": "1168065.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1168065.protein.info.v11.0.txt",
		        "node_list_path": "1168065.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1168065.protein.cluster.v11.0.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumRifcsphigho212Full6614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_66_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho212Full6614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797225.protein.info.v11.5.txt",
		        "node_list_path": "1797225.protein.complete.v11.5.txt"
		    }
		]
    )()

def WilliamsiaSpLeaf354Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Williamsia sp. Leaf354 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WilliamsiaSpLeaf354Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736349.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736349.protein.info.v11.5.txt",
		        "node_list_path": "1736349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivirgaEchinicomitans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseivirga echinicomitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivirgaEchinicomitans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "296218.protein.sequences.v11.5.fa",
		        "enrichment_path": "296218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "296218.protein.info.v11.5.txt",
		        "node_list_path": "296218.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusFlavefaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusFlavefaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265.protein.info.v11.5.txt",
		        "node_list_path": "1265.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteobacteriaBacteriumCag495Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium CAG:495 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteobacteriaBacteriumCag495Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262987.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262987.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262987.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262987.protein.info.v11.5.txt",
		        "node_list_path": "1262987.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262987.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JuncoHyemalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Junco hyemalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JuncoHyemalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40217.protein.sequences.v11.5.fa",
		        "enrichment_path": "40217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40217.protein.info.v11.5.txt",
		        "node_list_path": "40217.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanobacteriumEndosymbiontOfEpithemiaTurgidaIsolateEtsbLakeYunokoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return cyanobacterium endosymbiont of Epithemia turgida isolate EtSB Lake Yunoko Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobacteriumEndosymbiontOfEpithemiaTurgidaIsolateEtsbLakeYunokoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1228987.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1228987.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1228987.clusters.proteins.v11.5.txt",
		        "sequence_path": "1228987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1228987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1228987.protein.info.v11.5.txt",
		        "node_list_path": "1228987.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1228987.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesRapamycinicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces rapamycinicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRapamycinicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1343740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1343740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1343740.protein.info.v11.5.txt",
		        "node_list_path": "1343740.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpX15166bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. X15-166B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpX15166bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897620.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897620.protein.info.v11.5.txt",
		        "node_list_path": "1897620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumW1481(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum W1481 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumW1481", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408287.protein.info.v11.5.txt",
		        "node_list_path": "1408287.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeogobiusMelanostomus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neogobius melanostomus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeogobiusMelanostomus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47308.protein.sequences.v11.5.fa",
		        "enrichment_path": "47308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47308.protein.info.v11.5.txt",
		        "node_list_path": "47308.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaSancti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga sancti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaSancti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004.protein.info.v11.5.txt",
		        "node_list_path": "1004.protein.complete.v11.5.txt"
		    }
		]
    )()

def AliivibrioLogeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliivibrio logei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliivibrioLogeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "688.clusters.proteins.v11.5.txt",
		        "sequence_path": "688.protein.sequences.v11.5.fa",
		        "enrichment_path": "688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688.protein.info.v11.5.txt",
		        "node_list_path": "688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaGenitaliumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma genitalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaGenitaliumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243273.clusters.proteins.v11.5.txt",
		        "sequence_path": "243273.protein.sequences.v11.5.fa",
		        "enrichment_path": "243273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243273.protein.info.v11.5.txt",
		        "node_list_path": "243273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifcsphigho201Full5524(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_01_FULL_55_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho201Full5524", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801638.protein.info.v11.5.txt",
		        "node_list_path": "1801638.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRoot1257Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root1257 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRoot1257Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736439.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736439.protein.info.v11.5.txt",
		        "node_list_path": "1736439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacterLucknowensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter lucknowensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterLucknowensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1077936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077936.protein.info.v11.5.txt",
		        "node_list_path": "1077936.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMusc93(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MUSC 93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMusc93", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1428652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1428652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1428652.protein.info.v11.5.txt",
		        "node_list_path": "1428652.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumRifcsplowo212Full3511Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium RIFCSPLOWO2_12_FULL_35_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumRifcsplowo212Full3511Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798016.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798016.protein.info.v11.5.txt",
		        "node_list_path": "1798016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ToxoplasmaGondiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Toxoplasma gondii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ToxoplasmaGondiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5811.clusters.proteins.v11.5.txt",
		        "sequence_path": "5811.protein.sequences.v11.5.fa",
		        "enrichment_path": "5811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5811.protein.info.v11.5.txt",
		        "node_list_path": "5811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KineococcusRadiotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kineococcus radiotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KineococcusRadiotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266940.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266940.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266940.clusters.proteins.v11.5.txt",
		        "sequence_path": "266940.protein.sequences.v11.5.fa",
		        "enrichment_path": "266940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266940.protein.info.v11.5.txt",
		        "node_list_path": "266940.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266940.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumFrediiHh103(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii HH103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumFrediiHh103", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1117943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117943.protein.info.v11.5.txt",
		        "node_list_path": "1117943.protein.complete.v11.5.txt"
		    }
		]
    )()

def CupriavidusSpBis7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. BIS7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusSpBis7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217718.protein.info.v11.5.txt",
		        "node_list_path": "1217718.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCattleyaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces cattleya Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCattleyaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1003195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1003195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1003195.clusters.proteins.v11.5.txt",
		        "sequence_path": "1003195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1003195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1003195.protein.info.v11.5.txt",
		        "node_list_path": "1003195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1003195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FormosaSpHel3A148(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Formosa sp. Hel3_A1_48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaSpHel3A148", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336795.protein.info.v11.5.txt",
		        "node_list_path": "1336795.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4415cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_44_15c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4415cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802333.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802333.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802333.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802333.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802333.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802333.protein.info.v11.5.txt",
		        "node_list_path": "1802333.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802333.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumChlorophenolicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum chlorophenolicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumChlorophenolicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "211589.protein.sequences.v11.5.fa",
		        "enrichment_path": "211589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211589.protein.info.v11.5.txt",
		        "node_list_path": "211589.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusJorgensenbacteriaBacteriumGw2011Gwb15010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GW2011_GWB1_50_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGw2011Gwb15010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618665.protein.info.v11.5.txt",
		        "node_list_path": "1618665.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellvibrioSpPealriver(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio sp. pealriver graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellvibrioSpPealriver", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1622269.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622269.protein.info.v11.5.txt",
		        "node_list_path": "1622269.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterAntarcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterAntarcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34086.protein.sequences.v11.5.fa",
		        "enrichment_path": "34086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34086.protein.info.v11.5.txt",
		        "node_list_path": "34086.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumGwf25093(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_50_93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumGwf25093", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798574.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798574.protein.info.v11.5.txt",
		        "node_list_path": "1798574.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSmegmatisJs623(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium smegmatis JS623 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSmegmatisJs623", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "710686.protein.sequences.v11.5.fa",
		        "enrichment_path": "710686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710686.protein.info.v11.5.txt",
		        "node_list_path": "710686.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpScgcAaa160P02Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. SCGC AAA160-P02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpScgcAaa160P02Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1009412.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1009412.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1009412.clusters.proteins.v11.5.txt",
		        "sequence_path": "1009412.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009412.protein.info.v11.5.txt",
		        "node_list_path": "1009412.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1009412.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrassicaRapaSubspPekinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brassica rapa subsp. pekinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrassicaRapaSubspPekinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "51351.clusters.info.v11.5.txt",
		        "cluster_tree_path": "51351.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "51351.clusters.proteins.v11.5.txt",
		        "sequence_path": "51351.protein.sequences.v11.5.fa",
		        "enrichment_path": "51351.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51351.protein.info.v11.5.txt",
		        "node_list_path": "51351.cluster.nodes.v11.5.txt",
		        "edge_list_path": "51351.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusChondroitinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus chondroitinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusChondroitinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59842.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59842.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59842.clusters.proteins.v11.5.txt",
		        "sequence_path": "59842.protein.sequences.v11.5.fa",
		        "enrichment_path": "59842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59842.protein.info.v11.5.txt",
		        "node_list_path": "59842.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59842.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RosenbergiellaNectarea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rosenbergiella nectarea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RosenbergiellaNectarea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "988801.protein.sequences.v11.5.fa",
		        "enrichment_path": "988801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "988801.protein.info.v11.5.txt",
		        "node_list_path": "988801.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophagaNitratireducenticrescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga nitratireducenticrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaNitratireducenticrescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "754476.protein.sequences.v11.5.fa",
		        "enrichment_path": "754476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754476.protein.info.v11.5.txt",
		        "node_list_path": "754476.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermomicrobialesBacteriumKi4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermomicrobiales bacterium KI4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermomicrobialesBacteriumKi4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1382356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1382356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1382356.clusters.proteins.v11.5.txt",
		        "sequence_path": "1382356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382356.protein.info.v11.5.txt",
		        "node_list_path": "1382356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1382356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaDumasianaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria dumasiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaDumasianaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1931275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1931275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1931275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1931275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1931275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1931275.protein.info.v11.5.txt",
		        "node_list_path": "1931275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1931275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RomboutsiaSpMt17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Romboutsia sp. MT17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RomboutsiaSpMt17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720299.protein.info.v11.5.txt",
		        "node_list_path": "1720299.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraFaineiSerovarHurstbridgeStrBut6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira fainei serovar Hurstbridge str. BUT 6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraFaineiSerovarHurstbridgeStrBut6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193011.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193011.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193011.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193011.protein.info.v11.5.txt",
		        "node_list_path": "1193011.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193011.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasGardneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas gardneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasGardneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "90270.protein.sequences.v11.5.fa",
		        "enrichment_path": "90270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90270.protein.info.v11.5.txt",
		        "node_list_path": "90270.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpHix(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. HIX graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpHix", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1759074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759074.protein.info.v11.5.txt",
		        "node_list_path": "1759074.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumJannaschiiDsm6295Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium jannaschii DSM 6295 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumJannaschiiDsm6295Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122200.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122200.protein.info.v11.5.txt",
		        "node_list_path": "1122200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PediculusHumanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pediculus humanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediculusHumanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "121225.protein.sequences.v11.5.fa",
		        "enrichment_path": "121225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121225.protein.info.v11.5.txt",
		        "node_list_path": "121225.protein.complete.v11.5.txt"
		    }
		]
    )()

def TangfeifaniaDiversioriginumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tangfeifania diversioriginum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TangfeifaniaDiversioriginumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1168035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1168035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1168035.clusters.proteins.v11.5.txt",
		        "sequence_path": "1168035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168035.protein.info.v11.5.txt",
		        "node_list_path": "1168035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1168035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DietziaSp111n121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dietzia sp. 111N12-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DietziaSp111n121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1785156.protein.sequences.v11.5.fa",
		        "enrichment_path": "1785156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1785156.protein.info.v11.5.txt",
		        "node_list_path": "1785156.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifoxyd12Full5919Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFOXYD12_FULL_59_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifoxyd12Full5919Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797574.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797574.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797574.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797574.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797574.protein.info.v11.5.txt",
		        "node_list_path": "1797574.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797574.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkiellaAquaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkiella aquae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkiellaAquaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "295108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "295108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "295108.clusters.proteins.v11.5.txt",
		        "sequence_path": "295108.protein.sequences.v11.5.fa",
		        "enrichment_path": "295108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "295108.protein.info.v11.5.txt",
		        "node_list_path": "295108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "295108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNe2001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NE2001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNe2001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520823.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520823.protein.info.v11.5.txt",
		        "node_list_path": "1520823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillaceaeBacteriumG5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillaceae bacterium G5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillaceaeBacteriumG5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280390.protein.info.v11.5.txt",
		        "node_list_path": "1280390.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpH14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpH14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1312959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1312959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1312959.clusters.proteins.v11.5.txt",
		        "sequence_path": "1312959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1312959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1312959.protein.info.v11.5.txt",
		        "node_list_path": "1312959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1312959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaSpDsiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Dsi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaSpDsiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236908.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1236908.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1236908.clusters.proteins.v11.0.txt",
		        "sequence_path": "1236908.protein.sequences.v11.0.fa",
		        "enrichment_path": "1236908.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1236908.protein.info.v11.0.txt",
		        "node_list_path": "1236908.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1236908.protein.cluster.v11.0.txt"
		    }
		]
    )()

def PrevotellaSalivaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella salivae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSalivaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888832.clusters.proteins.v11.5.txt",
		        "sequence_path": "888832.protein.sequences.v11.5.fa",
		        "enrichment_path": "888832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888832.protein.info.v11.5.txt",
		        "node_list_path": "888832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumPygmaeum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium pygmaeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumPygmaeum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "370764.protein.sequences.v11.5.fa",
		        "enrichment_path": "370764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "370764.protein.info.v11.5.txt",
		        "node_list_path": "370764.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaJiangningensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga jiangningensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaJiangningensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1419482.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1419482.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1419482.clusters.proteins.v11.5.txt",
		        "sequence_path": "1419482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1419482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1419482.protein.info.v11.5.txt",
		        "node_list_path": "1419482.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1419482.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusTaiwanensisDsm18679(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus taiwanensis DSM 18679 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusTaiwanensisDsm18679", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122926.protein.info.v11.5.txt",
		        "node_list_path": "1122926.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophagaSulfidovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga sulfidovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaSulfidovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45496.protein.sequences.v11.5.fa",
		        "enrichment_path": "45496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45496.protein.info.v11.5.txt",
		        "node_list_path": "45496.protein.complete.v11.5.txt"
		    }
		]
    )()

def StigmatellaAurantiacaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stigmatella aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StigmatellaAurantiacaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "378806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "378806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "378806.clusters.proteins.v11.5.txt",
		        "sequence_path": "378806.protein.sequences.v11.5.fa",
		        "enrichment_path": "378806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "378806.protein.info.v11.5.txt",
		        "node_list_path": "378806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "378806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinotignumSchaaliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinotignum schaalii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinotignumSchaaliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59505.clusters.proteins.v11.5.txt",
		        "sequence_path": "59505.protein.sequences.v11.5.fa",
		        "enrichment_path": "59505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59505.protein.info.v11.5.txt",
		        "node_list_path": "59505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaSpEc08061901Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. EC080619-01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaSpEc08061901Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1096856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1096856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1096856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1096856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1096856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1096856.protein.info.v11.5.txt",
		        "node_list_path": "1096856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1096856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsCamponotiRufipedis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps camponoti-rufipedis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsCamponotiRufipedis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2004952.protein.sequences.v11.5.fa",
		        "enrichment_path": "2004952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2004952.protein.info.v11.5.txt",
		        "node_list_path": "2004952.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusNaphthalenovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus naphthalenovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusNaphthalenovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "162209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "162209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "162209.clusters.proteins.v11.5.txt",
		        "sequence_path": "162209.protein.sequences.v11.5.fa",
		        "enrichment_path": "162209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "162209.protein.info.v11.5.txt",
		        "node_list_path": "162209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "162209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AbyssisolibacterFermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Abyssisolibacter fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AbyssisolibacterFermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1766203.protein.sequences.v11.5.fa",
		        "enrichment_path": "1766203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1766203.protein.info.v11.5.txt",
		        "node_list_path": "1766203.protein.complete.v11.5.txt"
		    }
		]
    )()

def CamponotusFloridanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Camponotus floridanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CamponotusFloridanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "104421.protein.sequences.v11.5.fa",
		        "enrichment_path": "104421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104421.protein.info.v11.5.txt",
		        "node_list_path": "104421.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZygosaccharomycesRouxiiCbs732(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zygosaccharomyces rouxii CBS 732 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZygosaccharomycesRouxiiCbs732", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "559307.protein.sequences.v11.5.fa",
		        "enrichment_path": "559307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559307.protein.info.v11.5.txt",
		        "node_list_path": "559307.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusViridansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus viridans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusViridansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1377.protein.info.v11.5.txt",
		        "node_list_path": "1377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurospirillumHalorespiransDsm13726Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum halorespirans DSM 13726 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurospirillumHalorespiransDsm13726Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193502.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193502.protein.info.v11.5.txt",
		        "node_list_path": "1193502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterCryoconitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter cryoconitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterCryoconitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "188932.protein.sequences.v11.5.fa",
		        "enrichment_path": "188932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188932.protein.info.v11.5.txt",
		        "node_list_path": "188932.protein.complete.v11.5.txt"
		    }
		]
    )()

def SorexAraneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sorex araneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SorexAraneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42254.clusters.proteins.v11.5.txt",
		        "sequence_path": "42254.protein.sequences.v11.5.fa",
		        "enrichment_path": "42254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42254.protein.info.v11.5.txt",
		        "node_list_path": "42254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp6717Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 67-17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp6717Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895782.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895782.protein.info.v11.5.txt",
		        "node_list_path": "1895782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DehalococcoidesSpJdfr56Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides sp. JdFR-56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalococcoidesSpJdfr56Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935049.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935049.protein.info.v11.5.txt",
		        "node_list_path": "1935049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifoxyb2Full487Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFOXYB2_FULL_48_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2Full487Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802583.protein.info.v11.5.txt",
		        "node_list_path": "1802583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoschusMoschiferusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moschus moschiferus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoschusMoschiferusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68415.clusters.proteins.v11.5.txt",
		        "sequence_path": "68415.protein.sequences.v11.5.fa",
		        "enrichment_path": "68415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68415.protein.info.v11.5.txt",
		        "node_list_path": "68415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_44_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798689.protein.info.v11.5.txt",
		        "node_list_path": "1798689.protein.complete.v11.5.txt"
		    }
		]
    )()

def KazachstaniaAfricana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania africana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KazachstaniaAfricana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "432096.protein.sequences.v11.5.fa",
		        "enrichment_path": "432096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "432096.protein.info.v11.5.txt",
		        "node_list_path": "432096.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag793(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:793 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag793", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262840.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262840.protein.info.v11.5.txt",
		        "node_list_path": "1262840.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusViolaceofuscusCbs115571Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus violaceofuscus CBS 115571 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusViolaceofuscusCbs115571Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1450538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1450538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1450538.clusters.proteins.v11.5.txt",
		        "sequence_path": "1450538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450538.protein.info.v11.5.txt",
		        "node_list_path": "1450538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1450538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EdwardsiellaTarda(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Edwardsiella tarda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EdwardsiellaTarda", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "636.protein.sequences.v11.5.fa",
		        "enrichment_path": "636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "636.protein.info.v11.5.txt",
		        "node_list_path": "636.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpJ54(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. J54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpJ54", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935866.protein.sequences.v11.5.fa",
		        "enrichment_path": "935866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935866.protein.info.v11.5.txt",
		        "node_list_path": "935866.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpAi1a2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ai1a2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpAi1a2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "196490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "196490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "196490.clusters.proteins.v11.5.txt",
		        "sequence_path": "196490.protein.sequences.v11.5.fa",
		        "enrichment_path": "196490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "196490.protein.info.v11.5.txt",
		        "node_list_path": "196490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "196490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PneumocystisMurinaB123Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis murina B123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PneumocystisMurinaB123Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1069680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1069680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1069680.clusters.proteins.v11.5.txt",
		        "sequence_path": "1069680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069680.protein.info.v11.5.txt",
		        "node_list_path": "1069680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1069680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProsthecobacterDebontii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prosthecobacter debontii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProsthecobacterDebontii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "48467.protein.sequences.v11.5.fa",
		        "enrichment_path": "48467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48467.protein.info.v11.5.txt",
		        "node_list_path": "48467.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiabellaDrilacisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Niabella drilacis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiabellaDrilacisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1285928.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1285928.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1285928.clusters.proteins.v11.5.txt",
		        "sequence_path": "1285928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1285928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1285928.protein.info.v11.5.txt",
		        "node_list_path": "1285928.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1285928.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YarrowiaLipolyticaClib122(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yarrowia lipolytica CLIB122 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YarrowiaLipolyticaClib122", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "284591.protein.sequences.v11.5.fa",
		        "enrichment_path": "284591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284591.protein.info.v11.5.txt",
		        "node_list_path": "284591.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumRifcsplowo212Full6621Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO2_12_FULL_66_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212Full6621Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797191.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797191.protein.info.v11.5.txt",
		        "node_list_path": "1797191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EdhazardiaAedisUsnm41457Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Edhazardia aedis USNM 41457 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EdhazardiaAedisUsnm41457Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1003232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1003232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1003232.clusters.proteins.v11.5.txt",
		        "sequence_path": "1003232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1003232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1003232.protein.info.v11.5.txt",
		        "node_list_path": "1003232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1003232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusTanneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus tanneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusTanneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220188.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220188.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220188.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220188.protein.info.v11.5.txt",
		        "node_list_path": "1220188.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220188.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaTayloriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella taylorii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaTayloriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094560.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094560.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094560.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094560.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094560.protein.info.v11.5.txt",
		        "node_list_path": "1094560.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094560.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrocoleusSpPcc7113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microcoleus sp. PCC7113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrocoleusSpPcc7113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173027.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173027.protein.info.v11.5.txt",
		        "node_list_path": "1173027.protein.complete.v11.5.txt"
		    }
		]
    )()

def FervidobacteriumPennivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium pennivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidobacteriumPennivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "771875.protein.sequences.v11.5.fa",
		        "enrichment_path": "771875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "771875.protein.info.v11.5.txt",
		        "node_list_path": "771875.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumSp20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium sp. 20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumSp20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798803.protein.info.v11.5.txt",
		        "node_list_path": "1798803.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumEnshienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium enshiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumEnshienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1107311.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1107311.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1107311.clusters.proteins.v11.5.txt",
		        "sequence_path": "1107311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1107311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1107311.protein.info.v11.5.txt",
		        "node_list_path": "1107311.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1107311.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusOzensisDsm23829Jcm17196Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ozensis DSM 23829 JCM 17196 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOzensisDsm23829Jcm17196Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423781.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423781.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423781.protein.info.v11.5.txt",
		        "node_list_path": "1423781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaBannensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia bannensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaBannensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218075.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218075.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218075.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218075.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218075.protein.info.v11.5.txt",
		        "node_list_path": "1218075.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218075.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HepatobacterPenaeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hepatobacter penaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HepatobacterPenaeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1274402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1274402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1274402.clusters.proteins.v11.5.txt",
		        "sequence_path": "1274402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274402.protein.info.v11.5.txt",
		        "node_list_path": "1274402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1274402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaSubflava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria subflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSubflava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546268.protein.sequences.v11.5.fa",
		        "enrichment_path": "546268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546268.protein.info.v11.5.txt",
		        "node_list_path": "546268.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchangiumGephyraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archangium gephyra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchangiumGephyraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "48.clusters.info.v11.5.txt",
		        "cluster_tree_path": "48.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "48.clusters.proteins.v11.5.txt",
		        "sequence_path": "48.protein.sequences.v11.5.fa",
		        "enrichment_path": "48.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48.protein.info.v11.5.txt",
		        "node_list_path": "48.cluster.nodes.v11.5.txt",
		        "edge_list_path": "48.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusSpHmp52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. HMP52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusSpHmp52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1487923.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1487923.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1487923.clusters.proteins.v11.5.txt",
		        "sequence_path": "1487923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1487923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1487923.protein.info.v11.5.txt",
		        "node_list_path": "1487923.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1487923.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaeromyxobacterSpFw1095Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaeromyxobacter sp. Fw1095 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeromyxobacterSpFw1095Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "404589.clusters.info.v11.5.txt",
		        "cluster_tree_path": "404589.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "404589.clusters.proteins.v11.5.txt",
		        "sequence_path": "404589.protein.sequences.v11.5.fa",
		        "enrichment_path": "404589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "404589.protein.info.v11.5.txt",
		        "node_list_path": "404589.cluster.nodes.v11.5.txt",
		        "edge_list_path": "404589.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoxiellaLikeEndosymbiontCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coxiella-like endosymbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoxiellaLikeEndosymbiontCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1592897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1592897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1592897.clusters.proteins.v11.5.txt",
		        "sequence_path": "1592897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1592897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1592897.protein.info.v11.5.txt",
		        "node_list_path": "1592897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1592897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def Sar86ClusterBacteriumBacl1Mag120820Bin45(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium BACL1 MAG-120820-bin45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar86ClusterBacteriumBacl1Mag120820Bin45", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1655612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655612.protein.info.v11.5.txt",
		        "node_list_path": "1655612.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasSpV450Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. V450 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasSpV450Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1912139.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1912139.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1912139.clusters.proteins.v11.5.txt",
		        "sequence_path": "1912139.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912139.protein.info.v11.5.txt",
		        "node_list_path": "1912139.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1912139.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSpB98Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. B9-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSpB98Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236179.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236179.protein.info.v11.5.txt",
		        "node_list_path": "1236179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSaudimassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter saudimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSaudimassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461584.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461584.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461584.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461584.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461584.protein.info.v11.5.txt",
		        "node_list_path": "1461584.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461584.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE3251Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E3251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE3251Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834144.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834144.protein.info.v11.5.txt",
		        "node_list_path": "1834144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaInconspicua(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Candida] inconspicua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaInconspicua", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52247.protein.sequences.v11.5.fa",
		        "enrichment_path": "52247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52247.protein.info.v11.5.txt",
		        "node_list_path": "52247.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaRettgeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Providencia rettgeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaRettgeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "587.protein.sequences.v11.5.fa",
		        "enrichment_path": "587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "587.protein.info.v11.5.txt",
		        "node_list_path": "587.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelistegaSpMc2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelistega sp. MC2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelistegaSpMc2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720297.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720297.protein.info.v11.5.txt",
		        "node_list_path": "1720297.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylibiumPetroleiphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylibium petroleiphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylibiumPetroleiphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "420662.protein.sequences.v11.5.fa",
		        "enrichment_path": "420662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420662.protein.info.v11.5.txt",
		        "node_list_path": "420662.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacterAnodireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter anodireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterAnodireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1340425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1340425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1340425.clusters.proteins.v11.5.txt",
		        "sequence_path": "1340425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1340425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1340425.protein.info.v11.5.txt",
		        "node_list_path": "1340425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1340425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaEndosymbiontOfOrnithodorosMoubataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella endosymbiont of Ornithodoros moubata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaEndosymbiontOfOrnithodorosMoubataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1981171.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1981171.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1981171.clusters.proteins.v11.5.txt",
		        "sequence_path": "1981171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1981171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1981171.protein.info.v11.5.txt",
		        "node_list_path": "1981171.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1981171.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpPbc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. PBC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpPbc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "795665.protein.sequences.v11.5.fa",
		        "enrichment_path": "795665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "795665.protein.info.v11.5.txt",
		        "node_list_path": "795665.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaSpF0087(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0087 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaSpF0087", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "706436.protein.sequences.v11.5.fa",
		        "enrichment_path": "706436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706436.protein.info.v11.5.txt",
		        "node_list_path": "706436.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumXenopi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium xenopi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumXenopi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1789.protein.info.v11.5.txt",
		        "node_list_path": "1789.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinomonasPosidonica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas posidonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasPosidonica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "491952.protein.sequences.v11.5.fa",
		        "enrichment_path": "491952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "491952.protein.info.v11.5.txt",
		        "node_list_path": "491952.protein.complete.v11.5.txt"
		    }
		]
    )()

def SutterellaSpCag351(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sutterella sp. CAG:351 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SutterellaSpCag351", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262975.protein.info.v11.5.txt",
		        "node_list_path": "1262975.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaGonorrhoeaeFa1090Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria gonorrhoeae FA 1090 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaGonorrhoeaeFa1090Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "242231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "242231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "242231.clusters.proteins.v11.5.txt",
		        "sequence_path": "242231.protein.sequences.v11.5.fa",
		        "enrichment_path": "242231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "242231.protein.info.v11.5.txt",
		        "node_list_path": "242231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "242231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VavraiaCulicisSubspFloridensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vavraia culicis subsp. floridensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VavraiaCulicisSubspFloridensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "948595.protein.sequences.v11.5.fa",
		        "enrichment_path": "948595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "948595.protein.info.v11.5.txt",
		        "node_list_path": "948595.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusGorillaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus gorillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusGorillaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1243662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1243662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1243662.clusters.proteins.v11.5.txt",
		        "sequence_path": "1243662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1243662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1243662.protein.info.v11.5.txt",
		        "node_list_path": "1243662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1243662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYonathbacteriaBacteriumRifcsplowo201Full4327Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPLOWO2_01_FULL_43_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsplowo201Full4327Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802726.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802726.protein.info.v11.5.txt",
		        "node_list_path": "1802726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasHalodenitrificansDsm735(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas halodenitrificans DSM 735 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasHalodenitrificansDsm735", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121941.protein.info.v11.5.txt",
		        "node_list_path": "1121941.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesObesi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes obesi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesObesi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118061.protein.info.v11.5.txt",
		        "node_list_path": "1118061.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSpechtbacteriaBacteriumRifcsplowo202Full388Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_02_FULL_38_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo202Full388Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802164.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802164.protein.info.v11.5.txt",
		        "node_list_path": "1802164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsphigho202Full5017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPHIGHO2_02_FULL_50_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202Full5017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801857.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801857.protein.info.v11.5.txt",
		        "node_list_path": "1801857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesStercorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides stercoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesStercorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "449673.clusters.info.v11.5.txt",
		        "cluster_tree_path": "449673.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "449673.clusters.proteins.v11.5.txt",
		        "sequence_path": "449673.protein.sequences.v11.5.fa",
		        "enrichment_path": "449673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "449673.protein.info.v11.5.txt",
		        "node_list_path": "449673.cluster.nodes.v11.5.txt",
		        "edge_list_path": "449673.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasNasturtii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas nasturtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasNasturtii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1843581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1843581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1843581.protein.info.v11.5.txt",
		        "node_list_path": "1843581.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusTestisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus testis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusTestisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1622072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1622072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1622072.clusters.proteins.v11.5.txt",
		        "sequence_path": "1622072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622072.protein.info.v11.5.txt",
		        "node_list_path": "1622072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1622072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaSpiritensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella spiritensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaSpiritensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "452.clusters.proteins.v11.5.txt",
		        "sequence_path": "452.protein.sequences.v11.5.fa",
		        "enrichment_path": "452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452.protein.info.v11.5.txt",
		        "node_list_path": "452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonasGranuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas granuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasGranuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223521.protein.info.v11.5.txt",
		        "node_list_path": "1223521.protein.complete.v11.5.txt"
		    }
		]
    )()

def IdiomarinaSpMd25aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sp. MD25a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaSpMd25aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1889913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1889913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1889913.clusters.proteins.v11.5.txt",
		        "sequence_path": "1889913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889913.protein.info.v11.5.txt",
		        "node_list_path": "1889913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1889913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChondrusCrispusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chondrus crispus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChondrusCrispusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2769.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2769.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2769.clusters.proteins.v11.5.txt",
		        "sequence_path": "2769.protein.sequences.v11.5.fa",
		        "enrichment_path": "2769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2769.protein.info.v11.5.txt",
		        "node_list_path": "2769.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2769.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CladophialophoraYegresiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora yegresii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CladophialophoraYegresiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "470704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "470704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "470704.clusters.proteins.v11.5.txt",
		        "sequence_path": "470704.protein.sequences.v11.5.fa",
		        "enrichment_path": "470704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "470704.protein.info.v11.5.txt",
		        "node_list_path": "470704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "470704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium284Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 284 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium284Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "397287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "397287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "397287.clusters.proteins.v11.5.txt",
		        "sequence_path": "397287.protein.sequences.v11.5.fa",
		        "enrichment_path": "397287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397287.protein.info.v11.5.txt",
		        "node_list_path": "397287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "397287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpLeaf395Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Leaf395 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpLeaf395Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736362.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736362.protein.info.v11.5.txt",
		        "node_list_path": "1736362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKimchicusJcm15530(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kimchicus JCM 15530 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKimchicusJcm15530", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1302272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302272.protein.info.v11.5.txt",
		        "node_list_path": "1302272.protein.complete.v11.5.txt"
		    }
		]
    )()

def NdongobacterMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ndongobacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NdongobacterMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871025.protein.info.v11.5.txt",
		        "node_list_path": "1871025.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3714(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_37_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3714", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798276.protein.info.v11.5.txt",
		        "node_list_path": "1798276.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeurosporaTetrasperma(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neurospora tetrasperma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeurosporaTetrasperma", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40127.protein.sequences.v11.5.fa",
		        "enrichment_path": "40127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40127.protein.info.v11.5.txt",
		        "node_list_path": "40127.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioDesulfuricansNd132(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans ND132 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioDesulfuricansNd132", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641491.protein.sequences.v11.5.fa",
		        "enrichment_path": "641491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641491.protein.info.v11.5.txt",
		        "node_list_path": "641491.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHimb55Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HIMB55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHimb55Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "745014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "745014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "745014.clusters.proteins.v11.5.txt",
		        "sequence_path": "745014.protein.sequences.v11.5.fa",
		        "enrichment_path": "745014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745014.protein.info.v11.5.txt",
		        "node_list_path": "745014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "745014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAtribacteriaBacteriumCg2303313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atribacteria bacterium CG2_30_33_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAtribacteriaBacteriumCg2303313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805029.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805029.protein.info.v11.5.txt",
		        "node_list_path": "1805029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAlkylphenoliaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alkylphenolia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAlkylphenoliaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "237609.clusters.info.v11.5.txt",
		        "cluster_tree_path": "237609.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "237609.clusters.proteins.v11.5.txt",
		        "sequence_path": "237609.protein.sequences.v11.5.fa",
		        "enrichment_path": "237609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237609.protein.info.v11.5.txt",
		        "node_list_path": "237609.cluster.nodes.v11.5.txt",
		        "edge_list_path": "237609.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag440Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag440Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262807.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262807.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262807.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262807.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262807.protein.info.v11.5.txt",
		        "node_list_path": "1262807.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262807.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusZopfiiNbrc100606Jcm9919Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus zopfii NBRC 100606 JCM 9919 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusZopfiiNbrc100606Jcm9919Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219030.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219030.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219030.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219030.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219030.protein.info.v11.5.txt",
		        "node_list_path": "1219030.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219030.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanktothrixTepidaPcc9214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planktothrix tepida PCC 9214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktothrixTepidaPcc9214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "671072.protein.sequences.v11.5.fa",
		        "enrichment_path": "671072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "671072.protein.info.v11.5.txt",
		        "node_list_path": "671072.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaOchraceaDsm7271(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea DSM7271 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaOchraceaDsm7271", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521097.protein.sequences.v11.5.fa",
		        "enrichment_path": "521097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521097.protein.info.v11.5.txt",
		        "node_list_path": "521097.protein.complete.v11.5.txt"
		    }
		]
    )()

def NakamurellaLacteaDsm19367Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nakamurella lactea DSM 19367 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NakamurellaLacteaDsm19367Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123241.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123241.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123241.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123241.protein.info.v11.5.txt",
		        "node_list_path": "1123241.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123241.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesDurhamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces durhamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesDurhamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68194.clusters.proteins.v11.5.txt",
		        "sequence_path": "68194.protein.sequences.v11.5.fa",
		        "enrichment_path": "68194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68194.protein.info.v11.5.txt",
		        "node_list_path": "68194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSpCs1bsmeth3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. CS1BSMeth3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSpCs1bsmeth3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1892844.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1892844.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1892844.clusters.proteins.v11.5.txt",
		        "sequence_path": "1892844.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892844.protein.info.v11.5.txt",
		        "node_list_path": "1892844.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1892844.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumArsenijeviciiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium arsenijevicii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumArsenijeviciiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1585697.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1585697.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1585697.clusters.proteins.v11.5.txt",
		        "sequence_path": "1585697.protein.sequences.v11.5.fa",
		        "enrichment_path": "1585697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1585697.protein.info.v11.5.txt",
		        "node_list_path": "1585697.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1585697.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EggerthiaCatenaformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eggerthia catenaformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthiaCatenaformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999415.clusters.proteins.v11.5.txt",
		        "sequence_path": "999415.protein.sequences.v11.5.fa",
		        "enrichment_path": "999415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999415.protein.info.v11.5.txt",
		        "node_list_path": "999415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumGwb1496Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium GWB1_49_6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumGwb1496Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798644.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798644.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798644.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798644.protein.info.v11.5.txt",
		        "node_list_path": "1798644.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798644.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumGwc23926Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWC2_39_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumGwc23926Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801951.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801951.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801951.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801951.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801951.protein.info.v11.5.txt",
		        "node_list_path": "1801951.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801951.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpGxs13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. GXS13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpGxs13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1730094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1730094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1730094.protein.info.v11.5.txt",
		        "node_list_path": "1730094.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArabidopsisLyrataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arabidopsis lyrata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArabidopsisLyrataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59689.clusters.proteins.v11.5.txt",
		        "sequence_path": "59689.protein.sequences.v11.5.fa",
		        "enrichment_path": "59689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59689.protein.info.v11.5.txt",
		        "node_list_path": "59689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulophagaAlgicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaAlgicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "688270.protein.sequences.v11.5.fa",
		        "enrichment_path": "688270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688270.protein.info.v11.5.txt",
		        "node_list_path": "688270.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaProteobacteriumKb13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return beta proteobacterium KB13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaProteobacteriumKb13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314607.clusters.proteins.v11.5.txt",
		        "sequence_path": "314607.protein.sequences.v11.5.fa",
		        "enrichment_path": "314607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314607.protein.info.v11.5.txt",
		        "node_list_path": "314607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LiberibacterAsiaticusPsy62(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus psy62 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LiberibacterAsiaticusPsy62", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "537021.protein.sequences.v11.5.fa",
		        "enrichment_path": "537021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537021.protein.info.v11.5.txt",
		        "node_list_path": "537021.protein.complete.v11.5.txt"
		    }
		]
    )()

def PiscirickettsiaSalmonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Piscirickettsia salmonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiscirickettsiaSalmonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1238.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1238.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1238.clusters.proteins.v11.5.txt",
		        "sequence_path": "1238.protein.sequences.v11.5.fa",
		        "enrichment_path": "1238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1238.protein.info.v11.5.txt",
		        "node_list_path": "1238.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1238.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UstilagoMaydisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ustilago maydis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UstilagoMaydisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5270.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5270.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5270.clusters.proteins.v11.5.txt",
		        "sequence_path": "5270.protein.sequences.v11.5.fa",
		        "enrichment_path": "5270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5270.protein.info.v11.5.txt",
		        "node_list_path": "5270.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5270.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumGw2011Gwe24668Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_46_68 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24668Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618994.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618994.protein.info.v11.5.txt",
		        "node_list_path": "1618994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumMassiliodielmoenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium massiliodielmoense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumMassiliodielmoenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776385.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776385.protein.info.v11.5.txt",
		        "node_list_path": "1776385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSpMc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. MC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSpMc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717785.protein.sequences.v11.5.fa",
		        "enrichment_path": "717785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717785.protein.info.v11.5.txt",
		        "node_list_path": "717785.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaSchoenbuchensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella schoenbuchensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSchoenbuchensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094496.protein.info.v11.5.txt",
		        "node_list_path": "1094496.protein.complete.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaSchlechtendaliaChinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Schlechtendalia chinensis) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaSchlechtendaliaChinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118110.clusters.proteins.v11.5.txt",
		        "sequence_path": "118110.protein.sequences.v11.5.fa",
		        "enrichment_path": "118110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118110.protein.info.v11.5.txt",
		        "node_list_path": "118110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogulbenkianiaSubflavaDsm22618(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania subflava DSM 22618 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogulbenkianiaSubflavaDsm22618", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123014.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123014.protein.info.v11.5.txt",
		        "node_list_path": "1123014.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAustralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAustralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888833.clusters.proteins.v11.5.txt",
		        "sequence_path": "888833.protein.sequences.v11.5.fa",
		        "enrichment_path": "888833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888833.protein.info.v11.5.txt",
		        "node_list_path": "888833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CobetiaCrustatorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cobetia crustatorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CobetiaCrustatorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553385.protein.sequences.v11.5.fa",
		        "enrichment_path": "553385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553385.protein.info.v11.5.txt",
		        "node_list_path": "553385.protein.complete.v11.5.txt"
		    }
		]
    )()

def TerrimonasFerrugineaDsm30193Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terrimonas ferruginea DSM 30193 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrimonasFerrugineaDsm30193Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123356.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123356.protein.info.v11.5.txt",
		        "node_list_path": "1123356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentibacillusJeotgali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentibacillusJeotgali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "558169.protein.sequences.v11.5.fa",
		        "enrichment_path": "558169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558169.protein.info.v11.5.txt",
		        "node_list_path": "558169.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldimonasTaiwanensisNbrc104434Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldimonas taiwanensis NBRC 104434 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldimonasTaiwanensisNbrc104434Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349753.protein.info.v11.5.txt",
		        "node_list_path": "1349753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSp7136(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. 71-36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSp7136", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895788.protein.info.v11.5.txt",
		        "node_list_path": "1895788.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumOxydansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium oxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumOxydansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "82380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "82380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "82380.clusters.proteins.v11.5.txt",
		        "sequence_path": "82380.protein.sequences.v11.5.fa",
		        "enrichment_path": "82380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82380.protein.info.v11.5.txt",
		        "node_list_path": "82380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "82380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasSpartinae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas spartinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasSpartinae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1792290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792290.protein.info.v11.5.txt",
		        "node_list_path": "1792290.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzohydromonasAustralicaDsm1124Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azohydromonas australica DSM 1124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzohydromonasAustralicaDsm1124Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121030.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121030.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121030.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121030.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121030.protein.info.v11.5.txt",
		        "node_list_path": "1121030.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121030.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpAntB3c2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. ANT-B3C2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpAntB3c2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1844758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1844758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1844758.protein.info.v11.5.txt",
		        "node_list_path": "1844758.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusInfantisNrrlB14911Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus infantis NRRL B-14911 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusInfantisNrrlB14911Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1367477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1367477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1367477.clusters.proteins.v11.5.txt",
		        "sequence_path": "1367477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1367477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1367477.protein.info.v11.5.txt",
		        "node_list_path": "1367477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1367477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CutibacteriumAvidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cutibacterium avidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CutibacteriumAvidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33010.protein.sequences.v11.5.fa",
		        "enrichment_path": "33010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33010.protein.info.v11.5.txt",
		        "node_list_path": "33010.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusAlginolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alginolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusAlginolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122915.protein.info.v11.5.txt",
		        "node_list_path": "1122915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpWg5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. WG5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpWg5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1707785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1707785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1707785.clusters.proteins.v11.5.txt",
		        "sequence_path": "1707785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1707785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1707785.protein.info.v11.5.txt",
		        "node_list_path": "1707785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1707785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwc13813(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWC1_38_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwc13813", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618583.protein.info.v11.5.txt",
		        "node_list_path": "1618583.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacteraceaeBacteriumAt5844Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacteraceae bacterium AT5844 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacteraceaeBacteriumAt5844Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1054213.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1054213.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1054213.clusters.proteins.v11.5.txt",
		        "sequence_path": "1054213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1054213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1054213.protein.info.v11.5.txt",
		        "node_list_path": "1054213.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1054213.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachyspiraSpCag484Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira sp. CAG:484 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachyspiraSpCag484Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262759.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262759.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262759.protein.info.v11.5.txt",
		        "node_list_path": "1262759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioplocaIngrica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioploca ingrica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioplocaIngrica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40754.protein.sequences.v11.5.fa",
		        "enrichment_path": "40754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40754.protein.info.v11.5.txt",
		        "node_list_path": "40754.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumRuminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum ruminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumRuminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "696281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "696281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "696281.clusters.proteins.v11.5.txt",
		        "sequence_path": "696281.protein.sequences.v11.5.fa",
		        "enrichment_path": "696281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696281.protein.info.v11.5.txt",
		        "node_list_path": "696281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "696281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "266128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "266128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "266128.clusters.proteins.v11.5.txt",
		        "sequence_path": "266128.protein.sequences.v11.5.fa",
		        "enrichment_path": "266128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "266128.protein.info.v11.5.txt",
		        "node_list_path": "266128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "266128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinarimonadaceaeBacteriumHl109(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinarimonadaceae bacterium HL-109 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinarimonadaceaeBacteriumHl109", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1653334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1653334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1653334.protein.info.v11.5.txt",
		        "node_list_path": "1653334.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusAmylolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus amylolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusAmylolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "294699.clusters.info.v11.5.txt",
		        "cluster_tree_path": "294699.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "294699.clusters.proteins.v11.5.txt",
		        "sequence_path": "294699.protein.sequences.v11.5.fa",
		        "enrichment_path": "294699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294699.protein.info.v11.5.txt",
		        "node_list_path": "294699.cluster.nodes.v11.5.txt",
		        "edge_list_path": "294699.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesNourseiAtcc11455Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces noursei ATCC 11455 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesNourseiAtcc11455Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316284.clusters.proteins.v11.5.txt",
		        "sequence_path": "316284.protein.sequences.v11.5.fa",
		        "enrichment_path": "316284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316284.protein.info.v11.5.txt",
		        "node_list_path": "316284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaCanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaCanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "493.protein.sequences.v11.5.fa",
		        "enrichment_path": "493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "493.protein.info.v11.5.txt",
		        "node_list_path": "493.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaCanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaCanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1848903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1848903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1848903.clusters.proteins.v11.5.txt",
		        "sequence_path": "1848903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848903.protein.info.v11.5.txt",
		        "node_list_path": "1848903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1848903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinopolysporaMortivallisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora mortivallis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolysporaMortivallisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1050202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1050202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1050202.clusters.proteins.v11.5.txt",
		        "sequence_path": "1050202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1050202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1050202.protein.info.v11.5.txt",
		        "node_list_path": "1050202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1050202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4024(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4024", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798385.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798385.protein.info.v11.5.txt",
		        "node_list_path": "1798385.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat28004Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-28004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat28004Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1679165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1679165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1679165.clusters.proteins.v11.5.txt",
		        "sequence_path": "1679165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679165.protein.info.v11.5.txt",
		        "node_list_path": "1679165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1679165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpP5119Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. P5-119 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpP5119Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1602171.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1602171.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1602171.clusters.proteins.v11.5.txt",
		        "sequence_path": "1602171.protein.sequences.v11.5.fa",
		        "enrichment_path": "1602171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1602171.protein.info.v11.5.txt",
		        "node_list_path": "1602171.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1602171.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolobacteriumMooreiF0204(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solobacterium moorei F0204 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolobacteriumMooreiF0204", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "706433.protein.sequences.v11.5.fa",
		        "enrichment_path": "706433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706433.protein.info.v11.5.txt",
		        "node_list_path": "706433.protein.complete.v11.5.txt"
		    }
		]
    )()

def LampropediaCohaerens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lampropedia cohaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LampropediaCohaerens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1610491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1610491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1610491.protein.info.v11.5.txt",
		        "node_list_path": "1610491.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemmatimonadetesBacteriumKbs708Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium KBS708 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonadetesBacteriumKbs708Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "861299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "861299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "861299.clusters.proteins.v11.5.txt",
		        "sequence_path": "861299.protein.sequences.v11.5.fa",
		        "enrichment_path": "861299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861299.protein.info.v11.5.txt",
		        "node_list_path": "861299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "861299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaWashoensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella washoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaWashoensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094563.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094563.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094563.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094563.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094563.protein.info.v11.5.txt",
		        "node_list_path": "1094563.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094563.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSpRim28Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSpRim28Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1100720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1100720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1100720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1100720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1100720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1100720.protein.info.v11.5.txt",
		        "node_list_path": "1100720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1100720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusProtochlamydiaNaegleriophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Protochlamydia naegleriophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusProtochlamydiaNaegleriophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "389348.protein.sequences.v11.5.fa",
		        "enrichment_path": "389348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "389348.protein.info.v11.5.txt",
		        "node_list_path": "389348.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaPneumoniaeAr39(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae AR39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaPneumoniaeAr39", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "115711.protein.sequences.v11.5.fa",
		        "enrichment_path": "115711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115711.protein.info.v11.5.txt",
		        "node_list_path": "115711.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot1203(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1203 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot1203", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736427.protein.info.v11.5.txt",
		        "node_list_path": "1736427.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobiArchaeonJdfr42Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobi archaeon JdFR-42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobiArchaeonJdfr42Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935016.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935016.protein.info.v11.5.txt",
		        "node_list_path": "1935016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontStrain(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont strain graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontStrain", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "292805.protein.sequences.v11.5.fa",
		        "enrichment_path": "292805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292805.protein.info.v11.5.txt",
		        "node_list_path": "292805.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrioBacteriovorusStrTiberiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus str. Tiberius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrioBacteriovorusStrTiberiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1069642.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1069642.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1069642.clusters.proteins.v11.5.txt",
		        "sequence_path": "1069642.protein.sequences.v11.5.fa",
		        "enrichment_path": "1069642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1069642.protein.info.v11.5.txt",
		        "node_list_path": "1069642.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1069642.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp303mfcol52Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 303MFCol52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp303mfcol52Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1172181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1172181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1172181.clusters.proteins.v11.5.txt",
		        "sequence_path": "1172181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1172181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1172181.protein.info.v11.5.txt",
		        "node_list_path": "1172181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1172181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumJoostei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium joostei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumJoostei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "112234.protein.sequences.v11.5.fa",
		        "enrichment_path": "112234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112234.protein.info.v11.5.txt",
		        "node_list_path": "112234.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErysipelothrixLarvaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysipelothrix larvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelothrixLarvaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1514105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1514105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1514105.clusters.proteins.v11.5.txt",
		        "sequence_path": "1514105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1514105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1514105.protein.info.v11.5.txt",
		        "node_list_path": "1514105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1514105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MannheimiaHaemolyticaM42548Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica M42548 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaHaemolyticaM42548Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1316932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1316932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1316932.clusters.proteins.v11.5.txt",
		        "sequence_path": "1316932.protein.sequences.v11.5.fa",
		        "enrichment_path": "1316932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1316932.protein.info.v11.5.txt",
		        "node_list_path": "1316932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1316932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoflexibacterRuber(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoflexibacter ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoflexibacterRuber", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1003.protein.info.v11.5.txt",
		        "node_list_path": "1003.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchlesneriaPaludicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schlesneria paludicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchlesneriaPaludicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123242.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123242.protein.info.v11.5.txt",
		        "node_list_path": "1123242.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalanaerobiumSaccharolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halanaerobium saccharolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaerobiumSaccharolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1293054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293054.protein.info.v11.5.txt",
		        "node_list_path": "1293054.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrenophoraTriticiRepentisPt1cBfpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora tritici-repentis Pt-1C-BFP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrenophoraTriticiRepentisPt1cBfpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426418.clusters.proteins.v11.5.txt",
		        "sequence_path": "426418.protein.sequences.v11.5.fa",
		        "enrichment_path": "426418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426418.protein.info.v11.5.txt",
		        "node_list_path": "426418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusDestructans2063121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus destructans 20631-21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusDestructans2063121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658429.protein.sequences.v11.5.fa",
		        "enrichment_path": "658429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658429.protein.info.v11.5.txt",
		        "node_list_path": "658429.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaPolyisoprenivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia polyisoprenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaPolyisoprenivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1112204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112204.protein.info.v11.5.txt",
		        "node_list_path": "1112204.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesJohnsonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides johnsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesJohnsonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999419.protein.sequences.v11.5.fa",
		        "enrichment_path": "999419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999419.protein.info.v11.5.txt",
		        "node_list_path": "999419.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterZhejiangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter zhejiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterZhejiangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "488535.protein.sequences.v11.5.fa",
		        "enrichment_path": "488535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "488535.protein.info.v11.5.txt",
		        "node_list_path": "488535.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryobacteriumLuteumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryobacterium luteum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryobacteriumLuteumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1424661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1424661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1424661.clusters.proteins.v11.5.txt",
		        "sequence_path": "1424661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1424661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1424661.protein.info.v11.5.txt",
		        "node_list_path": "1424661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1424661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpNies3755(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. NIES-3755 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpNies3755", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752064.protein.info.v11.5.txt",
		        "node_list_path": "1752064.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumCag3125820Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium CAG:312_58_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumCag3125820Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897025.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897025.protein.info.v11.5.txt",
		        "node_list_path": "1897025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusMeridieiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus meridiei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusMeridieiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "768704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "768704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "768704.clusters.proteins.v11.5.txt",
		        "sequence_path": "768704.protein.sequences.v11.5.fa",
		        "enrichment_path": "768704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768704.protein.info.v11.5.txt",
		        "node_list_path": "768704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "768704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusDurus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus durus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusDurus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44251.protein.sequences.v11.5.fa",
		        "enrichment_path": "44251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44251.protein.info.v11.5.txt",
		        "node_list_path": "44251.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRifoxyd1Full5531(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1_FULL_55_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1Full5531", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797404.protein.info.v11.5.txt",
		        "node_list_path": "1797404.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusKuroshimensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus kuroshimensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusKuroshimensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121938.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121938.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121938.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121938.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121938.protein.info.v11.5.txt",
		        "node_list_path": "1121938.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121938.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesDirusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles dirus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesDirusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7168.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7168.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7168.clusters.proteins.v11.5.txt",
		        "sequence_path": "7168.protein.sequences.v11.5.fa",
		        "enrichment_path": "7168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7168.protein.info.v11.5.txt",
		        "node_list_path": "7168.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7168.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaceaeBacteriumTaa166(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium TAA166 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaceaeBacteriumTaa166", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "278963.protein.sequences.v11.5.fa",
		        "enrichment_path": "278963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278963.protein.info.v11.5.txt",
		        "node_list_path": "278963.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrodermaBenhamiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthroderma benhamiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrodermaBenhamiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "63400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "63400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "63400.clusters.proteins.v11.5.txt",
		        "sequence_path": "63400.protein.sequences.v11.5.fa",
		        "enrichment_path": "63400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63400.protein.info.v11.5.txt",
		        "node_list_path": "63400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "63400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSp6654Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. 66-54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSp6654Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895845.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895845.protein.info.v11.5.txt",
		        "node_list_path": "1895845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterButzleriEd1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter butzleri ED1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterButzleriEd1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "944546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "944546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "944546.clusters.proteins.v11.5.txt",
		        "sequence_path": "944546.protein.sequences.v11.5.fa",
		        "enrichment_path": "944546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944546.protein.info.v11.5.txt",
		        "node_list_path": "944546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "944546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaCanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaCanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1848903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848903.protein.info.v11.5.txt",
		        "node_list_path": "1848903.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodoferaxAntarcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodoferax antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodoferaxAntarcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "81479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "81479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "81479.clusters.proteins.v11.5.txt",
		        "sequence_path": "81479.protein.sequences.v11.5.fa",
		        "enrichment_path": "81479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81479.protein.info.v11.5.txt",
		        "node_list_path": "81479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "81479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpElb17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. ELB17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpElb17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "270374.protein.sequences.v11.5.fa",
		        "enrichment_path": "270374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "270374.protein.info.v11.5.txt",
		        "node_list_path": "270374.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf525(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF525 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf525", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463861.protein.info.v11.5.txt",
		        "node_list_path": "1463861.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusThermophilusHb8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus HB8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusThermophilusHb8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "300852.protein.sequences.v11.5.fa",
		        "enrichment_path": "300852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "300852.protein.info.v11.5.txt",
		        "node_list_path": "300852.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetrasphaeraJenkinsiiBen74(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera jenkinsii Ben 74 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrasphaeraJenkinsiiBen74", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193518.protein.info.v11.5.txt",
		        "node_list_path": "1193518.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacterium4019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 40-19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacterium4019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895705.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895705.protein.info.v11.5.txt",
		        "node_list_path": "1895705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporosarcinaSpHyo08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina sp. HYO08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaSpHyo08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1759557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759557.protein.info.v11.5.txt",
		        "node_list_path": "1759557.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumG41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium G41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumG41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1200749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1200749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1200749.clusters.proteins.v11.5.txt",
		        "sequence_path": "1200749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200749.protein.info.v11.5.txt",
		        "node_list_path": "1200749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1200749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumTuscanienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium tuscaniense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumTuscanienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1401064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1401064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1401064.clusters.proteins.v11.5.txt",
		        "sequence_path": "1401064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1401064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1401064.protein.info.v11.5.txt",
		        "node_list_path": "1401064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1401064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg16488(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_48_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg16488", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797641.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797641.protein.info.v11.5.txt",
		        "node_list_path": "1797641.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcaceaeBacteriumPga8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium pGA-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcaceaeBacteriumPga8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520829.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520829.protein.info.v11.5.txt",
		        "node_list_path": "1520829.protein.complete.v11.5.txt"
		    }
		]
    )()

def Sar116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return SAR116 cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "909943.protein.sequences.v11.5.fa",
		        "enrichment_path": "909943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "909943.protein.info.v11.5.txt",
		        "node_list_path": "909943.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumYanoikuyae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium yanoikuyae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumYanoikuyae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "13690.protein.sequences.v11.5.fa",
		        "enrichment_path": "13690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13690.protein.info.v11.5.txt",
		        "node_list_path": "13690.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumTrifoliiWsm2304Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum trifolii WSM2304 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumTrifoliiWsm2304Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "395492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "395492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "395492.clusters.proteins.v11.5.txt",
		        "sequence_path": "395492.protein.sequences.v11.5.fa",
		        "enrichment_path": "395492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395492.protein.info.v11.5.txt",
		        "node_list_path": "395492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "395492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusAlcaliphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus alcaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusAlcaliphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34002.protein.sequences.v11.5.fa",
		        "enrichment_path": "34002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34002.protein.info.v11.5.txt",
		        "node_list_path": "34002.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferThermotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer thermotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferThermotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "252514.protein.sequences.v11.5.fa",
		        "enrichment_path": "252514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "252514.protein.info.v11.5.txt",
		        "node_list_path": "252514.protein.complete.v11.5.txt"
		    }
		]
    )()

def SimplicispiraPsychrophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Simplicispira psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SimplicispiraPsychrophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123255.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123255.protein.info.v11.5.txt",
		        "node_list_path": "1123255.protein.complete.v11.5.txt"
		    }
		]
    )()

def HamiltosporidiumMagnivora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hamiltosporidium magnivora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HamiltosporidiumMagnivora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "148818.protein.sequences.v11.5.fa",
		        "enrichment_path": "148818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "148818.protein.info.v11.5.txt",
		        "node_list_path": "148818.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrioExovorusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrio exovorus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrioExovorusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1184267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1184267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1184267.clusters.proteins.v11.5.txt",
		        "sequence_path": "1184267.protein.sequences.v11.5.fa",
		        "enrichment_path": "1184267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1184267.protein.info.v11.5.txt",
		        "node_list_path": "1184267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1184267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonadaceaeBacteriumUkl131Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonadaceae bacterium UKL13-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonadaceaeBacteriumUkl131Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1690484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1690484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1690484.clusters.proteins.v11.5.txt",
		        "sequence_path": "1690484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690484.protein.info.v11.5.txt",
		        "node_list_path": "1690484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1690484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsphigho202Full3814(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO2_02_FULL_38_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho202Full3814", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802620.protein.info.v11.5.txt",
		        "node_list_path": "1802620.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaConcavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia concava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaConcavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206741.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206741.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206741.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206741.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206741.protein.info.v11.5.txt",
		        "node_list_path": "1206741.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206741.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurvibacterSpPaeUm(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter sp. PAE-UM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurvibacterSpPaeUm", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1714344.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714344.protein.info.v11.5.txt",
		        "node_list_path": "1714344.protein.complete.v11.5.txt"
		    }
		]
    )()

def PygocentrusNattereriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pygocentrus nattereri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PygocentrusNattereriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42514.clusters.proteins.v11.5.txt",
		        "sequence_path": "42514.protein.sequences.v11.5.fa",
		        "enrichment_path": "42514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42514.protein.info.v11.5.txt",
		        "node_list_path": "42514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasEucrenophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas eucrenophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasEucrenophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649.clusters.proteins.v11.5.txt",
		        "sequence_path": "649.protein.sequences.v11.5.fa",
		        "enrichment_path": "649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649.protein.info.v11.5.txt",
		        "node_list_path": "649.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermodesulfobacteriumCommune(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium commune graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfobacteriumCommune", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "289377.protein.sequences.v11.5.fa",
		        "enrichment_path": "289377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "289377.protein.info.v11.5.txt",
		        "node_list_path": "289377.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumGw2011Gwc23313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWC2_33_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwc23313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619061.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619061.protein.info.v11.5.txt",
		        "node_list_path": "1619061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpMctg268Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. MCTG268 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpMctg268Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415754.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415754.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415754.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415754.protein.info.v11.5.txt",
		        "node_list_path": "1415754.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415754.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAppendicisCip107643Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium appendicis CIP 107643 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAppendicisCip107643Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1161099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1161099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1161099.clusters.proteins.v11.5.txt",
		        "sequence_path": "1161099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1161099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1161099.protein.info.v11.5.txt",
		        "node_list_path": "1161099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1161099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSpOk098(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK098 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSpOk098", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855297.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855297.protein.info.v11.5.txt",
		        "node_list_path": "1855297.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpKh9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. KH9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpKh9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855324.protein.info.v11.5.txt",
		        "node_list_path": "1855324.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCb00455(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB00455 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCb00455", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703927.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703927.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703927.protein.info.v11.5.txt",
		        "node_list_path": "1703927.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpCpu(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Cpu graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpCpu", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1075399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1075399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1075399.protein.info.v11.5.txt",
		        "node_list_path": "1075399.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioGigas(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio gigas graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioGigas", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121448.protein.info.v11.5.txt",
		        "node_list_path": "1121448.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaLoescheii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella loescheii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaLoescheii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122985.protein.info.v11.5.txt",
		        "node_list_path": "1122985.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizophagusSpMucl43196(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus sp. MUCL 43196 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizophagusSpMucl43196", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803374.protein.info.v11.5.txt",
		        "node_list_path": "1803374.protein.complete.v11.5.txt"
		    }
		]
    )()

def NaegleriaGruberi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Naegleria gruberi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NaegleriaGruberi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5762.protein.sequences.v11.5.fa",
		        "enrichment_path": "5762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5762.protein.info.v11.5.txt",
		        "node_list_path": "5762.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumPseudocatenulatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudocatenulatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumPseudocatenulatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "547043.protein.sequences.v11.5.fa",
		        "enrichment_path": "547043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547043.protein.info.v11.5.txt",
		        "node_list_path": "547043.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusSulfureus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sulfureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSulfureus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1140003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1140003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1140003.protein.info.v11.5.txt",
		        "node_list_path": "1140003.protein.complete.v11.5.txt"
		    }
		]
    )()

def JaminaeaRoseaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jaminaea rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JaminaeaRoseaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1569628.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1569628.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1569628.clusters.proteins.v11.5.txt",
		        "sequence_path": "1569628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1569628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1569628.protein.info.v11.5.txt",
		        "node_list_path": "1569628.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1569628.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaRiboflavina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia riboflavina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaRiboflavina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46914.protein.sequences.v11.5.fa",
		        "enrichment_path": "46914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46914.protein.info.v11.5.txt",
		        "node_list_path": "46914.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrinomonasMethylaliphatogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrinomonas methylaliphatogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrinomonasMethylaliphatogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "454194.clusters.info.v11.5.txt",
		        "cluster_tree_path": "454194.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "454194.clusters.proteins.v11.5.txt",
		        "sequence_path": "454194.protein.sequences.v11.5.fa",
		        "enrichment_path": "454194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454194.protein.info.v11.5.txt",
		        "node_list_path": "454194.cluster.nodes.v11.5.txt",
		        "edge_list_path": "454194.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloferaxVolcaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloferax volcanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloferaxVolcaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "309800.clusters.info.v11.5.txt",
		        "cluster_tree_path": "309800.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "309800.clusters.proteins.v11.5.txt",
		        "sequence_path": "309800.protein.sequences.v11.5.fa",
		        "enrichment_path": "309800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "309800.protein.info.v11.5.txt",
		        "node_list_path": "309800.cluster.nodes.v11.5.txt",
		        "edge_list_path": "309800.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AggregatibacterSegnisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter segnis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterSegnisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "739.clusters.proteins.v11.5.txt",
		        "sequence_path": "739.protein.sequences.v11.5.fa",
		        "enrichment_path": "739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "739.protein.info.v11.5.txt",
		        "node_list_path": "739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaWoodyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella woodyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaWoodyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "392500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "392500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "392500.clusters.proteins.v11.5.txt",
		        "sequence_path": "392500.protein.sequences.v11.5.fa",
		        "enrichment_path": "392500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392500.protein.info.v11.5.txt",
		        "node_list_path": "392500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "392500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaArabinofermentansNrrlYb2248(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Candida] arabinofermentans NRRL YB-2248 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaArabinofermentansNrrlYb2248", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983967.protein.sequences.v11.5.fa",
		        "enrichment_path": "983967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983967.protein.info.v11.5.txt",
		        "node_list_path": "983967.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycetosporaChiangmaiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomycetospora chiangmaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycetosporaChiangmaiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120948.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120948.protein.info.v11.5.txt",
		        "node_list_path": "1120948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumRifcsplowo201Full3811Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPLOWO2_01_FULL_38_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsplowo201Full3811Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802556.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802556.protein.info.v11.5.txt",
		        "node_list_path": "1802556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CastorCanadensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Castor canadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CastorCanadensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "51338.protein.sequences.v11.5.fa",
		        "enrichment_path": "51338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51338.protein.info.v11.5.txt",
		        "node_list_path": "51338.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeuconostocLactis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc lactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeuconostocLactis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246.protein.info.v11.5.txt",
		        "node_list_path": "1246.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsplowo212Full5124Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPLOWO2_12_FULL_51_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212Full5124Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801869.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801869.protein.info.v11.5.txt",
		        "node_list_path": "1801869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumBohemicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium bohemicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumBohemicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2052828.protein.sequences.v11.5.fa",
		        "enrichment_path": "2052828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2052828.protein.info.v11.5.txt",
		        "node_list_path": "2052828.protein.complete.v11.5.txt"
		    }
		]
    )()

def FormivibrioCitricusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Formivibrio citricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormivibrioCitricusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83765.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83765.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83765.clusters.proteins.v11.5.txt",
		        "sequence_path": "83765.protein.sequences.v11.5.fa",
		        "enrichment_path": "83765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83765.protein.info.v11.5.txt",
		        "node_list_path": "83765.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83765.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRoot190(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root190 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRoot190", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736488.protein.info.v11.5.txt",
		        "node_list_path": "1736488.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusBrevisX23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus brevis X23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusBrevisX23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1200792.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1200792.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1200792.clusters.proteins.v11.5.txt",
		        "sequence_path": "1200792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200792.protein.info.v11.5.txt",
		        "node_list_path": "1200792.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1200792.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPolymyxaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPolymyxaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1406.clusters.proteins.v11.5.txt",
		        "sequence_path": "1406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1406.protein.info.v11.5.txt",
		        "node_list_path": "1406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DickeyaZeae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya zeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaZeae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "561229.protein.sequences.v11.5.fa",
		        "enrichment_path": "561229.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561229.protein.info.v11.5.txt",
		        "node_list_path": "561229.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium filum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121889.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121889.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121889.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121889.protein.info.v11.5.txt",
		        "node_list_path": "1121889.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121889.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot149Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root149 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot149Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736473.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736473.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736473.protein.info.v11.5.txt",
		        "node_list_path": "1736473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesVenezuelae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces venezuelae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesVenezuelae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "953739.protein.sequences.v11.5.fa",
		        "enrichment_path": "953739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "953739.protein.info.v11.5.txt",
		        "node_list_path": "953739.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSulfidigenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sulfidigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSulfidigenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "318464.protein.sequences.v11.5.fa",
		        "enrichment_path": "318464.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318464.protein.info.v11.5.txt",
		        "node_list_path": "318464.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusLaterosporusDsm25(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus laterosporus DSM25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusLaterosporusDsm25", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121121.protein.info.v11.5.txt",
		        "node_list_path": "1121121.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumHoustonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium houstonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumHoustonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "146021.protein.sequences.v11.5.fa",
		        "enrichment_path": "146021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146021.protein.info.v11.5.txt",
		        "node_list_path": "146021.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermothelomycesThermophilusAtcc42464(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermothelomyces thermophilus ATCC 42464 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermothelomycesThermophilusAtcc42464", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573729.protein.sequences.v11.5.fa",
		        "enrichment_path": "573729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573729.protein.info.v11.5.txt",
		        "node_list_path": "573729.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonRbg164813(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_16_48_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg164813", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797381.protein.info.v11.5.txt",
		        "node_list_path": "1797381.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeochlamydiaSpEps4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neochlamydia sp. EPS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeochlamydiaSpEps4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1478175.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1478175.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1478175.clusters.proteins.v11.5.txt",
		        "sequence_path": "1478175.protein.sequences.v11.5.fa",
		        "enrichment_path": "1478175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1478175.protein.info.v11.5.txt",
		        "node_list_path": "1478175.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1478175.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full399(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full399", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802040.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802040.protein.info.v11.5.txt",
		        "node_list_path": "1802040.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumSublineolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum sublineola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumSublineolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173701.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173701.protein.info.v11.5.txt",
		        "node_list_path": "1173701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RiemerellaAnatipestiferCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Riemerella anatipestifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RiemerellaAnatipestiferCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "992406.clusters.info.v11.5.txt",
		        "cluster_tree_path": "992406.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "992406.clusters.proteins.v11.5.txt",
		        "sequence_path": "992406.protein.sequences.v11.5.fa",
		        "enrichment_path": "992406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "992406.protein.info.v11.5.txt",
		        "node_list_path": "992406.cluster.nodes.v11.5.txt",
		        "edge_list_path": "992406.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumHibernumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium hibernum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumHibernumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37752.clusters.proteins.v11.5.txt",
		        "sequence_path": "37752.protein.sequences.v11.5.fa",
		        "enrichment_path": "37752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37752.protein.info.v11.5.txt",
		        "node_list_path": "37752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpCf149(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CF149 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpCf149", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "911239.protein.sequences.v11.5.fa",
		        "enrichment_path": "911239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "911239.protein.info.v11.5.txt",
		        "node_list_path": "911239.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalogenimonasFormicexedens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dehalogenimonas formicexedens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalogenimonasFormicexedens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1839801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1839801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1839801.protein.info.v11.5.txt",
		        "node_list_path": "1839801.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasTunicata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas tunicata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasTunicata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "87626.protein.sequences.v11.5.fa",
		        "enrichment_path": "87626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "87626.protein.info.v11.5.txt",
		        "node_list_path": "87626.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusBoroniphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus boroniphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusBoroniphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1294265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1294265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1294265.clusters.proteins.v11.5.txt",
		        "sequence_path": "1294265.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294265.protein.info.v11.5.txt",
		        "node_list_path": "1294265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1294265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalolactibacillusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halolactibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolactibacillusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "306540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "306540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "306540.clusters.proteins.v11.5.txt",
		        "sequence_path": "306540.protein.sequences.v11.5.fa",
		        "enrichment_path": "306540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306540.protein.info.v11.5.txt",
		        "node_list_path": "306540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "306540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaBacilliformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaBacilliformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "360095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "360095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "360095.clusters.proteins.v11.5.txt",
		        "sequence_path": "360095.protein.sequences.v11.5.fa",
		        "enrichment_path": "360095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360095.protein.info.v11.5.txt",
		        "node_list_path": "360095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "360095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho212Full5423Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_12_FULL_54_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho212Full5423Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802397.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802397.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802397.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802397.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802397.protein.info.v11.5.txt",
		        "node_list_path": "1802397.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802397.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAnorexicamassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium anorexicamassiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAnorexicamassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211817.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211817.protein.info.v11.5.txt",
		        "node_list_path": "1211817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumFossorDsm15642Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium fossor DSM 15642 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumFossorDsm15642Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121023.protein.info.v11.5.txt",
		        "node_list_path": "1121023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumTaichungense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium taichungense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumTaichungense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "295069.protein.sequences.v11.5.fa",
		        "enrichment_path": "295069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "295069.protein.info.v11.5.txt",
		        "node_list_path": "295069.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumGwf25119(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium GWF2_51_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumGwf25119", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802431.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802431.protein.info.v11.5.txt",
		        "node_list_path": "1802431.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalogenimonasFormicexedensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalogenimonas formicexedens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalogenimonasFormicexedensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1839801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1839801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1839801.clusters.proteins.v11.5.txt",
		        "sequence_path": "1839801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1839801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1839801.protein.info.v11.5.txt",
		        "node_list_path": "1839801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1839801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ApiotrichumPorosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Apiotrichum porosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApiotrichumPorosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "105984.clusters.info.v11.5.txt",
		        "cluster_tree_path": "105984.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "105984.clusters.proteins.v11.5.txt",
		        "sequence_path": "105984.protein.sequences.v11.5.fa",
		        "enrichment_path": "105984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105984.protein.info.v11.5.txt",
		        "node_list_path": "105984.cluster.nodes.v11.5.txt",
		        "edge_list_path": "105984.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermocrispumAgresteDsm44070Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermocrispum agreste DSM 44070 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocrispumAgresteDsm44070Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111738.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111738.protein.info.v11.5.txt",
		        "node_list_path": "1111738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusDentisani7747Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dentisani 7747 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDentisani7747Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1297857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1297857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1297857.clusters.proteins.v11.5.txt",
		        "sequence_path": "1297857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297857.protein.info.v11.5.txt",
		        "node_list_path": "1297857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1297857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumNk3b98Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium NK3B98 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumNk3b98Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "877414.clusters.info.v11.5.txt",
		        "cluster_tree_path": "877414.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "877414.clusters.proteins.v11.5.txt",
		        "sequence_path": "877414.protein.sequences.v11.5.fa",
		        "enrichment_path": "877414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877414.protein.info.v11.5.txt",
		        "node_list_path": "877414.cluster.nodes.v11.5.txt",
		        "edge_list_path": "877414.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpHot20860m813i02(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. HOT208_60m_813I02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpHot20860m813i02", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1961091.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961091.protein.info.v11.5.txt",
		        "node_list_path": "1961091.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpKrocy2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. KROCY2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpKrocy2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1305732.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1305732.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1305732.clusters.proteins.v11.5.txt",
		        "sequence_path": "1305732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305732.protein.info.v11.5.txt",
		        "node_list_path": "1305732.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1305732.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNealsonbacteriaBacteriumRbg134211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RBG_13_42_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRbg134211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801663.protein.info.v11.5.txt",
		        "node_list_path": "1801663.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWesteberhardiaCardiocondylaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Westeberhardia cardiocondylae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWesteberhardiaCardiocondylaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1594731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1594731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1594731.clusters.proteins.v11.5.txt",
		        "sequence_path": "1594731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1594731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1594731.protein.info.v11.5.txt",
		        "node_list_path": "1594731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1594731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpilithonimonasTenax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas tenax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpilithonimonasTenax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121870.protein.info.v11.5.txt",
		        "node_list_path": "1121870.protein.complete.v11.5.txt"
		    }
		]
    )()

def HolosporaElegansE1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Holospora elegans E1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HolosporaElegansE1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1427503.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1427503.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1427503.clusters.proteins.v11.5.txt",
		        "sequence_path": "1427503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1427503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1427503.protein.info.v11.5.txt",
		        "node_list_path": "1427503.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1427503.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FaecalibacteriumSpCag1138(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium sp. CAG:1138 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalibacteriumSpCag1138", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262896.protein.info.v11.5.txt",
		        "node_list_path": "1262896.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyotisDavidii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myotis davidii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyotisDavidii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "225400.protein.sequences.v11.5.fa",
		        "enrichment_path": "225400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225400.protein.info.v11.5.txt",
		        "node_list_path": "225400.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonasSpRcc299(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonas sp. RCC299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonasSpRcc299", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "296587.protein.sequences.v11.5.fa",
		        "enrichment_path": "296587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "296587.protein.info.v11.5.txt",
		        "node_list_path": "296587.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumMedpeSwcel(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium MedPE-SWcel graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumMedpeSwcel", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1860092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860092.protein.info.v11.5.txt",
		        "node_list_path": "1860092.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuricellaOtitidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Turicella otitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuricellaOtitidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883169.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883169.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883169.clusters.proteins.v11.5.txt",
		        "sequence_path": "883169.protein.sequences.v11.5.fa",
		        "enrichment_path": "883169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883169.protein.info.v11.5.txt",
		        "node_list_path": "883169.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883169.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClavibacterMichiganensisSepedonicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis sepedonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavibacterMichiganensisSepedonicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "31964.clusters.info.v11.5.txt",
		        "cluster_tree_path": "31964.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "31964.clusters.proteins.v11.5.txt",
		        "sequence_path": "31964.protein.sequences.v11.5.fa",
		        "enrichment_path": "31964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "31964.protein.info.v11.5.txt",
		        "node_list_path": "31964.cluster.nodes.v11.5.txt",
		        "edge_list_path": "31964.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesSpMarseilleP3160Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides sp. Marseille-P3160 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesSpMarseilleP3160Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1917887.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1917887.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1917887.clusters.proteins.v11.5.txt",
		        "sequence_path": "1917887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917887.protein.info.v11.5.txt",
		        "node_list_path": "1917887.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1917887.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaKururiensisM130Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia kururiensis M130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaKururiensisM130Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1268285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1268285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1268285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1268285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268285.protein.info.v11.5.txt",
		        "node_list_path": "1268285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1268285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidimicrobiaceaeBacteriumRaap2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidimicrobiaceae bacterium RAAP-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidimicrobiaceaeBacteriumRaap2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736654.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736654.protein.info.v11.5.txt",
		        "node_list_path": "1736654.protein.complete.v11.5.txt"
		    }
		]
    )()

def AllomycesMacrogynusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Allomyces macrogynus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllomycesMacrogynusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28583.clusters.proteins.v11.5.txt",
		        "sequence_path": "28583.protein.sequences.v11.5.fa",
		        "enrichment_path": "28583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28583.protein.info.v11.5.txt",
		        "node_list_path": "28583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TardiphagaSpOk245(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tardiphaga sp. OK245 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TardiphagaSpOk245", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855306.protein.info.v11.5.txt",
		        "node_list_path": "1855306.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusPerolensDsm12744(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus perolens DSM 12744 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPerolensDsm12744", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423792.protein.info.v11.5.txt",
		        "node_list_path": "1423792.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumMetalliduransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium metallidurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumMetalliduransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1297569.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1297569.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1297569.clusters.proteins.v11.5.txt",
		        "sequence_path": "1297569.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297569.protein.info.v11.5.txt",
		        "node_list_path": "1297569.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1297569.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfurisporaThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurispora thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurisporaThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121472.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121472.protein.info.v11.5.txt",
		        "node_list_path": "1121472.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaEriocheirisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma eriocheiris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaEriocheirisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "315358.clusters.info.v11.5.txt",
		        "cluster_tree_path": "315358.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "315358.clusters.proteins.v11.5.txt",
		        "sequence_path": "315358.protein.sequences.v11.5.fa",
		        "enrichment_path": "315358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "315358.protein.info.v11.5.txt",
		        "node_list_path": "315358.cluster.nodes.v11.5.txt",
		        "edge_list_path": "315358.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeleribacterHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Celeribacter halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeleribacterHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "576117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "576117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "576117.clusters.proteins.v11.5.txt",
		        "sequence_path": "576117.protein.sequences.v11.5.fa",
		        "enrichment_path": "576117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "576117.protein.info.v11.5.txt",
		        "node_list_path": "576117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "576117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnsiferSpLc11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. LC11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferSpLc11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1873712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1873712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1873712.protein.info.v11.5.txt",
		        "node_list_path": "1873712.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRiflebacteriaBacteriumGwc2508Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riflebacteria bacterium GWC2_50_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRiflebacteriaBacteriumGwc2508Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817874.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817874.protein.info.v11.5.txt",
		        "node_list_path": "1817874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParachlamydiaceaeBacteriumHsT3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parachlamydiaceae bacterium HS-T3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParachlamydiaceaeBacteriumHsT3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314958.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314958.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314958.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314958.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314958.protein.info.v11.5.txt",
		        "node_list_path": "1314958.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314958.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalarchaeumAcidiphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halarchaeum acidiphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalarchaeumAcidiphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1261545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261545.protein.info.v11.5.txt",
		        "node_list_path": "1261545.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRedseaS03B5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium REDSEA-S03_B5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRedseaS03B5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811661.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811661.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811661.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811661.protein.info.v11.5.txt",
		        "node_list_path": "1811661.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811661.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaeniglutamicibacterAntarcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paeniglutamicibacter antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaeniglutamicibacterAntarcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "494023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "494023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "494023.clusters.proteins.v11.5.txt",
		        "sequence_path": "494023.protein.sequences.v11.5.fa",
		        "enrichment_path": "494023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "494023.protein.info.v11.5.txt",
		        "node_list_path": "494023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "494023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpMedpeSwcelCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. MedPE-SWcel Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpMedpeSwcelCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1860086.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1860086.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1860086.clusters.proteins.v11.5.txt",
		        "sequence_path": "1860086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860086.protein.info.v11.5.txt",
		        "node_list_path": "1860086.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1860086.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptosporangiumRoseum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptosporangium roseum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptosporangiumRoseum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "479432.protein.sequences.v11.5.fa",
		        "enrichment_path": "479432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479432.protein.info.v11.5.txt",
		        "node_list_path": "479432.protein.complete.v11.5.txt"
		    }
		]
    )()

def MurdochiellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Murdochiella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MurdochiellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1673723.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673723.protein.info.v11.5.txt",
		        "node_list_path": "1673723.protein.complete.v11.5.txt"
		    }
		]
    )()

def EndosymbiontOfRidgeiaPiscesae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Ridgeia piscesae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndosymbiontOfRidgeiaPiscesae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "54398.protein.sequences.v11.5.fa",
		        "enrichment_path": "54398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54398.protein.info.v11.5.txt",
		        "node_list_path": "54398.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaConsociata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia consociata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaConsociata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "760117.protein.sequences.v11.5.fa",
		        "enrichment_path": "760117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "760117.protein.info.v11.5.txt",
		        "node_list_path": "760117.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumS714(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium S714 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumS714", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1284708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284708.protein.info.v11.5.txt",
		        "node_list_path": "1284708.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelomonasSpRoot1217Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelomonasSpRoot1217Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736430.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736430.protein.info.v11.5.txt",
		        "node_list_path": "1736430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanothermococcusThermolithotrophicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothermococcus thermolithotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermococcusThermolithotrophicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "523845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "523845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "523845.clusters.proteins.v11.5.txt",
		        "sequence_path": "523845.protein.sequences.v11.5.fa",
		        "enrichment_path": "523845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523845.protein.info.v11.5.txt",
		        "node_list_path": "523845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "523845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaCarbonaceaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora carbonacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaCarbonaceaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47853.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47853.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47853.clusters.proteins.v11.5.txt",
		        "sequence_path": "47853.protein.sequences.v11.5.fa",
		        "enrichment_path": "47853.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47853.protein.info.v11.5.txt",
		        "node_list_path": "47853.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47853.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1045854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045854.protein.info.v11.5.txt",
		        "node_list_path": "1045854.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterAscendensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter ascendens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterAscendensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "481146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "481146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "481146.clusters.proteins.v11.5.txt",
		        "sequence_path": "481146.protein.sequences.v11.5.fa",
		        "enrichment_path": "481146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481146.protein.info.v11.5.txt",
		        "node_list_path": "481146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "481146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiothrixCaldifontis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix caldifontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiothrixCaldifontis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525918.protein.sequences.v11.5.fa",
		        "enrichment_path": "525918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525918.protein.info.v11.5.txt",
		        "node_list_path": "525918.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaSpOmz838Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema sp. OMZ838 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSpOmz838Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1539298.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1539298.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1539298.clusters.proteins.v11.5.txt",
		        "sequence_path": "1539298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1539298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1539298.protein.info.v11.5.txt",
		        "node_list_path": "1539298.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1539298.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PromicromonosporaKroppenstedtii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Promicromonospora kroppenstedtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PromicromonosporaKroppenstedtii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926564.protein.sequences.v11.5.fa",
		        "enrichment_path": "926564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926564.protein.info.v11.5.txt",
		        "node_list_path": "926564.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpL1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. L1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpL1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1134413.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1134413.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1134413.clusters.proteins.v11.5.txt",
		        "sequence_path": "1134413.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134413.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134413.protein.info.v11.5.txt",
		        "node_list_path": "1134413.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1134413.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full4213(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_42_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full4213", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798286.protein.info.v11.5.txt",
		        "node_list_path": "1798286.protein.complete.v11.5.txt"
		    }
		]
    )()

def SucciniclasticumRuminisDsm9236(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Succiniclasticum ruminis DSM 9236 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SucciniclasticumRuminisDsm9236", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123323.protein.info.v11.5.txt",
		        "node_list_path": "1123323.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpMarseilleP299(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. Marseille-P299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpMarseilleP299", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805477.protein.info.v11.5.txt",
		        "node_list_path": "1805477.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaPunctataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza punctata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaPunctataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4537.clusters.proteins.v11.5.txt",
		        "sequence_path": "4537.protein.sequences.v11.5.fa",
		        "enrichment_path": "4537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4537.protein.info.v11.5.txt",
		        "node_list_path": "4537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsplowo2025612(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_02_56_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo2025612", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797874.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797874.protein.info.v11.5.txt",
		        "node_list_path": "1797874.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSalarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter salarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSalarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420917.protein.info.v11.5.txt",
		        "node_list_path": "1420917.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseoflavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseoflavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseoflavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "467200.protein.sequences.v11.5.fa",
		        "enrichment_path": "467200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "467200.protein.info.v11.5.txt",
		        "node_list_path": "467200.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBouvetiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter bouvetii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBouvetiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120925.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120925.protein.info.v11.5.txt",
		        "node_list_path": "1120925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusSenegalensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusSenegalensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033733.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033733.protein.info.v11.5.txt",
		        "node_list_path": "1033733.protein.complete.v11.5.txt"
		    }
		]
    )()

def KosmotogaArenicorallinaS304(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kosmotoga arenicorallina S304 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KosmotogaArenicorallinaS304", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1453497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453497.protein.info.v11.5.txt",
		        "node_list_path": "1453497.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCellulovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cellulovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCellulovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573061.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573061.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573061.clusters.proteins.v11.5.txt",
		        "sequence_path": "573061.protein.sequences.v11.5.fa",
		        "enrichment_path": "573061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573061.protein.info.v11.5.txt",
		        "node_list_path": "573061.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573061.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrospiraPlatensisC1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrospira platensis C1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrospiraPlatensisC1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "459495.protein.sequences.v11.5.fa",
		        "enrichment_path": "459495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "459495.protein.info.v11.5.txt",
		        "node_list_path": "459495.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptobacillusMoniliformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptobacillus moniliformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptobacillusMoniliformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "519441.protein.sequences.v11.5.fa",
		        "enrichment_path": "519441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "519441.protein.info.v11.5.txt",
		        "node_list_path": "519441.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpPamc22219(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. PAMC22219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpPamc22219", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1569209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1569209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1569209.protein.info.v11.5.txt",
		        "node_list_path": "1569209.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioflavicoccusMobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioflavicoccus mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioflavicoccusMobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765912.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765912.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765912.clusters.proteins.v11.5.txt",
		        "sequence_path": "765912.protein.sequences.v11.5.fa",
		        "enrichment_path": "765912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765912.protein.info.v11.5.txt",
		        "node_list_path": "765912.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765912.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumGloeosporioides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum gloeosporioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumGloeosporioides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "474922.protein.sequences.v11.5.fa",
		        "enrichment_path": "474922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "474922.protein.info.v11.5.txt",
		        "node_list_path": "474922.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeferribacterDesulfuricansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deferribacter desulfuricans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeferribacterDesulfuricansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "639282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "639282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "639282.clusters.proteins.v11.5.txt",
		        "sequence_path": "639282.protein.sequences.v11.5.fa",
		        "enrichment_path": "639282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "639282.protein.info.v11.5.txt",
		        "node_list_path": "639282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "639282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaPeanutWitchesbroom(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma peanut witchesbroom graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaPeanutWitchesbroom", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163385.protein.sequences.v11.0.fa",
		        "enrichment_path": "1163385.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1163385.protein.info.v11.0.txt",
		        "node_list_path": "1163385.protein.complete.v11.0.txt"
		    }
		]
    )()

def ThalassospiraSpTsl51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira sp. TSL5-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraSpTsl51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1544451.protein.sequences.v11.5.fa",
		        "enrichment_path": "1544451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1544451.protein.info.v11.5.txt",
		        "node_list_path": "1544451.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiothrixDisciformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix disciformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiothrixDisciformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123399.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123399.protein.info.v11.5.txt",
		        "node_list_path": "1123399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterEuropaeus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter europaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterEuropaeus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33995.protein.sequences.v11.5.fa",
		        "enrichment_path": "33995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33995.protein.info.v11.5.txt",
		        "node_list_path": "33995.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaSpOralTaxon847(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. oral taxon 847 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaSpOralTaxon847", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1785996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1785996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1785996.protein.info.v11.5.txt",
		        "node_list_path": "1785996.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosopelagicusSpRedseaS31B2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopelagicus sp. REDSEA-S31_B2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopelagicusSpRedseaS31B2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811586.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811586.protein.info.v11.5.txt",
		        "node_list_path": "1811586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumCg104632(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium CG10_46_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumCg104632", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1911907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1911907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1911907.protein.info.v11.5.txt",
		        "node_list_path": "1911907.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumRifcsphigho201Full5728(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPHIGHO2_01_FULL_57_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsphigho201Full5728", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798647.protein.info.v11.5.txt",
		        "node_list_path": "1798647.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoculleusSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1550566.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1550566.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1550566.clusters.proteins.v11.5.txt",
		        "sequence_path": "1550566.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550566.protein.info.v11.5.txt",
		        "node_list_path": "1550566.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1550566.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb241529c4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241_529C4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb241529c4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1471463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1471463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1471463.clusters.proteins.v11.5.txt",
		        "sequence_path": "1471463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471463.protein.info.v11.5.txt",
		        "node_list_path": "1471463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1471463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FurculomycesBoomerangusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Furculomyces boomerangus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FurculomycesBoomerangusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61424.clusters.proteins.v11.5.txt",
		        "sequence_path": "61424.protein.sequences.v11.5.fa",
		        "enrichment_path": "61424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61424.protein.info.v11.5.txt",
		        "node_list_path": "61424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSp6829(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. 68-29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSp6829", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895823.protein.info.v11.5.txt",
		        "node_list_path": "1895823.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlloiococcusOtitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alloiococcus otitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloiococcusOtitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883081.protein.sequences.v11.5.fa",
		        "enrichment_path": "883081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883081.protein.info.v11.5.txt",
		        "node_list_path": "883081.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaAgglomerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea agglomerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaAgglomerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "549.protein.sequences.v11.5.fa",
		        "enrichment_path": "549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "549.protein.info.v11.5.txt",
		        "node_list_path": "549.protein.complete.v11.5.txt"
		    }
		]
    )()

def JannaschiaPohangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia pohangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaPohangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "390807.clusters.info.v11.5.txt",
		        "cluster_tree_path": "390807.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "390807.clusters.proteins.v11.5.txt",
		        "sequence_path": "390807.protein.sequences.v11.5.fa",
		        "enrichment_path": "390807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390807.protein.info.v11.5.txt",
		        "node_list_path": "390807.cluster.nodes.v11.5.txt",
		        "edge_list_path": "390807.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKisonensisF0435(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kisonensis F0435 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKisonensisF0435", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "797516.protein.sequences.v11.5.fa",
		        "enrichment_path": "797516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797516.protein.info.v11.5.txt",
		        "node_list_path": "797516.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesHalstediiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces halstedii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesHalstediiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1944.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1944.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1944.clusters.proteins.v11.5.txt",
		        "sequence_path": "1944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1944.protein.info.v11.5.txt",
		        "node_list_path": "1944.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1944.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicoccusLuteusDsm17002(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus luteus DSM 17002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusLuteusDsm17002", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123233.protein.info.v11.5.txt",
		        "node_list_path": "1123233.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimnothrixSpCaciam69dCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnothrix sp. CACIAM 69d Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnothrixSpCaciam69dCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1890733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1890733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1890733.clusters.proteins.v11.5.txt",
		        "sequence_path": "1890733.protein.sequences.v11.5.fa",
		        "enrichment_path": "1890733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1890733.protein.info.v11.5.txt",
		        "node_list_path": "1890733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1890733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DehalogenimonasAlkenigignens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dehalogenimonas alkenigignens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalogenimonasAlkenigignens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217799.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217799.protein.info.v11.5.txt",
		        "node_list_path": "1217799.protein.complete.v11.5.txt"
		    }
		]
    )()

def DiplodiaSeriata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Diplodia seriata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiplodiaSeriata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "420778.protein.sequences.v11.5.fa",
		        "enrichment_path": "420778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420778.protein.info.v11.5.txt",
		        "node_list_path": "420778.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpPamc21119Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. PAMC21119 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpPamc21119Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1112209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1112209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1112209.clusters.proteins.v11.5.txt",
		        "sequence_path": "1112209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1112209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1112209.protein.info.v11.5.txt",
		        "node_list_path": "1112209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1112209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioBreoganiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio breoganii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioBreoganiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1205908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1205908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1205908.clusters.proteins.v11.5.txt",
		        "sequence_path": "1205908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1205908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1205908.protein.info.v11.5.txt",
		        "node_list_path": "1205908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1205908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBifidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBifidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1681.protein.info.v11.5.txt",
		        "node_list_path": "1681.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoculleusBourgensisMs2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus bourgensis MS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusBourgensisMs2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1201294.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1201294.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1201294.clusters.proteins.v11.5.txt",
		        "sequence_path": "1201294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1201294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1201294.protein.info.v11.5.txt",
		        "node_list_path": "1201294.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1201294.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacillusSalinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus salinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusSalinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "192814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "192814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "192814.clusters.proteins.v11.5.txt",
		        "sequence_path": "192814.protein.sequences.v11.5.fa",
		        "enrichment_path": "192814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192814.protein.info.v11.5.txt",
		        "node_list_path": "192814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "192814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFermentumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fermentum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFermentumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1613.clusters.proteins.v11.5.txt",
		        "sequence_path": "1613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1613.protein.info.v11.5.txt",
		        "node_list_path": "1613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumGwa24115(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium GWA2_41_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumGwa24115", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801814.protein.info.v11.5.txt",
		        "node_list_path": "1801814.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasInfelix(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas infelix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasInfelix", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679201.protein.sequences.v11.5.fa",
		        "enrichment_path": "679201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679201.protein.info.v11.5.txt",
		        "node_list_path": "679201.protein.complete.v11.5.txt"
		    }
		]
    )()

def PilibacterTermitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pilibacter termitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PilibacterTermitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "263852.protein.sequences.v11.5.fa",
		        "enrichment_path": "263852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263852.protein.info.v11.5.txt",
		        "node_list_path": "263852.protein.complete.v11.5.txt"
		    }
		]
    )()

def NonomuraeaSpAtcc55076Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea sp. ATCC 55076 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaSpAtcc55076Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1909395.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1909395.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1909395.clusters.proteins.v11.5.txt",
		        "sequence_path": "1909395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1909395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1909395.protein.info.v11.5.txt",
		        "node_list_path": "1909395.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1909395.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaGingivalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga gingivalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaGingivalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553178.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553178.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553178.clusters.proteins.v11.5.txt",
		        "sequence_path": "553178.protein.sequences.v11.5.fa",
		        "enrichment_path": "553178.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553178.protein.info.v11.5.txt",
		        "node_list_path": "553178.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553178.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpGhviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ghvi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpGhviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855319.protein.info.v11.5.txt",
		        "node_list_path": "1855319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasViridiflavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas viridiflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasViridiflavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33069.clusters.proteins.v11.5.txt",
		        "sequence_path": "33069.protein.sequences.v11.5.fa",
		        "enrichment_path": "33069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33069.protein.info.v11.5.txt",
		        "node_list_path": "33069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasElodeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas elodea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasElodeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1081640.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1081640.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1081640.clusters.proteins.v11.5.txt",
		        "sequence_path": "1081640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1081640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1081640.protein.info.v11.5.txt",
		        "node_list_path": "1081640.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1081640.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSpChkci003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. CHKCI003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpChkci003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1780376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780376.protein.info.v11.5.txt",
		        "node_list_path": "1780376.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_40_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618814.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618814.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618814.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618814.protein.info.v11.5.txt",
		        "node_list_path": "1618814.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618814.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosotenuisCloacae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis cloacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosotenuisCloacae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1603555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603555.protein.info.v11.5.txt",
		        "node_list_path": "1603555.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaColumbinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma columbinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaColumbinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1037410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1037410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1037410.clusters.proteins.v11.5.txt",
		        "sequence_path": "1037410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1037410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1037410.protein.info.v11.5.txt",
		        "node_list_path": "1037410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1037410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaludibacterPropionicigenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paludibacter propionicigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaludibacterPropionicigenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "694427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "694427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "694427.clusters.proteins.v11.5.txt",
		        "sequence_path": "694427.protein.sequences.v11.5.fa",
		        "enrichment_path": "694427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694427.protein.info.v11.5.txt",
		        "node_list_path": "694427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "694427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptococcusGattii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus gattii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptococcusGattii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "552467.protein.sequences.v11.5.fa",
		        "enrichment_path": "552467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "552467.protein.info.v11.5.txt",
		        "node_list_path": "552467.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobacteralesBacteriumS7086c20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium S7086C20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteralesBacteriumS7086c20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1869302.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1869302.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1869302.clusters.proteins.v11.5.txt",
		        "sequence_path": "1869302.protein.sequences.v11.5.fa",
		        "enrichment_path": "1869302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1869302.protein.info.v11.5.txt",
		        "node_list_path": "1869302.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1869302.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpNkbg15041c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. NKBG15041c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpNkbg15041c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1407650.protein.sequences.v11.5.fa",
		        "enrichment_path": "1407650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1407650.protein.info.v11.5.txt",
		        "node_list_path": "1407650.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerrithrixThermotoleransDsm19514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferrithrix thermotolerans DSM 19514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrithrixThermotoleransDsm19514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121881.protein.info.v11.5.txt",
		        "node_list_path": "1121881.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpEhc04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. EhC04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpEhc04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849168.protein.info.v11.5.txt",
		        "node_list_path": "1849168.protein.complete.v11.5.txt"
		    }
		]
    )()

def TalaromycesMarneffeiAtcc18224(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces marneffei ATCC 18224 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesMarneffeiAtcc18224", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "441960.protein.sequences.v11.5.fa",
		        "enrichment_path": "441960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441960.protein.info.v11.5.txt",
		        "node_list_path": "441960.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwe14915Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_49_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe14915Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618710.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618710.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618710.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618710.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618710.protein.info.v11.5.txt",
		        "node_list_path": "1618710.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618710.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaMarthiiFslS4120Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria marthii FSL S4-120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaMarthiiFslS4120Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "702457.clusters.info.v11.5.txt",
		        "cluster_tree_path": "702457.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "702457.clusters.proteins.v11.5.txt",
		        "sequence_path": "702457.protein.sequences.v11.5.fa",
		        "enrichment_path": "702457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702457.protein.info.v11.5.txt",
		        "node_list_path": "702457.cluster.nodes.v11.5.txt",
		        "edge_list_path": "702457.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenimonasDonghaensisDsm18148Ho3R19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas donghaensis DSM 18148 HO3-R19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenimonasDonghaensisDsm18148Ho3R19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121014.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121014.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121014.protein.info.v11.5.txt",
		        "node_list_path": "1121014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSiraeum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Eubacterium] siraeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSiraeum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39492.protein.sequences.v11.5.fa",
		        "enrichment_path": "39492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39492.protein.info.v11.5.txt",
		        "node_list_path": "39492.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScophthalmusMaximus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scophthalmus maximus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScophthalmusMaximus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52904.protein.sequences.v11.5.fa",
		        "enrichment_path": "52904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52904.protein.info.v11.5.txt",
		        "node_list_path": "52904.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaProteobacteriumScgcAaa027K21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return beta proteobacterium SCGC AAA027-K21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaProteobacteriumScgcAaa027K21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "938785.clusters.info.v11.5.txt",
		        "cluster_tree_path": "938785.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "938785.clusters.proteins.v11.5.txt",
		        "sequence_path": "938785.protein.sequences.v11.5.fa",
		        "enrichment_path": "938785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938785.protein.info.v11.5.txt",
		        "node_list_path": "938785.cluster.nodes.v11.5.txt",
		        "edge_list_path": "938785.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FungalSpNo11243(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return fungal sp. No.11243 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FungalSpNo11243", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1603295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603295.protein.info.v11.5.txt",
		        "node_list_path": "1603295.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrigoribacteriumSpLeaf172(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf172 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrigoribacteriumSpLeaf172", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736285.protein.info.v11.5.txt",
		        "node_list_path": "1736285.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaedibacterSp38128(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caedibacter sp. 38-128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaedibacterSp38128", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895736.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895736.protein.info.v11.5.txt",
		        "node_list_path": "1895736.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfipiaSpGas231Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. GAS231 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaSpGas231Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882747.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882747.protein.info.v11.5.txt",
		        "node_list_path": "1882747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasSpC04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas sp. C04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasSpC04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945857.protein.info.v11.5.txt",
		        "node_list_path": "1945857.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumAntarcticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumAntarcticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111730.protein.info.v11.5.txt",
		        "node_list_path": "1111730.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterExcellensHl55Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter excellens HL-55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterExcellensHl55Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1305731.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1305731.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1305731.clusters.proteins.v11.5.txt",
		        "sequence_path": "1305731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305731.protein.info.v11.5.txt",
		        "node_list_path": "1305731.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1305731.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumTimonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium timonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumTimonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203190.protein.info.v11.5.txt",
		        "node_list_path": "1203190.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalosarcinaPallidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halosarcina pallida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalosarcinaPallidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227487.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227487.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227487.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227487.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227487.protein.info.v11.5.txt",
		        "node_list_path": "1227487.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227487.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterPedocolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter pedocola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterPedocolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1792845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1792845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1792845.clusters.proteins.v11.5.txt",
		        "sequence_path": "1792845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1792845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1792845.protein.info.v11.5.txt",
		        "node_list_path": "1792845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1792845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpAnt17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. Ant17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpAnt17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461752.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461752.protein.info.v11.5.txt",
		        "node_list_path": "1461752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentibacterAlgarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentibacter algarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentibacterAlgarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "576131.protein.sequences.v11.5.fa",
		        "enrichment_path": "576131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "576131.protein.info.v11.5.txt",
		        "node_list_path": "576131.protein.complete.v11.5.txt"
		    }
		]
    )()

def OpitutaceaeBacteriumTav5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TAV5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpitutaceaeBacteriumTav5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "794903.protein.sequences.v11.5.fa",
		        "enrichment_path": "794903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "794903.protein.info.v11.5.txt",
		        "node_list_path": "794903.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiK12W3110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 W3110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiK12W3110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "316407.protein.sequences.v11.0.fa",
		        "enrichment_path": "316407.protein.enrichment.terms.v11.0.txt",
		        "info_path": "316407.protein.info.v11.0.txt",
		        "node_list_path": "316407.protein.complete.v11.0.txt"
		    }
		]
    )()

def MycobacteriumParascrofulaceum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium parascrofulaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumParascrofulaceum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525368.protein.sequences.v11.5.fa",
		        "enrichment_path": "525368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525368.protein.info.v11.5.txt",
		        "node_list_path": "525368.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseburiaSp831bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. 831b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSp831bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1261635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1261635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1261635.clusters.proteins.v11.5.txt",
		        "sequence_path": "1261635.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261635.protein.info.v11.5.txt",
		        "node_list_path": "1261635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1261635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusHoagiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus hoagii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusHoagiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43767.clusters.proteins.v11.5.txt",
		        "sequence_path": "43767.protein.sequences.v11.5.fa",
		        "enrichment_path": "43767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43767.protein.info.v11.5.txt",
		        "node_list_path": "43767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichosporonAsahiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichosporon asahii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichosporonAsahiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "82508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "82508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "82508.clusters.proteins.v11.5.txt",
		        "sequence_path": "82508.protein.sequences.v11.5.fa",
		        "enrichment_path": "82508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82508.protein.info.v11.5.txt",
		        "node_list_path": "82508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "82508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MangrovibacterPhragmitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mangrovibacter phragmitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MangrovibacterPhragmitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1691903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1691903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1691903.clusters.proteins.v11.5.txt",
		        "sequence_path": "1691903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1691903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1691903.protein.info.v11.5.txt",
		        "node_list_path": "1691903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1691903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobiusGelatinovorus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassobius gelatinovorus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobiusGelatinovorus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "53501.protein.sequences.v11.5.fa",
		        "enrichment_path": "53501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53501.protein.info.v11.5.txt",
		        "node_list_path": "53501.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrobacterIntestinalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterIntestinalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28122.protein.sequences.v11.5.fa",
		        "enrichment_path": "28122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28122.protein.info.v11.5.txt",
		        "node_list_path": "28122.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaeBacteriumSm2339(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium SM23_39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaeBacteriumSm2339", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1704235.protein.sequences.v11.5.fa",
		        "enrichment_path": "1704235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1704235.protein.info.v11.5.txt",
		        "node_list_path": "1704235.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasViscosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas viscosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasViscosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "871741.protein.sequences.v11.5.fa",
		        "enrichment_path": "871741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871741.protein.info.v11.5.txt",
		        "node_list_path": "871741.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermovenabulumGondwanenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermovenabulum gondwanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermovenabulumGondwanenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "520767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "520767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "520767.clusters.proteins.v11.5.txt",
		        "sequence_path": "520767.protein.sequences.v11.5.fa",
		        "enrichment_path": "520767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "520767.protein.info.v11.5.txt",
		        "node_list_path": "520767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "520767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TemnothoraxLongispinosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Temnothorax longispinosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TemnothoraxLongispinosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "300112.clusters.info.v11.5.txt",
		        "cluster_tree_path": "300112.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "300112.clusters.proteins.v11.5.txt",
		        "sequence_path": "300112.protein.sequences.v11.5.fa",
		        "enrichment_path": "300112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "300112.protein.info.v11.5.txt",
		        "node_list_path": "300112.cluster.nodes.v11.5.txt",
		        "edge_list_path": "300112.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_51_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798508.protein.info.v11.5.txt",
		        "node_list_path": "1798508.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_45_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802706.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802706.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802706.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802706.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802706.protein.info.v11.5.txt",
		        "node_list_path": "1802706.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802706.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacterium1147Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 1147 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacterium1147Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469610.clusters.proteins.v11.5.txt",
		        "sequence_path": "469610.protein.sequences.v11.5.fa",
		        "enrichment_path": "469610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469610.protein.info.v11.5.txt",
		        "node_list_path": "469610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WheatBlueCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wheat blue Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WheatBlueCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "321961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "321961.clusters.proteins.v11.5.txt",
		        "sequence_path": "321961.protein.sequences.v11.5.fa",
		        "enrichment_path": "321961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321961.protein.info.v11.5.txt",
		        "node_list_path": "321961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "321961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerticilliumDahliaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verticillium dahliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerticilliumDahliaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "27337.clusters.info.v11.5.txt",
		        "cluster_tree_path": "27337.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "27337.clusters.proteins.v11.5.txt",
		        "sequence_path": "27337.protein.sequences.v11.5.fa",
		        "enrichment_path": "27337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27337.protein.info.v11.5.txt",
		        "node_list_path": "27337.cluster.nodes.v11.5.txt",
		        "edge_list_path": "27337.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasSpLeaf148(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Leaf148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasSpLeaf148", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736275.protein.info.v11.5.txt",
		        "node_list_path": "1736275.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHimb30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HIMB30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHimb30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "751994.clusters.info.v11.0.txt",
		        "cluster_tree_path": "751994.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "751994.clusters.proteins.v11.0.txt",
		        "sequence_path": "751994.protein.sequences.v11.0.fa",
		        "enrichment_path": "751994.protein.enrichment.terms.v11.0.txt",
		        "info_path": "751994.protein.info.v11.0.txt",
		        "node_list_path": "751994.cluster.nodes.v11.0.txt",
		        "edge_list_path": "751994.protein.cluster.v11.0.txt"
		    }
		]
    )()

def SphingopyxisSpMc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. MC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpMc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1174684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1174684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1174684.clusters.proteins.v11.5.txt",
		        "sequence_path": "1174684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1174684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1174684.protein.info.v11.5.txt",
		        "node_list_path": "1174684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1174684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaRhamnosiphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia rhamnosiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaRhamnosiphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426716.protein.sequences.v11.5.fa",
		        "enrichment_path": "426716.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426716.protein.info.v11.5.txt",
		        "node_list_path": "426716.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiohalomonasDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiohalomonas denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiohalomonasDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "415747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "415747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "415747.clusters.proteins.v11.5.txt",
		        "sequence_path": "415747.protein.sequences.v11.5.fa",
		        "enrichment_path": "415747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "415747.protein.info.v11.5.txt",
		        "node_list_path": "415747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "415747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPseudoalcaligenesCect5344(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes CECT5344 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPseudoalcaligenesCect5344", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1182590.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182590.protein.info.v11.5.txt",
		        "node_list_path": "1182590.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumFimetariumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] fimetarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumFimetariumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "99656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "99656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "99656.clusters.proteins.v11.5.txt",
		        "sequence_path": "99656.protein.sequences.v11.5.fa",
		        "enrichment_path": "99656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "99656.protein.info.v11.5.txt",
		        "node_list_path": "99656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "99656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NakamurellaPanacisegetisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nakamurella panacisegetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NakamurellaPanacisegetisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1090615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1090615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1090615.clusters.proteins.v11.5.txt",
		        "sequence_path": "1090615.protein.sequences.v11.5.fa",
		        "enrichment_path": "1090615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1090615.protein.info.v11.5.txt",
		        "node_list_path": "1090615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1090615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerolineaceaeBacteriumOralTaxon439Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium oral taxon 439 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaceaeBacteriumOralTaxon439Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1889813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1889813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1889813.clusters.proteins.v11.5.txt",
		        "sequence_path": "1889813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889813.protein.info.v11.5.txt",
		        "node_list_path": "1889813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1889813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomicrobiumSpCs1gbmeth3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. CS1GBMeth3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomicrobiumSpCs1gbmeth3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1892845.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1892845.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1892845.clusters.proteins.v11.5.txt",
		        "sequence_path": "1892845.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892845.protein.info.v11.5.txt",
		        "node_list_path": "1892845.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1892845.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasAgarivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasAgarivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1307437.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307437.protein.info.v11.5.txt",
		        "node_list_path": "1307437.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasEntomophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas entomophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasEntomophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "384676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "384676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "384676.clusters.proteins.v11.5.txt",
		        "sequence_path": "384676.protein.sequences.v11.5.fa",
		        "enrichment_path": "384676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "384676.protein.info.v11.5.txt",
		        "node_list_path": "384676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "384676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MusCaroliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mus caroli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusCaroliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10089.clusters.proteins.v11.5.txt",
		        "sequence_path": "10089.protein.sequences.v11.5.fa",
		        "enrichment_path": "10089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10089.protein.info.v11.5.txt",
		        "node_list_path": "10089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMycoplasmaHaemobos(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemobos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMycoplasmaHaemobos", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "432608.protein.sequences.v11.5.fa",
		        "enrichment_path": "432608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "432608.protein.info.v11.5.txt",
		        "node_list_path": "432608.protein.complete.v11.5.txt"
		    }
		]
    )()

def MorusNotabilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Morus notabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MorusNotabilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "981085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "981085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "981085.clusters.proteins.v11.5.txt",
		        "sequence_path": "981085.protein.sequences.v11.5.fa",
		        "enrichment_path": "981085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981085.protein.info.v11.5.txt",
		        "node_list_path": "981085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "981085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivivaxSp22iis10sCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax sp. 22IIs10s Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxSp22iis10sCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1317118.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1317118.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1317118.clusters.proteins.v11.5.txt",
		        "sequence_path": "1317118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317118.protein.info.v11.5.txt",
		        "node_list_path": "1317118.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1317118.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanospirillumMarisDsm6286(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum maris DSM 6286 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanospirillumMarisDsm6286", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122617.protein.info.v11.5.txt",
		        "node_list_path": "1122617.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpLeaf234Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpLeaf234Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736303.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736303.protein.info.v11.5.txt",
		        "node_list_path": "1736303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErysipelotrichaceaeBacteriumNyuBlE8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium NYU-BL-E8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelotrichaceaeBacteriumNyuBlE8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1917463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1917463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1917463.clusters.proteins.v11.5.txt",
		        "sequence_path": "1917463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917463.protein.info.v11.5.txt",
		        "node_list_path": "1917463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1917463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BulleidiaExtructaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bulleidia extructa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BulleidiaExtructaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679192.clusters.proteins.v11.5.txt",
		        "sequence_path": "679192.protein.sequences.v11.5.fa",
		        "enrichment_path": "679192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679192.protein.info.v11.5.txt",
		        "node_list_path": "679192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesThetaiotaomicron(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides thetaiotaomicron graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesThetaiotaomicron", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "226186.protein.sequences.v11.5.fa",
		        "enrichment_path": "226186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226186.protein.info.v11.5.txt",
		        "node_list_path": "226186.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterCanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterCanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1357399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357399.protein.info.v11.5.txt",
		        "node_list_path": "1357399.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraRifamyciniDsm43936(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura rifamycini DSM 43936 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraRifamyciniDsm43936", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120937.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120937.protein.info.v11.5.txt",
		        "node_list_path": "1120937.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaPallida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora pallida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaPallida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "145854.protein.sequences.v11.5.fa",
		        "enrichment_path": "145854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "145854.protein.info.v11.5.txt",
		        "node_list_path": "145854.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSp1513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. 1513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSp1513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1883416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1883416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1883416.protein.info.v11.5.txt",
		        "node_list_path": "1883416.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalogranumSalarium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halogranum salarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalogranumSalarium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210908.protein.info.v11.5.txt",
		        "node_list_path": "1210908.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassobacillusCyriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacillus cyri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobacillusCyriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "571932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "571932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "571932.clusters.proteins.v11.5.txt",
		        "sequence_path": "571932.protein.sequences.v11.5.fa",
		        "enrichment_path": "571932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571932.protein.info.v11.5.txt",
		        "node_list_path": "571932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "571932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquamicrobiumDefluviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquamicrobium defluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquamicrobiumDefluviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69279.clusters.proteins.v11.5.txt",
		        "sequence_path": "69279.protein.sequences.v11.5.fa",
		        "enrichment_path": "69279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69279.protein.info.v11.5.txt",
		        "node_list_path": "69279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioVulnificusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio vulnificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioVulnificusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "672.clusters.proteins.v11.5.txt",
		        "sequence_path": "672.protein.sequences.v11.5.fa",
		        "enrichment_path": "672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "672.protein.info.v11.5.txt",
		        "node_list_path": "672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaloramatorQuimbayensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caloramator quimbayensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloramatorQuimbayensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1147123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1147123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1147123.protein.info.v11.5.txt",
		        "node_list_path": "1147123.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumScgcAaa300D14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA300-D14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumScgcAaa300D14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "939696.protein.sequences.v11.5.fa",
		        "enrichment_path": "939696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939696.protein.info.v11.5.txt",
		        "node_list_path": "939696.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalophilicArchaeonJ07hx64Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return halophilic archaeon J07HX64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalophilicArchaeonJ07hx64Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1085028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1085028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1085028.clusters.proteins.v11.5.txt",
		        "sequence_path": "1085028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1085028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1085028.protein.info.v11.5.txt",
		        "node_list_path": "1085028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1085028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1024025(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_40_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024025", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805305.protein.info.v11.5.txt",
		        "node_list_path": "1805305.protein.complete.v11.5.txt"
		    }
		]
    )()

def TessaracoccusSpT2530(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus sp. T2.5-30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusSpT2530", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1909732.protein.sequences.v11.5.fa",
		        "enrichment_path": "1909732.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1909732.protein.info.v11.5.txt",
		        "node_list_path": "1909732.protein.complete.v11.5.txt"
		    }
		]
    )()

def MerdibacterMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Merdibacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MerdibacterMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871030.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871030.protein.info.v11.5.txt",
		        "node_list_path": "1871030.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusNiaciniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus niacini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusNiaciniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86668.clusters.proteins.v11.5.txt",
		        "sequence_path": "86668.protein.sequences.v11.5.fa",
		        "enrichment_path": "86668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86668.protein.info.v11.5.txt",
		        "node_list_path": "86668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronorubrumTibetenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronorubrum tibetense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronorubrumTibetenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1114856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1114856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1114856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1114856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114856.protein.info.v11.5.txt",
		        "node_list_path": "1114856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1114856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpOrs3359Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3359 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpOrs3359Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "408184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "408184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "408184.clusters.proteins.v11.5.txt",
		        "sequence_path": "408184.protein.sequences.v11.5.fa",
		        "enrichment_path": "408184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408184.protein.info.v11.5.txt",
		        "node_list_path": "408184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "408184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioSpYe44Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. YE44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioSpYe44Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520802.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520802.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520802.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520802.protein.info.v11.5.txt",
		        "node_list_path": "1520802.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520802.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4035Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_40_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4035Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797534.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797534.protein.info.v11.5.txt",
		        "node_list_path": "1797534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylocapsaPalsarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylocapsa palsarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocapsaPalsarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1612308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1612308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1612308.clusters.proteins.v11.5.txt",
		        "sequence_path": "1612308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1612308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1612308.protein.info.v11.5.txt",
		        "node_list_path": "1612308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1612308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusScotoductus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus scotoductus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusScotoductus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743525.protein.sequences.v11.5.fa",
		        "enrichment_path": "743525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743525.protein.info.v11.5.txt",
		        "node_list_path": "743525.protein.complete.v11.5.txt"
		    }
		]
    )()

def EntomoplasmaLucivoraxAtcc49196Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Entomoplasma lucivorax ATCC 49196 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EntomoplasmaLucivoraxAtcc49196Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1399797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1399797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1399797.clusters.proteins.v11.5.txt",
		        "sequence_path": "1399797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399797.protein.info.v11.5.txt",
		        "node_list_path": "1399797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1399797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusOligofermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oligofermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOligofermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1302863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302863.protein.info.v11.5.txt",
		        "node_list_path": "1302863.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinisphaeraShabanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinisphaera shabanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisphaeraShabanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033802.protein.info.v11.5.txt",
		        "node_list_path": "1033802.protein.complete.v11.5.txt"
		    }
		]
    )()

def AureimonasFrigidaquaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas frigidaquae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasFrigidaquaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "424757.clusters.info.v11.5.txt",
		        "cluster_tree_path": "424757.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "424757.clusters.proteins.v11.5.txt",
		        "sequence_path": "424757.protein.sequences.v11.5.fa",
		        "enrichment_path": "424757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "424757.protein.info.v11.5.txt",
		        "node_list_path": "424757.cluster.nodes.v11.5.txt",
		        "edge_list_path": "424757.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XiphophorusCouchianusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xiphophorus couchianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XiphophorusCouchianusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "32473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "32473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "32473.clusters.proteins.v11.5.txt",
		        "sequence_path": "32473.protein.sequences.v11.5.fa",
		        "enrichment_path": "32473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32473.protein.info.v11.5.txt",
		        "node_list_path": "32473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "32473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseburiaSpCag471(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:471 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSpCag471", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262948.protein.info.v11.5.txt",
		        "node_list_path": "1262948.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0384(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0384 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0384", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "944560.protein.sequences.v11.5.fa",
		        "enrichment_path": "944560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944560.protein.info.v11.5.txt",
		        "node_list_path": "944560.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1025844Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_58_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1025844Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805313.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805313.protein.info.v11.5.txt",
		        "node_list_path": "1805313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaDispar(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella dispar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaDispar", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546273.protein.sequences.v11.5.fa",
		        "enrichment_path": "546273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546273.protein.info.v11.5.txt",
		        "node_list_path": "546273.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaPneumophilaPhiladelphiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila Philadelphia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaPneumophilaPhiladelphiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272624.clusters.proteins.v11.5.txt",
		        "sequence_path": "272624.protein.sequences.v11.5.fa",
		        "enrichment_path": "272624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272624.protein.info.v11.5.txt",
		        "node_list_path": "272624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccidioidesBrasiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccidioidesBrasiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "121759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "121759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "121759.clusters.proteins.v11.5.txt",
		        "sequence_path": "121759.protein.sequences.v11.5.fa",
		        "enrichment_path": "121759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121759.protein.info.v11.5.txt",
		        "node_list_path": "121759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "121759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacteriumSaccharolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium saccharolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacteriumSaccharolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094508.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094508.protein.info.v11.5.txt",
		        "node_list_path": "1094508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumChauvoeiJf4335Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium chauvoei JF4335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumChauvoeiJf4335Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1351755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1351755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1351755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1351755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1351755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1351755.protein.info.v11.5.txt",
		        "node_list_path": "1351755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1351755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSacchari(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSacchari", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "159450.protein.sequences.v11.5.fa",
		        "enrichment_path": "159450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "159450.protein.info.v11.5.txt",
		        "node_list_path": "159450.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonasKerstersii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas kerstersii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasKerstersii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "225992.protein.sequences.v11.5.fa",
		        "enrichment_path": "225992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225992.protein.info.v11.5.txt",
		        "node_list_path": "225992.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxSp43bgom46m(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. 43BGOM46m graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxSp43bgom46m", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380387.protein.info.v11.5.txt",
		        "node_list_path": "1380387.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag791(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:791 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag791", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262993.protein.info.v11.5.txt",
		        "node_list_path": "1262993.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpRoot1310Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root1310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpRoot1310Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736452.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736452.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736452.protein.info.v11.5.txt",
		        "node_list_path": "1736452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDadabacteriaBacteriumRifcsphigho212Full5321Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dadabacteria bacterium RIFCSPHIGHO2_12_FULL_53_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDadabacteriaBacteriumRifcsphigho212Full5321Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797756.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797756.protein.info.v11.5.txt",
		        "node_list_path": "1797756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusVaginalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusVaginalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655811.clusters.proteins.v11.5.txt",
		        "sequence_path": "655811.protein.sequences.v11.5.fa",
		        "enrichment_path": "655811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655811.protein.info.v11.5.txt",
		        "node_list_path": "655811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumScgcAaa027J17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA027-J17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumScgcAaa027J17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "932040.protein.sequences.v11.5.fa",
		        "enrichment_path": "932040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932040.protein.info.v11.5.txt",
		        "node_list_path": "932040.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumRbg166719Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_16_67_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumRbg166719Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802196.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802196.protein.info.v11.5.txt",
		        "node_list_path": "1802196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GranulicellaPectinivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Granulicella pectinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicellaPectinivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "474950.protein.sequences.v11.5.fa",
		        "enrichment_path": "474950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "474950.protein.info.v11.5.txt",
		        "node_list_path": "474950.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc055a01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC055A01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc055a01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1715083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715083.protein.info.v11.5.txt",
		        "node_list_path": "1715083.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpRoot608Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Root608 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpRoot608Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736569.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736569.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736569.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736569.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736569.protein.info.v11.5.txt",
		        "node_list_path": "1736569.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736569.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylorubrumSalsuginisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylorubrum salsuginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylorubrumSalsuginisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "414703.clusters.info.v11.5.txt",
		        "cluster_tree_path": "414703.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "414703.clusters.proteins.v11.5.txt",
		        "sequence_path": "414703.protein.sequences.v11.5.fa",
		        "enrichment_path": "414703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "414703.protein.info.v11.5.txt",
		        "node_list_path": "414703.cluster.nodes.v11.5.txt",
		        "edge_list_path": "414703.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapraHircusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capra hircus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapraHircusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9925.clusters.proteins.v11.5.txt",
		        "sequence_path": "9925.protein.sequences.v11.5.fa",
		        "enrichment_path": "9925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9925.protein.info.v11.5.txt",
		        "node_list_path": "9925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumD5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium D5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumD5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520815.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520815.protein.info.v11.5.txt",
		        "node_list_path": "1520815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseobacterSpMed193(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. MED193 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterSpMed193", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314262.protein.sequences.v11.5.fa",
		        "enrichment_path": "314262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314262.protein.info.v11.5.txt",
		        "node_list_path": "314262.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaCrocodyli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma crocodyli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaCrocodyli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "512564.protein.sequences.v11.5.fa",
		        "enrichment_path": "512564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512564.protein.info.v11.5.txt",
		        "node_list_path": "512564.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSp161mfsha21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 161MFSha21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSp161mfsha21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1151118.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1151118.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1151118.clusters.proteins.v11.5.txt",
		        "sequence_path": "1151118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151118.protein.info.v11.5.txt",
		        "node_list_path": "1151118.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1151118.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumKetosireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium ketosireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumKetosireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "92835.protein.sequences.v11.5.fa",
		        "enrichment_path": "92835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92835.protein.info.v11.5.txt",
		        "node_list_path": "92835.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinomonasAquimarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas aquimarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasAquimarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "295068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "295068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "295068.clusters.proteins.v11.5.txt",
		        "sequence_path": "295068.protein.sequences.v11.5.fa",
		        "enrichment_path": "295068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "295068.protein.info.v11.5.txt",
		        "node_list_path": "295068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "295068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho202Full4312(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_02_FULL_43_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho202Full4312", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802678.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802678.protein.info.v11.5.txt",
		        "node_list_path": "1802678.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpTb23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. TB23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpTb23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "494419.clusters.info.v11.5.txt",
		        "cluster_tree_path": "494419.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "494419.clusters.proteins.v11.5.txt",
		        "sequence_path": "494419.protein.sequences.v11.5.fa",
		        "enrichment_path": "494419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "494419.protein.info.v11.5.txt",
		        "node_list_path": "494419.cluster.nodes.v11.5.txt",
		        "edge_list_path": "494419.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermogemmatisporaSpPm5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermogemmatispora sp. PM5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermogemmatisporaSpPm5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1382306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382306.protein.info.v11.5.txt",
		        "node_list_path": "1382306.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaBurhodogranarieaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia burhodogranariea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaBurhodogranarieaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1141662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1141662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1141662.clusters.proteins.v11.5.txt",
		        "sequence_path": "1141662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141662.protein.info.v11.5.txt",
		        "node_list_path": "1141662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1141662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LaccariaBicolorS238nH82Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Laccaria bicolor S238N-H82 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LaccariaBicolorS238nH82Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "486041.clusters.info.v11.5.txt",
		        "cluster_tree_path": "486041.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "486041.clusters.proteins.v11.5.txt",
		        "sequence_path": "486041.protein.sequences.v11.5.fa",
		        "enrichment_path": "486041.protein.enrichment.terms.v11.5.txt",
		        "info_path": "486041.protein.info.v11.5.txt",
		        "node_list_path": "486041.cluster.nodes.v11.5.txt",
		        "edge_list_path": "486041.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CamponotusFloridanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Camponotus floridanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CamponotusFloridanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "104421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "104421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "104421.clusters.proteins.v11.5.txt",
		        "sequence_path": "104421.protein.sequences.v11.5.fa",
		        "enrichment_path": "104421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104421.protein.info.v11.5.txt",
		        "node_list_path": "104421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "104421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacteriumUtbcd1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium UTBCD1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacteriumUtbcd1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1961110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961110.protein.info.v11.5.txt",
		        "node_list_path": "1961110.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioclavaDalianensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioclava dalianensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaDalianensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1185766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185766.protein.info.v11.5.txt",
		        "node_list_path": "1185766.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumScgcAaa015N04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA015-N04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumScgcAaa015N04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "939296.protein.sequences.v11.5.fa",
		        "enrichment_path": "939296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "939296.protein.info.v11.5.txt",
		        "node_list_path": "939296.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpEe36(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. EE36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpEe36", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52598.protein.sequences.v11.5.fa",
		        "enrichment_path": "52598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52598.protein.info.v11.5.txt",
		        "node_list_path": "52598.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumShigenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium shigense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumShigenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "297244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "297244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "297244.clusters.proteins.v11.5.txt",
		        "sequence_path": "297244.protein.sequences.v11.5.fa",
		        "enrichment_path": "297244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "297244.protein.info.v11.5.txt",
		        "node_list_path": "297244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "297244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpKhp7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. khp7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpKhp7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761885.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761885.protein.info.v11.5.txt",
		        "node_list_path": "1761885.protein.complete.v11.5.txt"
		    }
		]
    )()

def QuadrisphaeraSpDsm44207Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Quadrisphaera sp. DSM 44207 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "QuadrisphaeraSpDsm44207Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881057.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881057.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881057.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881057.protein.info.v11.5.txt",
		        "node_list_path": "1881057.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881057.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasCampestrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCampestrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "340.clusters.proteins.v11.5.txt",
		        "sequence_path": "340.protein.sequences.v11.5.fa",
		        "enrichment_path": "340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340.protein.info.v11.5.txt",
		        "node_list_path": "340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioHydrothermalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio hydrothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioHydrothermalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121451.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121451.protein.info.v11.5.txt",
		        "node_list_path": "1121451.protein.complete.v11.5.txt"
		    }
		]
    )()

def PasteurellaceaeBacteriumNi1060(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurellaceae bacterium NI1060 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaceaeBacteriumNi1060", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1679001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679001.protein.info.v11.5.txt",
		        "node_list_path": "1679001.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumSubrubescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium subrubescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumSubrubescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1316194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1316194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1316194.protein.info.v11.5.txt",
		        "node_list_path": "1316194.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteococcusJaponicusLspLj1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteococcus japonicus LSP_Lj1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteococcusJaponicusLspLj1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1255658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1255658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1255658.clusters.proteins.v11.5.txt",
		        "sequence_path": "1255658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1255658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1255658.protein.info.v11.5.txt",
		        "node_list_path": "1255658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1255658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParascardoviaDenticolensDsm10105Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parascardovia denticolens DSM10105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParascardoviaDenticolensDsm10105Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "864564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "864564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "864564.clusters.proteins.v11.5.txt",
		        "sequence_path": "864564.protein.sequences.v11.5.fa",
		        "enrichment_path": "864564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864564.protein.info.v11.5.txt",
		        "node_list_path": "864564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "864564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PasteurellaTestudinisDsm23072(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella testudinis DSM 23072 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaTestudinisDsm23072", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122938.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122938.protein.info.v11.5.txt",
		        "node_list_path": "1122938.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMediterraneensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mediterraneensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMediterraneensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805474.protein.info.v11.5.txt",
		        "node_list_path": "1805474.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpNap1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. NAP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpNap1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "237727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "237727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "237727.clusters.proteins.v11.5.txt",
		        "sequence_path": "237727.protein.sequences.v11.5.fa",
		        "enrichment_path": "237727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237727.protein.info.v11.5.txt",
		        "node_list_path": "237727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "237727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesHarbinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces harbinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesHarbinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1176198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1176198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1176198.clusters.proteins.v11.5.txt",
		        "sequence_path": "1176198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1176198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1176198.protein.info.v11.5.txt",
		        "node_list_path": "1176198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1176198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaglaciecolaPolarisLmg21857Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraglaciecola polaris LMG 21857 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaglaciecolaPolarisLmg21857Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1129793.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1129793.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1129793.clusters.proteins.v11.5.txt",
		        "sequence_path": "1129793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1129793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1129793.protein.info.v11.5.txt",
		        "node_list_path": "1129793.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1129793.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpRoot656(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root656 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpRoot656", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736579.protein.info.v11.5.txt",
		        "node_list_path": "1736579.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0400(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0400 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0400", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888056.protein.sequences.v11.5.fa",
		        "enrichment_path": "888056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888056.protein.info.v11.5.txt",
		        "node_list_path": "888056.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumCg2303716Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium CG2_30_37_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumCg2303716Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805401.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805401.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805401.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805401.protein.info.v11.5.txt",
		        "node_list_path": "1805401.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805401.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAesculapii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium aesculapii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAesculapii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1329411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1329411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1329411.protein.info.v11.5.txt",
		        "node_list_path": "1329411.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaInohanensisNbrc100128(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia inohanensis NBRC 100128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaInohanensisNbrc100128", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210077.protein.info.v11.5.txt",
		        "node_list_path": "1210077.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaMuelleriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina muelleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaMuelleriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121007.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121007.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121007.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121007.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121007.protein.info.v11.5.txt",
		        "node_list_path": "1121007.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121007.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichomalopsisSarcophagaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichomalopsis sarcophagae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichomalopsisSarcophagaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "543379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "543379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "543379.clusters.proteins.v11.5.txt",
		        "sequence_path": "543379.protein.sequences.v11.5.fa",
		        "enrichment_path": "543379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543379.protein.info.v11.5.txt",
		        "node_list_path": "543379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "543379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumCg2303331Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium CG2_30_33_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumCg2303331Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805033.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805033.protein.info.v11.5.txt",
		        "node_list_path": "1805033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodothermusMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodothermus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodothermusMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "518766.protein.sequences.v11.5.fa",
		        "enrichment_path": "518766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "518766.protein.info.v11.5.txt",
		        "node_list_path": "518766.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpOralTaxon414Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. oral taxon 414 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpOralTaxon414Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "712122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "712122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "712122.clusters.proteins.v11.5.txt",
		        "sequence_path": "712122.protein.sequences.v11.5.fa",
		        "enrichment_path": "712122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712122.protein.info.v11.5.txt",
		        "node_list_path": "712122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "712122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OribacteriumSinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585501.protein.sequences.v11.5.fa",
		        "enrichment_path": "585501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585501.protein.info.v11.5.txt",
		        "node_list_path": "585501.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanotheceSpPcc7425Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7425 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanotheceSpPcc7425Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "395961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "395961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "395961.clusters.proteins.v11.5.txt",
		        "sequence_path": "395961.protein.sequences.v11.5.fa",
		        "enrichment_path": "395961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "395961.protein.info.v11.5.txt",
		        "node_list_path": "395961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "395961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusAcidoterrestrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidoterrestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusAcidoterrestrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1356854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1356854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1356854.clusters.proteins.v11.5.txt",
		        "sequence_path": "1356854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1356854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1356854.protein.info.v11.5.txt",
		        "node_list_path": "1356854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1356854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumLeguminosarumCb782(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum CB782 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumLeguminosarumCb782", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033991.protein.sequences.v11.0.fa",
		        "enrichment_path": "1033991.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1033991.protein.info.v11.0.txt",
		        "node_list_path": "1033991.protein.complete.v11.0.txt"
		    }
		]
    )()

def GeobacillusVulcaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus vulcani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusVulcaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1382315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1382315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1382315.clusters.proteins.v11.5.txt",
		        "sequence_path": "1382315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382315.protein.info.v11.5.txt",
		        "node_list_path": "1382315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1382315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidithiobacillusFerrooxidansAtcc53993Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans ATCC53993 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidithiobacillusFerrooxidansAtcc53993Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "380394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "380394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "380394.clusters.proteins.v11.5.txt",
		        "sequence_path": "380394.protein.sequences.v11.5.fa",
		        "enrichment_path": "380394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "380394.protein.info.v11.5.txt",
		        "node_list_path": "380394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "380394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EndozoicomonasElysicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas elysicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndozoicomonasElysicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "305900.protein.sequences.v11.5.fa",
		        "enrichment_path": "305900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "305900.protein.info.v11.5.txt",
		        "node_list_path": "305900.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslH70331Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSL H7-0331 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslH70331Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1920421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1920421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1920421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1920421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920421.protein.info.v11.5.txt",
		        "node_list_path": "1920421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1920421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslh70357(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslh70357", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1536774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536774.protein.info.v11.5.txt",
		        "node_list_path": "1536774.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4925Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_49_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4925Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802701.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802701.protein.info.v11.5.txt",
		        "node_list_path": "1802701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasMaliNbrc15500(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas mali NBRC 15500 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasMaliNbrc15500", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219048.protein.info.v11.5.txt",
		        "node_list_path": "1219048.protein.complete.v11.5.txt"
		    }
		]
    )()

def TerrimicrobiumSacchariphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terrimicrobium sacchariphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrimicrobiumSacchariphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "690879.protein.sequences.v11.5.fa",
		        "enrichment_path": "690879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690879.protein.info.v11.5.txt",
		        "node_list_path": "690879.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaJacobaeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia jacobaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaJacobaeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "122202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "122202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "122202.clusters.proteins.v11.5.txt",
		        "sequence_path": "122202.protein.sequences.v11.5.fa",
		        "enrichment_path": "122202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "122202.protein.info.v11.5.txt",
		        "node_list_path": "122202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "122202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AurantimonasSpLeaf443(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aurantimonas sp. Leaf443 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AurantimonasSpLeaf443", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736378.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736378.protein.info.v11.5.txt",
		        "node_list_path": "1736378.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterArcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterArcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "259536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "259536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "259536.clusters.proteins.v11.5.txt",
		        "sequence_path": "259536.protein.sequences.v11.5.fa",
		        "enrichment_path": "259536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "259536.protein.info.v11.5.txt",
		        "node_list_path": "259536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "259536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiumSpBvorr106Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. BvORR106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiumSpBvorr106Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1403819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1403819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1403819.clusters.proteins.v11.5.txt",
		        "sequence_path": "1403819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1403819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1403819.protein.info.v11.5.txt",
		        "node_list_path": "1403819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1403819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobiformaNitratireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobiforma nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobiformaNitratireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227454.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227454.protein.info.v11.5.txt",
		        "node_list_path": "1227454.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriaceaeBacterium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacteriaceae bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriaceaeBacterium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1873462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1873462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1873462.protein.info.v11.5.txt",
		        "node_list_path": "1873462.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwe24015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_40_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwe24015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797334.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797334.protein.info.v11.5.txt",
		        "node_list_path": "1797334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSpZor0009Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. ZOR0009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpZor0009Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1339253.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1339253.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1339253.clusters.proteins.v11.5.txt",
		        "sequence_path": "1339253.protein.sequences.v11.5.fa",
		        "enrichment_path": "1339253.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1339253.protein.info.v11.5.txt",
		        "node_list_path": "1339253.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1339253.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquimarinaSpSw150Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina sp. SW150 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaSpSw150Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1296415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1296415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1296415.clusters.proteins.v11.5.txt",
		        "sequence_path": "1296415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296415.protein.info.v11.5.txt",
		        "node_list_path": "1296415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1296415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobulbusMediterraneusDsm13871(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus mediterraneus DSM 13871 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbusMediterraneusDsm13871", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121404.protein.info.v11.5.txt",
		        "node_list_path": "1121404.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenobaculumSpHo(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenobaculum sp. HO graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenobaculumSpHo", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "547144.protein.sequences.v11.5.fa",
		        "enrichment_path": "547144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547144.protein.info.v11.5.txt",
		        "node_list_path": "547144.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloteneraVersatilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera versatilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraVersatilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "666681.clusters.info.v11.5.txt",
		        "cluster_tree_path": "666681.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "666681.clusters.proteins.v11.5.txt",
		        "sequence_path": "666681.protein.sequences.v11.5.fa",
		        "enrichment_path": "666681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "666681.protein.info.v11.5.txt",
		        "node_list_path": "666681.cluster.nodes.v11.5.txt",
		        "edge_list_path": "666681.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumJdfr81(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumJdfr81", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935142.protein.info.v11.5.txt",
		        "node_list_path": "1935142.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorothrixHollandica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorothrix hollandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorothrixHollandica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "317619.protein.sequences.v11.5.fa",
		        "enrichment_path": "317619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317619.protein.info.v11.5.txt",
		        "node_list_path": "317619.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaBirminghamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella birminghamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaBirminghamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28083.protein.sequences.v11.5.fa",
		        "enrichment_path": "28083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28083.protein.info.v11.5.txt",
		        "node_list_path": "28083.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesEpiroticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anopheles epiroticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesEpiroticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "199890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "199890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "199890.clusters.proteins.v11.5.txt",
		        "sequence_path": "199890.protein.sequences.v11.5.fa",
		        "enrichment_path": "199890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "199890.protein.info.v11.5.txt",
		        "node_list_path": "199890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "199890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumMoriokaense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium moriokaense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumMoriokaense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39691.protein.sequences.v11.5.fa",
		        "enrichment_path": "39691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39691.protein.info.v11.5.txt",
		        "node_list_path": "39691.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinivibrioSiamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio siamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinivibrioSiamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "414286.protein.sequences.v11.5.fa",
		        "enrichment_path": "414286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "414286.protein.info.v11.5.txt",
		        "node_list_path": "414286.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4825(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_48_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4825", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802765.protein.info.v11.5.txt",
		        "node_list_path": "1802765.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterHydrocarbonoclasticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter hydrocarbonoclasticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterHydrocarbonoclasticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351348.protein.sequences.v11.5.fa",
		        "enrichment_path": "351348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351348.protein.info.v11.5.txt",
		        "node_list_path": "351348.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpGm2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GM2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpGm2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1622070.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622070.protein.info.v11.5.txt",
		        "node_list_path": "1622070.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacteraceaeBacteriumWds1c4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium WDS1C4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacteraceaeBacteriumWds1c4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1914408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1914408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1914408.protein.info.v11.5.txt",
		        "node_list_path": "1914408.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifcsphigho212Full439(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_43_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho212Full439", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797867.protein.info.v11.5.txt",
		        "node_list_path": "1797867.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumRifcsplowo201Full4613(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RIFCSPLOWO2_01_FULL_46_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumRifcsplowo201Full4613", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817750.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817750.protein.info.v11.5.txt",
		        "node_list_path": "1817750.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaSativaJaponicaGroup(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Japonica Group graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaSativaJaponicaGroup", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39947.protein.sequences.v11.5.fa",
		        "enrichment_path": "39947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39947.protein.info.v11.5.txt",
		        "node_list_path": "39947.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumGossipiicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium gossipiicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumGossipiicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "582675.protein.sequences.v11.5.fa",
		        "enrichment_path": "582675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582675.protein.info.v11.5.txt",
		        "node_list_path": "582675.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumArbustiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium arbusti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumArbustiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "545243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "545243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "545243.clusters.proteins.v11.5.txt",
		        "sequence_path": "545243.protein.sequences.v11.5.fa",
		        "enrichment_path": "545243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545243.protein.info.v11.5.txt",
		        "node_list_path": "545243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "545243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp12458059(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1245805.9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp12458059", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1856862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1856862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1856862.protein.info.v11.5.txt",
		        "node_list_path": "1856862.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaSpOralTaxon807(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella sp. oral taxon 807 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaSpOralTaxon807", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "712411.protein.sequences.v11.5.fa",
		        "enrichment_path": "712411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "712411.protein.info.v11.5.txt",
		        "node_list_path": "712411.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4315(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_43_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4315", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797790.protein.info.v11.5.txt",
		        "node_list_path": "1797790.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterocytozoonHepatopenaei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterocytozoon hepatopenaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterocytozoonHepatopenaei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "646526.protein.sequences.v11.5.fa",
		        "enrichment_path": "646526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "646526.protein.info.v11.5.txt",
		        "node_list_path": "646526.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosococcusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosococcus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosococcusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "472759.protein.sequences.v11.5.fa",
		        "enrichment_path": "472759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472759.protein.info.v11.5.txt",
		        "node_list_path": "472759.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichodermaAtroviride(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma atroviride graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaAtroviride", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "63577.protein.sequences.v11.5.fa",
		        "enrichment_path": "63577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63577.protein.info.v11.5.txt",
		        "node_list_path": "63577.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSenegalensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSenegalensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033743.protein.info.v11.5.txt",
		        "node_list_path": "1033743.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaBrasiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaBrasiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1133849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1133849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1133849.protein.info.v11.5.txt",
		        "node_list_path": "1133849.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophilusSpLeaf414(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. Leaf414 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilusSpLeaf414", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736371.protein.info.v11.5.txt",
		        "node_list_path": "1736371.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusJiangxiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus jiangxiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusJiangxiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "235985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "235985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "235985.clusters.proteins.v11.5.txt",
		        "sequence_path": "235985.protein.sequences.v11.5.fa",
		        "enrichment_path": "235985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "235985.protein.info.v11.5.txt",
		        "node_list_path": "235985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "235985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoriobacteriaceaeBacteriumGd5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium GD5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacteriaceaeBacteriumGd5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232436.protein.info.v11.5.txt",
		        "node_list_path": "1232436.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesStephensi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles stephensi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesStephensi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "30069.protein.sequences.v11.5.fa",
		        "enrichment_path": "30069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30069.protein.info.v11.5.txt",
		        "node_list_path": "30069.protein.complete.v11.5.txt"
		    }
		]
    )()

def WickerhamomycesAnomalusNrrlY3668Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamomyces anomalus NRRL Y-366-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WickerhamomycesAnomalusNrrlY3668Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "683960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "683960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "683960.clusters.proteins.v11.5.txt",
		        "sequence_path": "683960.protein.sequences.v11.5.fa",
		        "enrichment_path": "683960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683960.protein.info.v11.5.txt",
		        "node_list_path": "683960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "683960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumCch3A5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium CCH3-A5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumCch3A5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1768796.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1768796.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1768796.clusters.proteins.v11.5.txt",
		        "sequence_path": "1768796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1768796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1768796.protein.info.v11.5.txt",
		        "node_list_path": "1768796.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1768796.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CrenarchaeotaArchaeonScgcAaa471B05(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon SCGC AAA471-B05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenarchaeotaArchaeonScgcAaa471B05", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1052801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1052801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1052801.protein.info.v11.5.txt",
		        "node_list_path": "1052801.protein.complete.v11.5.txt"
		    }
		]
    )()

def WinogradskyellaJejuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Winogradskyella jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinogradskyellaJejuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089305.protein.info.v11.5.txt",
		        "node_list_path": "1089305.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumSpA11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. A11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumSpA11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1394176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1394176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1394176.clusters.proteins.v11.5.txt",
		        "sequence_path": "1394176.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394176.protein.info.v11.5.txt",
		        "node_list_path": "1394176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1394176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolirubrobacterSpUrhd0082(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solirubrobacter sp. URHD0082 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolirubrobacterSpUrhd0082", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298857.protein.info.v11.5.txt",
		        "node_list_path": "1298857.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumFasciculatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium fasciculatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumFasciculatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2594813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2594813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2594813.clusters.proteins.v11.5.txt",
		        "sequence_path": "2594813.protein.sequences.v11.5.fa",
		        "enrichment_path": "2594813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2594813.protein.info.v11.5.txt",
		        "node_list_path": "2594813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2594813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusKhoisanaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus khoisanae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusKhoisanaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "880157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "880157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "880157.clusters.proteins.v11.5.txt",
		        "sequence_path": "880157.protein.sequences.v11.5.fa",
		        "enrichment_path": "880157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880157.protein.info.v11.5.txt",
		        "node_list_path": "880157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "880157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTaa040Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA040 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTaa040Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288083.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288083.protein.info.v11.5.txt",
		        "node_list_path": "1288083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloceanibacterMethanicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloceanibacter methanicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloceanibacterMethanicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1774968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1774968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1774968.protein.info.v11.5.txt",
		        "node_list_path": "1774968.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5420Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5420Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798513.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798513.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798513.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798513.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798513.protein.info.v11.5.txt",
		        "node_list_path": "1798513.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798513.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IzhakiellaCapsodis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Izhakiella capsodis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IzhakiellaCapsodis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1367852.protein.sequences.v11.5.fa",
		        "enrichment_path": "1367852.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1367852.protein.info.v11.5.txt",
		        "node_list_path": "1367852.protein.complete.v11.5.txt"
		    }
		]
    )()

def IntrasporangiumCalvum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Intrasporangium calvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntrasporangiumCalvum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "710696.protein.sequences.v11.5.fa",
		        "enrichment_path": "710696.protein.enrichment.terms.v11.5.txt",
		        "info_path": "710696.protein.info.v11.5.txt",
		        "node_list_path": "710696.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaSpCag317(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dorea sp. CAG:317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaSpCag317", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262873.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262873.protein.info.v11.5.txt",
		        "node_list_path": "1262873.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalocynthiibacterNamhaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halocynthiibacter namhaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalocynthiibacterNamhaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1290553.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1290553.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1290553.clusters.proteins.v11.5.txt",
		        "sequence_path": "1290553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1290553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1290553.protein.info.v11.5.txt",
		        "node_list_path": "1290553.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1290553.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaHaemolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga haemolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaHaemolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45243.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45243.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45243.clusters.proteins.v11.5.txt",
		        "sequence_path": "45243.protein.sequences.v11.5.fa",
		        "enrichment_path": "45243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45243.protein.info.v11.5.txt",
		        "node_list_path": "45243.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45243.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KocuriaRhizophilaP74Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kocuria rhizophila P74 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaRhizophilaP74Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1029824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1029824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1029824.clusters.proteins.v11.5.txt",
		        "sequence_path": "1029824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1029824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1029824.protein.info.v11.5.txt",
		        "node_list_path": "1029824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1029824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BotrytisEllipticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Botrytis elliptica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotrytisEllipticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "278938.clusters.info.v11.5.txt",
		        "cluster_tree_path": "278938.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "278938.clusters.proteins.v11.5.txt",
		        "sequence_path": "278938.protein.sequences.v11.5.fa",
		        "enrichment_path": "278938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278938.protein.info.v11.5.txt",
		        "node_list_path": "278938.cluster.nodes.v11.5.txt",
		        "edge_list_path": "278938.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpCot239oh1446Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT239OH1446 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpCot239oh1446Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1515613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1515613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1515613.clusters.proteins.v11.5.txt",
		        "sequence_path": "1515613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1515613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1515613.protein.info.v11.5.txt",
		        "node_list_path": "1515613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1515613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioclavaDalianensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioclava dalianensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaDalianensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1185766.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1185766.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1185766.clusters.proteins.v11.5.txt",
		        "sequence_path": "1185766.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185766.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185766.protein.info.v11.5.txt",
		        "node_list_path": "1185766.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1185766.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KordiaJejudonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kordia jejudonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KordiaJejudonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348245.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348245.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348245.protein.info.v11.5.txt",
		        "node_list_path": "1348245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanotheceSpPcc8801(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC8801 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanotheceSpPcc8801", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "41431.protein.sequences.v11.5.fa",
		        "enrichment_path": "41431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41431.protein.info.v11.5.txt",
		        "node_list_path": "41431.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosopumilusMaritimus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus maritimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopumilusMaritimus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "436308.protein.sequences.v11.5.fa",
		        "enrichment_path": "436308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436308.protein.info.v11.5.txt",
		        "node_list_path": "436308.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaColiBl21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli BL21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaColiBl21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469008.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469008.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469008.clusters.proteins.v11.5.txt",
		        "sequence_path": "469008.protein.sequences.v11.5.fa",
		        "enrichment_path": "469008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469008.protein.info.v11.5.txt",
		        "node_list_path": "469008.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469008.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcromyrmexEchinatiorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acromyrmex echinatior Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcromyrmexEchinatiorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "103372.clusters.info.v11.5.txt",
		        "cluster_tree_path": "103372.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "103372.clusters.proteins.v11.5.txt",
		        "sequence_path": "103372.protein.sequences.v11.5.fa",
		        "enrichment_path": "103372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103372.protein.info.v11.5.txt",
		        "node_list_path": "103372.cluster.nodes.v11.5.txt",
		        "edge_list_path": "103372.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UreaplasmaUrealyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ureaplasma urealyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UreaplasmaUrealyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "565575.clusters.info.v11.5.txt",
		        "cluster_tree_path": "565575.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "565575.clusters.proteins.v11.5.txt",
		        "sequence_path": "565575.protein.sequences.v11.5.fa",
		        "enrichment_path": "565575.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565575.protein.info.v11.5.txt",
		        "node_list_path": "565575.cluster.nodes.v11.5.txt",
		        "edge_list_path": "565575.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolemyaVelesianaGillSymbiontCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solemya velesiana gill symbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolemyaVelesianaGillSymbiontCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1918948.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1918948.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1918948.clusters.proteins.v11.5.txt",
		        "sequence_path": "1918948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918948.protein.info.v11.5.txt",
		        "node_list_path": "1918948.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1918948.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WohlfahrtiimonasPopuli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas populi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WohlfahrtiimonasPopuli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1940240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1940240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1940240.protein.info.v11.5.txt",
		        "node_list_path": "1940240.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonasSpT16b2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. T16B2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSpT16b2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280941.protein.info.v11.5.txt",
		        "node_list_path": "1280941.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotogaSpMc24Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga sp. Mc24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaSpMc24Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231241.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231241.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231241.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231241.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231241.protein.info.v11.5.txt",
		        "node_list_path": "1231241.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231241.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumXbb1006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBB1006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumXbb1006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520827.protein.info.v11.5.txt",
		        "node_list_path": "1520827.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf2580Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF2580 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf2580Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463841.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463841.protein.info.v11.5.txt",
		        "node_list_path": "1463841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmobacterMegaterium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmobacter megaterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmobacterMegaterium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1086013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1086013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1086013.protein.info.v11.5.txt",
		        "node_list_path": "1086013.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusZhangzhouensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus zhangzhouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusZhangzhouensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1073327.protein.sequences.v11.5.fa",
		        "enrichment_path": "1073327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1073327.protein.info.v11.5.txt",
		        "node_list_path": "1073327.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacillusSuccinogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus succinogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusSuccinogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "339671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "339671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "339671.clusters.proteins.v11.5.txt",
		        "sequence_path": "339671.protein.sequences.v11.5.fa",
		        "enrichment_path": "339671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "339671.protein.info.v11.5.txt",
		        "node_list_path": "339671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "339671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IndibacterAlkaliphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Indibacter alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IndibacterAlkaliphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1189612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1189612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1189612.protein.info.v11.5.txt",
		        "node_list_path": "1189612.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaTucsonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella tucsonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaTucsonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40335.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40335.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40335.clusters.proteins.v11.5.txt",
		        "sequence_path": "40335.protein.sequences.v11.5.fa",
		        "enrichment_path": "40335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40335.protein.info.v11.5.txt",
		        "node_list_path": "40335.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40335.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GaeumannomycesTriticiR3111a1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gaeumannomyces tritici R3-111a-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GaeumannomycesTriticiR3111a1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644352.clusters.proteins.v11.5.txt",
		        "sequence_path": "644352.protein.sequences.v11.5.fa",
		        "enrichment_path": "644352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644352.protein.info.v11.5.txt",
		        "node_list_path": "644352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpUnc41mfs5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. UNC41MFS5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpUnc41mfs5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449046.protein.info.v11.5.txt",
		        "node_list_path": "1449046.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinicolaSpMit1003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinicola sp. MIT1003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicolaSpMit1003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882734.protein.info.v11.5.txt",
		        "node_list_path": "1882734.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterBizzozeroniiCcug35545(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii CCUG 35545 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterBizzozeroniiCcug35545", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1002805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002805.protein.info.v11.5.txt",
		        "node_list_path": "1002805.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusMarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusMarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1925762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1925762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1925762.clusters.proteins.v11.5.txt",
		        "sequence_path": "1925762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1925762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1925762.protein.info.v11.5.txt",
		        "node_list_path": "1925762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1925762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumBacteremicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium bacteremicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumBacteremicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "564198.clusters.info.v11.5.txt",
		        "cluster_tree_path": "564198.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "564198.clusters.proteins.v11.5.txt",
		        "sequence_path": "564198.protein.sequences.v11.5.fa",
		        "enrichment_path": "564198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "564198.protein.info.v11.5.txt",
		        "node_list_path": "564198.cluster.nodes.v11.5.txt",
		        "edge_list_path": "564198.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3820(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_38_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3820", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802515.protein.info.v11.5.txt",
		        "node_list_path": "1802515.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaBurhodogranariea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Providencia burhodogranariea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaBurhodogranariea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1141662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1141662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1141662.protein.info.v11.5.txt",
		        "node_list_path": "1141662.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaSteigerwaltii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella steigerwaltii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaSteigerwaltii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "460.protein.sequences.v11.5.fa",
		        "enrichment_path": "460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "460.protein.info.v11.5.txt",
		        "node_list_path": "460.protein.complete.v11.5.txt"
		    }
		]
    )()

def BathymodiolusAzoricusThioautotrophicGillSymbiont(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bathymodiolus azoricus thioautotrophic gill symbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BathymodiolusAzoricusThioautotrophicGillSymbiont", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "235205.protein.sequences.v11.5.fa",
		        "enrichment_path": "235205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "235205.protein.info.v11.5.txt",
		        "node_list_path": "235205.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasXianhensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas xianhensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasXianhensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "442341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "442341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "442341.clusters.proteins.v11.5.txt",
		        "sequence_path": "442341.protein.sequences.v11.5.fa",
		        "enrichment_path": "442341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "442341.protein.info.v11.5.txt",
		        "node_list_path": "442341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "442341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VirgibacillusSalinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus salinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusSalinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553311.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553311.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553311.clusters.proteins.v11.5.txt",
		        "sequence_path": "553311.protein.sequences.v11.5.fa",
		        "enrichment_path": "553311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553311.protein.info.v11.5.txt",
		        "node_list_path": "553311.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553311.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterAdhaerens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter adhaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterAdhaerens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "225937.protein.sequences.v11.5.fa",
		        "enrichment_path": "225937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225937.protein.info.v11.5.txt",
		        "node_list_path": "225937.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumRifcsphigho201Full4710bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPHIGHO2_01_FULL_47_10b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsphigho201Full4710bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817738.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817738.protein.info.v11.5.txt",
		        "node_list_path": "1817738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpBpaaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. BPAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpBpaaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229512.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229512.protein.info.v11.5.txt",
		        "node_list_path": "1229512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpBa1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. ba1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpBa1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1522072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522072.protein.info.v11.5.txt",
		        "node_list_path": "1522072.protein.complete.v11.5.txt"
		    }
		]
    )()

def StappiaIndicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stappia indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StappiaIndicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "538381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "538381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "538381.clusters.proteins.v11.5.txt",
		        "sequence_path": "538381.protein.sequences.v11.5.fa",
		        "enrichment_path": "538381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "538381.protein.info.v11.5.txt",
		        "node_list_path": "538381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "538381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85201351886Sch5428379(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852013-51886_SCH5428379 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85201351886Sch5428379", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834111.protein.info.v11.5.txt",
		        "node_list_path": "1834111.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfobacillusThermosulfidooxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfobacillus thermosulfidooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfobacillusThermosulfidooxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28034.clusters.proteins.v11.5.txt",
		        "sequence_path": "28034.protein.sequences.v11.5.fa",
		        "enrichment_path": "28034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28034.protein.info.v11.5.txt",
		        "node_list_path": "28034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAcetotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acetotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAcetotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1600.protein.sequences.v11.5.fa",
		        "enrichment_path": "1600.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1600.protein.info.v11.5.txt",
		        "node_list_path": "1600.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAntibioticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces antibioticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAntibioticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1890.protein.info.v11.5.txt",
		        "node_list_path": "1890.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoanaerobacterMathraniiSubspMathraniiStrA3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter mathranii subsp. mathranii str. A3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerobacterMathraniiSubspMathraniiStrA3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "583358.protein.sequences.v11.5.fa",
		        "enrichment_path": "583358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "583358.protein.info.v11.5.txt",
		        "node_list_path": "583358.protein.complete.v11.5.txt"
		    }
		]
    )()

def SutterellaWadsworthensis2159bfaaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis 2159BFAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SutterellaWadsworthensis2159bfaaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742823.clusters.proteins.v11.5.txt",
		        "sequence_path": "742823.protein.sequences.v11.5.fa",
		        "enrichment_path": "742823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742823.protein.info.v11.5.txt",
		        "node_list_path": "742823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FacklamiaLanguida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Facklamia languida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FacklamiaLanguida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883113.protein.sequences.v11.5.fa",
		        "enrichment_path": "883113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883113.protein.info.v11.5.txt",
		        "node_list_path": "883113.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusSpPh9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. PH9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusSpPh9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118055.protein.info.v11.5.txt",
		        "node_list_path": "1118055.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpCpuCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Cpu Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpCpuCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1075399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1075399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1075399.clusters.proteins.v11.5.txt",
		        "sequence_path": "1075399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1075399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1075399.protein.info.v11.5.txt",
		        "node_list_path": "1075399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1075399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "985665.protein.sequences.v11.5.fa",
		        "enrichment_path": "985665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985665.protein.info.v11.5.txt",
		        "node_list_path": "985665.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesBouchesdurhonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces bouchesdurhonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesBouchesdurhonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852361.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852361.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852361.protein.info.v11.5.txt",
		        "node_list_path": "1852361.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaSp83e34(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. 83E34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSp83e34", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1692264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1692264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1692264.protein.info.v11.5.txt",
		        "node_list_path": "1692264.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetalesBacterium457213Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 4572_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetalesBacterium457213Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1971638.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1971638.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1971638.clusters.proteins.v11.5.txt",
		        "sequence_path": "1971638.protein.sequences.v11.5.fa",
		        "enrichment_path": "1971638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1971638.protein.info.v11.5.txt",
		        "node_list_path": "1971638.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1971638.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KluyveromycesLactisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kluyveromyces lactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KluyveromycesLactisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28985.clusters.proteins.v11.5.txt",
		        "sequence_path": "28985.protein.sequences.v11.5.fa",
		        "enrichment_path": "28985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28985.protein.info.v11.5.txt",
		        "node_list_path": "28985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpMtm3w52(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. MTM3W5.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpMtm3w52", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805827.protein.info.v11.5.txt",
		        "node_list_path": "1805827.protein.complete.v11.5.txt"
		    }
		]
    )()

def RalstoniaSp25mfcol41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. 25mfcol4.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSp25mfcol41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761899.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761899.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761899.protein.info.v11.5.txt",
		        "node_list_path": "1761899.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSporosphaeroidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sporosphaeroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSporosphaeroidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121334.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121334.protein.info.v11.5.txt",
		        "node_list_path": "1121334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpVcd2006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. VCD2006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpVcd2006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280664.protein.info.v11.5.txt",
		        "node_list_path": "1280664.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaueraTerpenica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thauera terpenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraTerpenica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348657.protein.info.v11.5.txt",
		        "node_list_path": "1348657.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasSpAlt199(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. ALT199 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasSpAlt199", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298865.protein.info.v11.5.txt",
		        "node_list_path": "1298865.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifoxyc12Full3455Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYC12_FULL_34_55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyc12Full3455Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798000.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798000.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798000.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798000.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798000.protein.info.v11.5.txt",
		        "node_list_path": "1798000.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798000.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkanindigesSpH1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkanindiges sp. H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkanindigesSpH1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907941.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907941.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907941.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907941.protein.info.v11.5.txt",
		        "node_list_path": "1907941.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907941.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HenriciellaPelagia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Henriciella pelagia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HenriciellaPelagia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1977912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977912.protein.info.v11.5.txt",
		        "node_list_path": "1977912.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitratireductorSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitratireductor soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratireductorSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1670619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1670619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1670619.clusters.proteins.v11.5.txt",
		        "sequence_path": "1670619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1670619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1670619.protein.info.v11.5.txt",
		        "node_list_path": "1670619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1670619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaFonticolaAuap2c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia fonticola AUAP2C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaFonticolaAuap2c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1332071.protein.sequences.v11.5.fa",
		        "enrichment_path": "1332071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1332071.protein.info.v11.5.txt",
		        "node_list_path": "1332071.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaGranulosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga granulosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaGranulosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641143.clusters.proteins.v11.5.txt",
		        "sequence_path": "641143.protein.sequences.v11.5.fa",
		        "enrichment_path": "641143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641143.protein.info.v11.5.txt",
		        "node_list_path": "641143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaxillusRubicundulusVe082h10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paxillus rubicundulus Ve08.2h10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaxillusRubicundulusVe082h10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930991.protein.sequences.v11.5.fa",
		        "enrichment_path": "930991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930991.protein.info.v11.5.txt",
		        "node_list_path": "930991.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumLongum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium longum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumLongum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216816.protein.sequences.v11.5.fa",
		        "enrichment_path": "216816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216816.protein.info.v11.5.txt",
		        "node_list_path": "216816.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpScgcAg212E16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. SCGC AG-212-E16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpScgcAg212E16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1799664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1799664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1799664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1799664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1799664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1799664.protein.info.v11.5.txt",
		        "node_list_path": "1799664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1799664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumGwb25436Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWB2_54_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumGwb25436Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797613.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797613.protein.info.v11.5.txt",
		        "node_list_path": "1797613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlloprevotellaRava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alloprevotella rava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloprevotellaRava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "679199.protein.sequences.v11.5.fa",
		        "enrichment_path": "679199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679199.protein.info.v11.5.txt",
		        "node_list_path": "679199.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumGregariumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium gregarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumGregariumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121287.protein.info.v11.5.txt",
		        "node_list_path": "1121287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonadaceaeCot184oh4590(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonadaceae COT184OH4590 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonadaceaeCot184oh4590", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1517682.protein.sequences.v11.5.fa",
		        "enrichment_path": "1517682.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1517682.protein.info.v11.5.txt",
		        "node_list_path": "1517682.protein.complete.v11.5.txt"
		    }
		]
    )()

def KurthiaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kurthia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KurthiaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033739.protein.info.v11.5.txt",
		        "node_list_path": "1033739.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5422(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_54_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5422", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798495.protein.info.v11.5.txt",
		        "node_list_path": "1798495.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaAbortusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila abortus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaAbortusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "218497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "218497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "218497.clusters.proteins.v11.5.txt",
		        "sequence_path": "218497.protein.sequences.v11.5.fa",
		        "enrichment_path": "218497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218497.protein.info.v11.5.txt",
		        "node_list_path": "218497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "218497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodothermusProfundi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodothermus profundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodothermusProfundi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "633813.protein.sequences.v11.5.fa",
		        "enrichment_path": "633813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633813.protein.info.v11.5.txt",
		        "node_list_path": "633813.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanomicrobiaArchaeonJdfr19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanomicrobia archaeon JdFR-19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomicrobiaArchaeonJdfr19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935140.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935140.protein.info.v11.5.txt",
		        "node_list_path": "1935140.protein.complete.v11.5.txt"
		    }
		]
    )()

def CardiobacteriumValvarumF0432Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cardiobacterium valvarum F0432 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CardiobacteriumValvarumF0432Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "797473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "797473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "797473.clusters.proteins.v11.5.txt",
		        "sequence_path": "797473.protein.sequences.v11.5.fa",
		        "enrichment_path": "797473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797473.protein.info.v11.5.txt",
		        "node_list_path": "797473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "797473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBeckwithbacteriaBacteriumCg1024737Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium CG1_02_47_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumCg1024737Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805034.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805034.protein.info.v11.5.txt",
		        "node_list_path": "1805034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporolactobacillusNakayamaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus nakayamae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolactobacillusNakayamaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "269670.clusters.info.v11.5.txt",
		        "cluster_tree_path": "269670.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "269670.clusters.proteins.v11.5.txt",
		        "sequence_path": "269670.protein.sequences.v11.5.fa",
		        "enrichment_path": "269670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269670.protein.info.v11.5.txt",
		        "node_list_path": "269670.cluster.nodes.v11.5.txt",
		        "edge_list_path": "269670.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetaBajacaliforniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta bajacaliforniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetaBajacaliforniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123274.protein.info.v11.5.txt",
		        "node_list_path": "1123274.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg166814(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_68_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg166814", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797660.protein.info.v11.5.txt",
		        "node_list_path": "1797660.protein.complete.v11.5.txt"
		    }
		]
    )()

def DermacoccusNishinomiyaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dermacoccus nishinomiyaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DermacoccusNishinomiyaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1274.protein.sequences.v11.5.fa",
		        "enrichment_path": "1274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1274.protein.info.v11.5.txt",
		        "node_list_path": "1274.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusHimalayensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus himalayensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusHimalayensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1888195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1888195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1888195.clusters.proteins.v11.5.txt",
		        "sequence_path": "1888195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1888195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1888195.protein.info.v11.5.txt",
		        "node_list_path": "1888195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1888195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizoctoniaSolaniAg1Ia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizoctonia solani AG-1 IA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizoctoniaSolaniAg1Ia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983506.protein.sequences.v11.5.fa",
		        "enrichment_path": "983506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983506.protein.info.v11.5.txt",
		        "node_list_path": "983506.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpLeaf337Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf337 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpLeaf337Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736342.protein.info.v11.5.txt",
		        "node_list_path": "1736342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaRhamnosiphilaNbrc108938(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia rhamnosiphila NBRC 108938 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaRhamnosiphilaNbrc108938", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223547.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223547.protein.info.v11.5.txt",
		        "node_list_path": "1223547.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusSp2gCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. 2G Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSp2gCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1570939.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1570939.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1570939.clusters.proteins.v11.5.txt",
		        "sequence_path": "1570939.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570939.protein.info.v11.5.txt",
		        "node_list_path": "1570939.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1570939.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesoflavibacterZeaxanthDsm18436(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanth. DSM18436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "MesoflavibacterZeaxanthDsm18436", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122225.protein.sequences.v11.0.fa",
		        "enrichment_path": "1122225.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1122225.protein.info.v11.0.txt",
		        "node_list_path": "1122225.protein.complete.v11.0.txt"
		    }
		]
    )()

def BifidobacteriumSaguiniDsm23967Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium saguini DSM 23967 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumSaguiniDsm23967Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1437607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1437607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1437607.clusters.proteins.v11.5.txt",
		        "sequence_path": "1437607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437607.protein.info.v11.5.txt",
		        "node_list_path": "1437607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1437607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLk11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. LK11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLk11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1390395.protein.sequences.v11.5.fa",
		        "enrichment_path": "1390395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1390395.protein.info.v11.5.txt",
		        "node_list_path": "1390395.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyclobacteriumLianumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacterium lianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyclobacteriumLianumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "388280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "388280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "388280.clusters.proteins.v11.5.txt",
		        "sequence_path": "388280.protein.sequences.v11.5.fa",
		        "enrichment_path": "388280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388280.protein.info.v11.5.txt",
		        "node_list_path": "388280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "388280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NomascusLeucogenys(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nomascus leucogenys graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NomascusLeucogenys", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61853.protein.sequences.v11.5.fa",
		        "enrichment_path": "61853.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61853.protein.info.v11.5.txt",
		        "node_list_path": "61853.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankineaeBacteriumMt45Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankineae bacterium MT45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankineaeBacteriumMt45Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882833.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882833.protein.info.v11.5.txt",
		        "node_list_path": "1882833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterRodentiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter rodentium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterRodentiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449345.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449345.protein.info.v11.5.txt",
		        "node_list_path": "1449345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag1092(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1092 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag1092", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262919.protein.info.v11.5.txt",
		        "node_list_path": "1262919.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaJacobaea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia jacobaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaJacobaea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "122202.protein.sequences.v11.5.fa",
		        "enrichment_path": "122202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "122202.protein.info.v11.5.txt",
		        "node_list_path": "122202.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesOdontolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces odontolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesOdontolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411466.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411466.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411466.clusters.proteins.v11.5.txt",
		        "sequence_path": "411466.protein.sequences.v11.5.fa",
		        "enrichment_path": "411466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411466.protein.info.v11.5.txt",
		        "node_list_path": "411466.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411466.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterWuhouensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter wuhouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterWuhouensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1879050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1879050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1879050.protein.info.v11.5.txt",
		        "node_list_path": "1879050.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalococcusHamelinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halococcus hamelinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusHamelinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1132509.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1132509.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1132509.clusters.proteins.v11.5.txt",
		        "sequence_path": "1132509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1132509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1132509.protein.info.v11.5.txt",
		        "node_list_path": "1132509.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1132509.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClavisporaLusitaniaeAtcc42720(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clavispora lusitaniae ATCC 42720 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavisporaLusitaniaeAtcc42720", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "306902.protein.sequences.v11.5.fa",
		        "enrichment_path": "306902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306902.protein.info.v11.5.txt",
		        "node_list_path": "306902.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizoctoniaSolaniAg1IbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizoctonia solani AG-1 IB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizoctoniaSolaniAg1IbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1108050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1108050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1108050.clusters.proteins.v11.5.txt",
		        "sequence_path": "1108050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1108050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1108050.protein.info.v11.5.txt",
		        "node_list_path": "1108050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1108050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudaestuariivitaAtlantica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudaestuariivita atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudaestuariivitaAtlantica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1317121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317121.protein.info.v11.5.txt",
		        "node_list_path": "1317121.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumHumi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumHumi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "640635.protein.sequences.v11.5.fa",
		        "enrichment_path": "640635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640635.protein.info.v11.5.txt",
		        "node_list_path": "640635.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4515bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_01_FULL_45_15b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4515bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802319.protein.info.v11.5.txt",
		        "node_list_path": "1802319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsathyrellaAberdarensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psathyrella aberdarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsathyrellaAberdarensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2316362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2316362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2316362.clusters.proteins.v11.5.txt",
		        "sequence_path": "2316362.protein.sequences.v11.5.fa",
		        "enrichment_path": "2316362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2316362.protein.info.v11.5.txt",
		        "node_list_path": "2316362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2316362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasHaloplanktisAnt505(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis ANT505 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasHaloplanktisAnt505", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "722419.protein.sequences.v11.5.fa",
		        "enrichment_path": "722419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "722419.protein.info.v11.5.txt",
		        "node_list_path": "722419.protein.complete.v11.5.txt"
		    }
		]
    )()

def NematocidaParisiiErtm3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nematocida parisii ERTm3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NematocidaParisiiErtm3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935791.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935791.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935791.clusters.proteins.v11.5.txt",
		        "sequence_path": "935791.protein.sequences.v11.5.fa",
		        "enrichment_path": "935791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935791.protein.info.v11.5.txt",
		        "node_list_path": "935791.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935791.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpLeaf191(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf191 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpLeaf191", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736296.protein.info.v11.5.txt",
		        "node_list_path": "1736296.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSpDv(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. DV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSpDv", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1844708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1844708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1844708.protein.info.v11.5.txt",
		        "node_list_path": "1844708.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusFlavefaciensMa2007(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens MA2007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusFlavefaciensMa2007", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410670.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410670.protein.info.v11.5.txt",
		        "node_list_path": "1410670.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumKoreenseCcug49689Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium koreense CCUG 49689 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumKoreenseCcug49689Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304281.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304281.protein.info.v11.5.txt",
		        "node_list_path": "1304281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioVulnificus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio vulnificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioVulnificus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "672.protein.sequences.v11.5.fa",
		        "enrichment_path": "672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "672.protein.info.v11.5.txt",
		        "node_list_path": "672.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenarthrobacterNicotinovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenarthrobacter nicotinovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenarthrobacterNicotinovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29320.protein.sequences.v11.5.fa",
		        "enrichment_path": "29320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29320.protein.info.v11.5.txt",
		        "node_list_path": "29320.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrondihabitansSpLeaf304(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frondihabitans sp. Leaf304 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrondihabitansSpLeaf304", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736329.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736329.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736329.protein.info.v11.5.txt",
		        "node_list_path": "1736329.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwe24015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_40_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwe24015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797334.protein.info.v11.5.txt",
		        "node_list_path": "1797334.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPortnoybacteriaBacteriumRifcsplowo201Full4311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RIFCSPLOWO2_01_FULL_43_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRifcsplowo201Full4311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802000.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802000.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802000.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802000.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802000.protein.info.v11.5.txt",
		        "node_list_path": "1802000.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802000.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumCg1025844(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_58_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1025844", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805313.protein.info.v11.5.txt",
		        "node_list_path": "1805313.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpRoot552Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root552 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpRoot552Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736555.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736555.protein.info.v11.5.txt",
		        "node_list_path": "1736555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumTuberculosisH37rvCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis H37Rv Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumTuberculosisH37rvCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83332.clusters.proteins.v11.5.txt",
		        "sequence_path": "83332.protein.sequences.v11.5.fa",
		        "enrichment_path": "83332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83332.protein.info.v11.5.txt",
		        "node_list_path": "83332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpNc2002Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. NC2002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpNc2002Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410610.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410610.protein.info.v11.5.txt",
		        "node_list_path": "1410610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpInlla21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. INlla21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpInlla21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520811.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520811.protein.info.v11.5.txt",
		        "node_list_path": "1520811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3913(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_39_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3913", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797796.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797796.protein.info.v11.5.txt",
		        "node_list_path": "1797796.protein.complete.v11.5.txt"
		    }
		]
    )()

def VicugnaPacosCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vicugna pacos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VicugnaPacosCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "30538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "30538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "30538.clusters.proteins.v11.5.txt",
		        "sequence_path": "30538.protein.sequences.v11.5.fa",
		        "enrichment_path": "30538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30538.protein.info.v11.5.txt",
		        "node_list_path": "30538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "30538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlossinaPallidipesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glossina pallidipes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlossinaPallidipesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7398.clusters.proteins.v11.5.txt",
		        "sequence_path": "7398.protein.sequences.v11.5.fa",
		        "enrichment_path": "7398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7398.protein.info.v11.5.txt",
		        "node_list_path": "7398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChrysolophusPictusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chrysolophus pictus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChrysolophusPictusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9089.clusters.proteins.v11.5.txt",
		        "sequence_path": "9089.protein.sequences.v11.5.fa",
		        "enrichment_path": "9089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9089.protein.info.v11.5.txt",
		        "node_list_path": "9089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EctothiorhodospiraSpBsl9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ectothiorhodospira sp. BSL-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctothiorhodospiraSpBsl9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1442136.protein.sequences.v11.5.fa",
		        "enrichment_path": "1442136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1442136.protein.info.v11.5.txt",
		        "node_list_path": "1442136.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerolineaceaeBacteriumOralTaxon439(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium oral taxon 439 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaceaeBacteriumOralTaxon439", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1889813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1889813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1889813.protein.info.v11.5.txt",
		        "node_list_path": "1889813.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribiusSpMola401(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maribius sp. MOLA401 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribiusSpMola401", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1530186.protein.sequences.v11.5.fa",
		        "enrichment_path": "1530186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1530186.protein.info.v11.5.txt",
		        "node_list_path": "1530186.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioFerrireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioFerrireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246191.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246191.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246191.clusters.proteins.v11.5.txt",
		        "sequence_path": "246191.protein.sequences.v11.5.fa",
		        "enrichment_path": "246191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246191.protein.info.v11.5.txt",
		        "node_list_path": "246191.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246191.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusFerrariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ferrarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusFerrariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1469647.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1469647.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1469647.clusters.proteins.v11.5.txt",
		        "sequence_path": "1469647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469647.protein.info.v11.5.txt",
		        "node_list_path": "1469647.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1469647.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MegasphaeraSpMjr8396cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. MJR8396C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraSpMjr8396cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1603888.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1603888.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1603888.clusters.proteins.v11.5.txt",
		        "sequence_path": "1603888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603888.protein.info.v11.5.txt",
		        "node_list_path": "1603888.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1603888.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpLtsp849Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LTSP849 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpLtsp849Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1615890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1615890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1615890.clusters.proteins.v11.5.txt",
		        "sequence_path": "1615890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1615890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1615890.protein.info.v11.5.txt",
		        "node_list_path": "1615890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1615890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumVincentii4113Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii 4113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumVincentii4113Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469606.clusters.proteins.v11.5.txt",
		        "sequence_path": "469606.protein.sequences.v11.5.fa",
		        "enrichment_path": "469606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469606.protein.info.v11.5.txt",
		        "node_list_path": "469606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumSp7101(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. 7101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumSp7101", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1394175.protein.sequences.v11.5.fa",
		        "enrichment_path": "1394175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1394175.protein.info.v11.5.txt",
		        "node_list_path": "1394175.protein.complete.v11.5.txt"
		    }
		]
    )()

def KitasatosporaSetaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora setae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaSetaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "452652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "452652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "452652.clusters.proteins.v11.5.txt",
		        "sequence_path": "452652.protein.sequences.v11.5.fa",
		        "enrichment_path": "452652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452652.protein.info.v11.5.txt",
		        "node_list_path": "452652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "452652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaprospiraGrandis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saprospira grandis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaprospiraGrandis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "984262.protein.sequences.v11.5.fa",
		        "enrichment_path": "984262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "984262.protein.info.v11.5.txt",
		        "node_list_path": "984262.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusCarnosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus carnosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusCarnosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "396513.clusters.info.v11.5.txt",
		        "cluster_tree_path": "396513.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "396513.clusters.proteins.v11.5.txt",
		        "sequence_path": "396513.protein.sequences.v11.5.fa",
		        "enrichment_path": "396513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396513.protein.info.v11.5.txt",
		        "node_list_path": "396513.cluster.nodes.v11.5.txt",
		        "edge_list_path": "396513.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_01_FULL_40_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797512.protein.info.v11.5.txt",
		        "node_list_path": "1797512.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoriobacteriaceaeBacteriumEmtcatb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium EMTCatB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacteriaceaeBacteriumEmtcatb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1927122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1927122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1927122.protein.info.v11.5.txt",
		        "node_list_path": "1927122.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaCibaria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella cibaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaCibaria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "911104.protein.sequences.v11.5.fa",
		        "enrichment_path": "911104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "911104.protein.info.v11.5.txt",
		        "node_list_path": "911104.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusVogelbacteriaBacteriumRifoxyb1Full4216(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYB1_FULL_42_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyb1Full4216", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802436.protein.info.v11.5.txt",
		        "node_list_path": "1802436.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZetaProteobacteriumScgcAb137C09Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return zeta proteobacterium SCGC AB-137-C09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaProteobacteriumScgcAb137C09Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131284.protein.info.v11.5.txt",
		        "node_list_path": "1131284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GallibacteriumGenomosp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallibacteriumGenomosp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "155515.protein.sequences.v11.5.fa",
		        "enrichment_path": "155515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "155515.protein.info.v11.5.txt",
		        "node_list_path": "155515.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag924Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:924 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag924Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262938.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262938.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262938.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262938.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262938.protein.info.v11.5.txt",
		        "node_list_path": "1262938.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262938.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TesticulariaCyperi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Testicularia cyperi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TesticulariaCyperi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882483.protein.info.v11.5.txt",
		        "node_list_path": "1882483.protein.complete.v11.5.txt"
		    }
		]
    )()

def PenicilliumRubensWisconsin541255(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium rubens Wisconsin 54-1255 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumRubensWisconsin541255", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "500485.protein.sequences.v11.5.fa",
		        "enrichment_path": "500485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500485.protein.info.v11.5.txt",
		        "node_list_path": "500485.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpFcs014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FCS014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpFcs014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408304.protein.info.v11.5.txt",
		        "node_list_path": "1408304.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeromyscusManiculatusBairdiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peromyscus maniculatus bairdii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeromyscusManiculatusBairdiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "230844.clusters.info.v11.5.txt",
		        "cluster_tree_path": "230844.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "230844.clusters.proteins.v11.5.txt",
		        "sequence_path": "230844.protein.sequences.v11.5.fa",
		        "enrichment_path": "230844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "230844.protein.info.v11.5.txt",
		        "node_list_path": "230844.cluster.nodes.v11.5.txt",
		        "edge_list_path": "230844.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaArgininiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma arginini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaArgininiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1188236.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1188236.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1188236.clusters.proteins.v11.5.txt",
		        "sequence_path": "1188236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188236.protein.info.v11.5.txt",
		        "node_list_path": "1188236.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1188236.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DactylococcopsisSalinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dactylococcopsis salina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DactylococcopsisSalinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "13035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "13035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "13035.clusters.proteins.v11.5.txt",
		        "sequence_path": "13035.protein.sequences.v11.5.fa",
		        "enrichment_path": "13035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "13035.protein.info.v11.5.txt",
		        "node_list_path": "13035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "13035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodothermaceaeBacteriumTcBr11B2g67(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodothermaceae bacterium Tc-Br11_B2g6_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodothermaceaeBacteriumTcBr11B2g67", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729468.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729468.protein.info.v11.5.txt",
		        "node_list_path": "1729468.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerolineaeBacteriumCg2305767(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium CG2_30_57_67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaeBacteriumCg2305767", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805003.protein.info.v11.5.txt",
		        "node_list_path": "1805003.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsphigho201Full4827Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_01_FULL_48_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho201Full4827Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802115.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802115.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802115.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802115.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802115.protein.info.v11.5.txt",
		        "node_list_path": "1802115.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802115.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusAetherivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus aetherivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusAetherivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "191292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "191292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "191292.clusters.proteins.v11.5.txt",
		        "sequence_path": "191292.protein.sequences.v11.5.fa",
		        "enrichment_path": "191292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "191292.protein.info.v11.5.txt",
		        "node_list_path": "191292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "191292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterGlacincolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter glacincola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterGlacincolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "56810.clusters.info.v11.5.txt",
		        "cluster_tree_path": "56810.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "56810.clusters.proteins.v11.5.txt",
		        "sequence_path": "56810.protein.sequences.v11.5.fa",
		        "enrichment_path": "56810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56810.protein.info.v11.5.txt",
		        "node_list_path": "56810.cluster.nodes.v11.5.txt",
		        "edge_list_path": "56810.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronorubrumThiooxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronorubrum thiooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronorubrumThiooxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "308853.protein.sequences.v11.5.fa",
		        "enrichment_path": "308853.protein.enrichment.terms.v11.5.txt",
		        "info_path": "308853.protein.info.v11.5.txt",
		        "node_list_path": "308853.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteiniphilumSpEbm39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteiniphilum sp. EBM-39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteiniphilumSpEbm39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1918497.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1918497.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1918497.clusters.proteins.v11.5.txt",
		        "sequence_path": "1918497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918497.protein.info.v11.5.txt",
		        "node_list_path": "1918497.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1918497.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4214(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_42_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4214", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802068.protein.info.v11.5.txt",
		        "node_list_path": "1802068.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophobotulusGlycolicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophobotulus glycolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophobotulusGlycolicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "645991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "645991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "645991.clusters.proteins.v11.5.txt",
		        "sequence_path": "645991.protein.sequences.v11.5.fa",
		        "enrichment_path": "645991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645991.protein.info.v11.5.txt",
		        "node_list_path": "645991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "645991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprobacillusCateniformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus cateniformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprobacillusCateniformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "100884.protein.sequences.v11.5.fa",
		        "enrichment_path": "100884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "100884.protein.info.v11.5.txt",
		        "node_list_path": "100884.protein.complete.v11.5.txt"
		    }
		]
    )()

def LitoreibacterAlbidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Litoreibacter albidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LitoreibacterAlbidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "670155.protein.sequences.v11.5.fa",
		        "enrichment_path": "670155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670155.protein.info.v11.5.txt",
		        "node_list_path": "670155.protein.complete.v11.5.txt"
		    }
		]
    )()

def NosocomiicoccusAmpullaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nosocomiicoccus ampullae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NosocomiicoccusAmpullaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "489910.clusters.info.v11.5.txt",
		        "cluster_tree_path": "489910.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "489910.clusters.proteins.v11.5.txt",
		        "sequence_path": "489910.protein.sequences.v11.5.fa",
		        "enrichment_path": "489910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "489910.protein.info.v11.5.txt",
		        "node_list_path": "489910.cluster.nodes.v11.5.txt",
		        "edge_list_path": "489910.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp2714(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 27_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp2714", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896979.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896979.protein.info.v11.5.txt",
		        "node_list_path": "1896979.protein.complete.v11.5.txt"
		    }
		]
    )()

def StagonosporaSpSrc1lsm3a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stagonospora sp. SRC1lsM3a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StagonosporaSpSrc1lsm3a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765868.protein.sequences.v11.5.fa",
		        "enrichment_path": "765868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765868.protein.info.v11.5.txt",
		        "node_list_path": "765868.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanococcusVoltaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanococcus voltae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanococcusVoltaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "456320.clusters.info.v11.5.txt",
		        "cluster_tree_path": "456320.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "456320.clusters.proteins.v11.5.txt",
		        "sequence_path": "456320.protein.sequences.v11.5.fa",
		        "enrichment_path": "456320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "456320.protein.info.v11.5.txt",
		        "node_list_path": "456320.cluster.nodes.v11.5.txt",
		        "edge_list_path": "456320.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumPusillumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium pusillum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumPusillumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69373.clusters.proteins.v11.5.txt",
		        "sequence_path": "69373.protein.sequences.v11.5.fa",
		        "enrichment_path": "69373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69373.protein.info.v11.5.txt",
		        "node_list_path": "69373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrilyobacterAtlanticusDsm19335(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrilyobacter atlanticus DSM 19335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrilyobacterAtlanticusDsm19335", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123032.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123032.protein.info.v11.5.txt",
		        "node_list_path": "1123032.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhycicoccusSpRoot563Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Root563 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycicoccusSpRoot563Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736562.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736562.protein.info.v11.5.txt",
		        "node_list_path": "1736562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalotheceSpPcc7418Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halothece sp. PCC7418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalotheceSpPcc7418Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "65093.clusters.info.v11.5.txt",
		        "cluster_tree_path": "65093.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "65093.clusters.proteins.v11.5.txt",
		        "sequence_path": "65093.protein.sequences.v11.5.fa",
		        "enrichment_path": "65093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65093.protein.info.v11.5.txt",
		        "node_list_path": "65093.cluster.nodes.v11.5.txt",
		        "edge_list_path": "65093.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumSpLk11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium sp. LK11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumSpLk11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1628212.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628212.protein.info.v11.5.txt",
		        "node_list_path": "1628212.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAc2012(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAc2012", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392494.protein.info.v11.5.txt",
		        "node_list_path": "1392494.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasNoxiaF0398(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas noxia F0398 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasNoxiaF0398", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "702437.protein.sequences.v11.5.fa",
		        "enrichment_path": "702437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702437.protein.info.v11.5.txt",
		        "node_list_path": "702437.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusThermodenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus thermodenitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusThermodenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "420246.protein.sequences.v11.5.fa",
		        "enrichment_path": "420246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420246.protein.info.v11.5.txt",
		        "node_list_path": "420246.protein.complete.v11.5.txt"
		    }
		]
    )()

def HammondiaHammondi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hammondia hammondi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HammondiaHammondi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "99158.protein.sequences.v11.5.fa",
		        "enrichment_path": "99158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "99158.protein.info.v11.5.txt",
		        "node_list_path": "99158.protein.complete.v11.5.txt"
		    }
		]
    )()

def PediculusHumanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pediculus humanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediculusHumanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "121225.clusters.info.v11.5.txt",
		        "cluster_tree_path": "121225.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "121225.clusters.proteins.v11.5.txt",
		        "sequence_path": "121225.protein.sequences.v11.5.fa",
		        "enrichment_path": "121225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121225.protein.info.v11.5.txt",
		        "node_list_path": "121225.cluster.nodes.v11.5.txt",
		        "edge_list_path": "121225.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFuchuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fuchuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFuchuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423747.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423747.protein.info.v11.5.txt",
		        "node_list_path": "1423747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusWarneriSg1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus warneri SG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusWarneriSg1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1194526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1194526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1194526.clusters.proteins.v11.5.txt",
		        "sequence_path": "1194526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194526.protein.info.v11.5.txt",
		        "node_list_path": "1194526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1194526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacticigeniumNaphtaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lacticigenium naphtae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacticigeniumNaphtaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122143.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122143.protein.info.v11.5.txt",
		        "node_list_path": "1122143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MerionesUnguiculatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meriones unguiculatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MerionesUnguiculatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10047.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10047.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10047.clusters.proteins.v11.5.txt",
		        "sequence_path": "10047.protein.sequences.v11.5.fa",
		        "enrichment_path": "10047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10047.protein.info.v11.5.txt",
		        "node_list_path": "10047.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10047.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychromonasArcticaDsm14288(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas arctica DSM 14288 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychromonasArcticaDsm14288", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123036.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123036.protein.info.v11.5.txt",
		        "node_list_path": "1123036.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpSph12015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Sph1(2015) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpSph12015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1628084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1628084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1628084.clusters.proteins.v11.5.txt",
		        "sequence_path": "1628084.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628084.protein.info.v11.5.txt",
		        "node_list_path": "1628084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1628084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonasCompostiDsm21721(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas composti DSM 21721 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasCompostiDsm21721", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121349.protein.info.v11.5.txt",
		        "node_list_path": "1121349.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusHelveticusCnrz32(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus CNRZ32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHelveticusCnrz32", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326425.protein.sequences.v11.5.fa",
		        "enrichment_path": "326425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326425.protein.info.v11.5.txt",
		        "node_list_path": "326425.protein.complete.v11.5.txt"
		    }
		]
    )()

def HeterobasidionIrregulare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Heterobasidion irregulare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeterobasidionIrregulare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "984962.protein.sequences.v11.5.fa",
		        "enrichment_path": "984962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "984962.protein.info.v11.5.txt",
		        "node_list_path": "984962.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusLacrimalisDsm7455Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus lacrimalis DSM 7455 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusLacrimalisDsm7455Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122949.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122949.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122949.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122949.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122949.protein.info.v11.5.txt",
		        "node_list_path": "1122949.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122949.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophaceaeBacteriumCg2304912Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophaceae bacterium CG2_30_49_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophaceaeBacteriumCg2304912Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805377.protein.info.v11.5.txt",
		        "node_list_path": "1805377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumOlb12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumOlb12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619897.protein.info.v11.5.txt",
		        "node_list_path": "1619897.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsphigho212Full4219Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_12_FULL_42_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho212Full4219Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801762.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801762.protein.info.v11.5.txt",
		        "node_list_path": "1801762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParachlamydiaAcanthamoebaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parachlamydia acanthamoebae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParachlamydiaAcanthamoebaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765952.clusters.proteins.v11.5.txt",
		        "sequence_path": "765952.protein.sequences.v11.5.fa",
		        "enrichment_path": "765952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765952.protein.info.v11.5.txt",
		        "node_list_path": "765952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BorreliaParkeri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia parkeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaParkeri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1313294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313294.protein.info.v11.5.txt",
		        "node_list_path": "1313294.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumPlurifariumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium plurifarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumPlurifariumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69974.clusters.proteins.v11.5.txt",
		        "sequence_path": "69974.protein.sequences.v11.5.fa",
		        "enrichment_path": "69974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69974.protein.info.v11.5.txt",
		        "node_list_path": "69974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarmoricolaSpLeaf446(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marmoricola sp. Leaf446 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarmoricolaSpLeaf446", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736379.protein.info.v11.5.txt",
		        "node_list_path": "1736379.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotaleaMetallivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotalea metallivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotaleaMetallivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "520762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "520762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "520762.clusters.proteins.v11.5.txt",
		        "sequence_path": "520762.protein.sequences.v11.5.fa",
		        "enrichment_path": "520762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "520762.protein.info.v11.5.txt",
		        "node_list_path": "520762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "520762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DietziaAlimentariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dietzia alimentaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DietziaAlimentariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1077144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1077144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1077144.clusters.proteins.v11.5.txt",
		        "sequence_path": "1077144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077144.protein.info.v11.5.txt",
		        "node_list_path": "1077144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1077144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DerxiaLacustrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Derxia lacustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DerxiaLacustrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "764842.clusters.info.v11.5.txt",
		        "cluster_tree_path": "764842.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "764842.clusters.proteins.v11.5.txt",
		        "sequence_path": "764842.protein.sequences.v11.5.fa",
		        "enrichment_path": "764842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "764842.protein.info.v11.5.txt",
		        "node_list_path": "764842.cluster.nodes.v11.5.txt",
		        "edge_list_path": "764842.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloarculaVallismortis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula vallismortis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaVallismortis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28442.protein.sequences.v11.5.fa",
		        "enrichment_path": "28442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28442.protein.info.v11.5.txt",
		        "node_list_path": "28442.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrientiaTsutsugamushi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Orientia tsutsugamushi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrientiaTsutsugamushi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "357244.protein.sequences.v11.5.fa",
		        "enrichment_path": "357244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357244.protein.info.v11.5.txt",
		        "node_list_path": "357244.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProsthecobacterDebontiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prosthecobacter debontii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProsthecobacterDebontiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "48467.clusters.info.v11.5.txt",
		        "cluster_tree_path": "48467.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "48467.clusters.proteins.v11.5.txt",
		        "sequence_path": "48467.protein.sequences.v11.5.fa",
		        "enrichment_path": "48467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48467.protein.info.v11.5.txt",
		        "node_list_path": "48467.cluster.nodes.v11.5.txt",
		        "edge_list_path": "48467.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumHiranonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium hiranonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumHiranonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "500633.protein.sequences.v11.5.fa",
		        "enrichment_path": "500633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500633.protein.info.v11.5.txt",
		        "node_list_path": "500633.protein.complete.v11.5.txt"
		    }
		]
    )()

def NostocSpPcc7107Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocSpPcc7107Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "317936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "317936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "317936.clusters.proteins.v11.5.txt",
		        "sequence_path": "317936.protein.sequences.v11.5.fa",
		        "enrichment_path": "317936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "317936.protein.info.v11.5.txt",
		        "node_list_path": "317936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "317936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpX13sy08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. X13SY08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpX13sy08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1676616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1676616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1676616.clusters.proteins.v11.5.txt",
		        "sequence_path": "1676616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676616.protein.info.v11.5.txt",
		        "node_list_path": "1676616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1676616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrantheGuttataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythranthe guttata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrantheGuttataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4155.clusters.proteins.v11.5.txt",
		        "sequence_path": "4155.protein.sequences.v11.5.fa",
		        "enrichment_path": "4155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4155.protein.info.v11.5.txt",
		        "node_list_path": "4155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls646(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS646 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls646", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463917.protein.info.v11.5.txt",
		        "node_list_path": "1463917.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlbidiferaxSpOv413Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Albidiferax sp. OV413 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlbidiferaxSpOv413Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855285.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855285.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855285.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855285.protein.info.v11.5.txt",
		        "node_list_path": "1855285.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855285.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitiniphilusShinanonensisDsm23277Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitiniphilus shinanonensis DSM 23277 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitiniphilusShinanonensisDsm23277Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121280.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121280.protein.info.v11.5.txt",
		        "node_list_path": "1121280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwc23714Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_37_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc23714Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619046.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619046.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619046.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619046.protein.info.v11.5.txt",
		        "node_list_path": "1619046.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619046.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusSpA2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius sp. A-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusSpA2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1570360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570360.protein.info.v11.5.txt",
		        "node_list_path": "1570360.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRifoxyd12Full5323Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12_FULL_53_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12Full5323Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797903.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797903.protein.info.v11.5.txt",
		        "node_list_path": "1797903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterocytozoonBieneusiH348(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterocytozoon bieneusi H348 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterocytozoonBieneusiH348", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "481877.protein.sequences.v11.5.fa",
		        "enrichment_path": "481877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481877.protein.info.v11.5.txt",
		        "node_list_path": "481877.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylosarcinaFibrataAmlC10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylosarcina fibrata AML-C10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylosarcinaFibrataAmlC10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1132443.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1132443.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1132443.clusters.proteins.v11.5.txt",
		        "sequence_path": "1132443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1132443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1132443.protein.info.v11.5.txt",
		        "node_list_path": "1132443.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1132443.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LautropiaSpScn6989Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lautropia sp. SCN 69-89 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LautropiaSpScn6989Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660104.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660104.protein.info.v11.5.txt",
		        "node_list_path": "1660104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpRoot70(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpRoot70", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736590.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736590.protein.info.v11.5.txt",
		        "node_list_path": "1736590.protein.complete.v11.5.txt"
		    }
		]
    )()

def LamprocystisPurpureaDsm4197(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lamprocystis purpurea DSM 4197 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LamprocystisPurpureaDsm4197", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "765909.protein.sequences.v11.5.fa",
		        "enrichment_path": "765909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765909.protein.info.v11.5.txt",
		        "node_list_path": "765909.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzorhizobiumCaulinodans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azorhizobium caulinodans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzorhizobiumCaulinodans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "438753.protein.sequences.v11.5.fa",
		        "enrichment_path": "438753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "438753.protein.info.v11.5.txt",
		        "node_list_path": "438753.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeorickettsiaRisticii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neorickettsia risticii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeorickettsiaRisticii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "434131.protein.sequences.v11.5.fa",
		        "enrichment_path": "434131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "434131.protein.info.v11.5.txt",
		        "node_list_path": "434131.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaChukchiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia chukchiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaChukchiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641665.clusters.proteins.v11.5.txt",
		        "sequence_path": "641665.protein.sequences.v11.5.fa",
		        "enrichment_path": "641665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641665.protein.info.v11.5.txt",
		        "node_list_path": "641665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalonotiusSpJ07hn4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halonotius sp. J07HN4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalonotiusSpJ07hn4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1070774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1070774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1070774.protein.info.v11.5.txt",
		        "node_list_path": "1070774.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaNonliquefaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella nonliquefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaNonliquefaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "478.clusters.proteins.v11.5.txt",
		        "sequence_path": "478.protein.sequences.v11.5.fa",
		        "enrichment_path": "478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "478.protein.info.v11.5.txt",
		        "node_list_path": "478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BettaSplendensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Betta splendens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BettaSplendensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "158456.clusters.info.v11.5.txt",
		        "cluster_tree_path": "158456.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "158456.clusters.proteins.v11.5.txt",
		        "sequence_path": "158456.protein.sequences.v11.5.fa",
		        "enrichment_path": "158456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158456.protein.info.v11.5.txt",
		        "node_list_path": "158456.cluster.nodes.v11.5.txt",
		        "edge_list_path": "158456.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfoplanesFormicivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfoplanes formicivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfoplanesFormicivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1592317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1592317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1592317.clusters.proteins.v11.5.txt",
		        "sequence_path": "1592317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1592317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1592317.protein.info.v11.5.txt",
		        "node_list_path": "1592317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1592317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasOleovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas oleovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasOleovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "301.protein.sequences.v11.5.fa",
		        "enrichment_path": "301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "301.protein.info.v11.5.txt",
		        "node_list_path": "301.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumDamselaeSubspDamselaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium damselae subsp. damselae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumDamselaeSubspDamselaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "85581.clusters.info.v11.5.txt",
		        "cluster_tree_path": "85581.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "85581.clusters.proteins.v11.5.txt",
		        "sequence_path": "85581.protein.sequences.v11.5.fa",
		        "enrichment_path": "85581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85581.protein.info.v11.5.txt",
		        "node_list_path": "85581.cluster.nodes.v11.5.txt",
		        "edge_list_path": "85581.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkiellaCookevillensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkiella cookevillensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkiellaCookevillensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "437022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "437022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "437022.clusters.proteins.v11.5.txt",
		        "sequence_path": "437022.protein.sequences.v11.5.fa",
		        "enrichment_path": "437022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "437022.protein.info.v11.5.txt",
		        "node_list_path": "437022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "437022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusSenegalensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusSenegalensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033733.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033733.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033733.protein.info.v11.5.txt",
		        "node_list_path": "1033733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_42_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798377.protein.info.v11.5.txt",
		        "node_list_path": "1798377.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioMagneticusIfrc170Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio magneticus IFRC170 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioMagneticusIfrc170Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304872.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304872.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304872.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304872.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304872.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304872.protein.info.v11.5.txt",
		        "node_list_path": "1304872.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304872.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RahnellaAquatilisCip7865(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rahnella aquatilis CIP78.65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RahnellaAquatilisCip7865", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "745277.protein.sequences.v11.5.fa",
		        "enrichment_path": "745277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "745277.protein.info.v11.5.txt",
		        "node_list_path": "745277.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSymbiont(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia symbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSymbiont", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "656024.protein.sequences.v11.5.fa",
		        "enrichment_path": "656024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "656024.protein.info.v11.5.txt",
		        "node_list_path": "656024.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitratireductorAquibiodomusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitratireductor aquibiodomus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratireductorAquibiodomusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231185.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231185.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231185.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231185.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231185.protein.info.v11.5.txt",
		        "node_list_path": "1231185.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231185.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylophagaAminisulfidivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga aminisulfidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaAminisulfidivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1026882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1026882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1026882.clusters.proteins.v11.5.txt",
		        "sequence_path": "1026882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1026882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1026882.protein.info.v11.5.txt",
		        "node_list_path": "1026882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1026882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpRu33b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. RU33B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpRu33b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1907390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907390.protein.info.v11.5.txt",
		        "node_list_path": "1907390.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvencibacteriumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Provencibacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvencibacteriumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1841868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841868.protein.info.v11.5.txt",
		        "node_list_path": "1841868.protein.complete.v11.5.txt"
		    }
		]
    )()

def CupriavidusSpIdo(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. IDO graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusSpIdo", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1539142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1539142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1539142.protein.info.v11.5.txt",
		        "node_list_path": "1539142.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAidingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus aidingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAidingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121085.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121085.protein.info.v11.5.txt",
		        "node_list_path": "1121085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusDysgalactiaeEquisimilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae equisimilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDysgalactiaeEquisimilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "759913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "759913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "759913.clusters.proteins.v11.5.txt",
		        "sequence_path": "759913.protein.sequences.v11.5.fa",
		        "enrichment_path": "759913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759913.protein.info.v11.5.txt",
		        "node_list_path": "759913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "759913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSp3613(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. 36_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSp3613", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897001.protein.info.v11.5.txt",
		        "node_list_path": "1897001.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwa13330(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_33_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa13330", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618542.protein.info.v11.5.txt",
		        "node_list_path": "1618542.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasCuatrocienegasensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas cuatrocienegasensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCuatrocienegasensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "543360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "543360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "543360.clusters.proteins.v11.5.txt",
		        "sequence_path": "543360.protein.sequences.v11.5.fa",
		        "enrichment_path": "543360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "543360.protein.info.v11.5.txt",
		        "node_list_path": "543360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "543360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphibacillusXylanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amphibacillus xylanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphibacillusXylanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "698758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "698758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "698758.clusters.proteins.v11.5.txt",
		        "sequence_path": "698758.protein.sequences.v11.5.fa",
		        "enrichment_path": "698758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698758.protein.info.v11.5.txt",
		        "node_list_path": "698758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "698758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinicoccusAlkaliphilusDsm16010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus alkaliphilus DSM 16010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinicoccusAlkaliphilusDsm16010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123231.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123231.protein.info.v11.5.txt",
		        "node_list_path": "1123231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrospiraDefluviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira defluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraDefluviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "330214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "330214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "330214.clusters.proteins.v11.5.txt",
		        "sequence_path": "330214.protein.sequences.v11.5.fa",
		        "enrichment_path": "330214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "330214.protein.info.v11.5.txt",
		        "node_list_path": "330214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "330214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PilodermaCroceumF1598Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Piloderma croceum F 1598 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PilodermaCroceumF1598Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765440.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765440.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765440.clusters.proteins.v11.5.txt",
		        "sequence_path": "765440.protein.sequences.v11.5.fa",
		        "enrichment_path": "765440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765440.protein.info.v11.5.txt",
		        "node_list_path": "765440.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765440.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPhaeomarinobacterEctocarpiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phaeomarinobacter ectocarpi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPhaeomarinobacterEctocarpiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1458461.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1458461.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1458461.clusters.proteins.v11.5.txt",
		        "sequence_path": "1458461.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458461.protein.info.v11.5.txt",
		        "node_list_path": "1458461.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1458461.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpRoot420(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root420 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpRoot420", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736533.protein.info.v11.5.txt",
		        "node_list_path": "1736533.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudobacteroidesCellulosolvens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobacteroides cellulosolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobacteroidesCellulosolvens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398512.protein.sequences.v11.5.fa",
		        "enrichment_path": "398512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398512.protein.info.v11.5.txt",
		        "node_list_path": "398512.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumFreneyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium freneyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumFreneyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1287475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1287475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1287475.clusters.proteins.v11.5.txt",
		        "sequence_path": "1287475.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287475.protein.info.v11.5.txt",
		        "node_list_path": "1287475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1287475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasOryzihabitans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas oryzihabitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasOryzihabitans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47885.protein.sequences.v11.5.fa",
		        "enrichment_path": "47885.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47885.protein.info.v11.5.txt",
		        "node_list_path": "47885.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterHormaecheiSubspOharae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. oharae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterHormaecheiSubspOharae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "301102.protein.sequences.v11.5.fa",
		        "enrichment_path": "301102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "301102.protein.info.v11.5.txt",
		        "node_list_path": "301102.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudanabaenaSpPcc6802(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudanabaena sp. PCC6802 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudanabaenaSpPcc6802", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118173.protein.sequences.v11.5.fa",
		        "enrichment_path": "118173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118173.protein.info.v11.5.txt",
		        "node_list_path": "118173.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoraliomargaritaAkajimensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coraliomargarita akajimensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoraliomargaritaAkajimensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "583355.protein.sequences.v11.5.fa",
		        "enrichment_path": "583355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "583355.protein.info.v11.5.txt",
		        "node_list_path": "583355.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKryptoniumThompsoni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kryptonium thompsoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKryptoniumThompsoni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1633631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1633631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1633631.protein.info.v11.5.txt",
		        "node_list_path": "1633631.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSilageiJcm19001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus silagei JCM 19001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSilageiJcm19001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1302250.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1302250.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1302250.clusters.proteins.v11.5.txt",
		        "sequence_path": "1302250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302250.protein.info.v11.5.txt",
		        "node_list_path": "1302250.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1302250.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanoperedensNitroreducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanoperedens nitroreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanoperedensNitroreducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1392998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392998.protein.info.v11.5.txt",
		        "node_list_path": "1392998.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumCsp17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium CSP1-7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumCsp17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1576480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1576480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1576480.protein.info.v11.5.txt",
		        "node_list_path": "1576480.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfuritaleaHydrogenivoransSk43hCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfuritalea hydrogenivorans sk43H Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfuritaleaHydrogenivoransSk43hCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223802.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223802.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223802.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223802.protein.info.v11.5.txt",
		        "node_list_path": "1223802.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223802.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpNd2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ND2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpNd2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1347366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347366.protein.info.v11.5.txt",
		        "node_list_path": "1347366.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifoxyd1Full4124Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFOXYD1_FULL_41_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifoxyd1Full4124Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802094.protein.info.v11.5.txt",
		        "node_list_path": "1802094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaSpBmg111209Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia sp. BMG111209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaSpBmg111209Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1160137.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1160137.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1160137.clusters.proteins.v11.5.txt",
		        "sequence_path": "1160137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160137.protein.info.v11.5.txt",
		        "node_list_path": "1160137.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1160137.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantheraTigrisAltaica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Panthera tigris altaica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantheraTigrisAltaica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "74533.protein.sequences.v11.5.fa",
		        "enrichment_path": "74533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74533.protein.info.v11.5.txt",
		        "node_list_path": "74533.protein.complete.v11.5.txt"
		    }
		]
    )()

def MustelaPutoriusFuro(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mustela putorius furo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MustelaPutoriusFuro", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9669.protein.sequences.v11.5.fa",
		        "enrichment_path": "9669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9669.protein.info.v11.5.txt",
		        "node_list_path": "9669.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumCyclohexanicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium cyclohexanicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumCyclohexanicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "64702.protein.sequences.v11.5.fa",
		        "enrichment_path": "64702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64702.protein.info.v11.5.txt",
		        "node_list_path": "64702.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumFormicaceticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium formicaceticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumFormicaceticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1497.protein.info.v11.5.txt",
		        "node_list_path": "1497.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacterSpHtcc7211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter sp. HTCC7211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterSpHtcc7211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "439493.protein.sequences.v11.5.fa",
		        "enrichment_path": "439493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "439493.protein.info.v11.5.txt",
		        "node_list_path": "439493.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudophaeobacterArcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudophaeobacter arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudophaeobacterArcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999550.clusters.proteins.v11.5.txt",
		        "sequence_path": "999550.protein.sequences.v11.5.fa",
		        "enrichment_path": "999550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999550.protein.info.v11.5.txt",
		        "node_list_path": "999550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumRifcsphigho201Full4526(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPHIGHO2_01_FULL_45_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsphigho201Full4526", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817737.protein.info.v11.5.txt",
		        "node_list_path": "1817737.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalegentibacterSalegensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter salegens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterSalegensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "143223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "143223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "143223.clusters.proteins.v11.5.txt",
		        "sequence_path": "143223.protein.sequences.v11.5.fa",
		        "enrichment_path": "143223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "143223.protein.info.v11.5.txt",
		        "node_list_path": "143223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "143223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhasianusColchicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phasianus colchicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhasianusColchicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9054.clusters.proteins.v11.5.txt",
		        "sequence_path": "9054.protein.sequences.v11.5.fa",
		        "enrichment_path": "9054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9054.protein.info.v11.5.txt",
		        "node_list_path": "9054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpUcdGka(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UCD-GKA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpUcdGka", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1913576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1913576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1913576.protein.info.v11.5.txt",
		        "node_list_path": "1913576.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinimicrobiaBacteriumJgi0000039D08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium JGI 0000039-D08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinimicrobiaBacteriumJgi0000039D08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1047055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1047055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1047055.protein.info.v11.5.txt",
		        "node_list_path": "1047055.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorogloeopsisFritschii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorogloeopsis fritschii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorogloeopsisFritschii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "211165.protein.sequences.v11.5.fa",
		        "enrichment_path": "211165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211165.protein.info.v11.5.txt",
		        "node_list_path": "211165.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasAnticariensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas anticariensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasAnticariensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121939.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121939.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121939.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121939.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121939.protein.info.v11.5.txt",
		        "node_list_path": "1121939.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121939.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusZymaeDsm19395(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus zymae DSM 19395 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusZymaeDsm19395", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423817.protein.info.v11.5.txt",
		        "node_list_path": "1423817.protein.complete.v11.5.txt"
		    }
		]
    )()

def AsticcacaulisBenevestitusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asticcacaulis benevestitus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsticcacaulisBenevestitusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121022.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121022.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121022.protein.info.v11.5.txt",
		        "node_list_path": "1121022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSpChkci003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. CHKCI003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpChkci003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1780376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1780376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1780376.clusters.proteins.v11.5.txt",
		        "sequence_path": "1780376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780376.protein.info.v11.5.txt",
		        "node_list_path": "1780376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1780376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumChabaudi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium chabaudi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumChabaudi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5825.protein.sequences.v11.5.fa",
		        "enrichment_path": "5825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5825.protein.info.v11.5.txt",
		        "node_list_path": "5825.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoleophilumAlbumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoleophilum album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoleophilumAlbumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29539.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29539.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29539.clusters.proteins.v11.5.txt",
		        "sequence_path": "29539.protein.sequences.v11.5.fa",
		        "enrichment_path": "29539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29539.protein.info.v11.5.txt",
		        "node_list_path": "29539.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29539.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSp6736Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 67-36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSp6736Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895849.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895849.protein.info.v11.5.txt",
		        "node_list_path": "1895849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterSpLa11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. LA11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterSpLa11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1898176.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898176.protein.info.v11.5.txt",
		        "node_list_path": "1898176.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusAnaerobius653l(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius 653L graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusAnaerobius653l", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "596329.protein.sequences.v11.5.fa",
		        "enrichment_path": "596329.protein.enrichment.terms.v11.5.txt",
		        "info_path": "596329.protein.info.v11.5.txt",
		        "node_list_path": "596329.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterDelicatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter delicatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterDelicatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "218672.protein.sequences.v11.5.fa",
		        "enrichment_path": "218672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218672.protein.info.v11.5.txt",
		        "node_list_path": "218672.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterDefluviiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter defluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterDefluviiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385515.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385515.protein.info.v11.5.txt",
		        "node_list_path": "1385515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumRifoxyc12Full6016(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium RIFOXYC12_FULL_60_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumRifoxyc12Full6016", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798582.protein.info.v11.5.txt",
		        "node_list_path": "1798582.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedRoseburiaSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Roseburia sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedRoseburiaSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "512314.protein.sequences.v11.5.fa",
		        "enrichment_path": "512314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512314.protein.info.v11.5.txt",
		        "node_list_path": "512314.protein.complete.v11.5.txt"
		    }
		]
    )()

def RalstoniaSolanacearumGmi1000(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum GMI1000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSolanacearumGmi1000", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "267608.protein.sequences.v11.5.fa",
		        "enrichment_path": "267608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267608.protein.info.v11.5.txt",
		        "node_list_path": "267608.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumTf0111(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium TF01-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumTf0111", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703332.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703332.protein.info.v11.5.txt",
		        "node_list_path": "1703332.protein.complete.v11.5.txt"
		    }
		]
    )()

def RheinheimeraPerlucidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera perlucida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraPerlucidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123054.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123054.protein.info.v11.5.txt",
		        "node_list_path": "1123054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifoxyc2Full4316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYC2_FULL_43_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyc2Full4316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801808.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801808.protein.info.v11.5.txt",
		        "node_list_path": "1801808.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumGorillaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium gorillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumGorillaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231063.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231063.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231063.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231063.protein.info.v11.5.txt",
		        "node_list_path": "1231063.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231063.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AequorivitaSublithincolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aequorivita sublithincola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AequorivitaSublithincolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "746697.clusters.info.v11.5.txt",
		        "cluster_tree_path": "746697.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "746697.clusters.proteins.v11.5.txt",
		        "sequence_path": "746697.protein.sequences.v11.5.fa",
		        "enrichment_path": "746697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "746697.protein.info.v11.5.txt",
		        "node_list_path": "746697.cluster.nodes.v11.5.txt",
		        "edge_list_path": "746697.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesUncialisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces uncialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesUncialisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1048205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1048205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1048205.clusters.proteins.v11.5.txt",
		        "sequence_path": "1048205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048205.protein.info.v11.5.txt",
		        "node_list_path": "1048205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1048205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobaculumLimnaeumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobaculum limnaeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobaculumLimnaeumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "274537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "274537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "274537.clusters.proteins.v11.5.txt",
		        "sequence_path": "274537.protein.sequences.v11.5.fa",
		        "enrichment_path": "274537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "274537.protein.info.v11.5.txt",
		        "node_list_path": "274537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "274537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumBdw918Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium BDW918 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumBdw918Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1168065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1168065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1168065.clusters.proteins.v11.5.txt",
		        "sequence_path": "1168065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168065.protein.info.v11.5.txt",
		        "node_list_path": "1168065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1168065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterSpMit115569(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT115569 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSpMit115569", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1548151.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548151.protein.info.v11.5.txt",
		        "node_list_path": "1548151.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKerfeldbacteriaBacteriumRifoxya2Full3824(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFOXYA2_FULL_38_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifoxya2Full3824", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798546.protein.info.v11.5.txt",
		        "node_list_path": "1798546.protein.complete.v11.5.txt"
		    }
		]
    )()

def NippostrongylusBrasiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nippostrongylus brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NippostrongylusBrasiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "27835.clusters.info.v11.5.txt",
		        "cluster_tree_path": "27835.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "27835.clusters.proteins.v11.5.txt",
		        "sequence_path": "27835.protein.sequences.v11.5.fa",
		        "enrichment_path": "27835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27835.protein.info.v11.5.txt",
		        "node_list_path": "27835.cluster.nodes.v11.5.txt",
		        "edge_list_path": "27835.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRiesiaPthiripubis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia pthiripubis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRiesiaPthiripubis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "428412.protein.sequences.v11.5.fa",
		        "enrichment_path": "428412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428412.protein.info.v11.5.txt",
		        "node_list_path": "428412.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaHaliotisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella haliotis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaHaliotisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236541.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236541.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236541.protein.info.v11.5.txt",
		        "node_list_path": "1236541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasSpGpe39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. GPE 39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasSpGpe39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1583099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1583099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1583099.clusters.proteins.v11.5.txt",
		        "sequence_path": "1583099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1583099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1583099.protein.info.v11.5.txt",
		        "node_list_path": "1583099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1583099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaSeeligeri12bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria seeligeri 12b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaSeeligeri12bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "683837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "683837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "683837.clusters.proteins.v11.5.txt",
		        "sequence_path": "683837.protein.sequences.v11.5.fa",
		        "enrichment_path": "683837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683837.protein.info.v11.5.txt",
		        "node_list_path": "683837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "683837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaylandiaZebra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Maylandia zebra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaylandiaZebra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "106582.protein.sequences.v11.5.fa",
		        "enrichment_path": "106582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106582.protein.info.v11.5.txt",
		        "node_list_path": "106582.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSimilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter similis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSimilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420916.protein.info.v11.5.txt",
		        "node_list_path": "1420916.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122921.protein.info.v11.5.txt",
		        "node_list_path": "1122921.protein.complete.v11.5.txt"
		    }
		]
    )()

def MizuhopectenYessoensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mizuhopecten yessoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MizuhopectenYessoensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6573.protein.sequences.v11.5.fa",
		        "enrichment_path": "6573.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6573.protein.info.v11.5.txt",
		        "node_list_path": "6573.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPhytoplasmaPruni(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma pruni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPhytoplasmaPruni", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "479893.protein.sequences.v11.5.fa",
		        "enrichment_path": "479893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479893.protein.info.v11.5.txt",
		        "node_list_path": "479893.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusSulfureusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sulfureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSulfureusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1140003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1140003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1140003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1140003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1140003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1140003.protein.info.v11.5.txt",
		        "node_list_path": "1140003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1140003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeotomaLepida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neotoma lepida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeotomaLepida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56216.protein.sequences.v11.5.fa",
		        "enrichment_path": "56216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56216.protein.info.v11.5.txt",
		        "node_list_path": "56216.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpYr460Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR460 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpYr460Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500290.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500290.protein.info.v11.5.txt",
		        "node_list_path": "1500290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PectobacteriumParmentieriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium parmentieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumParmentieriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1905730.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1905730.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1905730.clusters.proteins.v11.5.txt",
		        "sequence_path": "1905730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1905730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1905730.protein.info.v11.5.txt",
		        "node_list_path": "1905730.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1905730.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumProvencenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium provencense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumProvencenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1737425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1737425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1737425.clusters.proteins.v11.5.txt",
		        "sequence_path": "1737425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1737425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1737425.protein.info.v11.5.txt",
		        "node_list_path": "1737425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1737425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpP18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. P1.8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpP18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1699310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1699310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1699310.protein.info.v11.5.txt",
		        "node_list_path": "1699310.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaliangiumOchraceum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haliangium ochraceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaliangiumOchraceum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "502025.protein.sequences.v11.5.fa",
		        "enrichment_path": "502025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502025.protein.info.v11.5.txt",
		        "node_list_path": "502025.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag609Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:609 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag609Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262827.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262827.protein.info.v11.5.txt",
		        "node_list_path": "1262827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392877.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392877.protein.info.v11.5.txt",
		        "node_list_path": "1392877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PediococcusClaussenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus claussenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusClaussenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "701521.protein.sequences.v11.5.fa",
		        "enrichment_path": "701521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "701521.protein.info.v11.5.txt",
		        "node_list_path": "701521.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumImcc14465Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium IMCC14465 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumImcc14465Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220535.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220535.protein.info.v11.5.txt",
		        "node_list_path": "1220535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5135(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5135", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463858.protein.info.v11.5.txt",
		        "node_list_path": "1463858.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavihumibacterSolisilvaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavihumibacter solisilvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavihumibacterSolisilvaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349421.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349421.protein.info.v11.5.txt",
		        "node_list_path": "1349421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBiavatii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium biavatii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBiavatii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437608.protein.info.v11.5.txt",
		        "node_list_path": "1437608.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumChungangenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium chungangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumChungangenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1453505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1453505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1453505.clusters.proteins.v11.5.txt",
		        "sequence_path": "1453505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453505.protein.info.v11.5.txt",
		        "node_list_path": "1453505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1453505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterLwoffiiNctc5866Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii NCTC 5866 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterLwoffiiNctc5866Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "981327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "981327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "981327.clusters.proteins.v11.5.txt",
		        "sequence_path": "981327.protein.sequences.v11.5.fa",
		        "enrichment_path": "981327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981327.protein.info.v11.5.txt",
		        "node_list_path": "981327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "981327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalimicrobiumFlavidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salimicrobium flavidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalimicrobiumFlavidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "570947.protein.sequences.v11.5.fa",
		        "enrichment_path": "570947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570947.protein.info.v11.5.txt",
		        "node_list_path": "570947.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf23338Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_33_38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf23338Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797342.protein.info.v11.5.txt",
		        "node_list_path": "1797342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RaoultellaOrnithinolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Raoultella ornithinolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RaoultellaOrnithinolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1286170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286170.protein.info.v11.5.txt",
		        "node_list_path": "1286170.protein.complete.v11.5.txt"
		    }
		]
    )()

def PontibacterLucknowensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter lucknowensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterLucknowensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1077936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1077936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1077936.clusters.proteins.v11.5.txt",
		        "sequence_path": "1077936.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077936.protein.info.v11.5.txt",
		        "node_list_path": "1077936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1077936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoccidioidesPosadasiiStrSilveira(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides posadasii str. Silveira graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesPosadasiiStrSilveira", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "443226.protein.sequences.v11.5.fa",
		        "enrichment_path": "443226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443226.protein.info.v11.5.txt",
		        "node_list_path": "443226.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc13822Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC1_38_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc13822Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618897.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618897.protein.info.v11.5.txt",
		        "node_list_path": "1618897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlj16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlj16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158762.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158762.protein.info.v11.5.txt",
		        "node_list_path": "1158762.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrobacterSpS77(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sp. S77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterSpS77", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1080067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1080067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1080067.protein.info.v11.5.txt",
		        "node_list_path": "1080067.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterLitoralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterLitoralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314225.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314225.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314225.clusters.proteins.v11.5.txt",
		        "sequence_path": "314225.protein.sequences.v11.5.fa",
		        "enrichment_path": "314225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314225.protein.info.v11.5.txt",
		        "node_list_path": "314225.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314225.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanistesCaeruleus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanistes caeruleus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanistesCaeruleus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "156563.protein.sequences.v11.5.fa",
		        "enrichment_path": "156563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156563.protein.info.v11.5.txt",
		        "node_list_path": "156563.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpBcH(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Bc-h graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpBcH", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1943632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1943632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1943632.protein.info.v11.5.txt",
		        "node_list_path": "1943632.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZootermopsisNevadensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zootermopsis nevadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZootermopsisNevadensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "136037.clusters.info.v11.5.txt",
		        "cluster_tree_path": "136037.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "136037.clusters.proteins.v11.5.txt",
		        "sequence_path": "136037.protein.sequences.v11.5.fa",
		        "enrichment_path": "136037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "136037.protein.info.v11.5.txt",
		        "node_list_path": "136037.cluster.nodes.v11.5.txt",
		        "edge_list_path": "136037.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharothrixEspanaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharothrix espanaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharothrixEspanaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1179773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1179773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1179773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1179773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179773.protein.info.v11.5.txt",
		        "node_list_path": "1179773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1179773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WoeseiaOceaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Woeseia oceani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WoeseiaOceaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1548547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1548547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1548547.clusters.proteins.v11.5.txt",
		        "sequence_path": "1548547.protein.sequences.v11.5.fa",
		        "enrichment_path": "1548547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1548547.protein.info.v11.5.txt",
		        "node_list_path": "1548547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1548547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoraxellaCapraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella caprae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaCapraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122244.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122244.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122244.protein.info.v11.5.txt",
		        "node_list_path": "1122244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SutterellaSpCag351Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sutterella sp. CAG:351 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SutterellaSpCag351Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262975.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262975.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262975.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262975.protein.info.v11.5.txt",
		        "node_list_path": "1262975.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262975.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpW8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. W8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpW8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "613199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "613199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "613199.clusters.proteins.v11.5.txt",
		        "sequence_path": "613199.protein.sequences.v11.5.fa",
		        "enrichment_path": "613199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "613199.protein.info.v11.5.txt",
		        "node_list_path": "613199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "613199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSp6113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 61-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSp6113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895780.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895780.protein.info.v11.5.txt",
		        "node_list_path": "1895780.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrococcusKukulkaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrococcus kukulkanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrococcusKukulkaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1609559.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1609559.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1609559.clusters.proteins.v11.5.txt",
		        "sequence_path": "1609559.protein.sequences.v11.5.fa",
		        "enrichment_path": "1609559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1609559.protein.info.v11.5.txt",
		        "node_list_path": "1609559.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1609559.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumVeterumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium veterum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumVeterumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "408577.clusters.info.v11.5.txt",
		        "cluster_tree_path": "408577.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "408577.clusters.proteins.v11.5.txt",
		        "sequence_path": "408577.protein.sequences.v11.5.fa",
		        "enrichment_path": "408577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408577.protein.info.v11.5.txt",
		        "node_list_path": "408577.cluster.nodes.v11.5.txt",
		        "edge_list_path": "408577.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumChaponense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium chaponense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumChaponense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "713588.protein.sequences.v11.5.fa",
		        "enrichment_path": "713588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713588.protein.info.v11.5.txt",
		        "node_list_path": "713588.protein.complete.v11.5.txt"
		    }
		]
    )()

def HafniaAlvei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hafnia alvei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HafniaAlvei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1453496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453496.protein.info.v11.5.txt",
		        "node_list_path": "1453496.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusHerbarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus herbarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHerbarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1670446.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1670446.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1670446.clusters.proteins.v11.5.txt",
		        "sequence_path": "1670446.protein.sequences.v11.5.fa",
		        "enrichment_path": "1670446.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1670446.protein.info.v11.5.txt",
		        "node_list_path": "1670446.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1670446.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagnetobacteriumCasensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magnetobacterium casensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagnetobacteriumCasensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1455061.protein.sequences.v11.5.fa",
		        "enrichment_path": "1455061.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1455061.protein.info.v11.5.txt",
		        "node_list_path": "1455061.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasNoxiaAtcc43541(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas noxia ATCC43541 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasNoxiaAtcc43541", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585503.protein.sequences.v11.5.fa",
		        "enrichment_path": "585503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585503.protein.info.v11.5.txt",
		        "node_list_path": "585503.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobacterSpRoot1221(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root1221 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobacterSpRoot1221", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736433.protein.info.v11.5.txt",
		        "node_list_path": "1736433.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumMortiferumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium mortiferum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumMortiferumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469616.clusters.proteins.v11.5.txt",
		        "sequence_path": "469616.protein.sequences.v11.5.fa",
		        "enrichment_path": "469616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469616.protein.info.v11.5.txt",
		        "node_list_path": "469616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumHainanenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium hainanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumHainanenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52131.clusters.proteins.v11.5.txt",
		        "sequence_path": "52131.protein.sequences.v11.5.fa",
		        "enrichment_path": "52131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52131.protein.info.v11.5.txt",
		        "node_list_path": "52131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwa25646(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_56_46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwa25646", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797922.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797922.protein.info.v11.5.txt",
		        "node_list_path": "1797922.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaTropicalisMya3404(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida tropicalis MYA-3404 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaTropicalisMya3404", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "294747.protein.sequences.v11.5.fa",
		        "enrichment_path": "294747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294747.protein.info.v11.5.txt",
		        "node_list_path": "294747.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpWsm3983Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM3983 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpWsm3983Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1038867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1038867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1038867.clusters.proteins.v11.5.txt",
		        "sequence_path": "1038867.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038867.protein.info.v11.5.txt",
		        "node_list_path": "1038867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1038867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusGasseriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gasseri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusGasseriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "324831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "324831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "324831.clusters.proteins.v11.5.txt",
		        "sequence_path": "324831.protein.sequences.v11.5.fa",
		        "enrichment_path": "324831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "324831.protein.info.v11.5.txt",
		        "node_list_path": "324831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "324831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FonsecaeaPedrosoiCbs27137(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fonsecaea pedrosoi CBS 271.37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FonsecaeaPedrosoiCbs27137", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1442368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1442368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1442368.protein.info.v11.5.txt",
		        "node_list_path": "1442368.protein.complete.v11.5.txt"
		    }
		]
    )()

def DubosiellaNewyorkensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dubosiella newyorkensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DubosiellaNewyorkensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1862672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1862672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1862672.clusters.proteins.v11.5.txt",
		        "sequence_path": "1862672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1862672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1862672.protein.info.v11.5.txt",
		        "node_list_path": "1862672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1862672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtribacteriaBacterium34128(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atribacteria bacterium 34_128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtribacteriaBacterium34128", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635291.protein.info.v11.5.txt",
		        "node_list_path": "1635291.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyronemaOmphalodes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyronema omphalodes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyronemaOmphalodes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "337075.protein.sequences.v11.5.fa",
		        "enrichment_path": "337075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "337075.protein.info.v11.5.txt",
		        "node_list_path": "337075.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusHominisC80Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus hominis C80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusHominisC80Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "435837.clusters.info.v11.5.txt",
		        "cluster_tree_path": "435837.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "435837.clusters.proteins.v11.5.txt",
		        "sequence_path": "435837.protein.sequences.v11.5.fa",
		        "enrichment_path": "435837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435837.protein.info.v11.5.txt",
		        "node_list_path": "435837.cluster.nodes.v11.5.txt",
		        "edge_list_path": "435837.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaArundinaceumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma arundinaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaArundinaceumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "490622.clusters.info.v11.5.txt",
		        "cluster_tree_path": "490622.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "490622.clusters.proteins.v11.5.txt",
		        "sequence_path": "490622.protein.sequences.v11.5.fa",
		        "enrichment_path": "490622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "490622.protein.info.v11.5.txt",
		        "node_list_path": "490622.cluster.nodes.v11.5.txt",
		        "edge_list_path": "490622.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanocellaConradiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocella conradii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocellaConradiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1041930.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1041930.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1041930.clusters.proteins.v11.5.txt",
		        "sequence_path": "1041930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041930.protein.info.v11.5.txt",
		        "node_list_path": "1041930.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1041930.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaHarzianumCbs22695Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma harzianum CBS 226.95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaHarzianumCbs22695Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "983964.clusters.info.v11.5.txt",
		        "cluster_tree_path": "983964.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "983964.clusters.proteins.v11.5.txt",
		        "sequence_path": "983964.protein.sequences.v11.5.fa",
		        "enrichment_path": "983964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983964.protein.info.v11.5.txt",
		        "node_list_path": "983964.cluster.nodes.v11.5.txt",
		        "edge_list_path": "983964.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslr70331(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70331 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslr70331", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1536773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536773.protein.info.v11.5.txt",
		        "node_list_path": "1536773.protein.complete.v11.5.txt"
		    }
		]
    )()

def VulpesVulpesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vulpes vulpes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulpesVulpesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9627.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9627.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9627.clusters.proteins.v11.5.txt",
		        "sequence_path": "9627.protein.sequences.v11.5.fa",
		        "enrichment_path": "9627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9627.protein.info.v11.5.txt",
		        "node_list_path": "9627.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9627.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BotrytisCinereaBcdw1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Botrytis cinerea BcDW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BotrytisCinereaBcdw1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1290391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1290391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1290391.protein.info.v11.5.txt",
		        "node_list_path": "1290391.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionSr1BacteriumAalborgAaw1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division SR1 bacterium Aalborg_AAW-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionSr1BacteriumAalborgAaw1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1643353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643353.protein.info.v11.5.txt",
		        "node_list_path": "1643353.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg165418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_54_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797843.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797843.protein.info.v11.5.txt",
		        "node_list_path": "1797843.protein.complete.v11.5.txt"
		    }
		]
    )()

def OerskoviaTurbata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oerskovia turbata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OerskoviaTurbata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1713.protein.info.v11.5.txt",
		        "node_list_path": "1713.protein.complete.v11.5.txt"
		    }
		]
    )()

def AkkermansiaSpKle1797(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Akkermansia sp. KLE1797 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AkkermansiaSpKle1797", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1574264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1574264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1574264.protein.info.v11.5.txt",
		        "node_list_path": "1574264.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumPectinovorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium pectinovorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumPectinovorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29533.protein.sequences.v11.5.fa",
		        "enrichment_path": "29533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29533.protein.info.v11.5.txt",
		        "node_list_path": "29533.protein.complete.v11.5.txt"
		    }
		]
    )()

def SilicibacterLacuscaerulensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Silicibacter lacuscaerulensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SilicibacterLacuscaerulensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644107.protein.sequences.v11.5.fa",
		        "enrichment_path": "644107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644107.protein.info.v11.5.txt",
		        "node_list_path": "644107.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaProteobacteriumMlsDCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return delta proteobacterium MLS_D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaProteobacteriumMlsDCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1775673.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1775673.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1775673.clusters.proteins.v11.5.txt",
		        "sequence_path": "1775673.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775673.protein.info.v11.5.txt",
		        "node_list_path": "1775673.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1775673.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesViolens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces violens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesViolens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66377.protein.sequences.v11.5.fa",
		        "enrichment_path": "66377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66377.protein.info.v11.5.txt",
		        "node_list_path": "66377.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinospirillumCelere(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinospirillum celere graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinospirillumCelere", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122252.protein.info.v11.5.txt",
		        "node_list_path": "1122252.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizophagusIrregularisDaom181602Daom197198Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM 181602=DAOM 197198 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizophagusIrregularisDaom181602Daom197198Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "747089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "747089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "747089.clusters.proteins.v11.5.txt",
		        "sequence_path": "747089.protein.sequences.v11.5.fa",
		        "enrichment_path": "747089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747089.protein.info.v11.5.txt",
		        "node_list_path": "747089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "747089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumGeorgienseDsm11526(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium georgiense DSM 11526 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumGeorgienseDsm11526", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122198.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122198.protein.info.v11.5.txt",
		        "node_list_path": "1122198.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterHelveticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter helveticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterHelveticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28898.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28898.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28898.clusters.proteins.v11.5.txt",
		        "sequence_path": "28898.protein.sequences.v11.5.fa",
		        "enrichment_path": "28898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28898.protein.info.v11.5.txt",
		        "node_list_path": "28898.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28898.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArenimonasComposti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas composti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenimonasComposti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121013.protein.info.v11.5.txt",
		        "node_list_path": "1121013.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterHartonius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter hartonius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterHartonius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "425514.protein.sequences.v11.5.fa",
		        "enrichment_path": "425514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425514.protein.info.v11.5.txt",
		        "node_list_path": "425514.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollinsellaIhuae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collinsella ihuae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaIhuae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720204.protein.info.v11.5.txt",
		        "node_list_path": "1720204.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromicrobiumMarinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromicrobium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromicrobiumMarinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585531.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585531.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585531.clusters.proteins.v11.5.txt",
		        "sequence_path": "585531.protein.sequences.v11.5.fa",
		        "enrichment_path": "585531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585531.protein.info.v11.5.txt",
		        "node_list_path": "585531.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585531.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaAbyssalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina abyssalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaAbyssalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86102.clusters.proteins.v11.5.txt",
		        "sequence_path": "86102.protein.sequences.v11.5.fa",
		        "enrichment_path": "86102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86102.protein.info.v11.5.txt",
		        "node_list_path": "86102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BosGrunniensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bos grunniens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BosGrunniensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "30521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "30521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "30521.clusters.proteins.v11.5.txt",
		        "sequence_path": "30521.protein.sequences.v11.5.fa",
		        "enrichment_path": "30521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30521.protein.info.v11.5.txt",
		        "node_list_path": "30521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "30521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumReducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum reducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumReducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349161.protein.sequences.v11.5.fa",
		        "enrichment_path": "349161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349161.protein.info.v11.5.txt",
		        "node_list_path": "349161.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioNitratireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioNitratireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1255043.protein.sequences.v11.5.fa",
		        "enrichment_path": "1255043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1255043.protein.info.v11.5.txt",
		        "node_list_path": "1255043.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwb13910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618572.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618572.protein.info.v11.5.txt",
		        "node_list_path": "1618572.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpHu2014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. HU2014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpHu2014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1664275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1664275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1664275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1664275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1664275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1664275.protein.info.v11.5.txt",
		        "node_list_path": "1664275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1664275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesNordiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides nordii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesNordiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "997884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "997884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "997884.clusters.proteins.v11.5.txt",
		        "sequence_path": "997884.protein.sequences.v11.5.fa",
		        "enrichment_path": "997884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997884.protein.info.v11.5.txt",
		        "node_list_path": "997884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "997884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSp6146afaaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. 6146AFAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSp6146afaaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665942.clusters.proteins.v11.5.txt",
		        "sequence_path": "665942.protein.sequences.v11.5.fa",
		        "enrichment_path": "665942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665942.protein.info.v11.5.txt",
		        "node_list_path": "665942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MitsuariaSpPdc51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mitsuaria sp. PDC51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MitsuariaSpPdc51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881035.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881035.protein.info.v11.5.txt",
		        "node_list_path": "1881035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpHeli88(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. HelI88 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpHeli88", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1250006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1250006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1250006.protein.info.v11.5.txt",
		        "node_list_path": "1250006.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlbugoCandida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Albugo candida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlbugoCandida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "65357.protein.sequences.v11.5.fa",
		        "enrichment_path": "65357.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65357.protein.info.v11.5.txt",
		        "node_list_path": "65357.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumLipophiloflavumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium lipophiloflavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumLipophiloflavumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525263.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525263.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525263.clusters.proteins.v11.5.txt",
		        "sequence_path": "525263.protein.sequences.v11.5.fa",
		        "enrichment_path": "525263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525263.protein.info.v11.5.txt",
		        "node_list_path": "525263.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525263.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlaciecolaSp4h37ye5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola sp. 4H37YE5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaSp4h37ye5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "983545.protein.sequences.v11.5.fa",
		        "enrichment_path": "983545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "983545.protein.info.v11.5.txt",
		        "node_list_path": "983545.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitratifractorSalsuginis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitratifractor salsuginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitratifractorSalsuginis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "749222.protein.sequences.v11.5.fa",
		        "enrichment_path": "749222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "749222.protein.info.v11.5.txt",
		        "node_list_path": "749222.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaGlauca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora glauca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaGlauca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "928724.protein.sequences.v11.5.fa",
		        "enrichment_path": "928724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "928724.protein.info.v11.5.txt",
		        "node_list_path": "928724.protein.complete.v11.5.txt"
		    }
		]
    )()

def EggerthellaceaeBacteriumAt8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eggerthellaceae bacterium AT8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthellaceaeBacteriumAt8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1720315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1720315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1720315.clusters.proteins.v11.5.txt",
		        "sequence_path": "1720315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720315.protein.info.v11.5.txt",
		        "node_list_path": "1720315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1720315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WickerhamiellaSorbophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamiella sorbophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WickerhamiellaSorbophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45607.clusters.proteins.v11.5.txt",
		        "sequence_path": "45607.protein.sequences.v11.5.fa",
		        "enrichment_path": "45607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45607.protein.info.v11.5.txt",
		        "node_list_path": "45607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsphigho201Full4111Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_01_FULL_41_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho201Full4111Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797711.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797711.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797711.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797711.protein.info.v11.5.txt",
		        "node_list_path": "1797711.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797711.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylibiumPetroleiphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylibium petroleiphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylibiumPetroleiphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "420662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "420662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "420662.clusters.proteins.v11.5.txt",
		        "sequence_path": "420662.protein.sequences.v11.5.fa",
		        "enrichment_path": "420662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420662.protein.info.v11.5.txt",
		        "node_list_path": "420662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "420662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AndreprevotiaLacusDsm23236(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Andreprevotia lacus DSM 23236 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AndreprevotiaLacusDsm23236", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121001.protein.info.v11.5.txt",
		        "node_list_path": "1121001.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumColumnare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium columnare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumColumnare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041826.protein.info.v11.5.txt",
		        "node_list_path": "1041826.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFragi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fragi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFragi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1136138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1136138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1136138.protein.info.v11.5.txt",
		        "node_list_path": "1136138.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalanaerobiumPraevalens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halanaerobium praevalens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaerobiumPraevalens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "572479.protein.sequences.v11.5.fa",
		        "enrichment_path": "572479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572479.protein.info.v11.5.txt",
		        "node_list_path": "572479.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalieaceaeBacteriumImcc3088Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halieaceae bacterium IMCC3088 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalieaceaeBacteriumImcc3088Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2518989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2518989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2518989.clusters.proteins.v11.5.txt",
		        "sequence_path": "2518989.protein.sequences.v11.5.fa",
		        "enrichment_path": "2518989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2518989.protein.info.v11.5.txt",
		        "node_list_path": "2518989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2518989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpOk605(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. OK605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpOk605", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855317.protein.info.v11.5.txt",
		        "node_list_path": "1855317.protein.complete.v11.5.txt"
		    }
		]
    )()

def MoraxellaBovoculi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella bovoculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoraxellaBovoculi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743974.protein.sequences.v11.5.fa",
		        "enrichment_path": "743974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743974.protein.info.v11.5.txt",
		        "node_list_path": "743974.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryptosporidiumParvumIowaIiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporidium parvum Iowa II Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptosporidiumParvumIowaIiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "353152.clusters.info.v11.5.txt",
		        "cluster_tree_path": "353152.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "353152.clusters.proteins.v11.5.txt",
		        "sequence_path": "353152.protein.sequences.v11.5.fa",
		        "enrichment_path": "353152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "353152.protein.info.v11.5.txt",
		        "node_list_path": "353152.cluster.nodes.v11.5.txt",
		        "edge_list_path": "353152.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlloprevotellaRavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alloprevotella rava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloprevotellaRavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679199.clusters.proteins.v11.5.txt",
		        "sequence_path": "679199.protein.sequences.v11.5.fa",
		        "enrichment_path": "679199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679199.protein.info.v11.5.txt",
		        "node_list_path": "679199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumV9d3004(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium V9D3004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumV9d3004", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410632.protein.info.v11.5.txt",
		        "node_list_path": "1410632.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaGlumipatulaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza glumipatula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaGlumipatulaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40148.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40148.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40148.clusters.proteins.v11.5.txt",
		        "sequence_path": "40148.protein.sequences.v11.5.fa",
		        "enrichment_path": "40148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40148.protein.info.v11.5.txt",
		        "node_list_path": "40148.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40148.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumCsp18(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CSP1-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumCsp18", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1640514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640514.protein.info.v11.5.txt",
		        "node_list_path": "1640514.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquaspirillumSpLm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquaspirillum sp. LM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquaspirillumSpLm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1938604.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1938604.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1938604.clusters.proteins.v11.5.txt",
		        "sequence_path": "1938604.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938604.protein.info.v11.5.txt",
		        "node_list_path": "1938604.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1938604.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumPhenoxybenzoativoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium phenoxybenzoativorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumPhenoxybenzoativoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1592790.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1592790.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1592790.clusters.proteins.v11.5.txt",
		        "sequence_path": "1592790.protein.sequences.v11.5.fa",
		        "enrichment_path": "1592790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1592790.protein.info.v11.5.txt",
		        "node_list_path": "1592790.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1592790.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpBl107(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. BL107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpBl107", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313625.protein.sequences.v11.5.fa",
		        "enrichment_path": "313625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313625.protein.info.v11.5.txt",
		        "node_list_path": "313625.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterSpAbm4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter sp. AbM4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterSpAbm4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "224719.clusters.info.v11.5.txt",
		        "cluster_tree_path": "224719.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "224719.clusters.proteins.v11.5.txt",
		        "sequence_path": "224719.protein.sequences.v11.5.fa",
		        "enrichment_path": "224719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "224719.protein.info.v11.5.txt",
		        "node_list_path": "224719.cluster.nodes.v11.5.txt",
		        "edge_list_path": "224719.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GalerinaMarginataCbs33988(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Galerina marginata CBS 339.88 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GalerinaMarginataCbs33988", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "685588.protein.sequences.v11.5.fa",
		        "enrichment_path": "685588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "685588.protein.info.v11.5.txt",
		        "node_list_path": "685588.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho202Full4312Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_02_FULL_43_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho202Full4312Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802678.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802678.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802678.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802678.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802678.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802678.protein.info.v11.5.txt",
		        "node_list_path": "1802678.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802678.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OctadecabacterTemperatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Octadecabacter temperatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OctadecabacterTemperatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1458307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458307.protein.info.v11.5.txt",
		        "node_list_path": "1458307.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwp2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWP2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwp2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896216.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896216.protein.info.v11.5.txt",
		        "node_list_path": "1896216.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoecheraStricta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Boechera stricta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoecheraStricta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "72658.protein.sequences.v11.5.fa",
		        "enrichment_path": "72658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "72658.protein.info.v11.5.txt",
		        "node_list_path": "72658.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolyporusArculariusHhb13444Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polyporus arcularius HHB13444 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolyporusArculariusHhb13444Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1314778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1314778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1314778.clusters.proteins.v11.5.txt",
		        "sequence_path": "1314778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314778.protein.info.v11.5.txt",
		        "node_list_path": "1314778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1314778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisAtcc6249Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis ATCC6249 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisAtcc6249Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "864567.clusters.info.v11.5.txt",
		        "cluster_tree_path": "864567.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "864567.clusters.proteins.v11.5.txt",
		        "sequence_path": "864567.protein.sequences.v11.5.fa",
		        "enrichment_path": "864567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864567.protein.info.v11.5.txt",
		        "node_list_path": "864567.cluster.nodes.v11.5.txt",
		        "edge_list_path": "864567.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumSpYr522(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. YR522 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumSpYr522", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1144342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144342.protein.info.v11.5.txt",
		        "node_list_path": "1144342.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollinsellaVaginalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collinsella vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaVaginalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1870987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870987.protein.info.v11.5.txt",
		        "node_list_path": "1870987.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichophytonRubrumCbs118892Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton rubrum CBS 118892 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichophytonRubrumCbs118892Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "559305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "559305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "559305.clusters.proteins.v11.5.txt",
		        "sequence_path": "559305.protein.sequences.v11.5.fa",
		        "enrichment_path": "559305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559305.protein.info.v11.5.txt",
		        "node_list_path": "559305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "559305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisCga009(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris CGA009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisCga009", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "258594.protein.sequences.v11.5.fa",
		        "enrichment_path": "258594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "258594.protein.info.v11.5.txt",
		        "node_list_path": "258594.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaLactamica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria lactamica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaLactamica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "489653.protein.sequences.v11.5.fa",
		        "enrichment_path": "489653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "489653.protein.info.v11.5.txt",
		        "node_list_path": "489653.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpinaciaOleraceaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spinacia oleracea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpinaciaOleraceaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3562.clusters.proteins.v11.5.txt",
		        "sequence_path": "3562.protein.sequences.v11.5.fa",
		        "enrichment_path": "3562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3562.protein.info.v11.5.txt",
		        "node_list_path": "3562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterPolytrichastriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter polytrichastri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterPolytrichastriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1302689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1302689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1302689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1302689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1302689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1302689.protein.info.v11.5.txt",
		        "node_list_path": "1302689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1302689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MetallosphaeraSedulaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metallosphaera sedula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetallosphaeraSedulaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "399549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "399549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "399549.clusters.proteins.v11.5.txt",
		        "sequence_path": "399549.protein.sequences.v11.5.fa",
		        "enrichment_path": "399549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399549.protein.info.v11.5.txt",
		        "node_list_path": "399549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "399549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiothrixCaldifontisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix caldifontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiothrixCaldifontisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525918.clusters.proteins.v11.5.txt",
		        "sequence_path": "525918.protein.sequences.v11.5.fa",
		        "enrichment_path": "525918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525918.protein.info.v11.5.txt",
		        "node_list_path": "525918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BesnoitiaBesnoitiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Besnoitia besnoiti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BesnoitiaBesnoitiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "94643.clusters.info.v11.5.txt",
		        "cluster_tree_path": "94643.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "94643.clusters.proteins.v11.5.txt",
		        "sequence_path": "94643.protein.sequences.v11.5.fa",
		        "enrichment_path": "94643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94643.protein.info.v11.5.txt",
		        "node_list_path": "94643.cluster.nodes.v11.5.txt",
		        "edge_list_path": "94643.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterRuminantium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter ruminantium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterRuminantium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634498.protein.sequences.v11.5.fa",
		        "enrichment_path": "634498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634498.protein.info.v11.5.txt",
		        "node_list_path": "634498.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonasTerrigenaNbrc13299(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas terrigena NBRC 13299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasTerrigenaNbrc13299", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219032.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219032.protein.info.v11.5.txt",
		        "node_list_path": "1219032.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKryptobacterTengchongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kryptobacter tengchongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKryptobacterTengchongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1643429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643429.protein.info.v11.5.txt",
		        "node_list_path": "1643429.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAzambacteriaBacteriumRifoxyb1Full4033(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFOXYB1_FULL_40_33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifoxyb1Full4033", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797308.protein.info.v11.5.txt",
		        "node_list_path": "1797308.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrialbaAsiaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialba asiatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaAsiaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29540.clusters.proteins.v11.5.txt",
		        "sequence_path": "29540.protein.sequences.v11.5.fa",
		        "enrichment_path": "29540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29540.protein.info.v11.5.txt",
		        "node_list_path": "29540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemellaCuniculiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella cuniculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaCuniculiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121914.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121914.protein.info.v11.5.txt",
		        "node_list_path": "1121914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OpitutaceaeBacteriumTsb47(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TSB47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpitutaceaeBacteriumTsb47", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1184151.protein.sequences.v11.5.fa",
		        "enrichment_path": "1184151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1184151.protein.info.v11.5.txt",
		        "node_list_path": "1184151.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHimb55Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HIMB55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHimb55Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "745014.clusters.info.v11.0.txt",
		        "cluster_tree_path": "745014.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "745014.clusters.proteins.v11.0.txt",
		        "sequence_path": "745014.protein.sequences.v11.0.fa",
		        "enrichment_path": "745014.protein.enrichment.terms.v11.0.txt",
		        "info_path": "745014.protein.info.v11.0.txt",
		        "node_list_path": "745014.cluster.nodes.v11.0.txt",
		        "edge_list_path": "745014.protein.cluster.v11.0.txt"
		    }
		]
    )()

def NitrospiraeBacteriumCg10244142(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG1_02_44_142 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumCg10244142", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805276.protein.info.v11.5.txt",
		        "node_list_path": "1805276.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusAntranikianiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus antranikianii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusAntranikianiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123386.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123386.protein.info.v11.5.txt",
		        "node_list_path": "1123386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasPrydzensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas prydzensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasPrydzensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "182141.protein.sequences.v11.5.fa",
		        "enrichment_path": "182141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "182141.protein.info.v11.5.txt",
		        "node_list_path": "182141.protein.complete.v11.5.txt"
		    }
		]
    )()

def OpitutaceaeBacteriumTsb47Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TSB47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpitutaceaeBacteriumTsb47Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1184151.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1184151.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1184151.clusters.proteins.v11.5.txt",
		        "sequence_path": "1184151.protein.sequences.v11.5.fa",
		        "enrichment_path": "1184151.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1184151.protein.info.v11.5.txt",
		        "node_list_path": "1184151.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1184151.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusComposti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus composti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusComposti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423734.protein.info.v11.5.txt",
		        "node_list_path": "1423734.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacterSpCacia14h1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter sp. CACIA14H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterSpCacia14h1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408890.protein.info.v11.5.txt",
		        "node_list_path": "1408890.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5225Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_52_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5225Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798650.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798650.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798650.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798650.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798650.protein.info.v11.5.txt",
		        "node_list_path": "1798650.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798650.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FischerellaMuscicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fischerella muscicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FischerellaMuscicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "306281.protein.sequences.v11.5.fa",
		        "enrichment_path": "306281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306281.protein.info.v11.5.txt",
		        "node_list_path": "306281.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaSchoenbuchensisR1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella schoenbuchensis R1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSchoenbuchensisR1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "687861.protein.sequences.v11.5.fa",
		        "enrichment_path": "687861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "687861.protein.info.v11.5.txt",
		        "node_list_path": "687861.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumProfundum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium profundum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumProfundum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "298386.protein.sequences.v11.5.fa",
		        "enrichment_path": "298386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "298386.protein.info.v11.5.txt",
		        "node_list_path": "298386.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaSpDnf00869(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. DNF00869 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaSpDnf00869", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1384081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384081.protein.info.v11.5.txt",
		        "node_list_path": "1384081.protein.complete.v11.5.txt"
		    }
		]
    )()

def AminobacterSpRoot100Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aminobacter sp. Root100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AminobacterSpRoot100Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736420.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736420.protein.info.v11.5.txt",
		        "node_list_path": "1736420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProteiniborusEthanoligenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteiniborus ethanoligenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteiniborusEthanoligenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "415015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "415015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "415015.clusters.proteins.v11.5.txt",
		        "sequence_path": "415015.protein.sequences.v11.5.fa",
		        "enrichment_path": "415015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "415015.protein.info.v11.5.txt",
		        "node_list_path": "415015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "415015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArsenicicoccusSpOralTaxon190(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arsenicicoccus sp. oral taxon 190 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArsenicicoccusSpOralTaxon190", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658671.protein.info.v11.5.txt",
		        "node_list_path": "1658671.protein.complete.v11.5.txt"
		    }
		]
    )()

def PneumocystisJirovecii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PneumocystisJirovecii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42068.protein.sequences.v11.5.fa",
		        "enrichment_path": "42068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42068.protein.info.v11.5.txt",
		        "node_list_path": "42068.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfarculusBaarsiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfarculus baarsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfarculusBaarsiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "644282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "644282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "644282.clusters.proteins.v11.5.txt",
		        "sequence_path": "644282.protein.sequences.v11.5.fa",
		        "enrichment_path": "644282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644282.protein.info.v11.5.txt",
		        "node_list_path": "644282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "644282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSpLeaf216Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf216 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpLeaf216Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735684.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735684.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735684.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735684.protein.info.v11.5.txt",
		        "node_list_path": "1735684.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735684.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumMoukalabenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium moukalabense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumMoukalabenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1435051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1435051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1435051.clusters.proteins.v11.5.txt",
		        "sequence_path": "1435051.protein.sequences.v11.5.fa",
		        "enrichment_path": "1435051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1435051.protein.info.v11.5.txt",
		        "node_list_path": "1435051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1435051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaPeucetiaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora peucetia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaPeucetiaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47871.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47871.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47871.clusters.proteins.v11.5.txt",
		        "sequence_path": "47871.protein.sequences.v11.5.fa",
		        "enrichment_path": "47871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47871.protein.info.v11.5.txt",
		        "node_list_path": "47871.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47871.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CutaneotrichosporonOleaginosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cutaneotrichosporon oleaginosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CutaneotrichosporonOleaginosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "879819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "879819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "879819.clusters.proteins.v11.5.txt",
		        "sequence_path": "879819.protein.sequences.v11.5.fa",
		        "enrichment_path": "879819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879819.protein.info.v11.5.txt",
		        "node_list_path": "879819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "879819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AequorivitaCapsosiphonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aequorivita capsosiphonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AequorivitaCapsosiphonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120951.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120951.protein.info.v11.5.txt",
		        "node_list_path": "1120951.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumGwf24352(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWF2_43_52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumGwf24352", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801847.protein.info.v11.5.txt",
		        "node_list_path": "1801847.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaPerflava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria perflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaPerflava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33053.protein.sequences.v11.5.fa",
		        "enrichment_path": "33053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33053.protein.info.v11.5.txt",
		        "node_list_path": "33053.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaAsteroides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia asteroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAsteroides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1110697.protein.sequences.v11.5.fa",
		        "enrichment_path": "1110697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1110697.protein.info.v11.5.txt",
		        "node_list_path": "1110697.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChondromycesCrocatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chondromyces crocatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChondromycesCrocatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "52.clusters.info.v11.5.txt",
		        "cluster_tree_path": "52.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "52.clusters.proteins.v11.5.txt",
		        "sequence_path": "52.protein.sequences.v11.5.fa",
		        "enrichment_path": "52.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52.protein.info.v11.5.txt",
		        "node_list_path": "52.cluster.nodes.v11.5.txt",
		        "edge_list_path": "52.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloferulaSpBvorr071Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloferula sp. BvORR071 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloferulaSpBvorr071Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1396141.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1396141.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1396141.clusters.proteins.v11.5.txt",
		        "sequence_path": "1396141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1396141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1396141.protein.info.v11.5.txt",
		        "node_list_path": "1396141.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1396141.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStoquefichusSpSb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Stoquefichus sp. SB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStoquefichusSpSb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1658109.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1658109.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1658109.clusters.proteins.v11.5.txt",
		        "sequence_path": "1658109.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658109.protein.info.v11.5.txt",
		        "node_list_path": "1658109.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1658109.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1807753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1807753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1807753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1807753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807753.protein.info.v11.5.txt",
		        "node_list_path": "1807753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1807753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFslp40081Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLP40081 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFslp40081Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1536769.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1536769.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1536769.clusters.proteins.v11.5.txt",
		        "sequence_path": "1536769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536769.protein.info.v11.5.txt",
		        "node_list_path": "1536769.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1536769.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpSoil772(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. Soil772 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpSoil772", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736406.protein.info.v11.5.txt",
		        "node_list_path": "1736406.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpRoot483d1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. Root483D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpRoot483d1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736544.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736544.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736544.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736544.protein.info.v11.5.txt",
		        "node_list_path": "1736544.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736544.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpRoot265Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Root265 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpRoot265Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736504.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736504.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736504.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736504.protein.info.v11.5.txt",
		        "node_list_path": "1736504.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736504.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaColwelliana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella colwelliana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaColwelliana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "23.protein.sequences.v11.5.fa",
		        "enrichment_path": "23.protein.enrichment.terms.v11.5.txt",
		        "info_path": "23.protein.info.v11.5.txt",
		        "node_list_path": "23.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonasSpBrhC22Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. BRH_c22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasSpBrhC22Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1629710.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1629710.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1629710.clusters.proteins.v11.5.txt",
		        "sequence_path": "1629710.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629710.protein.info.v11.5.txt",
		        "node_list_path": "1629710.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1629710.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CronobacterSakazakiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter sakazakii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CronobacterSakazakiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28141.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28141.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28141.clusters.proteins.v11.5.txt",
		        "sequence_path": "28141.protein.sequences.v11.5.fa",
		        "enrichment_path": "28141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28141.protein.info.v11.5.txt",
		        "node_list_path": "28141.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28141.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterGlacialis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter glacialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterGlacialis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1908236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908236.protein.info.v11.5.txt",
		        "node_list_path": "1908236.protein.complete.v11.5.txt"
		    }
		]
    )()

def SparusAurataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sparus aurata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SparusAurataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8175.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8175.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8175.clusters.proteins.v11.5.txt",
		        "sequence_path": "8175.protein.sequences.v11.5.fa",
		        "enrichment_path": "8175.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8175.protein.info.v11.5.txt",
		        "node_list_path": "8175.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8175.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KerstersiaGyiorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kerstersia gyiorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KerstersiaGyiorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "206506.protein.sequences.v11.5.fa",
		        "enrichment_path": "206506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "206506.protein.info.v11.5.txt",
		        "node_list_path": "206506.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpJ37(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. J37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJ37", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935837.protein.sequences.v11.5.fa",
		        "enrichment_path": "935837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935837.protein.info.v11.5.txt",
		        "node_list_path": "935837.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZymobacterPalmaeDsm10491Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymobacter palmae DSM 10491 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZymobacterPalmaeDsm10491Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123510.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123510.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123510.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123510.protein.info.v11.5.txt",
		        "node_list_path": "1123510.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123510.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaCanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaCanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "493.clusters.info.v11.5.txt",
		        "cluster_tree_path": "493.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "493.clusters.proteins.v11.5.txt",
		        "sequence_path": "493.protein.sequences.v11.5.fa",
		        "enrichment_path": "493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "493.protein.info.v11.5.txt",
		        "node_list_path": "493.cluster.nodes.v11.5.txt",
		        "edge_list_path": "493.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifoxyb2Full4235(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFOXYB2_FULL_42_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2Full4235", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802580.protein.info.v11.5.txt",
		        "node_list_path": "1802580.protein.complete.v11.5.txt"
		    }
		]
    )()

def DacryopinaxPrimogenitus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dacryopinax primogenitus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DacryopinaxPrimogenitus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1858805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1858805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1858805.protein.info.v11.5.txt",
		        "node_list_path": "1858805.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpQxt31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. QXT-31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpQxt31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1357915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357915.protein.info.v11.5.txt",
		        "node_list_path": "1357915.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusMelliferCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mellifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMelliferCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218492.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218492.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218492.protein.info.v11.5.txt",
		        "node_list_path": "1218492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterSpRoot672Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. Root672 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterSpRoot672Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736584.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736584.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736584.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736584.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736584.protein.info.v11.5.txt",
		        "node_list_path": "1736584.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736584.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JeotgalibacaDankookensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalibaca dankookensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalibacaDankookensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "708126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "708126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "708126.clusters.proteins.v11.5.txt",
		        "sequence_path": "708126.protein.sequences.v11.5.fa",
		        "enrichment_path": "708126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "708126.protein.info.v11.5.txt",
		        "node_list_path": "708126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "708126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FulvimarinaPelagi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fulvimarina pelagi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FulvimarinaPelagi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314231.protein.sequences.v11.5.fa",
		        "enrichment_path": "314231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314231.protein.info.v11.5.txt",
		        "node_list_path": "314231.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaludibacteriumYongneupenseDsm18731(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paludibacterium yongneupense DSM 18731 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaludibacteriumYongneupenseDsm18731", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122928.protein.info.v11.5.txt",
		        "node_list_path": "1122928.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag557Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:557 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag557Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262819.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262819.protein.info.v11.5.txt",
		        "node_list_path": "1262819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HomoSapiens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Homo sapiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HomoSapiens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9606.protein.sequences.v11.5.fa",
		        "enrichment_path": "9606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9606.protein.info.v11.5.txt",
		        "node_list_path": "9606.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrorhabdusChilensisDsm12352(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus chilensis DSM 12352 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrorhabdusChilensisDsm12352", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123515.protein.info.v11.5.txt",
		        "node_list_path": "1123515.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSpCag324Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. CAG:324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSpCag324Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262969.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262969.protein.info.v11.5.txt",
		        "node_list_path": "1262969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSimulans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium simulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSimulans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "146827.protein.sequences.v11.5.fa",
		        "enrichment_path": "146827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146827.protein.info.v11.5.txt",
		        "node_list_path": "146827.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalothiobacillusSpLs2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halothiobacillus sp. LS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalothiobacillusSpLs2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1860122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1860122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1860122.clusters.proteins.v11.5.txt",
		        "sequence_path": "1860122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860122.protein.info.v11.5.txt",
		        "node_list_path": "1860122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1860122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusDarwinianus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus darwinianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusDarwinianus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380763.protein.info.v11.5.txt",
		        "node_list_path": "1380763.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumP6b14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium P6B14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumP6b14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410631.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410631.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410631.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410631.protein.info.v11.5.txt",
		        "node_list_path": "1410631.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410631.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptococcusGattiiVgiiR265(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus gattii VGII R265 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptococcusGattiiVgiiR265", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "294750.protein.sequences.v11.5.fa",
		        "enrichment_path": "294750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "294750.protein.info.v11.5.txt",
		        "node_list_path": "294750.protein.complete.v11.5.txt"
		    }
		]
    )()

def DyadobacterTibetensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter tibetensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyadobacterTibetensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434325.protein.info.v11.5.txt",
		        "node_list_path": "1434325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKuenenbacteriaBacteriumCg2303924(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium CG2_30_39_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumCg2303924", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805236.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805236.protein.info.v11.5.txt",
		        "node_list_path": "1805236.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlf5065Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5065 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlf5065Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463855.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463855.protein.info.v11.5.txt",
		        "node_list_path": "1463855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwa24512Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_45_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa24512Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797805.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797805.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797805.protein.info.v11.5.txt",
		        "node_list_path": "1797805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAviariusSubspAraffinosusDsm20653Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus aviarius subsp. araffinosus DSM 20653 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAviariusSubspAraffinosusDsm20653Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423820.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423820.protein.info.v11.5.txt",
		        "node_list_path": "1423820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyellaSpOk004Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyella sp. OK004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaSpOk004Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855292.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855292.protein.info.v11.5.txt",
		        "node_list_path": "1855292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesPsychrotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesPsychrotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005945.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005945.protein.info.v11.5.txt",
		        "node_list_path": "1005945.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf28Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf28Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735695.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735695.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735695.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735695.protein.info.v11.5.txt",
		        "node_list_path": "1735695.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735695.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VaribaculumCambrienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum cambriense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaribaculumCambrienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "184870.clusters.info.v11.5.txt",
		        "cluster_tree_path": "184870.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "184870.clusters.proteins.v11.5.txt",
		        "sequence_path": "184870.protein.sequences.v11.5.fa",
		        "enrichment_path": "184870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "184870.protein.info.v11.5.txt",
		        "node_list_path": "184870.cluster.nodes.v11.5.txt",
		        "edge_list_path": "184870.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioGenomospCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio genomosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioGenomospCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1187848.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1187848.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1187848.clusters.proteins.v11.5.txt",
		        "sequence_path": "1187848.protein.sequences.v11.5.fa",
		        "enrichment_path": "1187848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1187848.protein.info.v11.5.txt",
		        "node_list_path": "1187848.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1187848.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RomboutsiaLituseburensisDsm797(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Romboutsia lituseburensis DSM 797 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RomboutsiaLituseburensisDsm797", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121325.protein.info.v11.5.txt",
		        "node_list_path": "1121325.protein.complete.v11.5.txt"
		    }
		]
    )()

def OligellaUreolytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oligella ureolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OligellaUreolytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122619.protein.info.v11.5.txt",
		        "node_list_path": "1122619.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasBacteroidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas bacteroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasBacteroidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121124.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121124.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121124.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121124.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121124.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121124.protein.info.v11.5.txt",
		        "node_list_path": "1121124.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121124.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SetariaItalicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Setaria italica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SetariaItalicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4555.clusters.proteins.v11.5.txt",
		        "sequence_path": "4555.protein.sequences.v11.5.fa",
		        "enrichment_path": "4555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4555.protein.info.v11.5.txt",
		        "node_list_path": "4555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonadalesBacterium6970Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 69-70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonadalesBacterium6970Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895869.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895869.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895869.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895869.protein.info.v11.5.txt",
		        "node_list_path": "1895869.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895869.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalegentibacterSalinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salegentibacter salinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalegentibacterSalinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "447422.protein.sequences.v11.5.fa",
		        "enrichment_path": "447422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "447422.protein.info.v11.5.txt",
		        "node_list_path": "447422.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3719(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_37_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3719", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802514.protein.info.v11.5.txt",
		        "node_list_path": "1802514.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSp20gpm1509mCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. 20GPM1509m Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSp20gpm1509mCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380367.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380367.protein.info.v11.5.txt",
		        "node_list_path": "1380367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RodentibacterSpPpn85(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter sp. Ppn85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterSpPpn85", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1908525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908525.protein.info.v11.5.txt",
		        "node_list_path": "1908525.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpMusc14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. MUSC 14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpMusc14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1354889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1354889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1354889.protein.info.v11.5.txt",
		        "node_list_path": "1354889.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumCg2303430Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG2_30_34_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumCg2303430Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805160.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805160.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805160.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805160.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805160.protein.info.v11.5.txt",
		        "node_list_path": "1805160.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805160.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumClostridioforme2149faaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium clostridioforme 2149FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumClostridioforme2149faaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742735.clusters.proteins.v11.5.txt",
		        "sequence_path": "742735.protein.sequences.v11.5.fa",
		        "enrichment_path": "742735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742735.protein.info.v11.5.txt",
		        "node_list_path": "742735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminiclostridiumPapyrosolvensC7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminiclostridium papyrosolvens C7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminiclostridiumPapyrosolvensC7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1330534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1330534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1330534.protein.info.v11.5.txt",
		        "node_list_path": "1330534.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsplowo201Full3821Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_38_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3821Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798620.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798620.protein.info.v11.5.txt",
		        "node_list_path": "1798620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaGrayiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria grayi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaGrayiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525367.clusters.proteins.v11.5.txt",
		        "sequence_path": "525367.protein.sequences.v11.5.fa",
		        "enrichment_path": "525367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525367.protein.info.v11.5.txt",
		        "node_list_path": "525367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FischerellaSpPcc9339Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9339 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FischerellaSpPcc9339Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1174528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1174528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1174528.clusters.proteins.v11.5.txt",
		        "sequence_path": "1174528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1174528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1174528.protein.info.v11.5.txt",
		        "node_list_path": "1174528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1174528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaFlavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaFlavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095025.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095025.protein.info.v11.5.txt",
		        "node_list_path": "1095025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium6417(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 64-17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium6417", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895814.protein.info.v11.5.txt",
		        "node_list_path": "1895814.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLloydbacteriaBacteriumRifcsplowo202Full5111(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPLOWO2_02_FULL_51_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsplowo202Full5111", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798667.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798667.protein.info.v11.5.txt",
		        "node_list_path": "1798667.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsplowo201Full5916Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_59_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full5916Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802280.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802280.protein.info.v11.5.txt",
		        "node_list_path": "1802280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetrasphaeraJaponicaT1X7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera japonica T1-X7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrasphaeraJaponicaT1X7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1194083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194083.protein.info.v11.5.txt",
		        "node_list_path": "1194083.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasBatumiciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas batumici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasBatumiciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "226910.clusters.info.v11.5.txt",
		        "cluster_tree_path": "226910.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "226910.clusters.proteins.v11.5.txt",
		        "sequence_path": "226910.protein.sequences.v11.5.fa",
		        "enrichment_path": "226910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226910.protein.info.v11.5.txt",
		        "node_list_path": "226910.cluster.nodes.v11.5.txt",
		        "edge_list_path": "226910.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmobacterAquatilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmobacter aquatilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmobacterAquatilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "933059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "933059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "933059.clusters.proteins.v11.5.txt",
		        "sequence_path": "933059.protein.sequences.v11.5.fa",
		        "enrichment_path": "933059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "933059.protein.info.v11.5.txt",
		        "node_list_path": "933059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "933059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumGwb25436(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWB2_54_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumGwb25436", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797613.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797613.protein.info.v11.5.txt",
		        "node_list_path": "1797613.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterDaejeonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter daejeonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterDaejeonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385517.protein.info.v11.5.txt",
		        "node_list_path": "1385517.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag702(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:702 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag702", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262747.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262747.protein.info.v11.5.txt",
		        "node_list_path": "1262747.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesPaurosaccharolyticusJcm15092Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides paurosaccharolyticus JCM 15092 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesPaurosaccharolyticusJcm15092Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236498.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236498.protein.info.v11.5.txt",
		        "node_list_path": "1236498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UrsusAmericanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ursus americanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UrsusAmericanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9643.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9643.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9643.clusters.proteins.v11.5.txt",
		        "sequence_path": "9643.protein.sequences.v11.5.fa",
		        "enrichment_path": "9643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9643.protein.info.v11.5.txt",
		        "node_list_path": "9643.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9643.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumSpF0372(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium sp. F0372 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumSpF0372", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203605.protein.info.v11.5.txt",
		        "node_list_path": "1203605.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpUnc496mfCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNC496MF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpUnc496mfCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502753.protein.info.v11.5.txt",
		        "node_list_path": "1502753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterOleivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter oleivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterOleivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "436717.clusters.info.v11.5.txt",
		        "cluster_tree_path": "436717.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "436717.clusters.proteins.v11.5.txt",
		        "sequence_path": "436717.protein.sequences.v11.5.fa",
		        "enrichment_path": "436717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436717.protein.info.v11.5.txt",
		        "node_list_path": "436717.cluster.nodes.v11.5.txt",
		        "edge_list_path": "436717.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusHippeiDsm8344(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus hippei DSM 8344 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusHippeiDsm8344", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121419.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121419.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121419.protein.info.v11.5.txt",
		        "node_list_path": "1121419.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArsukibacteriumSpMj3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arsukibacterium sp. MJ3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArsukibacteriumSpMj3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1632859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1632859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1632859.protein.info.v11.5.txt",
		        "node_list_path": "1632859.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaIhumii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella ihumii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaIhumii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1917878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917878.protein.info.v11.5.txt",
		        "node_list_path": "1917878.protein.complete.v11.5.txt"
		    }
		]
    )()

def GillisiaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gillisia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GillisiaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1167637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1167637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1167637.clusters.proteins.v11.5.txt",
		        "sequence_path": "1167637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1167637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1167637.protein.info.v11.5.txt",
		        "node_list_path": "1167637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1167637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgibacterAquaticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algibacter aquaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgibacterAquaticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1849968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849968.protein.info.v11.5.txt",
		        "node_list_path": "1849968.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumOmnivorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium omnivorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumOmnivorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "178355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "178355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "178355.clusters.proteins.v11.5.txt",
		        "sequence_path": "178355.protein.sequences.v11.5.fa",
		        "enrichment_path": "178355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178355.protein.info.v11.5.txt",
		        "node_list_path": "178355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "178355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusEquigenerosiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus equigenerosi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusEquigenerosiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "417373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "417373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "417373.clusters.proteins.v11.5.txt",
		        "sequence_path": "417373.protein.sequences.v11.5.fa",
		        "enrichment_path": "417373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "417373.protein.info.v11.5.txt",
		        "node_list_path": "417373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "417373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumVentriosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium ventriosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumVentriosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "411463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "411463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "411463.clusters.proteins.v11.5.txt",
		        "sequence_path": "411463.protein.sequences.v11.5.fa",
		        "enrichment_path": "411463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411463.protein.info.v11.5.txt",
		        "node_list_path": "411463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "411463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumPiscinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium piscinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumPiscinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "686831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "686831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "686831.clusters.proteins.v11.5.txt",
		        "sequence_path": "686831.protein.sequences.v11.5.fa",
		        "enrichment_path": "686831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686831.protein.info.v11.5.txt",
		        "node_list_path": "686831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "686831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FervidicoccusFontis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fervidicoccus fontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidicoccusFontis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163730.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163730.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163730.protein.info.v11.5.txt",
		        "node_list_path": "1163730.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomonasSpFb6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas sp. FB-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomonasSpFb6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158291.protein.info.v11.5.txt",
		        "node_list_path": "1158291.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasMacacae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas macacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasMacacae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28115.protein.sequences.v11.5.fa",
		        "enrichment_path": "28115.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28115.protein.info.v11.5.txt",
		        "node_list_path": "28115.protein.complete.v11.5.txt"
		    }
		]
    )()

def CavenderiaFasciculataSh3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cavenderia fasciculata SH3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CavenderiaFasciculataSh3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1054147.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1054147.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1054147.clusters.proteins.v11.5.txt",
		        "sequence_path": "1054147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1054147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1054147.protein.info.v11.5.txt",
		        "node_list_path": "1054147.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1054147.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeraceosorusBombacisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ceraceosorus bombacis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeraceosorusBombacisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "401625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "401625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "401625.clusters.proteins.v11.5.txt",
		        "sequence_path": "401625.protein.sequences.v11.5.fa",
		        "enrichment_path": "401625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "401625.protein.info.v11.5.txt",
		        "node_list_path": "401625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "401625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumGranuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium granuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumGranuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "280093.clusters.info.v11.5.txt",
		        "cluster_tree_path": "280093.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "280093.clusters.proteins.v11.5.txt",
		        "sequence_path": "280093.protein.sequences.v11.5.fa",
		        "enrichment_path": "280093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "280093.protein.info.v11.5.txt",
		        "node_list_path": "280093.cluster.nodes.v11.5.txt",
		        "edge_list_path": "280093.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZetaproteobacteriaBacteriumCg1025345(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_53_45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaproteobacteriaBacteriumCg1025345", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805427.protein.info.v11.5.txt",
		        "node_list_path": "1805427.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonasJannaschianaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas jannaschiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasJannaschianaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280952.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280952.protein.info.v11.5.txt",
		        "node_list_path": "1280952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinovumAlgicolaDg898Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinovum algicola DG 898 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinovumAlgicolaDg898Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "988812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "988812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "988812.clusters.proteins.v11.5.txt",
		        "sequence_path": "988812.protein.sequences.v11.5.fa",
		        "enrichment_path": "988812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "988812.protein.info.v11.5.txt",
		        "node_list_path": "988812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "988812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaSpDiamantCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia sp. Diamant Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaSpDiamantCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1444711.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1444711.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1444711.clusters.proteins.v11.5.txt",
		        "sequence_path": "1444711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444711.protein.info.v11.5.txt",
		        "node_list_path": "1444711.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1444711.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubritepidaFlocculansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubritepida flocculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubritepidaFlocculansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123072.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123072.protein.info.v11.5.txt",
		        "node_list_path": "1123072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StomoxysCalcitransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stomoxys calcitrans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StomoxysCalcitransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "35570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "35570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "35570.clusters.proteins.v11.5.txt",
		        "sequence_path": "35570.protein.sequences.v11.5.fa",
		        "enrichment_path": "35570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35570.protein.info.v11.5.txt",
		        "node_list_path": "35570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "35570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSp6529Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSp6529Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895862.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895862.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895862.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895862.protein.info.v11.5.txt",
		        "node_list_path": "1895862.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895862.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteibacterRhizovicinusDsm16549(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter rhizovicinus DSM 16549 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteibacterRhizovicinusDsm16549", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1440763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1440763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1440763.protein.info.v11.5.txt",
		        "node_list_path": "1440763.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "199136.protein.sequences.v11.5.fa",
		        "enrichment_path": "199136.protein.enrichment.terms.v11.5.txt",
		        "info_path": "199136.protein.info.v11.5.txt",
		        "node_list_path": "199136.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalobacterSpCfCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalobacter sp. CF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalobacterSpCfCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1131462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1131462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1131462.clusters.proteins.v11.5.txt",
		        "sequence_path": "1131462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131462.protein.info.v11.5.txt",
		        "node_list_path": "1131462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1131462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SilvanigrellaAquaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Silvanigrella aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SilvanigrellaAquaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1915309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1915309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1915309.clusters.proteins.v11.5.txt",
		        "sequence_path": "1915309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915309.protein.info.v11.5.txt",
		        "node_list_path": "1915309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1915309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumCdBkt12695(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum CD BKT12695 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumCdBkt12695", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1443125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443125.protein.info.v11.5.txt",
		        "node_list_path": "1443125.protein.complete.v11.5.txt"
		    }
		]
    )()

def CronobacterDublinensisSubspLactaridiLmg23825(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. lactaridi LMG 23825 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CronobacterDublinensisSubspLactaridiLmg23825", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1159496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159496.protein.info.v11.5.txt",
		        "node_list_path": "1159496.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusAetherivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus aetherivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusAetherivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "191292.protein.sequences.v11.5.fa",
		        "enrichment_path": "191292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "191292.protein.info.v11.5.txt",
		        "node_list_path": "191292.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloligellaHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methyloligella halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloligellaHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1177755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1177755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1177755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1177755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177755.protein.info.v11.5.txt",
		        "node_list_path": "1177755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1177755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200251971Sch5477799A(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-51971_SCH5477799-a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200251971Sch5477799A", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834106.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834106.protein.info.v11.5.txt",
		        "node_list_path": "1834106.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full4019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_40_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full4019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798281.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798281.protein.info.v11.5.txt",
		        "node_list_path": "1798281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AbyssisolibacterFermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Abyssisolibacter fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AbyssisolibacterFermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1766203.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1766203.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1766203.clusters.proteins.v11.5.txt",
		        "sequence_path": "1766203.protein.sequences.v11.5.fa",
		        "enrichment_path": "1766203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1766203.protein.info.v11.5.txt",
		        "node_list_path": "1766203.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1766203.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumPalustre(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium palustre graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumPalustre", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "153971.protein.sequences.v11.5.fa",
		        "enrichment_path": "153971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "153971.protein.info.v11.5.txt",
		        "node_list_path": "153971.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalococcusSediminicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halococcus sediminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusSediminicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1264579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1264579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1264579.protein.info.v11.5.txt",
		        "node_list_path": "1264579.protein.complete.v11.5.txt"
		    }
		]
    )()

def WinogradskyellaSpPg2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Winogradskyella sp. PG-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinogradskyellaSpPg2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "754409.protein.sequences.v11.5.fa",
		        "enrichment_path": "754409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754409.protein.info.v11.5.txt",
		        "node_list_path": "754409.protein.complete.v11.5.txt"
		    }
		]
    )()

def GardnerellaVaginalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GardnerellaVaginalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2702.protein.sequences.v11.5.fa",
		        "enrichment_path": "2702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2702.protein.info.v11.5.txt",
		        "node_list_path": "2702.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpPbh53(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. PBH53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpPbh53", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577075.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577075.protein.info.v11.5.txt",
		        "node_list_path": "1577075.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaballeroniaHumiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaHumiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "326474.clusters.info.v11.5.txt",
		        "cluster_tree_path": "326474.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "326474.clusters.proteins.v11.5.txt",
		        "sequence_path": "326474.protein.sequences.v11.5.fa",
		        "enrichment_path": "326474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326474.protein.info.v11.5.txt",
		        "node_list_path": "326474.cluster.nodes.v11.5.txt",
		        "edge_list_path": "326474.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesPaurosaccharolyticusJcm15092(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides paurosaccharolyticus JCM 15092 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesPaurosaccharolyticusJcm15092", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236498.protein.info.v11.5.txt",
		        "node_list_path": "1236498.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterobacterSp638(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter sp. 638 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterSp638", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "399742.protein.sequences.v11.5.fa",
		        "enrichment_path": "399742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399742.protein.info.v11.5.txt",
		        "node_list_path": "399742.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSp63ed372Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 63ED37-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSp63ed372Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1678128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1678128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1678128.clusters.proteins.v11.5.txt",
		        "sequence_path": "1678128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678128.protein.info.v11.5.txt",
		        "node_list_path": "1678128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1678128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumFrediiHh103Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii HH103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumFrediiHh103Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1117943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1117943.clusters.proteins.v11.5.txt",
		        "sequence_path": "1117943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117943.protein.info.v11.5.txt",
		        "node_list_path": "1117943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1117943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumChungangense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium chungangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumChungangense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1453505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453505.protein.info.v11.5.txt",
		        "node_list_path": "1453505.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmphibacillusMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amphibacillus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphibacillusMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "872970.protein.sequences.v11.5.fa",
		        "enrichment_path": "872970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "872970.protein.info.v11.5.txt",
		        "node_list_path": "872970.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesPropionicifaciensDsm19291Jcm14649(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides propionicifaciens DSM 19291 JCM 14649 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesPropionicifaciensDsm19291Jcm14649", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121099.protein.info.v11.5.txt",
		        "node_list_path": "1121099.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfomicrobiumNorvegicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium norvegicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfomicrobiumNorvegicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52561.protein.sequences.v11.5.fa",
		        "enrichment_path": "52561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52561.protein.info.v11.5.txt",
		        "node_list_path": "52561.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag330(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag330", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262954.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262954.protein.info.v11.5.txt",
		        "node_list_path": "1262954.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeclerciaAdecarboxylata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leclercia adecarboxylata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeclerciaAdecarboxylata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "911008.protein.sequences.v11.5.fa",
		        "enrichment_path": "911008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "911008.protein.info.v11.5.txt",
		        "node_list_path": "911008.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermocrinisMinervae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermocrinis minervae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocrinisMinervae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "381751.protein.sequences.v11.5.fa",
		        "enrichment_path": "381751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "381751.protein.info.v11.5.txt",
		        "node_list_path": "381751.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaballeroniaPediCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia pedi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaPediCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1777141.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1777141.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1777141.clusters.proteins.v11.5.txt",
		        "sequence_path": "1777141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777141.protein.info.v11.5.txt",
		        "node_list_path": "1777141.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1777141.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MariniradiusSaccharolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mariniradius saccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MariniradiusSaccharolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1239962.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1239962.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1239962.clusters.proteins.v11.5.txt",
		        "sequence_path": "1239962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1239962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1239962.protein.info.v11.5.txt",
		        "node_list_path": "1239962.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1239962.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanoperedensNitroreducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanoperedens nitroreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanoperedensNitroreducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392998.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392998.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392998.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392998.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392998.protein.info.v11.5.txt",
		        "node_list_path": "1392998.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392998.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaPickettii12d(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia pickettii 12D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaPickettii12d", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "428406.protein.sequences.v11.5.fa",
		        "enrichment_path": "428406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428406.protein.info.v11.5.txt",
		        "node_list_path": "428406.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusVaginalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusVaginalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1756987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1756987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1756987.protein.info.v11.5.txt",
		        "node_list_path": "1756987.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaBronchialis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella bronchialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaBronchialis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "463025.protein.sequences.v11.5.fa",
		        "enrichment_path": "463025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "463025.protein.info.v11.5.txt",
		        "node_list_path": "463025.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaSpF0412(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. F0412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaSpF0412", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "879309.protein.sequences.v11.5.fa",
		        "enrichment_path": "879309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879309.protein.info.v11.5.txt",
		        "node_list_path": "879309.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumGallinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumGallinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1324352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1324352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1324352.protein.info.v11.5.txt",
		        "node_list_path": "1324352.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag770(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:770 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag770", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262751.protein.info.v11.5.txt",
		        "node_list_path": "1262751.protein.complete.v11.5.txt"
		    }
		]
    )()

def Sar116ClusterCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return SAR116 cluster Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar116ClusterCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "909943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "909943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "909943.clusters.proteins.v11.5.txt",
		        "sequence_path": "909943.protein.sequences.v11.5.fa",
		        "enrichment_path": "909943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "909943.protein.info.v11.5.txt",
		        "node_list_path": "909943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "909943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasXinjiangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasXinjiangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "487184.clusters.info.v11.5.txt",
		        "cluster_tree_path": "487184.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "487184.clusters.proteins.v11.5.txt",
		        "sequence_path": "487184.protein.sequences.v11.5.fa",
		        "enrichment_path": "487184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487184.protein.info.v11.5.txt",
		        "node_list_path": "487184.cluster.nodes.v11.5.txt",
		        "edge_list_path": "487184.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasCircumdentaria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas circumdentaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasCircumdentaria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29524.protein.sequences.v11.5.fa",
		        "enrichment_path": "29524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29524.protein.info.v11.5.txt",
		        "node_list_path": "29524.protein.complete.v11.5.txt"
		    }
		]
    )()

def KingellaNegevensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kingella negevensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KingellaNegevensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1522312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1522312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1522312.clusters.proteins.v11.5.txt",
		        "sequence_path": "1522312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522312.protein.info.v11.5.txt",
		        "node_list_path": "1522312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1522312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FodinicurvataFenggangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fodinicurvata fenggangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FodinicurvataFenggangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "570967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "570967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "570967.clusters.proteins.v11.5.txt",
		        "sequence_path": "570967.protein.sequences.v11.5.fa",
		        "enrichment_path": "570967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570967.protein.info.v11.5.txt",
		        "node_list_path": "570967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "570967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosopumilusKoreensisAr1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosopumilus koreensis AR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosopumilusKoreensisAr1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229908.protein.info.v11.5.txt",
		        "node_list_path": "1229908.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlexilineaFlocculiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flexilinea flocculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlexilineaFlocculiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1678840.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1678840.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1678840.clusters.proteins.v11.5.txt",
		        "sequence_path": "1678840.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678840.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678840.protein.info.v11.5.txt",
		        "node_list_path": "1678840.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1678840.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAbyssalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus abyssalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAbyssalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1221450.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1221450.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1221450.clusters.proteins.v11.5.txt",
		        "sequence_path": "1221450.protein.sequences.v11.5.fa",
		        "enrichment_path": "1221450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1221450.protein.info.v11.5.txt",
		        "node_list_path": "1221450.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1221450.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SiphonobacterAquaeclarae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Siphonobacter aquaeclarae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SiphonobacterAquaeclarae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "563176.protein.sequences.v11.5.fa",
		        "enrichment_path": "563176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563176.protein.info.v11.5.txt",
		        "node_list_path": "563176.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraSpHj(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira sp. HJ graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraSpHj", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1616823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1616823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1616823.protein.info.v11.5.txt",
		        "node_list_path": "1616823.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrincolaSpAD6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrincola sp. A-D6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrincolaSpAD6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1545442.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1545442.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1545442.clusters.proteins.v11.5.txt",
		        "sequence_path": "1545442.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545442.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545442.protein.info.v11.5.txt",
		        "node_list_path": "1545442.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1545442.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaSpF0382Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0382 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaSpF0382Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035193.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035193.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035193.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035193.protein.info.v11.5.txt",
		        "node_list_path": "1035193.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035193.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacteraceaeBacteriumGwc25311Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_53_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacteraceaeBacteriumGwc25311Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798316.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798316.protein.info.v11.5.txt",
		        "node_list_path": "1798316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YuhushiellaDesertiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yuhushiella deserti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YuhushiellaDesertiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "587909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "587909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "587909.clusters.proteins.v11.5.txt",
		        "sequence_path": "587909.protein.sequences.v11.5.fa",
		        "enrichment_path": "587909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "587909.protein.info.v11.5.txt",
		        "node_list_path": "587909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "587909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumXbd2001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBD2001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumXbd2001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520820.protein.info.v11.5.txt",
		        "node_list_path": "1520820.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioLitoralisDsm11393(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio litoralis DSM 11393 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioLitoralisDsm11393", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121455.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121455.protein.info.v11.5.txt",
		        "node_list_path": "1121455.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaGenitalium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma genitalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaGenitalium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243273.protein.sequences.v11.5.fa",
		        "enrichment_path": "243273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243273.protein.info.v11.5.txt",
		        "node_list_path": "243273.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusNeutrinimicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus neutrinimicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusNeutrinimicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "105420.protein.sequences.v11.5.fa",
		        "enrichment_path": "105420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "105420.protein.info.v11.5.txt",
		        "node_list_path": "105420.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophagaNitratireducenticrescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga nitratireducenticrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaNitratireducenticrescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "754476.clusters.info.v11.5.txt",
		        "cluster_tree_path": "754476.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "754476.clusters.proteins.v11.5.txt",
		        "sequence_path": "754476.protein.sequences.v11.5.fa",
		        "enrichment_path": "754476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754476.protein.info.v11.5.txt",
		        "node_list_path": "754476.cluster.nodes.v11.5.txt",
		        "edge_list_path": "754476.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpGha(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Gha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpGha", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855318.protein.info.v11.5.txt",
		        "node_list_path": "1855318.protein.complete.v11.5.txt"
		    }
		]
    )()

def GiardiaLambliaP15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Giardia lamblia P15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GiardiaLambliaP15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "658858.protein.sequences.v11.5.fa",
		        "enrichment_path": "658858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658858.protein.info.v11.5.txt",
		        "node_list_path": "658858.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwf2479Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWF2_47_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwf2479Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618541.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618541.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618541.protein.info.v11.5.txt",
		        "node_list_path": "1618541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterovibrioPacificus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioPacificus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1080227.protein.sequences.v11.5.fa",
		        "enrichment_path": "1080227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1080227.protein.info.v11.5.txt",
		        "node_list_path": "1080227.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinocyclocheilusRhinocerous(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinocyclocheilus rhinocerous graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinocyclocheilusRhinocerous", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "307959.protein.sequences.v11.5.fa",
		        "enrichment_path": "307959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "307959.protein.info.v11.5.txt",
		        "node_list_path": "307959.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSpNd2010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. ND2010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSpNd2010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410618.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410618.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410618.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410618.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410618.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410618.protein.info.v11.5.txt",
		        "node_list_path": "1410618.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410618.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlycomycesHarbinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glycomyces harbinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlycomycesHarbinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "58114.protein.sequences.v11.5.fa",
		        "enrichment_path": "58114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58114.protein.info.v11.5.txt",
		        "node_list_path": "58114.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptacidiphilusOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptacidiphilusOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449353.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449353.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449353.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449353.protein.info.v11.5.txt",
		        "node_list_path": "1449353.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449353.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionKazanBacteriumRbg13509Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RBG_13_50_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionKazanBacteriumRbg13509Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798535.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798535.protein.info.v11.5.txt",
		        "node_list_path": "1798535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb1438bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_43_8b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb1438bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618875.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618875.protein.info.v11.5.txt",
		        "node_list_path": "1618875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AllobaculumStercoricanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Allobaculum stercoricanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllobaculumStercoricanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1050201.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1050201.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1050201.clusters.proteins.v11.5.txt",
		        "sequence_path": "1050201.protein.sequences.v11.5.fa",
		        "enrichment_path": "1050201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1050201.protein.info.v11.5.txt",
		        "node_list_path": "1050201.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1050201.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacillusCapsulatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus capsulatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusCapsulatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120931.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120931.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120931.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120931.protein.info.v11.5.txt",
		        "node_list_path": "1120931.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120931.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full3811bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_38_11b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full3811bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797725.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797725.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797725.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797725.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797725.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797725.protein.info.v11.5.txt",
		        "node_list_path": "1797725.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797725.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpLeaf325(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf325 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpLeaf325", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736337.protein.info.v11.5.txt",
		        "node_list_path": "1736337.protein.complete.v11.5.txt"
		    }
		]
    )()

def NicotianaTomentosiformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nicotiana tomentosiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NicotianaTomentosiformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4098.protein.sequences.v11.5.fa",
		        "enrichment_path": "4098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4098.protein.info.v11.5.txt",
		        "node_list_path": "4098.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlwc3626Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3626 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlwc3626Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463926.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463926.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463926.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463926.protein.info.v11.5.txt",
		        "node_list_path": "1463926.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463926.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3630(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_36_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3630", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798275.protein.info.v11.5.txt",
		        "node_list_path": "1798275.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterWoliniiShCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter wolinii SH Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterWoliniiShCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410664.protein.info.v11.5.txt",
		        "node_list_path": "1410664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudanabaenaSpPcc7367(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudanabaena sp. PCC7367 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudanabaenaSpPcc7367", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "82654.protein.sequences.v11.5.fa",
		        "enrichment_path": "82654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82654.protein.info.v11.5.txt",
		        "node_list_path": "82654.protein.complete.v11.5.txt"
		    }
		]
    )()

def PandoraeaApistaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea apista Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaApistaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93218.clusters.proteins.v11.5.txt",
		        "sequence_path": "93218.protein.sequences.v11.5.fa",
		        "enrichment_path": "93218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93218.protein.info.v11.5.txt",
		        "node_list_path": "93218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusUltunensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ultunensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusUltunensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525365.protein.sequences.v11.5.fa",
		        "enrichment_path": "525365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525365.protein.info.v11.5.txt",
		        "node_list_path": "525365.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloceanibacterStevinii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloceanibacter stevinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloceanibacterStevinii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1774970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1774970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1774970.protein.info.v11.5.txt",
		        "node_list_path": "1774970.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusLarvae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus larvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusLarvae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "697284.protein.sequences.v11.5.fa",
		        "enrichment_path": "697284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "697284.protein.info.v11.5.txt",
		        "node_list_path": "697284.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusGauvreauiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus gauvreauii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusGauvreauiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123075.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123075.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123075.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123075.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123075.protein.info.v11.5.txt",
		        "node_list_path": "1123075.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123075.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzovibrioRestrictusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azovibrio restrictus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzovibrioRestrictusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121035.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121035.protein.info.v11.5.txt",
		        "node_list_path": "1121035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpDd13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpDd13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1777881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1777881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1777881.protein.info.v11.5.txt",
		        "node_list_path": "1777881.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpTnd4ek4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. TND4EK4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpTnd4ek4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907408.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907408.protein.info.v11.5.txt",
		        "node_list_path": "1907408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EndosymbiontOfAcanthamoebaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Acanthamoeba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndosymbiontOfAcanthamoebaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "86106.clusters.info.v11.5.txt",
		        "cluster_tree_path": "86106.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "86106.clusters.proteins.v11.5.txt",
		        "sequence_path": "86106.protein.sequences.v11.5.fa",
		        "enrichment_path": "86106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86106.protein.info.v11.5.txt",
		        "node_list_path": "86106.cluster.nodes.v11.5.txt",
		        "edge_list_path": "86106.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwc13813Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWC1_38_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwc13813Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618583.protein.info.v11.5.txt",
		        "node_list_path": "1618583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MonoraphidiumNeglectumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monoraphidium neglectum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonoraphidiumNeglectumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "145388.clusters.info.v11.5.txt",
		        "cluster_tree_path": "145388.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "145388.clusters.proteins.v11.5.txt",
		        "sequence_path": "145388.protein.sequences.v11.5.fa",
		        "enrichment_path": "145388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "145388.protein.info.v11.5.txt",
		        "node_list_path": "145388.cluster.nodes.v11.5.txt",
		        "edge_list_path": "145388.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaMultilocaleAtcc49900(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma multilocale ATCC 49900 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaMultilocaleAtcc49900", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278299.protein.info.v11.5.txt",
		        "node_list_path": "1278299.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorocebusSabaeus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorocebus sabaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorocebusSabaeus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "60711.protein.sequences.v11.5.fa",
		        "enrichment_path": "60711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60711.protein.info.v11.5.txt",
		        "node_list_path": "60711.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusJorgensenbacteriaBacteriumRifcsphigho202Full4520(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPHIGHO2_02_FULL_45_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsphigho202Full4520", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798470.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798470.protein.info.v11.5.txt",
		        "node_list_path": "1798470.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifcsphigho202Full4012b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_02_FULL_40_12b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho202Full4012b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801639.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801639.protein.info.v11.5.txt",
		        "node_list_path": "1801639.protein.complete.v11.5.txt"
		    }
		]
    )()

def SanguibacterKeddieiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter keddieii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SanguibacterKeddieiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "446469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "446469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "446469.clusters.proteins.v11.5.txt",
		        "sequence_path": "446469.protein.sequences.v11.5.fa",
		        "enrichment_path": "446469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446469.protein.info.v11.5.txt",
		        "node_list_path": "446469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "446469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasPolymorpha(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas polymorpha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasPolymorpha", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280954.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280954.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280954.protein.info.v11.5.txt",
		        "node_list_path": "1280954.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesLianchengensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides lianchengensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesLianchengensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1045774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1045774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1045774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1045774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045774.protein.info.v11.5.txt",
		        "node_list_path": "1045774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1045774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesDokdonensisFr1436(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides dokdonensis FR1436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesDokdonensisFr1436", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1300347.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300347.protein.info.v11.5.txt",
		        "node_list_path": "1300347.protein.complete.v11.5.txt"
		    }
		]
    )()

def CuniculiplasmaDivulgatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cuniculiplasma divulgatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CuniculiplasmaDivulgatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1673428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1673428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1673428.protein.info.v11.5.txt",
		        "node_list_path": "1673428.protein.complete.v11.5.txt"
		    }
		]
    )()

def DanausPlexippusPlexippus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Danaus plexippus plexippus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DanausPlexippusPlexippus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "278856.protein.sequences.v11.5.fa",
		        "enrichment_path": "278856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278856.protein.info.v11.5.txt",
		        "node_list_path": "278856.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaSpDb56Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. DB56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpDb56Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094755.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094755.protein.info.v11.5.txt",
		        "node_list_path": "1094755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidaminobacterHydrogenoformansDsm2784(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidaminobacter hydrogenoformans DSM 2784 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminobacterHydrogenoformansDsm2784", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120920.protein.info.v11.5.txt",
		        "node_list_path": "1120920.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumFontis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium fontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumFontis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1124188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1124188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1124188.protein.info.v11.5.txt",
		        "node_list_path": "1124188.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraVanthieliiSerovarHollandStrWazHollandAtcc700522(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira vanthielii serovar Holland str. Waz Holland ATCC 700522 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraVanthieliiSerovarHollandStrWazHollandAtcc700522", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1218591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218591.protein.info.v11.5.txt",
		        "node_list_path": "1218591.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlsenellaUrininfantisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella urininfantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaUrininfantisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871033.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871033.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871033.protein.info.v11.5.txt",
		        "node_list_path": "1871033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterCancerogenusAtcc35316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cancerogenus ATCC 35316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterCancerogenusAtcc35316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "500639.clusters.info.v11.5.txt",
		        "cluster_tree_path": "500639.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "500639.clusters.proteins.v11.5.txt",
		        "sequence_path": "500639.protein.sequences.v11.5.fa",
		        "enrichment_path": "500639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500639.protein.info.v11.5.txt",
		        "node_list_path": "500639.cluster.nodes.v11.5.txt",
		        "edge_list_path": "500639.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodoferaxAntarcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodoferax antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodoferaxAntarcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "81479.protein.sequences.v11.5.fa",
		        "enrichment_path": "81479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81479.protein.info.v11.5.txt",
		        "node_list_path": "81479.protein.complete.v11.5.txt"
		    }
		]
    )()

def OncorhynchusMykissCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oncorhynchus mykiss Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OncorhynchusMykissCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8022.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8022.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8022.clusters.proteins.v11.5.txt",
		        "sequence_path": "8022.protein.sequences.v11.5.fa",
		        "enrichment_path": "8022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8022.protein.info.v11.5.txt",
		        "node_list_path": "8022.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8022.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusPantotrophus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus pantotrophus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusPantotrophus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935565.protein.sequences.v11.5.fa",
		        "enrichment_path": "935565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935565.protein.info.v11.5.txt",
		        "node_list_path": "935565.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpTv2a2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Tv2a2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpTv2a2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "113395.protein.sequences.v11.5.fa",
		        "enrichment_path": "113395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113395.protein.info.v11.5.txt",
		        "node_list_path": "113395.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrnithinimicrobiumPekingense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ornithinimicrobium pekingense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithinimicrobiumPekingense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122622.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122622.protein.info.v11.5.txt",
		        "node_list_path": "1122622.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyxococcalesBacterium6820Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myxococcales bacterium 68-20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcalesBacterium6820Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895795.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895795.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895795.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895795.protein.info.v11.5.txt",
		        "node_list_path": "1895795.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895795.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NumidumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Numidum massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NumidumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1522315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522315.protein.info.v11.5.txt",
		        "node_list_path": "1522315.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWirthbacteriaBacteriumCg2305411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wirthbacteria bacterium CG2_30_54_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWirthbacteriaBacteriumCg2305411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817892.protein.info.v11.5.txt",
		        "node_list_path": "1817892.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesoplasmaChauliocolaAtcc49578Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesoplasma chauliocola ATCC 49578 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoplasmaChauliocolaAtcc49578Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336232.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336232.protein.info.v11.5.txt",
		        "node_list_path": "1336232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloferaxVolcanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloferax volcanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloferaxVolcanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "309800.protein.sequences.v11.5.fa",
		        "enrichment_path": "309800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "309800.protein.info.v11.5.txt",
		        "node_list_path": "309800.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonadaceaeBacteriumCg2303812Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium CG2_30_38_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonadaceaeBacteriumCg2303812Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805325.protein.info.v11.5.txt",
		        "node_list_path": "1805325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterNecessariusStir1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius STIR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterNecessariusStir1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "452638.protein.sequences.v11.5.fa",
		        "enrichment_path": "452638.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452638.protein.info.v11.5.txt",
		        "node_list_path": "452638.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermocladiumSpEchB(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermocladium sp. ECH_B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermocladiumSpEchB", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1714261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714261.protein.info.v11.5.txt",
		        "node_list_path": "1714261.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobulbaceaeBacteriumBrhC16a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbaceae bacterium BRH_c16a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbaceaeBacteriumBrhC16a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629713.protein.info.v11.5.txt",
		        "node_list_path": "1629713.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaAichiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia aichiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaAichiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220583.protein.info.v11.5.txt",
		        "node_list_path": "1220583.protein.complete.v11.5.txt"
		    }
		]
    )()

def RaineyellaAntarctica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Raineyella antarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RaineyellaAntarctica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577474.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577474.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577474.protein.info.v11.5.txt",
		        "node_list_path": "1577474.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyramidobacterSpC128Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyramidobacter sp. C12-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyramidobacterSpC128Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1943580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1943580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1943580.clusters.proteins.v11.5.txt",
		        "sequence_path": "1943580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1943580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1943580.protein.info.v11.5.txt",
		        "node_list_path": "1943580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1943580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RummeliibacillusStabekisii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rummeliibacillus stabekisii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RummeliibacillusStabekisii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "241244.protein.sequences.v11.5.fa",
		        "enrichment_path": "241244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "241244.protein.info.v11.5.txt",
		        "node_list_path": "241244.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_42_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798377.protein.info.v11.5.txt",
		        "node_list_path": "1798377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusCollinoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus collinoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCollinoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33960.protein.sequences.v11.5.fa",
		        "enrichment_path": "33960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33960.protein.info.v11.5.txt",
		        "node_list_path": "33960.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag678Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:678 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag678Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262831.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262831.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262831.protein.info.v11.5.txt",
		        "node_list_path": "1262831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumMerycicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium merycicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumMerycicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "78345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "78345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "78345.clusters.proteins.v11.5.txt",
		        "sequence_path": "78345.protein.sequences.v11.5.fa",
		        "enrichment_path": "78345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78345.protein.info.v11.5.txt",
		        "node_list_path": "78345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "78345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaTaiwanenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma taiwanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaTaiwanenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1276220.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1276220.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1276220.clusters.proteins.v11.5.txt",
		        "sequence_path": "1276220.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276220.protein.info.v11.5.txt",
		        "node_list_path": "1276220.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1276220.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumOlb19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium OLB19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumOlb19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617425.protein.info.v11.5.txt",
		        "node_list_path": "1617425.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesQuadriannulatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles quadriannulatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesQuadriannulatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "34691.protein.sequences.v11.5.fa",
		        "enrichment_path": "34691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34691.protein.info.v11.5.txt",
		        "node_list_path": "34691.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesNaeslundii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces naeslundii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesNaeslundii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1115803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1115803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1115803.protein.info.v11.5.txt",
		        "node_list_path": "1115803.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterSaltans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter saltans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSaltans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762903.protein.sequences.v11.5.fa",
		        "enrichment_path": "762903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762903.protein.info.v11.5.txt",
		        "node_list_path": "762903.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumSg813(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium SG8_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumSg813", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703398.protein.info.v11.5.txt",
		        "node_list_path": "1703398.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkaliphilusOremlandii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkaliphilus oremlandii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkaliphilusOremlandii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "350688.protein.sequences.v11.5.fa",
		        "enrichment_path": "350688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "350688.protein.info.v11.5.txt",
		        "node_list_path": "350688.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAegiribacteriaBacteriumMlsC(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aegiribacteria bacterium MLS_C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAegiribacteriaBacteriumMlsC", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1775674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775674.protein.info.v11.5.txt",
		        "node_list_path": "1775674.protein.complete.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumAcnesSk182bjcviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes SK182BJCVI Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumAcnesSk182bjcviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1051006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1051006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1051006.clusters.proteins.v11.5.txt",
		        "sequence_path": "1051006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1051006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1051006.protein.info.v11.5.txt",
		        "node_list_path": "1051006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1051006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterAurescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter aurescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterAurescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290340.clusters.proteins.v11.5.txt",
		        "sequence_path": "290340.protein.sequences.v11.5.fa",
		        "enrichment_path": "290340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290340.protein.info.v11.5.txt",
		        "node_list_path": "290340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAlbus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAlbus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67257.protein.sequences.v11.5.fa",
		        "enrichment_path": "67257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67257.protein.info.v11.5.txt",
		        "node_list_path": "67257.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpCc9616(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9616 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpCc9616", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "110663.protein.sequences.v11.5.fa",
		        "enrichment_path": "110663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "110663.protein.info.v11.5.txt",
		        "node_list_path": "110663.protein.complete.v11.5.txt"
		    }
		]
    )()

def VirgibacillusSenegalensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusSenegalensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499679.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499679.protein.info.v11.5.txt",
		        "node_list_path": "1499679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusPhoeniculicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus phoeniculicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusPhoeniculicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158610.protein.info.v11.5.txt",
		        "node_list_path": "1158610.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMethanolicusMga3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus methanolicus MGA3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMethanolicusMga3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "796606.protein.sequences.v11.5.fa",
		        "enrichment_path": "796606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796606.protein.info.v11.5.txt",
		        "node_list_path": "796606.protein.complete.v11.5.txt"
		    }
		]
    )()

def CallorhinchusMiliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Callorhinchus milii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CallorhinchusMiliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7868.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7868.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7868.clusters.proteins.v11.5.txt",
		        "sequence_path": "7868.protein.sequences.v11.5.fa",
		        "enrichment_path": "7868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7868.protein.info.v11.5.txt",
		        "node_list_path": "7868.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7868.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterDuraquaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter duraquae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterDuraquaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1835254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1835254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1835254.clusters.proteins.v11.5.txt",
		        "sequence_path": "1835254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1835254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1835254.protein.info.v11.5.txt",
		        "node_list_path": "1835254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1835254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterThiooxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter thiooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterThiooxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163409.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163409.protein.info.v11.5.txt",
		        "node_list_path": "1163409.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag1193(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1193 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag1193", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262771.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262771.protein.info.v11.5.txt",
		        "node_list_path": "1262771.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacterium4787(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium 47-87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacterium4787", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895828.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895828.protein.info.v11.5.txt",
		        "node_list_path": "1895828.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHimb30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HIMB30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHimb30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "751994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "751994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "751994.clusters.proteins.v11.5.txt",
		        "sequence_path": "751994.protein.sequences.v11.5.fa",
		        "enrichment_path": "751994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "751994.protein.info.v11.5.txt",
		        "node_list_path": "751994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "751994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaTyphi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica Typhi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaTyphi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "220341.protein.sequences.v11.5.fa",
		        "enrichment_path": "220341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220341.protein.info.v11.5.txt",
		        "node_list_path": "220341.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSpSoapLake7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. Soap Lake #7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpSoapLake7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1962264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1962264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1962264.clusters.proteins.v11.5.txt",
		        "sequence_path": "1962264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1962264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1962264.protein.info.v11.5.txt",
		        "node_list_path": "1962264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1962264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterSubantarcticusLmg24377(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter subantarcticus LMG 24377 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSubantarcticusLmg24377", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1388752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1388752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1388752.protein.info.v11.5.txt",
		        "node_list_path": "1388752.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSp77(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSp77", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1101192.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101192.protein.info.v11.5.txt",
		        "node_list_path": "1101192.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumAggregans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium aggregans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumAggregans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "81409.protein.sequences.v11.5.fa",
		        "enrichment_path": "81409.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81409.protein.info.v11.5.txt",
		        "node_list_path": "81409.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterHydrocarbonoclasticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter hydrocarbonoclasticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterHydrocarbonoclasticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351348.clusters.proteins.v11.5.txt",
		        "sequence_path": "351348.protein.sequences.v11.5.fa",
		        "enrichment_path": "351348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351348.protein.info.v11.5.txt",
		        "node_list_path": "351348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSpPacm27299Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. PACM 27299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpPacm27299Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1727164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1727164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1727164.clusters.proteins.v11.5.txt",
		        "sequence_path": "1727164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1727164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1727164.protein.info.v11.5.txt",
		        "node_list_path": "1727164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1727164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesTsukubensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces tsukubensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesTsukubensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83656.protein.sequences.v11.5.fa",
		        "enrichment_path": "83656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83656.protein.info.v11.5.txt",
		        "node_list_path": "83656.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusGobiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus gobiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGobiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1441095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1441095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1441095.protein.info.v11.5.txt",
		        "node_list_path": "1441095.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronomonasMoolapensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronomonas moolapensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronomonasMoolapensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "268739.protein.sequences.v11.5.fa",
		        "enrichment_path": "268739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "268739.protein.info.v11.5.txt",
		        "node_list_path": "268739.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosomonasSpAl212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. AL212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasSpAl212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "153948.protein.sequences.v11.5.fa",
		        "enrichment_path": "153948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "153948.protein.info.v11.5.txt",
		        "node_list_path": "153948.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumPhaseoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium phaseoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumPhaseoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "396.clusters.info.v11.5.txt",
		        "cluster_tree_path": "396.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "396.clusters.proteins.v11.5.txt",
		        "sequence_path": "396.protein.sequences.v11.5.fa",
		        "enrichment_path": "396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "396.protein.info.v11.5.txt",
		        "node_list_path": "396.cluster.nodes.v11.5.txt",
		        "edge_list_path": "396.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArachidicoccusRhizosphaeraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arachidicoccus rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArachidicoccusRhizosphaeraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "551991.clusters.info.v11.5.txt",
		        "cluster_tree_path": "551991.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "551991.clusters.proteins.v11.5.txt",
		        "sequence_path": "551991.protein.sequences.v11.5.fa",
		        "enrichment_path": "551991.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551991.protein.info.v11.5.txt",
		        "node_list_path": "551991.cluster.nodes.v11.5.txt",
		        "edge_list_path": "551991.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpPcc7376Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC7376 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpPcc7376Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "111781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "111781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "111781.clusters.proteins.v11.5.txt",
		        "sequence_path": "111781.protein.sequences.v11.5.fa",
		        "enrichment_path": "111781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "111781.protein.info.v11.5.txt",
		        "node_list_path": "111781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "111781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterGracilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter gracilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterGracilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553220.protein.sequences.v11.5.fa",
		        "enrichment_path": "553220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553220.protein.info.v11.5.txt",
		        "node_list_path": "553220.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnsiferSpLcm4579Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. LCM 4579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferSpLcm4579Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1848292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1848292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1848292.clusters.proteins.v11.5.txt",
		        "sequence_path": "1848292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848292.protein.info.v11.5.txt",
		        "node_list_path": "1848292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1848292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDesulfopertinaxCowenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desulfopertinax cowenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDesulfopertinaxCowenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1919273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1919273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1919273.protein.info.v11.5.txt",
		        "node_list_path": "1919273.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSp6728Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. 67-28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSp6728Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895822.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895822.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895822.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895822.protein.info.v11.5.txt",
		        "node_list_path": "1895822.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895822.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph2100Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH2100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph2100Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217708.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217708.protein.info.v11.5.txt",
		        "node_list_path": "1217708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusPatagoniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus patagoniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPatagoniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "228576.clusters.info.v11.5.txt",
		        "cluster_tree_path": "228576.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "228576.clusters.proteins.v11.5.txt",
		        "sequence_path": "228576.protein.sequences.v11.5.fa",
		        "enrichment_path": "228576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228576.protein.info.v11.5.txt",
		        "node_list_path": "228576.cluster.nodes.v11.5.txt",
		        "edge_list_path": "228576.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoflexibacterRuberCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoflexibacter ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoflexibacterRuberCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1003.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1003.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1003.clusters.proteins.v11.5.txt",
		        "sequence_path": "1003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1003.protein.info.v11.5.txt",
		        "node_list_path": "1003.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1003.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusReuteri10023(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri 10023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusReuteri10023", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349123.protein.sequences.v11.5.fa",
		        "enrichment_path": "349123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349123.protein.info.v11.5.txt",
		        "node_list_path": "349123.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAccumulibacterSpBa92(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. BA-92 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAccumulibacterSpBa92", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1454003.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454003.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454003.protein.info.v11.5.txt",
		        "node_list_path": "1454003.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpC9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. C9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpC9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1943579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1943579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1943579.protein.info.v11.5.txt",
		        "node_list_path": "1943579.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelobdellaRobustaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helobdella robusta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelobdellaRobustaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6412.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6412.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6412.clusters.proteins.v11.5.txt",
		        "sequence_path": "6412.protein.sequences.v11.5.fa",
		        "enrichment_path": "6412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6412.protein.info.v11.5.txt",
		        "node_list_path": "6412.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6412.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumGwa2528(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium GWA2_52_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumGwa2528", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801817.protein.info.v11.5.txt",
		        "node_list_path": "1801817.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4422bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_01_FULL_44_22b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4422bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802737.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802737.protein.info.v11.5.txt",
		        "node_list_path": "1802737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaSpLc5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. LC5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpLc5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502724.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502724.protein.info.v11.5.txt",
		        "node_list_path": "1502724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumShimoidei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium shimoidei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumShimoidei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29313.protein.sequences.v11.5.fa",
		        "enrichment_path": "29313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29313.protein.info.v11.5.txt",
		        "node_list_path": "29313.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpRoot381(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. Root381 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpRoot381", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736524.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736524.protein.info.v11.5.txt",
		        "node_list_path": "1736524.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNitrosopumilusKoreensisAr1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosopumilus koreensis AR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNitrosopumilusKoreensisAr1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229908.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229908.protein.info.v11.5.txt",
		        "node_list_path": "1229908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CharaBraunii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chara braunii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CharaBraunii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69332.protein.sequences.v11.5.fa",
		        "enrichment_path": "69332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69332.protein.info.v11.5.txt",
		        "node_list_path": "69332.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5331Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_53_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5331Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798481.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798481.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798481.protein.info.v11.5.txt",
		        "node_list_path": "1798481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DolosigranulumPigrumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dolosigranulum pigrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DolosigranulumPigrumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883103.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883103.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883103.clusters.proteins.v11.5.txt",
		        "sequence_path": "883103.protein.sequences.v11.5.fa",
		        "enrichment_path": "883103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883103.protein.info.v11.5.txt",
		        "node_list_path": "883103.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883103.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag95(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag95", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262988.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262988.protein.info.v11.5.txt",
		        "node_list_path": "1262988.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaProteobacteriumAap65Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return beta proteobacterium AAP65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaProteobacteriumAap65Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523424.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523424.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523424.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523424.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523424.protein.info.v11.5.txt",
		        "node_list_path": "1523424.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523424.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesInsulaeDsm17944Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides insulae DSM 17944 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesInsulaeDsm17944Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122610.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122610.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122610.protein.info.v11.5.txt",
		        "node_list_path": "1122610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNucleicultrixAmoebiphilaFs5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nucleicultrix amoebiphila FS5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNucleicultrixAmoebiphilaFs5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1414854.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1414854.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1414854.clusters.proteins.v11.5.txt",
		        "sequence_path": "1414854.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414854.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414854.protein.info.v11.5.txt",
		        "node_list_path": "1414854.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1414854.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwd26328(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWD2_63_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwd26328", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797937.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797937.protein.info.v11.5.txt",
		        "node_list_path": "1797937.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusAsini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus asini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusAsini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158606.protein.info.v11.5.txt",
		        "node_list_path": "1158606.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetakosakoniaMassiliensisJc163Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metakosakonia massiliensis JC163 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetakosakoniaMassiliensisJc163Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095768.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095768.protein.info.v11.5.txt",
		        "node_list_path": "1095768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrueperellaBernardiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trueperella bernardiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrueperellaBernardiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59561.protein.sequences.v11.5.fa",
		        "enrichment_path": "59561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59561.protein.info.v11.5.txt",
		        "node_list_path": "59561.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaGerundensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia gerundensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaGerundensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619313.protein.info.v11.5.txt",
		        "node_list_path": "1619313.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorticoccusHydrocarbonoclasticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porticoccus hydrocarbonoclasticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorticoccusHydrocarbonoclasticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415778.protein.info.v11.5.txt",
		        "node_list_path": "1415778.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp131216Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 13-12-16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp131216Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1570823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1570823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1570823.clusters.proteins.v11.5.txt",
		        "sequence_path": "1570823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570823.protein.info.v11.5.txt",
		        "node_list_path": "1570823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1570823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesViolaceusnigerCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces violaceusniger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesViolaceusnigerCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "653045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "653045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "653045.clusters.proteins.v11.5.txt",
		        "sequence_path": "653045.protein.sequences.v11.5.fa",
		        "enrichment_path": "653045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "653045.protein.info.v11.5.txt",
		        "node_list_path": "653045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "653045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SimonsiellaMuelleriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Simonsiella muelleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SimonsiellaMuelleriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641147.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641147.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641147.clusters.proteins.v11.5.txt",
		        "sequence_path": "641147.protein.sequences.v11.5.fa",
		        "enrichment_path": "641147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641147.protein.info.v11.5.txt",
		        "node_list_path": "641147.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641147.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPhaeoluteigriseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces phaeoluteigriseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPhaeoluteigriseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "114686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "114686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "114686.clusters.proteins.v11.5.txt",
		        "sequence_path": "114686.protein.sequences.v11.5.fa",
		        "enrichment_path": "114686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "114686.protein.info.v11.5.txt",
		        "node_list_path": "114686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "114686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KushneriaAvicenniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kushneria avicenniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KushneriaAvicenniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "402385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "402385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "402385.clusters.proteins.v11.5.txt",
		        "sequence_path": "402385.protein.sequences.v11.5.fa",
		        "enrichment_path": "402385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "402385.protein.info.v11.5.txt",
		        "node_list_path": "402385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "402385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WeissellaMinorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Weissella minor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaMinorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1620.clusters.proteins.v11.5.txt",
		        "sequence_path": "1620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1620.protein.info.v11.5.txt",
		        "node_list_path": "1620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLiptonbacteriaBacteriumGwb1496(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium GWB1_49_6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumGwb1496", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798644.protein.info.v11.5.txt",
		        "node_list_path": "1798644.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumGw2011Gwf23272Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011_GWF2_32_72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011Gwf23272Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619079.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619079.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619079.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619079.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619079.protein.info.v11.5.txt",
		        "node_list_path": "1619079.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619079.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterTropicalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter tropicalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterTropicalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "104102.protein.sequences.v11.5.fa",
		        "enrichment_path": "104102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104102.protein.info.v11.5.txt",
		        "node_list_path": "104102.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1934996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1934996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1934996.clusters.proteins.v11.5.txt",
		        "sequence_path": "1934996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934996.protein.info.v11.5.txt",
		        "node_list_path": "1934996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1934996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaTularensisSchus4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella tularensis SCHUS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaTularensisSchus4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "177416.protein.sequences.v11.5.fa",
		        "enrichment_path": "177416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "177416.protein.info.v11.5.txt",
		        "node_list_path": "177416.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyanotheceSpPcc7424Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7424 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanotheceSpPcc7424Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "65393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "65393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "65393.clusters.proteins.v11.5.txt",
		        "sequence_path": "65393.protein.sequences.v11.5.fa",
		        "enrichment_path": "65393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65393.protein.info.v11.5.txt",
		        "node_list_path": "65393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "65393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaNiigatensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia niigatensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaNiigatensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206733.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206733.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206733.protein.info.v11.5.txt",
		        "node_list_path": "1206733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterArcticusA12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter arcticus A12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterArcticusA12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206103.protein.info.v11.5.txt",
		        "node_list_path": "1206103.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaloceraViscosaTufc12733Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Calocera viscosa TUFC12733 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloceraViscosaTufc12733Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1330018.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1330018.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1330018.clusters.proteins.v11.5.txt",
		        "sequence_path": "1330018.protein.sequences.v11.5.fa",
		        "enrichment_path": "1330018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1330018.protein.info.v11.5.txt",
		        "node_list_path": "1330018.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1330018.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AquimarinaAmphilecti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina amphilecti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaAmphilecti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1038014.protein.sequences.v11.5.fa",
		        "enrichment_path": "1038014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1038014.protein.info.v11.5.txt",
		        "node_list_path": "1038014.protein.complete.v11.5.txt"
		    }
		]
    )()

def KushneriaAurantia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kushneria aurantia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KushneriaAurantia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122139.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122139.protein.info.v11.5.txt",
		        "node_list_path": "1122139.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusEurythermalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus eurythermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusEurythermalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1505907.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1505907.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1505907.clusters.proteins.v11.5.txt",
		        "sequence_path": "1505907.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505907.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505907.protein.info.v11.5.txt",
		        "node_list_path": "1505907.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1505907.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpNfr15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. NFR15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpNfr15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566282.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566282.protein.info.v11.5.txt",
		        "node_list_path": "1566282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EndozoicomonasAscidiicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas ascidiicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EndozoicomonasAscidiicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1698521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1698521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1698521.clusters.proteins.v11.5.txt",
		        "sequence_path": "1698521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1698521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1698521.protein.info.v11.5.txt",
		        "node_list_path": "1698521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1698521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FructobacillusTropaeoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fructobacillus tropaeoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FructobacillusTropaeoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "709323.clusters.info.v11.5.txt",
		        "cluster_tree_path": "709323.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "709323.clusters.proteins.v11.5.txt",
		        "sequence_path": "709323.protein.sequences.v11.5.fa",
		        "enrichment_path": "709323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709323.protein.info.v11.5.txt",
		        "node_list_path": "709323.cluster.nodes.v11.5.txt",
		        "edge_list_path": "709323.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaChrysopicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma chrysopicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaChrysopicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1276227.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276227.protein.info.v11.5.txt",
		        "node_list_path": "1276227.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErysipelotrichaceaeBacterium5254faa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium 5254FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelotrichaceaeBacterium5254faa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "552396.protein.sequences.v11.5.fa",
		        "enrichment_path": "552396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "552396.protein.info.v11.5.txt",
		        "node_list_path": "552396.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusSpLemmy01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. LEMMY01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusSpLemmy01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1954237.protein.sequences.v11.5.fa",
		        "enrichment_path": "1954237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1954237.protein.info.v11.5.txt",
		        "node_list_path": "1954237.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylocaldumSp14b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylocaldum sp. 14B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocaldumSp14b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1912213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912213.protein.info.v11.5.txt",
		        "node_list_path": "1912213.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicroscillaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microscilla marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicroscillaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313606.protein.sequences.v11.5.fa",
		        "enrichment_path": "313606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313606.protein.info.v11.5.txt",
		        "node_list_path": "313606.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp12458059Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1245805.9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp12458059Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1856862.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1856862.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1856862.clusters.proteins.v11.5.txt",
		        "sequence_path": "1856862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1856862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1856862.protein.info.v11.5.txt",
		        "node_list_path": "1856862.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1856862.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudovibrioAscidiaceicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio ascidiaceicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioAscidiaceicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "285279.protein.sequences.v11.5.fa",
		        "enrichment_path": "285279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285279.protein.info.v11.5.txt",
		        "node_list_path": "285279.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp4f(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 4F graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp4f", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1751294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1751294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1751294.protein.info.v11.5.txt",
		        "node_list_path": "1751294.protein.complete.v11.5.txt"
		    }
		]
    )()

def VitisVinifera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vitis vinifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VitisVinifera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29760.protein.sequences.v11.5.fa",
		        "enrichment_path": "29760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29760.protein.info.v11.5.txt",
		        "node_list_path": "29760.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumGw2011Gwa24110(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWA2_41_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwa24110", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618977.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618977.protein.info.v11.5.txt",
		        "node_list_path": "1618977.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaBiviaJcvihmp010(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bivia JCVIHMP010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaBiviaJcvihmp010", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553171.protein.sequences.v11.5.fa",
		        "enrichment_path": "553171.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553171.protein.info.v11.5.txt",
		        "node_list_path": "553171.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasUtahensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas utahensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasUtahensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86177.protein.sequences.v11.5.fa",
		        "enrichment_path": "86177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86177.protein.info.v11.5.txt",
		        "node_list_path": "86177.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeisingeraMethylohalidivoransDsm14336Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leisingera methylohalidivorans DSM 14336 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraMethylohalidivoransDsm14336Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999552.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999552.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999552.clusters.proteins.v11.5.txt",
		        "sequence_path": "999552.protein.sequences.v11.5.fa",
		        "enrichment_path": "999552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999552.protein.info.v11.5.txt",
		        "node_list_path": "999552.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999552.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JeotgalicoccusSp13mg44air(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalicoccus sp. 13MG44air graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalicoccusSp13mg44air", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461582.protein.info.v11.5.txt",
		        "node_list_path": "1461582.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrettanomycesBruxellensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brettanomyces bruxellensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrettanomycesBruxellensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5007.protein.sequences.v11.5.fa",
		        "enrichment_path": "5007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5007.protein.info.v11.5.txt",
		        "node_list_path": "5007.protein.complete.v11.5.txt"
		    }
		]
    )()

def TsukamurellaPaurometabolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tsukamurella paurometabola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TsukamurellaPaurometabolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521096.clusters.proteins.v11.5.txt",
		        "sequence_path": "521096.protein.sequences.v11.5.fa",
		        "enrichment_path": "521096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521096.protein.info.v11.5.txt",
		        "node_list_path": "521096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RodentibacterRarusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter rarus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterRarusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1908260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1908260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1908260.clusters.proteins.v11.5.txt",
		        "sequence_path": "1908260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908260.protein.info.v11.5.txt",
		        "node_list_path": "1908260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1908260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyotisLucifugusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myotis lucifugus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyotisLucifugusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59463.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59463.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59463.clusters.proteins.v11.5.txt",
		        "sequence_path": "59463.protein.sequences.v11.5.fa",
		        "enrichment_path": "59463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59463.protein.info.v11.5.txt",
		        "node_list_path": "59463.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59463.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExophialaSiderisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exophiala sideris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaSiderisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1016849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1016849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1016849.clusters.proteins.v11.5.txt",
		        "sequence_path": "1016849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1016849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1016849.protein.info.v11.5.txt",
		        "node_list_path": "1016849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1016849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodospirillalesBacterium7018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium 70-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillalesBacterium7018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895826.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895826.protein.info.v11.5.txt",
		        "node_list_path": "1895826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumChoerinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium choerinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumChoerinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35760.protein.sequences.v11.5.fa",
		        "enrichment_path": "35760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35760.protein.info.v11.5.txt",
		        "node_list_path": "35760.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorchorusOlitoriusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corchorus olitorius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorchorusOlitoriusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93759.clusters.proteins.v11.5.txt",
		        "sequence_path": "93759.protein.sequences.v11.5.fa",
		        "enrichment_path": "93759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93759.protein.info.v11.5.txt",
		        "node_list_path": "93759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAnatis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma anatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAnatis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1034808.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034808.protein.info.v11.5.txt",
		        "node_list_path": "1034808.protein.complete.v11.5.txt"
		    }
		]
    )()

def CladophialophoraImmundaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora immunda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CladophialophoraImmundaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "569365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "569365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "569365.clusters.proteins.v11.5.txt",
		        "sequence_path": "569365.protein.sequences.v11.5.fa",
		        "enrichment_path": "569365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "569365.protein.info.v11.5.txt",
		        "node_list_path": "569365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "569365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpTd01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. TD01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpTd01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999141.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999141.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999141.clusters.proteins.v11.5.txt",
		        "sequence_path": "999141.protein.sequences.v11.5.fa",
		        "enrichment_path": "999141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999141.protein.info.v11.5.txt",
		        "node_list_path": "999141.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999141.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumA2KyotoCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum A2 Kyoto Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumA2KyotoCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "536232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "536232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "536232.clusters.proteins.v11.5.txt",
		        "sequence_path": "536232.protein.sequences.v11.5.fa",
		        "enrichment_path": "536232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "536232.protein.info.v11.5.txt",
		        "node_list_path": "536232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "536232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaSpOralTaxon847Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. oral taxon 847 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaSpOralTaxon847Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1785996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1785996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1785996.clusters.proteins.v11.5.txt",
		        "sequence_path": "1785996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1785996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1785996.protein.info.v11.5.txt",
		        "node_list_path": "1785996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1785996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium9143bfaaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 9143BFAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium9143bfaaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658088.clusters.proteins.v11.5.txt",
		        "sequence_path": "658088.protein.sequences.v11.5.fa",
		        "enrichment_path": "658088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658088.protein.info.v11.5.txt",
		        "node_list_path": "658088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixibacteriaBacteriumSm2381(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm2381", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703428.protein.info.v11.5.txt",
		        "node_list_path": "1703428.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasCichoriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas cichorii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCichoriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1441629.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1441629.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1441629.clusters.proteins.v11.5.txt",
		        "sequence_path": "1441629.protein.sequences.v11.5.fa",
		        "enrichment_path": "1441629.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1441629.protein.info.v11.5.txt",
		        "node_list_path": "1441629.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1441629.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhialemoniopsisCurvataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phialemoniopsis curvata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhialemoniopsisCurvataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1093900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1093900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1093900.clusters.proteins.v11.5.txt",
		        "sequence_path": "1093900.protein.sequences.v11.5.fa",
		        "enrichment_path": "1093900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1093900.protein.info.v11.5.txt",
		        "node_list_path": "1093900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1093900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaGlathei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia glathei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaGlathei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "60547.protein.sequences.v11.5.fa",
		        "enrichment_path": "60547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60547.protein.info.v11.5.txt",
		        "node_list_path": "60547.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerocolumnaJejuensisDsm15929(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerocolumna jejuensis DSM 15929 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerocolumnaJejuensisDsm15929", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121322.protein.info.v11.5.txt",
		        "node_list_path": "1121322.protein.complete.v11.5.txt"
		    }
		]
    )()

def AchromobacterSpRoot83Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter sp. Root83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterSpRoot83Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736602.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736602.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736602.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736602.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736602.protein.info.v11.5.txt",
		        "node_list_path": "1736602.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736602.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag245(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:245 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag245", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262784.protein.info.v11.5.txt",
		        "node_list_path": "1262784.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusThoraltensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus thoraltensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusThoraltensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123318.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123318.protein.info.v11.5.txt",
		        "node_list_path": "1123318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosospiraSpNsp1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosospiraSpNsp1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "136547.protein.sequences.v11.5.fa",
		        "enrichment_path": "136547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "136547.protein.info.v11.5.txt",
		        "node_list_path": "136547.protein.complete.v11.5.txt"
		    }
		]
    )()

def PediococcusAcidilactici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus acidilactici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusAcidilactici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1254.protein.info.v11.5.txt",
		        "node_list_path": "1254.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpSph12015(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Sph1(2015) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpSph12015", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1628084.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628084.protein.info.v11.5.txt",
		        "node_list_path": "1628084.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpJ56(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. J56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpJ56", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "935850.protein.sequences.v11.5.fa",
		        "enrichment_path": "935850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935850.protein.info.v11.5.txt",
		        "node_list_path": "935850.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaGonorrhoeaeFa1090(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria gonorrhoeae FA 1090 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaGonorrhoeaeFa1090", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "242231.protein.sequences.v11.5.fa",
		        "enrichment_path": "242231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "242231.protein.info.v11.5.txt",
		        "node_list_path": "242231.protein.complete.v11.5.txt"
		    }
		]
    )()

def TimonellaSenegalensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Timonella senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TimonellaSenegalensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095772.protein.info.v11.5.txt",
		        "node_list_path": "1095772.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpRoot1304Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root1304 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpRoot1304Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736450.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736450.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736450.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736450.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736450.protein.info.v11.5.txt",
		        "node_list_path": "1736450.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736450.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeisingeraMethylohalidivoransDsm14336(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leisingera methylohalidivorans DSM 14336 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraMethylohalidivoransDsm14336", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999552.protein.sequences.v11.5.fa",
		        "enrichment_path": "999552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999552.protein.info.v11.5.txt",
		        "node_list_path": "999552.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasArabiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas arabiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasArabiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "874454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "874454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "874454.clusters.proteins.v11.5.txt",
		        "sequence_path": "874454.protein.sequences.v11.5.fa",
		        "enrichment_path": "874454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "874454.protein.info.v11.5.txt",
		        "node_list_path": "874454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "874454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudogymnoascusSpVkmF4246(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4246 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogymnoascusSpVkmF4246", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1420902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1420902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1420902.protein.info.v11.5.txt",
		        "node_list_path": "1420902.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumSpAt1b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. AT1b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumSpAt1b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "360911.protein.sequences.v11.5.fa",
		        "enrichment_path": "360911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360911.protein.info.v11.5.txt",
		        "node_list_path": "360911.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumKbs146Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium KBS146 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumKbs146Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "639030.clusters.info.v11.5.txt",
		        "cluster_tree_path": "639030.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "639030.clusters.proteins.v11.5.txt",
		        "sequence_path": "639030.protein.sequences.v11.5.fa",
		        "enrichment_path": "639030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "639030.protein.info.v11.5.txt",
		        "node_list_path": "639030.cluster.nodes.v11.5.txt",
		        "edge_list_path": "639030.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaSpM24t3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. M24T3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaSpM24t3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "932213.protein.sequences.v11.5.fa",
		        "enrichment_path": "932213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932213.protein.info.v11.5.txt",
		        "node_list_path": "932213.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrotaleaFlavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrotalea flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrotaleaFlavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "714549.clusters.info.v11.5.txt",
		        "cluster_tree_path": "714549.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "714549.clusters.proteins.v11.5.txt",
		        "sequence_path": "714549.protein.sequences.v11.5.fa",
		        "enrichment_path": "714549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "714549.protein.info.v11.5.txt",
		        "node_list_path": "714549.cluster.nodes.v11.5.txt",
		        "edge_list_path": "714549.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full3928Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_39_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full3928Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802690.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802690.protein.info.v11.5.txt",
		        "node_list_path": "1802690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusChisholmbacteriaBacteriumRifcsphigho201Full4812Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPHIGHO2_01_FULL_48_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsphigho201Full4812Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797589.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797589.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797589.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797589.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797589.protein.info.v11.5.txt",
		        "node_list_path": "1797589.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797589.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanibacterAnophelisNbrc107843Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janibacter anophelis NBRC 107843 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterAnophelisNbrc107843Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216968.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216968.protein.info.v11.5.txt",
		        "node_list_path": "1216968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusNantongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus nantongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusNantongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1796606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1796606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1796606.clusters.proteins.v11.5.txt",
		        "sequence_path": "1796606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796606.protein.info.v11.5.txt",
		        "node_list_path": "1796606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1796606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4234Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_12_FULL_42_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4234Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802314.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802314.protein.info.v11.5.txt",
		        "node_list_path": "1802314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesBungoensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces bungoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesBungoensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "285568.clusters.info.v11.5.txt",
		        "cluster_tree_path": "285568.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "285568.clusters.proteins.v11.5.txt",
		        "sequence_path": "285568.protein.sequences.v11.5.fa",
		        "enrichment_path": "285568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285568.protein.info.v11.5.txt",
		        "node_list_path": "285568.cluster.nodes.v11.5.txt",
		        "edge_list_path": "285568.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerrisporobacterGlycolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terrisporobacter glycolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrisporobacterGlycolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36841.protein.sequences.v11.5.fa",
		        "enrichment_path": "36841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36841.protein.info.v11.5.txt",
		        "node_list_path": "36841.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaceaeBacteriumKa00182(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonellaceae bacterium KA00182 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaceaeBacteriumKa00182", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1588748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1588748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1588748.protein.info.v11.5.txt",
		        "node_list_path": "1588748.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumRbg16439(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_43_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg16439", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802596.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802596.protein.info.v11.5.txt",
		        "node_list_path": "1802596.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumGa0074137Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium Ga0074137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumGa0074137Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752195.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752195.protein.info.v11.5.txt",
		        "node_list_path": "1752195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu023(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu023", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671649.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671649.protein.info.v11.5.txt",
		        "node_list_path": "1671649.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParoeduraPicta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paroedura picta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParoeduraPicta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "143630.protein.sequences.v11.5.fa",
		        "enrichment_path": "143630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "143630.protein.info.v11.5.txt",
		        "node_list_path": "143630.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerorhabdusFurcosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerorhabdus furcosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerorhabdusFurcosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118967.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118967.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118967.clusters.proteins.v11.5.txt",
		        "sequence_path": "118967.protein.sequences.v11.5.fa",
		        "enrichment_path": "118967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118967.protein.info.v11.5.txt",
		        "node_list_path": "118967.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118967.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumDesertiGimn1010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium deserti GIMN1.010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumDesertiGimn1010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "931089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "931089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "931089.clusters.proteins.v11.5.txt",
		        "sequence_path": "931089.protein.sequences.v11.5.fa",
		        "enrichment_path": "931089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "931089.protein.info.v11.5.txt",
		        "node_list_path": "931089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "931089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrochothrixThermosphacta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brochothrix thermosphacta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrochothrixThermosphacta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2756.protein.sequences.v11.5.fa",
		        "enrichment_path": "2756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2756.protein.info.v11.5.txt",
		        "node_list_path": "2756.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBeckwithbacteriaBacteriumGw2011Gwc14916(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium GW2011_GWC1_49_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumGw2011Gwc14916", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618372.protein.info.v11.5.txt",
		        "node_list_path": "1618372.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraWolbachiiSerovarCodiceStrCdcCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira wolbachii serovar Codice str. CDC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraWolbachiiSerovarCodiceStrCdcCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218599.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218599.protein.info.v11.5.txt",
		        "node_list_path": "1218599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAnthracisAmesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis Ames Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAnthracisAmesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "198094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "198094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "198094.clusters.proteins.v11.5.txt",
		        "sequence_path": "198094.protein.sequences.v11.5.fa",
		        "enrichment_path": "198094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198094.protein.info.v11.5.txt",
		        "node_list_path": "198094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "198094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusLugdunensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusLugdunensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28035.protein.sequences.v11.5.fa",
		        "enrichment_path": "28035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28035.protein.info.v11.5.txt",
		        "node_list_path": "28035.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriovoraxMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriovoraxMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "862908.protein.sequences.v11.5.fa",
		        "enrichment_path": "862908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862908.protein.info.v11.5.txt",
		        "node_list_path": "862908.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumHtcc2080Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2080 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumHtcc2080Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "247639.clusters.info.v11.5.txt",
		        "cluster_tree_path": "247639.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "247639.clusters.proteins.v11.5.txt",
		        "sequence_path": "247639.protein.sequences.v11.5.fa",
		        "enrichment_path": "247639.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247639.protein.info.v11.5.txt",
		        "node_list_path": "247639.cluster.nodes.v11.5.txt",
		        "edge_list_path": "247639.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PimelobacterSimplexCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pimelobacter simplex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PimelobacterSimplexCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2045.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2045.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2045.clusters.proteins.v11.5.txt",
		        "sequence_path": "2045.protein.sequences.v11.5.fa",
		        "enrichment_path": "2045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2045.protein.info.v11.5.txt",
		        "node_list_path": "2045.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2045.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriaceaeBacteriumDw12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriaceae bacterium DW12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriaceaeBacteriumDw12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1550091.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1550091.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1550091.clusters.proteins.v11.5.txt",
		        "sequence_path": "1550091.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550091.protein.info.v11.5.txt",
		        "node_list_path": "1550091.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1550091.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArmillariaGallica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Armillaria gallica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmillariaGallica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47427.protein.sequences.v11.5.fa",
		        "enrichment_path": "47427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47427.protein.info.v11.5.txt",
		        "node_list_path": "47427.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastomonasSpRac04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastomonas sp. RAC04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomonasSpRac04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1842535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842535.protein.info.v11.5.txt",
		        "node_list_path": "1842535.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusEvansiaMuelleri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Evansia muelleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusEvansiaMuelleri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1495769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495769.protein.info.v11.5.txt",
		        "node_list_path": "1495769.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylopilaSp73bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylopila sp. 73B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylopilaSp73bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120792.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120792.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120792.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120792.protein.info.v11.5.txt",
		        "node_list_path": "1120792.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120792.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoanaerosceptrumFracticalcisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerosceptrum fracticalcis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoanaerosceptrumFracticalcisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1712410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1712410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1712410.clusters.proteins.v11.5.txt",
		        "sequence_path": "1712410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1712410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1712410.protein.info.v11.5.txt",
		        "node_list_path": "1712410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1712410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumGa0077551Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0077551 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumGa0077551Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752185.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752185.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752185.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752185.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752185.protein.info.v11.5.txt",
		        "node_list_path": "1752185.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752185.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlebsiellaPneumoniaeSubspRhinoscleromatisAtcc13884Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. rhinoscleromatis ATCC 13884 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlebsiellaPneumoniaeSubspRhinoscleromatisAtcc13884Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "667127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "667127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "667127.clusters.proteins.v11.5.txt",
		        "sequence_path": "667127.protein.sequences.v11.5.fa",
		        "enrichment_path": "667127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "667127.protein.info.v11.5.txt",
		        "node_list_path": "667127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "667127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumCaeniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumCaeniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "490189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "490189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "490189.clusters.proteins.v11.5.txt",
		        "sequence_path": "490189.protein.sequences.v11.5.fa",
		        "enrichment_path": "490189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "490189.protein.info.v11.5.txt",
		        "node_list_path": "490189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "490189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PezolomaEricaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pezoloma ericae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PezolomaEricaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1745343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1745343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1745343.clusters.proteins.v11.5.txt",
		        "sequence_path": "1745343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1745343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1745343.protein.info.v11.5.txt",
		        "node_list_path": "1745343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1745343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpMrmr6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MRMR6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpMrmr6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1928617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1928617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1928617.clusters.proteins.v11.5.txt",
		        "sequence_path": "1928617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1928617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1928617.protein.info.v11.5.txt",
		        "node_list_path": "1928617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1928617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AbsidiaRepens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Absidia repens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AbsidiaRepens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "90262.protein.sequences.v11.5.fa",
		        "enrichment_path": "90262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "90262.protein.info.v11.5.txt",
		        "node_list_path": "90262.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalolactibacillusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halolactibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolactibacillusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "306540.protein.sequences.v11.5.fa",
		        "enrichment_path": "306540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306540.protein.info.v11.5.txt",
		        "node_list_path": "306540.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidianusManzaensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidianus manzaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidianusManzaensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "282676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "282676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "282676.clusters.proteins.v11.5.txt",
		        "sequence_path": "282676.protein.sequences.v11.5.fa",
		        "enrichment_path": "282676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "282676.protein.info.v11.5.txt",
		        "node_list_path": "282676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "282676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaDubliniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candida dubliniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaDubliniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42374.protein.sequences.v11.5.fa",
		        "enrichment_path": "42374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42374.protein.info.v11.5.txt",
		        "node_list_path": "42374.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinibacterRuber(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinibacter ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinibacterRuber", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "309807.protein.sequences.v11.5.fa",
		        "enrichment_path": "309807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "309807.protein.info.v11.5.txt",
		        "node_list_path": "309807.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaThermophilaTm1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina thermophila TM-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaThermophilaTm1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "523844.protein.sequences.v11.5.fa",
		        "enrichment_path": "523844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523844.protein.info.v11.5.txt",
		        "node_list_path": "523844.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4412(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_44_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4412", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802308.protein.info.v11.5.txt",
		        "node_list_path": "1802308.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumRifcsplowo202Full5016Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPLOWO2_02_FULL_50_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumRifcsplowo202Full5016Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801981.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801981.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801981.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801981.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801981.protein.info.v11.5.txt",
		        "node_list_path": "1801981.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801981.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioSpNor37Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. NOR37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioSpNor37Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798168.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798168.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798168.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798168.protein.info.v11.5.txt",
		        "node_list_path": "1798168.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798168.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyphomonasJannaschiana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas jannaschiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasJannaschiana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280952.protein.info.v11.5.txt",
		        "node_list_path": "1280952.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusLarvaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus larvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusLarvaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "697284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "697284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "697284.clusters.proteins.v11.5.txt",
		        "sequence_path": "697284.protein.sequences.v11.5.fa",
		        "enrichment_path": "697284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "697284.protein.info.v11.5.txt",
		        "node_list_path": "697284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "697284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EntomoplasmaLucivoraxAtcc49196(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Entomoplasma lucivorax ATCC 49196 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EntomoplasmaLucivoraxAtcc49196", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1399797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399797.protein.info.v11.5.txt",
		        "node_list_path": "1399797.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpCaviaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. caviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpCaviaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1915004.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1915004.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1915004.clusters.proteins.v11.5.txt",
		        "sequence_path": "1915004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915004.protein.info.v11.5.txt",
		        "node_list_path": "1915004.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1915004.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacterium4337Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 43-37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacterium4337Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895707.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895707.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895707.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895707.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895707.protein.info.v11.5.txt",
		        "node_list_path": "1895707.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895707.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TaylorellaEquigenitalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Taylorella equigenitalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TaylorellaEquigenitalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "937774.protein.sequences.v11.5.fa",
		        "enrichment_path": "937774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937774.protein.info.v11.5.txt",
		        "node_list_path": "937774.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlB24484(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL B-24484 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlB24484", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463833.protein.info.v11.5.txt",
		        "node_list_path": "1463833.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu033(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU033 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu033", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1676153.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676153.protein.info.v11.5.txt",
		        "node_list_path": "1676153.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasDenitrificansDsm6059(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas denitrificans DSM 6059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasDenitrificansDsm6059", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123010.protein.info.v11.5.txt",
		        "node_list_path": "1123010.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcanobacteriumPhocae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcanobacterium phocae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcanobacteriumPhocae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "131112.protein.sequences.v11.5.fa",
		        "enrichment_path": "131112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "131112.protein.info.v11.5.txt",
		        "node_list_path": "131112.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophothermusSpDtu052Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophothermus sp. DTU052 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophothermusSpDtu052Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671631.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671631.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671631.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671631.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671631.protein.info.v11.5.txt",
		        "node_list_path": "1671631.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671631.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SharpeaAzabuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sharpea azabuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SharpeaAzabuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410674.protein.info.v11.5.txt",
		        "node_list_path": "1410674.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermobifidaHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermobifida halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobifidaHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "483545.protein.sequences.v11.5.fa",
		        "enrichment_path": "483545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "483545.protein.info.v11.5.txt",
		        "node_list_path": "483545.protein.complete.v11.5.txt"
		    }
		]
    )()

def CharaBrauniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chara braunii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CharaBrauniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69332.clusters.proteins.v11.5.txt",
		        "sequence_path": "69332.protein.sequences.v11.5.fa",
		        "enrichment_path": "69332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69332.protein.info.v11.5.txt",
		        "node_list_path": "69332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpGw2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. GW2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpGw2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211114.protein.info.v11.5.txt",
		        "node_list_path": "1211114.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermacetogeniumPhaeumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermacetogenium phaeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermacetogeniumPhaeumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089553.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089553.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089553.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089553.protein.info.v11.5.txt",
		        "node_list_path": "1089553.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089553.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomagnumIshizawaiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomagnum ishizawai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomagnumIshizawaiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1760988.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1760988.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1760988.clusters.proteins.v11.5.txt",
		        "sequence_path": "1760988.protein.sequences.v11.5.fa",
		        "enrichment_path": "1760988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1760988.protein.info.v11.5.txt",
		        "node_list_path": "1760988.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1760988.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TepidibacterFormicigenesDsm15518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tepidibacter formicigenes DSM 15518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidibacterFormicigenesDsm15518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123349.protein.info.v11.5.txt",
		        "node_list_path": "1123349.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAle6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAle6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1266908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1266908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1266908.clusters.proteins.v11.5.txt",
		        "sequence_path": "1266908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1266908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1266908.protein.info.v11.5.txt",
		        "node_list_path": "1266908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1266908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GrimontiaIndicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Grimontia indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GrimontiaIndicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1056512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1056512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1056512.clusters.proteins.v11.5.txt",
		        "sequence_path": "1056512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1056512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1056512.protein.info.v11.5.txt",
		        "node_list_path": "1056512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1056512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillibacterSpEr4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. ER4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSpEr4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1519439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1519439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1519439.clusters.proteins.v11.5.txt",
		        "sequence_path": "1519439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519439.protein.info.v11.5.txt",
		        "node_list_path": "1519439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1519439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag460(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:460 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag460", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263024.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263024.protein.info.v11.5.txt",
		        "node_list_path": "1263024.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterSpNctc13003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. NCTC 13003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSpNctc13003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660064.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660064.protein.info.v11.5.txt",
		        "node_list_path": "1660064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterThereiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter thereius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterThereiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "544718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "544718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "544718.clusters.proteins.v11.5.txt",
		        "sequence_path": "544718.protein.sequences.v11.5.fa",
		        "enrichment_path": "544718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "544718.protein.info.v11.5.txt",
		        "node_list_path": "544718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "544718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3713(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_37_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3713", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802057.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802057.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802057.protein.info.v11.5.txt",
		        "node_list_path": "1802057.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmoSalar(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salmo salar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmoSalar", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8030.protein.sequences.v11.5.fa",
		        "enrichment_path": "8030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8030.protein.info.v11.5.txt",
		        "node_list_path": "8030.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobiBacteriumNicil2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobi bacterium NICIL-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiBacteriumNicil2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1662223.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1662223.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1662223.clusters.proteins.v11.5.txt",
		        "sequence_path": "1662223.protein.sequences.v11.5.fa",
		        "enrichment_path": "1662223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1662223.protein.info.v11.5.txt",
		        "node_list_path": "1662223.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1662223.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag568(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:568 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag568", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262821.protein.info.v11.5.txt",
		        "node_list_path": "1262821.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSabinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sabinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSabinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1268072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1268072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1268072.clusters.proteins.v11.5.txt",
		        "sequence_path": "1268072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268072.protein.info.v11.5.txt",
		        "node_list_path": "1268072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1268072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CercocebusAtys(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cercocebus atys graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CercocebusAtys", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9531.protein.sequences.v11.5.fa",
		        "enrichment_path": "9531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9531.protein.info.v11.5.txt",
		        "node_list_path": "9531.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaWashoensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella washoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaWashoensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094563.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094563.protein.info.v11.5.txt",
		        "node_list_path": "1094563.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentisphaeraeBacteriumGwf23869Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_38_69 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentisphaeraeBacteriumGwf23869Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798570.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798570.protein.info.v11.5.txt",
		        "node_list_path": "1798570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KitasatosporaCheerisanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora cheerisanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaCheerisanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348663.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348663.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348663.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348663.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348663.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348663.protein.info.v11.5.txt",
		        "node_list_path": "1348663.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348663.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DuganellaSacchari(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Duganella sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSacchari", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "551987.protein.sequences.v11.5.fa",
		        "enrichment_path": "551987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "551987.protein.info.v11.5.txt",
		        "node_list_path": "551987.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4186(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_41_86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4186", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817821.protein.info.v11.5.txt",
		        "node_list_path": "1817821.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaViolaceaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella violacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaViolaceaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "637905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "637905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "637905.clusters.proteins.v11.5.txt",
		        "sequence_path": "637905.protein.sequences.v11.5.fa",
		        "enrichment_path": "637905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637905.protein.info.v11.5.txt",
		        "node_list_path": "637905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "637905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PatulibacterMinatonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Patulibacter minatonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PatulibacterMinatonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "929712.protein.sequences.v11.5.fa",
		        "enrichment_path": "929712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929712.protein.info.v11.5.txt",
		        "node_list_path": "929712.protein.complete.v11.5.txt"
		    }
		]
    )()

def RufibacterTibetensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rufibacter tibetensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RufibacterTibetensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "512763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "512763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "512763.clusters.proteins.v11.5.txt",
		        "sequence_path": "512763.protein.sequences.v11.5.fa",
		        "enrichment_path": "512763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512763.protein.info.v11.5.txt",
		        "node_list_path": "512763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "512763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifoxyc12Full6523(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFOXYC12_FULL_65_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifoxyc12Full6523", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797572.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797572.protein.info.v11.5.txt",
		        "node_list_path": "1797572.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlaciecolaPsychrophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaPsychrophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1129794.protein.sequences.v11.5.fa",
		        "enrichment_path": "1129794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1129794.protein.info.v11.5.txt",
		        "node_list_path": "1129794.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionCpr2BacteriumGw2011Gwc23910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR2 bacterium GW2011_GWC2_39_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionCpr2BacteriumGw2011Gwc23910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618345.protein.info.v11.5.txt",
		        "node_list_path": "1618345.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumKh1t2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium KH1T2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumKh1t2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855374.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855374.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855374.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855374.protein.info.v11.5.txt",
		        "node_list_path": "1855374.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855374.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaAltamirensisNbrc108246(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia altamirensis NBRC 108246 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAltamirensisNbrc108246", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210064.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210064.protein.info.v11.5.txt",
		        "node_list_path": "1210064.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillibacterSpPc13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. PC13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillibacterSpPc13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855299.protein.info.v11.5.txt",
		        "node_list_path": "1855299.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4417(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_44_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4417", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802668.protein.info.v11.5.txt",
		        "node_list_path": "1802668.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusEquorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus equorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusEquorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1159488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159488.protein.info.v11.5.txt",
		        "node_list_path": "1159488.protein.complete.v11.5.txt"
		    }
		]
    )()

def MalusBaccata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Malus baccata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalusBaccata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "106549.protein.sequences.v11.5.fa",
		        "enrichment_path": "106549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106549.protein.info.v11.5.txt",
		        "node_list_path": "106549.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlF6676(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL F-6676 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlF6676", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463878.protein.info.v11.5.txt",
		        "node_list_path": "1463878.protein.complete.v11.5.txt"
		    }
		]
    )()

def MerdimonasFaecisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Merdimonas faecis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MerdimonasFaecisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1653435.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1653435.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1653435.clusters.proteins.v11.5.txt",
		        "sequence_path": "1653435.protein.sequences.v11.5.fa",
		        "enrichment_path": "1653435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1653435.protein.info.v11.5.txt",
		        "node_list_path": "1653435.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1653435.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaSpNbrc110055(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110055 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSpNbrc110055", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1570344.protein.sequences.v11.5.fa",
		        "enrichment_path": "1570344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1570344.protein.info.v11.5.txt",
		        "node_list_path": "1570344.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusErwiniaHaradaeaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Erwinia haradaeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusErwiniaHaradaeaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1922217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1922217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1922217.clusters.proteins.v11.5.txt",
		        "sequence_path": "1922217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1922217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1922217.protein.info.v11.5.txt",
		        "node_list_path": "1922217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1922217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MedicagoTruncatula(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Medicago truncatula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MedicagoTruncatula", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3880.protein.sequences.v11.5.fa",
		        "enrichment_path": "3880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3880.protein.info.v11.5.txt",
		        "node_list_path": "3880.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCaspium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium caspium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCaspium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121355.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121355.protein.info.v11.5.txt",
		        "node_list_path": "1121355.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumRosaNbrc15208Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium rosa NBRC 15208 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumRosaNbrc15208Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219053.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219053.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219053.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219053.protein.info.v11.5.txt",
		        "node_list_path": "1219053.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219053.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCytotoxicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cytotoxicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCytotoxicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "315749.protein.sequences.v11.5.fa",
		        "enrichment_path": "315749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "315749.protein.info.v11.5.txt",
		        "node_list_path": "315749.protein.complete.v11.5.txt"
		    }
		]
    )()

def SuillusLuteusUhSluLm8N1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Suillus luteus UH-Slu-Lm8-n1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SuillusLuteusUhSluLm8N1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "930992.protein.sequences.v11.5.fa",
		        "enrichment_path": "930992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930992.protein.info.v11.5.txt",
		        "node_list_path": "930992.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaPiezophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia piezophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaPiezophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265503.protein.info.v11.5.txt",
		        "node_list_path": "1265503.protein.complete.v11.5.txt"
		    }
		]
    )()

def TyzzerellaNexilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tyzzerella nexilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TyzzerellaNexilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "500632.clusters.info.v11.5.txt",
		        "cluster_tree_path": "500632.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "500632.clusters.proteins.v11.5.txt",
		        "sequence_path": "500632.protein.sequences.v11.5.fa",
		        "enrichment_path": "500632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500632.protein.info.v11.5.txt",
		        "node_list_path": "500632.cluster.nodes.v11.5.txt",
		        "edge_list_path": "500632.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh8020(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh8020", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "32052.protein.sequences.v11.5.fa",
		        "enrichment_path": "32052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "32052.protein.info.v11.5.txt",
		        "node_list_path": "32052.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpNb68Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. NB68 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpNb68Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1342302.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1342302.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1342302.clusters.proteins.v11.5.txt",
		        "sequence_path": "1342302.protein.sequences.v11.5.fa",
		        "enrichment_path": "1342302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1342302.protein.info.v11.5.txt",
		        "node_list_path": "1342302.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1342302.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitritaleaHalalkaliphilaLw7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitritalea halalkaliphila LW7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitritaleaHalalkaliphilaLw7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1189621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1189621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1189621.clusters.proteins.v11.5.txt",
		        "sequence_path": "1189621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1189621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1189621.protein.info.v11.5.txt",
		        "node_list_path": "1189621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1189621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusZeaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus zeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusZeaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423816.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423816.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423816.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423816.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423816.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423816.protein.info.v11.5.txt",
		        "node_list_path": "1423816.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423816.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPseudotuberculosis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pseudotuberculosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPseudotuberculosis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1719.protein.sequences.v11.5.fa",
		        "enrichment_path": "1719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1719.protein.info.v11.5.txt",
		        "node_list_path": "1719.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPortnoybacteriaBacteriumRifcsplowo201Full4311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RIFCSPLOWO2_01_FULL_43_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRifcsplowo201Full4311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802000.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802000.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802000.protein.info.v11.5.txt",
		        "node_list_path": "1802000.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterPyloriSa213aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori SA213A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterPyloriSa213aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1345592.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1345592.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1345592.clusters.proteins.v11.5.txt",
		        "sequence_path": "1345592.protein.sequences.v11.5.fa",
		        "enrichment_path": "1345592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1345592.protein.info.v11.5.txt",
		        "node_list_path": "1345592.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1345592.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RheinheimeraPerlucida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera perlucida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraPerlucida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123054.protein.info.v11.5.txt",
		        "node_list_path": "1123054.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusOrisPb013t23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oris PB013T23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOrisPb013t23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "908339.clusters.info.v11.5.txt",
		        "cluster_tree_path": "908339.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "908339.clusters.proteins.v11.5.txt",
		        "sequence_path": "908339.protein.sequences.v11.5.fa",
		        "enrichment_path": "908339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908339.protein.info.v11.5.txt",
		        "node_list_path": "908339.cluster.nodes.v11.5.txt",
		        "edge_list_path": "908339.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9314Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9314Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "167548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "167548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "167548.clusters.proteins.v11.5.txt",
		        "sequence_path": "167548.protein.sequences.v11.5.fa",
		        "enrichment_path": "167548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167548.protein.info.v11.5.txt",
		        "node_list_path": "167548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "167548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OhtaekwangiaKoreensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ohtaekwangia koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OhtaekwangiaKoreensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "688867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "688867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "688867.clusters.proteins.v11.5.txt",
		        "sequence_path": "688867.protein.sequences.v11.5.fa",
		        "enrichment_path": "688867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688867.protein.info.v11.5.txt",
		        "node_list_path": "688867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "688867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsphigho202Full3613(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_02_FULL_36_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho202Full3613", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797768.protein.info.v11.5.txt",
		        "node_list_path": "1797768.protein.complete.v11.5.txt"
		    }
		]
    )()

def RikenellaceaeBacteriumDtu002(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium DTU002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RikenellaceaeBacteriumDtu002", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671665.protein.info.v11.5.txt",
		        "node_list_path": "1671665.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9301Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9301Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "167546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "167546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "167546.clusters.proteins.v11.5.txt",
		        "sequence_path": "167546.protein.sequences.v11.5.fa",
		        "enrichment_path": "167546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "167546.protein.info.v11.5.txt",
		        "node_list_path": "167546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "167546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpX13sy08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. X13SY08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpX13sy08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1676616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1676616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1676616.protein.info.v11.5.txt",
		        "node_list_path": "1676616.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaAuratinigra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora auratinigra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaAuratinigra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "261654.protein.sequences.v11.5.fa",
		        "enrichment_path": "261654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "261654.protein.info.v11.5.txt",
		        "node_list_path": "261654.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag533Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:533 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag533Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262818.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262818.protein.info.v11.5.txt",
		        "node_list_path": "1262818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PoeciliaReticulata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Poecilia reticulata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PoeciliaReticulata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8081.protein.sequences.v11.5.fa",
		        "enrichment_path": "8081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8081.protein.info.v11.5.txt",
		        "node_list_path": "8081.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumCv2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium cv2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumCv2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1627893.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1627893.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1627893.clusters.proteins.v11.5.txt",
		        "sequence_path": "1627893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1627893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1627893.protein.info.v11.5.txt",
		        "node_list_path": "1627893.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1627893.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldanaerobiusFijiensisDsm17918Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldanaerobius fijiensis DSM 17918 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldanaerobiusFijiensisDsm17918Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121256.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121256.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121256.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121256.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121256.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121256.protein.info.v11.5.txt",
		        "node_list_path": "1121256.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121256.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterMacacae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter macacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterMacacae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1357400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1357400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1357400.protein.info.v11.5.txt",
		        "node_list_path": "1357400.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSp73h25apCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. 73H25AP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSp73h25apCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "864570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "864570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "864570.clusters.proteins.v11.5.txt",
		        "sequence_path": "864570.protein.sequences.v11.5.fa",
		        "enrichment_path": "864570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864570.protein.info.v11.5.txt",
		        "node_list_path": "864570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "864570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterLuteus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterLuteus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "572036.protein.sequences.v11.5.fa",
		        "enrichment_path": "572036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572036.protein.info.v11.5.txt",
		        "node_list_path": "572036.protein.complete.v11.5.txt"
		    }
		]
    )()

def FischerellaSpNies3754(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fischerella sp. NIES-3754 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FischerellaSpNies3754", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752063.protein.info.v11.5.txt",
		        "node_list_path": "1752063.protein.complete.v11.5.txt"
		    }
		]
    )()

def StappiaSp22iiS9Z10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stappia sp. 22II-S9-Z10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StappiaSp22iiS9Z10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1317123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1317123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1317123.clusters.proteins.v11.5.txt",
		        "sequence_path": "1317123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1317123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1317123.protein.info.v11.5.txt",
		        "node_list_path": "1317123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1317123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GluconobacterRoseus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterRoseus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "586239.protein.sequences.v11.5.fa",
		        "enrichment_path": "586239.protein.enrichment.terms.v11.5.txt",
		        "info_path": "586239.protein.info.v11.5.txt",
		        "node_list_path": "586239.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusOralisAtcc49296(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis ATCC49296 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOralisAtcc49296", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888049.protein.sequences.v11.5.fa",
		        "enrichment_path": "888049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888049.protein.info.v11.5.txt",
		        "node_list_path": "888049.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPhytoplasmaPruniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma pruni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPhytoplasmaPruniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "479893.clusters.info.v11.5.txt",
		        "cluster_tree_path": "479893.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "479893.clusters.proteins.v11.5.txt",
		        "sequence_path": "479893.protein.sequences.v11.5.fa",
		        "enrichment_path": "479893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479893.protein.info.v11.5.txt",
		        "node_list_path": "479893.cluster.nodes.v11.5.txt",
		        "edge_list_path": "479893.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusRhodniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus rhodnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusRhodniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1273125.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1273125.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1273125.clusters.proteins.v11.5.txt",
		        "sequence_path": "1273125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1273125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1273125.protein.info.v11.5.txt",
		        "node_list_path": "1273125.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1273125.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeptunomonasPhycophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neptunomonas phycophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptunomonasPhycophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1572645.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1572645.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1572645.clusters.proteins.v11.5.txt",
		        "sequence_path": "1572645.protein.sequences.v11.5.fa",
		        "enrichment_path": "1572645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1572645.protein.info.v11.5.txt",
		        "node_list_path": "1572645.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1572645.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaFlocculareAtcc27399(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma flocculare ATCC 27399 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaFlocculareAtcc27399", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743971.protein.sequences.v11.5.fa",
		        "enrichment_path": "743971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743971.protein.info.v11.5.txt",
		        "node_list_path": "743971.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterSpMwhAdlerW8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. MWH-Adler-W8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterSpMwhAdlerW8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1819727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1819727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1819727.protein.info.v11.5.txt",
		        "node_list_path": "1819727.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapsicumChinenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capsicum chinense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsicumChinenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "80379.clusters.info.v11.5.txt",
		        "cluster_tree_path": "80379.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "80379.clusters.proteins.v11.5.txt",
		        "sequence_path": "80379.protein.sequences.v11.5.fa",
		        "enrichment_path": "80379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80379.protein.info.v11.5.txt",
		        "node_list_path": "80379.cluster.nodes.v11.5.txt",
		        "edge_list_path": "80379.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchlesneriaPaludicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schlesneria paludicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchlesneriaPaludicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123242.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123242.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123242.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123242.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123242.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123242.protein.info.v11.5.txt",
		        "node_list_path": "1123242.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123242.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium6217Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 62-17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium6217Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895810.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895810.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895810.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895810.protein.info.v11.5.txt",
		        "node_list_path": "1895810.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895810.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwe13228(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWE1_32_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwe13228", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618760.protein.info.v11.5.txt",
		        "node_list_path": "1618760.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "415425.clusters.info.v11.5.txt",
		        "cluster_tree_path": "415425.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "415425.clusters.proteins.v11.5.txt",
		        "sequence_path": "415425.protein.sequences.v11.5.fa",
		        "enrichment_path": "415425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "415425.protein.info.v11.5.txt",
		        "node_list_path": "415425.cluster.nodes.v11.5.txt",
		        "edge_list_path": "415425.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusJorgensenbacteriaBacteriumGw2011Gwb1499(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GW2011_GWB1_49_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGw2011Gwb1499", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618664.protein.info.v11.5.txt",
		        "node_list_path": "1618664.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogulbenkianiaSpNh8bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania sp. NH8B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogulbenkianiaSpNh8bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "748280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "748280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "748280.clusters.proteins.v11.5.txt",
		        "sequence_path": "748280.protein.sequences.v11.5.fa",
		        "enrichment_path": "748280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748280.protein.info.v11.5.txt",
		        "node_list_path": "748280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "748280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumGilvum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium gilvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumGilvum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "350054.protein.sequences.v11.5.fa",
		        "enrichment_path": "350054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "350054.protein.info.v11.5.txt",
		        "node_list_path": "350054.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusDentisani7746Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dentisani 7746 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDentisani7746Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1297534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1297534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1297534.clusters.proteins.v11.5.txt",
		        "sequence_path": "1297534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297534.protein.info.v11.5.txt",
		        "node_list_path": "1297534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1297534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MobiluncusMulierisAtcc35239Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris ATCC 35239 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobiluncusMulierisAtcc35239Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "871571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "871571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "871571.clusters.proteins.v11.5.txt",
		        "sequence_path": "871571.protein.sequences.v11.5.fa",
		        "enrichment_path": "871571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871571.protein.info.v11.5.txt",
		        "node_list_path": "871571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "871571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotodesmusKatoptronCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photodesmus katoptron Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotodesmusKatoptronCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28176.clusters.proteins.v11.5.txt",
		        "sequence_path": "28176.protein.sequences.v11.5.fa",
		        "enrichment_path": "28176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28176.protein.info.v11.5.txt",
		        "node_list_path": "28176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusCastoreus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus castoreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusCastoreus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123299.protein.info.v11.5.txt",
		        "node_list_path": "1123299.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAzambacteriaBacteriumRifcsplowo201Full4625Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPLOWO2_01_FULL_46_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsplowo201Full4625Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797298.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797298.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797298.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797298.protein.info.v11.5.txt",
		        "node_list_path": "1797298.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797298.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsphigho202Full4611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO2_02_FULL_46_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202Full4611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801820.protein.info.v11.5.txt",
		        "node_list_path": "1801820.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermanaerovibrioVeloxCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermanaerovibrio velox Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermanaerovibrioVeloxCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926567.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926567.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926567.clusters.proteins.v11.5.txt",
		        "sequence_path": "926567.protein.sequences.v11.5.fa",
		        "enrichment_path": "926567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926567.protein.info.v11.5.txt",
		        "node_list_path": "926567.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926567.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSilaceus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces silaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSilaceus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "545123.protein.sequences.v11.5.fa",
		        "enrichment_path": "545123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545123.protein.info.v11.5.txt",
		        "node_list_path": "545123.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpAi1a2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ai1a2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpAi1a2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "196490.protein.sequences.v11.5.fa",
		        "enrichment_path": "196490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "196490.protein.info.v11.5.txt",
		        "node_list_path": "196490.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterGinsenosidimutans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter ginsenosidimutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterGinsenosidimutans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "687842.protein.sequences.v11.5.fa",
		        "enrichment_path": "687842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "687842.protein.info.v11.5.txt",
		        "node_list_path": "687842.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusEntericus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus entericus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusEntericus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123302.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123302.protein.info.v11.5.txt",
		        "node_list_path": "1123302.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemonchusPlaceiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemonchus placei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemonchusPlaceiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6290.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6290.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6290.clusters.proteins.v11.5.txt",
		        "sequence_path": "6290.protein.sequences.v11.5.fa",
		        "enrichment_path": "6290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6290.protein.info.v11.5.txt",
		        "node_list_path": "6290.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6290.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AkkermansiaGlycaniphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Akkermansia glycaniphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AkkermansiaGlycaniphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1679444.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1679444.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1679444.clusters.proteins.v11.5.txt",
		        "sequence_path": "1679444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679444.protein.info.v11.5.txt",
		        "node_list_path": "1679444.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1679444.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumFirm05(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumFirm05", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674843.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674843.protein.info.v11.5.txt",
		        "node_list_path": "1674843.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSubterrani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter subterrani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSubterrani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658765.protein.info.v11.5.txt",
		        "node_list_path": "1658765.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusStrNatl2a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus str. NATL2A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusStrNatl2a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59920.protein.sequences.v11.5.fa",
		        "enrichment_path": "59920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59920.protein.info.v11.5.txt",
		        "node_list_path": "59920.protein.complete.v11.5.txt"
		    }
		]
    )()

def MitsuokellaMultacidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mitsuokella multacida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MitsuokellaMultacidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "500635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "500635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "500635.clusters.proteins.v11.5.txt",
		        "sequence_path": "500635.protein.sequences.v11.5.fa",
		        "enrichment_path": "500635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500635.protein.info.v11.5.txt",
		        "node_list_path": "500635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "500635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ComamonasTestosteroniCnb2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas testosteroni CNB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonasTestosteroniCnb2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "688245.clusters.info.v11.5.txt",
		        "cluster_tree_path": "688245.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "688245.clusters.proteins.v11.5.txt",
		        "sequence_path": "688245.protein.sequences.v11.5.fa",
		        "enrichment_path": "688245.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688245.protein.info.v11.5.txt",
		        "node_list_path": "688245.cluster.nodes.v11.5.txt",
		        "edge_list_path": "688245.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YarrowiaLipolyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yarrowia lipolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YarrowiaLipolyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4952.clusters.proteins.v11.5.txt",
		        "sequence_path": "4952.protein.sequences.v11.5.fa",
		        "enrichment_path": "4952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4952.protein.info.v11.5.txt",
		        "node_list_path": "4952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifoxyd1Full4124(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFOXYD1_FULL_41_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifoxyd1Full4124", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802094.protein.info.v11.5.txt",
		        "node_list_path": "1802094.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeishmaniaPanamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leishmania panamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeishmaniaPanamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5679.clusters.proteins.v11.5.txt",
		        "sequence_path": "5679.protein.sequences.v11.5.fa",
		        "enrichment_path": "5679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5679.protein.info.v11.5.txt",
		        "node_list_path": "5679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumMongolenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium mongolense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumMongolenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1079460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1079460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1079460.clusters.proteins.v11.5.txt",
		        "sequence_path": "1079460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1079460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1079460.protein.info.v11.5.txt",
		        "node_list_path": "1079460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1079460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKimchiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kimchiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKimchiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "993692.protein.sequences.v11.5.fa",
		        "enrichment_path": "993692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "993692.protein.info.v11.5.txt",
		        "node_list_path": "993692.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRifcsplowo202Full7116(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RIFCSPLOWO2_02_FULL_71_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRifcsplowo202Full7116", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797672.protein.info.v11.5.txt",
		        "node_list_path": "1797672.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCoelicolor(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces coelicolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCoelicolor", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "100226.protein.sequences.v11.5.fa",
		        "enrichment_path": "100226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "100226.protein.info.v11.5.txt",
		        "node_list_path": "100226.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaWadeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia wadei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaWadeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888055.clusters.proteins.v11.5.txt",
		        "sequence_path": "888055.protein.sequences.v11.5.fa",
		        "enrichment_path": "888055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888055.protein.info.v11.5.txt",
		        "node_list_path": "888055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseospirillumParvum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseospirillum parvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseospirillumParvum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83401.protein.sequences.v11.5.fa",
		        "enrichment_path": "83401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83401.protein.info.v11.5.txt",
		        "node_list_path": "83401.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSp4681(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. 4681 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSp4681", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1525715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1525715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1525715.protein.info.v11.5.txt",
		        "node_list_path": "1525715.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaBirtlesiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella birtlesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaBirtlesiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1201035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1201035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1201035.clusters.proteins.v11.5.txt",
		        "sequence_path": "1201035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1201035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1201035.protein.info.v11.5.txt",
		        "node_list_path": "1201035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1201035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIs1264Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1264 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIs1264Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834158.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834158.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834158.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834158.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834158.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834158.protein.info.v11.5.txt",
		        "node_list_path": "1834158.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834158.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BipolarisMaydisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris maydis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisMaydisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5016.clusters.proteins.v11.5.txt",
		        "sequence_path": "5016.protein.sequences.v11.5.fa",
		        "enrichment_path": "5016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5016.protein.info.v11.5.txt",
		        "node_list_path": "5016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacteriumCg1024916(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_49_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024916", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805290.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805290.protein.info.v11.5.txt",
		        "node_list_path": "1805290.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag127Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:127 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag127Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262774.protein.info.v11.5.txt",
		        "node_list_path": "1262774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpWmmb322Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. WMMB 322 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpWmmb322Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1286821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1286821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1286821.clusters.proteins.v11.5.txt",
		        "sequence_path": "1286821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1286821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1286821.protein.info.v11.5.txt",
		        "node_list_path": "1286821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1286821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaBoryanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya boryana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaBoryanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272134.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272134.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272134.clusters.proteins.v11.5.txt",
		        "sequence_path": "272134.protein.sequences.v11.5.fa",
		        "enrichment_path": "272134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272134.protein.info.v11.5.txt",
		        "node_list_path": "272134.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272134.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterGuillouiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter guillouiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterGuillouiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217656.protein.info.v11.5.txt",
		        "node_list_path": "1217656.protein.complete.v11.5.txt"
		    }
		]
    )()

def DialisterPneumosintes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dialister pneumosintes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterPneumosintes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39950.protein.sequences.v11.5.fa",
		        "enrichment_path": "39950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39950.protein.info.v11.5.txt",
		        "node_list_path": "39950.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusCetiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCetiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122146.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122146.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122146.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122146.protein.info.v11.5.txt",
		        "node_list_path": "1122146.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122146.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfomonileTiedjei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfomonile tiedjei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfomonileTiedjei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "706587.protein.sequences.v11.5.fa",
		        "enrichment_path": "706587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706587.protein.info.v11.5.txt",
		        "node_list_path": "706587.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpHensonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. hensonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpHensonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1922337.protein.sequences.v11.5.fa",
		        "enrichment_path": "1922337.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1922337.protein.info.v11.5.txt",
		        "node_list_path": "1922337.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802516.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802516.protein.info.v11.5.txt",
		        "node_list_path": "1802516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaRattimassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella rattimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaRattimassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094556.protein.info.v11.5.txt",
		        "node_list_path": "1094556.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpSrs2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SRS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpSrs2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "133190.protein.sequences.v11.5.fa",
		        "enrichment_path": "133190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133190.protein.info.v11.5.txt",
		        "node_list_path": "133190.protein.complete.v11.5.txt"
		    }
		]
    )()

def DehalococcoidesSpJdfr54(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides sp. JdFR-54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DehalococcoidesSpJdfr54", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935047.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935047.protein.info.v11.5.txt",
		        "node_list_path": "1935047.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseomonasRoseaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseomonasRoseaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "198092.clusters.info.v11.5.txt",
		        "cluster_tree_path": "198092.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "198092.clusters.proteins.v11.5.txt",
		        "sequence_path": "198092.protein.sequences.v11.5.fa",
		        "enrichment_path": "198092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198092.protein.info.v11.5.txt",
		        "node_list_path": "198092.cluster.nodes.v11.5.txt",
		        "edge_list_path": "198092.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsplowo201Full4826Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_01_FULL_48_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo201Full4826Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802126.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802126.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802126.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802126.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802126.protein.info.v11.5.txt",
		        "node_list_path": "1802126.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802126.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterGudaonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter gudaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterGudaonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "375760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "375760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "375760.clusters.proteins.v11.5.txt",
		        "sequence_path": "375760.protein.sequences.v11.5.fa",
		        "enrichment_path": "375760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "375760.protein.info.v11.5.txt",
		        "node_list_path": "375760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "375760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo2024111(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_02_41_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo2024111", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797731.protein.info.v11.5.txt",
		        "node_list_path": "1797731.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumRifcsplowo201Full5912Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO2_01_FULL_59_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201Full5912Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797946.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797946.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797946.protein.info.v11.5.txt",
		        "node_list_path": "1797946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptospiraBorgpeterseniiSerovarPomonaStr200901868(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii serovar Pomona str. 200901868 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraBorgpeterseniiSerovarPomonaStr200901868", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1192866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1192866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1192866.protein.info.v11.5.txt",
		        "node_list_path": "1192866.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerriphaselusSpR1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferriphaselus sp. R1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerriphaselusSpR1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1485544.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1485544.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1485544.clusters.proteins.v11.5.txt",
		        "sequence_path": "1485544.protein.sequences.v11.5.fa",
		        "enrichment_path": "1485544.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1485544.protein.info.v11.5.txt",
		        "node_list_path": "1485544.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1485544.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalinisporaPacificaDsm45544(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45544 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinisporaPacificaDsm45544", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999543.protein.sequences.v11.5.fa",
		        "enrichment_path": "999543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999543.protein.info.v11.5.txt",
		        "node_list_path": "999543.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanobacillusPicturaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus picturae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusPicturaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "171693.clusters.info.v11.5.txt",
		        "cluster_tree_path": "171693.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "171693.clusters.proteins.v11.5.txt",
		        "sequence_path": "171693.protein.sequences.v11.5.fa",
		        "enrichment_path": "171693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "171693.protein.info.v11.5.txt",
		        "node_list_path": "171693.cluster.nodes.v11.5.txt",
		        "edge_list_path": "171693.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OchotonaPrincepsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ochotona princeps Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OchotonaPrincepsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9978.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9978.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9978.clusters.proteins.v11.5.txt",
		        "sequence_path": "9978.protein.sequences.v11.5.fa",
		        "enrichment_path": "9978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9978.protein.info.v11.5.txt",
		        "node_list_path": "9978.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9978.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaGrimmiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia grimmiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaGrimmiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071679.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071679.protein.info.v11.5.txt",
		        "node_list_path": "1071679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE3251(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E3251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE3251", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834144.protein.info.v11.5.txt",
		        "node_list_path": "1834144.protein.complete.v11.5.txt"
		    }
		]
    )()

def LoktanellaCinnabarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella cinnabarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoktanellaCinnabarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1337093.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1337093.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1337093.clusters.proteins.v11.5.txt",
		        "sequence_path": "1337093.protein.sequences.v11.5.fa",
		        "enrichment_path": "1337093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1337093.protein.info.v11.5.txt",
		        "node_list_path": "1337093.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1337093.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumPaucimobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium paucimobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumPaucimobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1346330.protein.sequences.v11.5.fa",
		        "enrichment_path": "1346330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1346330.protein.info.v11.5.txt",
		        "node_list_path": "1346330.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg135211(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_52_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg135211", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797829.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797829.protein.info.v11.5.txt",
		        "node_list_path": "1797829.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodoferaxFermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodoferax fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodoferaxFermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28066.protein.sequences.v11.5.fa",
		        "enrichment_path": "28066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28066.protein.info.v11.5.txt",
		        "node_list_path": "28066.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinitogaHydrogenitoleransDsm16785Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinitoga hydrogenitolerans DSM 16785 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinitogaHydrogenitoleransDsm16785Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122195.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122195.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122195.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122195.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122195.protein.info.v11.5.txt",
		        "node_list_path": "1122195.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122195.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9107(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9107", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59921.protein.sequences.v11.5.fa",
		        "enrichment_path": "59921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59921.protein.info.v11.5.txt",
		        "node_list_path": "59921.protein.complete.v11.5.txt"
		    }
		]
    )()

def MuricaudaSpCp2a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Muricauda sp. CP2A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuricaudaSpCp2a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1848189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848189.protein.info.v11.5.txt",
		        "node_list_path": "1848189.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasChromatireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas chromatireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasChromatireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "507626.protein.sequences.v11.5.fa",
		        "enrichment_path": "507626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "507626.protein.info.v11.5.txt",
		        "node_list_path": "507626.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaBryantiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema bryantii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaBryantiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "877418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "877418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "877418.clusters.proteins.v11.5.txt",
		        "sequence_path": "877418.protein.sequences.v11.5.fa",
		        "enrichment_path": "877418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877418.protein.info.v11.5.txt",
		        "node_list_path": "877418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "877418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifcsphigho201Full4213(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO2_01_FULL_42_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201Full4213", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802617.protein.info.v11.5.txt",
		        "node_list_path": "1802617.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioEzuraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ezurae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioEzuraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219080.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219080.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219080.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219080.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219080.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219080.protein.info.v11.5.txt",
		        "node_list_path": "1219080.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219080.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PristionchusPacificus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pristionchus pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PristionchusPacificus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "54126.protein.sequences.v11.5.fa",
		        "enrichment_path": "54126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54126.protein.info.v11.5.txt",
		        "node_list_path": "54126.protein.complete.v11.5.txt"
		    }
		]
    )()

def AromatoleumToluclasticumAtcc700605Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aromatoleum toluclasticum ATCC 700605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AromatoleumToluclasticumAtcc700605Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1261621.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1261621.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1261621.clusters.proteins.v11.5.txt",
		        "sequence_path": "1261621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1261621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1261621.protein.info.v11.5.txt",
		        "node_list_path": "1261621.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1261621.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnhydraLutrisKenyoniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enhydra lutris kenyoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnhydraLutrisKenyoniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391180.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391180.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391180.clusters.proteins.v11.5.txt",
		        "sequence_path": "391180.protein.sequences.v11.5.fa",
		        "enrichment_path": "391180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391180.protein.info.v11.5.txt",
		        "node_list_path": "391180.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391180.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchaedlerellaArabinosiphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schaedlerella arabinosiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchaedlerellaArabinosiphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2044587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2044587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2044587.clusters.proteins.v11.5.txt",
		        "sequence_path": "2044587.protein.sequences.v11.5.fa",
		        "enrichment_path": "2044587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2044587.protein.info.v11.5.txt",
		        "node_list_path": "2044587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2044587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterSpRtaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter sp. RTa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterSpRtaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1532557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1532557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1532557.clusters.proteins.v11.5.txt",
		        "sequence_path": "1532557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1532557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1532557.protein.info.v11.5.txt",
		        "node_list_path": "1532557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1532557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpJcm18996Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 18996 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpJcm18996Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1301085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1301085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1301085.clusters.proteins.v11.5.txt",
		        "sequence_path": "1301085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1301085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1301085.protein.info.v11.5.txt",
		        "node_list_path": "1301085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1301085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoactinomycesSpDsm45892Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. DSM 45892 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoactinomycesSpDsm45892Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882753.protein.info.v11.5.txt",
		        "node_list_path": "1882753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnoclostridiumPhytofermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnoclostridium phytofermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnoclostridiumPhytofermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "357809.clusters.info.v11.5.txt",
		        "cluster_tree_path": "357809.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "357809.clusters.proteins.v11.5.txt",
		        "sequence_path": "357809.protein.sequences.v11.5.fa",
		        "enrichment_path": "357809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357809.protein.info.v11.5.txt",
		        "node_list_path": "357809.cluster.nodes.v11.5.txt",
		        "edge_list_path": "357809.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OidiodendronMaiusZn(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oidiodendron maius Zn graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OidiodendronMaiusZn", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "913774.protein.sequences.v11.5.fa",
		        "enrichment_path": "913774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "913774.protein.info.v11.5.txt",
		        "node_list_path": "913774.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumTcs42(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium tcs-42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumTcs42", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1742866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742866.protein.info.v11.5.txt",
		        "node_list_path": "1742866.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusMisasensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus misasensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusMisasensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121382.protein.info.v11.5.txt",
		        "node_list_path": "1121382.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnidentifiedEubacteriumScb49(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return unidentified eubacterium SCB49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnidentifiedEubacteriumScb49", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "50743.protein.sequences.v11.5.fa",
		        "enrichment_path": "50743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50743.protein.info.v11.5.txt",
		        "node_list_path": "50743.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasDiminuta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas diminuta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasDiminuta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "293.protein.sequences.v11.5.fa",
		        "enrichment_path": "293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "293.protein.info.v11.5.txt",
		        "node_list_path": "293.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfipiaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Afipia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "211460.clusters.info.v11.5.txt",
		        "cluster_tree_path": "211460.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "211460.clusters.proteins.v11.5.txt",
		        "sequence_path": "211460.protein.sequences.v11.5.fa",
		        "enrichment_path": "211460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211460.protein.info.v11.5.txt",
		        "node_list_path": "211460.cluster.nodes.v11.5.txt",
		        "edge_list_path": "211460.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4413Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_44_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4413Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802069.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802069.protein.info.v11.5.txt",
		        "node_list_path": "1802069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusShapirobacteriaBacteriumGw2011Gwe23830Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium GW2011_GWE2_38_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusShapirobacteriaBacteriumGw2011Gwe23830Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618490.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618490.protein.info.v11.5.txt",
		        "node_list_path": "1618490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmoebophilusAsiaticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amoebophilus asiaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmoebophilusAsiaticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "452471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "452471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "452471.clusters.proteins.v11.5.txt",
		        "sequence_path": "452471.protein.sequences.v11.5.fa",
		        "enrichment_path": "452471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452471.protein.info.v11.5.txt",
		        "node_list_path": "452471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "452471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalypteAnnaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Calypte anna Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalypteAnnaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9244.clusters.proteins.v11.5.txt",
		        "sequence_path": "9244.protein.sequences.v11.5.fa",
		        "enrichment_path": "9244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9244.protein.info.v11.5.txt",
		        "node_list_path": "9244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RosaChinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rosa chinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RosaChinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "74649.protein.sequences.v11.5.fa",
		        "enrichment_path": "74649.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74649.protein.info.v11.5.txt",
		        "node_list_path": "74649.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsphigho202Full3917(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_02_FULL_39_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho202Full3917", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797539.protein.info.v11.5.txt",
		        "node_list_path": "1797539.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpOk095(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. OK095 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpOk095", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882760.protein.info.v11.5.txt",
		        "node_list_path": "1882760.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp12451111(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1245111.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp12451111", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834073.protein.info.v11.5.txt",
		        "node_list_path": "1834073.protein.complete.v11.5.txt"
		    }
		]
    )()

def TaylorellaAsinigenitalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Taylorella asinigenitalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TaylorellaAsinigenitalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1008459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1008459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1008459.clusters.proteins.v11.5.txt",
		        "sequence_path": "1008459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1008459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1008459.protein.info.v11.5.txt",
		        "node_list_path": "1008459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1008459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EmpedobacterFalsenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Empedobacter falsenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EmpedobacterFalsenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "343874.protein.sequences.v11.5.fa",
		        "enrichment_path": "343874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "343874.protein.info.v11.5.txt",
		        "node_list_path": "343874.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSalyersiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides salyersiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSalyersiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121101.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121101.protein.info.v11.5.txt",
		        "node_list_path": "1121101.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusDenitrificansPd1222(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus denitrificans PD1222 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusDenitrificansPd1222", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "318586.protein.sequences.v11.5.fa",
		        "enrichment_path": "318586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318586.protein.info.v11.5.txt",
		        "node_list_path": "318586.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpErmr104(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. ERMR1:04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpErmr104", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1705393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705393.protein.info.v11.5.txt",
		        "node_list_path": "1705393.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinopolysporaSaharensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora saharensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolysporaSaharensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "995062.protein.sequences.v11.5.fa",
		        "enrichment_path": "995062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "995062.protein.info.v11.5.txt",
		        "node_list_path": "995062.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoregulaFormicicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoregula formicica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoregulaFormicicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "593750.clusters.info.v11.5.txt",
		        "cluster_tree_path": "593750.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "593750.clusters.proteins.v11.5.txt",
		        "sequence_path": "593750.protein.sequences.v11.5.fa",
		        "enrichment_path": "593750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "593750.protein.info.v11.5.txt",
		        "node_list_path": "593750.cluster.nodes.v11.5.txt",
		        "edge_list_path": "593750.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumImcc26207(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium IMCC26207 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumImcc26207", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1641811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1641811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1641811.protein.info.v11.5.txt",
		        "node_list_path": "1641811.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4733(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_47_33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4733", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802764.protein.info.v11.5.txt",
		        "node_list_path": "1802764.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasSobriaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas sobria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSobriaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "646.clusters.proteins.v11.5.txt",
		        "sequence_path": "646.protein.sequences.v11.5.fa",
		        "enrichment_path": "646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "646.protein.info.v11.5.txt",
		        "node_list_path": "646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesKebangsaanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces kebangsaanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesKebangsaanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "864058.protein.sequences.v11.5.fa",
		        "enrichment_path": "864058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864058.protein.info.v11.5.txt",
		        "node_list_path": "864058.protein.complete.v11.5.txt"
		    }
		]
    )()

def MailhellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mailhella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MailhellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1903261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903261.protein.info.v11.5.txt",
		        "node_list_path": "1903261.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusTuccetiDsm20183Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus tucceti DSM 20183 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusTuccetiDsm20183Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423811.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423811.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423811.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423811.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423811.protein.info.v11.5.txt",
		        "node_list_path": "1423811.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423811.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedAnaerotruncusSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Anaerotruncus sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedAnaerotruncusSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "905011.protein.sequences.v11.5.fa",
		        "enrichment_path": "905011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "905011.protein.info.v11.5.txt",
		        "node_list_path": "905011.protein.complete.v11.5.txt"
		    }
		]
    )()

def ComamonadaceaeBacteriumH1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ComamonadaceaeBacteriumH1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1458427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1458427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1458427.clusters.proteins.v11.5.txt",
		        "sequence_path": "1458427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1458427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1458427.protein.info.v11.5.txt",
		        "node_list_path": "1458427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1458427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoriobacteriaceaeBacterium6813Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium 68-1-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoriobacteriaceaeBacterium6813Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1531429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1531429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1531429.clusters.proteins.v11.5.txt",
		        "sequence_path": "1531429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1531429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1531429.protein.info.v11.5.txt",
		        "node_list_path": "1531429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1531429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusMesonae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mesonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMesonae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193713.protein.info.v11.5.txt",
		        "node_list_path": "1193713.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaEriocheiris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma eriocheiris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaEriocheiris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "315358.protein.sequences.v11.5.fa",
		        "enrichment_path": "315358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "315358.protein.info.v11.5.txt",
		        "node_list_path": "315358.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg134322Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_43_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg134322Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797825.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797825.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797825.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797825.protein.info.v11.5.txt",
		        "node_list_path": "1797825.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797825.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwc13712bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWC1_37_12b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwc13712bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618510.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618510.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618510.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618510.protein.info.v11.5.txt",
		        "node_list_path": "1618510.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618510.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumChimaeraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium chimaera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumChimaeraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "222805.clusters.info.v11.5.txt",
		        "cluster_tree_path": "222805.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "222805.clusters.proteins.v11.5.txt",
		        "sequence_path": "222805.protein.sequences.v11.5.fa",
		        "enrichment_path": "222805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "222805.protein.info.v11.5.txt",
		        "node_list_path": "222805.cluster.nodes.v11.5.txt",
		        "edge_list_path": "222805.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiothrixLacustris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix lacustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiothrixLacustris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123401.protein.info.v11.5.txt",
		        "node_list_path": "1123401.protein.complete.v11.5.txt"
		    }
		]
    )()

def PorphyromonasSpCot290oh860Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT290OH860 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasSpCot290oh860Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1515615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1515615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1515615.clusters.proteins.v11.5.txt",
		        "sequence_path": "1515615.protein.sequences.v11.5.fa",
		        "enrichment_path": "1515615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1515615.protein.info.v11.5.txt",
		        "node_list_path": "1515615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1515615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SclerotiniaSclerotiorum1980Uf70(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sclerotinia sclerotiorum 1980 UF-70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SclerotiniaSclerotiorum1980Uf70", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665079.protein.sequences.v11.5.fa",
		        "enrichment_path": "665079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665079.protein.info.v11.5.txt",
		        "node_list_path": "665079.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpCci3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. CcI3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpCci3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "106370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "106370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "106370.clusters.proteins.v11.5.txt",
		        "sequence_path": "106370.protein.sequences.v11.5.fa",
		        "enrichment_path": "106370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106370.protein.info.v11.5.txt",
		        "node_list_path": "106370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "106370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaSpIstkbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea sp. ISTKB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaSpIstkbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1586708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1586708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1586708.clusters.proteins.v11.5.txt",
		        "sequence_path": "1586708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1586708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1586708.protein.info.v11.5.txt",
		        "node_list_path": "1586708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1586708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPectinilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus pectinilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPectinilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "512399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "512399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "512399.clusters.proteins.v11.5.txt",
		        "sequence_path": "512399.protein.sequences.v11.5.fa",
		        "enrichment_path": "512399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512399.protein.info.v11.5.txt",
		        "node_list_path": "512399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "512399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumBbfl7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium BBFL7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumBbfl7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "156586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "156586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "156586.clusters.proteins.v11.5.txt",
		        "sequence_path": "156586.protein.sequences.v11.5.fa",
		        "enrichment_path": "156586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156586.protein.info.v11.5.txt",
		        "node_list_path": "156586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "156586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsphigho202Full5616Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_02_FULL_56_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho202Full5616Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797542.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797542.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797542.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797542.protein.info.v11.5.txt",
		        "node_list_path": "1797542.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797542.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusDamuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus damuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusDamuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "937928.protein.sequences.v11.5.fa",
		        "enrichment_path": "937928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937928.protein.info.v11.5.txt",
		        "node_list_path": "937928.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusLocisalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus locisalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusLocisalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "305507.clusters.info.v11.5.txt",
		        "cluster_tree_path": "305507.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "305507.clusters.proteins.v11.5.txt",
		        "sequence_path": "305507.protein.sequences.v11.5.fa",
		        "enrichment_path": "305507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "305507.protein.info.v11.5.txt",
		        "node_list_path": "305507.cluster.nodes.v11.5.txt",
		        "edge_list_path": "305507.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhycisphaeraMikurensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phycisphaera mikurensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycisphaeraMikurensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1142394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1142394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1142394.protein.info.v11.5.txt",
		        "node_list_path": "1142394.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaFlavescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaFlavescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1715806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715806.protein.info.v11.5.txt",
		        "node_list_path": "1715806.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBaumanniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBaumanniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "470.clusters.info.v11.5.txt",
		        "cluster_tree_path": "470.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "470.clusters.proteins.v11.5.txt",
		        "sequence_path": "470.protein.sequences.v11.5.fa",
		        "enrichment_path": "470.protein.enrichment.terms.v11.5.txt",
		        "info_path": "470.protein.info.v11.5.txt",
		        "node_list_path": "470.cluster.nodes.v11.5.txt",
		        "edge_list_path": "470.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloversatilisUniversalisEhg5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloversatilis universalis EHg5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloversatilisUniversalisEhg5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "999628.protein.sequences.v11.5.fa",
		        "enrichment_path": "999628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999628.protein.info.v11.5.txt",
		        "node_list_path": "999628.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwc24220(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWC2_42_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwc24220", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618756.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618756.protein.info.v11.5.txt",
		        "node_list_path": "1618756.protein.complete.v11.5.txt"
		    }
		]
    )()

def MuricaudaLutaonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Muricauda lutaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuricaudaLutaonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "516051.clusters.info.v11.5.txt",
		        "cluster_tree_path": "516051.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "516051.clusters.proteins.v11.5.txt",
		        "sequence_path": "516051.protein.sequences.v11.5.fa",
		        "enrichment_path": "516051.protein.enrichment.terms.v11.5.txt",
		        "info_path": "516051.protein.info.v11.5.txt",
		        "node_list_path": "516051.cluster.nodes.v11.5.txt",
		        "edge_list_path": "516051.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb14912(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_49_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb14912", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618882.protein.info.v11.5.txt",
		        "node_list_path": "1618882.protein.complete.v11.5.txt"
		    }
		]
    )()

def PectobacteriumSpScc3193(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium sp. SCC3193 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumSpScc3193", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1166016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1166016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1166016.protein.info.v11.5.txt",
		        "node_list_path": "1166016.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusDuerdenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus duerdenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusDuerdenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "862517.protein.sequences.v11.5.fa",
		        "enrichment_path": "862517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862517.protein.info.v11.5.txt",
		        "node_list_path": "862517.protein.complete.v11.5.txt"
		    }
		]
    )()

def DemequinaSediminicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina sediminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaSediminicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095026.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095026.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095026.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095026.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095026.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095026.protein.info.v11.5.txt",
		        "node_list_path": "1095026.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095026.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusXylosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus xylosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusXylosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288.protein.info.v11.5.txt",
		        "node_list_path": "1288.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DermabacterVaginalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dermabacter vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DermabacterVaginalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1630135.protein.sequences.v11.5.fa",
		        "enrichment_path": "1630135.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1630135.protein.info.v11.5.txt",
		        "node_list_path": "1630135.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusSp4g2Div0659(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sp. 4G2_DIV0659 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSp4g2Div0659", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834181.protein.info.v11.5.txt",
		        "node_list_path": "1834181.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBacteroidesPeriocalifornicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus [Bacteroides] periocalifornicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBacteroidesPeriocalifornicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1702214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1702214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1702214.protein.info.v11.5.txt",
		        "node_list_path": "1702214.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaFicariaNbrc102596Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia ficaria NBRC 102596 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaFicariaNbrc102596Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1411141.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1411141.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1411141.clusters.proteins.v11.5.txt",
		        "sequence_path": "1411141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1411141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1411141.protein.info.v11.5.txt",
		        "node_list_path": "1411141.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1411141.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynergistesSp31syn1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synergistes sp. 31syn1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynergistesSp31syn1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "457415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "457415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "457415.clusters.proteins.v11.5.txt",
		        "sequence_path": "457415.protein.sequences.v11.5.fa",
		        "enrichment_path": "457415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "457415.protein.info.v11.5.txt",
		        "node_list_path": "457415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "457415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionisporaVibrioides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionispora vibrioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionisporaVibrioides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "112903.protein.sequences.v11.5.fa",
		        "enrichment_path": "112903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "112903.protein.info.v11.5.txt",
		        "node_list_path": "112903.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophomonasSpDtu019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas sp. DTU019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophomonasSpDtu019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671630.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671630.protein.info.v11.5.txt",
		        "node_list_path": "1671630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychromicrobiumLacuslunaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychromicrobium lacuslunae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychromicrobiumLacuslunaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618207.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618207.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618207.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618207.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618207.protein.info.v11.5.txt",
		        "node_list_path": "1618207.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618207.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoheibacterSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moheibacter sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoheibacterSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434700.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434700.protein.info.v11.5.txt",
		        "node_list_path": "1434700.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinosynnemaSpAli144Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinosynnema sp. ALI-1.44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinosynnemaSpAli144Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1933779.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1933779.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1933779.clusters.proteins.v11.5.txt",
		        "sequence_path": "1933779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933779.protein.info.v11.5.txt",
		        "node_list_path": "1933779.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1933779.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSoil761(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil761 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSoil761", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736400.protein.info.v11.5.txt",
		        "node_list_path": "1736400.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwb1388(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_38_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb1388", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618570.protein.info.v11.5.txt",
		        "node_list_path": "1618570.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsplowo202Full4511c(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_02_FULL_45_11c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo202Full4511c", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802128.protein.info.v11.5.txt",
		        "node_list_path": "1802128.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesThetaiotaomicronCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides thetaiotaomicron Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesThetaiotaomicronCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "226186.clusters.info.v11.5.txt",
		        "cluster_tree_path": "226186.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "226186.clusters.proteins.v11.5.txt",
		        "sequence_path": "226186.protein.sequences.v11.5.fa",
		        "enrichment_path": "226186.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226186.protein.info.v11.5.txt",
		        "node_list_path": "226186.cluster.nodes.v11.5.txt",
		        "edge_list_path": "226186.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DietziaSpUcdthpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dietzia sp. UCDTHP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DietziaSpUcdthpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1292020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1292020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1292020.clusters.proteins.v11.5.txt",
		        "sequence_path": "1292020.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292020.protein.info.v11.5.txt",
		        "node_list_path": "1292020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1292020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirosomaRiguiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma rigui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaRiguiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "564064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "564064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "564064.clusters.proteins.v11.5.txt",
		        "sequence_path": "564064.protein.sequences.v11.5.fa",
		        "enrichment_path": "564064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "564064.protein.info.v11.5.txt",
		        "node_list_path": "564064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "564064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumD16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium D16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumD16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "552398.protein.sequences.v11.5.fa",
		        "enrichment_path": "552398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "552398.protein.info.v11.5.txt",
		        "node_list_path": "552398.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpWcd3002Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. WCD3002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpWcd3002Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280676.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280676.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280676.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280676.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280676.protein.info.v11.5.txt",
		        "node_list_path": "1280676.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280676.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeopsychrobacterElectrodiphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geopsychrobacter electrodiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeopsychrobacterElectrodiphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121918.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121918.protein.info.v11.5.txt",
		        "node_list_path": "1121918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenibacillusSchlegelii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenibacillus schlegelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenibacillusSchlegelii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484.protein.info.v11.5.txt",
		        "node_list_path": "1484.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerolineaThermophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerolinea thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaThermophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926569.protein.sequences.v11.5.fa",
		        "enrichment_path": "926569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926569.protein.info.v11.5.txt",
		        "node_list_path": "926569.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesCanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces canus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesCanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "58343.clusters.info.v11.5.txt",
		        "cluster_tree_path": "58343.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "58343.clusters.proteins.v11.5.txt",
		        "sequence_path": "58343.protein.sequences.v11.5.fa",
		        "enrichment_path": "58343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58343.protein.info.v11.5.txt",
		        "node_list_path": "58343.cluster.nodes.v11.5.txt",
		        "edge_list_path": "58343.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpFf12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FF12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpFf12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1608584.protein.sequences.v11.5.fa",
		        "enrichment_path": "1608584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1608584.protein.info.v11.5.txt",
		        "node_list_path": "1608584.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusNuruki(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus nuruki graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusNuruki", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1886670.protein.sequences.v11.5.fa",
		        "enrichment_path": "1886670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1886670.protein.info.v11.5.txt",
		        "node_list_path": "1886670.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhaeodactylumTricornutumCcap10551(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeodactylum tricornutum CCAP 1055/1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeodactylumTricornutumCcap10551", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "556484.protein.sequences.v11.5.fa",
		        "enrichment_path": "556484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556484.protein.info.v11.5.txt",
		        "node_list_path": "556484.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095769.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095769.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095769.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095769.protein.info.v11.5.txt",
		        "node_list_path": "1095769.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095769.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WuchereriaBancrofti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wuchereria bancrofti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WuchereriaBancrofti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6293.protein.sequences.v11.5.fa",
		        "enrichment_path": "6293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6293.protein.info.v11.5.txt",
		        "node_list_path": "6293.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaGlabrataCbs138(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Candida] glabrata CBS 138 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaGlabrataCbs138", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "284593.protein.sequences.v11.5.fa",
		        "enrichment_path": "284593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284593.protein.info.v11.5.txt",
		        "node_list_path": "284593.protein.complete.v11.5.txt"
		    }
		]
    )()

def CercocebusAtysCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cercocebus atys Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CercocebusAtysCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9531.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9531.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9531.clusters.proteins.v11.5.txt",
		        "sequence_path": "9531.protein.sequences.v11.5.fa",
		        "enrichment_path": "9531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9531.protein.info.v11.5.txt",
		        "node_list_path": "9531.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9531.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinospirillumAlkaliphilumDsm21637(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinospirillum alkaliphilum DSM 21637 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinospirillumAlkaliphilumDsm21637", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122209.protein.info.v11.5.txt",
		        "node_list_path": "1122209.protein.complete.v11.5.txt"
		    }
		]
    )()

def AliivibrioLogei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aliivibrio logei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliivibrioLogei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "688.protein.sequences.v11.5.fa",
		        "enrichment_path": "688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688.protein.info.v11.5.txt",
		        "node_list_path": "688.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNbrc109706(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NBRC 109706 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNbrc109706", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1550035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550035.protein.info.v11.5.txt",
		        "node_list_path": "1550035.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19041(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19041 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19041", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1460637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460637.protein.info.v11.5.txt",
		        "node_list_path": "1460637.protein.complete.v11.5.txt"
		    }
		]
    )()

def FacklamiaMiroungaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Facklamia miroungae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FacklamiaMiroungaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "120956.clusters.info.v11.5.txt",
		        "cluster_tree_path": "120956.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "120956.clusters.proteins.v11.5.txt",
		        "sequence_path": "120956.protein.sequences.v11.5.fa",
		        "enrichment_path": "120956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "120956.protein.info.v11.5.txt",
		        "node_list_path": "120956.cluster.nodes.v11.5.txt",
		        "edge_list_path": "120956.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusLimiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus limi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusLimiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "930131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "930131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "930131.clusters.proteins.v11.5.txt",
		        "sequence_path": "930131.protein.sequences.v11.5.fa",
		        "enrichment_path": "930131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "930131.protein.info.v11.5.txt",
		        "node_list_path": "930131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "930131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychromonasArcticaDsm14288Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas arctica DSM 14288 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychromonasArcticaDsm14288Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123036.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123036.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123036.protein.info.v11.5.txt",
		        "node_list_path": "1123036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MiscellaneousCrenarchaeotaGroup6ArchaeonAd81(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return miscellaneous Crenarchaeota group-6 archaeon AD8-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MiscellaneousCrenarchaeotaGroup6ArchaeonAd81", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1685126.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685126.protein.info.v11.5.txt",
		        "node_list_path": "1685126.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKerfeldbacteriaBacteriumRifcsplowo201Full4811Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPLOWO2_01_FULL_48_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsplowo201Full4811Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798543.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798543.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798543.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798543.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798543.protein.info.v11.5.txt",
		        "node_list_path": "1798543.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798543.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpAm1D1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. AM1-D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpAm1D1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1917485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1917485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1917485.clusters.proteins.v11.5.txt",
		        "sequence_path": "1917485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917485.protein.info.v11.5.txt",
		        "node_list_path": "1917485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1917485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TenericutesBacteriumGwf235184(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWF2_35_184 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenericutesBacteriumGwf235184", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802352.protein.info.v11.5.txt",
		        "node_list_path": "1802352.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag156(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:156 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag156", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262880.protein.info.v11.5.txt",
		        "node_list_path": "1262880.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpHun007Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. HUN007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpHun007Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1514668.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1514668.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1514668.clusters.proteins.v11.5.txt",
		        "sequence_path": "1514668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1514668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1514668.protein.info.v11.5.txt",
		        "node_list_path": "1514668.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1514668.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpWsm3626Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. WSM3626 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpWsm3626Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1040987.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1040987.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1040987.clusters.proteins.v11.5.txt",
		        "sequence_path": "1040987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1040987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1040987.protein.info.v11.5.txt",
		        "node_list_path": "1040987.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1040987.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaReeseiQm6a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma reesei QM6a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaReeseiQm6a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "431241.protein.sequences.v11.5.fa",
		        "enrichment_path": "431241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431241.protein.info.v11.5.txt",
		        "node_list_path": "431241.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchistosomaMargrebowieiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma margrebowiei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaMargrebowieiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "48269.clusters.info.v11.5.txt",
		        "cluster_tree_path": "48269.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "48269.clusters.proteins.v11.5.txt",
		        "sequence_path": "48269.protein.sequences.v11.5.fa",
		        "enrichment_path": "48269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48269.protein.info.v11.5.txt",
		        "node_list_path": "48269.cluster.nodes.v11.5.txt",
		        "edge_list_path": "48269.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumGw2011Gwa14424(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWA1_44_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwa14424", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619002.protein.info.v11.5.txt",
		        "node_list_path": "1619002.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium32(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium32", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235799.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235799.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235799.protein.info.v11.5.txt",
		        "node_list_path": "1235799.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusMucosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius mucosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusMucosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1288298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288298.protein.info.v11.5.txt",
		        "node_list_path": "1288298.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho202Full4212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_42_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full4212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798607.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798607.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798607.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798607.protein.info.v11.5.txt",
		        "node_list_path": "1798607.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798607.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumNebraskense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium nebraskense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumNebraskense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "244292.protein.sequences.v11.5.fa",
		        "enrichment_path": "244292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "244292.protein.info.v11.5.txt",
		        "node_list_path": "244292.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArsukibacteriumIkkense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arsukibacterium ikkense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArsukibacteriumIkkense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "336831.protein.sequences.v11.5.fa",
		        "enrichment_path": "336831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336831.protein.info.v11.5.txt",
		        "node_list_path": "336831.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterCryaerophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter cryaerophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterCryaerophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28198.protein.sequences.v11.5.fa",
		        "enrichment_path": "28198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28198.protein.info.v11.5.txt",
		        "node_list_path": "28198.protein.complete.v11.5.txt"
		    }
		]
    )()

def MariniphagaAnaerophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mariniphaga anaerophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MariniphagaAnaerophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1484053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1484053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1484053.protein.info.v11.5.txt",
		        "node_list_path": "1484053.protein.complete.v11.5.txt"
		    }
		]
    )()

def RheinheimeraNanhaiensisE4078Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera nanhaiensis E407-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RheinheimeraNanhaiensisE4078Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "562729.clusters.info.v11.5.txt",
		        "cluster_tree_path": "562729.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "562729.clusters.proteins.v11.5.txt",
		        "sequence_path": "562729.protein.sequences.v11.5.fa",
		        "enrichment_path": "562729.protein.enrichment.terms.v11.5.txt",
		        "info_path": "562729.protein.info.v11.5.txt",
		        "node_list_path": "562729.cluster.nodes.v11.5.txt",
		        "edge_list_path": "562729.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_55_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798516.protein.info.v11.5.txt",
		        "node_list_path": "1798516.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "522492.clusters.info.v11.5.txt",
		        "cluster_tree_path": "522492.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "522492.clusters.proteins.v11.5.txt",
		        "sequence_path": "522492.protein.sequences.v11.5.fa",
		        "enrichment_path": "522492.protein.enrichment.terms.v11.5.txt",
		        "info_path": "522492.protein.info.v11.5.txt",
		        "node_list_path": "522492.cluster.nodes.v11.5.txt",
		        "edge_list_path": "522492.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasSpRu39bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas sp. RU39B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSpRu39bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907416.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907416.protein.info.v11.5.txt",
		        "node_list_path": "1907416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpKpl1860Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1860 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpKpl1860Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203567.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203567.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203567.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203567.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203567.protein.info.v11.5.txt",
		        "node_list_path": "1203567.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203567.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacunisphaeraLimnophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lacunisphaera limnophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacunisphaeraLimnophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1838286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1838286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1838286.protein.info.v11.5.txt",
		        "node_list_path": "1838286.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaSpSgdV85Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sp. SGD-V-85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSpSgdV85Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1414651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1414651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1414651.clusters.proteins.v11.5.txt",
		        "sequence_path": "1414651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1414651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1414651.protein.info.v11.5.txt",
		        "node_list_path": "1414651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1414651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumThalpophilumDsm11723Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium thalpophilum DSM 11723 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumThalpophilumDsm11723Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123265.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123265.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123265.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123265.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123265.protein.info.v11.5.txt",
		        "node_list_path": "1123265.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123265.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrocoleusVaginatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microcoleus vaginatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrocoleusVaginatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "756067.protein.sequences.v11.5.fa",
		        "enrichment_path": "756067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "756067.protein.info.v11.5.txt",
		        "node_list_path": "756067.protein.complete.v11.5.txt"
		    }
		]
    )()

def WeissellaJogaejeotgali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Weissella jogaejeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WeissellaJogaejeotgali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1631871.protein.sequences.v11.5.fa",
		        "enrichment_path": "1631871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1631871.protein.info.v11.5.txt",
		        "node_list_path": "1631871.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuegeriaDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1715692.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1715692.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1715692.clusters.proteins.v11.5.txt",
		        "sequence_path": "1715692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715692.protein.info.v11.5.txt",
		        "node_list_path": "1715692.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1715692.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SilvibacteriumBohemicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Silvibacterium bohemicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SilvibacteriumBohemicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577686.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577686.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577686.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577686.protein.info.v11.5.txt",
		        "node_list_path": "1577686.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577686.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EncephalitozoonCuniculiGbM1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Encephalitozoon cuniculi GB-M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EncephalitozoonCuniculiGbM1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "284813.protein.sequences.v11.5.fa",
		        "enrichment_path": "284813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284813.protein.info.v11.5.txt",
		        "node_list_path": "284813.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasParafulvaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas parafulva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasParafulvaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1215114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1215114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1215114.clusters.proteins.v11.5.txt",
		        "sequence_path": "1215114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215114.protein.info.v11.5.txt",
		        "node_list_path": "1215114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1215114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumMs4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium MS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumMs4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120746.protein.info.v11.5.txt",
		        "node_list_path": "1120746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesGuanduensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces guanduensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGuanduensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "310781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "310781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "310781.clusters.proteins.v11.5.txt",
		        "sequence_path": "310781.protein.sequences.v11.5.fa",
		        "enrichment_path": "310781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "310781.protein.info.v11.5.txt",
		        "node_list_path": "310781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "310781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FischerellaThermalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fischerella thermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FischerellaThermalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "98439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "98439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "98439.clusters.proteins.v11.5.txt",
		        "sequence_path": "98439.protein.sequences.v11.5.fa",
		        "enrichment_path": "98439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "98439.protein.info.v11.5.txt",
		        "node_list_path": "98439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "98439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaSuccinifaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema succinifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSuccinifaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "869209.protein.sequences.v11.5.fa",
		        "enrichment_path": "869209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869209.protein.info.v11.5.txt",
		        "node_list_path": "869209.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexusSpMsgCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexus sp. MSG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexusSpMsgCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1521187.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1521187.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1521187.clusters.proteins.v11.5.txt",
		        "sequence_path": "1521187.protein.sequences.v11.5.fa",
		        "enrichment_path": "1521187.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1521187.protein.info.v11.5.txt",
		        "node_list_path": "1521187.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1521187.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfurellaAmilsiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurella amilsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurellaAmilsiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1562698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1562698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1562698.clusters.proteins.v11.5.txt",
		        "sequence_path": "1562698.protein.sequences.v11.5.fa",
		        "enrichment_path": "1562698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1562698.protein.info.v11.5.txt",
		        "node_list_path": "1562698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1562698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasRuminantiumLactilyticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium lactilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasRuminantiumLactilyticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "927704.clusters.info.v11.5.txt",
		        "cluster_tree_path": "927704.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "927704.clusters.proteins.v11.5.txt",
		        "sequence_path": "927704.protein.sequences.v11.5.fa",
		        "enrichment_path": "927704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927704.protein.info.v11.5.txt",
		        "node_list_path": "927704.cluster.nodes.v11.5.txt",
		        "edge_list_path": "927704.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MangrovimonasSpSt2l15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. ST2L15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MangrovimonasSpSt2l15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1645916.protein.sequences.v11.5.fa",
		        "enrichment_path": "1645916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1645916.protein.info.v11.5.txt",
		        "node_list_path": "1645916.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaSpWri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia sp. wRi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaSpWri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66084.protein.sequences.v11.5.fa",
		        "enrichment_path": "66084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66084.protein.info.v11.5.txt",
		        "node_list_path": "66084.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaSp2742308Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia sp. 2742-308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaSp2742308Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1806891.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1806891.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1806891.clusters.proteins.v11.5.txt",
		        "sequence_path": "1806891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806891.protein.info.v11.5.txt",
		        "node_list_path": "1806891.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1806891.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NematocidaSp1Ertm2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nematocida sp. 1 ERTm2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NematocidaSp1Ertm2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "944018.clusters.info.v11.5.txt",
		        "cluster_tree_path": "944018.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "944018.clusters.proteins.v11.5.txt",
		        "sequence_path": "944018.protein.sequences.v11.5.fa",
		        "enrichment_path": "944018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944018.protein.info.v11.5.txt",
		        "node_list_path": "944018.cluster.nodes.v11.5.txt",
		        "edge_list_path": "944018.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCny243(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNY243 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCny243", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1169161.protein.sequences.v11.5.fa",
		        "enrichment_path": "1169161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1169161.protein.info.v11.5.txt",
		        "node_list_path": "1169161.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho201Full4623Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_01_FULL_46_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho201Full4623Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802382.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802382.protein.info.v11.5.txt",
		        "node_list_path": "1802382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GiardiaLambliaAtcc50803(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Giardia lamblia ATCC 50803 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GiardiaLambliaAtcc50803", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "184922.protein.sequences.v11.5.fa",
		        "enrichment_path": "184922.protein.enrichment.terms.v11.5.txt",
		        "info_path": "184922.protein.info.v11.5.txt",
		        "node_list_path": "184922.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKerfeldbacteriaBacteriumRifcsplowo201Full4811(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPLOWO2_01_FULL_48_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsplowo201Full4811", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798543.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798543.protein.info.v11.5.txt",
		        "node_list_path": "1798543.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeeuwenhoekiellaPalythoaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella palythoae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeeuwenhoekiellaPalythoaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573501.clusters.proteins.v11.5.txt",
		        "sequence_path": "573501.protein.sequences.v11.5.fa",
		        "enrichment_path": "573501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573501.protein.info.v11.5.txt",
		        "node_list_path": "573501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpRlCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. RL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpRlCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1452718.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1452718.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1452718.clusters.proteins.v11.5.txt",
		        "sequence_path": "1452718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1452718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1452718.protein.info.v11.5.txt",
		        "node_list_path": "1452718.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1452718.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusCristatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus cristatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusCristatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "889201.clusters.info.v11.5.txt",
		        "cluster_tree_path": "889201.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "889201.clusters.proteins.v11.5.txt",
		        "sequence_path": "889201.protein.sequences.v11.5.fa",
		        "enrichment_path": "889201.protein.enrichment.terms.v11.5.txt",
		        "info_path": "889201.protein.info.v11.5.txt",
		        "node_list_path": "889201.cluster.nodes.v11.5.txt",
		        "edge_list_path": "889201.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaGallinaceaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia gallinacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaGallinaceaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1143323.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1143323.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1143323.clusters.proteins.v11.5.txt",
		        "sequence_path": "1143323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1143323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1143323.protein.info.v11.5.txt",
		        "node_list_path": "1143323.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1143323.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumHungaricumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium hungaricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumHungaricumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "454006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "454006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "454006.clusters.proteins.v11.5.txt",
		        "sequence_path": "454006.protein.sequences.v11.5.fa",
		        "enrichment_path": "454006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454006.protein.info.v11.5.txt",
		        "node_list_path": "454006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "454006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpOcn003Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. OCN003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpOcn003Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348114.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348114.protein.info.v11.5.txt",
		        "node_list_path": "1348114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwa24315Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWA2_43_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwa24315Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618738.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618738.protein.info.v11.5.txt",
		        "node_list_path": "1618738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaWenyoniiStrMassachusetts(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma wenyonii str. Massachusetts graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaWenyoniiStrMassachusetts", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1197325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1197325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1197325.protein.info.v11.5.txt",
		        "node_list_path": "1197325.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlistipesSpCag268(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:268 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpCag268", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262693.protein.info.v11.5.txt",
		        "node_list_path": "1262693.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnserCygnoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anser cygnoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnserCygnoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8845.protein.sequences.v11.5.fa",
		        "enrichment_path": "8845.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8845.protein.info.v11.5.txt",
		        "node_list_path": "8845.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpYr528(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR528 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpYr528", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500258.protein.info.v11.5.txt",
		        "node_list_path": "1500258.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwf24518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWF2_45_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwf24518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618539.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618539.protein.info.v11.5.txt",
		        "node_list_path": "1618539.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpKk1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. KK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpKk1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855726.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855726.protein.info.v11.5.txt",
		        "node_list_path": "1855726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterIshigakiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter ishigakiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterIshigakiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "476157.protein.sequences.v11.5.fa",
		        "enrichment_path": "476157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "476157.protein.info.v11.5.txt",
		        "node_list_path": "476157.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumLiaoningense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium liaoningense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumLiaoningense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43992.protein.sequences.v11.5.fa",
		        "enrichment_path": "43992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43992.protein.info.v11.5.txt",
		        "node_list_path": "43992.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumTofieldiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum tofieldiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumTofieldiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "708197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "708197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "708197.clusters.proteins.v11.5.txt",
		        "sequence_path": "708197.protein.sequences.v11.5.fa",
		        "enrichment_path": "708197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "708197.protein.info.v11.5.txt",
		        "node_list_path": "708197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "708197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SmittiumMucronatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Smittium mucronatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SmittiumMucronatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "133383.protein.sequences.v11.5.fa",
		        "enrichment_path": "133383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "133383.protein.info.v11.5.txt",
		        "node_list_path": "133383.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag1058(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag1058", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262918.protein.info.v11.5.txt",
		        "node_list_path": "1262918.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpRoot1279Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Root1279 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpRoot1279Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736443.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736443.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736443.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736443.protein.info.v11.5.txt",
		        "node_list_path": "1736443.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736443.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaKt2440(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida KT2440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaKt2440", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "160488.protein.sequences.v11.5.fa",
		        "enrichment_path": "160488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "160488.protein.info.v11.5.txt",
		        "node_list_path": "160488.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelomonasSpRoot1217(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelomonasSpRoot1217", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736430.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736430.protein.info.v11.5.txt",
		        "node_list_path": "1736430.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusVaccinostercusDsm20634(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus vaccinostercus DSM 20634 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusVaccinostercusDsm20634", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423813.protein.info.v11.5.txt",
		        "node_list_path": "1423813.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaChokoriensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora chokoriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaChokoriensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "356851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "356851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "356851.clusters.proteins.v11.5.txt",
		        "sequence_path": "356851.protein.sequences.v11.5.fa",
		        "enrichment_path": "356851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "356851.protein.info.v11.5.txt",
		        "node_list_path": "356851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "356851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasParapaucimobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas parapaucimobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasParapaucimobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219049.protein.info.v11.5.txt",
		        "node_list_path": "1219049.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioMediterraneiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio mediterranei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioMediterraneiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "689.clusters.proteins.v11.5.txt",
		        "sequence_path": "689.protein.sequences.v11.5.fa",
		        "enrichment_path": "689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "689.protein.info.v11.5.txt",
		        "node_list_path": "689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PectobacteriumCarotovorumOdoriferumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum odoriferum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumCarotovorumOdoriferumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "78398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "78398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "78398.clusters.proteins.v11.5.txt",
		        "sequence_path": "78398.protein.sequences.v11.5.fa",
		        "enrichment_path": "78398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78398.protein.info.v11.5.txt",
		        "node_list_path": "78398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "78398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor3BacteriumSm2342(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR_3 bacterium SM23_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor3BacteriumSm2342", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1703779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703779.protein.info.v11.5.txt",
		        "node_list_path": "1703779.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumCanariasenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium canariasense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumCanariasenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "228230.clusters.info.v11.5.txt",
		        "cluster_tree_path": "228230.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "228230.clusters.proteins.v11.5.txt",
		        "sequence_path": "228230.protein.sequences.v11.5.fa",
		        "enrichment_path": "228230.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228230.protein.info.v11.5.txt",
		        "node_list_path": "228230.cluster.nodes.v11.5.txt",
		        "edge_list_path": "228230.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MacellibacteroidesSpHhZs(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Macellibacteroides sp. HH-ZS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacellibacteroidesSpHhZs", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1857568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1857568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1857568.protein.info.v11.5.txt",
		        "node_list_path": "1857568.protein.complete.v11.5.txt"
		    }
		]
    )()

def TropherymaWhippleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tropheryma whipplei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TropherymaWhippleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "203267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "203267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "203267.clusters.proteins.v11.5.txt",
		        "sequence_path": "203267.protein.sequences.v11.5.fa",
		        "enrichment_path": "203267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203267.protein.info.v11.5.txt",
		        "node_list_path": "203267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "203267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacillusPleuropneumoniae14074(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae 1 4074 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusPleuropneumoniae14074", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "228399.protein.sequences.v11.5.fa",
		        "enrichment_path": "228399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228399.protein.info.v11.5.txt",
		        "node_list_path": "228399.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfolobusAcidocaldarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfolobusAcidocaldarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "330779.protein.sequences.v11.5.fa",
		        "enrichment_path": "330779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "330779.protein.info.v11.5.txt",
		        "node_list_path": "330779.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxWautersii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax wautersii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxWautersii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1177982.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177982.protein.info.v11.5.txt",
		        "node_list_path": "1177982.protein.complete.v11.5.txt"
		    }
		]
    )()

def MooreaProducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Moorea producens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MooreaProducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "489825.protein.sequences.v11.5.fa",
		        "enrichment_path": "489825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "489825.protein.info.v11.5.txt",
		        "node_list_path": "489825.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumNiameyenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium niameyense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumNiameyenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1622073.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1622073.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1622073.clusters.proteins.v11.5.txt",
		        "sequence_path": "1622073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1622073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1622073.protein.info.v11.5.txt",
		        "node_list_path": "1622073.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1622073.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpMbes04Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. MBES04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpMbes04Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206458.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206458.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206458.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206458.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206458.protein.info.v11.5.txt",
		        "node_list_path": "1206458.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206458.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumTegetincolaDsm22377(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium tegetincola DSM 22377 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumTegetincolaDsm22377", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121901.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121901.protein.info.v11.5.txt",
		        "node_list_path": "1121901.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumAzadirachtaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium azadirachtae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumAzadirachtaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582680.clusters.proteins.v11.5.txt",
		        "sequence_path": "582680.protein.sequences.v11.5.fa",
		        "enrichment_path": "582680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582680.protein.info.v11.5.txt",
		        "node_list_path": "582680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaDilworthiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia dilworthii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaDilworthiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "948106.clusters.info.v11.5.txt",
		        "cluster_tree_path": "948106.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "948106.clusters.proteins.v11.5.txt",
		        "sequence_path": "948106.protein.sequences.v11.5.fa",
		        "enrichment_path": "948106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "948106.protein.info.v11.5.txt",
		        "node_list_path": "948106.cluster.nodes.v11.5.txt",
		        "edge_list_path": "948106.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaProteobacteriumScgcAaa536K22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA536-K22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaProteobacteriumScgcAaa536K22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1009709.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009709.protein.info.v11.5.txt",
		        "node_list_path": "1009709.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiabellaDrilacis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Niabella drilacis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiabellaDrilacis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1285928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1285928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1285928.protein.info.v11.5.txt",
		        "node_list_path": "1285928.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaSpOralTaxon020StrF0370Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. oral taxon 020 str. F0370 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSpOralTaxon020StrF0370Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1127694.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1127694.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1127694.clusters.proteins.v11.5.txt",
		        "sequence_path": "1127694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127694.protein.info.v11.5.txt",
		        "node_list_path": "1127694.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1127694.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasCitronellolisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas citronellolis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCitronellolisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53408.clusters.proteins.v11.5.txt",
		        "sequence_path": "53408.protein.sequences.v11.5.fa",
		        "enrichment_path": "53408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53408.protein.info.v11.5.txt",
		        "node_list_path": "53408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpFf4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FF4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFf4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1347369.protein.sequences.v11.5.fa",
		        "enrichment_path": "1347369.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1347369.protein.info.v11.5.txt",
		        "node_list_path": "1347369.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE1747(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E1747 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE1747", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834128.protein.info.v11.5.txt",
		        "node_list_path": "1834128.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusGallinarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusGallinarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "565653.protein.sequences.v11.5.fa",
		        "enrichment_path": "565653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565653.protein.info.v11.5.txt",
		        "node_list_path": "565653.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteroidesSaopaulenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacteroides saopaulense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteroidesSaopaulenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1578165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1578165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1578165.clusters.proteins.v11.5.txt",
		        "sequence_path": "1578165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1578165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1578165.protein.info.v11.5.txt",
		        "node_list_path": "1578165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1578165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumHibernum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium hibernum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumHibernum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37752.protein.sequences.v11.5.fa",
		        "enrichment_path": "37752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37752.protein.info.v11.5.txt",
		        "node_list_path": "37752.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrypanosomaCruziStrainClBrener(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma cruzi strain CL Brener graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrypanosomaCruziStrainClBrener", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "353153.protein.sequences.v11.5.fa",
		        "enrichment_path": "353153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "353153.protein.info.v11.5.txt",
		        "node_list_path": "353153.protein.complete.v11.5.txt"
		    }
		]
    )()

def KinetoplastibacteriumBlastocrithidii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium blastocrithidii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KinetoplastibacteriumBlastocrithidii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208923.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208923.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208923.protein.info.v11.5.txt",
		        "node_list_path": "1208923.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriumAlbumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacterium album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriumAlbumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "945713.clusters.info.v11.5.txt",
		        "cluster_tree_path": "945713.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "945713.clusters.proteins.v11.5.txt",
		        "sequence_path": "945713.protein.sequences.v11.5.fa",
		        "enrichment_path": "945713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "945713.protein.info.v11.5.txt",
		        "node_list_path": "945713.cluster.nodes.v11.5.txt",
		        "edge_list_path": "945713.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MonosporascusSp5c6a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. 5C6A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSp5c6a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2211642.protein.sequences.v11.5.fa",
		        "enrichment_path": "2211642.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2211642.protein.info.v11.5.txt",
		        "node_list_path": "2211642.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacterSpLpb0142(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter sp. LPB0142 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterSpLpb0142", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1850250.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850250.protein.info.v11.5.txt",
		        "node_list_path": "1850250.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumSpXm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. XM-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumSpXm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1663591.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1663591.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1663591.clusters.proteins.v11.5.txt",
		        "sequence_path": "1663591.protein.sequences.v11.5.fa",
		        "enrichment_path": "1663591.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1663591.protein.info.v11.5.txt",
		        "node_list_path": "1663591.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1663591.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasShengliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas shengliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasShengliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "419597.protein.sequences.v11.5.fa",
		        "enrichment_path": "419597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419597.protein.info.v11.5.txt",
		        "node_list_path": "419597.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptoalloteichusHindustanus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptoalloteichus hindustanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptoalloteichusHindustanus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2017.protein.sequences.v11.5.fa",
		        "enrichment_path": "2017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2017.protein.info.v11.5.txt",
		        "node_list_path": "2017.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRbg166620(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_66_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRbg166620", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797479.protein.info.v11.5.txt",
		        "node_list_path": "1797479.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag555(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:555 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag555", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263030.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263030.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263030.protein.info.v11.5.txt",
		        "node_list_path": "1263030.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusSp4g2Div0659Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sp. 4G2_DIV0659 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSp4g2Div0659Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834181.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834181.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834181.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834181.protein.info.v11.5.txt",
		        "node_list_path": "1834181.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834181.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpRoot241(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root241 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpRoot241", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736501.protein.info.v11.5.txt",
		        "node_list_path": "1736501.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpLf2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. LF2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpLf2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1499689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1499689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1499689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1499689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499689.protein.info.v11.5.txt",
		        "node_list_path": "1499689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1499689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumThermoalcaliphilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] thermoalcaliphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumThermoalcaliphilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29349.clusters.proteins.v11.5.txt",
		        "sequence_path": "29349.protein.sequences.v11.5.fa",
		        "enrichment_path": "29349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29349.protein.info.v11.5.txt",
		        "node_list_path": "29349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeiothermusRuber(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusRuber", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "504728.protein.sequences.v11.5.fa",
		        "enrichment_path": "504728.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504728.protein.info.v11.5.txt",
		        "node_list_path": "504728.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaNelsoniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichinella nelsoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaNelsoniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6336.clusters.proteins.v11.5.txt",
		        "sequence_path": "6336.protein.sequences.v11.5.fa",
		        "enrichment_path": "6336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6336.protein.info.v11.5.txt",
		        "node_list_path": "6336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PropionibacteriumGranulosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium granulosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PropionibacteriumGranulosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1292373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292373.protein.info.v11.5.txt",
		        "node_list_path": "1292373.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusAfricanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus africanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusAfricanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1137993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1137993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1137993.clusters.proteins.v11.5.txt",
		        "sequence_path": "1137993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137993.protein.info.v11.5.txt",
		        "node_list_path": "1137993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1137993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodovulumSpMb263(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. MB263 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovulumSpMb263", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "308754.protein.sequences.v11.5.fa",
		        "enrichment_path": "308754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "308754.protein.info.v11.5.txt",
		        "node_list_path": "308754.protein.complete.v11.5.txt"
		    }
		]
    )()

def DokdoniaSpMed134(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dokdonia sp. MED134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DokdoniaSpMed134", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "313590.protein.sequences.v11.5.fa",
		        "enrichment_path": "313590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313590.protein.info.v11.5.txt",
		        "node_list_path": "313590.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1564956.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1564956.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1564956.clusters.proteins.v11.5.txt",
		        "sequence_path": "1564956.protein.sequences.v11.5.fa",
		        "enrichment_path": "1564956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1564956.protein.info.v11.5.txt",
		        "node_list_path": "1564956.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1564956.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKryptobacterTengchongensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kryptobacter tengchongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKryptobacterTengchongensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1643429.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1643429.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1643429.clusters.proteins.v11.5.txt",
		        "sequence_path": "1643429.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643429.protein.info.v11.5.txt",
		        "node_list_path": "1643429.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1643429.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MonosporascusSpGib2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Monosporascus sp. GIB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MonosporascusSpGib2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2211647.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2211647.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2211647.clusters.proteins.v11.5.txt",
		        "sequence_path": "2211647.protein.sequences.v11.5.fa",
		        "enrichment_path": "2211647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2211647.protein.info.v11.5.txt",
		        "node_list_path": "2211647.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2211647.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HyaloperonosporaArabidopsidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyaloperonospora arabidopsidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyaloperonosporaArabidopsidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "272952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "272952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "272952.clusters.proteins.v11.5.txt",
		        "sequence_path": "272952.protein.sequences.v11.5.fa",
		        "enrichment_path": "272952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272952.protein.info.v11.5.txt",
		        "node_list_path": "272952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "272952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpAp23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. AP23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpAp23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "499656.protein.sequences.v11.5.fa",
		        "enrichment_path": "499656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "499656.protein.info.v11.5.txt",
		        "node_list_path": "499656.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaeromyxobacterDehalogenans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaeromyxobacter dehalogenans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeromyxobacterDehalogenans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290397.protein.sequences.v11.5.fa",
		        "enrichment_path": "290397.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290397.protein.info.v11.5.txt",
		        "node_list_path": "290397.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolicicoccusSubflavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolicicoccus subflavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolicicoccusSubflavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "443218.protein.sequences.v11.5.fa",
		        "enrichment_path": "443218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443218.protein.info.v11.5.txt",
		        "node_list_path": "443218.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumAb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium AB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumAb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1898108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898108.protein.info.v11.5.txt",
		        "node_list_path": "1898108.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUzinuraDiaspidicolaStrAsner(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uzinura diaspidicola str. ASNER graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUzinuraDiaspidicolaStrAsner", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1133592.protein.sequences.v11.5.fa",
		        "enrichment_path": "1133592.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1133592.protein.info.v11.5.txt",
		        "node_list_path": "1133592.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsplowo201Full6025Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_60_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full6025Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802281.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802281.protein.info.v11.5.txt",
		        "node_list_path": "1802281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisJaponicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisJaponicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "281687.clusters.info.v11.5.txt",
		        "cluster_tree_path": "281687.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "281687.clusters.proteins.v11.5.txt",
		        "sequence_path": "281687.protein.sequences.v11.5.fa",
		        "enrichment_path": "281687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "281687.protein.info.v11.5.txt",
		        "node_list_path": "281687.cluster.nodes.v11.5.txt",
		        "edge_list_path": "281687.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSaprophyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus saprophyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSaprophyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "342451.clusters.info.v11.5.txt",
		        "cluster_tree_path": "342451.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "342451.clusters.proteins.v11.5.txt",
		        "sequence_path": "342451.protein.sequences.v11.5.fa",
		        "enrichment_path": "342451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342451.protein.info.v11.5.txt",
		        "node_list_path": "342451.cluster.nodes.v11.5.txt",
		        "edge_list_path": "342451.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwa25134Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_51_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwa25134Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797921.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797921.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797921.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797921.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797921.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797921.protein.info.v11.5.txt",
		        "node_list_path": "1797921.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797921.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpDoa9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. DOA9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpDoa9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1126627.protein.sequences.v11.5.fa",
		        "enrichment_path": "1126627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1126627.protein.info.v11.5.txt",
		        "node_list_path": "1126627.protein.complete.v11.5.txt"
		    }
		]
    )()

def GaeumannomycesGraminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gaeumannomyces graminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GaeumannomycesGraminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29850.clusters.proteins.v11.5.txt",
		        "sequence_path": "29850.protein.sequences.v11.5.fa",
		        "enrichment_path": "29850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29850.protein.info.v11.5.txt",
		        "node_list_path": "29850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KozakiaBaliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kozakia baliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KozakiaBaliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "153496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "153496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "153496.clusters.proteins.v11.5.txt",
		        "sequence_path": "153496.protein.sequences.v11.5.fa",
		        "enrichment_path": "153496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "153496.protein.info.v11.5.txt",
		        "node_list_path": "153496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "153496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusParafarraginis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus parafarraginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParafarraginis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "797515.protein.sequences.v11.5.fa",
		        "enrichment_path": "797515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797515.protein.info.v11.5.txt",
		        "node_list_path": "797515.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc24031(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC2_40_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc24031", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618924.protein.info.v11.5.txt",
		        "node_list_path": "1618924.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBrocadiaSinica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sinica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBrocadiaSinica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "795830.protein.sequences.v11.5.fa",
		        "enrichment_path": "795830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "795830.protein.info.v11.5.txt",
		        "node_list_path": "795830.protein.complete.v11.5.txt"
		    }
		]
    )()

def PectobacteriumBrasiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium brasiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumBrasiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "180957.protein.sequences.v11.5.fa",
		        "enrichment_path": "180957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180957.protein.info.v11.5.txt",
		        "node_list_path": "180957.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1934988.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1934988.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1934988.clusters.proteins.v11.5.txt",
		        "sequence_path": "1934988.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934988.protein.info.v11.5.txt",
		        "node_list_path": "1934988.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1934988.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalococcusAgarilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halococcus agarilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusAgarilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232219.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232219.protein.info.v11.5.txt",
		        "node_list_path": "1232219.protein.complete.v11.5.txt"
		    }
		]
    )()

def KordiimonasLacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kordiimonas lacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KordiimonasLacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "637679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "637679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "637679.clusters.proteins.v11.5.txt",
		        "sequence_path": "637679.protein.sequences.v11.5.fa",
		        "enrichment_path": "637679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637679.protein.info.v11.5.txt",
		        "node_list_path": "637679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "637679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumDamselae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium damselae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumDamselae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675817.protein.sequences.v11.5.fa",
		        "enrichment_path": "675817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675817.protein.info.v11.5.txt",
		        "node_list_path": "675817.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSpJ31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. J31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSpJ31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935851.clusters.proteins.v11.5.txt",
		        "sequence_path": "935851.protein.sequences.v11.5.fa",
		        "enrichment_path": "935851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935851.protein.info.v11.5.txt",
		        "node_list_path": "935851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSp3613Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. 36_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSp3613Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897001.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897001.protein.info.v11.5.txt",
		        "node_list_path": "1897001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarineActinobacteriumMedacidiG3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineActinobacteriumMedacidiG3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1550402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550402.protein.info.v11.5.txt",
		        "node_list_path": "1550402.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterLipolyticusSm19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter lipolyticus SM19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterLipolyticusSm19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1318628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1318628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1318628.protein.info.v11.5.txt",
		        "node_list_path": "1318628.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporothrixSchenckiiAtcc58251Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporothrix schenckii ATCC 58251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporothrixSchenckiiAtcc58251Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1391915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1391915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1391915.clusters.proteins.v11.5.txt",
		        "sequence_path": "1391915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391915.protein.info.v11.5.txt",
		        "node_list_path": "1391915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1391915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EremotheciumCymbalariaeDbvpg7215(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium cymbalariae DBVPG#7215 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EremotheciumCymbalariaeDbvpg7215", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "931890.protein.sequences.v11.5.fa",
		        "enrichment_path": "931890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "931890.protein.info.v11.5.txt",
		        "node_list_path": "931890.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterFelisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter felis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterFelisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936155.clusters.proteins.v11.5.txt",
		        "sequence_path": "936155.protein.sequences.v11.5.fa",
		        "enrichment_path": "936155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936155.protein.info.v11.5.txt",
		        "node_list_path": "936155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg166814Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_68_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg166814Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797660.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797660.protein.info.v11.5.txt",
		        "node_list_path": "1797660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpEr16(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. ER1/6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpEr16", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1891920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1891920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1891920.protein.info.v11.5.txt",
		        "node_list_path": "1891920.protein.complete.v11.5.txt"
		    }
		]
    )()

def HortaeaWerneckiiExf2000(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hortaea werneckii EXF-2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HortaeaWerneckiiExf2000", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157616.protein.info.v11.5.txt",
		        "node_list_path": "1157616.protein.complete.v11.5.txt"
		    }
		]
    )()

def NdongobacterMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ndongobacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NdongobacterMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871025.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871025.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871025.protein.info.v11.5.txt",
		        "node_list_path": "1871025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaDentiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria dentiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaDentiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "194197.protein.sequences.v11.5.fa",
		        "enrichment_path": "194197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "194197.protein.info.v11.5.txt",
		        "node_list_path": "194197.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusSpLeaf369Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus sp. Leaf369 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusSpLeaf369Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736354.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736354.protein.info.v11.5.txt",
		        "node_list_path": "1736354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRbg16437(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_43_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg16437", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798373.protein.info.v11.5.txt",
		        "node_list_path": "1798373.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusNiacini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus niacini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusNiacini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86668.protein.sequences.v11.5.fa",
		        "enrichment_path": "86668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86668.protein.info.v11.5.txt",
		        "node_list_path": "86668.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpP6a1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. P6A1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpP6a1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410612.protein.info.v11.5.txt",
		        "node_list_path": "1410612.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumFrigidisoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium frigidisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumFrigidisoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1125876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1125876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1125876.protein.info.v11.5.txt",
		        "node_list_path": "1125876.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifcsphigho212Full4616(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_12_FULL_46_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho212Full4616", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802513.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802513.protein.info.v11.5.txt",
		        "node_list_path": "1802513.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryctolagusCuniculusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryctolagus cuniculus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryctolagusCuniculusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9986.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9986.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9986.clusters.proteins.v11.5.txt",
		        "sequence_path": "9986.protein.sequences.v11.5.fa",
		        "enrichment_path": "9986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9986.protein.info.v11.5.txt",
		        "node_list_path": "9986.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9986.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylocaldumSp14bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylocaldum sp. 14B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocaldumSp14bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1912213.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1912213.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1912213.clusters.proteins.v11.5.txt",
		        "sequence_path": "1912213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912213.protein.info.v11.5.txt",
		        "node_list_path": "1912213.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1912213.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SalmoTrutta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salmo trutta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmoTrutta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8032.protein.sequences.v11.5.fa",
		        "enrichment_path": "8032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8032.protein.info.v11.5.txt",
		        "node_list_path": "8032.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSpRoot436(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. Root436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpRoot436", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736537.protein.info.v11.5.txt",
		        "node_list_path": "1736537.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterAntibioticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter antibioticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterAntibioticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "84531.protein.sequences.v11.5.fa",
		        "enrichment_path": "84531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84531.protein.info.v11.5.txt",
		        "node_list_path": "84531.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpAap93Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpAap93Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523427.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523427.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523427.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523427.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523427.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523427.protein.info.v11.5.txt",
		        "node_list_path": "1523427.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523427.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ConchiformibiusSteedaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Conchiformibius steedae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConchiformibiusSteedaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121352.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121352.protein.info.v11.5.txt",
		        "node_list_path": "1121352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArtemisiaAnnua(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Artemisia annua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArtemisiaAnnua", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35608.protein.sequences.v11.5.fa",
		        "enrichment_path": "35608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35608.protein.info.v11.5.txt",
		        "node_list_path": "35608.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSpHl93(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. HL-93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpHl93", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1666906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1666906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1666906.protein.info.v11.5.txt",
		        "node_list_path": "1666906.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesUrogenitalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesUrogenitalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "103621.protein.sequences.v11.5.fa",
		        "enrichment_path": "103621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103621.protein.info.v11.5.txt",
		        "node_list_path": "103621.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorDanieliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor danielii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorDanieliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1387557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1387557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1387557.clusters.proteins.v11.5.txt",
		        "sequence_path": "1387557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387557.protein.info.v11.5.txt",
		        "node_list_path": "1387557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1387557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpC05Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpC05Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945855.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945855.protein.info.v11.5.txt",
		        "node_list_path": "1945855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ExophialaDermatitidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exophiala dermatitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaDermatitidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5970.protein.sequences.v11.5.fa",
		        "enrichment_path": "5970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5970.protein.info.v11.5.txt",
		        "node_list_path": "5970.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaSpYr573(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga sp. YR573 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaSpYr573", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881040.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881040.protein.info.v11.5.txt",
		        "node_list_path": "1881040.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3818(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_38_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3818", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797795.protein.info.v11.5.txt",
		        "node_list_path": "1797795.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaSaoudiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella saoudiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaSaoudiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1750561.protein.sequences.v11.5.fa",
		        "enrichment_path": "1750561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1750561.protein.info.v11.5.txt",
		        "node_list_path": "1750561.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErysipelotrichaceaeBacterium5254faaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium 5254FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelotrichaceaeBacterium5254faaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "552396.clusters.info.v11.5.txt",
		        "cluster_tree_path": "552396.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "552396.clusters.proteins.v11.5.txt",
		        "sequence_path": "552396.protein.sequences.v11.5.fa",
		        "enrichment_path": "552396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "552396.protein.info.v11.5.txt",
		        "node_list_path": "552396.cluster.nodes.v11.5.txt",
		        "edge_list_path": "552396.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMycoplasmaHaemolamaeStrPurdue(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemolamae str. Purdue graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMycoplasmaHaemolamaeStrPurdue", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1212765.protein.sequences.v11.5.fa",
		        "enrichment_path": "1212765.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1212765.protein.info.v11.5.txt",
		        "node_list_path": "1212765.protein.complete.v11.5.txt"
		    }
		]
    )()

def PasteurellaTestudinisDsm23072Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella testudinis DSM 23072 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaTestudinisDsm23072Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122938.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122938.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122938.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122938.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122938.protein.info.v11.5.txt",
		        "node_list_path": "1122938.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122938.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HespelliaStercorisuisDsm15480Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hespellia stercorisuis DSM 15480 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HespelliaStercorisuisDsm15480Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121950.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121950.protein.info.v11.5.txt",
		        "node_list_path": "1121950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonasSpMex14Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. Mex14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasSpMex14Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1917157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1917157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1917157.clusters.proteins.v11.5.txt",
		        "sequence_path": "1917157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917157.protein.info.v11.5.txt",
		        "node_list_path": "1917157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1917157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwa2319(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_31_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwa2319", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797314.protein.info.v11.5.txt",
		        "node_list_path": "1797314.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelcococcusKunziiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helcococcus kunzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelcococcusKunziiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883114.clusters.proteins.v11.5.txt",
		        "sequence_path": "883114.protein.sequences.v11.5.fa",
		        "enrichment_path": "883114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883114.protein.info.v11.5.txt",
		        "node_list_path": "883114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwc13712b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWC1_37_12b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwc13712b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618510.protein.info.v11.5.txt",
		        "node_list_path": "1618510.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusChampanellensis18p13Jcm17042Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus champanellensis 18P13 JCM 17042 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusChampanellensis18p13Jcm17042Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "213810.clusters.info.v11.5.txt",
		        "cluster_tree_path": "213810.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "213810.clusters.proteins.v11.5.txt",
		        "sequence_path": "213810.protein.sequences.v11.5.fa",
		        "enrichment_path": "213810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "213810.protein.info.v11.5.txt",
		        "node_list_path": "213810.cluster.nodes.v11.5.txt",
		        "edge_list_path": "213810.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanomicrobiumGlacieiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planomicrobium glaciei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanomicrobiumGlacieiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1273538.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1273538.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1273538.clusters.proteins.v11.5.txt",
		        "sequence_path": "1273538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1273538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1273538.protein.info.v11.5.txt",
		        "node_list_path": "1273538.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1273538.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaPneumoniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia pneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaPneumoniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206737.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206737.protein.info.v11.5.txt",
		        "node_list_path": "1206737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAminophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio aminophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAminophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121440.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121440.protein.info.v11.5.txt",
		        "node_list_path": "1121440.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4415(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_12_FULL_44_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4415", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798364.protein.info.v11.5.txt",
		        "node_list_path": "1798364.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosovibrioSpNv6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosovibrio sp. Nv6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosovibrioSpNv6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855340.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855340.protein.info.v11.5.txt",
		        "node_list_path": "1855340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BipolarisZeicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris zeicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BipolarisZeicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5017.protein.sequences.v11.5.fa",
		        "enrichment_path": "5017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5017.protein.info.v11.5.txt",
		        "node_list_path": "5017.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRifcsphigho201Full4029(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFCSPHIGHO2_01_FULL_40_29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRifcsphigho201Full4029", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797389.protein.info.v11.5.txt",
		        "node_list_path": "1797389.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumFreiburgenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium freiburgense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumFreiburgenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121360.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121360.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121360.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121360.protein.info.v11.5.txt",
		        "node_list_path": "1121360.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121360.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph758(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH758 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph758", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217712.protein.info.v11.5.txt",
		        "node_list_path": "1217712.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusFusiformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus fusiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusFusiformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "714961.protein.sequences.v11.5.fa",
		        "enrichment_path": "714961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "714961.protein.info.v11.5.txt",
		        "node_list_path": "714961.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermobisporaBisporaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermobispora bispora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobisporaBisporaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469371.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469371.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469371.clusters.proteins.v11.5.txt",
		        "sequence_path": "469371.protein.sequences.v11.5.fa",
		        "enrichment_path": "469371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469371.protein.info.v11.5.txt",
		        "node_list_path": "469371.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469371.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GuillardiaThetaCcmp2712(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Guillardia theta CCMP2712 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GuillardiaThetaCcmp2712", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "905079.protein.sequences.v11.5.fa",
		        "enrichment_path": "905079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "905079.protein.info.v11.5.txt",
		        "node_list_path": "905079.protein.complete.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumThermophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumThermophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33905.protein.sequences.v11.5.fa",
		        "enrichment_path": "33905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33905.protein.info.v11.5.txt",
		        "node_list_path": "33905.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumMs0242a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium MS0242A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumMs0242a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "487796.protein.sequences.v11.5.fa",
		        "enrichment_path": "487796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "487796.protein.info.v11.5.txt",
		        "node_list_path": "487796.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaSpiralisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichinella spiralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaSpiralisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6334.clusters.proteins.v11.5.txt",
		        "sequence_path": "6334.protein.sequences.v11.5.fa",
		        "enrichment_path": "6334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6334.protein.info.v11.5.txt",
		        "node_list_path": "6334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumTetanomorphum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tetanomorphum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTetanomorphum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230342.protein.info.v11.5.txt",
		        "node_list_path": "1230342.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnhygromyxaSalina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enhygromyxa salina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnhygromyxaSalina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "215803.protein.sequences.v11.5.fa",
		        "enrichment_path": "215803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215803.protein.info.v11.5.txt",
		        "node_list_path": "215803.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls87Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls87Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463920.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463920.protein.info.v11.5.txt",
		        "node_list_path": "1463920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCelerecrescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] celerecrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCelerecrescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29354.protein.sequences.v11.5.fa",
		        "enrichment_path": "29354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29354.protein.info.v11.5.txt",
		        "node_list_path": "29354.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaAzureaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora azurea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaAzureaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1114959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1114959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1114959.clusters.proteins.v11.5.txt",
		        "sequence_path": "1114959.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114959.protein.info.v11.5.txt",
		        "node_list_path": "1114959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1114959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusCaeniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusCaeniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "405946.clusters.info.v11.5.txt",
		        "cluster_tree_path": "405946.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "405946.clusters.proteins.v11.5.txt",
		        "sequence_path": "405946.protein.sequences.v11.5.fa",
		        "enrichment_path": "405946.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405946.protein.info.v11.5.txt",
		        "node_list_path": "405946.cluster.nodes.v11.5.txt",
		        "edge_list_path": "405946.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriaceaeBacteriumChkci005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacteriaceae bacterium CHKCI005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriaceaeBacteriumChkci005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1780381.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1780381.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1780381.clusters.proteins.v11.5.txt",
		        "sequence_path": "1780381.protein.sequences.v11.5.fa",
		        "enrichment_path": "1780381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1780381.protein.info.v11.5.txt",
		        "node_list_path": "1780381.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1780381.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NicotianaAttenuataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nicotiana attenuata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NicotianaAttenuataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "49451.clusters.info.v11.5.txt",
		        "cluster_tree_path": "49451.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "49451.clusters.proteins.v11.5.txt",
		        "sequence_path": "49451.protein.sequences.v11.5.fa",
		        "enrichment_path": "49451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "49451.protein.info.v11.5.txt",
		        "node_list_path": "49451.cluster.nodes.v11.5.txt",
		        "edge_list_path": "49451.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VaribaculumTimonense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum timonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaribaculumTimonense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1964383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1964383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1964383.protein.info.v11.5.txt",
		        "node_list_path": "1964383.protein.complete.v11.5.txt"
		    }
		]
    )()

def CupriavidusSpYr651(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. YR651 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusSpYr651", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855315.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855315.protein.info.v11.5.txt",
		        "node_list_path": "1855315.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacterMarinusA45Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacter marinus A45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacterMarinusA45Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "674036.clusters.info.v11.5.txt",
		        "cluster_tree_path": "674036.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "674036.clusters.proteins.v11.5.txt",
		        "sequence_path": "674036.protein.sequences.v11.5.fa",
		        "enrichment_path": "674036.protein.enrichment.terms.v11.5.txt",
		        "info_path": "674036.protein.info.v11.5.txt",
		        "node_list_path": "674036.cluster.nodes.v11.5.txt",
		        "edge_list_path": "674036.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusVitulinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus vitulinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusVitulinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1167632.protein.sequences.v11.5.fa",
		        "enrichment_path": "1167632.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1167632.protein.info.v11.5.txt",
		        "node_list_path": "1167632.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusCaccae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus caccae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusCaccae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158612.protein.info.v11.5.txt",
		        "node_list_path": "1158612.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag927Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:927 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag927Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262753.protein.info.v11.5.txt",
		        "node_list_path": "1262753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CohnellaLaeviribosi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cohnella laeviribosi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CohnellaLaeviribosi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121346.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121346.protein.info.v11.5.txt",
		        "node_list_path": "1121346.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaAnanatisAj13355Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea ananatis AJ13355 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaAnanatisAj13355Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "932677.clusters.info.v11.5.txt",
		        "cluster_tree_path": "932677.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "932677.clusters.proteins.v11.5.txt",
		        "sequence_path": "932677.protein.sequences.v11.5.fa",
		        "enrichment_path": "932677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932677.protein.info.v11.5.txt",
		        "node_list_path": "932677.cluster.nodes.v11.5.txt",
		        "edge_list_path": "932677.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KwoniellaDejecticolaCbs10117Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella dejecticola CBS 10117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KwoniellaDejecticolaCbs10117Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1296121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1296121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1296121.clusters.proteins.v11.5.txt",
		        "sequence_path": "1296121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296121.protein.info.v11.5.txt",
		        "node_list_path": "1296121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1296121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaQueenslandensisAustNh15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella queenslandensis AUST/NH15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaQueenslandensisAustNh15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1221525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1221525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1221525.protein.info.v11.5.txt",
		        "node_list_path": "1221525.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwc2387(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWC2_38_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwc2387", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618920.protein.info.v11.5.txt",
		        "node_list_path": "1618920.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterLusitanusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter lusitanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterLusitanusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1503925.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1503925.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1503925.clusters.proteins.v11.5.txt",
		        "sequence_path": "1503925.protein.sequences.v11.5.fa",
		        "enrichment_path": "1503925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1503925.protein.info.v11.5.txt",
		        "node_list_path": "1503925.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1503925.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassospiraSpMccc1a01148Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A01148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraSpMccc1a01148Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "501834.clusters.info.v11.5.txt",
		        "cluster_tree_path": "501834.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "501834.clusters.proteins.v11.5.txt",
		        "sequence_path": "501834.protein.sequences.v11.5.fa",
		        "enrichment_path": "501834.protein.enrichment.terms.v11.5.txt",
		        "info_path": "501834.protein.info.v11.5.txt",
		        "node_list_path": "501834.cluster.nodes.v11.5.txt",
		        "edge_list_path": "501834.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoplasmaVolcanium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasma volcanium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmaVolcanium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "273116.protein.sequences.v11.5.fa",
		        "enrichment_path": "273116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273116.protein.info.v11.5.txt",
		        "node_list_path": "273116.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProvidenciaRustigianiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia rustigianii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaRustigianiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "500637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "500637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "500637.clusters.proteins.v11.5.txt",
		        "sequence_path": "500637.protein.sequences.v11.5.fa",
		        "enrichment_path": "500637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500637.protein.info.v11.5.txt",
		        "node_list_path": "500637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "500637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumStanieriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium stanieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumStanieriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1042375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1042375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1042375.clusters.proteins.v11.5.txt",
		        "sequence_path": "1042375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042375.protein.info.v11.5.txt",
		        "node_list_path": "1042375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1042375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpTpA0875Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. TP-A0875 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpTpA0875Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "552354.clusters.info.v11.5.txt",
		        "cluster_tree_path": "552354.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "552354.clusters.proteins.v11.5.txt",
		        "sequence_path": "552354.protein.sequences.v11.5.fa",
		        "enrichment_path": "552354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "552354.protein.info.v11.5.txt",
		        "node_list_path": "552354.cluster.nodes.v11.5.txt",
		        "edge_list_path": "552354.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusSpJcm19060(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. JCM 19060 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusSpJcm19060", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1481930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1481930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1481930.protein.info.v11.5.txt",
		        "node_list_path": "1481930.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwa1377(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_37_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa1377", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618545.protein.info.v11.5.txt",
		        "node_list_path": "1618545.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaAuratinigraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora auratinigra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaAuratinigraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "261654.clusters.info.v11.5.txt",
		        "cluster_tree_path": "261654.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "261654.clusters.proteins.v11.5.txt",
		        "sequence_path": "261654.protein.sequences.v11.5.fa",
		        "enrichment_path": "261654.protein.enrichment.terms.v11.5.txt",
		        "info_path": "261654.protein.info.v11.5.txt",
		        "node_list_path": "261654.cluster.nodes.v11.5.txt",
		        "edge_list_path": "261654.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelotomaculumThermopropionicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelotomaculum thermopropionicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelotomaculumThermopropionicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "370438.clusters.info.v11.5.txt",
		        "cluster_tree_path": "370438.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "370438.clusters.proteins.v11.5.txt",
		        "sequence_path": "370438.protein.sequences.v11.5.fa",
		        "enrichment_path": "370438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "370438.protein.info.v11.5.txt",
		        "node_list_path": "370438.cluster.nodes.v11.5.txt",
		        "edge_list_path": "370438.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusAmargosaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus amargosae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusAmargosaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1296565.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1296565.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1296565.clusters.proteins.v11.5.txt",
		        "sequence_path": "1296565.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296565.protein.info.v11.5.txt",
		        "node_list_path": "1296565.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1296565.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PoeciliaFormosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Poecilia formosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PoeciliaFormosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "48698.protein.sequences.v11.5.fa",
		        "enrichment_path": "48698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48698.protein.info.v11.5.txt",
		        "node_list_path": "48698.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgarivoransAlbusMkt106(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agarivorans albus MKT 106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgarivoransAlbusMkt106", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1331007.protein.sequences.v11.5.fa",
		        "enrichment_path": "1331007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1331007.protein.info.v11.5.txt",
		        "node_list_path": "1331007.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpXpd2006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. XPD2006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpXpd2006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280668.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280668.protein.info.v11.5.txt",
		        "node_list_path": "1280668.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemmataSpShPl17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmata sp. SH-PL17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmataSpShPl17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1630693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1630693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1630693.protein.info.v11.5.txt",
		        "node_list_path": "1630693.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhormidesmisPriestleyiUlc007(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi ULC007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhormidesmisPriestleyiUlc007", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1920490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920490.protein.info.v11.5.txt",
		        "node_list_path": "1920490.protein.complete.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaCinaraPseudotaxifoliaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara pseudotaxifoliae) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaCinaraPseudotaxifoliaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655384.clusters.proteins.v11.5.txt",
		        "sequence_path": "655384.protein.sequences.v11.5.fa",
		        "enrichment_path": "655384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655384.protein.info.v11.5.txt",
		        "node_list_path": "655384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSp73h25ap(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. 73H25AP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSp73h25ap", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "864570.protein.sequences.v11.5.fa",
		        "enrichment_path": "864570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864570.protein.info.v11.5.txt",
		        "node_list_path": "864570.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterGandensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter gandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterGandensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1443941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443941.protein.info.v11.5.txt",
		        "node_list_path": "1443941.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronorubrumTexcoconenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronorubrum texcoconense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronorubrumTexcoconenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1095776.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1095776.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1095776.clusters.proteins.v11.5.txt",
		        "sequence_path": "1095776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095776.protein.info.v11.5.txt",
		        "node_list_path": "1095776.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1095776.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaSpHmsc064e01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC064E01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSpHmsc064e01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1715052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1715052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1715052.clusters.proteins.v11.5.txt",
		        "sequence_path": "1715052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1715052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1715052.protein.info.v11.5.txt",
		        "node_list_path": "1715052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1715052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmatimonasSpAp64(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonas sp. AP64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonasSpAp64", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379270.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379270.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379270.protein.info.v11.5.txt",
		        "node_list_path": "1379270.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusPanaciterraeDsm19096(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus panaciterrae DSM 19096 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPanaciterraeDsm19096", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121093.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121093.protein.info.v11.5.txt",
		        "node_list_path": "1121093.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaFleischmanniiSubspFleischmanniiLu20061Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria fleischmannii subsp. fleischmannii LU2006-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaFleischmanniiSubspFleischmanniiLu20061Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1214117.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1214117.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1214117.clusters.proteins.v11.5.txt",
		        "sequence_path": "1214117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214117.protein.info.v11.5.txt",
		        "node_list_path": "1214117.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1214117.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0310Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0310Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888052.clusters.proteins.v11.5.txt",
		        "sequence_path": "888052.protein.sequences.v11.5.fa",
		        "enrichment_path": "888052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888052.protein.info.v11.5.txt",
		        "node_list_path": "888052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumAgaricidamnosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium agaricidamnosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumAgaricidamnosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349767.protein.info.v11.5.txt",
		        "node_list_path": "1349767.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConiophoraPuteanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coniophora puteana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConiophoraPuteanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "80637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "80637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "80637.clusters.proteins.v11.5.txt",
		        "sequence_path": "80637.protein.sequences.v11.5.fa",
		        "enrichment_path": "80637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80637.protein.info.v11.5.txt",
		        "node_list_path": "80637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "80637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinophytocolaXanthiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinophytocola xanthii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinophytocolaXanthiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1912961.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1912961.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1912961.clusters.proteins.v11.5.txt",
		        "sequence_path": "1912961.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912961.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912961.protein.info.v11.5.txt",
		        "node_list_path": "1912961.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1912961.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumVe20213(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumVe20213", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232443.protein.info.v11.5.txt",
		        "node_list_path": "1232443.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesoniaPhycicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesonia phycicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesoniaPhycicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "579105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "579105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "579105.clusters.proteins.v11.5.txt",
		        "sequence_path": "579105.protein.sequences.v11.5.fa",
		        "enrichment_path": "579105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579105.protein.info.v11.5.txt",
		        "node_list_path": "579105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "579105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaProteobacteriumScgcAaa076P13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA076-P13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaProteobacteriumScgcAaa076P13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1007119.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007119.protein.info.v11.5.txt",
		        "node_list_path": "1007119.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3630Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_36_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3630Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798275.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798275.protein.info.v11.5.txt",
		        "node_list_path": "1798275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpNbrc111131(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. NBRC 111131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpNbrc111131", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1661046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661046.protein.info.v11.5.txt",
		        "node_list_path": "1661046.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAlcoholivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio alcoholivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAlcoholivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121438.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121438.protein.info.v11.5.txt",
		        "node_list_path": "1121438.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusOdysseyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus odysseyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusOdysseyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220589.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220589.protein.info.v11.5.txt",
		        "node_list_path": "1220589.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaumarchaeotaArchaeonCaspThauma3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon casp-thauma3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaumarchaeotaArchaeonCaspThauma3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1661713.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661713.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661713.protein.info.v11.5.txt",
		        "node_list_path": "1661713.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeromonasSalmonicidaSubspSalmonicida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. salmonicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasSalmonicidaSubspSalmonicida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29491.protein.sequences.v11.5.fa",
		        "enrichment_path": "29491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29491.protein.info.v11.5.txt",
		        "node_list_path": "29491.protein.complete.v11.5.txt"
		    }
		]
    )()

def OphiocordycepsAustralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OphiocordycepsAustralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1399860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1399860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1399860.protein.info.v11.5.txt",
		        "node_list_path": "1399860.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusThermomutatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus thermomutatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusThermomutatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "41047.clusters.info.v11.5.txt",
		        "cluster_tree_path": "41047.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "41047.clusters.proteins.v11.5.txt",
		        "sequence_path": "41047.protein.sequences.v11.5.fa",
		        "enrichment_path": "41047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41047.protein.info.v11.5.txt",
		        "node_list_path": "41047.cluster.nodes.v11.5.txt",
		        "edge_list_path": "41047.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcaceaeBacteriumMarseilleP2935(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium Marseille-P2935 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcaceaeBacteriumMarseilleP2935", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852383.protein.info.v11.5.txt",
		        "node_list_path": "1852383.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasPhenolicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas phenolica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasPhenolicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "161398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "161398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "161398.clusters.proteins.v11.5.txt",
		        "sequence_path": "161398.protein.sequences.v11.5.fa",
		        "enrichment_path": "161398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161398.protein.info.v11.5.txt",
		        "node_list_path": "161398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "161398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaNbrc14164Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida NBRC14164 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaNbrc14164Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211579.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211579.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211579.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211579.protein.info.v11.5.txt",
		        "node_list_path": "1211579.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211579.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SyntrophomonasPalmitaticaJcm14374Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas palmitatica JCM 14374 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophomonasPalmitaticaJcm14374Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1294023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1294023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1294023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1294023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294023.protein.info.v11.5.txt",
		        "node_list_path": "1294023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1294023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LodderomycesElongisporusNrrlYb4239(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lodderomyces elongisporus NRRL YB-4239 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LodderomycesElongisporusNrrlYb4239", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "379508.protein.sequences.v11.5.fa",
		        "enrichment_path": "379508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "379508.protein.info.v11.5.txt",
		        "node_list_path": "379508.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurihydrogenibiumAzorenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium azorense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurihydrogenibiumAzorenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "204536.clusters.info.v11.5.txt",
		        "cluster_tree_path": "204536.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "204536.clusters.proteins.v11.5.txt",
		        "sequence_path": "204536.protein.sequences.v11.5.fa",
		        "enrichment_path": "204536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "204536.protein.info.v11.5.txt",
		        "node_list_path": "204536.cluster.nodes.v11.5.txt",
		        "edge_list_path": "204536.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp14657030Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1465703.0 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp14657030Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834078.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834078.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834078.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834078.protein.info.v11.5.txt",
		        "node_list_path": "1834078.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834078.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SilvanigrellaAquatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Silvanigrella aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SilvanigrellaAquatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1915309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915309.protein.info.v11.5.txt",
		        "node_list_path": "1915309.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterJejuni414(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter jejuni 414 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterJejuni414", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "683083.protein.sequences.v11.5.fa",
		        "enrichment_path": "683083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "683083.protein.info.v11.5.txt",
		        "node_list_path": "683083.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemmatimonadetesBacterium13120cm46611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium 13_1_20CM_4_66_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonadetesBacterium13120cm46611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805172.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805172.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805172.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805172.protein.info.v11.5.txt",
		        "node_list_path": "1805172.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805172.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumFe2018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium FE2018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumFe2018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410624.protein.info.v11.5.txt",
		        "node_list_path": "1410624.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4422b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_01_FULL_44_22b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4422b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802737.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802737.protein.info.v11.5.txt",
		        "node_list_path": "1802737.protein.complete.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioProteoclasticusB316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus B316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioProteoclasticusB316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "515622.clusters.info.v11.5.txt",
		        "cluster_tree_path": "515622.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "515622.clusters.proteins.v11.5.txt",
		        "sequence_path": "515622.protein.sequences.v11.5.fa",
		        "enrichment_path": "515622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "515622.protein.info.v11.5.txt",
		        "node_list_path": "515622.cluster.nodes.v11.5.txt",
		        "edge_list_path": "515622.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinopolysporaErythraea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora erythraea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinopolysporaErythraea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "414996.protein.sequences.v11.5.fa",
		        "enrichment_path": "414996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "414996.protein.info.v11.5.txt",
		        "node_list_path": "414996.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaShahii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia shahii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaShahii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122172.protein.info.v11.5.txt",
		        "node_list_path": "1122172.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesUniformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides uniformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesUniformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411479.protein.sequences.v11.5.fa",
		        "enrichment_path": "411479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411479.protein.info.v11.5.txt",
		        "node_list_path": "411479.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumEzzemoulenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum ezzemoulense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumEzzemoulenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121945.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121945.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121945.protein.info.v11.5.txt",
		        "node_list_path": "1121945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GracilibacillusUreilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus ureilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusUreilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "531814.protein.sequences.v11.5.fa",
		        "enrichment_path": "531814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "531814.protein.info.v11.5.txt",
		        "node_list_path": "531814.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSubterranea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas subterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSubterranea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "416874.protein.sequences.v11.5.fa",
		        "enrichment_path": "416874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "416874.protein.info.v11.5.txt",
		        "node_list_path": "416874.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseburiaSpCag182Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:182 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSpCag182Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262942.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262942.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262942.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262942.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262942.protein.info.v11.5.txt",
		        "node_list_path": "1262942.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262942.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumGw2011Gwa24413b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWA2_44_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwa24413b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618647.protein.info.v11.5.txt",
		        "node_list_path": "1618647.protein.complete.v11.5.txt"
		    }
		]
    )()

def SnodgrassellaAlviWkb2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Snodgrassella alvi wkB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SnodgrassellaAlviWkb2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196094.protein.info.v11.5.txt",
		        "node_list_path": "1196094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumLacusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium lacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumLacusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "877455.clusters.info.v11.5.txt",
		        "cluster_tree_path": "877455.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "877455.clusters.proteins.v11.5.txt",
		        "sequence_path": "877455.protein.sequences.v11.5.fa",
		        "enrichment_path": "877455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877455.protein.info.v11.5.txt",
		        "node_list_path": "877455.cluster.nodes.v11.5.txt",
		        "edge_list_path": "877455.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAcidophilus30scCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus 30SC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAcidophilus30scCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "891391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "891391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "891391.clusters.proteins.v11.5.txt",
		        "sequence_path": "891391.protein.sequences.v11.5.fa",
		        "enrichment_path": "891391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "891391.protein.info.v11.5.txt",
		        "node_list_path": "891391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "891391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobacillusSpC254(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacillus sp. C254 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobacillusSpC254", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1225341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225341.protein.info.v11.5.txt",
		        "node_list_path": "1225341.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpDg25bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. DG25B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpDg25bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385664.protein.info.v11.5.txt",
		        "node_list_path": "1385664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpChol1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Chol1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpChol1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "440512.clusters.info.v11.5.txt",
		        "cluster_tree_path": "440512.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "440512.clusters.proteins.v11.5.txt",
		        "sequence_path": "440512.protein.sequences.v11.5.fa",
		        "enrichment_path": "440512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "440512.protein.info.v11.5.txt",
		        "node_list_path": "440512.cluster.nodes.v11.5.txt",
		        "edge_list_path": "440512.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumTestaceumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium testaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumTestaceumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "979556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "979556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "979556.clusters.proteins.v11.5.txt",
		        "sequence_path": "979556.protein.sequences.v11.5.fa",
		        "enrichment_path": "979556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "979556.protein.info.v11.5.txt",
		        "node_list_path": "979556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "979556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaTularensisHolarcticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella tularensis holarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaTularensisHolarcticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "376619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "376619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "376619.clusters.proteins.v11.5.txt",
		        "sequence_path": "376619.protein.sequences.v11.5.fa",
		        "enrichment_path": "376619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376619.protein.info.v11.5.txt",
		        "node_list_path": "376619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "376619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParascardoviaDenticolensIpla20019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parascardovia denticolens IPLA20019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParascardoviaDenticolensIpla20019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1193128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1193128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1193128.clusters.proteins.v11.5.txt",
		        "sequence_path": "1193128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193128.protein.info.v11.5.txt",
		        "node_list_path": "1193128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1193128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaPneumophilaSubspFraseriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila subsp. fraseri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaPneumophilaSubspFraseriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "91892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "91892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "91892.clusters.proteins.v11.5.txt",
		        "sequence_path": "91892.protein.sequences.v11.5.fa",
		        "enrichment_path": "91892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "91892.protein.info.v11.5.txt",
		        "node_list_path": "91892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "91892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClavisporaLusitaniaeAtcc42720Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clavispora lusitaniae ATCC 42720 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClavisporaLusitaniaeAtcc42720Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "306902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "306902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "306902.clusters.proteins.v11.5.txt",
		        "sequence_path": "306902.protein.sequences.v11.5.fa",
		        "enrichment_path": "306902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306902.protein.info.v11.5.txt",
		        "node_list_path": "306902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "306902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpS6spd3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. S6Spd3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpS6spd3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1284680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1284680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1284680.clusters.proteins.v11.5.txt",
		        "sequence_path": "1284680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1284680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1284680.protein.info.v11.5.txt",
		        "node_list_path": "1284680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1284680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanibacterLimosusNbrc16128Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janibacter limosus NBRC 16128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterLimosusNbrc16128Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216970.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216970.protein.info.v11.5.txt",
		        "node_list_path": "1216970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CollinsellaVaginalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collinsella vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaVaginalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1870987.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1870987.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1870987.clusters.proteins.v11.5.txt",
		        "sequence_path": "1870987.protein.sequences.v11.5.fa",
		        "enrichment_path": "1870987.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1870987.protein.info.v11.5.txt",
		        "node_list_path": "1870987.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1870987.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonB261Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B26-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB261Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1779370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1779370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1779370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1779370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1779370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1779370.protein.info.v11.5.txt",
		        "node_list_path": "1779370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1779370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasCapeferrumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas capeferrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCapeferrumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1495066.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1495066.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1495066.clusters.proteins.v11.5.txt",
		        "sequence_path": "1495066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1495066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1495066.protein.info.v11.5.txt",
		        "node_list_path": "1495066.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1495066.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852387.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852387.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852387.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852387.protein.info.v11.5.txt",
		        "node_list_path": "1852387.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852387.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DemequinaGlobuliformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Demequina globuliformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DemequinaGlobuliformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "676202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "676202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "676202.clusters.proteins.v11.5.txt",
		        "sequence_path": "676202.protein.sequences.v11.5.fa",
		        "enrichment_path": "676202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "676202.protein.info.v11.5.txt",
		        "node_list_path": "676202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "676202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifoxyd2Full3916(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYD2_FULL_39_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyd2Full3916", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798009.protein.info.v11.5.txt",
		        "node_list_path": "1798009.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumLacus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium lacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumLacus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "877455.protein.sequences.v11.5.fa",
		        "enrichment_path": "877455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877455.protein.info.v11.5.txt",
		        "node_list_path": "877455.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterFetusTestudinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus testudinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterFetusTestudinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1244528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1244528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1244528.protein.info.v11.5.txt",
		        "node_list_path": "1244528.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumCg10239135(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium CG1_02_39_135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumCg10239135", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805425.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805425.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805425.protein.info.v11.5.txt",
		        "node_list_path": "1805425.protein.complete.v11.5.txt"
		    }
		]
    )()

def JannaschiaPohangensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia pohangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaPohangensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "390807.protein.sequences.v11.5.fa",
		        "enrichment_path": "390807.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390807.protein.info.v11.5.txt",
		        "node_list_path": "390807.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichechusManatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichechus manatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichechusManatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9778.clusters.proteins.v11.5.txt",
		        "sequence_path": "9778.protein.sequences.v11.5.fa",
		        "enrichment_path": "9778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9778.protein.info.v11.5.txt",
		        "node_list_path": "9778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusPobuzihii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pobuzihii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPobuzihii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "449659.protein.sequences.v11.5.fa",
		        "enrichment_path": "449659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "449659.protein.info.v11.5.txt",
		        "node_list_path": "449659.protein.complete.v11.5.txt"
		    }
		]
    )()

def KangiellaSediminilitorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kangiella sediminilitoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KangiellaSediminilitorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1144748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1144748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1144748.clusters.proteins.v11.5.txt",
		        "sequence_path": "1144748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1144748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1144748.protein.info.v11.5.txt",
		        "node_list_path": "1144748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1144748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliiroseovariusSediminilitorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliiroseovarius sediminilitoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliiroseovariusSediminilitorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173584.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173584.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173584.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173584.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173584.protein.info.v11.5.txt",
		        "node_list_path": "1173584.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173584.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarivivensSpJlt3646(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marivivens sp. JLT3646 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivivensSpJlt3646", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1920883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920883.protein.info.v11.5.txt",
		        "node_list_path": "1920883.protein.complete.v11.5.txt"
		    }
		]
    )()

def GrimontiaIndica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Grimontia indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GrimontiaIndica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1056512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1056512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1056512.protein.info.v11.5.txt",
		        "node_list_path": "1056512.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaAmazonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella amazonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaAmazonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326297.protein.sequences.v11.5.fa",
		        "enrichment_path": "326297.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326297.protein.info.v11.5.txt",
		        "node_list_path": "326297.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf24(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf24", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735690.protein.info.v11.5.txt",
		        "node_list_path": "1735690.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusThiodiazotrophaEndoloripesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thiodiazotropha endoloripes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThiodiazotrophaEndoloripesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1818881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1818881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1818881.clusters.proteins.v11.5.txt",
		        "sequence_path": "1818881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1818881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1818881.protein.info.v11.5.txt",
		        "node_list_path": "1818881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1818881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerovibrioSpRm50(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerovibrio sp. RM50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerovibrioSpRm50", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1200557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200557.protein.info.v11.5.txt",
		        "node_list_path": "1200557.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumLiaoningenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium liaoningense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumLiaoningenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43992.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43992.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43992.clusters.proteins.v11.5.txt",
		        "sequence_path": "43992.protein.sequences.v11.5.fa",
		        "enrichment_path": "43992.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43992.protein.info.v11.5.txt",
		        "node_list_path": "43992.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43992.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaliscomenobacterHydrossis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haliscomenobacter hydrossis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaliscomenobacterHydrossis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "760192.protein.sequences.v11.5.fa",
		        "enrichment_path": "760192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "760192.protein.info.v11.5.txt",
		        "node_list_path": "760192.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermanaeromonasToyohensisTobeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermanaeromonas toyohensis ToBE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermanaeromonasToyohensisTobeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "698762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "698762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "698762.clusters.proteins.v11.5.txt",
		        "sequence_path": "698762.protein.sequences.v11.5.fa",
		        "enrichment_path": "698762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698762.protein.info.v11.5.txt",
		        "node_list_path": "698762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "698762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumC7867003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumC7867003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1659197.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659197.protein.info.v11.5.txt",
		        "node_list_path": "1659197.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu072Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU072 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu072Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671656.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671656.protein.info.v11.5.txt",
		        "node_list_path": "1671656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusBrockianus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus brockianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusBrockianus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56956.protein.sequences.v11.5.fa",
		        "enrichment_path": "56956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56956.protein.info.v11.5.txt",
		        "node_list_path": "56956.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumElephantisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium elephantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumElephantisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "81858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "81858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "81858.clusters.proteins.v11.5.txt",
		        "sequence_path": "81858.protein.sequences.v11.5.fa",
		        "enrichment_path": "81858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81858.protein.info.v11.5.txt",
		        "node_list_path": "81858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "81858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingorhabdusMarinaDsm22363(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingorhabdus marina DSM 22363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingorhabdusMarinaDsm22363", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123272.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123272.protein.info.v11.5.txt",
		        "node_list_path": "1123272.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscovopsisWeberi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escovopsis weberi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscovopsisWeberi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "150374.protein.sequences.v11.5.fa",
		        "enrichment_path": "150374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150374.protein.info.v11.5.txt",
		        "node_list_path": "150374.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfococcusOleovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfococcus oleovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfococcusOleovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "96561.protein.sequences.v11.5.fa",
		        "enrichment_path": "96561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "96561.protein.info.v11.5.txt",
		        "node_list_path": "96561.protein.complete.v11.5.txt"
		    }
		]
    )()

def AngelakisellaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Angelakisella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AngelakisellaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1871018.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871018.protein.info.v11.5.txt",
		        "node_list_path": "1871018.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerpulaLacrymansVarLacrymansS73Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serpula lacrymans var. lacrymans S7.3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerpulaLacrymansVarLacrymansS73Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936435.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936435.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936435.clusters.proteins.v11.5.txt",
		        "sequence_path": "936435.protein.sequences.v11.5.fa",
		        "enrichment_path": "936435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936435.protein.info.v11.5.txt",
		        "node_list_path": "936435.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936435.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArachisHypogaea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arachis hypogaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArachisHypogaea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3818.protein.sequences.v11.5.fa",
		        "enrichment_path": "3818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3818.protein.info.v11.5.txt",
		        "node_list_path": "3818.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaCulicicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma culicicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaCulicicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1276246.protein.sequences.v11.5.fa",
		        "enrichment_path": "1276246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1276246.protein.info.v11.5.txt",
		        "node_list_path": "1276246.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusMarincolaDsm16067Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus marincola DSM16067 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusMarincolaDsm16067Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120966.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120966.protein.info.v11.5.txt",
		        "node_list_path": "1120966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesVenezuelaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces venezuelae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesVenezuelaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "953739.clusters.info.v11.5.txt",
		        "cluster_tree_path": "953739.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "953739.clusters.proteins.v11.5.txt",
		        "sequence_path": "953739.protein.sequences.v11.5.fa",
		        "enrichment_path": "953739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "953739.protein.info.v11.5.txt",
		        "node_list_path": "953739.cluster.nodes.v11.5.txt",
		        "edge_list_path": "953739.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KibdelosporangiumPhytohabitans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kibdelosporangium phytohabitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KibdelosporangiumPhytohabitans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "860235.protein.sequences.v11.5.fa",
		        "enrichment_path": "860235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "860235.protein.info.v11.5.txt",
		        "node_list_path": "860235.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumGleum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium gleum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumGleum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525257.protein.sequences.v11.5.fa",
		        "enrichment_path": "525257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525257.protein.info.v11.5.txt",
		        "node_list_path": "525257.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpKmsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KMS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpKmsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1566023.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1566023.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1566023.clusters.proteins.v11.5.txt",
		        "sequence_path": "1566023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566023.protein.info.v11.5.txt",
		        "node_list_path": "1566023.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1566023.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpKnhs209(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpKnhs209", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1469948.protein.sequences.v11.5.fa",
		        "enrichment_path": "1469948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1469948.protein.info.v11.5.txt",
		        "node_list_path": "1469948.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumGw2011Gwf24415(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWF2_44_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwf24415", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618404.protein.info.v11.5.txt",
		        "node_list_path": "1618404.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZosteraMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Zostera marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZosteraMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29655.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29655.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29655.clusters.proteins.v11.5.txt",
		        "sequence_path": "29655.protein.sequences.v11.5.fa",
		        "enrichment_path": "29655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29655.protein.info.v11.5.txt",
		        "node_list_path": "29655.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29655.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpHsism1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. HSISM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpHsism1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1316408.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1316408.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1316408.clusters.proteins.v11.5.txt",
		        "sequence_path": "1316408.protein.sequences.v11.5.fa",
		        "enrichment_path": "1316408.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1316408.protein.info.v11.5.txt",
		        "node_list_path": "1316408.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1316408.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumDefluvii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium defluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumDefluvii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "370979.protein.sequences.v11.5.fa",
		        "enrichment_path": "370979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "370979.protein.info.v11.5.txt",
		        "node_list_path": "370979.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpLeaf337(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf337 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpLeaf337", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736342.protein.info.v11.5.txt",
		        "node_list_path": "1736342.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeptunomonasJaponicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neptunomonas japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptunomonasJaponicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122599.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122599.protein.info.v11.5.txt",
		        "node_list_path": "1122599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasEndophytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas endophytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasEndophytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1563157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1563157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1563157.protein.info.v11.5.txt",
		        "node_list_path": "1563157.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioCuneatusDsm11391Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio cuneatus DSM 11391 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioCuneatusDsm11391Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121443.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121443.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121443.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121443.protein.info.v11.5.txt",
		        "node_list_path": "1121443.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121443.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDesulfofervidusAuxilii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desulfofervidus auxilii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDesulfofervidusAuxilii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1621989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1621989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1621989.protein.info.v11.5.txt",
		        "node_list_path": "1621989.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurivirgaCaldicuraliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurivirga caldicuralii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurivirgaCaldicuraliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "364032.clusters.info.v11.5.txt",
		        "cluster_tree_path": "364032.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "364032.clusters.proteins.v11.5.txt",
		        "sequence_path": "364032.protein.sequences.v11.5.fa",
		        "enrichment_path": "364032.protein.enrichment.terms.v11.5.txt",
		        "info_path": "364032.protein.info.v11.5.txt",
		        "node_list_path": "364032.cluster.nodes.v11.5.txt",
		        "edge_list_path": "364032.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaplasmaMarginaleSt(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma marginale St. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaplasmaMarginaleSt", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "234826.protein.sequences.v11.5.fa",
		        "enrichment_path": "234826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "234826.protein.info.v11.5.txt",
		        "node_list_path": "234826.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanibacterCorallicolaNbrc107790(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janibacter corallicola NBRC 107790 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterCorallicolaNbrc107790", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216969.protein.info.v11.5.txt",
		        "node_list_path": "1216969.protein.complete.v11.5.txt"
		    }
		]
    )()

def MannheimiaSucciniciproducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia succiniciproducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MannheimiaSucciniciproducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "221988.clusters.info.v11.5.txt",
		        "cluster_tree_path": "221988.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "221988.clusters.proteins.v11.5.txt",
		        "sequence_path": "221988.protein.sequences.v11.5.fa",
		        "enrichment_path": "221988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221988.protein.info.v11.5.txt",
		        "node_list_path": "221988.cluster.nodes.v11.5.txt",
		        "edge_list_path": "221988.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysobacterToleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter tolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterToleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1604334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1604334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1604334.clusters.proteins.v11.5.txt",
		        "sequence_path": "1604334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1604334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1604334.protein.info.v11.5.txt",
		        "node_list_path": "1604334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1604334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaMexicanaNbrc108244Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia mexicana NBRC 108244 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaMexicanaNbrc108244Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210089.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210089.protein.info.v11.5.txt",
		        "node_list_path": "1210089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SutterellaParvirubraYit11816(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sutterella parvirubra YIT 11816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SutterellaParvirubraYit11816", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "762967.protein.sequences.v11.5.fa",
		        "enrichment_path": "762967.protein.enrichment.terms.v11.5.txt",
		        "info_path": "762967.protein.info.v11.5.txt",
		        "node_list_path": "762967.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpKpl1989Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1989 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpKpl1989Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203622.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203622.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203622.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203622.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203622.protein.info.v11.5.txt",
		        "node_list_path": "1203622.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203622.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusAcidiproducensDsm23148(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus acidiproducens DSM 23148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAcidiproducensDsm23148", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "444461.protein.sequences.v11.5.fa",
		        "enrichment_path": "444461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "444461.protein.info.v11.5.txt",
		        "node_list_path": "444461.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeofusicoccumParvum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neofusicoccum parvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeofusicoccumParvum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "310453.protein.sequences.v11.5.fa",
		        "enrichment_path": "310453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "310453.protein.info.v11.5.txt",
		        "node_list_path": "310453.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpAg109O510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Ag109_O5-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpAg109O510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855349.protein.info.v11.5.txt",
		        "node_list_path": "1855349.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaLimicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena limicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaLimicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230457.protein.info.v11.5.txt",
		        "node_list_path": "1230457.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb241529c4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241_529C4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb241529c4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1471463.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471463.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471463.protein.info.v11.5.txt",
		        "node_list_path": "1471463.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAcetothermiaBacteriumJdfr48(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acetothermia bacterium JdFR-48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAcetothermiaBacteriumJdfr48", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935102.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935102.protein.info.v11.5.txt",
		        "node_list_path": "1935102.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsplowo201Full6025(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_60_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full6025", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802281.protein.info.v11.5.txt",
		        "node_list_path": "1802281.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraSpSgBin2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospira sp. SG-bin2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraSpSgBin2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1827377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827377.protein.info.v11.5.txt",
		        "node_list_path": "1827377.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollinsellaTanakaei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collinsella tanakaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaTanakaei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742742.protein.sequences.v11.5.fa",
		        "enrichment_path": "742742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742742.protein.info.v11.5.txt",
		        "node_list_path": "742742.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesLiubingyangiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces liubingyangii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesLiubingyangiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1921764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1921764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1921764.clusters.proteins.v11.5.txt",
		        "sequence_path": "1921764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921764.protein.info.v11.5.txt",
		        "node_list_path": "1921764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1921764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomirabilisOxyfera(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomirabilis oxyfera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomirabilisOxyfera", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "671143.protein.sequences.v11.5.fa",
		        "enrichment_path": "671143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "671143.protein.info.v11.5.txt",
		        "node_list_path": "671143.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasSpMitacek01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Mitacek01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasSpMitacek01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1732019.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1732019.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1732019.clusters.proteins.v11.5.txt",
		        "sequence_path": "1732019.protein.sequences.v11.5.fa",
		        "enrichment_path": "1732019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1732019.protein.info.v11.5.txt",
		        "node_list_path": "1732019.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1732019.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusTorquesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Ruminococcus] torques Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusTorquesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33039.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33039.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33039.clusters.proteins.v11.5.txt",
		        "sequence_path": "33039.protein.sequences.v11.5.fa",
		        "enrichment_path": "33039.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33039.protein.info.v11.5.txt",
		        "node_list_path": "33039.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33039.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumCg1024617(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium CG1_02_46_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumCg1024617", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1803508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803508.protein.info.v11.5.txt",
		        "node_list_path": "1803508.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrososphaeraViennensisEn76Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrososphaera viennensis EN76 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrososphaeraViennensisEn76Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926571.clusters.proteins.v11.5.txt",
		        "sequence_path": "926571.protein.sequences.v11.5.fa",
		        "enrichment_path": "926571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926571.protein.info.v11.5.txt",
		        "node_list_path": "926571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumAngustumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium angustum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumAngustumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314292.clusters.proteins.v11.5.txt",
		        "sequence_path": "314292.protein.sequences.v11.5.fa",
		        "enrichment_path": "314292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314292.protein.info.v11.5.txt",
		        "node_list_path": "314292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AggregatibacterAphrophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter aphrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AggregatibacterAphrophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634176.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634176.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634176.clusters.proteins.v11.5.txt",
		        "sequence_path": "634176.protein.sequences.v11.5.fa",
		        "enrichment_path": "634176.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634176.protein.info.v11.5.txt",
		        "node_list_path": "634176.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634176.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterDongtanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter dongtanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterDongtanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "692370.protein.sequences.v11.5.fa",
		        "enrichment_path": "692370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "692370.protein.info.v11.5.txt",
		        "node_list_path": "692370.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpUnc451mfCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNC451MF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpUnc451mfCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449063.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449063.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449063.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449063.protein.info.v11.5.txt",
		        "node_list_path": "1449063.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449063.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentibacillusHaloduransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus halodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentibacillusHaloduransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "237679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "237679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "237679.clusters.proteins.v11.5.txt",
		        "sequence_path": "237679.protein.sequences.v11.5.fa",
		        "enrichment_path": "237679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237679.protein.info.v11.5.txt",
		        "node_list_path": "237679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "237679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusSaliphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus saliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSaliphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "405559.protein.sequences.v11.5.fa",
		        "enrichment_path": "405559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405559.protein.info.v11.5.txt",
		        "node_list_path": "405559.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacteraceaeBacteriumGomA1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacteraceae bacterium GOM-A1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacteraceaeBacteriumGomA1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1696173.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1696173.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1696173.clusters.proteins.v11.5.txt",
		        "sequence_path": "1696173.protein.sequences.v11.5.fa",
		        "enrichment_path": "1696173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1696173.protein.info.v11.5.txt",
		        "node_list_path": "1696173.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1696173.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylocystisSpSc2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylocystis sp. SC2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocystisSpSc2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "187303.clusters.info.v11.5.txt",
		        "cluster_tree_path": "187303.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "187303.clusters.proteins.v11.5.txt",
		        "sequence_path": "187303.protein.sequences.v11.5.fa",
		        "enrichment_path": "187303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "187303.protein.info.v11.5.txt",
		        "node_list_path": "187303.cluster.nodes.v11.5.txt",
		        "edge_list_path": "187303.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudorhodoferaxSpLeaf267(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf267 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodoferaxSpLeaf267", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736316.protein.info.v11.5.txt",
		        "node_list_path": "1736316.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinomonasMediterranea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas mediterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasMediterranea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "717774.protein.sequences.v11.5.fa",
		        "enrichment_path": "717774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717774.protein.info.v11.5.txt",
		        "node_list_path": "717774.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrochaeteSpPcc7126Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microchaete sp. PCC7126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrochaeteSpPcc7126Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "643473.clusters.info.v11.5.txt",
		        "cluster_tree_path": "643473.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "643473.clusters.proteins.v11.5.txt",
		        "sequence_path": "643473.protein.sequences.v11.5.fa",
		        "enrichment_path": "643473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "643473.protein.info.v11.5.txt",
		        "node_list_path": "643473.cluster.nodes.v11.5.txt",
		        "edge_list_path": "643473.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolanumLycopersicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solanum lycopersicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolanumLycopersicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4081.clusters.proteins.v11.5.txt",
		        "sequence_path": "4081.protein.sequences.v11.5.fa",
		        "enrichment_path": "4081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4081.protein.info.v11.5.txt",
		        "node_list_path": "4081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusFasciansLmg3625Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus fascians LMG 3625 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusFasciansLmg3625Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1443905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1443905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1443905.clusters.proteins.v11.5.txt",
		        "sequence_path": "1443905.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443905.protein.info.v11.5.txt",
		        "node_list_path": "1443905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1443905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumAmericanum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium americanum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumAmericanum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408224.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408224.protein.info.v11.5.txt",
		        "node_list_path": "1408224.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrobacterRodentiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter rodentium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterRodentiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "637910.clusters.info.v11.5.txt",
		        "cluster_tree_path": "637910.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "637910.clusters.proteins.v11.5.txt",
		        "sequence_path": "637910.protein.sequences.v11.5.fa",
		        "enrichment_path": "637910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637910.protein.info.v11.5.txt",
		        "node_list_path": "637910.cluster.nodes.v11.5.txt",
		        "edge_list_path": "637910.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumGw2011Gwc23922Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWC2_39_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwc23922Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619013.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619013.protein.info.v11.5.txt",
		        "node_list_path": "1619013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarivirgaTractuosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marivirga tractuosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivirgaTractuosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "643867.protein.sequences.v11.5.fa",
		        "enrichment_path": "643867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "643867.protein.info.v11.5.txt",
		        "node_list_path": "643867.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpRoot710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpRoot710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736594.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736594.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736594.protein.info.v11.5.txt",
		        "node_list_path": "1736594.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParamesorhizobiumDeserti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paramesorhizobium deserti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParamesorhizobiumDeserti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1494590.protein.sequences.v11.5.fa",
		        "enrichment_path": "1494590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1494590.protein.info.v11.5.txt",
		        "node_list_path": "1494590.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpCn3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. CN3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpCn3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "298655.clusters.info.v11.5.txt",
		        "cluster_tree_path": "298655.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "298655.clusters.proteins.v11.5.txt",
		        "sequence_path": "298655.protein.sequences.v11.5.fa",
		        "enrichment_path": "298655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "298655.protein.info.v11.5.txt",
		        "node_list_path": "298655.cluster.nodes.v11.5.txt",
		        "edge_list_path": "298655.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumA52c2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium A52C2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumA52c2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855383.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855383.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855383.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855383.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855383.protein.info.v11.5.txt",
		        "node_list_path": "1855383.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855383.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColletotrichumTanaceti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum tanaceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumTanaceti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1306861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306861.protein.info.v11.5.txt",
		        "node_list_path": "1306861.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerolineaThermolimosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerolinea thermolimosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaThermolimosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "229919.protein.sequences.v11.5.fa",
		        "enrichment_path": "229919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229919.protein.info.v11.5.txt",
		        "node_list_path": "229919.protein.complete.v11.5.txt"
		    }
		]
    )()

def AltererythrobacterSpRoot672(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. Root672 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AltererythrobacterSpRoot672", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736584.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736584.protein.info.v11.5.txt",
		        "node_list_path": "1736584.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassotaleaAgarivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassotalea agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassotaleaAgarivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349064.protein.sequences.v11.5.fa",
		        "enrichment_path": "349064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349064.protein.info.v11.5.txt",
		        "node_list_path": "349064.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsphigho202Full3613Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_02_FULL_36_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho202Full3613Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797768.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797768.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797768.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797768.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797768.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797768.protein.info.v11.5.txt",
		        "node_list_path": "1797768.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797768.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpNc3005Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. NC3005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpNc3005Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280685.protein.info.v11.5.txt",
		        "node_list_path": "1280685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaribacterArcticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterArcticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "561365.clusters.info.v11.5.txt",
		        "cluster_tree_path": "561365.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "561365.clusters.proteins.v11.5.txt",
		        "sequence_path": "561365.protein.sequences.v11.5.fa",
		        "enrichment_path": "561365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561365.protein.info.v11.5.txt",
		        "node_list_path": "561365.cluster.nodes.v11.5.txt",
		        "edge_list_path": "561365.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NumidaMeleagrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Numida meleagris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NumidaMeleagrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8996.clusters.proteins.v11.5.txt",
		        "sequence_path": "8996.protein.sequences.v11.5.fa",
		        "enrichment_path": "8996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8996.protein.info.v11.5.txt",
		        "node_list_path": "8996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpPcc7336(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7336 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpPcc7336", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "195250.protein.sequences.v11.5.fa",
		        "enrichment_path": "195250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195250.protein.info.v11.5.txt",
		        "node_list_path": "195250.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusJorgensenbacteriaBacteriumGw2011Gwb1499Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GW2011_GWB1_49_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGw2011Gwb1499Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618664.protein.info.v11.5.txt",
		        "node_list_path": "1618664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VogesellaSpEb(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vogesella sp. EB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VogesellaSpEb", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1526735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1526735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1526735.protein.info.v11.5.txt",
		        "node_list_path": "1526735.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnteractinococcusHelveticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enteractinococcus helveticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnteractinococcusHelveticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1837282.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1837282.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1837282.clusters.proteins.v11.5.txt",
		        "sequence_path": "1837282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1837282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1837282.protein.info.v11.5.txt",
		        "node_list_path": "1837282.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1837282.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfitobacteriumHafnienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium hafniense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitobacteriumHafnienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "138119.clusters.info.v11.5.txt",
		        "cluster_tree_path": "138119.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "138119.clusters.proteins.v11.5.txt",
		        "sequence_path": "138119.protein.sequences.v11.5.fa",
		        "enrichment_path": "138119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "138119.protein.info.v11.5.txt",
		        "node_list_path": "138119.cluster.nodes.v11.5.txt",
		        "edge_list_path": "138119.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioNitratireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioNitratireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1255043.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1255043.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1255043.clusters.proteins.v11.5.txt",
		        "sequence_path": "1255043.protein.sequences.v11.5.fa",
		        "enrichment_path": "1255043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1255043.protein.info.v11.5.txt",
		        "node_list_path": "1255043.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1255043.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GordoniaLacunae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia lacunae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaLacunae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "417102.protein.sequences.v11.5.fa",
		        "enrichment_path": "417102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "417102.protein.info.v11.5.txt",
		        "node_list_path": "417102.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusChinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus chinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusChinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525640.protein.sequences.v11.5.fa",
		        "enrichment_path": "525640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525640.protein.info.v11.5.txt",
		        "node_list_path": "525640.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChromobacteriumSphagniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chromobacterium sphagni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromobacteriumSphagniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1903179.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1903179.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1903179.clusters.proteins.v11.5.txt",
		        "sequence_path": "1903179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1903179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1903179.protein.info.v11.5.txt",
		        "node_list_path": "1903179.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1903179.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaemophilusSpFf7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus sp. FF7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusSpFf7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1461579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461579.protein.info.v11.5.txt",
		        "node_list_path": "1461579.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaSpNb41yCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sp. NB4-1Y Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSpNb41yCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1241906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1241906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1241906.clusters.proteins.v11.5.txt",
		        "sequence_path": "1241906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1241906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1241906.protein.info.v11.5.txt",
		        "node_list_path": "1241906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1241906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MandrillusLeucophaeus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mandrillus leucophaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MandrillusLeucophaeus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9568.protein.sequences.v11.5.fa",
		        "enrichment_path": "9568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9568.protein.info.v11.5.txt",
		        "node_list_path": "9568.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasProtegensPf5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas protegens Pf5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasProtegensPf5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "220664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "220664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "220664.clusters.proteins.v11.5.txt",
		        "sequence_path": "220664.protein.sequences.v11.5.fa",
		        "enrichment_path": "220664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220664.protein.info.v11.5.txt",
		        "node_list_path": "220664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "220664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucispirillumSchaedleriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucispirillum schaedleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucispirillumSchaedleriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379858.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379858.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379858.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379858.protein.info.v11.5.txt",
		        "node_list_path": "1379858.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379858.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumQingshengii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium qingshengii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumQingshengii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1165689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1165689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1165689.protein.info.v11.5.txt",
		        "node_list_path": "1165689.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp2621(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 26_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp2621", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896977.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896977.protein.info.v11.5.txt",
		        "node_list_path": "1896977.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1735685.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1735685.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1735685.clusters.proteins.v11.5.txt",
		        "sequence_path": "1735685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735685.protein.info.v11.5.txt",
		        "node_list_path": "1735685.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1735685.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRbg164113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_41_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802484.protein.info.v11.5.txt",
		        "node_list_path": "1802484.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSpE463(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. E463 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSpE463", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1234593.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234593.protein.info.v11.5.txt",
		        "node_list_path": "1234593.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrenneriaGoodwiniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brenneria goodwinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrenneriaGoodwiniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1109412.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1109412.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1109412.clusters.proteins.v11.5.txt",
		        "sequence_path": "1109412.protein.sequences.v11.5.fa",
		        "enrichment_path": "1109412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1109412.protein.info.v11.5.txt",
		        "node_list_path": "1109412.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1109412.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaPhymatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phymatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaPhymatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391038.protein.sequences.v11.5.fa",
		        "enrichment_path": "391038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391038.protein.info.v11.5.txt",
		        "node_list_path": "391038.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaMelophagiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella melophagi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaMelophagiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094557.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094557.protein.info.v11.5.txt",
		        "node_list_path": "1094557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FaecalicoccusPleomorphusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalicoccus pleomorphus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalicoccusPleomorphusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123313.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123313.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123313.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123313.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123313.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123313.protein.info.v11.5.txt",
		        "node_list_path": "1123313.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123313.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpUrha0020(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. URHA0020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpUrha0020", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380392.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380392.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380392.protein.info.v11.5.txt",
		        "node_list_path": "1380392.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumMcbrellneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium mcbrellneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumMcbrellneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585530.protein.sequences.v11.5.fa",
		        "enrichment_path": "585530.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585530.protein.info.v11.5.txt",
		        "node_list_path": "585530.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpAtcc29733(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ATCC29733 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpAtcc29733", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1507.protein.sequences.v11.5.fa",
		        "enrichment_path": "1507.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1507.protein.info.v11.5.txt",
		        "node_list_path": "1507.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteococcusJaponicusLspLj1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Luteococcus japonicus LSP_Lj1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteococcusJaponicusLspLj1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1255658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1255658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1255658.protein.info.v11.5.txt",
		        "node_list_path": "1255658.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpRoot411Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. Root411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpRoot411Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736530.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736530.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736530.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736530.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736530.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736530.protein.info.v11.5.txt",
		        "node_list_path": "1736530.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736530.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumAb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium AB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumAb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1898108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1898108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1898108.clusters.proteins.v11.5.txt",
		        "sequence_path": "1898108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898108.protein.info.v11.5.txt",
		        "node_list_path": "1898108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1898108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAviumAvium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Mycobacterium avium avium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAviumAvium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "44454.protein.sequences.v11.0.fa",
		        "enrichment_path": "44454.protein.enrichment.terms.v11.0.txt",
		        "info_path": "44454.protein.info.v11.0.txt",
		        "node_list_path": "44454.protein.complete.v11.0.txt"
		    }
		]
    )()

def StreptomycesAvicenniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces avicenniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAvicenniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "500153.clusters.info.v11.5.txt",
		        "cluster_tree_path": "500153.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "500153.clusters.proteins.v11.5.txt",
		        "sequence_path": "500153.protein.sequences.v11.5.fa",
		        "enrichment_path": "500153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "500153.protein.info.v11.5.txt",
		        "node_list_path": "500153.cluster.nodes.v11.5.txt",
		        "edge_list_path": "500153.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSordidicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sordidicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSordidicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "196367.protein.sequences.v11.5.fa",
		        "enrichment_path": "196367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "196367.protein.info.v11.5.txt",
		        "node_list_path": "196367.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloferacalesArchaeonDl31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Haloferacales archaeon DL31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "HaloferacalesArchaeonDl31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "756883.clusters.info.v11.0.txt",
		        "cluster_tree_path": "756883.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "756883.clusters.proteins.v11.0.txt",
		        "sequence_path": "756883.protein.sequences.v11.0.fa",
		        "enrichment_path": "756883.protein.enrichment.terms.v11.0.txt",
		        "info_path": "756883.protein.info.v11.0.txt",
		        "node_list_path": "756883.cluster.nodes.v11.0.txt",
		        "edge_list_path": "756883.protein.cluster.v11.0.txt"
		    }
		]
    )()

def SalmonellaEntericaSubspEntericaSerovarTyphimuriumStrLt2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. enterica serovar Typhimurium str. LT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaSubspEntericaSerovarTyphimuriumStrLt2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "99287.protein.sequences.v11.5.fa",
		        "enrichment_path": "99287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "99287.protein.info.v11.5.txt",
		        "node_list_path": "99287.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusHelveticusDpc4571(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus DPC4571 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHelveticusDpc4571", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "405566.protein.sequences.v11.5.fa",
		        "enrichment_path": "405566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "405566.protein.info.v11.5.txt",
		        "node_list_path": "405566.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactococcusRaffinolactis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactococcusRaffinolactis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1215915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1215915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1215915.protein.info.v11.5.txt",
		        "node_list_path": "1215915.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifoxyd12Full6137Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFOXYD12_FULL_61_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifoxyd12Full6137Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798308.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798308.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798308.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798308.protein.info.v11.5.txt",
		        "node_list_path": "1798308.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798308.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusAlbus7Dsm20455Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus albus 7  DSM 20455 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusAlbus7Dsm20455Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "697329.clusters.info.v11.5.txt",
		        "cluster_tree_path": "697329.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "697329.clusters.proteins.v11.5.txt",
		        "sequence_path": "697329.protein.sequences.v11.5.fa",
		        "enrichment_path": "697329.protein.enrichment.terms.v11.5.txt",
		        "info_path": "697329.protein.info.v11.5.txt",
		        "node_list_path": "697329.cluster.nodes.v11.5.txt",
		        "edge_list_path": "697329.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchistocephalusSolidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schistocephalus solidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistocephalusSolidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "70667.protein.sequences.v11.5.fa",
		        "enrichment_path": "70667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "70667.protein.info.v11.5.txt",
		        "node_list_path": "70667.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaMarcescensDb11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia marcescens Db11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaMarcescensDb11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "273526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "273526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "273526.clusters.proteins.v11.5.txt",
		        "sequence_path": "273526.protein.sequences.v11.5.fa",
		        "enrichment_path": "273526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273526.protein.info.v11.5.txt",
		        "node_list_path": "273526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "273526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusCanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusCanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "482234.protein.sequences.v11.5.fa",
		        "enrichment_path": "482234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "482234.protein.info.v11.5.txt",
		        "node_list_path": "482234.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrodictiumOccultum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pyrodictium occultum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrodictiumOccultum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2309.protein.sequences.v11.5.fa",
		        "enrichment_path": "2309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2309.protein.info.v11.5.txt",
		        "node_list_path": "2309.protein.complete.v11.5.txt"
		    }
		]
    )()

def TepidanaerobacterSpEbm38(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tepidanaerobacter sp. EBM-38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidanaerobacterSpEbm38", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1918496.protein.sequences.v11.5.fa",
		        "enrichment_path": "1918496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1918496.protein.info.v11.5.txt",
		        "node_list_path": "1918496.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasSpBiir7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas sp. BIIR7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasSpBiir7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1904462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1904462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1904462.clusters.proteins.v11.5.txt",
		        "sequence_path": "1904462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1904462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1904462.protein.info.v11.5.txt",
		        "node_list_path": "1904462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1904462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSpF0436(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. F0436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSpF0436", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "879308.protein.sequences.v11.5.fa",
		        "enrichment_path": "879308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879308.protein.info.v11.5.txt",
		        "node_list_path": "879308.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShigellaFlexneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shigella flexneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShigellaFlexneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "198214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "198214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "198214.clusters.proteins.v11.5.txt",
		        "sequence_path": "198214.protein.sequences.v11.5.fa",
		        "enrichment_path": "198214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198214.protein.info.v11.5.txt",
		        "node_list_path": "198214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "198214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AchromobacterInsuavisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter insuavis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchromobacterInsuavisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1003200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1003200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1003200.clusters.proteins.v11.5.txt",
		        "sequence_path": "1003200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1003200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1003200.protein.info.v11.5.txt",
		        "node_list_path": "1003200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1003200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanobiumGracile(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanobium gracile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobiumGracile", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "292564.protein.sequences.v11.5.fa",
		        "enrichment_path": "292564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "292564.protein.info.v11.5.txt",
		        "node_list_path": "292564.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpRoot55(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpRoot55", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736554.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736554.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736554.protein.info.v11.5.txt",
		        "node_list_path": "1736554.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcaromycesIngoldii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acaromyces ingoldii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcaromycesIngoldii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "215250.protein.sequences.v11.5.fa",
		        "enrichment_path": "215250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215250.protein.info.v11.5.txt",
		        "node_list_path": "215250.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeinococcusMaricopensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus maricopensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusMaricopensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "709986.clusters.info.v11.5.txt",
		        "cluster_tree_path": "709986.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "709986.clusters.proteins.v11.5.txt",
		        "sequence_path": "709986.protein.sequences.v11.5.fa",
		        "enrichment_path": "709986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "709986.protein.info.v11.5.txt",
		        "node_list_path": "709986.cluster.nodes.v11.5.txt",
		        "edge_list_path": "709986.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsphigho201Full388(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_01_FULL_38_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho201Full388", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797760.protein.info.v11.5.txt",
		        "node_list_path": "1797760.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquamicrobiumDefluvii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquamicrobium defluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquamicrobiumDefluvii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69279.protein.sequences.v11.5.fa",
		        "enrichment_path": "69279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69279.protein.info.v11.5.txt",
		        "node_list_path": "69279.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinilabiliaSalmonicolorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinilabilia salmonicolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinilabiliaSalmonicolorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1168289.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1168289.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1168289.clusters.proteins.v11.5.txt",
		        "sequence_path": "1168289.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168289.protein.info.v11.5.txt",
		        "node_list_path": "1168289.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1168289.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesXanthophaeus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces xanthophaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesXanthophaeus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67385.protein.sequences.v11.5.fa",
		        "enrichment_path": "67385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67385.protein.info.v11.5.txt",
		        "node_list_path": "67385.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensHk44(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens HK44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensHk44", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1042209.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042209.protein.info.v11.5.txt",
		        "node_list_path": "1042209.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtopobiumDeltaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium deltae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumDeltaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1393034.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1393034.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1393034.clusters.proteins.v11.5.txt",
		        "sequence_path": "1393034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1393034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1393034.protein.info.v11.5.txt",
		        "node_list_path": "1393034.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1393034.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnoxybacillusPushchinoensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus pushchinoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnoxybacillusPushchinoensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "150248.clusters.info.v11.5.txt",
		        "cluster_tree_path": "150248.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "150248.clusters.proteins.v11.5.txt",
		        "sequence_path": "150248.protein.sequences.v11.5.fa",
		        "enrichment_path": "150248.protein.enrichment.terms.v11.5.txt",
		        "info_path": "150248.protein.info.v11.5.txt",
		        "node_list_path": "150248.cluster.nodes.v11.5.txt",
		        "edge_list_path": "150248.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsphigho202Full6720Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPHIGHO2_02_FULL_67_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202Full6720Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801860.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801860.protein.info.v11.5.txt",
		        "node_list_path": "1801860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OoceraeaBiroiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ooceraea biroi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OoceraeaBiroiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2015173.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2015173.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2015173.clusters.proteins.v11.5.txt",
		        "sequence_path": "2015173.protein.sequences.v11.5.fa",
		        "enrichment_path": "2015173.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2015173.protein.info.v11.5.txt",
		        "node_list_path": "2015173.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2015173.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpLeaf288(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf288 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpLeaf288", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736323.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736323.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736323.protein.info.v11.5.txt",
		        "node_list_path": "1736323.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaAurisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma auris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaAurisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1188233.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1188233.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1188233.clusters.proteins.v11.5.txt",
		        "sequence_path": "1188233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188233.protein.info.v11.5.txt",
		        "node_list_path": "1188233.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1188233.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrassicaOleraceaVarOleraceaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brassica oleracea var. oleracea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrassicaOleraceaVarOleraceaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "109376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "109376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "109376.clusters.proteins.v11.5.txt",
		        "sequence_path": "109376.protein.sequences.v11.5.fa",
		        "enrichment_path": "109376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109376.protein.info.v11.5.txt",
		        "node_list_path": "109376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "109376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StrigopsHabroptila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Strigops habroptila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrigopsHabroptila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2489341.protein.sequences.v11.5.fa",
		        "enrichment_path": "2489341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2489341.protein.info.v11.5.txt",
		        "node_list_path": "2489341.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf238335Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_38_335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf238335Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797344.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797344.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797344.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797344.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797344.protein.info.v11.5.txt",
		        "node_list_path": "1797344.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797344.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysobacterDokdonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterDokdonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1300345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300345.protein.info.v11.5.txt",
		        "node_list_path": "1300345.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiisalibacterPaucivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiisalibacter paucivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiisalibacterPaucivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121289.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121289.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121289.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121289.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121289.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121289.protein.info.v11.5.txt",
		        "node_list_path": "1121289.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121289.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag302(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:302 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag302", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262793.protein.info.v11.5.txt",
		        "node_list_path": "1262793.protein.complete.v11.5.txt"
		    }
		]
    )()

def TheileriaOrientalisStrainShintokuCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Theileria orientalis strain Shintoku Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheileriaOrientalisStrainShintokuCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "869250.clusters.info.v11.5.txt",
		        "cluster_tree_path": "869250.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "869250.clusters.proteins.v11.5.txt",
		        "sequence_path": "869250.protein.sequences.v11.5.fa",
		        "enrichment_path": "869250.protein.enrichment.terms.v11.5.txt",
		        "info_path": "869250.protein.info.v11.5.txt",
		        "node_list_path": "869250.cluster.nodes.v11.5.txt",
		        "edge_list_path": "869250.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacillusMinorNm305Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus minor NM305 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusMinorNm305Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "637911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "637911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "637911.clusters.proteins.v11.5.txt",
		        "sequence_path": "637911.protein.sequences.v11.5.fa",
		        "enrichment_path": "637911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637911.protein.info.v11.5.txt",
		        "node_list_path": "637911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "637911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumBalustinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium balustinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumBalustinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246.clusters.proteins.v11.5.txt",
		        "sequence_path": "246.protein.sequences.v11.5.fa",
		        "enrichment_path": "246.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246.protein.info.v11.5.txt",
		        "node_list_path": "246.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf198(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf198 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf198", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736299.protein.info.v11.5.txt",
		        "node_list_path": "1736299.protein.complete.v11.5.txt"
		    }
		]
    )()

def MusMusculus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mus musculus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusMusculus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10090.protein.sequences.v11.5.fa",
		        "enrichment_path": "10090.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10090.protein.info.v11.5.txt",
		        "node_list_path": "10090.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimimaricolaPyoseonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limimaricola pyoseonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimimaricolaPyoseonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "521013.protein.sequences.v11.5.fa",
		        "enrichment_path": "521013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521013.protein.info.v11.5.txt",
		        "node_list_path": "521013.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwb13910Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13910Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618572.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618572.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618572.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618572.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618572.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618572.protein.info.v11.5.txt",
		        "node_list_path": "1618572.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618572.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpJcm10914(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 10914 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpJcm10914", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236974.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236974.protein.info.v11.5.txt",
		        "node_list_path": "1236974.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaElaeisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia elaeis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaElaeisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1770058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1770058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1770058.clusters.proteins.v11.5.txt",
		        "sequence_path": "1770058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1770058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1770058.protein.info.v11.5.txt",
		        "node_list_path": "1770058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1770058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrococcusRivularisNies593Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrococcus rivularis NIES-593 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrococcusRivularisNies593Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1921803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1921803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1921803.clusters.proteins.v11.5.txt",
		        "sequence_path": "1921803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921803.protein.info.v11.5.txt",
		        "node_list_path": "1921803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1921803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirosomaSpitsbergenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma spitsbergense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaSpitsbergenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123278.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123278.protein.info.v11.5.txt",
		        "node_list_path": "1123278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TetradesmusObliquusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetradesmus obliquus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetradesmusObliquusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3088.clusters.proteins.v11.5.txt",
		        "sequence_path": "3088.protein.sequences.v11.5.fa",
		        "enrichment_path": "3088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3088.protein.info.v11.5.txt",
		        "node_list_path": "3088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumMd2004(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MD2004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumMd2004", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410625.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410625.protein.info.v11.5.txt",
		        "node_list_path": "1410625.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSubglaciescolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas subglaciescola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSubglaciescolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29571.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29571.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29571.clusters.proteins.v11.5.txt",
		        "sequence_path": "29571.protein.sequences.v11.5.fa",
		        "enrichment_path": "29571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29571.protein.info.v11.5.txt",
		        "node_list_path": "29571.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29571.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRbg16378(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_37_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg16378", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798371.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798371.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798371.protein.info.v11.5.txt",
		        "node_list_path": "1798371.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumCarboxidivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium carboxidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCarboxidivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "536227.clusters.info.v11.5.txt",
		        "cluster_tree_path": "536227.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "536227.clusters.proteins.v11.5.txt",
		        "sequence_path": "536227.protein.sequences.v11.5.fa",
		        "enrichment_path": "536227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "536227.protein.info.v11.5.txt",
		        "node_list_path": "536227.cluster.nodes.v11.5.txt",
		        "edge_list_path": "536227.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusThermophilusLmd9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus LMD9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusThermophilusLmd9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "322159.protein.sequences.v11.5.fa",
		        "enrichment_path": "322159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "322159.protein.info.v11.5.txt",
		        "node_list_path": "322159.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzotobacterChroococcumNcimb8003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azotobacter chroococcum NCIMB 8003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzotobacterChroococcumNcimb8003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1328314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1328314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1328314.protein.info.v11.5.txt",
		        "node_list_path": "1328314.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5921Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_59_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5921Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798500.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798500.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798500.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798500.protein.info.v11.5.txt",
		        "node_list_path": "1798500.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798500.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSticklandiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sticklandii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSticklandiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1511.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1511.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1511.clusters.proteins.v11.5.txt",
		        "sequence_path": "1511.protein.sequences.v11.5.fa",
		        "enrichment_path": "1511.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1511.protein.info.v11.5.txt",
		        "node_list_path": "1511.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1511.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpLq44(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. LQ44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpLq44", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1749259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1749259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1749259.protein.info.v11.5.txt",
		        "node_list_path": "1749259.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumUltunense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium ultunense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumUltunense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "865861.protein.sequences.v11.5.fa",
		        "enrichment_path": "865861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "865861.protein.info.v11.5.txt",
		        "node_list_path": "865861.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidaminococcusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidaminococcus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidaminococcusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852375.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852375.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852375.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852375.protein.info.v11.5.txt",
		        "node_list_path": "1852375.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852375.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_50_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798662.protein.info.v11.5.txt",
		        "node_list_path": "1798662.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifcsplowo212Full5310(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_12_FULL_53_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo212Full5310", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801930.protein.info.v11.5.txt",
		        "node_list_path": "1801930.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc3903Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 3903 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc3903Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977883.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977883.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977883.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977883.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977883.protein.info.v11.5.txt",
		        "node_list_path": "1977883.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977883.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolimonasSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solimonas soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolimonasSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123261.protein.info.v11.5.txt",
		        "node_list_path": "1123261.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThorselliaAnophelisDsm18579(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thorsellia anophelis DSM 18579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThorselliaAnophelisDsm18579", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123402.protein.info.v11.5.txt",
		        "node_list_path": "1123402.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSaccharolyticaF0055(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella saccharolytica F0055 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSaccharolyticaF0055", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1127699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127699.protein.info.v11.5.txt",
		        "node_list_path": "1127699.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacterAestuarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterAestuarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "453582.protein.sequences.v11.5.fa",
		        "enrichment_path": "453582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "453582.protein.info.v11.5.txt",
		        "node_list_path": "453582.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusOralisSk1074(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis SK1074 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOralisSk1074", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095738.protein.info.v11.5.txt",
		        "node_list_path": "1095738.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMethanolicusPb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus methanolicus PB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMethanolicusPb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "997296.protein.sequences.v11.5.fa",
		        "enrichment_path": "997296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997296.protein.info.v11.5.txt",
		        "node_list_path": "997296.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophilalesBacteriumMbrsf5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophilales bacterium MBRSF5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophilalesBacteriumMbrsf5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1623448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1623448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1623448.clusters.proteins.v11.5.txt",
		        "sequence_path": "1623448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1623448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1623448.protein.info.v11.5.txt",
		        "node_list_path": "1623448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1623448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusUreilyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus ureilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusUreilyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131292.protein.info.v11.5.txt",
		        "node_list_path": "1131292.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaFleischmanniiSubspFleischmanniiLu20061(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria fleischmannii subsp. fleischmannii LU2006-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaFleischmanniiSubspFleischmanniiLu20061", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1214117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1214117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1214117.protein.info.v11.5.txt",
		        "node_list_path": "1214117.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermomicrobiumRoseum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermomicrobium roseum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermomicrobiumRoseum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "309801.protein.sequences.v11.5.fa",
		        "enrichment_path": "309801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "309801.protein.info.v11.5.txt",
		        "node_list_path": "309801.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusSp7f3Div0205Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sp. 7F3_DIV0205 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSp7f3Div0205Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834189.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834189.protein.info.v11.5.txt",
		        "node_list_path": "1834189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarichromatiumPurpuratumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marichromatium purpuratum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarichromatiumPurpuratumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765910.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765910.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765910.clusters.proteins.v11.5.txt",
		        "sequence_path": "765910.protein.sequences.v11.5.fa",
		        "enrichment_path": "765910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765910.protein.info.v11.5.txt",
		        "node_list_path": "765910.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765910.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FervidobacteriumThailandense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium thailandense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FervidobacteriumThailandense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1008305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1008305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1008305.protein.info.v11.5.txt",
		        "node_list_path": "1008305.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusOvisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus ovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOvisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123312.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123312.protein.info.v11.5.txt",
		        "node_list_path": "1123312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpRoot411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. Root411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpRoot411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736530.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736530.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736530.protein.info.v11.5.txt",
		        "node_list_path": "1736530.protein.complete.v11.5.txt"
		    }
		]
    )()

def OdobenusRosmarusDivergensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Odobenus rosmarus divergens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OdobenusRosmarusDivergensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9708.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9708.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9708.clusters.proteins.v11.5.txt",
		        "sequence_path": "9708.protein.sequences.v11.5.fa",
		        "enrichment_path": "9708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9708.protein.info.v11.5.txt",
		        "node_list_path": "9708.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9708.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumBifermentansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium bifermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBifermentansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1391646.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1391646.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1391646.clusters.proteins.v11.5.txt",
		        "sequence_path": "1391646.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391646.protein.info.v11.5.txt",
		        "node_list_path": "1391646.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1391646.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MagnetofabaAustralisIt1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetofaba australis IT-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetofabaAustralisIt1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434232.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434232.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434232.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434232.protein.info.v11.5.txt",
		        "node_list_path": "1434232.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434232.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsbolusVerrucosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Asbolus verrucosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsbolusVerrucosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1661398.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1661398.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1661398.clusters.proteins.v11.5.txt",
		        "sequence_path": "1661398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1661398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1661398.protein.info.v11.5.txt",
		        "node_list_path": "1661398.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1661398.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanococcusMaritimus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planococcus maritimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanococcusMaritimus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "192421.protein.sequences.v11.5.fa",
		        "enrichment_path": "192421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "192421.protein.info.v11.5.txt",
		        "node_list_path": "192421.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaPinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga pinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaPinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "485918.protein.sequences.v11.5.fa",
		        "enrichment_path": "485918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "485918.protein.info.v11.5.txt",
		        "node_list_path": "485918.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpCc9605Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpCc9605Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "110662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "110662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "110662.clusters.proteins.v11.5.txt",
		        "sequence_path": "110662.protein.sequences.v11.5.fa",
		        "enrichment_path": "110662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "110662.protein.info.v11.5.txt",
		        "node_list_path": "110662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "110662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DiaportheHelianthi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Diaporthe helianthi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiaportheHelianthi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "158607.protein.sequences.v11.5.fa",
		        "enrichment_path": "158607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158607.protein.info.v11.5.txt",
		        "node_list_path": "158607.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusPanacihumi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus panacihumi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusPanacihumi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408254.protein.info.v11.5.txt",
		        "node_list_path": "1408254.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusShenzhenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus shenzhenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusShenzhenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231336.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231336.protein.info.v11.5.txt",
		        "node_list_path": "1231336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusProfundus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus profundus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusProfundus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "572546.protein.sequences.v11.5.fa",
		        "enrichment_path": "572546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572546.protein.info.v11.5.txt",
		        "node_list_path": "572546.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenoxybacterAcetivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenoxybacter acetivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenoxybacterAcetivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123296.protein.info.v11.5.txt",
		        "node_list_path": "1123296.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa25110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_51_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa25110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618855.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618855.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618855.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618855.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618855.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618855.protein.info.v11.5.txt",
		        "node_list_path": "1618855.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618855.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RodentibacterMyodisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter myodis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterMyodisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907939.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907939.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907939.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907939.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907939.protein.info.v11.5.txt",
		        "node_list_path": "1907939.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907939.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MobiluncusCurtisiiAtcc35241(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii ATCC35241 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobiluncusCurtisiiAtcc35241", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585198.protein.sequences.v11.5.fa",
		        "enrichment_path": "585198.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585198.protein.info.v11.5.txt",
		        "node_list_path": "585198.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag557(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:557 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag557", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262819.protein.info.v11.5.txt",
		        "node_list_path": "1262819.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerminiimonasArsenitoxidans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herminiimonas arsenitoxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerminiimonasArsenitoxidans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1809410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1809410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1809410.protein.info.v11.5.txt",
		        "node_list_path": "1809410.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaFlavescensNrl30031h210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria flavescens NRL30031H210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaFlavescensNrl30031h210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546264.protein.sequences.v11.5.fa",
		        "enrichment_path": "546264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546264.protein.info.v11.5.txt",
		        "node_list_path": "546264.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpMrs7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. MRS7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpMrs7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1268622.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1268622.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1268622.clusters.proteins.v11.5.txt",
		        "sequence_path": "1268622.protein.sequences.v11.5.fa",
		        "enrichment_path": "1268622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1268622.protein.info.v11.5.txt",
		        "node_list_path": "1268622.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1268622.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosomonasEuropaeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosomonas europaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosomonasEuropaeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "228410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "228410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "228410.clusters.proteins.v11.5.txt",
		        "sequence_path": "228410.protein.sequences.v11.5.fa",
		        "enrichment_path": "228410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228410.protein.info.v11.5.txt",
		        "node_list_path": "228410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "228410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermotogaNeapolitanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga neapolitana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaNeapolitanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "309803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "309803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "309803.clusters.proteins.v11.5.txt",
		        "sequence_path": "309803.protein.sequences.v11.5.fa",
		        "enrichment_path": "309803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "309803.protein.info.v11.5.txt",
		        "node_list_path": "309803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "309803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumGraminearumPh1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium graminearum PH-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumGraminearumPh1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "229533.protein.sequences.v11.5.fa",
		        "enrichment_path": "229533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229533.protein.info.v11.5.txt",
		        "node_list_path": "229533.protein.complete.v11.5.txt"
		    }
		]
    )()

def FolsomiaCandida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Folsomia candida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FolsomiaCandida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "158441.protein.sequences.v11.5.fa",
		        "enrichment_path": "158441.protein.enrichment.terms.v11.5.txt",
		        "info_path": "158441.protein.info.v11.5.txt",
		        "node_list_path": "158441.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichococcusIlyisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichococcus ilyis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichococcusIlyisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "640938.clusters.info.v11.5.txt",
		        "cluster_tree_path": "640938.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "640938.clusters.proteins.v11.5.txt",
		        "sequence_path": "640938.protein.sequences.v11.5.fa",
		        "enrichment_path": "640938.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640938.protein.info.v11.5.txt",
		        "node_list_path": "640938.cluster.nodes.v11.5.txt",
		        "edge_list_path": "640938.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumTaeniosporum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium taeniosporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTaeniosporum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "394958.protein.sequences.v11.5.fa",
		        "enrichment_path": "394958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394958.protein.info.v11.5.txt",
		        "node_list_path": "394958.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSpCg232Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. CG23_2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSpCg232Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1706231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1706231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1706231.clusters.proteins.v11.5.txt",
		        "sequence_path": "1706231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1706231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1706231.protein.info.v11.5.txt",
		        "node_list_path": "1706231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1706231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyxococcusSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyxococcusSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1297742.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1297742.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1297742.clusters.proteins.v11.5.txt",
		        "sequence_path": "1297742.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297742.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297742.protein.info.v11.5.txt",
		        "node_list_path": "1297742.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1297742.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumChlorophenolicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium chlorophenolicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumChlorophenolicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46429.protein.sequences.v11.5.fa",
		        "enrichment_path": "46429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46429.protein.info.v11.5.txt",
		        "node_list_path": "46429.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumBotulinumBkt015925Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum BKT015925 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBotulinumBkt015925Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "929506.clusters.info.v11.5.txt",
		        "cluster_tree_path": "929506.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "929506.clusters.proteins.v11.5.txt",
		        "sequence_path": "929506.protein.sequences.v11.5.fa",
		        "enrichment_path": "929506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "929506.protein.info.v11.5.txt",
		        "node_list_path": "929506.cluster.nodes.v11.5.txt",
		        "edge_list_path": "929506.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AliivibrioSp1s175(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aliivibrio sp. 1S175 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AliivibrioSp1s175", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1840087.protein.sequences.v11.5.fa",
		        "enrichment_path": "1840087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1840087.protein.info.v11.5.txt",
		        "node_list_path": "1840087.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusAcidianusCopahuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acidianus copahuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAcidianusCopahuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1160895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1160895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1160895.clusters.proteins.v11.5.txt",
		        "sequence_path": "1160895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1160895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1160895.protein.info.v11.5.txt",
		        "node_list_path": "1160895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1160895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporosarcinaSpD27Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina sp. D27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaSpD27Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1382305.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1382305.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1382305.clusters.proteins.v11.5.txt",
		        "sequence_path": "1382305.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382305.protein.info.v11.5.txt",
		        "node_list_path": "1382305.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1382305.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusClavatusNrrl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus clavatus NRRL 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusClavatusNrrl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "344612.protein.sequences.v11.5.fa",
		        "enrichment_path": "344612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "344612.protein.info.v11.5.txt",
		        "node_list_path": "344612.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusAlkaliphilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusAlkaliphilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "279824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "279824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "279824.clusters.proteins.v11.5.txt",
		        "sequence_path": "279824.protein.sequences.v11.5.fa",
		        "enrichment_path": "279824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279824.protein.info.v11.5.txt",
		        "node_list_path": "279824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "279824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfonatronumThiodismutans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronum thiodismutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronumThiodismutans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "159290.protein.sequences.v11.5.fa",
		        "enrichment_path": "159290.protein.enrichment.terms.v11.5.txt",
		        "info_path": "159290.protein.info.v11.5.txt",
		        "node_list_path": "159290.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacterium4415(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 44-15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacterium4415", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895837.protein.info.v11.5.txt",
		        "node_list_path": "1895837.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillospiraceaeBacteriumZagget6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oscillospiraceae bacterium Zagget6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillospiraceaeBacteriumZagget6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1930019.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930019.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930019.protein.info.v11.5.txt",
		        "node_list_path": "1930019.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrusSinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrus sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrusSinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2711.protein.sequences.v11.5.fa",
		        "enrichment_path": "2711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2711.protein.info.v11.5.txt",
		        "node_list_path": "2711.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaProteobacteriumL13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return beta proteobacterium L13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaProteobacteriumL13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229489.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229489.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229489.protein.info.v11.5.txt",
		        "node_list_path": "1229489.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121364.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121364.protein.info.v11.5.txt",
		        "node_list_path": "1121364.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpYr221Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR221 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpYr221Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500293.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500293.protein.info.v11.5.txt",
		        "node_list_path": "1500293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GallibacteriumAnatisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallibacterium anatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallibacteriumAnatisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005058.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005058.protein.info.v11.5.txt",
		        "node_list_path": "1005058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpHl48(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. HL48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpHl48", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1479235.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479235.protein.info.v11.5.txt",
		        "node_list_path": "1479235.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMastitidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium mastitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMastitidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121365.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121365.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121365.protein.info.v11.5.txt",
		        "node_list_path": "1121365.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaMatsumotoenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora matsumotoense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaMatsumotoenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "121616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "121616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "121616.clusters.proteins.v11.5.txt",
		        "sequence_path": "121616.protein.sequences.v11.5.fa",
		        "enrichment_path": "121616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121616.protein.info.v11.5.txt",
		        "node_list_path": "121616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "121616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysinibacillusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211035.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211035.protein.info.v11.5.txt",
		        "node_list_path": "1211035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumLeiognathi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumLeiognathi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553611.protein.sequences.v11.5.fa",
		        "enrichment_path": "553611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553611.protein.info.v11.5.txt",
		        "node_list_path": "553611.protein.complete.v11.5.txt"
		    }
		]
    )()

def RugosibacterAromaticivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rugosibacter aromaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RugosibacterAromaticivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1565605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1565605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1565605.clusters.proteins.v11.5.txt",
		        "sequence_path": "1565605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1565605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1565605.protein.info.v11.5.txt",
		        "node_list_path": "1565605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1565605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag646Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:646 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag646Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262995.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262995.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262995.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262995.protein.info.v11.5.txt",
		        "node_list_path": "1262995.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262995.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ScytalidiumLignicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scytalidium lignicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScytalidiumLignicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5539.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5539.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5539.clusters.proteins.v11.5.txt",
		        "sequence_path": "5539.protein.sequences.v11.5.fa",
		        "enrichment_path": "5539.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5539.protein.info.v11.5.txt",
		        "node_list_path": "5539.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5539.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLm7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. LM7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLm7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1938607.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938607.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938607.protein.info.v11.5.txt",
		        "node_list_path": "1938607.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusAlkalitellurisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus alkalitelluris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusAlkalitellurisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "304268.clusters.info.v11.5.txt",
		        "cluster_tree_path": "304268.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "304268.clusters.proteins.v11.5.txt",
		        "sequence_path": "304268.protein.sequences.v11.5.fa",
		        "enrichment_path": "304268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "304268.protein.info.v11.5.txt",
		        "node_list_path": "304268.cluster.nodes.v11.5.txt",
		        "edge_list_path": "304268.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzoarcusSpBh72(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azoarcus sp. BH72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzoarcusSpBh72", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "62928.protein.sequences.v11.5.fa",
		        "enrichment_path": "62928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "62928.protein.info.v11.5.txt",
		        "node_list_path": "62928.protein.complete.v11.5.txt"
		    }
		]
    )()

def EikenellaSpNml02A017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eikenella sp. NML02-A-017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EikenellaSpNml02A017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1795827.protein.sequences.v11.5.fa",
		        "enrichment_path": "1795827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1795827.protein.info.v11.5.txt",
		        "node_list_path": "1795827.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumSiliguriense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium siliguriense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumSiliguriense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1136497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1136497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1136497.protein.info.v11.5.txt",
		        "node_list_path": "1136497.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminococcusAlbusAd2013Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus albus AD2013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusAlbusAd2013Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1384065.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1384065.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1384065.clusters.proteins.v11.5.txt",
		        "sequence_path": "1384065.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384065.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384065.protein.info.v11.5.txt",
		        "node_list_path": "1384065.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1384065.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSaerimneri30a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus saerimneri 30a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSaerimneri30a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227363.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227363.protein.info.v11.5.txt",
		        "node_list_path": "1227363.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColwelliaSpPamc21821(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia sp. PAMC 21821 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaSpPamc21821", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1816219.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816219.protein.info.v11.5.txt",
		        "node_list_path": "1816219.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPutrefaciensKs1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens KS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPutrefaciensKs1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "743965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "743965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "743965.clusters.proteins.v11.5.txt",
		        "sequence_path": "743965.protein.sequences.v11.5.fa",
		        "enrichment_path": "743965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743965.protein.info.v11.5.txt",
		        "node_list_path": "743965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "743965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterGlobiformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter globiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterGlobiformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1077972.protein.sequences.v11.5.fa",
		        "enrichment_path": "1077972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1077972.protein.info.v11.5.txt",
		        "node_list_path": "1077972.protein.complete.v11.5.txt"
		    }
		]
    )()

def NereidaIgnavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nereida ignava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NereidaIgnavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "282199.clusters.info.v11.5.txt",
		        "cluster_tree_path": "282199.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "282199.clusters.proteins.v11.5.txt",
		        "sequence_path": "282199.protein.sequences.v11.5.fa",
		        "enrichment_path": "282199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "282199.protein.info.v11.5.txt",
		        "node_list_path": "282199.cluster.nodes.v11.5.txt",
		        "edge_list_path": "282199.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VirgibacillusSiamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus siamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VirgibacillusSiamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "480071.clusters.info.v11.5.txt",
		        "cluster_tree_path": "480071.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "480071.clusters.proteins.v11.5.txt",
		        "sequence_path": "480071.protein.sequences.v11.5.fa",
		        "enrichment_path": "480071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "480071.protein.info.v11.5.txt",
		        "node_list_path": "480071.cluster.nodes.v11.5.txt",
		        "edge_list_path": "480071.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomonosporaAlbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomonospora alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomonosporaAlbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "183763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "183763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "183763.clusters.proteins.v11.5.txt",
		        "sequence_path": "183763.protein.sequences.v11.5.fa",
		        "enrichment_path": "183763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "183763.protein.info.v11.5.txt",
		        "node_list_path": "183763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "183763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SandaracinusAmylolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sandaracinus amylolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SandaracinusAmylolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "927083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "927083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "927083.clusters.proteins.v11.5.txt",
		        "sequence_path": "927083.protein.sequences.v11.5.fa",
		        "enrichment_path": "927083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "927083.protein.info.v11.5.txt",
		        "node_list_path": "927083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "927083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5417Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_54_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5417Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798664.protein.info.v11.5.txt",
		        "node_list_path": "1798664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CesiribacterAndamanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cesiribacter andamanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CesiribacterAndamanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1279009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1279009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1279009.protein.info.v11.5.txt",
		        "node_list_path": "1279009.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat18019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-18019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat18019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1705110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1705110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1705110.clusters.proteins.v11.5.txt",
		        "sequence_path": "1705110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705110.protein.info.v11.5.txt",
		        "node_list_path": "1705110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1705110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24726Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_47_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24726Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618844.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618844.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618844.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618844.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618844.protein.info.v11.5.txt",
		        "node_list_path": "1618844.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618844.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NigeriumMassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nigerium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NigeriumMassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1522317.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1522317.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1522317.clusters.proteins.v11.5.txt",
		        "sequence_path": "1522317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522317.protein.info.v11.5.txt",
		        "node_list_path": "1522317.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1522317.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpJm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. JM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpJm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1233950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1233950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1233950.clusters.proteins.v11.5.txt",
		        "sequence_path": "1233950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1233950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1233950.protein.info.v11.5.txt",
		        "node_list_path": "1233950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1233950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachypodiumDistachyon(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachypodium distachyon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachypodiumDistachyon", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "15368.protein.sequences.v11.5.fa",
		        "enrichment_path": "15368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "15368.protein.info.v11.5.txt",
		        "node_list_path": "15368.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasCampestrisCampestrisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Xanthomonas campestris campestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCampestrisCampestrisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "340.clusters.info.v11.0.txt",
		        "cluster_tree_path": "340.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "340.clusters.proteins.v11.0.txt",
		        "sequence_path": "340.protein.sequences.v11.0.fa",
		        "enrichment_path": "340.protein.enrichment.terms.v11.0.txt",
		        "info_path": "340.protein.info.v11.0.txt",
		        "node_list_path": "340.cluster.nodes.v11.0.txt",
		        "edge_list_path": "340.protein.cluster.v11.0.txt"
		    }
		]
    )()

def RhizobiumFreireiPrf81(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium freirei PRF 81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumFreireiPrf81", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "363754.protein.sequences.v11.5.fa",
		        "enrichment_path": "363754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "363754.protein.info.v11.5.txt",
		        "node_list_path": "363754.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlB24484Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL B-24484 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlB24484Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463833.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463833.protein.info.v11.5.txt",
		        "node_list_path": "1463833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YooniaRoseaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yoonia rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YooniaRoseaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "287098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "287098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "287098.clusters.proteins.v11.5.txt",
		        "sequence_path": "287098.protein.sequences.v11.5.fa",
		        "enrichment_path": "287098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "287098.protein.info.v11.5.txt",
		        "node_list_path": "287098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "287098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaIntermediaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia intermedia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaIntermediaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349965.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349965.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349965.clusters.proteins.v11.5.txt",
		        "sequence_path": "349965.protein.sequences.v11.5.fa",
		        "enrichment_path": "349965.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349965.protein.info.v11.5.txt",
		        "node_list_path": "349965.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349965.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusariumOxysporumFSpCubenseRace1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. cubense race 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumOxysporumFSpCubenseRace1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229664.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229664.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229664.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229664.protein.info.v11.5.txt",
		        "node_list_path": "1229664.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229664.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlj1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlj1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1158144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1158144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1158144.clusters.proteins.v11.5.txt",
		        "sequence_path": "1158144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158144.protein.info.v11.5.txt",
		        "node_list_path": "1158144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1158144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CohaesibacterMarisflavi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cohaesibacter marisflavi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CohaesibacterMarisflavi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655353.protein.sequences.v11.5.fa",
		        "enrichment_path": "655353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655353.protein.info.v11.5.txt",
		        "node_list_path": "655353.protein.complete.v11.5.txt"
		    }
		]
    )()

def SchistosomaRodhaini(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma rodhaini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaRodhaini", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6188.protein.sequences.v11.5.fa",
		        "enrichment_path": "6188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6188.protein.info.v11.5.txt",
		        "node_list_path": "6188.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacteriumSalinarumNrc1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium salinarum NRC-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacteriumSalinarumNrc1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "64091.clusters.info.v11.5.txt",
		        "cluster_tree_path": "64091.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "64091.clusters.proteins.v11.5.txt",
		        "sequence_path": "64091.protein.sequences.v11.5.fa",
		        "enrichment_path": "64091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64091.protein.info.v11.5.txt",
		        "node_list_path": "64091.cluster.nodes.v11.5.txt",
		        "edge_list_path": "64091.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrovirgaLotononidisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microvirga lotononidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaLotononidisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "864069.clusters.info.v11.5.txt",
		        "cluster_tree_path": "864069.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "864069.clusters.proteins.v11.5.txt",
		        "sequence_path": "864069.protein.sequences.v11.5.fa",
		        "enrichment_path": "864069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864069.protein.info.v11.5.txt",
		        "node_list_path": "864069.cluster.nodes.v11.5.txt",
		        "edge_list_path": "864069.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumCeleriflavumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium celeriflavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumCeleriflavumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1249101.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1249101.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1249101.clusters.proteins.v11.5.txt",
		        "sequence_path": "1249101.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249101.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249101.protein.info.v11.5.txt",
		        "node_list_path": "1249101.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1249101.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlsenellaUmbonata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella umbonata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaUmbonata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "604330.protein.sequences.v11.5.fa",
		        "enrichment_path": "604330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "604330.protein.info.v11.5.txt",
		        "node_list_path": "604330.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacterium41269(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium 41_269 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacterium41269", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635275.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635275.protein.info.v11.5.txt",
		        "node_list_path": "1635275.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasArgentinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas argentinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasArgentinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "289370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "289370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "289370.clusters.proteins.v11.5.txt",
		        "sequence_path": "289370.protein.sequences.v11.5.fa",
		        "enrichment_path": "289370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "289370.protein.info.v11.5.txt",
		        "node_list_path": "289370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "289370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumNovyiBNctc9691(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium novyi B NCTC9691 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumNovyiBNctc9691", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1443122.protein.sequences.v11.5.fa",
		        "enrichment_path": "1443122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1443122.protein.info.v11.5.txt",
		        "node_list_path": "1443122.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurihydrogenibiumSubterraneum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium subterraneum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurihydrogenibiumSubterraneum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123325.protein.info.v11.5.txt",
		        "node_list_path": "1123325.protein.complete.v11.5.txt"
		    }
		]
    )()

def XylariaFlabelliformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylaria flabelliformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylariaFlabelliformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2512241.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2512241.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2512241.clusters.proteins.v11.5.txt",
		        "sequence_path": "2512241.protein.sequences.v11.5.fa",
		        "enrichment_path": "2512241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2512241.protein.info.v11.5.txt",
		        "node_list_path": "2512241.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2512241.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorhabdusTiamatea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorhabdus tiamatea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorhabdusTiamatea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033806.protein.info.v11.5.txt",
		        "node_list_path": "1033806.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolimonasFlavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solimonas flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolimonasFlavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123257.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123257.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123257.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123257.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123257.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123257.protein.info.v11.5.txt",
		        "node_list_path": "1123257.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123257.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpLnjc398b00(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LNJC398B00 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpLnjc398b00", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1287276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287276.protein.info.v11.5.txt",
		        "node_list_path": "1287276.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerococcusVaginalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusVaginalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655811.protein.sequences.v11.5.fa",
		        "enrichment_path": "655811.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655811.protein.info.v11.5.txt",
		        "node_list_path": "655811.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumOryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumOryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "464029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "464029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "464029.clusters.proteins.v11.5.txt",
		        "sequence_path": "464029.protein.sequences.v11.5.fa",
		        "enrichment_path": "464029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "464029.protein.info.v11.5.txt",
		        "node_list_path": "464029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "464029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterAntarcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterAntarcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "564117.protein.sequences.v11.5.fa",
		        "enrichment_path": "564117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "564117.protein.info.v11.5.txt",
		        "node_list_path": "564117.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaGrenadensisNbrc108939(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia grenadensis NBRC 108939 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaGrenadensisNbrc108939", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223546.protein.info.v11.5.txt",
		        "node_list_path": "1223546.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaSpOralTaxon020StrF0370(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. oral taxon 020 str. F0370 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaSpOralTaxon020StrF0370", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1127694.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127694.protein.info.v11.5.txt",
		        "node_list_path": "1127694.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsplowo201Full4724Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_01_FULL_47_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo201Full4724Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802401.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802401.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802401.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802401.protein.info.v11.5.txt",
		        "node_list_path": "1802401.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802401.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoactinosporaRubra(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoactinospora rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoactinosporaRubra", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1088767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1088767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1088767.protein.info.v11.5.txt",
		        "node_list_path": "1088767.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaceaeBacteriumDtu054Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU054 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaceaeBacteriumDtu054Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671643.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671643.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671643.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671643.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671643.protein.info.v11.5.txt",
		        "node_list_path": "1671643.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671643.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterNanhaisediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter nanhaisediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterNanhaisediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "604088.clusters.info.v11.5.txt",
		        "cluster_tree_path": "604088.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "604088.clusters.proteins.v11.5.txt",
		        "sequence_path": "604088.protein.sequences.v11.5.fa",
		        "enrichment_path": "604088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "604088.protein.info.v11.5.txt",
		        "node_list_path": "604088.cluster.nodes.v11.5.txt",
		        "edge_list_path": "604088.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsphigho2024316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_43_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho2024316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798331.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798331.protein.info.v11.5.txt",
		        "node_list_path": "1798331.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalothermothrixSpDtu029Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halothermothrix sp. DTU029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalothermothrixSpDtu029Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671624.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671624.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671624.protein.info.v11.5.txt",
		        "node_list_path": "1671624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusSibiricus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus sibiricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusSibiricus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "604354.protein.sequences.v11.5.fa",
		        "enrichment_path": "604354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "604354.protein.info.v11.5.txt",
		        "node_list_path": "604354.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusSpLc300Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. LC300 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusSpLc300Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1519377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1519377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1519377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1519377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519377.protein.info.v11.5.txt",
		        "node_list_path": "1519377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1519377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudodesulfovibrioIndicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudodesulfovibrio indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudodesulfovibrioIndicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1716143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1716143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1716143.clusters.proteins.v11.5.txt",
		        "sequence_path": "1716143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1716143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1716143.protein.info.v11.5.txt",
		        "node_list_path": "1716143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1716143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesAlpinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides alpinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesAlpinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "748909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "748909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "748909.clusters.proteins.v11.5.txt",
		        "sequence_path": "748909.protein.sequences.v11.5.fa",
		        "enrichment_path": "748909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "748909.protein.info.v11.5.txt",
		        "node_list_path": "748909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "748909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5413(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5413", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798512.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798512.protein.info.v11.5.txt",
		        "node_list_path": "1798512.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaSpF0382(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0382 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaSpF0382", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1035193.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035193.protein.info.v11.5.txt",
		        "node_list_path": "1035193.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpHw567Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. HW567 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpHw567Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1034769.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1034769.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1034769.clusters.proteins.v11.5.txt",
		        "sequence_path": "1034769.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034769.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034769.protein.info.v11.5.txt",
		        "node_list_path": "1034769.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1034769.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BelliellaBaltica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Belliella baltica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BelliellaBaltica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "866536.protein.sequences.v11.5.fa",
		        "enrichment_path": "866536.protein.enrichment.terms.v11.5.txt",
		        "info_path": "866536.protein.info.v11.5.txt",
		        "node_list_path": "866536.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusSpTolMCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. Tol-M Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusSpTolMCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1536651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1536651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1536651.clusters.proteins.v11.5.txt",
		        "sequence_path": "1536651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536651.protein.info.v11.5.txt",
		        "node_list_path": "1536651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1536651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusMellisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mellis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMellisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218508.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218508.protein.info.v11.5.txt",
		        "node_list_path": "1218508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicocarpusGriseusUamh5409Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicocarpus griseus UAMH5409 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicocarpusGriseusUamh5409Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1447875.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1447875.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1447875.clusters.proteins.v11.5.txt",
		        "sequence_path": "1447875.protein.sequences.v11.5.fa",
		        "enrichment_path": "1447875.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1447875.protein.info.v11.5.txt",
		        "node_list_path": "1447875.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1447875.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OenococcusOeniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oenococcus oeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OenococcusOeniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "203123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "203123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "203123.clusters.proteins.v11.5.txt",
		        "sequence_path": "203123.protein.sequences.v11.5.fa",
		        "enrichment_path": "203123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203123.protein.info.v11.5.txt",
		        "node_list_path": "203123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "203123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusTectomicrobiaBacteriumRifcsplowo202Full7019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tectomicrobia bacterium RIFCSPLOWO2_02_FULL_70_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTectomicrobiaBacteriumRifcsplowo202Full7019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802342.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802342.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802342.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802342.protein.info.v11.5.txt",
		        "node_list_path": "1802342.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802342.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenisporosarcinaSpHgh0030(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenisporosarcina sp. HGH0030 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenisporosarcinaSpHgh0030", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1078085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078085.protein.info.v11.5.txt",
		        "node_list_path": "1078085.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumBrachiatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium brachiatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumBrachiatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "269660.protein.sequences.v11.5.fa",
		        "enrichment_path": "269660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "269660.protein.info.v11.5.txt",
		        "node_list_path": "269660.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumGw2011Gwe14915(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_49_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe14915", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618710.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618710.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618710.protein.info.v11.5.txt",
		        "node_list_path": "1618710.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg134322(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_43_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg134322", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797825.protein.info.v11.5.txt",
		        "node_list_path": "1797825.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterOrientalis21f2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter orientalis 21F-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterOrientalis21f2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231341.protein.info.v11.5.txt",
		        "node_list_path": "1231341.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCiconiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium ciconiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCiconiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121356.protein.info.v11.5.txt",
		        "node_list_path": "1121356.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnsiferSpLcm4579(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. LCM 4579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferSpLcm4579", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1848292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1848292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1848292.protein.info.v11.5.txt",
		        "node_list_path": "1848292.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumFrigidicarnisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium frigidicarnis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumFrigidicarnisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "84698.clusters.info.v11.5.txt",
		        "cluster_tree_path": "84698.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "84698.clusters.proteins.v11.5.txt",
		        "sequence_path": "84698.protein.sequences.v11.5.fa",
		        "enrichment_path": "84698.protein.enrichment.terms.v11.5.txt",
		        "info_path": "84698.protein.info.v11.5.txt",
		        "node_list_path": "84698.cluster.nodes.v11.5.txt",
		        "edge_list_path": "84698.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpBplan(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. BPLAN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpBplan", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "600809.protein.sequences.v11.5.fa",
		        "enrichment_path": "600809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "600809.protein.info.v11.5.txt",
		        "node_list_path": "600809.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavihumibacterPetaseusNbrc106054(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavihumibacter petaseus NBRC 106054 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavihumibacterPetaseusNbrc106054", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1220578.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220578.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220578.protein.info.v11.5.txt",
		        "node_list_path": "1220578.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhaeobacterGallaeciensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter gallaeciensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterGallaeciensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423144.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423144.protein.info.v11.5.txt",
		        "node_list_path": "1423144.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfomicrobiumEscambienseDsm10707(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium escambiense DSM 10707 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfomicrobiumEscambienseDsm10707", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121411.protein.info.v11.5.txt",
		        "node_list_path": "1121411.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterAquivivusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter aquivivus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterAquivivusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "228958.clusters.info.v11.5.txt",
		        "cluster_tree_path": "228958.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "228958.clusters.proteins.v11.5.txt",
		        "sequence_path": "228958.protein.sequences.v11.5.fa",
		        "enrichment_path": "228958.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228958.protein.info.v11.5.txt",
		        "node_list_path": "228958.cluster.nodes.v11.5.txt",
		        "edge_list_path": "228958.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ModestobacterCaceresiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Modestobacter caceresii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ModestobacterCaceresiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1522368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1522368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1522368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1522368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522368.protein.info.v11.5.txt",
		        "node_list_path": "1522368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1522368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumEndosymbiontOfMortierella(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Mortierella graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumEndosymbiontOfMortierella", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1562701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1562701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1562701.protein.info.v11.5.txt",
		        "node_list_path": "1562701.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrantheGuttata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythranthe guttata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrantheGuttata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4155.protein.sequences.v11.5.fa",
		        "enrichment_path": "4155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4155.protein.info.v11.5.txt",
		        "node_list_path": "4155.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedAnaerotruncusSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Anaerotruncus sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedAnaerotruncusSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "905011.clusters.info.v11.5.txt",
		        "cluster_tree_path": "905011.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "905011.clusters.proteins.v11.5.txt",
		        "sequence_path": "905011.protein.sequences.v11.5.fa",
		        "enrichment_path": "905011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "905011.protein.info.v11.5.txt",
		        "node_list_path": "905011.cluster.nodes.v11.5.txt",
		        "edge_list_path": "905011.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumCoe1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium COE1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumCoe1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235793.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235793.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235793.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235793.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235793.protein.info.v11.5.txt",
		        "node_list_path": "1235793.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235793.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylomonasSp11b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylomonas sp. 11b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylomonasSp11b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1168169.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168169.protein.info.v11.5.txt",
		        "node_list_path": "1168169.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalothermothrixOrenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halothermothrix orenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalothermothrixOrenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "373903.protein.sequences.v11.5.fa",
		        "enrichment_path": "373903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "373903.protein.info.v11.5.txt",
		        "node_list_path": "373903.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfipiaSpOhsuic4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. OHSUIC4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaSpOhsuic4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1297863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297863.protein.info.v11.5.txt",
		        "node_list_path": "1297863.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethyloversatilisSpRac08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methyloversatilis sp. RAC08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloversatilisSpRac08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1842540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842540.protein.info.v11.5.txt",
		        "node_list_path": "1842540.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuberibacillusCalidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tuberibacillus calidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuberibacillusCalidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123405.protein.info.v11.5.txt",
		        "node_list_path": "1123405.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumTcs42Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium tcs-42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumTcs42Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1742866.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1742866.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1742866.clusters.proteins.v11.5.txt",
		        "sequence_path": "1742866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742866.protein.info.v11.5.txt",
		        "node_list_path": "1742866.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1742866.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full349(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_34_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full349", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802206.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802206.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802206.protein.info.v11.5.txt",
		        "node_list_path": "1802206.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumGiardinii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium giardinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumGiardinii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1041139.protein.sequences.v11.5.fa",
		        "enrichment_path": "1041139.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1041139.protein.info.v11.5.txt",
		        "node_list_path": "1041139.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirosomaSp209Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma sp. 209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaSp209Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1955701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1955701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1955701.clusters.proteins.v11.5.txt",
		        "sequence_path": "1955701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1955701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1955701.protein.info.v11.5.txt",
		        "node_list_path": "1955701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1955701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloplanusNatans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloplanus natans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloplanusNatans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "926690.protein.sequences.v11.5.fa",
		        "enrichment_path": "926690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926690.protein.info.v11.5.txt",
		        "node_list_path": "926690.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpOr444(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. OR444 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpOr444", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1076525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076525.protein.info.v11.5.txt",
		        "node_list_path": "1076525.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantheraTigris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Panthera tigris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantheraTigris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9694.protein.sequences.v11.5.fa",
		        "enrichment_path": "9694.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9694.protein.info.v11.5.txt",
		        "node_list_path": "9694.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpPh1b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. PH1b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpPh1b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1397282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397282.protein.info.v11.5.txt",
		        "node_list_path": "1397282.protein.complete.v11.5.txt"
		    }
		]
    )()

def SunxiuqiniaElliptica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sunxiuqinia elliptica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SunxiuqiniaElliptica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655355.protein.sequences.v11.5.fa",
		        "enrichment_path": "655355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655355.protein.info.v11.5.txt",
		        "node_list_path": "655355.protein.complete.v11.5.txt"
		    }
		]
    )()

def FormosaHaliotis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Formosa haliotis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaHaliotis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1555194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1555194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1555194.protein.info.v11.5.txt",
		        "node_list_path": "1555194.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioclavaSpDt234Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. DT234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioclavaSpDt234Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1353528.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1353528.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1353528.clusters.proteins.v11.5.txt",
		        "sequence_path": "1353528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353528.protein.info.v11.5.txt",
		        "node_list_path": "1353528.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1353528.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavigranumRuoffiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavigranum ruoffiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavigranumRuoffiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "89093.clusters.info.v11.5.txt",
		        "cluster_tree_path": "89093.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "89093.clusters.proteins.v11.5.txt",
		        "sequence_path": "89093.protein.sequences.v11.5.fa",
		        "enrichment_path": "89093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89093.protein.info.v11.5.txt",
		        "node_list_path": "89093.cluster.nodes.v11.5.txt",
		        "edge_list_path": "89093.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TheropithecusGelada(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Theropithecus gelada graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheropithecusGelada", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9565.protein.sequences.v11.5.fa",
		        "enrichment_path": "9565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9565.protein.info.v11.5.txt",
		        "node_list_path": "9565.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusLugdunensisHku0901Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis HKU0901 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusLugdunensisHku0901Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "698737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "698737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "698737.clusters.proteins.v11.5.txt",
		        "sequence_path": "698737.protein.sequences.v11.5.fa",
		        "enrichment_path": "698737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698737.protein.info.v11.5.txt",
		        "node_list_path": "698737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "698737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumAromaticivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium aromaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumAromaticivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "279238.protein.sequences.v11.5.fa",
		        "enrichment_path": "279238.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279238.protein.info.v11.5.txt",
		        "node_list_path": "279238.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeishmaniaInfantumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leishmania infantum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeishmaniaInfantumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5671.clusters.proteins.v11.5.txt",
		        "sequence_path": "5671.protein.sequences.v11.5.fa",
		        "enrichment_path": "5671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5671.protein.info.v11.5.txt",
		        "node_list_path": "5671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSungbacteriaBacteriumRifcsplowo201Full5421Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_54_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full5421Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802279.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802279.protein.info.v11.5.txt",
		        "node_list_path": "1802279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BhargavaeaCecembensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bhargavaea cecembensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BhargavaeaCecembensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235279.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235279.protein.info.v11.5.txt",
		        "node_list_path": "1235279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaSpTx077308Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella sp. TX077308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaSpTx077308Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "573569.clusters.info.v11.5.txt",
		        "cluster_tree_path": "573569.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "573569.clusters.proteins.v11.5.txt",
		        "sequence_path": "573569.protein.sequences.v11.5.fa",
		        "enrichment_path": "573569.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573569.protein.info.v11.5.txt",
		        "node_list_path": "573569.cluster.nodes.v11.5.txt",
		        "edge_list_path": "573569.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaSpW121067Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella sp. W121067 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaSpW121067Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385420.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385420.protein.info.v11.5.txt",
		        "node_list_path": "1385420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzospirillumSpCag239(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum sp. CAG:239 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumSpCag239", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262705.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262705.protein.info.v11.5.txt",
		        "node_list_path": "1262705.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfCimexLectularius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Cimex lectularius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfCimexLectularius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "246273.protein.sequences.v11.5.fa",
		        "enrichment_path": "246273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246273.protein.info.v11.5.txt",
		        "node_list_path": "246273.protein.complete.v11.5.txt"
		    }
		]
    )()

def Haloarchaeon3a1dgrCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return haloarchaeon 3A1DGR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Haloarchaeon3a1dgrCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1071085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1071085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1071085.clusters.proteins.v11.5.txt",
		        "sequence_path": "1071085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1071085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1071085.protein.info.v11.5.txt",
		        "node_list_path": "1071085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1071085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanothermusFervidusDsm2088Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothermus fervidus DSM 2088 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanothermusFervidusDsm2088Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "523846.clusters.info.v11.5.txt",
		        "cluster_tree_path": "523846.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "523846.clusters.proteins.v11.5.txt",
		        "sequence_path": "523846.protein.sequences.v11.5.fa",
		        "enrichment_path": "523846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523846.protein.info.v11.5.txt",
		        "node_list_path": "523846.cluster.nodes.v11.5.txt",
		        "edge_list_path": "523846.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedArchaeonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedArchaeonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "115547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "115547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "115547.clusters.proteins.v11.5.txt",
		        "sequence_path": "115547.protein.sequences.v11.5.fa",
		        "enrichment_path": "115547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "115547.protein.info.v11.5.txt",
		        "node_list_path": "115547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "115547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumSpJcm19050(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium sp. JCM 19050 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumSpJcm19050", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1460644.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460644.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460644.protein.info.v11.5.txt",
		        "node_list_path": "1460644.protein.complete.v11.5.txt"
		    }
		]
    )()

def AvibacteriumParagallinarum221(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum 221 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AvibacteriumParagallinarum221", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278971.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278971.protein.info.v11.5.txt",
		        "node_list_path": "1278971.protein.complete.v11.5.txt"
		    }
		]
    )()

def LawsonellaClevelandensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lawsonella clevelandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LawsonellaClevelandensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1528099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1528099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1528099.clusters.proteins.v11.5.txt",
		        "sequence_path": "1528099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1528099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1528099.protein.info.v11.5.txt",
		        "node_list_path": "1528099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1528099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpRoot930(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Root930 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpRoot930", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736609.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736609.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736609.protein.info.v11.5.txt",
		        "node_list_path": "1736609.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScardoviaInopinataJcm12537(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scardovia inopinata JCM 12537 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScardoviaInopinataJcm12537", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150468.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150468.protein.info.v11.5.txt",
		        "node_list_path": "1150468.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumAc2012Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumAc2012Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392494.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392494.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392494.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392494.protein.info.v11.5.txt",
		        "node_list_path": "1392494.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392494.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomyceteKsu1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return planctomycete KSU1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomyceteKsu1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "247490.clusters.info.v11.5.txt",
		        "cluster_tree_path": "247490.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "247490.clusters.proteins.v11.5.txt",
		        "sequence_path": "247490.protein.sequences.v11.5.fa",
		        "enrichment_path": "247490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247490.protein.info.v11.5.txt",
		        "node_list_path": "247490.cluster.nodes.v11.5.txt",
		        "edge_list_path": "247490.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumP6a3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium P6A3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumP6a3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410630.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410630.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410630.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410630.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410630.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410630.protein.info.v11.5.txt",
		        "node_list_path": "1410630.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410630.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AeromonasEncheleia(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas encheleia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeromonasEncheleia", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "73010.protein.sequences.v11.5.fa",
		        "enrichment_path": "73010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "73010.protein.info.v11.5.txt",
		        "node_list_path": "73010.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusPhenolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus phenolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusPhenolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "263849.protein.sequences.v11.5.fa",
		        "enrichment_path": "263849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "263849.protein.info.v11.5.txt",
		        "node_list_path": "263849.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeganemaPerideroedes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meganema perideroedes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeganemaPerideroedes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122218.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122218.protein.info.v11.5.txt",
		        "node_list_path": "1122218.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasAlkaliantarctica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas alkaliantarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasAlkaliantarctica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "232346.protein.sequences.v11.5.fa",
		        "enrichment_path": "232346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "232346.protein.info.v11.5.txt",
		        "node_list_path": "232346.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesXanthophaeusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces xanthophaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesXanthophaeusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67385.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67385.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67385.clusters.proteins.v11.5.txt",
		        "sequence_path": "67385.protein.sequences.v11.5.fa",
		        "enrichment_path": "67385.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67385.protein.info.v11.5.txt",
		        "node_list_path": "67385.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67385.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerticilliumAlfalfaeVams102Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verticillium alfalfae VaMs.102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerticilliumAlfalfaeVams102Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "526221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "526221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "526221.clusters.proteins.v11.5.txt",
		        "sequence_path": "526221.protein.sequences.v11.5.fa",
		        "enrichment_path": "526221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526221.protein.info.v11.5.txt",
		        "node_list_path": "526221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "526221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf412(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf412", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736370.protein.info.v11.5.txt",
		        "node_list_path": "1736370.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoccomyxaSubellipsoideaC169(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coccomyxa subellipsoidea C-169 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccomyxaSubellipsoideaC169", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "574566.protein.sequences.v11.5.fa",
		        "enrichment_path": "574566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574566.protein.info.v11.5.txt",
		        "node_list_path": "574566.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlloiococcusOtitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alloiococcus otitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloiococcusOtitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883081.clusters.proteins.v11.5.txt",
		        "sequence_path": "883081.protein.sequences.v11.5.fa",
		        "enrichment_path": "883081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883081.protein.info.v11.5.txt",
		        "node_list_path": "883081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnncaliiaAlgeraePra339Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anncaliia algerae PRA339 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnncaliiaAlgeraePra339Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288291.protein.info.v11.5.txt",
		        "node_list_path": "1288291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EhrlichiaMurisAs145Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia muris AS145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EhrlichiaMurisAs145Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423892.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423892.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423892.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423892.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423892.protein.info.v11.5.txt",
		        "node_list_path": "1423892.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423892.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhialocephalaSubalpina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phialocephala subalpina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhialocephalaSubalpina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "576137.protein.sequences.v11.5.fa",
		        "enrichment_path": "576137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "576137.protein.info.v11.5.txt",
		        "node_list_path": "576137.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusPsittaciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus psittaci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPsittaciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122152.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122152.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122152.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122152.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122152.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122152.protein.info.v11.5.txt",
		        "node_list_path": "1122152.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122152.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProvidenciaAlcalifaciensR901475Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens R90-1475 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProvidenciaAlcalifaciensR901475Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1256989.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1256989.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1256989.clusters.proteins.v11.5.txt",
		        "sequence_path": "1256989.protein.sequences.v11.5.fa",
		        "enrichment_path": "1256989.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1256989.protein.info.v11.5.txt",
		        "node_list_path": "1256989.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1256989.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSviceus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sviceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSviceus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "463191.protein.sequences.v11.5.fa",
		        "enrichment_path": "463191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "463191.protein.info.v11.5.txt",
		        "node_list_path": "463191.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeomicrococcusAestuarii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neomicrococcus aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeomicrococcusAestuarii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "556325.protein.sequences.v11.5.fa",
		        "enrichment_path": "556325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556325.protein.info.v11.5.txt",
		        "node_list_path": "556325.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaLaterculaDsm2041Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina latercula DSM 2041 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaLaterculaDsm2041Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121006.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121006.protein.info.v11.5.txt",
		        "node_list_path": "1121006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4714(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_47_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4714", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798680.protein.info.v11.5.txt",
		        "node_list_path": "1798680.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpCf8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. CF8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpCf8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "110319.protein.sequences.v11.5.fa",
		        "enrichment_path": "110319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "110319.protein.info.v11.5.txt",
		        "node_list_path": "110319.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasProsekii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas prosekii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasProsekii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1148509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1148509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1148509.protein.info.v11.5.txt",
		        "node_list_path": "1148509.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseorubensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseorubens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseorubensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "66897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "66897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "66897.clusters.proteins.v11.5.txt",
		        "sequence_path": "66897.protein.sequences.v11.5.fa",
		        "enrichment_path": "66897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66897.protein.info.v11.5.txt",
		        "node_list_path": "66897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "66897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitricoccusSpCh26aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citricoccus sp. CH26A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitricoccusSpCh26aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1045009.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1045009.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1045009.clusters.proteins.v11.5.txt",
		        "sequence_path": "1045009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045009.protein.info.v11.5.txt",
		        "node_list_path": "1045009.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1045009.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StrongylocentrotusPurpuratus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Strongylocentrotus purpuratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StrongylocentrotusPurpuratus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7668.protein.sequences.v11.5.fa",
		        "enrichment_path": "7668.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7668.protein.info.v11.5.txt",
		        "node_list_path": "7668.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichinellaZimbabwensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichinella zimbabwensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaZimbabwensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "268475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "268475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "268475.clusters.proteins.v11.5.txt",
		        "sequence_path": "268475.protein.sequences.v11.5.fa",
		        "enrichment_path": "268475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "268475.protein.info.v11.5.txt",
		        "node_list_path": "268475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "268475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusColwellbacteriaBacteriumRifcsplowo212Full4311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_12_FULL_43_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo212Full4311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797693.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797693.protein.info.v11.5.txt",
		        "node_list_path": "1797693.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCoagulans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coagulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCoagulans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1398.protein.info.v11.5.txt",
		        "node_list_path": "1398.protein.complete.v11.5.txt"
		    }
		]
    )()

def InsolitispirillumPeregrinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Insolitispirillum peregrinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "InsolitispirillumPeregrinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "80876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "80876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "80876.clusters.proteins.v11.5.txt",
		        "sequence_path": "80876.protein.sequences.v11.5.fa",
		        "enrichment_path": "80876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "80876.protein.info.v11.5.txt",
		        "node_list_path": "80876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "80876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpKt25bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. KT25b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpKt25bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855336.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855336.protein.info.v11.5.txt",
		        "node_list_path": "1855336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumSpBv1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum sp. BV1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumSpBv1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1498500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1498500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1498500.protein.info.v11.5.txt",
		        "node_list_path": "1498500.protein.complete.v11.5.txt"
		    }
		]
    )()

def BartonellaBovis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaBovis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094491.protein.info.v11.5.txt",
		        "node_list_path": "1094491.protein.complete.v11.5.txt"
		    }
		]
    )()

def WickerhamomycesCiferriiNrrlY1031(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamomyces ciferrii NRRL Y-1031 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WickerhamomycesCiferriiNrrlY1031", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1206466.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206466.protein.info.v11.5.txt",
		        "node_list_path": "1206466.protein.complete.v11.5.txt"
		    }
		]
    )()

def CrenarchaeotaArchaeon13140cm35217(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_52_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CrenarchaeotaArchaeon13140cm35217", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805096.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805096.protein.info.v11.5.txt",
		        "node_list_path": "1805096.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaFelisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila felis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaFelisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264202.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264202.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264202.clusters.proteins.v11.5.txt",
		        "sequence_path": "264202.protein.sequences.v11.5.fa",
		        "enrichment_path": "264202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264202.protein.info.v11.5.txt",
		        "node_list_path": "264202.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264202.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterRhaeticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter rhaeticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterRhaeticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1432055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432055.protein.info.v11.5.txt",
		        "node_list_path": "1432055.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpWao(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. WAO graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpWao", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "406341.protein.sequences.v11.5.fa",
		        "enrichment_path": "406341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "406341.protein.info.v11.5.txt",
		        "node_list_path": "406341.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerovibrioSpRm50Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerovibrio sp. RM50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerovibrioSpRm50Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1200557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1200557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1200557.clusters.proteins.v11.5.txt",
		        "sequence_path": "1200557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1200557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1200557.protein.info.v11.5.txt",
		        "node_list_path": "1200557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1200557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumParaputrificum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium paraputrificum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumParaputrificum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280689.protein.info.v11.5.txt",
		        "node_list_path": "1280689.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhaeobacterPorticolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter porticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterPorticolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1844006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1844006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1844006.clusters.proteins.v11.5.txt",
		        "sequence_path": "1844006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1844006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1844006.protein.info.v11.5.txt",
		        "node_list_path": "1844006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1844006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasParapaucimobilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas parapaucimobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasParapaucimobilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219049.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219049.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219049.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219049.protein.info.v11.5.txt",
		        "node_list_path": "1219049.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219049.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeriophthalmusMagnuspinnatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Periophthalmus magnuspinnatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeriophthalmusMagnuspinnatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "409849.protein.sequences.v11.5.fa",
		        "enrichment_path": "409849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "409849.protein.info.v11.5.txt",
		        "node_list_path": "409849.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErythrobacterSpNap1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter sp. NAP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterSpNap1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "237727.protein.sequences.v11.5.fa",
		        "enrichment_path": "237727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237727.protein.info.v11.5.txt",
		        "node_list_path": "237727.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumFioriniaePj7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum fioriniae PJ7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumFioriniaePj7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1445577.protein.sequences.v11.5.fa",
		        "enrichment_path": "1445577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1445577.protein.info.v11.5.txt",
		        "node_list_path": "1445577.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaMirumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma mirum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaMirumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "838561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "838561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "838561.clusters.proteins.v11.5.txt",
		        "sequence_path": "838561.protein.sequences.v11.5.fa",
		        "enrichment_path": "838561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "838561.protein.info.v11.5.txt",
		        "node_list_path": "838561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "838561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusSpDsm45219(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus sp. DSM 45219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusSpDsm45219", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881103.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881103.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881103.protein.info.v11.5.txt",
		        "node_list_path": "1881103.protein.complete.v11.5.txt"
		    }
		]
    )()

def AeribacillusPallidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeribacillus pallidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AeribacillusPallidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33936.clusters.proteins.v11.5.txt",
		        "sequence_path": "33936.protein.sequences.v11.5.fa",
		        "enrichment_path": "33936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33936.protein.info.v11.5.txt",
		        "node_list_path": "33936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FaecalicatenaFissicatena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Faecalicatena fissicatena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FaecalicatenaFissicatena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290055.protein.sequences.v11.5.fa",
		        "enrichment_path": "290055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290055.protein.info.v11.5.txt",
		        "node_list_path": "290055.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoccidioidesImmitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesImmitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5501.protein.sequences.v11.5.fa",
		        "enrichment_path": "5501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5501.protein.info.v11.5.txt",
		        "node_list_path": "5501.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumPolysaccharolyticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] polysaccharolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumPolysaccharolyticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29364.protein.sequences.v11.5.fa",
		        "enrichment_path": "29364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29364.protein.info.v11.5.txt",
		        "node_list_path": "29364.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylocapsaPalsarum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylocapsa palsarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocapsaPalsarum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1612308.protein.sequences.v11.5.fa",
		        "enrichment_path": "1612308.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1612308.protein.info.v11.5.txt",
		        "node_list_path": "1612308.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpFjat25496(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-25496 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpFjat25496", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1742359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742359.protein.info.v11.5.txt",
		        "node_list_path": "1742359.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaBeijingensisNbrc16342Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia beijingensis NBRC 16342 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaBeijingensisNbrc16342Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210068.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210068.protein.info.v11.5.txt",
		        "node_list_path": "1210068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OpitutaceaeBacteriumTav4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TAV4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OpitutaceaeBacteriumTav4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "278959.protein.sequences.v11.5.fa",
		        "enrichment_path": "278959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "278959.protein.info.v11.5.txt",
		        "node_list_path": "278959.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColibacterMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colibacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColibacterMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1852379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852379.protein.info.v11.5.txt",
		        "node_list_path": "1852379.protein.complete.v11.5.txt"
		    }
		]
    )()

def UnculturedRoseburiaSpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Roseburia sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedRoseburiaSpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "512314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "512314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "512314.clusters.proteins.v11.5.txt",
		        "sequence_path": "512314.protein.sequences.v11.5.fa",
		        "enrichment_path": "512314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512314.protein.info.v11.5.txt",
		        "node_list_path": "512314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "512314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumHtcc2148Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2148Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "247634.clusters.info.v11.0.txt",
		        "cluster_tree_path": "247634.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "247634.clusters.proteins.v11.0.txt",
		        "sequence_path": "247634.protein.sequences.v11.0.fa",
		        "enrichment_path": "247634.protein.enrichment.terms.v11.0.txt",
		        "info_path": "247634.protein.info.v11.0.txt",
		        "node_list_path": "247634.cluster.nodes.v11.0.txt",
		        "edge_list_path": "247634.protein.cluster.v11.0.txt"
		    }
		]
    )()

def PhaeobacterSpCect5382(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter sp. CECT 5382 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterSpCect5382", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1712645.protein.sequences.v11.5.fa",
		        "enrichment_path": "1712645.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1712645.protein.info.v11.5.txt",
		        "node_list_path": "1712645.protein.complete.v11.5.txt"
		    }
		]
    )()

def DevosiaSpLeaf420(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia sp. Leaf420 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaSpLeaf420", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736374.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736374.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736374.protein.info.v11.5.txt",
		        "node_list_path": "1736374.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrankiaSpCn3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. CN3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpCn3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "298655.protein.sequences.v11.5.fa",
		        "enrichment_path": "298655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "298655.protein.info.v11.5.txt",
		        "node_list_path": "298655.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterDaejeonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter daejeonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterDaejeonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385517.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385517.protein.info.v11.5.txt",
		        "node_list_path": "1385517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MuricaudaRuestringensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Muricauda ruestringensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MuricaudaRuestringensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "886377.protein.sequences.v11.5.fa",
		        "enrichment_path": "886377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "886377.protein.info.v11.5.txt",
		        "node_list_path": "886377.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodovulumSpP5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. P5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovulumSpP5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1564506.protein.sequences.v11.5.fa",
		        "enrichment_path": "1564506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1564506.protein.info.v11.5.txt",
		        "node_list_path": "1564506.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionZixibacteriaBacteriumRbg16439(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium RBG_16_43_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumRbg16439", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802784.protein.info.v11.5.txt",
		        "node_list_path": "1802784.protein.complete.v11.5.txt"
		    }
		]
    )()

def HymenobacterSedentarius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sedentarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSedentarius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1411621.protein.sequences.v11.5.fa",
		        "enrichment_path": "1411621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1411621.protein.info.v11.5.txt",
		        "node_list_path": "1411621.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumNk3b98(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium NK3B98 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumNk3b98", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "877414.protein.sequences.v11.5.fa",
		        "enrichment_path": "877414.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877414.protein.info.v11.5.txt",
		        "node_list_path": "877414.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasFloridensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas floridensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasFloridensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1843580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1843580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1843580.protein.info.v11.5.txt",
		        "node_list_path": "1843580.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfuromonasSpTf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfuromonas sp. TF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfuromonasSpTf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232410.protein.info.v11.5.txt",
		        "node_list_path": "1232410.protein.complete.v11.5.txt"
		    }
		]
    )()

def OchrobactrumRhizosphaerae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OchrobactrumRhizosphaerae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437448.protein.info.v11.5.txt",
		        "node_list_path": "1437448.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorchorusCapsularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corchorus capsularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorchorusCapsularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "210143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "210143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "210143.clusters.proteins.v11.5.txt",
		        "sequence_path": "210143.protein.sequences.v11.5.fa",
		        "enrichment_path": "210143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "210143.protein.info.v11.5.txt",
		        "node_list_path": "210143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "210143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaHoronobensisHb1Jcm15518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina horonobensis HB-1 JCM 15518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaHoronobensisHb1Jcm15518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434110.protein.info.v11.5.txt",
		        "node_list_path": "1434110.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwa14423Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_44_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa14423Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618558.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618558.protein.info.v11.5.txt",
		        "node_list_path": "1618558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrametesCoccineaBrfm310Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trametes coccinea BRFM310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrametesCoccineaBrfm310Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1353009.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1353009.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1353009.clusters.proteins.v11.5.txt",
		        "sequence_path": "1353009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353009.protein.info.v11.5.txt",
		        "node_list_path": "1353009.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1353009.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SarcophilusHarrisii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sarcophilus harrisii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SarcophilusHarrisii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9305.protein.sequences.v11.5.fa",
		        "enrichment_path": "9305.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9305.protein.info.v11.5.txt",
		        "node_list_path": "9305.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorvusBrachyrhynchos(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corvus brachyrhynchos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorvusBrachyrhynchos", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "85066.protein.sequences.v11.5.fa",
		        "enrichment_path": "85066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85066.protein.info.v11.5.txt",
		        "node_list_path": "85066.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg166485Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_64_85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg166485Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797846.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797846.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797846.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797846.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797846.protein.info.v11.5.txt",
		        "node_list_path": "1797846.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797846.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanobacteriumSpPcc7702Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Cyanobacterium sp. PCC7702 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "CyanobacteriumSpPcc7702Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173021.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1173021.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1173021.clusters.proteins.v11.0.txt",
		        "sequence_path": "1173021.protein.sequences.v11.0.fa",
		        "enrichment_path": "1173021.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1173021.protein.info.v11.0.txt",
		        "node_list_path": "1173021.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1173021.protein.cluster.v11.0.txt"
		    }
		]
    )()

def CandidatusTerrybacteriaBacteriumRifcsplowo2024220Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPLOWO2_02_42_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsplowo2024220Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802370.protein.info.v11.5.txt",
		        "node_list_path": "1802370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSpBv3c26(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. BV3C26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSpBv3c26", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111134.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111134.protein.info.v11.5.txt",
		        "node_list_path": "1111134.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaSpongiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina spongiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaSpongiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "570521.protein.sequences.v11.5.fa",
		        "enrichment_path": "570521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570521.protein.info.v11.5.txt",
		        "node_list_path": "570521.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterPiechaudiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter piechaudii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterPiechaudiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945521.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945521.protein.info.v11.5.txt",
		        "node_list_path": "1945521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicroscillaMarinaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microscilla marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicroscillaMarinaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "313606.clusters.info.v11.5.txt",
		        "cluster_tree_path": "313606.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "313606.clusters.proteins.v11.5.txt",
		        "sequence_path": "313606.protein.sequences.v11.5.fa",
		        "enrichment_path": "313606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "313606.protein.info.v11.5.txt",
		        "node_list_path": "313606.cluster.nodes.v11.5.txt",
		        "edge_list_path": "313606.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionTm6BacteriumRifcsphigho212Full3622(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium RIFCSPHIGHO2_12_FULL_36_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionTm6BacteriumRifcsphigho212Full3622", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802376.protein.info.v11.5.txt",
		        "node_list_path": "1802376.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpKpl1986Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1986 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpKpl1986Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203619.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203619.protein.info.v11.5.txt",
		        "node_list_path": "1203619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DonghicolaXiamenensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Donghicola xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DonghicolaXiamenensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121479.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121479.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121479.protein.info.v11.5.txt",
		        "node_list_path": "1121479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumSpCag274(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:274 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSpCag274", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262888.protein.info.v11.5.txt",
		        "node_list_path": "1262888.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp150fbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 150FB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp150fbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1576605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1576605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1576605.clusters.proteins.v11.5.txt",
		        "sequence_path": "1576605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1576605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1576605.protein.info.v11.5.txt",
		        "node_list_path": "1576605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1576605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanoculleusMarisnigriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus marisnigri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusMarisnigriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "368407.clusters.info.v11.5.txt",
		        "cluster_tree_path": "368407.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "368407.clusters.proteins.v11.5.txt",
		        "sequence_path": "368407.protein.sequences.v11.5.fa",
		        "enrichment_path": "368407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "368407.protein.info.v11.5.txt",
		        "node_list_path": "368407.cluster.nodes.v11.5.txt",
		        "edge_list_path": "368407.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HugenholtziaRoseolaDsm9546Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hugenholtzia roseola DSM 9546 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HugenholtziaRoseolaDsm9546Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121903.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121903.protein.info.v11.5.txt",
		        "node_list_path": "1121903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaAbyssalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina abyssalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaAbyssalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "86102.protein.sequences.v11.5.fa",
		        "enrichment_path": "86102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "86102.protein.info.v11.5.txt",
		        "node_list_path": "86102.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaeroglobusGeminatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaeroglobus geminatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeroglobusGeminatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "861450.protein.sequences.v11.5.fa",
		        "enrichment_path": "861450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861450.protein.info.v11.5.txt",
		        "node_list_path": "861450.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpGxt6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. GXT6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpGxt6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "711393.clusters.info.v11.5.txt",
		        "cluster_tree_path": "711393.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "711393.clusters.proteins.v11.5.txt",
		        "sequence_path": "711393.protein.sequences.v11.5.fa",
		        "enrichment_path": "711393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "711393.protein.info.v11.5.txt",
		        "node_list_path": "711393.cluster.nodes.v11.5.txt",
		        "edge_list_path": "711393.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusSclerotialisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sclerotialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusSclerotialisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2070753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2070753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2070753.clusters.proteins.v11.5.txt",
		        "sequence_path": "2070753.protein.sequences.v11.5.fa",
		        "enrichment_path": "2070753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2070753.protein.info.v11.5.txt",
		        "node_list_path": "2070753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2070753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMarinimicrobiaBacteriumCg1024814Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Marinimicrobia bacterium CG1_02_48_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMarinimicrobiaBacteriumCg1024814Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805240.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805240.protein.info.v11.5.txt",
		        "node_list_path": "1805240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OnchocercaVolvulus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Onchocerca volvulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OnchocercaVolvulus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6282.protein.sequences.v11.5.fa",
		        "enrichment_path": "6282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6282.protein.info.v11.5.txt",
		        "node_list_path": "6282.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoprobacillusSp291(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus sp. 291 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprobacillusSp291", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469596.protein.sequences.v11.5.fa",
		        "enrichment_path": "469596.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469596.protein.info.v11.5.txt",
		        "node_list_path": "469596.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasTranslucensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas translucens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasTranslucensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1205753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1205753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1205753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1205753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1205753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1205753.protein.info.v11.5.txt",
		        "node_list_path": "1205753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1205753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaribacterReichenbachii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter reichenbachii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterReichenbachii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "996801.protein.sequences.v11.5.fa",
		        "enrichment_path": "996801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "996801.protein.info.v11.5.txt",
		        "node_list_path": "996801.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermusSpCcbus3uf1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus sp. CCBUS3UF1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusSpCcbus3uf1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111069.protein.info.v11.5.txt",
		        "node_list_path": "1111069.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusRuber(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusRuber", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1240349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1240349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1240349.protein.info.v11.5.txt",
		        "node_list_path": "1240349.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusEhimensisA2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ehimensis A2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusEhimensisA2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1444314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1444314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1444314.clusters.proteins.v11.5.txt",
		        "sequence_path": "1444314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444314.protein.info.v11.5.txt",
		        "node_list_path": "1444314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1444314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DrosophilaErecta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila erecta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DrosophilaErecta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7220.protein.sequences.v11.5.fa",
		        "enrichment_path": "7220.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7220.protein.info.v11.5.txt",
		        "node_list_path": "7220.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHarrisonbacteriaBacteriumRifcsphigho202Full4216(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPHIGHO2_02_FULL_42_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsphigho202Full4216", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798404.protein.info.v11.5.txt",
		        "node_list_path": "1798404.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpTv2a2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Tv2a2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpTv2a2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "113395.clusters.info.v11.5.txt",
		        "cluster_tree_path": "113395.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "113395.clusters.proteins.v11.5.txt",
		        "sequence_path": "113395.protein.sequences.v11.5.fa",
		        "enrichment_path": "113395.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113395.protein.info.v11.5.txt",
		        "node_list_path": "113395.cluster.nodes.v11.5.txt",
		        "edge_list_path": "113395.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptostreptococcusRussellii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus russellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptostreptococcusRussellii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "215200.protein.sequences.v11.5.fa",
		        "enrichment_path": "215200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "215200.protein.info.v11.5.txt",
		        "node_list_path": "215200.protein.complete.v11.5.txt"
		    }
		]
    )()

def GilvimarinusAgarilyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gilvimarinus agarilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GilvimarinusAgarilyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679259.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679259.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679259.clusters.proteins.v11.5.txt",
		        "sequence_path": "679259.protein.sequences.v11.5.fa",
		        "enrichment_path": "679259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679259.protein.info.v11.5.txt",
		        "node_list_path": "679259.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679259.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrochothrixThermosphactaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brochothrix thermosphacta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrochothrixThermosphactaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2756.clusters.proteins.v11.5.txt",
		        "sequence_path": "2756.protein.sequences.v11.5.fa",
		        "enrichment_path": "2756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2756.protein.info.v11.5.txt",
		        "node_list_path": "2756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumGwa23526(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium GWA2_35_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumGwa23526", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798013.protein.info.v11.5.txt",
		        "node_list_path": "1798013.protein.complete.v11.5.txt"
		    }
		]
    )()

def JeotgalicoccusMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalicoccus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JeotgalicoccusMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122128.protein.info.v11.5.txt",
		        "node_list_path": "1122128.protein.complete.v11.5.txt"
		    }
		]
    )()

def AdlercreutziaEquolifaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Adlercreutzia equolifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AdlercreutziaEquolifaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1384484.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1384484.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1384484.clusters.proteins.v11.5.txt",
		        "sequence_path": "1384484.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384484.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384484.protein.info.v11.5.txt",
		        "node_list_path": "1384484.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1384484.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumScgcAaa164E04(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium SCGC AAA164-E04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumScgcAaa164E04", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1009415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1009415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1009415.protein.info.v11.5.txt",
		        "node_list_path": "1009415.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpLeaf334(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Leaf334 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpLeaf334", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736339.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736339.protein.info.v11.5.txt",
		        "node_list_path": "1736339.protein.complete.v11.5.txt"
		    }
		]
    )()

def DysgonomonasCapnocytophagoidesDsm22835Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas capnocytophagoides DSM 22835 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasCapnocytophagoidesDsm22835Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121485.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121485.protein.info.v11.5.txt",
		        "node_list_path": "1121485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaCinaraConfinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara confinis) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaCinaraConfinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1878935.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1878935.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1878935.clusters.proteins.v11.5.txt",
		        "sequence_path": "1878935.protein.sequences.v11.5.fa",
		        "enrichment_path": "1878935.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1878935.protein.info.v11.5.txt",
		        "node_list_path": "1878935.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1878935.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpMs1601(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. MS1601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpMs1601", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1936029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1936029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1936029.protein.info.v11.5.txt",
		        "node_list_path": "1936029.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonRbg13389Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_38_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg13389Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797377.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797377.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797377.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797377.protein.info.v11.5.txt",
		        "node_list_path": "1797377.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797377.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaFicariaNbrc102596(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia ficaria NBRC 102596 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaFicariaNbrc102596", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1411141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1411141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1411141.protein.info.v11.5.txt",
		        "node_list_path": "1411141.protein.complete.v11.5.txt"
		    }
		]
    )()

def LepidothrixCoronata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lepidothrix coronata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LepidothrixCoronata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "321398.protein.sequences.v11.5.fa",
		        "enrichment_path": "321398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321398.protein.info.v11.5.txt",
		        "node_list_path": "321398.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloracidobacteriumThermophilumB(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloracidobacterium thermophilum B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloracidobacteriumThermophilumB", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "981222.protein.sequences.v11.5.fa",
		        "enrichment_path": "981222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981222.protein.info.v11.5.txt",
		        "node_list_path": "981222.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesVariegatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces variegatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesVariegatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "284040.clusters.info.v11.5.txt",
		        "cluster_tree_path": "284040.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "284040.clusters.proteins.v11.5.txt",
		        "sequence_path": "284040.protein.sequences.v11.5.fa",
		        "enrichment_path": "284040.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284040.protein.info.v11.5.txt",
		        "node_list_path": "284040.cluster.nodes.v11.5.txt",
		        "edge_list_path": "284040.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KiritimatiellaGlycovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kiritimatiella glycovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KiritimatiellaGlycovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1307763.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1307763.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1307763.clusters.proteins.v11.5.txt",
		        "sequence_path": "1307763.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307763.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307763.protein.info.v11.5.txt",
		        "node_list_path": "1307763.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1307763.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StappiaStellulataDsm5886Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stappia stellulata DSM 5886 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StappiaStellulataDsm5886Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123294.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123294.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123294.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123294.protein.info.v11.5.txt",
		        "node_list_path": "1123294.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123294.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacterium688(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 68-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacterium688", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895817.protein.info.v11.5.txt",
		        "node_list_path": "1895817.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusArsenophonusLipoptenae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arsenophonus lipoptenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusArsenophonusLipoptenae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634113.protein.sequences.v11.5.fa",
		        "enrichment_path": "634113.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634113.protein.info.v11.5.txt",
		        "node_list_path": "634113.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumOlb14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumOlb14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1617415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617415.protein.info.v11.5.txt",
		        "node_list_path": "1617415.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbiconiuxSolaniNbrc106740Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbiconiux solani NBRC 106740 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbiconiuxSolaniNbrc106740Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220584.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220584.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220584.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220584.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220584.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220584.protein.info.v11.5.txt",
		        "node_list_path": "1220584.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220584.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotodesmusBlepharusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photodesmus blepharus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotodesmusBlepharusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1179155.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1179155.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1179155.clusters.proteins.v11.5.txt",
		        "sequence_path": "1179155.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179155.protein.info.v11.5.txt",
		        "node_list_path": "1179155.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1179155.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErysipelotrichaceaeBacteriumNk3d112Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium NK3D112 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErysipelotrichaceaeBacteriumNk3d112Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "877415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "877415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "877415.clusters.proteins.v11.5.txt",
		        "sequence_path": "877415.protein.sequences.v11.5.fa",
		        "enrichment_path": "877415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877415.protein.info.v11.5.txt",
		        "node_list_path": "877415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "877415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanolobusSpT824Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus sp. T82-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanolobusSpT824Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1794908.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1794908.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1794908.clusters.proteins.v11.5.txt",
		        "sequence_path": "1794908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1794908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1794908.protein.info.v11.5.txt",
		        "node_list_path": "1794908.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1794908.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMycoplasmaHaemominutumBirmingham1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemominutum Birmingham 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMycoplasmaHaemominutumBirmingham1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1116213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116213.protein.info.v11.5.txt",
		        "node_list_path": "1116213.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpM143Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. M143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpM143Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "563037.clusters.info.v11.5.txt",
		        "cluster_tree_path": "563037.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "563037.clusters.proteins.v11.5.txt",
		        "sequence_path": "563037.protein.sequences.v11.5.fa",
		        "enrichment_path": "563037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563037.protein.info.v11.5.txt",
		        "node_list_path": "563037.cluster.nodes.v11.5.txt",
		        "edge_list_path": "563037.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EpibacteriumMobileF1926Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Epibacterium mobile F1926 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpibacteriumMobileF1926Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265309.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265309.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265309.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265309.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265309.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265309.protein.info.v11.5.txt",
		        "node_list_path": "1265309.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265309.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusSp2009Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. 2009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusSp2009Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "684949.clusters.info.v11.5.txt",
		        "cluster_tree_path": "684949.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "684949.clusters.proteins.v11.5.txt",
		        "sequence_path": "684949.protein.sequences.v11.5.fa",
		        "enrichment_path": "684949.protein.enrichment.terms.v11.5.txt",
		        "info_path": "684949.protein.info.v11.5.txt",
		        "node_list_path": "684949.cluster.nodes.v11.5.txt",
		        "edge_list_path": "684949.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacteriumGa0077551(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0077551 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacteriumGa0077551", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752185.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752185.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752185.protein.info.v11.5.txt",
		        "node_list_path": "1752185.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeishmaniaInfantum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leishmania infantum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeishmaniaInfantum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5671.protein.sequences.v11.5.fa",
		        "enrichment_path": "5671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5671.protein.info.v11.5.txt",
		        "node_list_path": "5671.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaloranaerobacterFerrireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caloranaerobacter ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaloranaerobacterFerrireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1323370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1323370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1323370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1323370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1323370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1323370.protein.info.v11.5.txt",
		        "node_list_path": "1323370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1323370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaSiciliaeC2jCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina siciliae C2J Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaSiciliaeC2jCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1434118.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1434118.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1434118.clusters.proteins.v11.5.txt",
		        "sequence_path": "1434118.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434118.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434118.protein.info.v11.5.txt",
		        "node_list_path": "1434118.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1434118.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TaylorellaEquigenitalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Taylorella equigenitalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TaylorellaEquigenitalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "937774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "937774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "937774.clusters.proteins.v11.5.txt",
		        "sequence_path": "937774.protein.sequences.v11.5.fa",
		        "enrichment_path": "937774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "937774.protein.info.v11.5.txt",
		        "node_list_path": "937774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "937774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusFaecimarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus faecimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusFaecimarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "686796.clusters.info.v11.5.txt",
		        "cluster_tree_path": "686796.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "686796.clusters.proteins.v11.5.txt",
		        "sequence_path": "686796.protein.sequences.v11.5.fa",
		        "enrichment_path": "686796.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686796.protein.info.v11.5.txt",
		        "node_list_path": "686796.cluster.nodes.v11.5.txt",
		        "edge_list_path": "686796.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LysobacterEnzymogenesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter enzymogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterEnzymogenesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69.clusters.proteins.v11.5.txt",
		        "sequence_path": "69.protein.sequences.v11.5.fa",
		        "enrichment_path": "69.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69.protein.info.v11.5.txt",
		        "node_list_path": "69.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcholeplasmaAxanthum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma axanthum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcholeplasmaAxanthum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278311.protein.info.v11.5.txt",
		        "node_list_path": "1278311.protein.complete.v11.5.txt"
		    }
		]
    )()

def RegiellaInsecticola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Regiella insecticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RegiellaInsecticola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "663321.protein.sequences.v11.5.fa",
		        "enrichment_path": "663321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663321.protein.info.v11.5.txt",
		        "node_list_path": "663321.protein.complete.v11.5.txt"
		    }
		]
    )()

def DoreaSp428(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dorea sp. 42_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DoreaSp428", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896999.protein.info.v11.5.txt",
		        "node_list_path": "1896999.protein.complete.v11.5.txt"
		    }
		]
    )()

def TypeBSymbiontOfPlautiaStali(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Type-B symbiont of Plautia stali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TypeBSymbiontOfPlautiaStali", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1560354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1560354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1560354.protein.info.v11.5.txt",
		        "node_list_path": "1560354.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerostipesHadrusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerostipes hadrus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerostipesHadrusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649756.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649756.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649756.clusters.proteins.v11.5.txt",
		        "sequence_path": "649756.protein.sequences.v11.5.fa",
		        "enrichment_path": "649756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649756.protein.info.v11.5.txt",
		        "node_list_path": "649756.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649756.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NanohaloarchaeaArchaeonB1Br10U2g19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon B1-Br10_U2g19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NanohaloarchaeaArchaeonB1Br10U2g19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729454.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729454.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729454.protein.info.v11.5.txt",
		        "node_list_path": "1729454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusWasatchensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus wasatchensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusWasatchensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1335616.protein.sequences.v11.5.fa",
		        "enrichment_path": "1335616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1335616.protein.info.v11.5.txt",
		        "node_list_path": "1335616.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusPobuzihiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pobuzihii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusPobuzihiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "449659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "449659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "449659.clusters.proteins.v11.5.txt",
		        "sequence_path": "449659.protein.sequences.v11.5.fa",
		        "enrichment_path": "449659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "449659.protein.info.v11.5.txt",
		        "node_list_path": "449659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "449659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacteriaBacteriumRifcsphigho202Full4916(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_02_FULL_49_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho202Full4916", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801918.protein.info.v11.5.txt",
		        "node_list_path": "1801918.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrancisellaSpFsc1006(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella sp. FSC1006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaSpFsc1006", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1547445.protein.sequences.v11.5.fa",
		        "enrichment_path": "1547445.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1547445.protein.info.v11.5.txt",
		        "node_list_path": "1547445.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPunonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas punonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPunonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220495.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220495.protein.info.v11.5.txt",
		        "node_list_path": "1220495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MusaAcuminataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Musa acuminata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MusaAcuminataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4641.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4641.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4641.clusters.proteins.v11.5.txt",
		        "sequence_path": "4641.protein.sequences.v11.5.fa",
		        "enrichment_path": "4641.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4641.protein.info.v11.5.txt",
		        "node_list_path": "4641.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4641.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusLutraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lutrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusLutraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "155085.clusters.info.v11.5.txt",
		        "cluster_tree_path": "155085.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "155085.clusters.proteins.v11.5.txt",
		        "sequence_path": "155085.protein.sequences.v11.5.fa",
		        "enrichment_path": "155085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "155085.protein.info.v11.5.txt",
		        "node_list_path": "155085.cluster.nodes.v11.5.txt",
		        "edge_list_path": "155085.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacterium6eCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium 6E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacterium6eCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1688776.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1688776.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1688776.clusters.proteins.v11.5.txt",
		        "sequence_path": "1688776.protein.sequences.v11.5.fa",
		        "enrichment_path": "1688776.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1688776.protein.info.v11.5.txt",
		        "node_list_path": "1688776.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1688776.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusShackletonii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus shackletonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusShackletonii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "157838.protein.sequences.v11.5.fa",
		        "enrichment_path": "157838.protein.enrichment.terms.v11.5.txt",
		        "info_path": "157838.protein.info.v11.5.txt",
		        "node_list_path": "157838.protein.complete.v11.5.txt"
		    }
		]
    )()

def DefluviimonasAlba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Defluviimonas alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DefluviimonasAlba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1335048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1335048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1335048.protein.info.v11.5.txt",
		        "node_list_path": "1335048.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_54_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802390.protein.info.v11.5.txt",
		        "node_list_path": "1802390.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumMagneticumAmb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum magneticum AMB-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumMagneticumAmb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "342108.protein.sequences.v11.5.fa",
		        "enrichment_path": "342108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342108.protein.info.v11.5.txt",
		        "node_list_path": "342108.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporolituusThermophilusDsm23256(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporolituus thermophilus DSM 23256 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporolituusThermophilusDsm23256", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123285.protein.info.v11.5.txt",
		        "node_list_path": "1123285.protein.complete.v11.5.txt"
		    }
		]
    )()

def RalstoniaSpPbaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. PBA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSpPbaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "795666.clusters.info.v11.5.txt",
		        "cluster_tree_path": "795666.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "795666.clusters.proteins.v11.5.txt",
		        "sequence_path": "795666.protein.sequences.v11.5.fa",
		        "enrichment_path": "795666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "795666.protein.info.v11.5.txt",
		        "node_list_path": "795666.cluster.nodes.v11.5.txt",
		        "edge_list_path": "795666.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachanceaFermentati(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachancea fermentati graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachanceaFermentati", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4955.protein.sequences.v11.5.fa",
		        "enrichment_path": "4955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4955.protein.info.v11.5.txt",
		        "node_list_path": "4955.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychroflexusHalocaseiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychroflexus halocasei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychroflexusHalocaseiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "908615.clusters.info.v11.5.txt",
		        "cluster_tree_path": "908615.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "908615.clusters.proteins.v11.5.txt",
		        "sequence_path": "908615.protein.sequences.v11.5.fa",
		        "enrichment_path": "908615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908615.protein.info.v11.5.txt",
		        "node_list_path": "908615.cluster.nodes.v11.5.txt",
		        "edge_list_path": "908615.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPolymyxa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPolymyxa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1406.protein.sequences.v11.5.fa",
		        "enrichment_path": "1406.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1406.protein.info.v11.5.txt",
		        "node_list_path": "1406.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrisomaLimi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrisoma limi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrisomaLimi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1185876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185876.protein.info.v11.5.txt",
		        "node_list_path": "1185876.protein.complete.v11.5.txt"
		    }
		]
    )()

def HoldemaniaMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Holdemania massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HoldemaniaMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211819.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211819.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211819.protein.info.v11.5.txt",
		        "node_list_path": "1211819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAndersenbacteriaBacteriumRifcsphigho201Full4636(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Andersenbacteria bacterium RIFCSPHIGHO2_01_FULL_46_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAndersenbacteriaBacteriumRifcsphigho201Full4636", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797278.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797278.protein.info.v11.5.txt",
		        "node_list_path": "1797278.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpTab87(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. TAB 87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpTab87", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729581.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729581.protein.info.v11.5.txt",
		        "node_list_path": "1729581.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanospirillumLinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum linum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanospirillumLinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "966.protein.sequences.v11.5.fa",
		        "enrichment_path": "966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "966.protein.info.v11.5.txt",
		        "node_list_path": "966.protein.complete.v11.5.txt"
		    }
		]
    )()

def AhrensiaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ahrensia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AhrensiaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1514904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1514904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1514904.protein.info.v11.5.txt",
		        "node_list_path": "1514904.protein.complete.v11.5.txt"
		    }
		]
    )()

def MeiraMiltonrushii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Meira miltonrushii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiraMiltonrushii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1280837.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280837.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280837.protein.info.v11.5.txt",
		        "node_list_path": "1280837.protein.complete.v11.5.txt"
		    }
		]
    )()

def SulfurihydrogenibiumSpYo3aop1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium sp. YO3AOP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurihydrogenibiumSpYo3aop1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "436114.protein.sequences.v11.5.fa",
		        "enrichment_path": "436114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436114.protein.info.v11.5.txt",
		        "node_list_path": "436114.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAureofaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aureofaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAureofaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1894.protein.info.v11.5.txt",
		        "node_list_path": "1894.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumRadiotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium radiotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumRadiotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "426355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "426355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "426355.clusters.proteins.v11.5.txt",
		        "sequence_path": "426355.protein.sequences.v11.5.fa",
		        "enrichment_path": "426355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426355.protein.info.v11.5.txt",
		        "node_list_path": "426355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "426355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumTrichothecenolyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium trichothecenolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumTrichothecenolyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69370.clusters.proteins.v11.5.txt",
		        "sequence_path": "69370.protein.sequences.v11.5.fa",
		        "enrichment_path": "69370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69370.protein.info.v11.5.txt",
		        "node_list_path": "69370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpYr710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. YR710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpYr710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882773.protein.info.v11.5.txt",
		        "node_list_path": "1882773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoruegeriaSpSk021Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoruegeria sp. SK021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoruegeriaSpSk021Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1933035.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1933035.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1933035.clusters.proteins.v11.5.txt",
		        "sequence_path": "1933035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933035.protein.info.v11.5.txt",
		        "node_list_path": "1933035.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1933035.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumDegerlacheiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium degerlachei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumDegerlacheiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "229203.clusters.info.v11.5.txt",
		        "cluster_tree_path": "229203.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "229203.clusters.proteins.v11.5.txt",
		        "sequence_path": "229203.protein.sequences.v11.5.fa",
		        "enrichment_path": "229203.protein.enrichment.terms.v11.5.txt",
		        "info_path": "229203.protein.info.v11.5.txt",
		        "node_list_path": "229203.cluster.nodes.v11.5.txt",
		        "edge_list_path": "229203.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubidibacterLacunaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubidibacter lacunae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubidibacterLacunaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "582515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "582515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "582515.clusters.proteins.v11.5.txt",
		        "sequence_path": "582515.protein.sequences.v11.5.fa",
		        "enrichment_path": "582515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "582515.protein.info.v11.5.txt",
		        "node_list_path": "582515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "582515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EikenellaCorrodensAtcc23834Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eikenella corrodens ATCC23834 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EikenellaCorrodensAtcc23834Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546274.clusters.proteins.v11.5.txt",
		        "sequence_path": "546274.protein.sequences.v11.5.fa",
		        "enrichment_path": "546274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546274.protein.info.v11.5.txt",
		        "node_list_path": "546274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrobaculumCalidifontisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum calidifontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumCalidifontisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "410359.clusters.info.v11.5.txt",
		        "cluster_tree_path": "410359.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "410359.clusters.proteins.v11.5.txt",
		        "sequence_path": "410359.protein.sequences.v11.5.fa",
		        "enrichment_path": "410359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "410359.protein.info.v11.5.txt",
		        "node_list_path": "410359.cluster.nodes.v11.5.txt",
		        "edge_list_path": "410359.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FischerellaSpPcc9339(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9339 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FischerellaSpPcc9339", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1174528.protein.sequences.v11.5.fa",
		        "enrichment_path": "1174528.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1174528.protein.info.v11.5.txt",
		        "node_list_path": "1174528.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScytonemaTolypothrichoidesVb61278(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scytonema tolypothrichoides VB-61278 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScytonemaTolypothrichoidesVb61278", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1233231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1233231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1233231.protein.info.v11.5.txt",
		        "node_list_path": "1233231.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSuisR61(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis R61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSuisR61", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "996306.protein.sequences.v11.5.fa",
		        "enrichment_path": "996306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "996306.protein.info.v11.5.txt",
		        "node_list_path": "996306.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermococcusOnnurineus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus onnurineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusOnnurineus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "523850.protein.sequences.v11.5.fa",
		        "enrichment_path": "523850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523850.protein.info.v11.5.txt",
		        "node_list_path": "523850.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpH105(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. H105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpH105", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348393.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348393.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348393.protein.info.v11.5.txt",
		        "node_list_path": "1348393.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusDisparCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus dispar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusDisparCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1139219.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1139219.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1139219.clusters.proteins.v11.5.txt",
		        "sequence_path": "1139219.protein.sequences.v11.5.fa",
		        "enrichment_path": "1139219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1139219.protein.info.v11.5.txt",
		        "node_list_path": "1139219.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1139219.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpE2479(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2479 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpE2479", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834134.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834134.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834134.protein.info.v11.5.txt",
		        "node_list_path": "1834134.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanocellaArvoryzaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocella arvoryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocellaArvoryzaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351160.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351160.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351160.clusters.proteins.v11.5.txt",
		        "sequence_path": "351160.protein.sequences.v11.5.fa",
		        "enrichment_path": "351160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351160.protein.info.v11.5.txt",
		        "node_list_path": "351160.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351160.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumAlamiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium alamii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumAlamiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "492774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "492774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "492774.clusters.proteins.v11.5.txt",
		        "sequence_path": "492774.protein.sequences.v11.5.fa",
		        "enrichment_path": "492774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "492774.protein.info.v11.5.txt",
		        "node_list_path": "492774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "492774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaNoatunensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella noatunensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaNoatunensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163389.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1163389.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1163389.clusters.proteins.v11.5.txt",
		        "sequence_path": "1163389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163389.protein.info.v11.5.txt",
		        "node_list_path": "1163389.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1163389.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpMwb1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. MWB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpMwb1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1537715.protein.sequences.v11.5.fa",
		        "enrichment_path": "1537715.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1537715.protein.info.v11.5.txt",
		        "node_list_path": "1537715.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumGw2011Gwf24317Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_43_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf24317Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619068.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619068.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619068.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619068.protein.info.v11.5.txt",
		        "node_list_path": "1619068.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619068.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpLeaf104(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf104 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpLeaf104", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736254.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736254.protein.info.v11.5.txt",
		        "node_list_path": "1736254.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHydrothermaeBacteriumJdfr72(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrothermae bacterium JdFR-72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHydrothermaeBacteriumJdfr72", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1935123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935123.protein.info.v11.5.txt",
		        "node_list_path": "1935123.protein.complete.v11.5.txt"
		    }
		]
    )()

def OleispiraAntarcticaRb8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oleispira antarctica RB-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OleispiraAntarcticaRb8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "698738.protein.sequences.v11.5.fa",
		        "enrichment_path": "698738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698738.protein.info.v11.5.txt",
		        "node_list_path": "698738.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterTrogontumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter trogontum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterTrogontumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "50960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "50960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "50960.clusters.proteins.v11.5.txt",
		        "sequence_path": "50960.protein.sequences.v11.5.fa",
		        "enrichment_path": "50960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "50960.protein.info.v11.5.txt",
		        "node_list_path": "50960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "50960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumCiceriCa181(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium ciceri ca181 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumCiceriCa181", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "682633.protein.sequences.v11.5.fa",
		        "enrichment_path": "682633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "682633.protein.info.v11.5.txt",
		        "node_list_path": "682633.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusBuchneriNrrlb30929(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri NRRLB30929 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusBuchneriNrrlb30929", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "511437.protein.sequences.v11.5.fa",
		        "enrichment_path": "511437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511437.protein.info.v11.5.txt",
		        "node_list_path": "511437.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumGw2011Gwc2489Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium GW2011_GWC2_48_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumGw2011Gwc2489Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619071.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619071.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619071.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619071.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619071.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619071.protein.info.v11.5.txt",
		        "node_list_path": "1619071.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619071.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag10605727Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:1060_57_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag10605727Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896975.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896975.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896975.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896975.protein.info.v11.5.txt",
		        "node_list_path": "1896975.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896975.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumYurii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium yurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumYurii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "864565.protein.sequences.v11.5.fa",
		        "enrichment_path": "864565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864565.protein.info.v11.5.txt",
		        "node_list_path": "864565.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrialbaceaeArchaeonB1Br10E2g2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon B1-Br10_E2g2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaceaeArchaeonB1Br10E2g2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1729458.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1729458.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1729458.clusters.proteins.v11.5.txt",
		        "sequence_path": "1729458.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729458.protein.info.v11.5.txt",
		        "node_list_path": "1729458.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1729458.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacteriumSenegalense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium senegalense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacteriumSenegalense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033736.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033736.protein.info.v11.5.txt",
		        "node_list_path": "1033736.protein.complete.v11.5.txt"
		    }
		]
    )()

def GranulicellaPectinivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Granulicella pectinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GranulicellaPectinivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "474950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "474950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "474950.clusters.proteins.v11.5.txt",
		        "sequence_path": "474950.protein.sequences.v11.5.fa",
		        "enrichment_path": "474950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "474950.protein.info.v11.5.txt",
		        "node_list_path": "474950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "474950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusNantensisDsm16982(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nantensis DSM 16982 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusNantensisDsm16982", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423774.protein.info.v11.5.txt",
		        "node_list_path": "1423774.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasJeddahensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas jeddahensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasJeddahensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1915074.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1915074.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1915074.clusters.proteins.v11.5.txt",
		        "sequence_path": "1915074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1915074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1915074.protein.info.v11.5.txt",
		        "node_list_path": "1915074.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1915074.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaMelliferumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma melliferum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaMelliferumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1129368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1129368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1129368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1129368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1129368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1129368.protein.info.v11.5.txt",
		        "node_list_path": "1129368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1129368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpFc2011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. FC2011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpFc2011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408311.protein.info.v11.5.txt",
		        "node_list_path": "1408311.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumKutscheri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium kutscheri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumKutscheri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "35755.protein.sequences.v11.5.fa",
		        "enrichment_path": "35755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "35755.protein.info.v11.5.txt",
		        "node_list_path": "35755.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenisporosarcinaIndicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenisporosarcina indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenisporosarcinaIndicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "650093.clusters.info.v11.5.txt",
		        "cluster_tree_path": "650093.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "650093.clusters.proteins.v11.5.txt",
		        "sequence_path": "650093.protein.sequences.v11.5.fa",
		        "enrichment_path": "650093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "650093.protein.info.v11.5.txt",
		        "node_list_path": "650093.cluster.nodes.v11.5.txt",
		        "edge_list_path": "650093.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCf046Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. cf046 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCf046Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761803.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761803.protein.info.v11.5.txt",
		        "node_list_path": "1761803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusPauculus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus pauculus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusPauculus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "82633.protein.sequences.v11.5.fa",
		        "enrichment_path": "82633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82633.protein.info.v11.5.txt",
		        "node_list_path": "82633.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisBisa53Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisA53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisBisa53Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316055.clusters.proteins.v11.5.txt",
		        "sequence_path": "316055.protein.sequences.v11.5.fa",
		        "enrichment_path": "316055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316055.protein.info.v11.5.txt",
		        "node_list_path": "316055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesAureus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAureus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "193461.protein.sequences.v11.5.fa",
		        "enrichment_path": "193461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "193461.protein.info.v11.5.txt",
		        "node_list_path": "193461.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumCrh(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CRH graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumCrh", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1742859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1742859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1742859.protein.info.v11.5.txt",
		        "node_list_path": "1742859.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoxanthomonasSuwonensisJ43Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis J43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoxanthomonasSuwonensisJ43Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935567.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935567.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935567.clusters.proteins.v11.5.txt",
		        "sequence_path": "935567.protein.sequences.v11.5.fa",
		        "enrichment_path": "935567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935567.protein.info.v11.5.txt",
		        "node_list_path": "935567.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935567.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IntestinibacterBartlettiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Intestinibacter bartlettii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IntestinibacterBartlettiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445973.clusters.proteins.v11.5.txt",
		        "sequence_path": "445973.protein.sequences.v11.5.fa",
		        "enrichment_path": "445973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445973.protein.info.v11.5.txt",
		        "node_list_path": "445973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiumMinutumPei191(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobium minutum Pei191 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiumMinutumPei191", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445932.protein.sequences.v11.5.fa",
		        "enrichment_path": "445932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445932.protein.info.v11.5.txt",
		        "node_list_path": "445932.protein.complete.v11.5.txt"
		    }
		]
    )()

def DichantheliumOligosanthes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dichanthelium oligosanthes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DichantheliumOligosanthes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888268.protein.sequences.v11.5.fa",
		        "enrichment_path": "888268.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888268.protein.info.v11.5.txt",
		        "node_list_path": "888268.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumRifoxya2Full4118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYA2_FULL_41_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxya2Full4118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801904.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801904.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801904.protein.info.v11.5.txt",
		        "node_list_path": "1801904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChromatialesBacteriumUscgTaylorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chromatiales bacterium USCg_Taylor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChromatialesBacteriumUscgTaylorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1934255.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1934255.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1934255.clusters.proteins.v11.5.txt",
		        "sequence_path": "1934255.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934255.protein.info.v11.5.txt",
		        "node_list_path": "1934255.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1934255.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrogenophilaceaeBacteriumCg10262390Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophilaceae bacterium CG1_02_62_390 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophilaceaeBacteriumCg10262390Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805218.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805218.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805218.protein.info.v11.5.txt",
		        "node_list_path": "1805218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumGw2011Gwb24212Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_42_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24212Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618386.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618386.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618386.protein.info.v11.5.txt",
		        "node_list_path": "1618386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaDioxanivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia dioxanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaDioxanivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "675635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "675635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "675635.clusters.proteins.v11.5.txt",
		        "sequence_path": "675635.protein.sequences.v11.5.fa",
		        "enrichment_path": "675635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675635.protein.info.v11.5.txt",
		        "node_list_path": "675635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "675635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinactinosporaThermotoleransDsm45154Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinactinospora thermotolerans DSM 45154 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinactinosporaThermotoleransDsm45154Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122192.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122192.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122192.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122192.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122192.protein.info.v11.5.txt",
		        "node_list_path": "1122192.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122192.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusDuransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus durans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusDuransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1140001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1140001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1140001.clusters.proteins.v11.5.txt",
		        "sequence_path": "1140001.protein.sequences.v11.5.fa",
		        "enrichment_path": "1140001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1140001.protein.info.v11.5.txt",
		        "node_list_path": "1140001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1140001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanicaulisSpBbd199110Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. BBD 1991-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanicaulisSpBbd199110Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852617.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852617.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852617.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852617.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852617.protein.info.v11.5.txt",
		        "node_list_path": "1852617.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852617.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu083(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu083", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671660.protein.info.v11.5.txt",
		        "node_list_path": "1671660.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnophelesFarauti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles farauti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesFarauti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69004.protein.sequences.v11.5.fa",
		        "enrichment_path": "69004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69004.protein.info.v11.5.txt",
		        "node_list_path": "69004.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrnithinibacillusScapharcae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ornithinibacillus scapharcae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrnithinibacillusScapharcae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "981383.protein.sequences.v11.5.fa",
		        "enrichment_path": "981383.protein.enrichment.terms.v11.5.txt",
		        "info_path": "981383.protein.info.v11.5.txt",
		        "node_list_path": "981383.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpXt11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. XT11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpXt11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "367477.protein.sequences.v11.5.fa",
		        "enrichment_path": "367477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "367477.protein.info.v11.5.txt",
		        "node_list_path": "367477.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPohangensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pohangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPohangensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "364197.clusters.info.v11.5.txt",
		        "cluster_tree_path": "364197.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "364197.clusters.proteins.v11.5.txt",
		        "sequence_path": "364197.protein.sequences.v11.5.fa",
		        "enrichment_path": "364197.protein.enrichment.terms.v11.5.txt",
		        "info_path": "364197.protein.info.v11.5.txt",
		        "node_list_path": "364197.cluster.nodes.v11.5.txt",
		        "edge_list_path": "364197.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HymenobacterSpIs2118Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter sp. IS2118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HymenobacterSpIs2118Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1505605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1505605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1505605.clusters.proteins.v11.5.txt",
		        "sequence_path": "1505605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1505605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1505605.protein.info.v11.5.txt",
		        "node_list_path": "1505605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1505605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalorubrumAidingenseJcm13560Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum aidingense JCM 13560 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumAidingenseJcm13560Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1230454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1230454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1230454.clusters.proteins.v11.5.txt",
		        "sequence_path": "1230454.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230454.protein.info.v11.5.txt",
		        "node_list_path": "1230454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1230454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusAvium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus avium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusAvium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1140002.protein.sequences.v11.5.fa",
		        "enrichment_path": "1140002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1140002.protein.info.v11.5.txt",
		        "node_list_path": "1140002.protein.complete.v11.5.txt"
		    }
		]
    )()

def CordycepsJavanica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps javanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CordycepsJavanica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43265.protein.sequences.v11.5.fa",
		        "enrichment_path": "43265.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43265.protein.info.v11.5.txt",
		        "node_list_path": "43265.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacillusSuisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus suis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacillusSuisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "696748.clusters.info.v11.5.txt",
		        "cluster_tree_path": "696748.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "696748.clusters.proteins.v11.5.txt",
		        "sequence_path": "696748.protein.sequences.v11.5.fa",
		        "enrichment_path": "696748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696748.protein.info.v11.5.txt",
		        "node_list_path": "696748.cluster.nodes.v11.5.txt",
		        "edge_list_path": "696748.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProsthecomicrobiumHirschii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prosthecomicrobium hirschii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProsthecomicrobiumHirschii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665126.protein.sequences.v11.5.fa",
		        "enrichment_path": "665126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665126.protein.info.v11.5.txt",
		        "node_list_path": "665126.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4720(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_47_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4720", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802335.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802335.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802335.protein.info.v11.5.txt",
		        "node_list_path": "1802335.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaviaAperea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cavia aperea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaviaAperea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "37548.protein.sequences.v11.5.fa",
		        "enrichment_path": "37548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37548.protein.info.v11.5.txt",
		        "node_list_path": "37548.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223545.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223545.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223545.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223545.protein.info.v11.5.txt",
		        "node_list_path": "1223545.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223545.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobacteriaceaeArchaeon41258(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacteriaceae archaeon 41_258 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriaceaeArchaeon41258", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635284.protein.info.v11.5.txt",
		        "node_list_path": "1635284.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptolyngbyaSpO77(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. O-77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptolyngbyaSpO77", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1080068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1080068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1080068.protein.info.v11.5.txt",
		        "node_list_path": "1080068.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomaduraLatinaNbrc106108Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura latina NBRC 106108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomaduraLatinaNbrc106108Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220563.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220563.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220563.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220563.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220563.protein.info.v11.5.txt",
		        "node_list_path": "1220563.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220563.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumMaltaromaticum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium maltaromaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumMaltaromaticum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1234679.protein.sequences.v11.5.fa",
		        "enrichment_path": "1234679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1234679.protein.info.v11.5.txt",
		        "node_list_path": "1234679.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumMedicaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium medicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumMedicaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "366394.clusters.info.v11.5.txt",
		        "cluster_tree_path": "366394.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "366394.clusters.proteins.v11.5.txt",
		        "sequence_path": "366394.protein.sequences.v11.5.fa",
		        "enrichment_path": "366394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366394.protein.info.v11.5.txt",
		        "node_list_path": "366394.cluster.nodes.v11.5.txt",
		        "edge_list_path": "366394.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpNml140438(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML140438 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpNml140438", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906334.protein.info.v11.5.txt",
		        "node_list_path": "1906334.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeisseriaPolysacchareaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaPolysacchareaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "546267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "546267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "546267.clusters.proteins.v11.5.txt",
		        "sequence_path": "546267.protein.sequences.v11.5.fa",
		        "enrichment_path": "546267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546267.protein.info.v11.5.txt",
		        "node_list_path": "546267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "546267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumPolymorphumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum polymorphum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumPolymorphumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "393480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "393480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "393480.clusters.proteins.v11.5.txt",
		        "sequence_path": "393480.protein.sequences.v11.5.fa",
		        "enrichment_path": "393480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "393480.protein.info.v11.5.txt",
		        "node_list_path": "393480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "393480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MandrillusLeucophaeusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mandrillus leucophaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MandrillusLeucophaeusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9568.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9568.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9568.clusters.proteins.v11.5.txt",
		        "sequence_path": "9568.protein.sequences.v11.5.fa",
		        "enrichment_path": "9568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9568.protein.info.v11.5.txt",
		        "node_list_path": "9568.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9568.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisAustraliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis australiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisAustraliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546364.protein.sequences.v11.5.fa",
		        "enrichment_path": "546364.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546364.protein.info.v11.5.txt",
		        "node_list_path": "546364.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulomonasSpRoot485Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Root485 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulomonasSpRoot485Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736546.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736546.protein.info.v11.5.txt",
		        "node_list_path": "1736546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacillusParabrevisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus parabrevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusParabrevisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "54914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "54914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "54914.clusters.proteins.v11.5.txt",
		        "sequence_path": "54914.protein.sequences.v11.5.fa",
		        "enrichment_path": "54914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "54914.protein.info.v11.5.txt",
		        "node_list_path": "54914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "54914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRifoxyd1Full4619(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYD1_FULL_46_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyd1Full4619", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802552.protein.info.v11.5.txt",
		        "node_list_path": "1802552.protein.complete.v11.5.txt"
		    }
		]
    )()

def BizioniaSpApa3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bizionia sp. APA-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BizioniaSpApa3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1861784.protein.sequences.v11.5.fa",
		        "enrichment_path": "1861784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1861784.protein.info.v11.5.txt",
		        "node_list_path": "1861784.protein.complete.v11.5.txt"
		    }
		]
    )()

def FluoribacterBozemanaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fluoribacter bozemanae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FluoribacterBozemanaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "447.clusters.info.v11.5.txt",
		        "cluster_tree_path": "447.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "447.clusters.proteins.v11.5.txt",
		        "sequence_path": "447.protein.sequences.v11.5.fa",
		        "enrichment_path": "447.protein.enrichment.terms.v11.5.txt",
		        "info_path": "447.protein.info.v11.5.txt",
		        "node_list_path": "447.cluster.nodes.v11.5.txt",
		        "edge_list_path": "447.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSp6829Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. 68-29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSp6829Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895823.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895823.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895823.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895823.protein.info.v11.5.txt",
		        "node_list_path": "1895823.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895823.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusFlavusNrrl3357(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus flavus NRRL3357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusFlavusNrrl3357", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "332952.protein.sequences.v11.5.fa",
		        "enrichment_path": "332952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332952.protein.info.v11.5.txt",
		        "node_list_path": "332952.protein.complete.v11.5.txt"
		    }
		]
    )()

def ApostasiaShenzhenicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Apostasia shenzhenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApostasiaShenzhenicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1088818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1088818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1088818.clusters.proteins.v11.5.txt",
		        "sequence_path": "1088818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1088818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1088818.protein.info.v11.5.txt",
		        "node_list_path": "1088818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1088818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GrosmanniaClavigeraKw1407Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Grosmannia clavigera kw1407 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GrosmanniaClavigeraKw1407Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655863.clusters.proteins.v11.5.txt",
		        "sequence_path": "655863.protein.sequences.v11.5.fa",
		        "enrichment_path": "655863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655863.protein.info.v11.5.txt",
		        "node_list_path": "655863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElsinoeAustralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elsinoe australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElsinoeAustralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40998.protein.sequences.v11.5.fa",
		        "enrichment_path": "40998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40998.protein.info.v11.5.txt",
		        "node_list_path": "40998.protein.complete.v11.5.txt"
		    }
		]
    )()

def DickeyaDianthicolaNcppb3534(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dianthicola NCPPB 3534 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaDianthicolaNcppb3534", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223570.protein.info.v11.5.txt",
		        "node_list_path": "1223570.protein.complete.v11.5.txt"
		    }
		]
    )()

def TaphrinaDeformans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Taphrina deformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TaphrinaDeformans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5011.protein.sequences.v11.5.fa",
		        "enrichment_path": "5011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5011.protein.info.v11.5.txt",
		        "node_list_path": "5011.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassospiraSpTsl51Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassospira sp. TSL5-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassospiraSpTsl51Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1544451.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1544451.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1544451.clusters.proteins.v11.5.txt",
		        "sequence_path": "1544451.protein.sequences.v11.5.fa",
		        "enrichment_path": "1544451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1544451.protein.info.v11.5.txt",
		        "node_list_path": "1544451.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1544451.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudorhodobacterAquimaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudorhodobacter aquimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudorhodobacterAquimaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "687412.protein.sequences.v11.5.fa",
		        "enrichment_path": "687412.protein.enrichment.terms.v11.5.txt",
		        "info_path": "687412.protein.info.v11.5.txt",
		        "node_list_path": "687412.protein.complete.v11.5.txt"
		    }
		]
    )()

def MobiluncusMulierisAtcc35243(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris ATCC35243 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MobiluncusMulierisAtcc35243", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "585199.protein.sequences.v11.5.fa",
		        "enrichment_path": "585199.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585199.protein.info.v11.5.txt",
		        "node_list_path": "585199.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumH9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumH9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1807757.protein.sequences.v11.5.fa",
		        "enrichment_path": "1807757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1807757.protein.info.v11.5.txt",
		        "node_list_path": "1807757.protein.complete.v11.5.txt"
		    }
		]
    )()

def TubulinosemaRatisbonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tubulinosema ratisbonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TubulinosemaRatisbonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "291195.protein.sequences.v11.5.fa",
		        "enrichment_path": "291195.protein.enrichment.terms.v11.5.txt",
		        "info_path": "291195.protein.info.v11.5.txt",
		        "node_list_path": "291195.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumLeiognathiLrivu41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi lrivu41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumLeiognathiLrivu41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1248232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1248232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1248232.protein.info.v11.5.txt",
		        "node_list_path": "1248232.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumAntarcticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumAntarcticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1358423.protein.sequences.v11.5.fa",
		        "enrichment_path": "1358423.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1358423.protein.info.v11.5.txt",
		        "node_list_path": "1358423.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrialbaceaeArchaeonTcBr11E2g14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon Tc-Br11_E2g14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrialbaceaeArchaeonTcBr11E2g14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729462.protein.info.v11.5.txt",
		        "node_list_path": "1729462.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaMonocytogenesScottCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria monocytogenes Scott Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaMonocytogenesScottCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1027396.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1027396.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1027396.clusters.proteins.v11.5.txt",
		        "sequence_path": "1027396.protein.sequences.v11.5.fa",
		        "enrichment_path": "1027396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1027396.protein.info.v11.5.txt",
		        "node_list_path": "1027396.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1027396.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfonauticusSubmarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonauticus submarinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonauticusSubmarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "206665.protein.sequences.v11.5.fa",
		        "enrichment_path": "206665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "206665.protein.info.v11.5.txt",
		        "node_list_path": "206665.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumSpMb1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium sp. MB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumSpMb1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379702.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379702.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379702.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379702.protein.info.v11.5.txt",
		        "node_list_path": "1379702.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379702.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusLoiseleuriaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus loiseleuriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLoiseleuriaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1679170.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1679170.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1679170.clusters.proteins.v11.5.txt",
		        "sequence_path": "1679170.protein.sequences.v11.5.fa",
		        "enrichment_path": "1679170.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1679170.protein.info.v11.5.txt",
		        "node_list_path": "1679170.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1679170.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "376733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "376733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "376733.clusters.proteins.v11.5.txt",
		        "sequence_path": "376733.protein.sequences.v11.5.fa",
		        "enrichment_path": "376733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "376733.protein.info.v11.5.txt",
		        "node_list_path": "376733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "376733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusAzizii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus azizii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAzizii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1579424.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579424.protein.info.v11.5.txt",
		        "node_list_path": "1579424.protein.complete.v11.5.txt"
		    }
		]
    )()

def PasteurellaSkyensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella skyensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaSkyensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "97481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "97481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "97481.clusters.proteins.v11.5.txt",
		        "sequence_path": "97481.protein.sequences.v11.5.fa",
		        "enrichment_path": "97481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97481.protein.info.v11.5.txt",
		        "node_list_path": "97481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "97481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaSolanacearumPo82Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum Po82 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSolanacearumPo82Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1031711.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1031711.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1031711.clusters.proteins.v11.5.txt",
		        "sequence_path": "1031711.protein.sequences.v11.5.fa",
		        "enrichment_path": "1031711.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1031711.protein.info.v11.5.txt",
		        "node_list_path": "1031711.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1031711.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BremiaLactucae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bremia lactucae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BremiaLactucae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4779.protein.sequences.v11.5.fa",
		        "enrichment_path": "4779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4779.protein.info.v11.5.txt",
		        "node_list_path": "4779.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSoil782Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil782 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSoil782Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736410.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736410.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736410.protein.info.v11.5.txt",
		        "node_list_path": "1736410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMelainabacteriaBacteriumRifoxya2Full329Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFOXYA2_FULL_32_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifoxya2Full329Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801611.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801611.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801611.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801611.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801611.protein.info.v11.5.txt",
		        "node_list_path": "1801611.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801611.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioThiocyanoxidansArh4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArh4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "713587.protein.sequences.v11.0.fa",
		        "enrichment_path": "713587.protein.enrichment.terms.v11.0.txt",
		        "info_path": "713587.protein.info.v11.0.txt",
		        "node_list_path": "713587.protein.complete.v11.0.txt"
		    }
		]
    )()

def PaenibacillusSpSoil787(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil787 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpSoil787", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736411.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736411.protein.info.v11.5.txt",
		        "node_list_path": "1736411.protein.complete.v11.5.txt"
		    }
		]
    )()

def BdellovibrionalesBacteriumRifoxya1Full3614(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYA1_FULL_36_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BdellovibrionalesBacteriumRifoxya1Full3614", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797391.protein.info.v11.5.txt",
		        "node_list_path": "1797391.protein.complete.v11.5.txt"
		    }
		]
    )()

def CroceibacterAtlanticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Croceibacter atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CroceibacterAtlanticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "216432.protein.sequences.v11.5.fa",
		        "enrichment_path": "216432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "216432.protein.info.v11.5.txt",
		        "node_list_path": "216432.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRickettsiellaIsopodorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rickettsiella isopodorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRickettsiellaIsopodorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1225476.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225476.protein.info.v11.5.txt",
		        "node_list_path": "1225476.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriumOl1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium OL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumOl1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1504822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504822.protein.info.v11.5.txt",
		        "node_list_path": "1504822.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhascolarctosCinereus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phascolarctos cinereus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhascolarctosCinereus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "38626.protein.sequences.v11.5.fa",
		        "enrichment_path": "38626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38626.protein.info.v11.5.txt",
		        "node_list_path": "38626.protein.complete.v11.5.txt"
		    }
		]
    )()

def TalaromycesStipitatusAtcc10500Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces stipitatus ATCC 10500 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesStipitatusAtcc10500Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "441959.clusters.info.v11.5.txt",
		        "cluster_tree_path": "441959.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "441959.clusters.proteins.v11.5.txt",
		        "sequence_path": "441959.protein.sequences.v11.5.fa",
		        "enrichment_path": "441959.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441959.protein.info.v11.5.txt",
		        "node_list_path": "441959.cluster.nodes.v11.5.txt",
		        "edge_list_path": "441959.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmphriteaAtlantica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Amphritea atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmphriteaAtlantica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "355243.protein.sequences.v11.5.fa",
		        "enrichment_path": "355243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "355243.protein.info.v11.5.txt",
		        "node_list_path": "355243.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusGlucanolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus glucanolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusGlucanolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59843.protein.sequences.v11.5.fa",
		        "enrichment_path": "59843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59843.protein.info.v11.5.txt",
		        "node_list_path": "59843.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesDurhamensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces durhamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesDurhamensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "68194.protein.sequences.v11.5.fa",
		        "enrichment_path": "68194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68194.protein.info.v11.5.txt",
		        "node_list_path": "68194.protein.complete.v11.5.txt"
		    }
		]
    )()

def RalstoniaSolanacearumGmi1000Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum GMI1000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSolanacearumGmi1000Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "267608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "267608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "267608.clusters.proteins.v11.5.txt",
		        "sequence_path": "267608.protein.sequences.v11.5.fa",
		        "enrichment_path": "267608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267608.protein.info.v11.5.txt",
		        "node_list_path": "267608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "267608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterSmithiiAtcc35061Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter smithii ATCC35061 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterSmithiiAtcc35061Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "420247.clusters.info.v11.5.txt",
		        "cluster_tree_path": "420247.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "420247.clusters.proteins.v11.5.txt",
		        "sequence_path": "420247.protein.sequences.v11.5.fa",
		        "enrichment_path": "420247.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420247.protein.info.v11.5.txt",
		        "node_list_path": "420247.cluster.nodes.v11.5.txt",
		        "edge_list_path": "420247.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AzorhizobiumCaulinodansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Azorhizobium caulinodans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzorhizobiumCaulinodansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "438753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "438753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "438753.clusters.proteins.v11.5.txt",
		        "sequence_path": "438753.protein.sequences.v11.5.fa",
		        "enrichment_path": "438753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "438753.protein.info.v11.5.txt",
		        "node_list_path": "438753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "438753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacteraceaeBacteriumCg2305140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium CG2_30_51_40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteraceaeBacteriumCg2305140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805128.protein.info.v11.5.txt",
		        "node_list_path": "1805128.protein.complete.v11.5.txt"
		    }
		]
    )()

def DialisterMicroaerophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dialister microaerophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DialisterMicroaerophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "910314.protein.sequences.v11.5.fa",
		        "enrichment_path": "910314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "910314.protein.info.v11.5.txt",
		        "node_list_path": "910314.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptosporangiumAmethystogenes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptosporangium amethystogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptosporangiumAmethystogenes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2002.protein.sequences.v11.5.fa",
		        "enrichment_path": "2002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2002.protein.info.v11.5.txt",
		        "node_list_path": "2002.protein.complete.v11.5.txt"
		    }
		]
    )()

def RodentibacterRattiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rodentibacter ratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RodentibacterRattiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906745.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906745.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906745.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906745.protein.info.v11.5.txt",
		        "node_list_path": "1906745.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906745.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusMitisAtcc6249(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis ATCC6249 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMitisAtcc6249", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "864567.protein.sequences.v11.5.fa",
		        "enrichment_path": "864567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "864567.protein.info.v11.5.txt",
		        "node_list_path": "864567.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusPhocaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus phocae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusPhocaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "119224.clusters.info.v11.5.txt",
		        "cluster_tree_path": "119224.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "119224.clusters.proteins.v11.5.txt",
		        "sequence_path": "119224.protein.sequences.v11.5.fa",
		        "enrichment_path": "119224.protein.enrichment.terms.v11.5.txt",
		        "info_path": "119224.protein.info.v11.5.txt",
		        "node_list_path": "119224.cluster.nodes.v11.5.txt",
		        "edge_list_path": "119224.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnothrixSpCaciam69d(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnothrix sp. CACIAM 69d graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnothrixSpCaciam69d", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1890733.protein.sequences.v11.5.fa",
		        "enrichment_path": "1890733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1890733.protein.info.v11.5.txt",
		        "node_list_path": "1890733.protein.complete.v11.5.txt"
		    }
		]
    )()

def PoseidonocellaPacifica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Poseidonocella pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PoseidonocellaPacifica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "871651.protein.sequences.v11.5.fa",
		        "enrichment_path": "871651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871651.protein.info.v11.5.txt",
		        "node_list_path": "871651.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpAap58(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. AAP58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpAap58", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1523422.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523422.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523422.protein.info.v11.5.txt",
		        "node_list_path": "1523422.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumKansasiiAtcc12478Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii ATCC12478 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumKansasiiAtcc12478Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "557599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "557599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "557599.clusters.proteins.v11.5.txt",
		        "sequence_path": "557599.protein.sequences.v11.5.fa",
		        "enrichment_path": "557599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "557599.protein.info.v11.5.txt",
		        "node_list_path": "557599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "557599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterovibrioNorvegicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterovibrioNorvegicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1190603.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1190603.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1190603.clusters.proteins.v11.5.txt",
		        "sequence_path": "1190603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1190603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1190603.protein.info.v11.5.txt",
		        "node_list_path": "1190603.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1190603.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsplowo201Full3910(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_39_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3910", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798622.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798622.protein.info.v11.5.txt",
		        "node_list_path": "1798622.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSpS2151Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. S2151 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpS2151Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "579478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "579478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "579478.clusters.proteins.v11.5.txt",
		        "sequence_path": "579478.protein.sequences.v11.5.fa",
		        "enrichment_path": "579478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "579478.protein.info.v11.5.txt",
		        "node_list_path": "579478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "579478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumRifcsplowo212Full4812Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPLOWO2_12_FULL_48_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsplowo212Full4812Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801643.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801643.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801643.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801643.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801643.protein.info.v11.5.txt",
		        "node_list_path": "1801643.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801643.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacteralesBacteriumRifcsphigho201Full7019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacterales bacterium RIFCSPHIGHO2_01_FULL_70_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacteralesBacteriumRifcsphigho201Full7019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797585.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797585.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797585.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797585.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797585.protein.info.v11.5.txt",
		        "node_list_path": "1797585.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797585.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EscherichiaAlbertiiTw07627(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia albertii TW07627 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaAlbertiiTw07627", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "502347.protein.sequences.v11.5.fa",
		        "enrichment_path": "502347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502347.protein.info.v11.5.txt",
		        "node_list_path": "502347.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidobacteriaBacterium13220cm5827Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_2_20CM_58_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidobacteriaBacterium13220cm5827Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803466.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803466.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803466.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803466.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803466.protein.info.v11.5.txt",
		        "node_list_path": "1803466.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803466.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaliobacillusRyukyuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraliobacillus ryukyuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaliobacillusRyukyuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "200904.clusters.info.v11.5.txt",
		        "cluster_tree_path": "200904.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "200904.clusters.proteins.v11.5.txt",
		        "sequence_path": "200904.protein.sequences.v11.5.fa",
		        "enrichment_path": "200904.protein.enrichment.terms.v11.5.txt",
		        "info_path": "200904.protein.info.v11.5.txt",
		        "node_list_path": "200904.cluster.nodes.v11.5.txt",
		        "edge_list_path": "200904.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc5054Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 5054 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc5054Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977877.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977877.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977877.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977877.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977877.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977877.protein.info.v11.5.txt",
		        "node_list_path": "1977877.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977877.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiaNova(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia nova graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaNova", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415166.protein.info.v11.5.txt",
		        "node_list_path": "1415166.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpRoot1279(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Root1279 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpRoot1279", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736443.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736443.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736443.protein.info.v11.5.txt",
		        "node_list_path": "1736443.protein.complete.v11.5.txt"
		    }
		]
    )()

def GardnerellaVaginalis101(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis 101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GardnerellaVaginalis101", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "904144.protein.sequences.v11.5.fa",
		        "enrichment_path": "904144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904144.protein.info.v11.5.txt",
		        "node_list_path": "904144.protein.complete.v11.5.txt"
		    }
		]
    )()

def KaistiaAdipataDsm17808(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kaistia adipata DSM 17808 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KaistiaAdipataDsm17808", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122131.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122131.protein.info.v11.5.txt",
		        "node_list_path": "1122131.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumLundense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium lundense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumLundense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410653.protein.info.v11.5.txt",
		        "node_list_path": "1410653.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryptosporangiumAurantiacumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporangium aurantiacum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptosporangiumAurantiacumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "134849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "134849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "134849.clusters.proteins.v11.5.txt",
		        "sequence_path": "134849.protein.sequences.v11.5.fa",
		        "enrichment_path": "134849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "134849.protein.info.v11.5.txt",
		        "node_list_path": "134849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "134849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferSpHz11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer sp. HZ11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferSpHz11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1453501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1453501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1453501.clusters.proteins.v11.5.txt",
		        "sequence_path": "1453501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453501.protein.info.v11.5.txt",
		        "node_list_path": "1453501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1453501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichophytonBenhamiaeCbs112371(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton benhamiae CBS 112371 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichophytonBenhamiaeCbs112371", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "663331.protein.sequences.v11.5.fa",
		        "enrichment_path": "663331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "663331.protein.info.v11.5.txt",
		        "node_list_path": "663331.protein.complete.v11.5.txt"
		    }
		]
    )()

def NostocSpMbr210(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nostoc sp. MBR 210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocSpMbr210", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1881015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881015.protein.info.v11.5.txt",
		        "node_list_path": "1881015.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsplowo201Full4421(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPLOWO2_01_FULL_44_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsplowo201Full4421", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817841.protein.info.v11.5.txt",
		        "node_list_path": "1817841.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyberlindneraFabianii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyberlindnera fabianii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyberlindneraFabianii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36022.protein.sequences.v11.5.fa",
		        "enrichment_path": "36022.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36022.protein.info.v11.5.txt",
		        "node_list_path": "36022.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoccidioidesPosadasiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides posadasii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesPosadasiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "199306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "199306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "199306.clusters.proteins.v11.5.txt",
		        "sequence_path": "199306.protein.sequences.v11.5.fa",
		        "enrichment_path": "199306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "199306.protein.info.v11.5.txt",
		        "node_list_path": "199306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "199306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirillosporaAlbidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirillospora albida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirillosporaAlbidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "58123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "58123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "58123.clusters.proteins.v11.5.txt",
		        "sequence_path": "58123.protein.sequences.v11.5.fa",
		        "enrichment_path": "58123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58123.protein.info.v11.5.txt",
		        "node_list_path": "58123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "58123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasMariniglutinosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas mariniglutinosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasMariniglutinosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "206042.protein.sequences.v11.5.fa",
		        "enrichment_path": "206042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "206042.protein.info.v11.5.txt",
		        "node_list_path": "206042.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusIhumii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ihumii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusIhumii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "687436.protein.sequences.v11.5.fa",
		        "enrichment_path": "687436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "687436.protein.info.v11.5.txt",
		        "node_list_path": "687436.protein.complete.v11.5.txt"
		    }
		]
    )()

def ConexibacterWoeseiIso977nCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Conexibacter woesei Iso977N Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ConexibacterWoeseiIso977nCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1283299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1283299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1283299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1283299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283299.protein.info.v11.5.txt",
		        "node_list_path": "1283299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1283299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpYl23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. YL23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpYl23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1335760.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1335760.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1335760.clusters.proteins.v11.5.txt",
		        "sequence_path": "1335760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1335760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1335760.protein.info.v11.5.txt",
		        "node_list_path": "1335760.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1335760.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumKa00274Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium KA00274 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumKa00274Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1497955.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1497955.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1497955.clusters.proteins.v11.5.txt",
		        "sequence_path": "1497955.protein.sequences.v11.5.fa",
		        "enrichment_path": "1497955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1497955.protein.info.v11.5.txt",
		        "node_list_path": "1497955.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1497955.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFarciminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus farciminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFarciminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936140.protein.sequences.v11.5.fa",
		        "enrichment_path": "936140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936140.protein.info.v11.5.txt",
		        "node_list_path": "936140.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusRhamnosus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rhamnosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusRhamnosus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "568703.protein.sequences.v11.5.fa",
		        "enrichment_path": "568703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "568703.protein.info.v11.5.txt",
		        "node_list_path": "568703.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpBp1148Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. BP1-148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpBp1148Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "645274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "645274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "645274.clusters.proteins.v11.5.txt",
		        "sequence_path": "645274.protein.sequences.v11.5.fa",
		        "enrichment_path": "645274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "645274.protein.info.v11.5.txt",
		        "node_list_path": "645274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "645274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NiabellaGinsenosidivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Niabella ginsenosidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiabellaGinsenosidivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1176587.protein.sequences.v11.5.fa",
		        "enrichment_path": "1176587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1176587.protein.info.v11.5.txt",
		        "node_list_path": "1176587.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenomonasSputigena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sputigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasSputigena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546271.protein.sequences.v11.5.fa",
		        "enrichment_path": "546271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546271.protein.info.v11.5.txt",
		        "node_list_path": "546271.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumRbg166413Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_16_64_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumRbg166413Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797200.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797200.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797200.protein.info.v11.5.txt",
		        "node_list_path": "1797200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycetocolaSaprophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycetocola saprophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycetocolaSaprophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "76636.clusters.info.v11.5.txt",
		        "cluster_tree_path": "76636.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "76636.clusters.proteins.v11.5.txt",
		        "sequence_path": "76636.protein.sequences.v11.5.fa",
		        "enrichment_path": "76636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76636.protein.info.v11.5.txt",
		        "node_list_path": "76636.cluster.nodes.v11.5.txt",
		        "edge_list_path": "76636.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpRoot342(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root342 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpRoot342", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736519.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736519.protein.info.v11.5.txt",
		        "node_list_path": "1736519.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumGw2011Gwf24242Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011_GWF2_42_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011Gwf24242Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619142.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619142.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619142.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619142.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619142.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619142.protein.info.v11.5.txt",
		        "node_list_path": "1619142.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619142.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsplowo201Full4531(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPLOWO2_01_FULL_45_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsplowo201Full4531", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797545.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797545.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797545.protein.info.v11.5.txt",
		        "node_list_path": "1797545.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterFelis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter felis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterFelis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "936155.protein.sequences.v11.5.fa",
		        "enrichment_path": "936155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936155.protein.info.v11.5.txt",
		        "node_list_path": "936155.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusOrnithinivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus ornithinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusOrnithinivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "226506.protein.sequences.v11.5.fa",
		        "enrichment_path": "226506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226506.protein.info.v11.5.txt",
		        "node_list_path": "226506.protein.complete.v11.5.txt"
		    }
		]
    )()

def WinogradskyellaSpRha55Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Winogradskyella sp. RHA_55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinogradskyellaSpRha55Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1249933.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1249933.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1249933.clusters.proteins.v11.5.txt",
		        "sequence_path": "1249933.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249933.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249933.protein.info.v11.5.txt",
		        "node_list_path": "1249933.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1249933.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SiccibacterTuricensisLmg23730(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Siccibacter turicensis LMG 23730 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SiccibacterTuricensisLmg23730", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1388748.protein.sequences.v11.5.fa",
		        "enrichment_path": "1388748.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1388748.protein.info.v11.5.txt",
		        "node_list_path": "1388748.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesTsukubensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces tsukubensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesTsukubensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "83656.clusters.info.v11.5.txt",
		        "cluster_tree_path": "83656.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "83656.clusters.proteins.v11.5.txt",
		        "sequence_path": "83656.protein.sequences.v11.5.fa",
		        "enrichment_path": "83656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83656.protein.info.v11.5.txt",
		        "node_list_path": "83656.cluster.nodes.v11.5.txt",
		        "edge_list_path": "83656.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DelphinapterusLeucas(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Delphinapterus leucas graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DelphinapterusLeucas", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9749.protein.sequences.v11.5.fa",
		        "enrichment_path": "9749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9749.protein.info.v11.5.txt",
		        "node_list_path": "9749.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloarchaeobiusIranensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloarchaeobius iranensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarchaeobiusIranensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "996166.protein.sequences.v11.5.fa",
		        "enrichment_path": "996166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "996166.protein.info.v11.5.txt",
		        "node_list_path": "996166.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusFlexus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus flexus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusFlexus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1444310.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444310.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444310.protein.info.v11.5.txt",
		        "node_list_path": "1444310.protein.complete.v11.5.txt"
		    }
		]
    )()

def NeurosporaTetraspermaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neurospora tetrasperma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeurosporaTetraspermaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40127.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40127.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40127.clusters.proteins.v11.5.txt",
		        "sequence_path": "40127.protein.sequences.v11.5.fa",
		        "enrichment_path": "40127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40127.protein.info.v11.5.txt",
		        "node_list_path": "40127.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40127.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpH050Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H050 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpH050Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1759072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1759072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1759072.clusters.proteins.v11.5.txt",
		        "sequence_path": "1759072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759072.protein.info.v11.5.txt",
		        "node_list_path": "1759072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1759072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MartelellaEndophytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Martelella endophytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MartelellaEndophytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1486262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1486262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1486262.protein.info.v11.5.txt",
		        "node_list_path": "1486262.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusStellifer(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus stellifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusStellifer", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "169760.protein.sequences.v11.5.fa",
		        "enrichment_path": "169760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "169760.protein.info.v11.5.txt",
		        "node_list_path": "169760.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifoxyb2Full4645Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFOXYB2_FULL_46_45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2Full4645Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802582.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802582.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802582.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802582.protein.info.v11.5.txt",
		        "node_list_path": "1802582.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802582.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylosinusSpPw1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylosinus sp. PW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylosinusSpPw1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "107636.protein.sequences.v11.5.fa",
		        "enrichment_path": "107636.protein.enrichment.terms.v11.5.txt",
		        "info_path": "107636.protein.info.v11.5.txt",
		        "node_list_path": "107636.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusKoppenhoeferi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus koppenhoeferi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusKoppenhoeferi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "351659.protein.sequences.v11.5.fa",
		        "enrichment_path": "351659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351659.protein.info.v11.5.txt",
		        "node_list_path": "351659.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExophialaXenobiotica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exophiala xenobiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExophialaXenobiotica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "348802.protein.sequences.v11.5.fa",
		        "enrichment_path": "348802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "348802.protein.info.v11.5.txt",
		        "node_list_path": "348802.protein.complete.v11.5.txt"
		    }
		]
    )()

def GryllotalpicolaGinsengisoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gryllotalpicola ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GryllotalpicolaGinsengisoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121372.protein.info.v11.5.txt",
		        "node_list_path": "1121372.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumScgcAaa027n21Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium SCGC AAA027N21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumScgcAaa027n21Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "938709.clusters.info.v11.5.txt",
		        "cluster_tree_path": "938709.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "938709.clusters.proteins.v11.5.txt",
		        "sequence_path": "938709.protein.sequences.v11.5.fa",
		        "enrichment_path": "938709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "938709.protein.info.v11.5.txt",
		        "node_list_path": "938709.cluster.nodes.v11.5.txt",
		        "edge_list_path": "938709.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KocuriaFlavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kocuria flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaFlavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "446860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "446860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "446860.clusters.proteins.v11.5.txt",
		        "sequence_path": "446860.protein.sequences.v11.5.fa",
		        "enrichment_path": "446860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446860.protein.info.v11.5.txt",
		        "node_list_path": "446860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "446860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusOrisF0423(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oris F0423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusOrisF0423", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "944562.protein.sequences.v11.5.fa",
		        "enrichment_path": "944562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944562.protein.info.v11.5.txt",
		        "node_list_path": "944562.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusFasciansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus fascians Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusFasciansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1828.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1828.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1828.clusters.proteins.v11.5.txt",
		        "sequence_path": "1828.protein.sequences.v11.5.fa",
		        "enrichment_path": "1828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1828.protein.info.v11.5.txt",
		        "node_list_path": "1828.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1828.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentinulaEdodes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentinula edodes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentinulaEdodes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5353.protein.sequences.v11.5.fa",
		        "enrichment_path": "5353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5353.protein.info.v11.5.txt",
		        "node_list_path": "5353.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrochaeteSpPcc7126(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microchaete sp. PCC7126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrochaeteSpPcc7126", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "643473.protein.sequences.v11.5.fa",
		        "enrichment_path": "643473.protein.enrichment.terms.v11.5.txt",
		        "info_path": "643473.protein.info.v11.5.txt",
		        "node_list_path": "643473.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioSonorensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sonorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioSonorensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1004316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1004316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1004316.clusters.proteins.v11.5.txt",
		        "sequence_path": "1004316.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004316.protein.info.v11.5.txt",
		        "node_list_path": "1004316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1004316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag571(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:571 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag571", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262822.protein.info.v11.5.txt",
		        "node_list_path": "1262822.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBrocadiaCaroliniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia caroliniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBrocadiaCaroliniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1004156.protein.sequences.v11.5.fa",
		        "enrichment_path": "1004156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1004156.protein.info.v11.5.txt",
		        "node_list_path": "1004156.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsphigho201Full4523Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_01_FULL_45_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho201Full4523Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798325.protein.info.v11.5.txt",
		        "node_list_path": "1798325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichechusManatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichechus manatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichechusManatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9778.protein.sequences.v11.5.fa",
		        "enrichment_path": "9778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9778.protein.info.v11.5.txt",
		        "node_list_path": "9778.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyotisBrandtii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myotis brandtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyotisBrandtii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "109478.protein.sequences.v11.5.fa",
		        "enrichment_path": "109478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "109478.protein.info.v11.5.txt",
		        "node_list_path": "109478.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegasphaeraGenomospCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera genomosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraGenomospCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "699218.clusters.info.v11.5.txt",
		        "cluster_tree_path": "699218.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "699218.clusters.proteins.v11.5.txt",
		        "sequence_path": "699218.protein.sequences.v11.5.fa",
		        "enrichment_path": "699218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "699218.protein.info.v11.5.txt",
		        "node_list_path": "699218.cluster.nodes.v11.5.txt",
		        "edge_list_path": "699218.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhinolophusFerrumequinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhinolophus ferrumequinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhinolophusFerrumequinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59479.protein.sequences.v11.5.fa",
		        "enrichment_path": "59479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59479.protein.info.v11.5.txt",
		        "node_list_path": "59479.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTerasakiellaMagnetica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terasakiella magnetica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTerasakiellaMagnetica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1867952.protein.sequences.v11.5.fa",
		        "enrichment_path": "1867952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1867952.protein.info.v11.5.txt",
		        "node_list_path": "1867952.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechocystisSpPcc6714(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC6714 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechocystisSpPcc6714", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1147.protein.info.v11.5.txt",
		        "node_list_path": "1147.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpGa1199(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1199 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpGa1199", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1772287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772287.protein.info.v11.5.txt",
		        "node_list_path": "1772287.protein.complete.v11.5.txt"
		    }
		]
    )()

def CucumibacterMarinusDsm18995(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cucumibacter marinus DSM 18995 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CucumibacterMarinusDsm18995", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "422296.protein.sequences.v11.5.fa",
		        "enrichment_path": "422296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "422296.protein.info.v11.5.txt",
		        "node_list_path": "422296.protein.complete.v11.5.txt"
		    }
		]
    )()

def CystobacterFuscusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cystobacter fuscus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CystobacterFuscusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1242864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1242864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1242864.clusters.proteins.v11.5.txt",
		        "sequence_path": "1242864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1242864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1242864.protein.info.v11.5.txt",
		        "node_list_path": "1242864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1242864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SeonamhaeicolaSpS23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Seonamhaeicola sp. S2-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SeonamhaeicolaSpS23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1936081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1936081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1936081.protein.info.v11.5.txt",
		        "node_list_path": "1936081.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWesteberhardiaCardiocondylae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Westeberhardia cardiocondylae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWesteberhardiaCardiocondylae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1594731.protein.sequences.v11.5.fa",
		        "enrichment_path": "1594731.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1594731.protein.info.v11.5.txt",
		        "node_list_path": "1594731.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThecamonasTrahensAtcc50062Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thecamonas trahens ATCC 50062 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThecamonasTrahensAtcc50062Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "461836.clusters.info.v11.5.txt",
		        "cluster_tree_path": "461836.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "461836.clusters.proteins.v11.5.txt",
		        "sequence_path": "461836.protein.sequences.v11.5.fa",
		        "enrichment_path": "461836.protein.enrichment.terms.v11.5.txt",
		        "info_path": "461836.protein.info.v11.5.txt",
		        "node_list_path": "461836.cluster.nodes.v11.5.txt",
		        "edge_list_path": "461836.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusKunkeei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kunkeei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKunkeei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "148814.protein.sequences.v11.5.fa",
		        "enrichment_path": "148814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "148814.protein.info.v11.5.txt",
		        "node_list_path": "148814.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSalegens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas salegens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSalegens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434072.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434072.protein.info.v11.5.txt",
		        "node_list_path": "1434072.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusKawachiiIfo4308(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus kawachii IFO 4308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusKawachiiIfo4308", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033177.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033177.protein.info.v11.5.txt",
		        "node_list_path": "1033177.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg166443Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_64_43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg166443Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797659.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797659.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797659.protein.info.v11.5.txt",
		        "node_list_path": "1797659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OstreococcusLucimarinusCce9901Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ostreococcus lucimarinus CCE9901 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OstreococcusLucimarinusCce9901Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "436017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "436017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "436017.clusters.proteins.v11.5.txt",
		        "sequence_path": "436017.protein.sequences.v11.5.fa",
		        "enrichment_path": "436017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "436017.protein.info.v11.5.txt",
		        "node_list_path": "436017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "436017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaSpCb01531(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora sp. CB01531 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaSpCb01531", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1718947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1718947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1718947.protein.info.v11.5.txt",
		        "node_list_path": "1718947.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumGa0077544(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium Ga0077544 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumGa0077544", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752206.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752206.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752206.protein.info.v11.5.txt",
		        "node_list_path": "1752206.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydomonasEustigma(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydomonas eustigma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydomonasEustigma", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157962.protein.info.v11.5.txt",
		        "node_list_path": "1157962.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharibacteriaBacteriumRifcsplowo201Full4813(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPLOWO2_01_FULL_48_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsplowo201Full4813", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802146.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802146.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802146.protein.info.v11.5.txt",
		        "node_list_path": "1802146.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProlemurSimus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prolemur simus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProlemurSimus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1328070.protein.sequences.v11.5.fa",
		        "enrichment_path": "1328070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1328070.protein.info.v11.5.txt",
		        "node_list_path": "1328070.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasPutidaH8234(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida H8234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPutidaH8234", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1331671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1331671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1331671.protein.info.v11.5.txt",
		        "node_list_path": "1331671.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusHayakitensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hayakitensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHayakitensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423755.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423755.protein.info.v11.5.txt",
		        "node_list_path": "1423755.protein.complete.v11.5.txt"
		    }
		]
    )()

def OlleyaMarilimosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olleya marilimosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlleyaMarilimosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1353276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1353276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1353276.clusters.proteins.v11.5.txt",
		        "sequence_path": "1353276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1353276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1353276.protein.info.v11.5.txt",
		        "node_list_path": "1353276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1353276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaSpBmg512(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. BMG512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpBmg512", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "222534.protein.sequences.v11.5.fa",
		        "enrichment_path": "222534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "222534.protein.info.v11.5.txt",
		        "node_list_path": "222534.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiobacillusSp6529(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiobacillusSp6529", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895862.protein.info.v11.5.txt",
		        "node_list_path": "1895862.protein.complete.v11.5.txt"
		    }
		]
    )()

def VulpesVulpes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vulpes vulpes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VulpesVulpes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9627.protein.sequences.v11.5.fa",
		        "enrichment_path": "9627.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9627.protein.info.v11.5.txt",
		        "node_list_path": "9627.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusFaeciumC68(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecium C68 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusFaeciumC68", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "565664.protein.sequences.v11.5.fa",
		        "enrichment_path": "565664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565664.protein.info.v11.5.txt",
		        "node_list_path": "565664.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusThermoglucosidasius(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus thermoglucosidasius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusThermoglucosidasius", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634956.protein.sequences.v11.5.fa",
		        "enrichment_path": "634956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634956.protein.info.v11.5.txt",
		        "node_list_path": "634956.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodopseudomonasPalustrisBisb18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisB18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopseudomonasPalustrisBisb18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "316056.clusters.info.v11.5.txt",
		        "cluster_tree_path": "316056.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "316056.clusters.proteins.v11.5.txt",
		        "sequence_path": "316056.protein.sequences.v11.5.fa",
		        "enrichment_path": "316056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "316056.protein.info.v11.5.txt",
		        "node_list_path": "316056.cluster.nodes.v11.5.txt",
		        "edge_list_path": "316056.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumSpScn7031Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. SCN 70-31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumSpScn7031Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660129.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660129.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660129.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660129.protein.info.v11.5.txt",
		        "node_list_path": "1660129.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660129.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaSpUcdKl12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. UCD-KL12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSpUcdKl12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1917163.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1917163.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1917163.clusters.proteins.v11.5.txt",
		        "sequence_path": "1917163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917163.protein.info.v11.5.txt",
		        "node_list_path": "1917163.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1917163.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoritellaDasanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moritella dasanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoritellaDasanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1201293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1201293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1201293.clusters.proteins.v11.5.txt",
		        "sequence_path": "1201293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1201293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1201293.protein.info.v11.5.txt",
		        "node_list_path": "1201293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1201293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrosopumilusPiranensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus piranensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosopumilusPiranensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1582439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1582439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1582439.clusters.proteins.v11.5.txt",
		        "sequence_path": "1582439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1582439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1582439.protein.info.v11.5.txt",
		        "node_list_path": "1582439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1582439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusCereusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cereus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCereusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1396.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1396.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1396.clusters.proteins.v11.5.txt",
		        "sequence_path": "1396.protein.sequences.v11.5.fa",
		        "enrichment_path": "1396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1396.protein.info.v11.5.txt",
		        "node_list_path": "1396.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1396.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LacunisphaeraLimnophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lacunisphaera limnophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LacunisphaeraLimnophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1838286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1838286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1838286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1838286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1838286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1838286.protein.info.v11.5.txt",
		        "node_list_path": "1838286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1838286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaPneumoniaeM129(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae M129 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaPneumoniaeM129", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272634.protein.sequences.v11.5.fa",
		        "enrichment_path": "272634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272634.protein.info.v11.5.txt",
		        "node_list_path": "272634.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumPerfoetensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium perfoetens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumPerfoetensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408439.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408439.protein.info.v11.5.txt",
		        "node_list_path": "1408439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKerfeldbacteriaBacteriumRifcsphigho202Full4214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPHIGHO2_02_FULL_42_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsphigho202Full4214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798540.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798540.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798540.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798540.protein.info.v11.5.txt",
		        "node_list_path": "1798540.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798540.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusAculeatusAtcc16872Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus aculeatus ATCC 16872 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusAculeatusAtcc16872Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "690307.clusters.info.v11.5.txt",
		        "cluster_tree_path": "690307.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "690307.clusters.proteins.v11.5.txt",
		        "sequence_path": "690307.protein.sequences.v11.5.fa",
		        "enrichment_path": "690307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690307.protein.info.v11.5.txt",
		        "node_list_path": "690307.cluster.nodes.v11.5.txt",
		        "edge_list_path": "690307.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapnocytophagaOchraceaDsm7271Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea DSM7271 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapnocytophagaOchraceaDsm7271Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "521097.clusters.info.v11.5.txt",
		        "cluster_tree_path": "521097.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "521097.clusters.proteins.v11.5.txt",
		        "sequence_path": "521097.protein.sequences.v11.5.fa",
		        "enrichment_path": "521097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "521097.protein.info.v11.5.txt",
		        "node_list_path": "521097.cluster.nodes.v11.5.txt",
		        "edge_list_path": "521097.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RubritaleaMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rubritalea marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RubritaleaMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123070.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123070.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123070.protein.info.v11.5.txt",
		        "node_list_path": "1123070.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhinopithecusBieti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhinopithecus bieti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhinopithecusBieti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "61621.protein.sequences.v11.5.fa",
		        "enrichment_path": "61621.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61621.protein.info.v11.5.txt",
		        "node_list_path": "61621.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusSciuriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sciuri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusSciuriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232666.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232666.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232666.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232666.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232666.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232666.protein.info.v11.5.txt",
		        "node_list_path": "1232666.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232666.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalovivaxAsiaticusJcm14624(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halovivax asiaticus JCM 14624 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalovivaxAsiaticusJcm14624", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227490.protein.info.v11.5.txt",
		        "node_list_path": "1227490.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "637971.protein.sequences.v11.5.fa",
		        "enrichment_path": "637971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "637971.protein.info.v11.5.txt",
		        "node_list_path": "637971.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlaciecolaSpHtcc2999Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola sp. HTCC2999 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciecolaSpHtcc2999Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "455436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "455436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "455436.clusters.proteins.v11.5.txt",
		        "sequence_path": "455436.protein.sequences.v11.5.fa",
		        "enrichment_path": "455436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "455436.protein.info.v11.5.txt",
		        "node_list_path": "455436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "455436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PandoraeaSputorum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pandoraea sputorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PandoraeaSputorum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93222.protein.sequences.v11.5.fa",
		        "enrichment_path": "93222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93222.protein.info.v11.5.txt",
		        "node_list_path": "93222.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumW1481Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum W1481 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumW1481Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408287.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408287.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408287.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408287.protein.info.v11.5.txt",
		        "node_list_path": "1408287.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408287.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaEndosymbiontOfDactylopiusCoccusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Dactylopius coccus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaEndosymbiontOfDactylopiusCoccusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1605993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1605993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1605993.clusters.proteins.v11.5.txt",
		        "sequence_path": "1605993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1605993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1605993.protein.info.v11.5.txt",
		        "node_list_path": "1605993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1605993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiumSpGas474(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. GAS474 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiumSpGas474", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882831.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882831.protein.info.v11.5.txt",
		        "node_list_path": "1882831.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSalivariusUcc118(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus salivarius UCC118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSalivariusUcc118", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "362948.protein.sequences.v11.5.fa",
		        "enrichment_path": "362948.protein.enrichment.terms.v11.5.txt",
		        "info_path": "362948.protein.info.v11.5.txt",
		        "node_list_path": "362948.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaWelshimeriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria welshimeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaWelshimeriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "386043.clusters.info.v11.5.txt",
		        "cluster_tree_path": "386043.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "386043.clusters.proteins.v11.5.txt",
		        "sequence_path": "386043.protein.sequences.v11.5.fa",
		        "enrichment_path": "386043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "386043.protein.info.v11.5.txt",
		        "node_list_path": "386043.cluster.nodes.v11.5.txt",
		        "edge_list_path": "386043.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumRuminantiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium ruminantium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumRuminantiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "78346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "78346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "78346.clusters.proteins.v11.5.txt",
		        "sequence_path": "78346.protein.sequences.v11.5.fa",
		        "enrichment_path": "78346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78346.protein.info.v11.5.txt",
		        "node_list_path": "78346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "78346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFrederiksbergensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas frederiksbergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFrederiksbergensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "104087.protein.sequences.v11.5.fa",
		        "enrichment_path": "104087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "104087.protein.info.v11.5.txt",
		        "node_list_path": "104087.protein.complete.v11.5.txt"
		    }
		]
    )()

def GouaniaWilldenowi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gouania willdenowi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GouaniaWilldenowi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "441366.protein.sequences.v11.5.fa",
		        "enrichment_path": "441366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441366.protein.info.v11.5.txt",
		        "node_list_path": "441366.protein.complete.v11.5.txt"
		    }
		]
    )()

def PoseidonocellaPacificaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Poseidonocella pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PoseidonocellaPacificaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "871651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "871651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "871651.clusters.proteins.v11.5.txt",
		        "sequence_path": "871651.protein.sequences.v11.5.fa",
		        "enrichment_path": "871651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871651.protein.info.v11.5.txt",
		        "node_list_path": "871651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "871651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusDentisani7747(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dentisani 7747 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusDentisani7747", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1297857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297857.protein.info.v11.5.txt",
		        "node_list_path": "1297857.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasAstaxanthinifaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas astaxanthinifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasAstaxanthinifaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123267.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123267.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123267.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123267.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123267.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123267.protein.info.v11.5.txt",
		        "node_list_path": "1123267.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123267.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasNaphthalenivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas naphthalenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasNaphthalenivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "365044.protein.sequences.v11.5.fa",
		        "enrichment_path": "365044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "365044.protein.info.v11.5.txt",
		        "node_list_path": "365044.protein.complete.v11.5.txt"
		    }
		]
    )()

def LimnohabitansSp103dpr2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 103DPR2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnohabitansSp103dpr2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1678129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678129.protein.info.v11.5.txt",
		        "node_list_path": "1678129.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermoflavimicrobiumDichotomicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoflavimicrobium dichotomicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoflavimicrobiumDichotomicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46223.protein.sequences.v11.5.fa",
		        "enrichment_path": "46223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46223.protein.info.v11.5.txt",
		        "node_list_path": "46223.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4611Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_02_FULL_46_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4611Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817832.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817832.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817832.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817832.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817832.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817832.protein.info.v11.5.txt",
		        "node_list_path": "1817832.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817832.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumGw2011Gwb1471(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWB1_47_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwb1471", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619007.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619007.protein.info.v11.5.txt",
		        "node_list_path": "1619007.protein.complete.v11.5.txt"
		    }
		]
    )()

def VaribaculumCambrienseDsm15806(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum cambriense DSM15806 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VaribaculumCambrienseDsm15806", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123488.protein.info.v11.5.txt",
		        "node_list_path": "1123488.protein.complete.v11.5.txt"
		    }
		]
    )()

def EggerthellaSpCag298(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eggerthella sp. CAG:298 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EggerthellaSpCag298", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262876.protein.info.v11.5.txt",
		        "node_list_path": "1262876.protein.complete.v11.5.txt"
		    }
		]
    )()

def MacrococcusCanis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Macrococcus canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacrococcusCanis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855823.protein.info.v11.5.txt",
		        "node_list_path": "1855823.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc11e11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC11E11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc11e11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1581089.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1581089.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1581089.clusters.proteins.v11.5.txt",
		        "sequence_path": "1581089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581089.protein.info.v11.5.txt",
		        "node_list_path": "1581089.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1581089.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesOnderdonkii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes onderdonkii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesOnderdonkii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203611.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203611.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203611.protein.info.v11.5.txt",
		        "node_list_path": "1203611.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaPallidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema pallidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaPallidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "243276.protein.sequences.v11.5.fa",
		        "enrichment_path": "243276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243276.protein.info.v11.5.txt",
		        "node_list_path": "243276.protein.complete.v11.5.txt"
		    }
		]
    )()

def AzospirillumOryzae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AzospirillumOryzae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "286727.protein.sequences.v11.5.fa",
		        "enrichment_path": "286727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "286727.protein.info.v11.5.txt",
		        "node_list_path": "286727.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumArbusti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium arbusti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumArbusti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "545243.protein.sequences.v11.5.fa",
		        "enrichment_path": "545243.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545243.protein.info.v11.5.txt",
		        "node_list_path": "545243.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumSpAk27Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium sp. AK27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumSpAk27Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1232683.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1232683.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1232683.clusters.proteins.v11.5.txt",
		        "sequence_path": "1232683.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232683.protein.info.v11.5.txt",
		        "node_list_path": "1232683.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1232683.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IdiomarinaBalticaOs145(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina baltica OS145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IdiomarinaBalticaOs145", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314276.protein.sequences.v11.5.fa",
		        "enrichment_path": "314276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314276.protein.info.v11.5.txt",
		        "node_list_path": "314276.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioGilichinskyiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio gilichinskyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioGilichinskyiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1519643.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1519643.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1519643.clusters.proteins.v11.5.txt",
		        "sequence_path": "1519643.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519643.protein.info.v11.5.txt",
		        "node_list_path": "1519643.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1519643.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaMeningitidisMc58Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria meningitidis MC58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaMeningitidisMc58Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "122586.clusters.info.v11.5.txt",
		        "cluster_tree_path": "122586.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "122586.clusters.proteins.v11.5.txt",
		        "sequence_path": "122586.protein.sequences.v11.5.fa",
		        "enrichment_path": "122586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "122586.protein.info.v11.5.txt",
		        "node_list_path": "122586.cluster.nodes.v11.5.txt",
		        "edge_list_path": "122586.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBlackburnbacteriaBacteriumRifcsphigho202Full4420Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_02_FULL_44_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho202Full4420Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797516.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797516.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797516.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797516.protein.info.v11.5.txt",
		        "node_list_path": "1797516.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797516.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumIndoltheticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium indoltheticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumIndoltheticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "254.clusters.info.v11.5.txt",
		        "cluster_tree_path": "254.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "254.clusters.proteins.v11.5.txt",
		        "sequence_path": "254.protein.sequences.v11.5.fa",
		        "enrichment_path": "254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "254.protein.info.v11.5.txt",
		        "node_list_path": "254.cluster.nodes.v11.5.txt",
		        "edge_list_path": "254.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PantoeaRwandensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea rwandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaRwandensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1076550.protein.sequences.v11.5.fa",
		        "enrichment_path": "1076550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1076550.protein.info.v11.5.txt",
		        "node_list_path": "1076550.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSoleaferreaMassiliensisAp7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Soleaferrea massiliensis AP7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSoleaferreaMassiliensisAp7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211843.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211843.protein.info.v11.5.txt",
		        "node_list_path": "1211843.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg135136Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_51_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg135136Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797625.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797625.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797625.protein.info.v11.5.txt",
		        "node_list_path": "1797625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BelnapiaMoabensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Belnapia moabensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BelnapiaMoabensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121106.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121106.protein.info.v11.5.txt",
		        "node_list_path": "1121106.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusShenzhenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus shenzhenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusShenzhenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231336.protein.info.v11.5.txt",
		        "node_list_path": "1231336.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodoferaxKoreense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodoferax koreense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodoferaxKoreense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1842727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842727.protein.info.v11.5.txt",
		        "node_list_path": "1842727.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucobacterKomagataeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter komagatae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterKomagataeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "55969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "55969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "55969.clusters.proteins.v11.5.txt",
		        "sequence_path": "55969.protein.sequences.v11.5.fa",
		        "enrichment_path": "55969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "55969.protein.info.v11.5.txt",
		        "node_list_path": "55969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "55969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RalstoniaSpA12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. A12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RalstoniaSpA12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1217052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217052.protein.info.v11.5.txt",
		        "node_list_path": "1217052.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaAurantiacaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaAurantiacaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236508.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236508.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236508.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236508.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236508.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236508.protein.info.v11.5.txt",
		        "node_list_path": "1236508.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236508.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4733Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_47_33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4733Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802764.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802764.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802764.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802764.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802764.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802764.protein.info.v11.5.txt",
		        "node_list_path": "1802764.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802764.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSpechtbacteriaBacteriumRifcsplowo202Full388(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_02_FULL_38_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo202Full388", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802164.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802164.protein.info.v11.5.txt",
		        "node_list_path": "1802164.protein.complete.v11.5.txt"
		    }
		]
    )()

def KurthiaSpJc8eCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kurthia sp. JC8E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KurthiaSpJc8eCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1033740.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1033740.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1033740.clusters.proteins.v11.5.txt",
		        "sequence_path": "1033740.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033740.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033740.protein.info.v11.5.txt",
		        "node_list_path": "1033740.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1033740.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeisingeraSpAng1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leisingera sp. ANG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraSpAng1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1002340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002340.protein.info.v11.5.txt",
		        "node_list_path": "1002340.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwa24015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_40_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwa24015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797319.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797319.protein.info.v11.5.txt",
		        "node_list_path": "1797319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusSpOv096Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. OV096 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusSpOv096Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855314.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855314.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855314.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855314.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855314.protein.info.v11.5.txt",
		        "node_list_path": "1855314.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855314.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KosmotogaPacificaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kosmotoga pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KosmotogaPacificaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1330330.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1330330.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1330330.clusters.proteins.v11.5.txt",
		        "sequence_path": "1330330.protein.sequences.v11.5.fa",
		        "enrichment_path": "1330330.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1330330.protein.info.v11.5.txt",
		        "node_list_path": "1330330.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1330330.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TuberibacillusCalidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tuberibacillus calidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuberibacillusCalidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123405.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123405.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123405.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123405.protein.info.v11.5.txt",
		        "node_list_path": "1123405.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123405.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumOl1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium OL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumOl1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1504822.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1504822.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1504822.clusters.proteins.v11.5.txt",
		        "sequence_path": "1504822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1504822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1504822.protein.info.v11.5.txt",
		        "node_list_path": "1504822.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1504822.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumWce2004(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium WCE2004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumWce2004", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945890.protein.info.v11.5.txt",
		        "node_list_path": "1945890.protein.complete.v11.5.txt"
		    }
		]
    )()

def DysgonomonasMossii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas mossii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DysgonomonasMossii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742767.protein.sequences.v11.5.fa",
		        "enrichment_path": "742767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742767.protein.info.v11.5.txt",
		        "node_list_path": "742767.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPelagibacterSpRs39Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. RS39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPelagibacterSpRs39Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977864.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977864.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977864.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977864.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977864.protein.info.v11.5.txt",
		        "node_list_path": "1977864.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977864.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusAgnetisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus agnetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusAgnetisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "985762.clusters.info.v11.5.txt",
		        "cluster_tree_path": "985762.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "985762.clusters.proteins.v11.5.txt",
		        "sequence_path": "985762.protein.sequences.v11.5.fa",
		        "enrichment_path": "985762.protein.enrichment.terms.v11.5.txt",
		        "info_path": "985762.protein.info.v11.5.txt",
		        "node_list_path": "985762.cluster.nodes.v11.5.txt",
		        "edge_list_path": "985762.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AromatoleumTolulyticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aromatoleum tolulyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AromatoleumTolulyticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "34027.clusters.info.v11.5.txt",
		        "cluster_tree_path": "34027.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "34027.clusters.proteins.v11.5.txt",
		        "sequence_path": "34027.protein.sequences.v11.5.fa",
		        "enrichment_path": "34027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "34027.protein.info.v11.5.txt",
		        "node_list_path": "34027.cluster.nodes.v11.5.txt",
		        "edge_list_path": "34027.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesLavenduligriseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces lavenduligriseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesLavenduligriseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "67315.clusters.info.v11.5.txt",
		        "cluster_tree_path": "67315.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "67315.clusters.proteins.v11.5.txt",
		        "sequence_path": "67315.protein.sequences.v11.5.fa",
		        "enrichment_path": "67315.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67315.protein.info.v11.5.txt",
		        "node_list_path": "67315.cluster.nodes.v11.5.txt",
		        "edge_list_path": "67315.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarvinbryantiaFormatexigensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marvinbryantia formatexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarvinbryantiaFormatexigensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "478749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "478749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "478749.clusters.proteins.v11.5.txt",
		        "sequence_path": "478749.protein.sequences.v11.5.fa",
		        "enrichment_path": "478749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "478749.protein.info.v11.5.txt",
		        "node_list_path": "478749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "478749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerinicoccusProfundiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Serinicoccus profundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerinicoccusProfundiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1043205.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1043205.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1043205.clusters.proteins.v11.5.txt",
		        "sequence_path": "1043205.protein.sequences.v11.5.fa",
		        "enrichment_path": "1043205.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1043205.protein.info.v11.5.txt",
		        "node_list_path": "1043205.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1043205.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinosporangiumAlbum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sinosporangium album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinosporangiumAlbum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "504805.protein.sequences.v11.5.fa",
		        "enrichment_path": "504805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504805.protein.info.v11.5.txt",
		        "node_list_path": "504805.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTerrybacteriaBacteriumRifcsphigho201Full5815Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPHIGHO2_01_FULL_58_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsphigho201Full5815Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802363.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802363.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802363.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802363.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802363.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802363.protein.info.v11.5.txt",
		        "node_list_path": "1802363.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802363.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParamesorhizobiumDesertiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paramesorhizobium deserti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParamesorhizobiumDesertiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1494590.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1494590.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1494590.clusters.proteins.v11.5.txt",
		        "sequence_path": "1494590.protein.sequences.v11.5.fa",
		        "enrichment_path": "1494590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1494590.protein.info.v11.5.txt",
		        "node_list_path": "1494590.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1494590.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaRattiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella ratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaRattiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883156.clusters.proteins.v11.5.txt",
		        "sequence_path": "883156.protein.sequences.v11.5.fa",
		        "enrichment_path": "883156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883156.protein.info.v11.5.txt",
		        "node_list_path": "883156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSolimangroviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus solimangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSolimangroviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1305675.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1305675.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1305675.clusters.proteins.v11.5.txt",
		        "sequence_path": "1305675.protein.sequences.v11.5.fa",
		        "enrichment_path": "1305675.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1305675.protein.info.v11.5.txt",
		        "node_list_path": "1305675.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1305675.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpCipa165Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIPA165 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpCipa165Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "40373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "40373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "40373.clusters.proteins.v11.5.txt",
		        "sequence_path": "40373.protein.sequences.v11.5.fa",
		        "enrichment_path": "40373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40373.protein.info.v11.5.txt",
		        "node_list_path": "40373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "40373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumPhsc20c1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium PHSC20C1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumPhsc20c1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "312284.protein.sequences.v11.5.fa",
		        "enrichment_path": "312284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "312284.protein.info.v11.5.txt",
		        "node_list_path": "312284.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpD20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. D20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpD20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "585543.clusters.info.v11.5.txt",
		        "cluster_tree_path": "585543.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "585543.clusters.proteins.v11.5.txt",
		        "sequence_path": "585543.protein.sequences.v11.5.fa",
		        "enrichment_path": "585543.protein.enrichment.terms.v11.5.txt",
		        "info_path": "585543.protein.info.v11.5.txt",
		        "node_list_path": "585543.cluster.nodes.v11.5.txt",
		        "edge_list_path": "585543.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumAlsenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium alsense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumAlsenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "324058.clusters.info.v11.5.txt",
		        "cluster_tree_path": "324058.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "324058.clusters.proteins.v11.5.txt",
		        "sequence_path": "324058.protein.sequences.v11.5.fa",
		        "enrichment_path": "324058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "324058.protein.info.v11.5.txt",
		        "node_list_path": "324058.cluster.nodes.v11.5.txt",
		        "edge_list_path": "324058.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5417(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_54_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5417", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798664.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798664.protein.info.v11.5.txt",
		        "node_list_path": "1798664.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalolactibacillusMiurensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halolactibacillus miurensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalolactibacillusMiurensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "306541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "306541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "306541.clusters.proteins.v11.5.txt",
		        "sequence_path": "306541.protein.sequences.v11.5.fa",
		        "enrichment_path": "306541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306541.protein.info.v11.5.txt",
		        "node_list_path": "306541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "306541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomyceteKsu1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return planctomycete KSU1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomyceteKsu1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "247490.protein.sequences.v11.5.fa",
		        "enrichment_path": "247490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247490.protein.info.v11.5.txt",
		        "node_list_path": "247490.protein.complete.v11.5.txt"
		    }
		]
    )()

def VeillonellaParvulaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella parvula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaParvulaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "479436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "479436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "479436.clusters.proteins.v11.5.txt",
		        "sequence_path": "479436.protein.sequences.v11.5.fa",
		        "enrichment_path": "479436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479436.protein.info.v11.5.txt",
		        "node_list_path": "479436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "479436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfitobacterSpMm124Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. MM124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfitobacterSpMm124Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1342299.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1342299.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1342299.clusters.proteins.v11.5.txt",
		        "sequence_path": "1342299.protein.sequences.v11.5.fa",
		        "enrichment_path": "1342299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1342299.protein.info.v11.5.txt",
		        "node_list_path": "1342299.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1342299.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumGambriniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium gambrini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumGambriniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "373672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "373672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "373672.clusters.proteins.v11.5.txt",
		        "sequence_path": "373672.protein.sequences.v11.5.fa",
		        "enrichment_path": "373672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "373672.protein.info.v11.5.txt",
		        "node_list_path": "373672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "373672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AbiotrophiaDefectivaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Abiotrophia defectiva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AbiotrophiaDefectivaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "592010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "592010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "592010.clusters.proteins.v11.5.txt",
		        "sequence_path": "592010.protein.sequences.v11.5.fa",
		        "enrichment_path": "592010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592010.protein.info.v11.5.txt",
		        "node_list_path": "592010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "592010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumHominisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumHominisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "420404.clusters.info.v11.5.txt",
		        "cluster_tree_path": "420404.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "420404.clusters.proteins.v11.5.txt",
		        "sequence_path": "420404.protein.sequences.v11.5.fa",
		        "enrichment_path": "420404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420404.protein.info.v11.5.txt",
		        "node_list_path": "420404.cluster.nodes.v11.5.txt",
		        "edge_list_path": "420404.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaTamiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella tamiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaTamiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1094558.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1094558.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1094558.clusters.proteins.v11.5.txt",
		        "sequence_path": "1094558.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094558.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094558.protein.info.v11.5.txt",
		        "node_list_path": "1094558.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1094558.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaAncashensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella ancashensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaAncashensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1318743.protein.sequences.v11.5.fa",
		        "enrichment_path": "1318743.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1318743.protein.info.v11.5.txt",
		        "node_list_path": "1318743.protein.complete.v11.5.txt"
		    }
		]
    )()

def GoniumPectoraleCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gonium pectorale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GoniumPectoraleCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "33097.clusters.info.v11.5.txt",
		        "cluster_tree_path": "33097.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "33097.clusters.proteins.v11.5.txt",
		        "sequence_path": "33097.protein.sequences.v11.5.fa",
		        "enrichment_path": "33097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33097.protein.info.v11.5.txt",
		        "node_list_path": "33097.cluster.nodes.v11.5.txt",
		        "edge_list_path": "33097.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SediminibacteriumSalmoneumNbrc103935(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium salmoneum NBRC 103935 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SediminibacteriumSalmoneumNbrc103935", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1400522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400522.protein.info.v11.5.txt",
		        "node_list_path": "1400522.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusThermokryptusMobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thermokryptus mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusThermokryptusMobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1643428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643428.protein.info.v11.5.txt",
		        "node_list_path": "1643428.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasSp23gom1509m(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. 23GOM1509m graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSp23gom1509m", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1380358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380358.protein.info.v11.5.txt",
		        "node_list_path": "1380358.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemellaCuniculi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemella cuniculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaCuniculi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121914.protein.info.v11.5.txt",
		        "node_list_path": "1121914.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobialesBacteriumNrl2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium NRL2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobialesBacteriumNrl2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1862950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1862950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1862950.protein.info.v11.5.txt",
		        "node_list_path": "1862950.protein.complete.v11.5.txt"
		    }
		]
    )()

def GallusGallusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallus gallus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GallusGallusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9031.clusters.proteins.v11.5.txt",
		        "sequence_path": "9031.protein.sequences.v11.5.fa",
		        "enrichment_path": "9031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9031.protein.info.v11.5.txt",
		        "node_list_path": "9031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaPhymatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phymatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaPhymatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391038.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391038.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391038.clusters.proteins.v11.5.txt",
		        "sequence_path": "391038.protein.sequences.v11.5.fa",
		        "enrichment_path": "391038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391038.protein.info.v11.5.txt",
		        "node_list_path": "391038.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391038.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLevybacteriaBacteriumRifcsphigho202Full3713Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_37_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full3713Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798602.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798602.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798602.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798602.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798602.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798602.protein.info.v11.5.txt",
		        "node_list_path": "1798602.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798602.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TranquillimonasAlkanivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tranquillimonas alkanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TranquillimonasAlkanivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "441119.protein.sequences.v11.5.fa",
		        "enrichment_path": "441119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "441119.protein.info.v11.5.txt",
		        "node_list_path": "441119.protein.complete.v11.5.txt"
		    }
		]
    )()

def KetogulonicigeniumVulgare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ketogulonicigenium vulgare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KetogulonicigeniumVulgare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "759362.protein.sequences.v11.5.fa",
		        "enrichment_path": "759362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "759362.protein.info.v11.5.txt",
		        "node_list_path": "759362.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSunkii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sunkii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSunkii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "481719.protein.sequences.v11.5.fa",
		        "enrichment_path": "481719.protein.enrichment.terms.v11.5.txt",
		        "info_path": "481719.protein.info.v11.5.txt",
		        "node_list_path": "481719.protein.complete.v11.5.txt"
		    }
		]
    )()

def IzhakiellaAustraliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Izhakiella australiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IzhakiellaAustraliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1926881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1926881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1926881.clusters.proteins.v11.5.txt",
		        "sequence_path": "1926881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1926881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1926881.protein.info.v11.5.txt",
		        "node_list_path": "1926881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1926881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CribrihabitansMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cribrihabitans marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CribrihabitansMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227549.protein.info.v11.5.txt",
		        "node_list_path": "1227549.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaAlliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea allii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaAlliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "574096.clusters.info.v11.5.txt",
		        "cluster_tree_path": "574096.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "574096.clusters.proteins.v11.5.txt",
		        "sequence_path": "574096.protein.sequences.v11.5.fa",
		        "enrichment_path": "574096.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574096.protein.info.v11.5.txt",
		        "node_list_path": "574096.cluster.nodes.v11.5.txt",
		        "edge_list_path": "574096.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpUnc267mfsha11m11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UNC267MFSha1.1M11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpUnc267mfsha11m11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502745.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502745.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502745.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502745.protein.info.v11.5.txt",
		        "node_list_path": "1502745.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502745.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SutterellaWadsworthensis3145bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis 3145B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SutterellaWadsworthensis3145bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "742821.clusters.info.v11.5.txt",
		        "cluster_tree_path": "742821.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "742821.clusters.proteins.v11.5.txt",
		        "sequence_path": "742821.protein.sequences.v11.5.fa",
		        "enrichment_path": "742821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742821.protein.info.v11.5.txt",
		        "node_list_path": "742821.cluster.nodes.v11.5.txt",
		        "edge_list_path": "742821.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumZagget3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Zagget3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumZagget3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1930016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1930016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1930016.clusters.proteins.v11.5.txt",
		        "sequence_path": "1930016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1930016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1930016.protein.info.v11.5.txt",
		        "node_list_path": "1930016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1930016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobaculumSpF0552(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum sp. F0552 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobaculumSpF0552", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227261.protein.info.v11.5.txt",
		        "node_list_path": "1227261.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf23316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_33_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf23316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797341.protein.info.v11.5.txt",
		        "node_list_path": "1797341.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobiumSpYl23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. YL23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumSpYl23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1335760.protein.sequences.v11.5.fa",
		        "enrichment_path": "1335760.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1335760.protein.info.v11.5.txt",
		        "node_list_path": "1335760.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumAlkaliphilum121Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium alkaliphilum 12/1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumAlkaliphilum121Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "506480.clusters.info.v11.5.txt",
		        "cluster_tree_path": "506480.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "506480.clusters.proteins.v11.5.txt",
		        "sequence_path": "506480.protein.sequences.v11.5.fa",
		        "enrichment_path": "506480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "506480.protein.info.v11.5.txt",
		        "node_list_path": "506480.cluster.nodes.v11.5.txt",
		        "edge_list_path": "506480.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermococcusNautili(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus nautili graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermococcusNautili", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "195522.protein.sequences.v11.5.fa",
		        "enrichment_path": "195522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "195522.protein.info.v11.5.txt",
		        "node_list_path": "195522.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumSaphenumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium saphenum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumSaphenumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "592031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "592031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "592031.clusters.proteins.v11.5.txt",
		        "sequence_path": "592031.protein.sequences.v11.5.fa",
		        "enrichment_path": "592031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "592031.protein.info.v11.5.txt",
		        "node_list_path": "592031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "592031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AureimonasFrigidaquae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aureimonas frigidaquae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AureimonasFrigidaquae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "424757.protein.sequences.v11.5.fa",
		        "enrichment_path": "424757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "424757.protein.info.v11.5.txt",
		        "node_list_path": "424757.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpC01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpC01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945856.protein.info.v11.5.txt",
		        "node_list_path": "1945856.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusMarimammaliumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus marimammalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusMarimammaliumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123306.protein.info.v11.5.txt",
		        "node_list_path": "1123306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyroidesGuanonis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myroides guanonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyroidesGuanonis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1150112.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150112.protein.info.v11.5.txt",
		        "node_list_path": "1150112.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaAlbensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella albensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaAlbensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122978.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122978.protein.info.v11.5.txt",
		        "node_list_path": "1122978.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterHeraklionensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter heraklionensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterHeraklionensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "512402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "512402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "512402.clusters.proteins.v11.5.txt",
		        "sequence_path": "512402.protein.sequences.v11.5.fa",
		        "enrichment_path": "512402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "512402.protein.info.v11.5.txt",
		        "node_list_path": "512402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "512402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeefgeaRivuliDsm18356(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deefgea rivuli DSM 18356 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeefgeaRivuliDsm18356", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121375.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121375.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121375.protein.info.v11.5.txt",
		        "node_list_path": "1121375.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZetaproteobacteriaBacteriumCg1024923(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_49_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaproteobacteriaBacteriumCg1024923", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805426.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805426.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805426.protein.info.v11.5.txt",
		        "node_list_path": "1805426.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryptococcusNeoformans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus neoformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptococcusNeoformans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "5207.protein.sequences.v11.5.fa",
		        "enrichment_path": "5207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5207.protein.info.v11.5.txt",
		        "node_list_path": "5207.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaribacterStanieriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter stanieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterStanieriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "440514.clusters.info.v11.5.txt",
		        "cluster_tree_path": "440514.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "440514.clusters.proteins.v11.5.txt",
		        "sequence_path": "440514.protein.sequences.v11.5.fa",
		        "enrichment_path": "440514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "440514.protein.info.v11.5.txt",
		        "node_list_path": "440514.cluster.nodes.v11.5.txt",
		        "edge_list_path": "440514.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlS4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRL S-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlS4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1519471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1519471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1519471.clusters.proteins.v11.5.txt",
		        "sequence_path": "1519471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1519471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1519471.protein.info.v11.5.txt",
		        "node_list_path": "1519471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1519471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeribacterRiflensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacter riflensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeribacterRiflensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1735162.protein.sequences.v11.5.fa",
		        "enrichment_path": "1735162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1735162.protein.info.v11.5.txt",
		        "node_list_path": "1735162.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFirestonebacteriaBacteriumRifoxya2Full408Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Firestonebacteria bacterium RIFOXYA2_FULL_40_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFirestonebacteriaBacteriumRifoxya2Full408Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817859.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817859.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817859.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817859.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817859.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817859.protein.info.v11.5.txt",
		        "node_list_path": "1817859.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817859.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpF0384Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0384 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpF0384Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "944560.clusters.info.v11.5.txt",
		        "cluster_tree_path": "944560.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "944560.clusters.proteins.v11.5.txt",
		        "sequence_path": "944560.protein.sequences.v11.5.fa",
		        "enrichment_path": "944560.protein.enrichment.terms.v11.5.txt",
		        "info_path": "944560.protein.info.v11.5.txt",
		        "node_list_path": "944560.cluster.nodes.v11.5.txt",
		        "edge_list_path": "944560.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeonectriaDitissimaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neonectria ditissima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeonectriaDitissimaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "78410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "78410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "78410.clusters.proteins.v11.5.txt",
		        "sequence_path": "78410.protein.sequences.v11.5.fa",
		        "enrichment_path": "78410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78410.protein.info.v11.5.txt",
		        "node_list_path": "78410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "78410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KushneriaSpYcwa18Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kushneria sp. YCWA18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KushneriaSpYcwa18Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "657387.clusters.info.v11.5.txt",
		        "cluster_tree_path": "657387.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "657387.clusters.proteins.v11.5.txt",
		        "sequence_path": "657387.protein.sequences.v11.5.fa",
		        "enrichment_path": "657387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "657387.protein.info.v11.5.txt",
		        "node_list_path": "657387.cluster.nodes.v11.5.txt",
		        "edge_list_path": "657387.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesSpHgb5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. HGB5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesSpHgb5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "908612.protein.sequences.v11.5.fa",
		        "enrichment_path": "908612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "908612.protein.info.v11.5.txt",
		        "node_list_path": "908612.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusIndolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus indolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusIndolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "997350.protein.sequences.v11.5.fa",
		        "enrichment_path": "997350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "997350.protein.info.v11.5.txt",
		        "node_list_path": "997350.protein.complete.v11.5.txt"
		    }
		]
    )()

def EctothiorhodospiraMarina(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ectothiorhodospira marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EctothiorhodospiraMarina", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1396821.protein.sequences.v11.5.fa",
		        "enrichment_path": "1396821.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1396821.protein.info.v11.5.txt",
		        "node_list_path": "1396821.protein.complete.v11.5.txt"
		    }
		]
    )()

def MassiliaNamucuonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia namucuonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaNamucuonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035707.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035707.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035707.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035707.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035707.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035707.protein.info.v11.5.txt",
		        "node_list_path": "1035707.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035707.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhotodesmusBlepharus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photodesmus blepharus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotodesmusBlepharus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1179155.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179155.protein.info.v11.5.txt",
		        "node_list_path": "1179155.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaLongaSw024Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina longa SW024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaLongaSw024Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379258.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379258.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379258.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379258.protein.info.v11.5.txt",
		        "node_list_path": "1379258.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379258.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFarciminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus farciminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFarciminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "936140.clusters.info.v11.5.txt",
		        "cluster_tree_path": "936140.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "936140.clusters.proteins.v11.5.txt",
		        "sequence_path": "936140.protein.sequences.v11.5.fa",
		        "enrichment_path": "936140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "936140.protein.info.v11.5.txt",
		        "node_list_path": "936140.cluster.nodes.v11.5.txt",
		        "edge_list_path": "936140.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4112Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4112Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801774.protein.info.v11.5.txt",
		        "node_list_path": "1801774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobiusMediterraneus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thalassobius mediterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobiusMediterraneus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "340021.protein.sequences.v11.5.fa",
		        "enrichment_path": "340021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "340021.protein.info.v11.5.txt",
		        "node_list_path": "340021.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaSpongiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina spongiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaSpongiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "570521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "570521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "570521.clusters.proteins.v11.5.txt",
		        "sequence_path": "570521.protein.sequences.v11.5.fa",
		        "enrichment_path": "570521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570521.protein.info.v11.5.txt",
		        "node_list_path": "570521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "570521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ColwelliaMytili(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia mytili graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColwelliaMytili", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1888913.protein.sequences.v11.5.fa",
		        "enrichment_path": "1888913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1888913.protein.info.v11.5.txt",
		        "node_list_path": "1888913.protein.complete.v11.5.txt"
		    }
		]
    )()

def SerratiaPlymuthica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia plymuthica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaPlymuthica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "82996.protein.sequences.v11.5.fa",
		        "enrichment_path": "82996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "82996.protein.info.v11.5.txt",
		        "node_list_path": "82996.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaGenomosp8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaGenomosp8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1416806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416806.protein.info.v11.5.txt",
		        "node_list_path": "1416806.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumHeidelbergenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium heidelbergense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumHeidelbergenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53376.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53376.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53376.clusters.proteins.v11.5.txt",
		        "sequence_path": "53376.protein.sequences.v11.5.fa",
		        "enrichment_path": "53376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53376.protein.info.v11.5.txt",
		        "node_list_path": "53376.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53376.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpAap43Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. AAP43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpAap43Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1523420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1523420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1523420.clusters.proteins.v11.5.txt",
		        "sequence_path": "1523420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1523420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1523420.protein.info.v11.5.txt",
		        "node_list_path": "1523420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1523420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GillisiaSpHeli29(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gillisia sp. HelI29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GillisiaSpHeli29", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1249975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1249975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1249975.protein.info.v11.5.txt",
		        "node_list_path": "1249975.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasVranovensisDsm16006Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas vranovensis DSM 16006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasVranovensisDsm16006Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1292031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1292031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1292031.clusters.proteins.v11.5.txt",
		        "sequence_path": "1292031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1292031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1292031.protein.info.v11.5.txt",
		        "node_list_path": "1292031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1292031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaFonticolaRb25(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia fonticola RB25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaFonticolaRb25", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1441930.protein.sequences.v11.5.fa",
		        "enrichment_path": "1441930.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1441930.protein.info.v11.5.txt",
		        "node_list_path": "1441930.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsilocybeCyanescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psilocybe cyanescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsilocybeCyanescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "93625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "93625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "93625.clusters.proteins.v11.5.txt",
		        "sequence_path": "93625.protein.sequences.v11.5.fa",
		        "enrichment_path": "93625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93625.protein.info.v11.5.txt",
		        "node_list_path": "93625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "93625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlistipesMarseilloanorexicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes marseilloanorexicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlistipesMarseilloanorexicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211813.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211813.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211813.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211813.protein.info.v11.5.txt",
		        "node_list_path": "1211813.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211813.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusSpCag382Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:382 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusSpCag382Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262957.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262957.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262957.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262957.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262957.protein.info.v11.5.txt",
		        "node_list_path": "1262957.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262957.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonadalesBacteriumGa0077531Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium Ga0077531 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonadalesBacteriumGa0077531Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752231.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752231.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752231.protein.info.v11.5.txt",
		        "node_list_path": "1752231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferDonghaiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer donghaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferDonghaiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "494016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "494016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "494016.clusters.proteins.v11.5.txt",
		        "sequence_path": "494016.protein.sequences.v11.5.fa",
		        "enrichment_path": "494016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "494016.protein.info.v11.5.txt",
		        "node_list_path": "494016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "494016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumCg2304514(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium CG2_30_45_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumCg2304514", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805255.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805255.protein.info.v11.5.txt",
		        "node_list_path": "1805255.protein.complete.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumCag1295924Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:129_59_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumCag1295924Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897028.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897028.protein.info.v11.5.txt",
		        "node_list_path": "1897028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaStercoreaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella stercorea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaStercoreaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1002367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1002367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1002367.clusters.proteins.v11.5.txt",
		        "sequence_path": "1002367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1002367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1002367.protein.info.v11.5.txt",
		        "node_list_path": "1002367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1002367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasNitroreducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasNitroreducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46680.protein.sequences.v11.5.fa",
		        "enrichment_path": "46680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46680.protein.info.v11.5.txt",
		        "node_list_path": "46680.protein.complete.v11.5.txt"
		    }
		]
    )()

def MalasseziaRestrictaCbs7877Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Malassezia restricta CBS 7877 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MalasseziaRestrictaCbs7877Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "425264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "425264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "425264.clusters.proteins.v11.5.txt",
		        "sequence_path": "425264.protein.sequences.v11.5.fa",
		        "enrichment_path": "425264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425264.protein.info.v11.5.txt",
		        "node_list_path": "425264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "425264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarineGroupIThaumarchaeoteScgcAb629i23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote SCGC AB629I23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarineGroupIThaumarchaeoteScgcAb629i23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131266.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131266.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131266.protein.info.v11.5.txt",
		        "node_list_path": "1131266.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitricoccusSpCh26a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citricoccus sp. CH26A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitricoccusSpCh26a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1045009.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045009.protein.info.v11.5.txt",
		        "node_list_path": "1045009.protein.complete.v11.5.txt"
		    }
		]
    )()

def FacklamiaHominisCcug36813Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Facklamia hominis CCUG 36813 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FacklamiaHominisCcug36813Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "883111.clusters.info.v11.5.txt",
		        "cluster_tree_path": "883111.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "883111.clusters.proteins.v11.5.txt",
		        "sequence_path": "883111.protein.sequences.v11.5.fa",
		        "enrichment_path": "883111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883111.protein.info.v11.5.txt",
		        "node_list_path": "883111.cluster.nodes.v11.5.txt",
		        "edge_list_path": "883111.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaFuscaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella fusca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaFuscaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1236517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1236517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1236517.clusters.proteins.v11.5.txt",
		        "sequence_path": "1236517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236517.protein.info.v11.5.txt",
		        "node_list_path": "1236517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1236517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TinamusGuttatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tinamus guttatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TinamusGuttatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "94827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "94827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "94827.clusters.proteins.v11.5.txt",
		        "sequence_path": "94827.protein.sequences.v11.5.fa",
		        "enrichment_path": "94827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94827.protein.info.v11.5.txt",
		        "node_list_path": "94827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "94827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastococcusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1211815.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1211815.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1211815.clusters.proteins.v11.5.txt",
		        "sequence_path": "1211815.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211815.protein.info.v11.5.txt",
		        "node_list_path": "1211815.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1211815.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb14014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_40_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb14014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618865.protein.info.v11.5.txt",
		        "node_list_path": "1618865.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeoglobusAhangari(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geoglobus ahangari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeoglobusAhangari", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "113653.protein.sequences.v11.5.fa",
		        "enrichment_path": "113653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113653.protein.info.v11.5.txt",
		        "node_list_path": "113653.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShinellaSpDd12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shinella sp. DD12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShinellaSpDd12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410620.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410620.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410620.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410620.protein.info.v11.5.txt",
		        "node_list_path": "1410620.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410620.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumParaseoulenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium paraseoulense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumParaseoulenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "590652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "590652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "590652.clusters.proteins.v11.5.txt",
		        "sequence_path": "590652.protein.sequences.v11.5.fa",
		        "enrichment_path": "590652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "590652.protein.info.v11.5.txt",
		        "node_list_path": "590652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "590652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicromonosporaParvaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora parva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaParvaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1464048.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1464048.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1464048.clusters.proteins.v11.5.txt",
		        "sequence_path": "1464048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1464048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1464048.protein.info.v11.5.txt",
		        "node_list_path": "1464048.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1464048.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LomentosporaProlificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lomentospora prolificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LomentosporaProlificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "41688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "41688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "41688.clusters.proteins.v11.5.txt",
		        "sequence_path": "41688.protein.sequences.v11.5.fa",
		        "enrichment_path": "41688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "41688.protein.info.v11.5.txt",
		        "node_list_path": "41688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "41688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpC1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. C-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpC1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "262667.protein.sequences.v11.5.fa",
		        "enrichment_path": "262667.protein.enrichment.terms.v11.5.txt",
		        "info_path": "262667.protein.info.v11.5.txt",
		        "node_list_path": "262667.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp4414(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 44_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp4414", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1896984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896984.protein.info.v11.5.txt",
		        "node_list_path": "1896984.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumLlatzerenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium llatzerense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumLlatzerenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "280871.clusters.info.v11.5.txt",
		        "cluster_tree_path": "280871.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "280871.clusters.proteins.v11.5.txt",
		        "sequence_path": "280871.protein.sequences.v11.5.fa",
		        "enrichment_path": "280871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "280871.protein.info.v11.5.txt",
		        "node_list_path": "280871.cluster.nodes.v11.5.txt",
		        "edge_list_path": "280871.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhycomycesBlakesleeanusNrrl1555(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phycomyces blakesleeanus NRRL 1555(-) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhycomycesBlakesleeanusNrrl1555", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "763407.protein.sequences.v11.5.fa",
		        "enrichment_path": "763407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "763407.protein.info.v11.5.txt",
		        "node_list_path": "763407.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusMarinusMit9313Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusMarinusMit9313Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "74547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "74547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "74547.clusters.proteins.v11.5.txt",
		        "sequence_path": "74547.protein.sequences.v11.5.fa",
		        "enrichment_path": "74547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74547.protein.info.v11.5.txt",
		        "node_list_path": "74547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "74547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicavibrioAeruginosavorusEpbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micavibrio aeruginosavorus EPB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicavibrioAeruginosavorusEpbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349215.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349215.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349215.clusters.proteins.v11.5.txt",
		        "sequence_path": "349215.protein.sequences.v11.5.fa",
		        "enrichment_path": "349215.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349215.protein.info.v11.5.txt",
		        "node_list_path": "349215.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349215.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SclerodermaCitrinumFougACluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scleroderma citrinum Foug A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SclerodermaCitrinumFougACluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1036808.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1036808.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1036808.clusters.proteins.v11.5.txt",
		        "sequence_path": "1036808.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036808.protein.info.v11.5.txt",
		        "node_list_path": "1036808.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1036808.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRbg166418(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_64_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRbg166418", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797477.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797477.protein.info.v11.5.txt",
		        "node_list_path": "1797477.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArmatimonadetesBacterium5513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium 55-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArmatimonadetesBacterium5513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895717.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895717.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895717.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895717.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895717.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895717.protein.info.v11.5.txt",
		        "node_list_path": "1895717.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895717.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifoxyd2Full4310(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYD2_FULL_43_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyd2Full4310", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802653.protein.info.v11.5.txt",
		        "node_list_path": "1802653.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSaccharophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium saccharophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSaccharophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29534.protein.sequences.v11.5.fa",
		        "enrichment_path": "29534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29534.protein.info.v11.5.txt",
		        "node_list_path": "29534.protein.complete.v11.5.txt"
		    }
		]
    )()

def EdwardsiellaHoshinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Edwardsiella hoshinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EdwardsiellaHoshinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1216966.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1216966.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1216966.clusters.proteins.v11.5.txt",
		        "sequence_path": "1216966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216966.protein.info.v11.5.txt",
		        "node_list_path": "1216966.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1216966.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TorrubiellaHemipterigena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Torrubiella hemipterigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TorrubiellaHemipterigena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1531966.protein.sequences.v11.5.fa",
		        "enrichment_path": "1531966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1531966.protein.info.v11.5.txt",
		        "node_list_path": "1531966.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpCag474(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:474 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpCag474", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262926.protein.info.v11.5.txt",
		        "node_list_path": "1262926.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThalassobaculumLitoreumDsm18839Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassobaculum litoreum DSM 18839 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobaculumLitoreumDsm18839Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123362.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123362.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123362.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123362.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123362.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123362.protein.info.v11.5.txt",
		        "node_list_path": "1123362.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123362.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterAsburiaeLf7aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter asburiae LF7a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterAsburiaeLf7aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "640513.clusters.info.v11.5.txt",
		        "cluster_tree_path": "640513.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "640513.clusters.proteins.v11.5.txt",
		        "sequence_path": "640513.protein.sequences.v11.5.fa",
		        "enrichment_path": "640513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640513.protein.info.v11.5.txt",
		        "node_list_path": "640513.cluster.nodes.v11.5.txt",
		        "edge_list_path": "640513.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrococcusRivularisNies593(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrococcus rivularis NIES-593 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrococcusRivularisNies593", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1921803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921803.protein.info.v11.5.txt",
		        "node_list_path": "1921803.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumYsd2013Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium YSD2013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumYsd2013Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520828.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520828.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520828.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520828.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520828.protein.info.v11.5.txt",
		        "node_list_path": "1520828.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520828.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MoniliophthoraRoreriMca2997Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Moniliophthora roreri MCA 2997 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MoniliophthoraRoreriMca2997Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1381753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1381753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1381753.clusters.proteins.v11.5.txt",
		        "sequence_path": "1381753.protein.sequences.v11.5.fa",
		        "enrichment_path": "1381753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1381753.protein.info.v11.5.txt",
		        "node_list_path": "1381753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1381753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WallemiaSebi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wallemia sebi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WallemiaSebi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "148960.protein.sequences.v11.5.fa",
		        "enrichment_path": "148960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "148960.protein.info.v11.5.txt",
		        "node_list_path": "148960.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatrinemaPallidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natrinema pallidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatrinemaPallidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227495.protein.info.v11.5.txt",
		        "node_list_path": "1227495.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5525Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_55_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5525Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798517.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798517.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798517.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798517.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798517.protein.info.v11.5.txt",
		        "node_list_path": "1798517.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798517.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaHofstadiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia hofstadii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaHofstadiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634994.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634994.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634994.clusters.proteins.v11.5.txt",
		        "sequence_path": "634994.protein.sequences.v11.5.fa",
		        "enrichment_path": "634994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634994.protein.info.v11.5.txt",
		        "node_list_path": "634994.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634994.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraInfestansT304Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora infestans T30-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraInfestansT304Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "403677.clusters.info.v11.5.txt",
		        "cluster_tree_path": "403677.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "403677.clusters.proteins.v11.5.txt",
		        "sequence_path": "403677.protein.sequences.v11.5.fa",
		        "enrichment_path": "403677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "403677.protein.info.v11.5.txt",
		        "node_list_path": "403677.cluster.nodes.v11.5.txt",
		        "edge_list_path": "403677.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpK4410Mgs306Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. K4410.MGS-306 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpK4410Mgs306Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1637501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1637501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1637501.clusters.proteins.v11.5.txt",
		        "sequence_path": "1637501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1637501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1637501.protein.info.v11.5.txt",
		        "node_list_path": "1637501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1637501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlagellimonasFlava(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flagellimonas flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlagellimonasFlava", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "570519.protein.sequences.v11.5.fa",
		        "enrichment_path": "570519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "570519.protein.info.v11.5.txt",
		        "node_list_path": "570519.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusEpidermidisRp62aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis RP62A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusEpidermidisRp62aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "176279.clusters.info.v11.5.txt",
		        "cluster_tree_path": "176279.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "176279.clusters.proteins.v11.5.txt",
		        "sequence_path": "176279.protein.sequences.v11.5.fa",
		        "enrichment_path": "176279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "176279.protein.info.v11.5.txt",
		        "node_list_path": "176279.cluster.nodes.v11.5.txt",
		        "edge_list_path": "176279.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArabidopsisThaliana(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arabidopsis thaliana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArabidopsisThaliana", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3702.protein.sequences.v11.5.fa",
		        "enrichment_path": "3702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3702.protein.info.v11.5.txt",
		        "node_list_path": "3702.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpA47(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. A47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpA47", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1561217.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561217.protein.info.v11.5.txt",
		        "node_list_path": "1561217.protein.complete.v11.5.txt"
		    }
		]
    )()

def VariovoraxSpYr216Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax sp. YR216 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VariovoraxSpYr216Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1882828.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1882828.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1882828.clusters.proteins.v11.5.txt",
		        "sequence_path": "1882828.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882828.protein.info.v11.5.txt",
		        "node_list_path": "1882828.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1882828.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IxodesScapularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ixodes scapularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IxodesScapularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6945.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6945.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6945.clusters.proteins.v11.5.txt",
		        "sequence_path": "6945.protein.sequences.v11.5.fa",
		        "enrichment_path": "6945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6945.protein.info.v11.5.txt",
		        "node_list_path": "6945.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6945.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpiroforme(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium spiroforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpiroforme", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "428126.protein.sequences.v11.5.fa",
		        "enrichment_path": "428126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "428126.protein.info.v11.5.txt",
		        "node_list_path": "428126.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpCf299Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. CF299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpCf299Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500284.protein.info.v11.5.txt",
		        "node_list_path": "1500284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrankiaSpIso899(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. Iso899 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrankiaSpIso899", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1283283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283283.protein.info.v11.5.txt",
		        "node_list_path": "1283283.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProteiniphilumSaccharofermentans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Proteiniphilum saccharofermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProteiniphilumSaccharofermentans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1642647.protein.sequences.v11.5.fa",
		        "enrichment_path": "1642647.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1642647.protein.info.v11.5.txt",
		        "node_list_path": "1642647.protein.complete.v11.5.txt"
		    }
		]
    )()

def MartelellaMediterraneaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Martelella mediterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MartelellaMediterraneaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122214.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122214.protein.info.v11.5.txt",
		        "node_list_path": "1122214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenorhabdusGriffiniaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus griffiniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusGriffiniaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351672.clusters.proteins.v11.5.txt",
		        "sequence_path": "351672.protein.sequences.v11.5.fa",
		        "enrichment_path": "351672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351672.protein.info.v11.5.txt",
		        "node_list_path": "351672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpDmb20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. DMB20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpDmb20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1642570.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1642570.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1642570.clusters.proteins.v11.5.txt",
		        "sequence_path": "1642570.protein.sequences.v11.5.fa",
		        "enrichment_path": "1642570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1642570.protein.info.v11.5.txt",
		        "node_list_path": "1642570.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1642570.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacterium2w06(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 2W06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacterium2w06", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1838287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1838287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1838287.protein.info.v11.5.txt",
		        "node_list_path": "1838287.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumMizutaiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium mizutaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumMizutaiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1010.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1010.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1010.clusters.proteins.v11.5.txt",
		        "sequence_path": "1010.protein.sequences.v11.5.fa",
		        "enrichment_path": "1010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1010.protein.info.v11.5.txt",
		        "node_list_path": "1010.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1010.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu058(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu058", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671653.protein.info.v11.5.txt",
		        "node_list_path": "1671653.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChelonoidisAbingdoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chelonoidis abingdonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChelonoidisAbingdoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "106734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "106734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "106734.clusters.proteins.v11.5.txt",
		        "sequence_path": "106734.protein.sequences.v11.5.fa",
		        "enrichment_path": "106734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "106734.protein.info.v11.5.txt",
		        "node_list_path": "106734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "106734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpHmsc067h01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. HMSC067H01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpHmsc067h01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1739491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1739491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1739491.protein.info.v11.5.txt",
		        "node_list_path": "1739491.protein.complete.v11.5.txt"
		    }
		]
    )()

def SolimonasAquatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Solimonas aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolimonasAquatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "489703.protein.sequences.v11.5.fa",
		        "enrichment_path": "489703.protein.enrichment.terms.v11.5.txt",
		        "info_path": "489703.protein.info.v11.5.txt",
		        "node_list_path": "489703.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfatiglansAniliniDsm4660Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfatiglans anilini DSM 4660 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfatiglansAniliniDsm4660Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121399.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121399.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121399.protein.info.v11.5.txt",
		        "node_list_path": "1121399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RobiginitomaculumAntarcticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Robiginitomaculum antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RobiginitomaculumAntarcticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123059.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123059.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123059.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123059.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123059.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123059.protein.info.v11.5.txt",
		        "node_list_path": "1123059.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123059.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusOrisratti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus orisratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusOrisratti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123311.protein.info.v11.5.txt",
		        "node_list_path": "1123311.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusViolaceofuscusCbs115571(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus violaceofuscus CBS 115571 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusViolaceofuscusCbs115571", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1450538.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450538.protein.info.v11.5.txt",
		        "node_list_path": "1450538.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanoplasmaTermitum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanoplasma termitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanoplasmaTermitum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577791.protein.info.v11.5.txt",
		        "node_list_path": "1577791.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylocaldumSzegedienseO12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylocaldum szegediense O-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylocaldumSzegedienseO12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675524.protein.sequences.v11.5.fa",
		        "enrichment_path": "675524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675524.protein.info.v11.5.txt",
		        "node_list_path": "675524.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpWb2n11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Wb2n-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpWb2n11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1030533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1030533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1030533.protein.info.v11.5.txt",
		        "node_list_path": "1030533.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaSpFb8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella sp. FB8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaSpFb8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1159870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159870.protein.info.v11.5.txt",
		        "node_list_path": "1159870.protein.complete.v11.5.txt"
		    }
		]
    )()

def BubalusBubalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bubalus bubalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BubalusBubalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "89462.clusters.info.v11.5.txt",
		        "cluster_tree_path": "89462.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "89462.clusters.proteins.v11.5.txt",
		        "sequence_path": "89462.protein.sequences.v11.5.fa",
		        "enrichment_path": "89462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "89462.protein.info.v11.5.txt",
		        "node_list_path": "89462.cluster.nodes.v11.5.txt",
		        "edge_list_path": "89462.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSmithiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus smithii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSmithiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665952.clusters.proteins.v11.5.txt",
		        "sequence_path": "665952.protein.sequences.v11.5.fa",
		        "enrichment_path": "665952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665952.protein.info.v11.5.txt",
		        "node_list_path": "665952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1898207.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1898207.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1898207.clusters.proteins.v11.5.txt",
		        "sequence_path": "1898207.protein.sequences.v11.5.fa",
		        "enrichment_path": "1898207.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1898207.protein.info.v11.5.txt",
		        "node_list_path": "1898207.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1898207.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErwiniaTracheiphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia tracheiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaTracheiphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "65700.clusters.info.v11.5.txt",
		        "cluster_tree_path": "65700.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "65700.clusters.proteins.v11.5.txt",
		        "sequence_path": "65700.protein.sequences.v11.5.fa",
		        "enrichment_path": "65700.protein.enrichment.terms.v11.5.txt",
		        "info_path": "65700.protein.info.v11.5.txt",
		        "node_list_path": "65700.cluster.nodes.v11.5.txt",
		        "edge_list_path": "65700.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusFascians(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus fascians graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusFascians", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1828.protein.sequences.v11.5.fa",
		        "enrichment_path": "1828.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1828.protein.info.v11.5.txt",
		        "node_list_path": "1828.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpRc3bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Rc3b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpRc3bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855322.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855322.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855322.protein.info.v11.5.txt",
		        "node_list_path": "1855322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalanaerobiumKushneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halanaerobium kushneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaerobiumKushneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56779.protein.sequences.v11.5.fa",
		        "enrichment_path": "56779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56779.protein.info.v11.5.txt",
		        "node_list_path": "56779.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerobiospirillumSucciniciproducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobiospirillum succiniciproducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobiospirillumSucciniciproducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120988.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120988.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120988.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120988.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120988.protein.info.v11.5.txt",
		        "node_list_path": "1120988.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120988.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCompetibacterDenitrificansRunAD11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Competibacter denitrificans Run_A_D11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCompetibacterDenitrificansRunAD11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1400863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400863.protein.info.v11.5.txt",
		        "node_list_path": "1400863.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumTaiwanense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium taiwanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumTaiwanense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "363331.protein.sequences.v11.5.fa",
		        "enrichment_path": "363331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "363331.protein.info.v11.5.txt",
		        "node_list_path": "363331.protein.complete.v11.5.txt"
		    }
		]
    )()

def DechloromonasAromaticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dechloromonas aromatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DechloromonasAromaticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "159087.clusters.info.v11.5.txt",
		        "cluster_tree_path": "159087.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "159087.clusters.proteins.v11.5.txt",
		        "sequence_path": "159087.protein.sequences.v11.5.fa",
		        "enrichment_path": "159087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "159087.protein.info.v11.5.txt",
		        "node_list_path": "159087.cluster.nodes.v11.5.txt",
		        "edge_list_path": "159087.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KlenkiaSoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Klenkia soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KlenkiaSoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1052260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1052260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1052260.clusters.proteins.v11.5.txt",
		        "sequence_path": "1052260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1052260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1052260.protein.info.v11.5.txt",
		        "node_list_path": "1052260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1052260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodopirellulaEuropaeaSh398(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopirellula europaea SH398 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodopirellulaEuropaeaSh398", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1263868.protein.sequences.v11.5.fa",
		        "enrichment_path": "1263868.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1263868.protein.info.v11.5.txt",
		        "node_list_path": "1263868.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumSeropedicae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum seropedicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumSeropedicae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "757424.protein.sequences.v11.5.fa",
		        "enrichment_path": "757424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "757424.protein.info.v11.5.txt",
		        "node_list_path": "757424.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumGa0077533Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium Ga0077533 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumGa0077533Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1752234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1752234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1752234.clusters.proteins.v11.5.txt",
		        "sequence_path": "1752234.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752234.protein.info.v11.5.txt",
		        "node_list_path": "1752234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1752234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuegeriaMarisrubri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria marisrubri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuegeriaMarisrubri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1685379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1685379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1685379.protein.info.v11.5.txt",
		        "node_list_path": "1685379.protein.complete.v11.5.txt"
		    }
		]
    )()

def CardiniumEndosymbiontCeper1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cardinium endosymbiont cEper1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CardiniumEndosymbiontCeper1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1231626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231626.protein.info.v11.5.txt",
		        "node_list_path": "1231626.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusManganicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus manganicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusManganicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1384049.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384049.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384049.protein.info.v11.5.txt",
		        "node_list_path": "1384049.protein.complete.v11.5.txt"
		    }
		]
    )()

def FormosaSpHel131208Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Formosa sp. Hel1_31_208 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaSpHel131208Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798225.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798225.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798225.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798225.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798225.protein.info.v11.5.txt",
		        "node_list_path": "1798225.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798225.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioAlcoholivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio alcoholivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioAlcoholivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121438.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121438.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121438.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121438.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121438.protein.info.v11.5.txt",
		        "node_list_path": "1121438.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121438.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CurvibacterLanceolatusAtcc14669(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter lanceolatus ATCC 14669 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurvibacterLanceolatusAtcc14669", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265504.protein.info.v11.5.txt",
		        "node_list_path": "1265504.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxHongdengensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax hongdengensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxHongdengensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1177179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177179.protein.info.v11.5.txt",
		        "node_list_path": "1177179.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaFeeleiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella feeleii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaFeeleiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "453.clusters.proteins.v11.5.txt",
		        "sequence_path": "453.protein.sequences.v11.5.fa",
		        "enrichment_path": "453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "453.protein.info.v11.5.txt",
		        "node_list_path": "453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardiopsisValliformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis valliformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisValliformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1246448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1246448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1246448.protein.info.v11.5.txt",
		        "node_list_path": "1246448.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrobacterSp6223Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrobacter sp. 62-23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrobacterSp6223Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895798.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895798.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895798.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895798.protein.info.v11.5.txt",
		        "node_list_path": "1895798.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895798.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChrysemysPictaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chrysemys picta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChrysemysPictaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8479.clusters.proteins.v11.5.txt",
		        "sequence_path": "8479.protein.sequences.v11.5.fa",
		        "enrichment_path": "8479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8479.protein.info.v11.5.txt",
		        "node_list_path": "8479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumBrumae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium brumae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumBrumae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "85968.protein.sequences.v11.5.fa",
		        "enrichment_path": "85968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "85968.protein.info.v11.5.txt",
		        "node_list_path": "85968.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaSaccharolyticaF0055Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella saccharolytica F0055 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSaccharolyticaF0055Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1127699.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1127699.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1127699.clusters.proteins.v11.5.txt",
		        "sequence_path": "1127699.protein.sequences.v11.5.fa",
		        "enrichment_path": "1127699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1127699.protein.info.v11.5.txt",
		        "node_list_path": "1127699.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1127699.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaBacteriumDg743Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_74_3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaBacteriumDg743Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703767.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703767.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703767.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703767.protein.info.v11.5.txt",
		        "node_list_path": "1703767.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703767.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerriglobusSaanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terriglobus saanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerriglobusSaanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "401053.protein.sequences.v11.5.fa",
		        "enrichment_path": "401053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "401053.protein.info.v11.5.txt",
		        "node_list_path": "401053.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCereusAtcc14579Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cereus ATCC 14579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCereusAtcc14579Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "226900.clusters.info.v11.5.txt",
		        "cluster_tree_path": "226900.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "226900.clusters.proteins.v11.5.txt",
		        "sequence_path": "226900.protein.sequences.v11.5.fa",
		        "enrichment_path": "226900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226900.protein.info.v11.5.txt",
		        "node_list_path": "226900.cluster.nodes.v11.5.txt",
		        "edge_list_path": "226900.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusReticulitermitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus reticulitermitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusReticulitermitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "856736.protein.sequences.v11.5.fa",
		        "enrichment_path": "856736.protein.enrichment.terms.v11.5.txt",
		        "info_path": "856736.protein.info.v11.5.txt",
		        "node_list_path": "856736.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpF0263(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0263 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpF0263", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321782.protein.info.v11.5.txt",
		        "node_list_path": "1321782.protein.complete.v11.5.txt"
		    }
		]
    )()

def NigeriumMassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nigerium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NigeriumMassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1522317.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522317.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522317.protein.info.v11.5.txt",
		        "node_list_path": "1522317.protein.complete.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwb26316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWB2_63_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwb26316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797928.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797928.protein.info.v11.5.txt",
		        "node_list_path": "1797928.protein.complete.v11.5.txt"
		    }
		]
    )()

def AhrensiaSpR2a130(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ahrensia sp. R2A130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AhrensiaSpR2a130", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "744979.protein.sequences.v11.5.fa",
		        "enrichment_path": "744979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "744979.protein.info.v11.5.txt",
		        "node_list_path": "744979.protein.complete.v11.5.txt"
		    }
		]
    )()

def GloeobacterViolaceus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gloeobacter violaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GloeobacterViolaceus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "251221.protein.sequences.v11.5.fa",
		        "enrichment_path": "251221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "251221.protein.info.v11.5.txt",
		        "node_list_path": "251221.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpSirexaae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. SirexAAE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpSirexaae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "862751.protein.sequences.v11.5.fa",
		        "enrichment_path": "862751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862751.protein.info.v11.5.txt",
		        "node_list_path": "862751.protein.complete.v11.5.txt"
		    }
		]
    )()

def ScheffersomycesStipitisCbs6054Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Scheffersomyces stipitis CBS 6054 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ScheffersomycesStipitisCbs6054Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "322104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "322104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "322104.clusters.proteins.v11.5.txt",
		        "sequence_path": "322104.protein.sequences.v11.5.fa",
		        "enrichment_path": "322104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "322104.protein.info.v11.5.txt",
		        "node_list_path": "322104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "322104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpL77Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. L77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpL77Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1496689.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1496689.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1496689.clusters.proteins.v11.5.txt",
		        "sequence_path": "1496689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1496689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1496689.protein.info.v11.5.txt",
		        "node_list_path": "1496689.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1496689.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full3914Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_39_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full3914Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797532.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797532.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797532.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797532.protein.info.v11.5.txt",
		        "node_list_path": "1797532.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797532.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EutypaLataUcrel1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eutypa lata UCREL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EutypaLataUcrel1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1287681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287681.protein.info.v11.5.txt",
		        "node_list_path": "1287681.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumC6a11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium C6A11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumC6a11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410622.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410622.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410622.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410622.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410622.protein.info.v11.5.txt",
		        "node_list_path": "1410622.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410622.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinitogaPiezophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinitoga piezophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinitogaPiezophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "443254.protein.sequences.v11.5.fa",
		        "enrichment_path": "443254.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443254.protein.info.v11.5.txt",
		        "node_list_path": "443254.protein.complete.v11.5.txt"
		    }
		]
    )()

def CatalinimonasAlkaloidigenaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Catalinimonas alkaloidigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatalinimonasAlkaloidigenaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1075417.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1075417.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1075417.clusters.proteins.v11.5.txt",
		        "sequence_path": "1075417.protein.sequences.v11.5.fa",
		        "enrichment_path": "1075417.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1075417.protein.info.v11.5.txt",
		        "node_list_path": "1075417.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1075417.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KordiaAlgicida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kordia algicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KordiaAlgicida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391587.protein.sequences.v11.5.fa",
		        "enrichment_path": "391587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391587.protein.info.v11.5.txt",
		        "node_list_path": "391587.protein.complete.v11.5.txt"
		    }
		]
    )()

def AidingimonasHalophila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aidingimonas halophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AidingimonasHalophila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "574349.protein.sequences.v11.5.fa",
		        "enrichment_path": "574349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "574349.protein.info.v11.5.txt",
		        "node_list_path": "574349.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalophilicArchaeonJ07hb67Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return halophilic archaeon J07HB67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalophilicArchaeonJ07hb67Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1085029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1085029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1085029.clusters.proteins.v11.5.txt",
		        "sequence_path": "1085029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1085029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1085029.protein.info.v11.5.txt",
		        "node_list_path": "1085029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1085029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumGw2011Gwf24332(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium GW2011_GWF2_43_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumGw2011Gwf24332", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618643.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618643.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618643.protein.info.v11.5.txt",
		        "node_list_path": "1618643.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4013(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_40_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4013", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802063.protein.info.v11.5.txt",
		        "node_list_path": "1802063.protein.complete.v11.5.txt"
		    }
		]
    )()

def CyclobacteriumQasimii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacterium qasimii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyclobacteriumQasimii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641524.protein.sequences.v11.5.fa",
		        "enrichment_path": "641524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641524.protein.info.v11.5.txt",
		        "node_list_path": "641524.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaDenitrificansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaDenitrificansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "318161.clusters.info.v11.5.txt",
		        "cluster_tree_path": "318161.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "318161.clusters.proteins.v11.5.txt",
		        "sequence_path": "318161.protein.sequences.v11.5.fa",
		        "enrichment_path": "318161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318161.protein.info.v11.5.txt",
		        "node_list_path": "318161.cluster.nodes.v11.5.txt",
		        "edge_list_path": "318161.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumCg1024326(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium CG1_02_43_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumCg1024326", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805421.protein.info.v11.5.txt",
		        "node_list_path": "1805421.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumEzzemoulense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum ezzemoulense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumEzzemoulense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121945.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121945.protein.info.v11.5.txt",
		        "node_list_path": "1121945.protein.complete.v11.5.txt"
		    }
		]
    )()

def HelicobacterSpMit016451(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT016451 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSpMit016451", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "425400.protein.sequences.v11.5.fa",
		        "enrichment_path": "425400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425400.protein.info.v11.5.txt",
		        "node_list_path": "425400.protein.complete.v11.5.txt"
		    }
		]
    )()

def CapraHircus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Capra hircus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapraHircus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9925.protein.sequences.v11.5.fa",
		        "enrichment_path": "9925.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9925.protein.info.v11.5.txt",
		        "node_list_path": "9925.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaSpA4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. A4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpA4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1225184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1225184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1225184.protein.info.v11.5.txt",
		        "node_list_path": "1225184.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumAcapulenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium acapulense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumAcapulenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "114977.clusters.info.v11.5.txt",
		        "cluster_tree_path": "114977.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "114977.clusters.proteins.v11.5.txt",
		        "sequence_path": "114977.protein.sequences.v11.5.fa",
		        "enrichment_path": "114977.protein.enrichment.terms.v11.5.txt",
		        "info_path": "114977.protein.info.v11.5.txt",
		        "node_list_path": "114977.cluster.nodes.v11.5.txt",
		        "edge_list_path": "114977.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpN5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. N5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpN5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1101189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1101189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1101189.clusters.proteins.v11.5.txt",
		        "sequence_path": "1101189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1101189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1101189.protein.info.v11.5.txt",
		        "node_list_path": "1101189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1101189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag356(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:356 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag356", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262800.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262800.protein.info.v11.5.txt",
		        "node_list_path": "1262800.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusFlorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus florum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFlorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1221537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1221537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1221537.clusters.proteins.v11.5.txt",
		        "sequence_path": "1221537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1221537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1221537.protein.info.v11.5.txt",
		        "node_list_path": "1221537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1221537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxSpP2s70Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. P2S70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxSpP2s70Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1397527.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1397527.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1397527.clusters.proteins.v11.5.txt",
		        "sequence_path": "1397527.protein.sequences.v11.5.fa",
		        "enrichment_path": "1397527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1397527.protein.info.v11.5.txt",
		        "node_list_path": "1397527.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1397527.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaVinsoniiSubspArupensisOk94513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella vinsonii subsp. arupensis OK-94-513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaVinsoniiSubspArupensisOk94513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094562.protein.info.v11.5.txt",
		        "node_list_path": "1094562.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDesantisbacteriaBacteriumCg2304021Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG2_30_40_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg2304021Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817895.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817895.protein.info.v11.5.txt",
		        "node_list_path": "1817895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesViridosporus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces viridosporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesViridosporus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665577.protein.sequences.v11.5.fa",
		        "enrichment_path": "665577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665577.protein.info.v11.5.txt",
		        "node_list_path": "665577.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3513Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_35_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3513Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802055.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802055.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802055.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802055.protein.info.v11.5.txt",
		        "node_list_path": "1802055.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802055.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusCaballi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus caballi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusCaballi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123298.protein.info.v11.5.txt",
		        "node_list_path": "1123298.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusClarkii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Bacillus] clarkii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusClarkii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "79879.protein.sequences.v11.5.fa",
		        "enrichment_path": "79879.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79879.protein.info.v11.5.txt",
		        "node_list_path": "79879.protein.complete.v11.5.txt"
		    }
		]
    )()

def BosGrunniens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bos grunniens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BosGrunniens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "30521.protein.sequences.v11.5.fa",
		        "enrichment_path": "30521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "30521.protein.info.v11.5.txt",
		        "node_list_path": "30521.protein.complete.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumRbg165411(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_54_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165411", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797842.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797842.protein.info.v11.5.txt",
		        "node_list_path": "1797842.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioPutealisDsm16056(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio putealis DSM 16056 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioPutealisDsm16056", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121462.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121462.protein.info.v11.5.txt",
		        "node_list_path": "1121462.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaemophilusHaemolyticusM19501Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M19501 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaemophilusHaemolyticusM19501Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1028803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1028803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1028803.clusters.proteins.v11.5.txt",
		        "sequence_path": "1028803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1028803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1028803.protein.info.v11.5.txt",
		        "node_list_path": "1028803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1028803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PenicilliumDigitatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium digitatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PenicilliumDigitatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36651.clusters.proteins.v11.5.txt",
		        "sequence_path": "36651.protein.sequences.v11.5.fa",
		        "enrichment_path": "36651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36651.protein.info.v11.5.txt",
		        "node_list_path": "36651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasCoronafaciensPvPorri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas coronafaciens pv. porri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasCoronafaciensPvPorri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83964.protein.sequences.v11.5.fa",
		        "enrichment_path": "83964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83964.protein.info.v11.5.txt",
		        "node_list_path": "83964.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanocaldococcusSpFs40622(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus sp. FS40622 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanocaldococcusSpFs40622", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "644281.protein.sequences.v11.5.fa",
		        "enrichment_path": "644281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "644281.protein.info.v11.5.txt",
		        "node_list_path": "644281.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospirillalesBacteriumRifcsplowo202Full5816(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium RIFCSPLOWO2_02_FULL_58_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillalesBacteriumRifcsplowo202Full5816", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802021.protein.info.v11.5.txt",
		        "node_list_path": "1802021.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrorhabdusChilensisDsm12352Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus chilensis DSM 12352 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrorhabdusChilensisDsm12352Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123515.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123515.protein.info.v11.5.txt",
		        "node_list_path": "1123515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OlsenellaUliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella uli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OlsenellaUliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "633147.clusters.info.v11.5.txt",
		        "cluster_tree_path": "633147.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "633147.clusters.proteins.v11.5.txt",
		        "sequence_path": "633147.protein.sequences.v11.5.fa",
		        "enrichment_path": "633147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633147.protein.info.v11.5.txt",
		        "node_list_path": "633147.cluster.nodes.v11.5.txt",
		        "edge_list_path": "633147.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpR575(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. R57-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpR575", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1610576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1610576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1610576.protein.info.v11.5.txt",
		        "node_list_path": "1610576.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumGw2011Gwc2459Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWC2_45_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwc2459Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618589.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618589.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618589.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618589.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618589.protein.info.v11.5.txt",
		        "node_list_path": "1618589.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618589.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaceaeBacteriumHun156(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotellaceae bacterium HUN156 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaceaeBacteriumHun156", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520830.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520830.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520830.protein.info.v11.5.txt",
		        "node_list_path": "1520830.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacterium3317(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 33-17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacterium3317", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895704.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895704.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895704.protein.info.v11.5.txt",
		        "node_list_path": "1895704.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudogulbenkianiaSubflavaDsm22618Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania subflava DSM 22618 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudogulbenkianiaSubflavaDsm22618Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123014.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123014.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123014.protein.info.v11.5.txt",
		        "node_list_path": "1123014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmorphusCoralliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amorphus coralli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmorphusCoralliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120983.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120983.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120983.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120983.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120983.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120983.protein.info.v11.5.txt",
		        "node_list_path": "1120983.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120983.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LewinellaSp4g2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lewinella sp. 4G2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LewinellaSp4g2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803372.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803372.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803372.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803372.protein.info.v11.5.txt",
		        "node_list_path": "1803372.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803372.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrachymonasDenitrificansDsm15123(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brachymonas denitrificans DSM 15123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrachymonasDenitrificansDsm15123", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121117.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121117.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121117.protein.info.v11.5.txt",
		        "node_list_path": "1121117.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusariumSpAf8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusariumSpAf8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1325734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1325734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1325734.clusters.proteins.v11.5.txt",
		        "sequence_path": "1325734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1325734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1325734.protein.info.v11.5.txt",
		        "node_list_path": "1325734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1325734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusLicheniformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus licheniformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusLicheniformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "279010.protein.sequences.v11.5.fa",
		        "enrichment_path": "279010.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279010.protein.info.v11.5.txt",
		        "node_list_path": "279010.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusYunnanensisNbrc103083Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus yunnanensis NBRC 103083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusYunnanensisNbrc103083Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219029.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219029.protein.info.v11.5.txt",
		        "node_list_path": "1219029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumRubiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium rubi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumRubiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1220582.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1220582.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1220582.clusters.proteins.v11.5.txt",
		        "sequence_path": "1220582.protein.sequences.v11.5.fa",
		        "enrichment_path": "1220582.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1220582.protein.info.v11.5.txt",
		        "node_list_path": "1220582.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1220582.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesDentalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces dentalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesDentalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120941.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120941.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120941.protein.info.v11.5.txt",
		        "node_list_path": "1120941.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermobacillusCompostiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermobacillus composti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermobacillusCompostiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "717605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "717605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "717605.clusters.proteins.v11.5.txt",
		        "sequence_path": "717605.protein.sequences.v11.5.fa",
		        "enrichment_path": "717605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "717605.protein.info.v11.5.txt",
		        "node_list_path": "717605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "717605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLloydbacteriaBacteriumRifcsplowo201Full5020Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPLOWO2_01_FULL_50_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsplowo201Full5020Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798665.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798665.protein.info.v11.5.txt",
		        "node_list_path": "1798665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasSpMed121(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. MED121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasSpMed121", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314277.protein.sequences.v11.5.fa",
		        "enrichment_path": "314277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314277.protein.info.v11.5.txt",
		        "node_list_path": "314277.protein.complete.v11.5.txt"
		    }
		]
    )()

def AfipiaSpOhsuic4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. OHSUIC4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AfipiaSpOhsuic4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1297863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1297863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1297863.clusters.proteins.v11.5.txt",
		        "sequence_path": "1297863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1297863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1297863.protein.info.v11.5.txt",
		        "node_list_path": "1297863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1297863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParaburkholderiaGinsengiterraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengiterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParaburkholderiaGinsengiterraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1462993.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1462993.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1462993.clusters.proteins.v11.5.txt",
		        "sequence_path": "1462993.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462993.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462993.protein.info.v11.5.txt",
		        "node_list_path": "1462993.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1462993.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpHgb0020(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. HGB0020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpHgb0020", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1078086.protein.sequences.v11.5.fa",
		        "enrichment_path": "1078086.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1078086.protein.info.v11.5.txt",
		        "node_list_path": "1078086.protein.complete.v11.5.txt"
		    }
		]
    )()

def HungateiclostridiumStraminisolvensJcm21531(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hungateiclostridium straminisolvens JCM 21531 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HungateiclostridiumStraminisolvensJcm21531", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1294263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1294263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1294263.protein.info.v11.5.txt",
		        "node_list_path": "1294263.protein.complete.v11.5.txt"
		    }
		]
    )()

def BhargavaeaGinsengi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bhargavaea ginsengi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BhargavaeaGinsengi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426757.protein.sequences.v11.5.fa",
		        "enrichment_path": "426757.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426757.protein.info.v11.5.txt",
		        "node_list_path": "426757.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumRbg135024(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RBG_13_50_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumRbg135024", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801962.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801962.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801962.protein.info.v11.5.txt",
		        "node_list_path": "1801962.protein.complete.v11.5.txt"
		    }
		]
    )()

def TilletiariaAnomalaUbc951Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tilletiaria anomala UBC 951 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TilletiariaAnomalaUbc951Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1037660.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1037660.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1037660.clusters.proteins.v11.5.txt",
		        "sequence_path": "1037660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1037660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1037660.protein.info.v11.5.txt",
		        "node_list_path": "1037660.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1037660.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4922b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_01_FULL_49_22b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4922b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802448.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802448.protein.info.v11.5.txt",
		        "node_list_path": "1802448.protein.complete.v11.5.txt"
		    }
		]
    )()

def CloacimonetesBacteriumWwei01(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium WWEI_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CloacimonetesBacteriumWwei01", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1674914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674914.protein.info.v11.5.txt",
		        "node_list_path": "1674914.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterEquiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter equi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterEquiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1324350.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1324350.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1324350.clusters.proteins.v11.5.txt",
		        "sequence_path": "1324350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1324350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1324350.protein.info.v11.5.txt",
		        "node_list_path": "1324350.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1324350.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanofollisLiminatansDsm4140(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanofollis liminatans DSM 4140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanofollisLiminatansDsm4140", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28892.protein.sequences.v11.5.fa",
		        "enrichment_path": "28892.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28892.protein.info.v11.5.txt",
		        "node_list_path": "28892.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumPaludis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium paludis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumPaludis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "868131.protein.sequences.v11.5.fa",
		        "enrichment_path": "868131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "868131.protein.info.v11.5.txt",
		        "node_list_path": "868131.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSwuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus swuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSwuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1178515.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1178515.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1178515.clusters.proteins.v11.5.txt",
		        "sequence_path": "1178515.protein.sequences.v11.5.fa",
		        "enrichment_path": "1178515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1178515.protein.info.v11.5.txt",
		        "node_list_path": "1178515.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1178515.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpCnh287Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNH287 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpCnh287Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288082.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288082.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288082.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288082.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288082.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288082.protein.info.v11.5.txt",
		        "node_list_path": "1288082.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288082.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseomonasAerilataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas aerilata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseomonasAerilataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123060.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123060.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123060.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123060.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123060.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123060.protein.info.v11.5.txt",
		        "node_list_path": "1123060.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123060.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpD5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. D5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpD5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "556261.protein.sequences.v11.5.fa",
		        "enrichment_path": "556261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "556261.protein.info.v11.5.txt",
		        "node_list_path": "556261.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterLwoffiiSh145(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii SH145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterLwoffiiSh145", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "575588.protein.sequences.v11.5.fa",
		        "enrichment_path": "575588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "575588.protein.info.v11.5.txt",
		        "node_list_path": "575588.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptotrichiaSpW9775(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. W9775 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptotrichiaSpW9775", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321779.protein.info.v11.5.txt",
		        "node_list_path": "1321779.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacterCrescentusCb15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter crescentus CB15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterCrescentusCb15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "190650.clusters.info.v11.5.txt",
		        "cluster_tree_path": "190650.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "190650.clusters.proteins.v11.5.txt",
		        "sequence_path": "190650.protein.sequences.v11.5.fa",
		        "enrichment_path": "190650.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190650.protein.info.v11.5.txt",
		        "node_list_path": "190650.cluster.nodes.v11.5.txt",
		        "edge_list_path": "190650.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudonajaTextilisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonaja textilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonajaTextilisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "8673.clusters.info.v11.5.txt",
		        "cluster_tree_path": "8673.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "8673.clusters.proteins.v11.5.txt",
		        "sequence_path": "8673.protein.sequences.v11.5.fa",
		        "enrichment_path": "8673.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8673.protein.info.v11.5.txt",
		        "node_list_path": "8673.cluster.nodes.v11.5.txt",
		        "edge_list_path": "8673.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWor1BacteriumRifoxyb2Full4235Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR-1 bacterium RIFOXYB2_FULL_42_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2Full4235Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802580.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802580.protein.info.v11.5.txt",
		        "node_list_path": "1802580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSp17376Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 17376 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp17376Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "977905.clusters.info.v11.5.txt",
		        "cluster_tree_path": "977905.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "977905.clusters.proteins.v11.5.txt",
		        "sequence_path": "977905.protein.sequences.v11.5.fa",
		        "enrichment_path": "977905.protein.enrichment.terms.v11.5.txt",
		        "info_path": "977905.protein.info.v11.5.txt",
		        "node_list_path": "977905.cluster.nodes.v11.5.txt",
		        "edge_list_path": "977905.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BellilineaCaldifistulae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bellilinea caldifistulae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BellilineaCaldifistulae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "360411.protein.sequences.v11.5.fa",
		        "enrichment_path": "360411.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360411.protein.info.v11.5.txt",
		        "node_list_path": "360411.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacteriumCg1024416(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_44_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024416", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805287.protein.info.v11.5.txt",
		        "node_list_path": "1805287.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParafilimonasTerrae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parafilimonas terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParafilimonasTerrae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1465490.protein.sequences.v11.5.fa",
		        "enrichment_path": "1465490.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1465490.protein.info.v11.5.txt",
		        "node_list_path": "1465490.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollinsellaSp4847faa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Collinsella sp. 4847FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaSp4847faa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742722.protein.sequences.v11.5.fa",
		        "enrichment_path": "742722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742722.protein.info.v11.5.txt",
		        "node_list_path": "742722.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusSclerotionigerCbs115572Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sclerotioniger CBS 115572 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusSclerotionigerCbs115572Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1450535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1450535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1450535.clusters.proteins.v11.5.txt",
		        "sequence_path": "1450535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1450535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1450535.protein.info.v11.5.txt",
		        "node_list_path": "1450535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1450535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferSpHz11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer sp. HZ11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferSpHz11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1453501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453501.protein.info.v11.5.txt",
		        "node_list_path": "1453501.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaSpG5847Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. G5847 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaSpG5847Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1179777.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1179777.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1179777.clusters.proteins.v11.5.txt",
		        "sequence_path": "1179777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1179777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1179777.protein.info.v11.5.txt",
		        "node_list_path": "1179777.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1179777.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharopolysporaRectivirgula(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharopolyspora rectivirgula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharopolysporaRectivirgula", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "28042.protein.sequences.v11.5.fa",
		        "enrichment_path": "28042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28042.protein.info.v11.5.txt",
		        "node_list_path": "28042.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCytotoxicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cytotoxicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCytotoxicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "315749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "315749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "315749.clusters.proteins.v11.5.txt",
		        "sequence_path": "315749.protein.sequences.v11.5.fa",
		        "enrichment_path": "315749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "315749.protein.info.v11.5.txt",
		        "node_list_path": "315749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "315749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusHaemolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus haemolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusHaemolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "279808.clusters.info.v11.5.txt",
		        "cluster_tree_path": "279808.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "279808.clusters.proteins.v11.5.txt",
		        "sequence_path": "279808.protein.sequences.v11.5.fa",
		        "enrichment_path": "279808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "279808.protein.info.v11.5.txt",
		        "node_list_path": "279808.cluster.nodes.v11.5.txt",
		        "edge_list_path": "279808.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusAquimarinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus aquimarinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusAquimarinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "237018.clusters.info.v11.5.txt",
		        "cluster_tree_path": "237018.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "237018.clusters.proteins.v11.5.txt",
		        "sequence_path": "237018.protein.sequences.v11.5.fa",
		        "enrichment_path": "237018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "237018.protein.info.v11.5.txt",
		        "node_list_path": "237018.cluster.nodes.v11.5.txt",
		        "edge_list_path": "237018.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalomonasSpSoapLake7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. Soap Lake #7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasSpSoapLake7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1962264.protein.sequences.v11.5.fa",
		        "enrichment_path": "1962264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1962264.protein.info.v11.5.txt",
		        "node_list_path": "1962264.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasPruniNbrc15498(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas pruni NBRC 15498 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasPruniNbrc15498", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219052.protein.info.v11.5.txt",
		        "node_list_path": "1219052.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoplanusPetroleariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoplanus petrolearius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoplanusPetroleariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679926.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679926.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679926.clusters.proteins.v11.5.txt",
		        "sequence_path": "679926.protein.sequences.v11.5.fa",
		        "enrichment_path": "679926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679926.protein.info.v11.5.txt",
		        "node_list_path": "679926.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679926.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaromonasJejuensisNbrc106434Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas jejuensis NBRC 106434 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaromonasJejuensisNbrc106434Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321608.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321608.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321608.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321608.protein.info.v11.5.txt",
		        "node_list_path": "1321608.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321608.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirochaetesBacteriumGwf1518(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWF1_51_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirochaetesBacteriumGwf1518", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802190.protein.info.v11.5.txt",
		        "node_list_path": "1802190.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBathyarchaeotaArchaeonB24(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB24", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1779368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1779368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1779368.protein.info.v11.5.txt",
		        "node_list_path": "1779368.protein.complete.v11.5.txt"
		    }
		]
    )()

def KalmanozymaBrasiliensisGhg001Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kalmanozyma brasiliensis GHG001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KalmanozymaBrasiliensisGhg001Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1365824.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1365824.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1365824.clusters.proteins.v11.5.txt",
		        "sequence_path": "1365824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1365824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1365824.protein.info.v11.5.txt",
		        "node_list_path": "1365824.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1365824.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpIbvss2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. IBVSS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpIbvss2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1985172.protein.sequences.v11.5.fa",
		        "enrichment_path": "1985172.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1985172.protein.info.v11.5.txt",
		        "node_list_path": "1985172.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfomicrobiumBaculatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium baculatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfomicrobiumBaculatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "525897.protein.sequences.v11.5.fa",
		        "enrichment_path": "525897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525897.protein.info.v11.5.txt",
		        "node_list_path": "525897.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusOrientisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus orientis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusOrientisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "768706.clusters.info.v11.5.txt",
		        "cluster_tree_path": "768706.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "768706.clusters.proteins.v11.5.txt",
		        "sequence_path": "768706.protein.sequences.v11.5.fa",
		        "enrichment_path": "768706.protein.enrichment.terms.v11.5.txt",
		        "info_path": "768706.protein.info.v11.5.txt",
		        "node_list_path": "768706.cluster.nodes.v11.5.txt",
		        "edge_list_path": "768706.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpNiph973(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH973 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpNiph973", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "520709.protein.sequences.v11.5.fa",
		        "enrichment_path": "520709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "520709.protein.info.v11.5.txt",
		        "node_list_path": "520709.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusCoryniformisSubspCoryniformisCect5711Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis subsp. coryniformis CECT 5711 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusCoryniformisSubspCoryniformisCect5711Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1185325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1185325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1185325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1185325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185325.protein.info.v11.5.txt",
		        "node_list_path": "1185325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1185325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PleurocapsaSpPcc7319(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pleurocapsa sp. PCC7319 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PleurocapsaSpPcc7319", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118161.protein.sequences.v11.5.fa",
		        "enrichment_path": "118161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118161.protein.info.v11.5.txt",
		        "node_list_path": "118161.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArcobacterButzleriRm4018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter butzleri RM4018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterButzleriRm4018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "367737.clusters.info.v11.5.txt",
		        "cluster_tree_path": "367737.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "367737.clusters.proteins.v11.5.txt",
		        "sequence_path": "367737.protein.sequences.v11.5.fa",
		        "enrichment_path": "367737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "367737.protein.info.v11.5.txt",
		        "node_list_path": "367737.cluster.nodes.v11.5.txt",
		        "edge_list_path": "367737.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesLongwoodensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces longwoodensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesLongwoodensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68231.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68231.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68231.clusters.proteins.v11.5.txt",
		        "sequence_path": "68231.protein.sequences.v11.5.fa",
		        "enrichment_path": "68231.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68231.protein.info.v11.5.txt",
		        "node_list_path": "68231.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68231.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpHmsc08h08Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. HMSC08H08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpHmsc08h08Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1581143.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1581143.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1581143.clusters.proteins.v11.5.txt",
		        "sequence_path": "1581143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581143.protein.info.v11.5.txt",
		        "node_list_path": "1581143.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1581143.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSpRoot1257(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root1257 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSpRoot1257", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736439.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736439.protein.info.v11.5.txt",
		        "node_list_path": "1736439.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSp103mf(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 103mf graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSp103mf", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1761751.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761751.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761751.protein.info.v11.5.txt",
		        "node_list_path": "1761751.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarboxydothermusIslandicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carboxydothermus islandicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarboxydothermusIslandicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "661089.protein.sequences.v11.5.fa",
		        "enrichment_path": "661089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "661089.protein.info.v11.5.txt",
		        "node_list_path": "661089.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusYonginensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus yonginensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusYonginensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1462996.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1462996.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1462996.clusters.proteins.v11.5.txt",
		        "sequence_path": "1462996.protein.sequences.v11.5.fa",
		        "enrichment_path": "1462996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1462996.protein.info.v11.5.txt",
		        "node_list_path": "1462996.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1462996.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSanguinisSk36Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSanguinisSk36Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "388919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "388919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "388919.clusters.proteins.v11.5.txt",
		        "sequence_path": "388919.protein.sequences.v11.5.fa",
		        "enrichment_path": "388919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388919.protein.info.v11.5.txt",
		        "node_list_path": "388919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "388919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGastranaerophilalesBacteriumHum9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium HUM_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumHum9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1916320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1916320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1916320.protein.info.v11.5.txt",
		        "node_list_path": "1916320.protein.complete.v11.5.txt"
		    }
		]
    )()

def DickeyaSp2b12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya sp. 2B12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DickeyaSp2b12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577887.protein.info.v11.5.txt",
		        "node_list_path": "1577887.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlcanivoraxPacificusW115(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax pacificus W11-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlcanivoraxPacificusW115", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391936.protein.sequences.v11.5.fa",
		        "enrichment_path": "391936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391936.protein.info.v11.5.txt",
		        "node_list_path": "391936.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlaciibacterSuperstesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciibacter superstes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciibacterSuperstesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121924.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121924.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121924.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121924.protein.info.v11.5.txt",
		        "node_list_path": "1121924.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121924.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevibacillusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1118054.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1118054.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1118054.clusters.proteins.v11.5.txt",
		        "sequence_path": "1118054.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118054.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118054.protein.info.v11.5.txt",
		        "node_list_path": "1118054.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1118054.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CitreicellaSpSe45Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citreicella sp. SE45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitreicellaSpSe45Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "501479.clusters.info.v11.5.txt",
		        "cluster_tree_path": "501479.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "501479.clusters.proteins.v11.5.txt",
		        "sequence_path": "501479.protein.sequences.v11.5.fa",
		        "enrichment_path": "501479.protein.enrichment.terms.v11.5.txt",
		        "info_path": "501479.protein.info.v11.5.txt",
		        "node_list_path": "501479.cluster.nodes.v11.5.txt",
		        "edge_list_path": "501479.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumGwf24212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWF2_42_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumGwf24212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797824.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797824.protein.info.v11.5.txt",
		        "node_list_path": "1797824.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumLundenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium lundense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumLundenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410653.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410653.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410653.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410653.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410653.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410653.protein.info.v11.5.txt",
		        "node_list_path": "1410653.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410653.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpUnc279mftsu51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. UNC279MFTsu5.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpUnc279mftsu51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1502775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502775.protein.info.v11.5.txt",
		        "node_list_path": "1502775.protein.complete.v11.5.txt"
		    }
		]
    )()

def FerroplasmaAcidiphilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ferroplasma acidiphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerroplasmaAcidiphilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "74969.protein.sequences.v11.5.fa",
		        "enrichment_path": "74969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "74969.protein.info.v11.5.txt",
		        "node_list_path": "74969.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrobacterHamburgensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrobacter hamburgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrobacterHamburgensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "323097.protein.sequences.v11.5.fa",
		        "enrichment_path": "323097.protein.enrichment.terms.v11.5.txt",
		        "info_path": "323097.protein.info.v11.5.txt",
		        "node_list_path": "323097.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMarisflavi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus marisflavi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMarisflavi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "189381.protein.sequences.v11.5.fa",
		        "enrichment_path": "189381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "189381.protein.info.v11.5.txt",
		        "node_list_path": "189381.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermodesulfobacteriumHveragerdenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium hveragerdense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermodesulfobacteriumHveragerdenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1123372.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1123372.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1123372.clusters.proteins.v11.5.txt",
		        "sequence_path": "1123372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123372.protein.info.v11.5.txt",
		        "node_list_path": "1123372.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1123372.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseibiumSpTrichskd4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseibium sp. TrichSKD4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseibiumSpTrichskd4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "744980.protein.sequences.v11.5.fa",
		        "enrichment_path": "744980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "744980.protein.info.v11.5.txt",
		        "node_list_path": "744980.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiomicrospiraArctica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomicrospiraArctica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123514.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123514.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123514.protein.info.v11.5.txt",
		        "node_list_path": "1123514.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaAbortus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila abortus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaAbortus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "218497.protein.sequences.v11.5.fa",
		        "enrichment_path": "218497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218497.protein.info.v11.5.txt",
		        "node_list_path": "218497.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaCrassostreaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga crassostreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaCrassostreaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1763535.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1763535.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1763535.clusters.proteins.v11.5.txt",
		        "sequence_path": "1763535.protein.sequences.v11.5.fa",
		        "enrichment_path": "1763535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1763535.protein.info.v11.5.txt",
		        "node_list_path": "1763535.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1763535.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ModestobacterCaceresii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Modestobacter caceresii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ModestobacterCaceresii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1522368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522368.protein.info.v11.5.txt",
		        "node_list_path": "1522368.protein.complete.v11.5.txt"
		    }
		]
    )()

def VitreoscillaStercoraria(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vitreoscilla stercoraria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VitreoscillaStercoraria", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123499.protein.info.v11.5.txt",
		        "node_list_path": "1123499.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumNk4a144Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A144 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumNk4a144Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "877421.clusters.info.v11.5.txt",
		        "cluster_tree_path": "877421.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "877421.clusters.proteins.v11.5.txt",
		        "sequence_path": "877421.protein.sequences.v11.5.fa",
		        "enrichment_path": "877421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877421.protein.info.v11.5.txt",
		        "node_list_path": "877421.cluster.nodes.v11.5.txt",
		        "edge_list_path": "877421.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRedseaS03B5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium REDSEA-S03_B5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRedseaS03B5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1811661.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811661.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811661.protein.info.v11.5.txt",
		        "node_list_path": "1811661.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeniophoraSpCont(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peniophora sp. CONT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeniophoraSpCont", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314672.protein.info.v11.5.txt",
		        "node_list_path": "1314672.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudovibrioSpJcm19062Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. JCM 19062 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioSpJcm19062Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1481932.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1481932.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1481932.clusters.proteins.v11.5.txt",
		        "sequence_path": "1481932.protein.sequences.v11.5.fa",
		        "enrichment_path": "1481932.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1481932.protein.info.v11.5.txt",
		        "node_list_path": "1481932.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1481932.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SnodgrassellaSpCfcc13594Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Snodgrassella sp. CFCC 13594 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SnodgrassellaSpCfcc13594Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1775559.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1775559.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1775559.clusters.proteins.v11.5.txt",
		        "sequence_path": "1775559.protein.sequences.v11.5.fa",
		        "enrichment_path": "1775559.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1775559.protein.info.v11.5.txt",
		        "node_list_path": "1775559.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1775559.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerococcusTetradiusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus tetradius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerococcusTetradiusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525255.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525255.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525255.clusters.proteins.v11.5.txt",
		        "sequence_path": "525255.protein.sequences.v11.5.fa",
		        "enrichment_path": "525255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525255.protein.info.v11.5.txt",
		        "node_list_path": "525255.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525255.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumScrofulaceum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium scrofulaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumScrofulaceum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1783.protein.info.v11.5.txt",
		        "node_list_path": "1783.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeitlerinemaSpBbd19919Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geitlerinema sp. BBD 1991-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeitlerinemaSpBbd19919Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1643526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1643526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1643526.clusters.proteins.v11.5.txt",
		        "sequence_path": "1643526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643526.protein.info.v11.5.txt",
		        "node_list_path": "1643526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1643526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterCanadensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter canadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterCanadensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "537970.clusters.info.v11.5.txt",
		        "cluster_tree_path": "537970.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "537970.clusters.proteins.v11.5.txt",
		        "sequence_path": "537970.protein.sequences.v11.5.fa",
		        "enrichment_path": "537970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "537970.protein.info.v11.5.txt",
		        "node_list_path": "537970.cluster.nodes.v11.5.txt",
		        "edge_list_path": "537970.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr27(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr27", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1934984.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934984.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934984.protein.info.v11.5.txt",
		        "node_list_path": "1934984.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpHph0090Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. HPH0090 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpHph0090Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203590.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203590.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203590.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203590.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203590.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203590.protein.info.v11.5.txt",
		        "node_list_path": "1203590.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203590.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NesterenkoniaSpF(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. F graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NesterenkoniaSpF", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "795955.protein.sequences.v11.5.fa",
		        "enrichment_path": "795955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "795955.protein.info.v11.5.txt",
		        "node_list_path": "795955.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinimicrobiumMangroviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinimicrobium mangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinimicrobiumMangroviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1043493.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1043493.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1043493.clusters.proteins.v11.5.txt",
		        "sequence_path": "1043493.protein.sequences.v11.5.fa",
		        "enrichment_path": "1043493.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1043493.protein.info.v11.5.txt",
		        "node_list_path": "1043493.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1043493.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumOlb9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumOlb9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1617420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1617420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1617420.clusters.proteins.v11.5.txt",
		        "sequence_path": "1617420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1617420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1617420.protein.info.v11.5.txt",
		        "node_list_path": "1617420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1617420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudooceanicolaFlagellatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudooceanicola flagellatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudooceanicolaFlagellatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1387277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387277.protein.info.v11.5.txt",
		        "node_list_path": "1387277.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrobaculumSpWp30Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum sp. WP30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumSpWp30Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227555.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227555.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227555.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227555.protein.info.v11.5.txt",
		        "node_list_path": "1227555.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227555.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AustrofundulusLimnaeus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Austrofundulus limnaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AustrofundulusLimnaeus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "52670.protein.sequences.v11.5.fa",
		        "enrichment_path": "52670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "52670.protein.info.v11.5.txt",
		        "node_list_path": "52670.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpRoot568Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root568 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpRoot568Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736565.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736565.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736565.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736565.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736565.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736565.protein.info.v11.5.txt",
		        "node_list_path": "1736565.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736565.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4013(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4013", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798384.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798384.protein.info.v11.5.txt",
		        "node_list_path": "1798384.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumFragaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium fragae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumFragaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1260918.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1260918.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1260918.clusters.proteins.v11.5.txt",
		        "sequence_path": "1260918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1260918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1260918.protein.info.v11.5.txt",
		        "node_list_path": "1260918.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1260918.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumImcc26134Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium IMCC26134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumImcc26134Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1637999.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1637999.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1637999.clusters.proteins.v11.5.txt",
		        "sequence_path": "1637999.protein.sequences.v11.5.fa",
		        "enrichment_path": "1637999.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1637999.protein.info.v11.5.txt",
		        "node_list_path": "1637999.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1637999.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseivivaxHalotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseivivaxHalotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93684.protein.sequences.v11.5.fa",
		        "enrichment_path": "93684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93684.protein.info.v11.5.txt",
		        "node_list_path": "93684.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParvularculaBermudensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parvularcula bermudensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParvularculaBermudensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "314260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "314260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "314260.clusters.proteins.v11.5.txt",
		        "sequence_path": "314260.protein.sequences.v11.5.fa",
		        "enrichment_path": "314260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314260.protein.info.v11.5.txt",
		        "node_list_path": "314260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "314260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SerratiaProteamaculans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Serratia proteamaculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SerratiaProteamaculans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "399741.protein.sequences.v11.5.fa",
		        "enrichment_path": "399741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "399741.protein.info.v11.5.txt",
		        "node_list_path": "399741.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusInfantisSk970Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis SK970 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusInfantisSk970Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1035189.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1035189.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1035189.clusters.proteins.v11.5.txt",
		        "sequence_path": "1035189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1035189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1035189.protein.info.v11.5.txt",
		        "node_list_path": "1035189.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1035189.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudospirillumJaponicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudospirillum japonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudospirillumJaponicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "64971.clusters.info.v11.5.txt",
		        "cluster_tree_path": "64971.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "64971.clusters.proteins.v11.5.txt",
		        "sequence_path": "64971.protein.sequences.v11.5.fa",
		        "enrichment_path": "64971.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64971.protein.info.v11.5.txt",
		        "node_list_path": "64971.cluster.nodes.v11.5.txt",
		        "edge_list_path": "64971.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterNanhaisediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter nanhaisediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterNanhaisediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "604088.protein.sequences.v11.5.fa",
		        "enrichment_path": "604088.protein.enrichment.terms.v11.5.txt",
		        "info_path": "604088.protein.info.v11.5.txt",
		        "node_list_path": "604088.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumRubiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium rubi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumRubiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28099.clusters.proteins.v11.5.txt",
		        "sequence_path": "28099.protein.sequences.v11.5.fa",
		        "enrichment_path": "28099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28099.protein.info.v11.5.txt",
		        "node_list_path": "28099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def UnculturedClostridiumSp(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Clostridium sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UnculturedClostridiumSp", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59620.protein.sequences.v11.5.fa",
		        "enrichment_path": "59620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59620.protein.info.v11.5.txt",
		        "node_list_path": "59620.protein.complete.v11.5.txt"
		    }
		]
    )()

def BisonBisonBisonCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bison bison bison Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BisonBisonBisonCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43346.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43346.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43346.clusters.proteins.v11.5.txt",
		        "sequence_path": "43346.protein.sequences.v11.5.fa",
		        "enrichment_path": "43346.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43346.protein.info.v11.5.txt",
		        "node_list_path": "43346.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43346.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnicoccusIslandicusDsm13165Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignicoccus islandicus DSM 13165 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnicoccusIslandicusDsm13165Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "940295.clusters.info.v11.5.txt",
		        "cluster_tree_path": "940295.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "940295.clusters.proteins.v11.5.txt",
		        "sequence_path": "940295.protein.sequences.v11.5.fa",
		        "enrichment_path": "940295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "940295.protein.info.v11.5.txt",
		        "node_list_path": "940295.cluster.nodes.v11.5.txt",
		        "edge_list_path": "940295.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LoaLoa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Loa loa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LoaLoa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7209.protein.sequences.v11.5.fa",
		        "enrichment_path": "7209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7209.protein.info.v11.5.txt",
		        "node_list_path": "7209.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicroplitisDemolitorCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microplitis demolitor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicroplitisDemolitorCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "69319.clusters.info.v11.5.txt",
		        "cluster_tree_path": "69319.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "69319.clusters.proteins.v11.5.txt",
		        "sequence_path": "69319.protein.sequences.v11.5.fa",
		        "enrichment_path": "69319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69319.protein.info.v11.5.txt",
		        "node_list_path": "69319.cluster.nodes.v11.5.txt",
		        "edge_list_path": "69319.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VignaRadiataVarRadiataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vigna radiata var. radiata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VignaRadiataVarRadiataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "3916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "3916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "3916.clusters.proteins.v11.5.txt",
		        "sequence_path": "3916.protein.sequences.v11.5.fa",
		        "enrichment_path": "3916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3916.protein.info.v11.5.txt",
		        "node_list_path": "3916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "3916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRifcsplowo202Full7116Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RIFCSPLOWO2_02_FULL_71_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRifcsplowo202Full7116Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797672.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797672.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797672.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797672.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797672.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797672.protein.info.v11.5.txt",
		        "node_list_path": "1797672.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797672.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumOculiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium oculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumOculiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1544416.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1544416.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1544416.clusters.proteins.v11.5.txt",
		        "sequence_path": "1544416.protein.sequences.v11.5.fa",
		        "enrichment_path": "1544416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1544416.protein.info.v11.5.txt",
		        "node_list_path": "1544416.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1544416.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSp1m11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 1M-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSp1m11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1529006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1529006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1529006.protein.info.v11.5.txt",
		        "node_list_path": "1529006.protein.complete.v11.5.txt"
		    }
		]
    )()

def SynechocystisSpPcc6803(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC6803 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechocystisSpPcc6803", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1148.protein.sequences.v11.5.fa",
		        "enrichment_path": "1148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1148.protein.info.v11.5.txt",
		        "node_list_path": "1148.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusTimonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusTimonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095770.protein.info.v11.5.txt",
		        "node_list_path": "1095770.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodococcusTriatomae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus triatomae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusTriatomae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278078.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278078.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278078.protein.info.v11.5.txt",
		        "node_list_path": "1278078.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusSpJ56Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. J56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusSpJ56Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935850.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935850.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935850.clusters.proteins.v11.5.txt",
		        "sequence_path": "935850.protein.sequences.v11.5.fa",
		        "enrichment_path": "935850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935850.protein.info.v11.5.txt",
		        "node_list_path": "935850.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935850.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSpJdfr37(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSpJdfr37", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1934994.protein.sequences.v11.5.fa",
		        "enrichment_path": "1934994.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1934994.protein.info.v11.5.txt",
		        "node_list_path": "1934994.protein.complete.v11.5.txt"
		    }
		]
    )()

def FusibacterSp3d3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusibacter sp. 3D3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusibacterSp3d3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1048380.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1048380.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1048380.clusters.proteins.v11.5.txt",
		        "sequence_path": "1048380.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048380.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048380.protein.info.v11.5.txt",
		        "node_list_path": "1048380.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1048380.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HeterocephalusGlaber(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Heterocephalus glaber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HeterocephalusGlaber", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10181.protein.sequences.v11.5.fa",
		        "enrichment_path": "10181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10181.protein.info.v11.5.txt",
		        "node_list_path": "10181.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaMoravica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella moravica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaMoravica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122165.protein.info.v11.5.txt",
		        "node_list_path": "1122165.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodospirillaceaeBacteriumBrhC57(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillaceae bacterium BRH_c57 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillaceaeBacteriumBrhC57", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629718.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629718.protein.info.v11.5.txt",
		        "node_list_path": "1629718.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesFulvoviolaceus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces fulvoviolaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesFulvoviolaceus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "285535.protein.sequences.v11.5.fa",
		        "enrichment_path": "285535.protein.enrichment.terms.v11.5.txt",
		        "info_path": "285535.protein.info.v11.5.txt",
		        "node_list_path": "285535.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrogenomatesGroupBacteriumGw2011Gwf2479(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011_GWF2_47_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011Gwf2479", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618541.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618541.protein.info.v11.5.txt",
		        "node_list_path": "1618541.protein.complete.v11.5.txt"
		    }
		]
    )()

def EwingellaAmericanaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ewingella americana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EwingellaAmericanaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "910964.clusters.info.v11.5.txt",
		        "cluster_tree_path": "910964.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "910964.clusters.proteins.v11.5.txt",
		        "sequence_path": "910964.protein.sequences.v11.5.fa",
		        "enrichment_path": "910964.protein.enrichment.terms.v11.5.txt",
		        "info_path": "910964.protein.info.v11.5.txt",
		        "node_list_path": "910964.cluster.nodes.v11.5.txt",
		        "edge_list_path": "910964.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PectobacteriumCarotovorumOdoriferum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum odoriferum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PectobacteriumCarotovorumOdoriferum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "78398.protein.sequences.v11.5.fa",
		        "enrichment_path": "78398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "78398.protein.info.v11.5.txt",
		        "node_list_path": "78398.protein.complete.v11.5.txt"
		    }
		]
    )()

def MorganellaPsychrotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Morganella psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MorganellaPsychrotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "368603.clusters.info.v11.5.txt",
		        "cluster_tree_path": "368603.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "368603.clusters.proteins.v11.5.txt",
		        "sequence_path": "368603.protein.sequences.v11.5.fa",
		        "enrichment_path": "368603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "368603.protein.info.v11.5.txt",
		        "node_list_path": "368603.cluster.nodes.v11.5.txt",
		        "edge_list_path": "368603.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusAmesbacteriaBacteriumGw2011Gwa24212(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWA2_42_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwa24212", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618356.protein.info.v11.5.txt",
		        "node_list_path": "1618356.protein.complete.v11.5.txt"
		    }
		]
    )()

def LuteipulveratusMongoliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteipulveratus mongoliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteipulveratusMongoliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "571913.clusters.info.v11.5.txt",
		        "cluster_tree_path": "571913.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "571913.clusters.proteins.v11.5.txt",
		        "sequence_path": "571913.protein.sequences.v11.5.fa",
		        "enrichment_path": "571913.protein.enrichment.terms.v11.5.txt",
		        "info_path": "571913.protein.info.v11.5.txt",
		        "node_list_path": "571913.cluster.nodes.v11.5.txt",
		        "edge_list_path": "571913.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMargulisbacteriaBacteriumGwf2359(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Margulisbacteria bacterium GWF2_35_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMargulisbacteriaBacteriumGwf2359", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817873.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817873.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817873.protein.info.v11.5.txt",
		        "node_list_path": "1817873.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacterium13220cm27011Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_2_20CM_2_70_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacterium13220cm27011Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805370.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805370.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805370.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805370.protein.info.v11.5.txt",
		        "node_list_path": "1805370.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805370.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumRussii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium russii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumRussii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278306.protein.info.v11.5.txt",
		        "node_list_path": "1278306.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterArupensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter arupensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterArupensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "342002.clusters.info.v11.5.txt",
		        "cluster_tree_path": "342002.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "342002.clusters.proteins.v11.5.txt",
		        "sequence_path": "342002.protein.sequences.v11.5.fa",
		        "enrichment_path": "342002.protein.enrichment.terms.v11.5.txt",
		        "info_path": "342002.protein.info.v11.5.txt",
		        "node_list_path": "342002.cluster.nodes.v11.5.txt",
		        "edge_list_path": "342002.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpAg109O510Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Ag109_O5-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpAg109O510Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855349.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855349.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855349.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855349.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855349.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855349.protein.info.v11.5.txt",
		        "node_list_path": "1855349.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855349.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusEllipticusCbs70779(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ellipticus CBS 707.79 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusEllipticusCbs70779", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1448320.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448320.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448320.protein.info.v11.5.txt",
		        "node_list_path": "1448320.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusAcidiphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus acidiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusAcidiphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "646529.protein.sequences.v11.5.fa",
		        "enrichment_path": "646529.protein.enrichment.terms.v11.5.txt",
		        "info_path": "646529.protein.info.v11.5.txt",
		        "node_list_path": "646529.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSolisilvae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus solisilvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSolisilvae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1516104.protein.sequences.v11.5.fa",
		        "enrichment_path": "1516104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1516104.protein.info.v11.5.txt",
		        "node_list_path": "1516104.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlorobiumPhaeovibrioidesCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium phaeovibrioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumPhaeovibrioidesCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "290318.clusters.info.v11.5.txt",
		        "cluster_tree_path": "290318.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "290318.clusters.proteins.v11.5.txt",
		        "sequence_path": "290318.protein.sequences.v11.5.fa",
		        "enrichment_path": "290318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290318.protein.info.v11.5.txt",
		        "node_list_path": "290318.cluster.nodes.v11.5.txt",
		        "edge_list_path": "290318.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusMurinusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus murinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusMurinusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1235801.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1235801.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1235801.clusters.proteins.v11.5.txt",
		        "sequence_path": "1235801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235801.protein.info.v11.5.txt",
		        "node_list_path": "1235801.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1235801.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumBifidumPrl2010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum PRL2010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumBifidumPrl2010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "702459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "702459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "702459.clusters.proteins.v11.5.txt",
		        "sequence_path": "702459.protein.sequences.v11.5.fa",
		        "enrichment_path": "702459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702459.protein.info.v11.5.txt",
		        "node_list_path": "702459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "702459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumYsb2008(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium YSB2008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumYsb2008", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410633.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410633.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410633.protein.info.v11.5.txt",
		        "node_list_path": "1410633.protein.complete.v11.5.txt"
		    }
		]
    )()

def TenacibaculumMaritimum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tenacibaculum maritimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TenacibaculumMaritimum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1349785.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349785.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349785.protein.info.v11.5.txt",
		        "node_list_path": "1349785.protein.complete.v11.5.txt"
		    }
		]
    )()

def MacrophominaPhaseolinaMs6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Macrophomina phaseolina MS6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacrophominaPhaseolinaMs6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1126212.protein.sequences.v11.5.fa",
		        "enrichment_path": "1126212.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1126212.protein.info.v11.5.txt",
		        "node_list_path": "1126212.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasArboricola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas arboricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasArboricola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "454957.protein.sequences.v11.5.fa",
		        "enrichment_path": "454957.protein.enrichment.terms.v11.5.txt",
		        "info_path": "454957.protein.info.v11.5.txt",
		        "node_list_path": "454957.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpSm9913(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. SM9913 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpSm9913", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "234831.protein.sequences.v11.5.fa",
		        "enrichment_path": "234831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "234831.protein.info.v11.5.txt",
		        "node_list_path": "234831.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumSpScn6914Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. SCN 69-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumSpScn6914Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660128.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660128.protein.info.v11.5.txt",
		        "node_list_path": "1660128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasRubraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasRubraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "634430.clusters.info.v11.5.txt",
		        "cluster_tree_path": "634430.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "634430.clusters.proteins.v11.5.txt",
		        "sequence_path": "634430.protein.sequences.v11.5.fa",
		        "enrichment_path": "634430.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634430.protein.info.v11.5.txt",
		        "node_list_path": "634430.cluster.nodes.v11.5.txt",
		        "edge_list_path": "634430.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SulfurimonasSpRifoxyd12Full3339(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFOXYD12_FULL_33_39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SulfurimonasSpRifoxyd12Full3339", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802259.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802259.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802259.protein.info.v11.5.txt",
		        "node_list_path": "1802259.protein.complete.v11.5.txt"
		    }
		]
    )()

def NevskiaRamosaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nevskia ramosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NevskiaRamosaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122603.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122603.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122603.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122603.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122603.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122603.protein.info.v11.5.txt",
		        "node_list_path": "1122603.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122603.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoplasmaAcidophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasma acidophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoplasmaAcidophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "273075.protein.sequences.v11.5.fa",
		        "enrichment_path": "273075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "273075.protein.info.v11.5.txt",
		        "node_list_path": "273075.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseburiaSpCag309(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:309 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseburiaSpCag309", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262945.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262945.protein.info.v11.5.txt",
		        "node_list_path": "1262945.protein.complete.v11.5.txt"
		    }
		]
    )()

def PasteurellaMultocidaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PasteurellaMultocidaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "747.clusters.info.v11.5.txt",
		        "cluster_tree_path": "747.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "747.clusters.proteins.v11.5.txt",
		        "sequence_path": "747.protein.sequences.v11.5.fa",
		        "enrichment_path": "747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "747.protein.info.v11.5.txt",
		        "node_list_path": "747.cluster.nodes.v11.5.txt",
		        "edge_list_path": "747.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalothrixSpPcc7507(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC7507 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalothrixSpPcc7507", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "99598.protein.sequences.v11.5.fa",
		        "enrichment_path": "99598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "99598.protein.info.v11.5.txt",
		        "node_list_path": "99598.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesWedmorensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces wedmorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesWedmorensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "43759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "43759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "43759.clusters.proteins.v11.5.txt",
		        "sequence_path": "43759.protein.sequences.v11.5.fa",
		        "enrichment_path": "43759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43759.protein.info.v11.5.txt",
		        "node_list_path": "43759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "43759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaFloridensisFslS101187Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria floridensis FSL S10-1187 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaFloridensisFslS101187Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1265817.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1265817.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1265817.clusters.proteins.v11.5.txt",
		        "sequence_path": "1265817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265817.protein.info.v11.5.txt",
		        "node_list_path": "1265817.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1265817.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioCrossotusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio crossotus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioCrossotusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "511680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "511680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "511680.clusters.proteins.v11.5.txt",
		        "sequence_path": "511680.protein.sequences.v11.5.fa",
		        "enrichment_path": "511680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "511680.protein.info.v11.5.txt",
		        "node_list_path": "511680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "511680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsphigho202Full6720(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPHIGHO2_02_FULL_67_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202Full6720", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801860.protein.info.v11.5.txt",
		        "node_list_path": "1801860.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3926Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_39_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3926Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802770.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802770.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802770.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802770.protein.info.v11.5.txt",
		        "node_list_path": "1802770.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802770.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlteromonadaceaeBacteriumBs31Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonadaceae bacterium Bs31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonadaceaeBacteriumBs31Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304903.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304903.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304903.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304903.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304903.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304903.protein.info.v11.5.txt",
		        "node_list_path": "1304903.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304903.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg166432Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_64_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg166432Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797658.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797658.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797658.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797658.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797658.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797658.protein.info.v11.5.txt",
		        "node_list_path": "1797658.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797658.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NioellaSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nioella sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NioellaSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1912092.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1912092.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1912092.clusters.proteins.v11.5.txt",
		        "sequence_path": "1912092.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912092.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912092.protein.info.v11.5.txt",
		        "node_list_path": "1912092.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1912092.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaematobacterMissouriensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haematobacter missouriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaematobacterMissouriensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "366616.protein.sequences.v11.5.fa",
		        "enrichment_path": "366616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "366616.protein.info.v11.5.txt",
		        "node_list_path": "366616.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAutolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces autolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAutolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "75293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "75293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "75293.clusters.proteins.v11.5.txt",
		        "sequence_path": "75293.protein.sequences.v11.5.fa",
		        "enrichment_path": "75293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "75293.protein.info.v11.5.txt",
		        "node_list_path": "75293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "75293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AsterYellowsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aster yellows Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AsterYellowsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "322098.clusters.info.v11.5.txt",
		        "cluster_tree_path": "322098.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "322098.clusters.proteins.v11.5.txt",
		        "sequence_path": "322098.protein.sequences.v11.5.fa",
		        "enrichment_path": "322098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "322098.protein.info.v11.5.txt",
		        "node_list_path": "322098.cluster.nodes.v11.5.txt",
		        "edge_list_path": "322098.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinoplanesSpN902109Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinoplanes sp. N902109 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinoplanesSpN902109Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "649831.clusters.info.v11.5.txt",
		        "cluster_tree_path": "649831.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "649831.clusters.proteins.v11.5.txt",
		        "sequence_path": "649831.protein.sequences.v11.5.fa",
		        "enrichment_path": "649831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649831.protein.info.v11.5.txt",
		        "node_list_path": "649831.cluster.nodes.v11.5.txt",
		        "edge_list_path": "649831.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrococcusMobilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrococcus mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrococcusMobilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314278.protein.sequences.v11.5.fa",
		        "enrichment_path": "314278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314278.protein.info.v11.5.txt",
		        "node_list_path": "314278.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicromonosporaHalophytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora halophytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicromonosporaHalophytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47864.protein.sequences.v11.5.fa",
		        "enrichment_path": "47864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47864.protein.info.v11.5.txt",
		        "node_list_path": "47864.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhaeobacterSpS60Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeobacter sp. S60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhaeobacterSpS60Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1569353.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1569353.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1569353.clusters.proteins.v11.5.txt",
		        "sequence_path": "1569353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1569353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1569353.protein.info.v11.5.txt",
		        "node_list_path": "1569353.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1569353.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusRhodochrousCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus rhodochrous Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusRhodochrousCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1429046.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1429046.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1429046.clusters.proteins.v11.5.txt",
		        "sequence_path": "1429046.protein.sequences.v11.5.fa",
		        "enrichment_path": "1429046.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1429046.protein.info.v11.5.txt",
		        "node_list_path": "1429046.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1429046.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LuteipulveratusHalotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteipulveratus halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LuteipulveratusHalotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1631356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1631356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1631356.clusters.proteins.v11.5.txt",
		        "sequence_path": "1631356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1631356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1631356.protein.info.v11.5.txt",
		        "node_list_path": "1631356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1631356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElysiaChlorotica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elysia chlorotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElysiaChlorotica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "188477.protein.sequences.v11.5.fa",
		        "enrichment_path": "188477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188477.protein.info.v11.5.txt",
		        "node_list_path": "188477.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumRbg135152Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_51_52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumRbg135152Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797626.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797626.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797626.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797626.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797626.protein.info.v11.5.txt",
		        "node_list_path": "1797626.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797626.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterUreolyticusRigs9880(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter ureolyticus RIGS 9880 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterUreolyticusRigs9880", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1032069.protein.sequences.v11.5.fa",
		        "enrichment_path": "1032069.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1032069.protein.info.v11.5.txt",
		        "node_list_path": "1032069.protein.complete.v11.5.txt"
		    }
		]
    )()

def BoseaSpLc85Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bosea sp. LC85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BoseaSpLc85Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1502851.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1502851.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1502851.clusters.proteins.v11.5.txt",
		        "sequence_path": "1502851.protein.sequences.v11.5.fa",
		        "enrichment_path": "1502851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1502851.protein.info.v11.5.txt",
		        "node_list_path": "1502851.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1502851.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydophilaPneumoniaeTw183(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae TW183 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydophilaPneumoniaeTw183", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "182082.protein.sequences.v11.5.fa",
		        "enrichment_path": "182082.protein.enrichment.terms.v11.5.txt",
		        "info_path": "182082.protein.info.v11.5.txt",
		        "node_list_path": "182082.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpScn6718Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SCN 67-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpScn6718Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1660141.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1660141.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1660141.clusters.proteins.v11.5.txt",
		        "sequence_path": "1660141.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660141.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660141.protein.info.v11.5.txt",
		        "node_list_path": "1660141.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1660141.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusHominis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHominis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423758.protein.info.v11.5.txt",
		        "node_list_path": "1423758.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterFetus8240Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus 8240 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterFetus8240Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "360106.clusters.info.v11.5.txt",
		        "cluster_tree_path": "360106.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "360106.clusters.proteins.v11.5.txt",
		        "sequence_path": "360106.protein.sequences.v11.5.fa",
		        "enrichment_path": "360106.protein.enrichment.terms.v11.5.txt",
		        "info_path": "360106.protein.info.v11.5.txt",
		        "node_list_path": "360106.cluster.nodes.v11.5.txt",
		        "edge_list_path": "360106.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasTaetrolensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas taetrolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasTaetrolensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47884.clusters.proteins.v11.5.txt",
		        "sequence_path": "47884.protein.sequences.v11.5.fa",
		        "enrichment_path": "47884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47884.protein.info.v11.5.txt",
		        "node_list_path": "47884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpKpl1989(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1989 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpKpl1989", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1203622.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203622.protein.info.v11.5.txt",
		        "node_list_path": "1203622.protein.complete.v11.5.txt"
		    }
		]
    )()

def StaphylococcusLugdunensisN920143(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis N920143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusLugdunensisN920143", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1034809.protein.sequences.v11.5.fa",
		        "enrichment_path": "1034809.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1034809.protein.info.v11.5.txt",
		        "node_list_path": "1034809.protein.complete.v11.5.txt"
		    }
		]
    )()

def NomascusLeucogenysCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nomascus leucogenys Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NomascusLeucogenysCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61853.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61853.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61853.clusters.proteins.v11.5.txt",
		        "sequence_path": "61853.protein.sequences.v11.5.fa",
		        "enrichment_path": "61853.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61853.protein.info.v11.5.txt",
		        "node_list_path": "61853.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61853.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlamydiaSpRubis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia sp. Rubis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaSpRubis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1444712.protein.sequences.v11.5.fa",
		        "enrichment_path": "1444712.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1444712.protein.info.v11.5.txt",
		        "node_list_path": "1444712.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusBerkelbacteriaBacteriumRifcsplowo201Full5028Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFCSPLOWO2_01_FULL_50_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifcsplowo201Full5028Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797471.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797471.protein.info.v11.5.txt",
		        "node_list_path": "1797471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyellaSpOk004(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dyella sp. OK004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaSpOk004", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855292.protein.info.v11.5.txt",
		        "node_list_path": "1855292.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferYueqingensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer yueqingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferYueqingensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "658219.clusters.info.v11.5.txt",
		        "cluster_tree_path": "658219.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "658219.clusters.proteins.v11.5.txt",
		        "sequence_path": "658219.protein.sequences.v11.5.fa",
		        "enrichment_path": "658219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "658219.protein.info.v11.5.txt",
		        "node_list_path": "658219.cluster.nodes.v11.5.txt",
		        "edge_list_path": "658219.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasMaliNbrc15500Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas mali NBRC 15500 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasMaliNbrc15500Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219048.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219048.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219048.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219048.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219048.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219048.protein.info.v11.5.txt",
		        "node_list_path": "1219048.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219048.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaBcc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola BCc graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaBcc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "372461.protein.sequences.v11.5.fa",
		        "enrichment_path": "372461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "372461.protein.info.v11.5.txt",
		        "node_list_path": "372461.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfolunaSpongiiphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfoluna spongiiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfolunaSpongiiphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "419481.clusters.info.v11.5.txt",
		        "cluster_tree_path": "419481.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "419481.clusters.proteins.v11.5.txt",
		        "sequence_path": "419481.protein.sequences.v11.5.fa",
		        "enrichment_path": "419481.protein.enrichment.terms.v11.5.txt",
		        "info_path": "419481.protein.info.v11.5.txt",
		        "node_list_path": "419481.cluster.nodes.v11.5.txt",
		        "edge_list_path": "419481.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusHeteromorphusCbs11755(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus heteromorphus CBS 117.55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusHeteromorphusCbs11755", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1448321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1448321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1448321.protein.info.v11.5.txt",
		        "node_list_path": "1448321.protein.complete.v11.5.txt"
		    }
		]
    )()

def StarkeyaNovella(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Starkeya novella graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StarkeyaNovella", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "639283.protein.sequences.v11.5.fa",
		        "enrichment_path": "639283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "639283.protein.info.v11.5.txt",
		        "node_list_path": "639283.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegasphaeraSpBv3c161Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. BV3C161 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraSpBv3c161Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1111454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1111454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1111454.clusters.proteins.v11.5.txt",
		        "sequence_path": "1111454.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111454.protein.info.v11.5.txt",
		        "node_list_path": "1111454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1111454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumAcidurici(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acidurici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAcidurici", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1128398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128398.protein.info.v11.5.txt",
		        "node_list_path": "1128398.protein.complete.v11.5.txt"
		    }
		]
    )()

def KluyveraIntermediaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kluyvera intermedia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KluyveraIntermediaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61648.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61648.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61648.clusters.proteins.v11.5.txt",
		        "sequence_path": "61648.protein.sequences.v11.5.fa",
		        "enrichment_path": "61648.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61648.protein.info.v11.5.txt",
		        "node_list_path": "61648.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61648.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumGw2011Gwa24416(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011_GWA2_44_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011Gwa24416", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619110.protein.info.v11.5.txt",
		        "node_list_path": "1619110.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumOrbiscindens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium orbiscindens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumOrbiscindens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742738.protein.sequences.v11.5.fa",
		        "enrichment_path": "742738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742738.protein.info.v11.5.txt",
		        "node_list_path": "742738.protein.complete.v11.5.txt"
		    }
		]
    )()

def LentibacillusAmyloliquefaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus amyloliquefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentibacillusAmyloliquefaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1472767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1472767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1472767.protein.info.v11.5.txt",
		        "node_list_path": "1472767.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterPiscatorii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter piscatorii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterPiscatorii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "554343.protein.sequences.v11.5.fa",
		        "enrichment_path": "554343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "554343.protein.info.v11.5.txt",
		        "node_list_path": "554343.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpAcs4331Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS4331 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpAcs4331Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834121.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834121.protein.info.v11.5.txt",
		        "node_list_path": "1834121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanoculleusHoronobensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus horonobensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoculleusHoronobensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "528314.protein.sequences.v11.5.fa",
		        "enrichment_path": "528314.protein.enrichment.terms.v11.5.txt",
		        "info_path": "528314.protein.info.v11.5.txt",
		        "node_list_path": "528314.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeucobacterCelerSubspAstrifaciensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter celer subsp. astrifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucobacterCelerSubspAstrifaciensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1461260.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1461260.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1461260.clusters.proteins.v11.5.txt",
		        "sequence_path": "1461260.protein.sequences.v11.5.fa",
		        "enrichment_path": "1461260.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1461260.protein.info.v11.5.txt",
		        "node_list_path": "1461260.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1461260.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharothrixSpAli22ICluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharothrix sp. ALI-22-I Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharothrixSpAli22ICluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1933778.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1933778.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1933778.clusters.proteins.v11.5.txt",
		        "sequence_path": "1933778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933778.protein.info.v11.5.txt",
		        "node_list_path": "1933778.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1933778.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CohnellaPanacarviGsoil349(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cohnella panacarvi Gsoil 349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CohnellaPanacarviGsoil349", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "979226.protein.sequences.v11.5.fa",
		        "enrichment_path": "979226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "979226.protein.info.v11.5.txt",
		        "node_list_path": "979226.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwc246850Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWC2_46_850 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwc246850Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797327.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797327.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797327.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797327.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797327.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797327.protein.info.v11.5.txt",
		        "node_list_path": "1797327.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797327.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaPiezotoleransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella piezotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaPiezotoleransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "225849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "225849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "225849.clusters.proteins.v11.5.txt",
		        "sequence_path": "225849.protein.sequences.v11.5.fa",
		        "enrichment_path": "225849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225849.protein.info.v11.5.txt",
		        "node_list_path": "225849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "225849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc4558Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4558 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc4558Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977876.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977876.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977876.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977876.protein.info.v11.5.txt",
		        "node_list_path": "1977876.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977876.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfococcusOleovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfococcus oleovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfococcusOleovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "96561.clusters.info.v11.5.txt",
		        "cluster_tree_path": "96561.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "96561.clusters.proteins.v11.5.txt",
		        "sequence_path": "96561.protein.sequences.v11.5.fa",
		        "enrichment_path": "96561.protein.enrichment.terms.v11.5.txt",
		        "info_path": "96561.protein.info.v11.5.txt",
		        "node_list_path": "96561.cluster.nodes.v11.5.txt",
		        "edge_list_path": "96561.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesOvatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides ovatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesOvatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "411476.protein.sequences.v11.5.fa",
		        "enrichment_path": "411476.protein.enrichment.terms.v11.5.txt",
		        "info_path": "411476.protein.info.v11.5.txt",
		        "node_list_path": "411476.protein.complete.v11.5.txt"
		    }
		]
    )()

def OrchesellaCincta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Orchesella cincta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OrchesellaCincta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "48709.protein.sequences.v11.5.fa",
		        "enrichment_path": "48709.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48709.protein.info.v11.5.txt",
		        "node_list_path": "48709.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasProtegensPf5(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas protegens Pf5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasProtegensPf5", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "220664.protein.sequences.v11.5.fa",
		        "enrichment_path": "220664.protein.enrichment.terms.v11.5.txt",
		        "info_path": "220664.protein.info.v11.5.txt",
		        "node_list_path": "220664.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlb24720(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLB24720 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlb24720", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1476876.protein.sequences.v11.5.fa",
		        "enrichment_path": "1476876.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1476876.protein.info.v11.5.txt",
		        "node_list_path": "1476876.protein.complete.v11.5.txt"
		    }
		]
    )()

def AspergillusNomiusNrrl13137(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus nomius NRRL 13137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusNomiusNrrl13137", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1509407.protein.sequences.v11.5.fa",
		        "enrichment_path": "1509407.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1509407.protein.info.v11.5.txt",
		        "node_list_path": "1509407.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumRbg166422(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RBG_16_64_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumRbg166422", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801708.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801708.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801708.protein.info.v11.5.txt",
		        "node_list_path": "1801708.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusDelbrueckiiBulgaricus2038Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii bulgaricus 2038 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusDelbrueckiiBulgaricus2038Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "353496.clusters.info.v11.5.txt",
		        "cluster_tree_path": "353496.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "353496.clusters.proteins.v11.5.txt",
		        "sequence_path": "353496.protein.sequences.v11.5.fa",
		        "enrichment_path": "353496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "353496.protein.info.v11.5.txt",
		        "node_list_path": "353496.cluster.nodes.v11.5.txt",
		        "edge_list_path": "353496.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsphigho201Full4523(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_01_FULL_45_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho201Full4523", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798325.protein.info.v11.5.txt",
		        "node_list_path": "1798325.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusVietnamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus vietnamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusVietnamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "218284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "218284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "218284.clusters.proteins.v11.5.txt",
		        "sequence_path": "218284.protein.sequences.v11.5.fa",
		        "enrichment_path": "218284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "218284.protein.info.v11.5.txt",
		        "node_list_path": "218284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "218284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusMacrosporangiidus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus macrosporangiidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusMacrosporangiidus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1382304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382304.protein.info.v11.5.txt",
		        "node_list_path": "1382304.protein.complete.v11.5.txt"
		    }
		]
    )()

def Sar92BacteriumBacl16Mag120619Bin48Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return SAR92 bacterium BACL16 MAG-120619-bin48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar92BacteriumBacl16Mag120619Bin48Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1655625.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1655625.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1655625.clusters.proteins.v11.5.txt",
		        "sequence_path": "1655625.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655625.protein.info.v11.5.txt",
		        "node_list_path": "1655625.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1655625.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCochleariumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cochlearium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCochleariumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1494.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1494.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1494.clusters.proteins.v11.5.txt",
		        "sequence_path": "1494.protein.sequences.v11.5.fa",
		        "enrichment_path": "1494.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1494.protein.info.v11.5.txt",
		        "node_list_path": "1494.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1494.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp2817Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 28_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp2817Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896981.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896981.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896981.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896981.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896981.protein.info.v11.5.txt",
		        "node_list_path": "1896981.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896981.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusParalimentariusDsm19674Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paralimentarius DSM 19674 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusParalimentariusDsm19674Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423788.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423788.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423788.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423788.protein.info.v11.5.txt",
		        "node_list_path": "1423788.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423788.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioSalexigens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio salexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioSalexigens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "526222.protein.sequences.v11.5.fa",
		        "enrichment_path": "526222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526222.protein.info.v11.5.txt",
		        "node_list_path": "526222.protein.complete.v11.5.txt"
		    }
		]
    )()

def PythiumIrregulare(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pythium irregulare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PythiumIrregulare", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36331.protein.sequences.v11.5.fa",
		        "enrichment_path": "36331.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36331.protein.info.v11.5.txt",
		        "node_list_path": "36331.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusDispar(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus dispar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusDispar", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1139219.protein.sequences.v11.5.fa",
		        "enrichment_path": "1139219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1139219.protein.info.v11.5.txt",
		        "node_list_path": "1139219.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpMrMd2014(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MR_MD2014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpMrMd2014", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1561023.protein.sequences.v11.5.fa",
		        "enrichment_path": "1561023.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1561023.protein.info.v11.5.txt",
		        "node_list_path": "1561023.protein.complete.v11.5.txt"
		    }
		]
    )()

def UncinocarpusReesii1704(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Uncinocarpus reesii 1704 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UncinocarpusReesii1704", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "336963.protein.sequences.v11.5.fa",
		        "enrichment_path": "336963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "336963.protein.info.v11.5.txt",
		        "node_list_path": "336963.protein.complete.v11.5.txt"
		    }
		]
    )()

def NaemateliaEncephalaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Naematelia encephala Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NaemateliaEncephalaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "71784.clusters.info.v11.5.txt",
		        "cluster_tree_path": "71784.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "71784.clusters.proteins.v11.5.txt",
		        "sequence_path": "71784.protein.sequences.v11.5.fa",
		        "enrichment_path": "71784.protein.enrichment.terms.v11.5.txt",
		        "info_path": "71784.protein.info.v11.5.txt",
		        "node_list_path": "71784.cluster.nodes.v11.5.txt",
		        "edge_list_path": "71784.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlasmodiumVivaxSal1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium vivax Sal-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlasmodiumVivaxSal1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "126793.clusters.info.v11.5.txt",
		        "cluster_tree_path": "126793.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "126793.clusters.proteins.v11.5.txt",
		        "sequence_path": "126793.protein.sequences.v11.5.fa",
		        "enrichment_path": "126793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "126793.protein.info.v11.5.txt",
		        "node_list_path": "126793.cluster.nodes.v11.5.txt",
		        "edge_list_path": "126793.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaSpBmaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Bma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaSpBmaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "292805.clusters.info.v11.0.txt",
		        "cluster_tree_path": "292805.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "292805.clusters.proteins.v11.0.txt",
		        "sequence_path": "292805.protein.sequences.v11.0.fa",
		        "enrichment_path": "292805.protein.enrichment.terms.v11.0.txt",
		        "info_path": "292805.protein.info.v11.0.txt",
		        "node_list_path": "292805.cluster.nodes.v11.0.txt",
		        "edge_list_path": "292805.protein.cluster.v11.0.txt"
		    }
		]
    )()

def VibrioBreoganii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio breoganii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioBreoganii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1205908.protein.sequences.v11.5.fa",
		        "enrichment_path": "1205908.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1205908.protein.info.v11.5.txt",
		        "node_list_path": "1205908.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full4120(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_41_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full4120", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798283.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798283.protein.info.v11.5.txt",
		        "node_list_path": "1798283.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusPatagoniensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus patagoniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusPatagoniensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "228576.protein.sequences.v11.5.fa",
		        "enrichment_path": "228576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "228576.protein.info.v11.5.txt",
		        "node_list_path": "228576.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumArborisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium arboris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumArborisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "935557.clusters.info.v11.5.txt",
		        "cluster_tree_path": "935557.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "935557.clusters.proteins.v11.5.txt",
		        "sequence_path": "935557.protein.sequences.v11.5.fa",
		        "enrichment_path": "935557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "935557.protein.info.v11.5.txt",
		        "node_list_path": "935557.cluster.nodes.v11.5.txt",
		        "edge_list_path": "935557.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaballeroniaTelluris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caballeronia telluris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaballeroniaTelluris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "326475.protein.sequences.v11.5.fa",
		        "enrichment_path": "326475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "326475.protein.info.v11.5.txt",
		        "node_list_path": "326475.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridialesBacteriumDtu075Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU075 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridialesBacteriumDtu075Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1671659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1671659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1671659.clusters.proteins.v11.5.txt",
		        "sequence_path": "1671659.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671659.protein.info.v11.5.txt",
		        "node_list_path": "1671659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1671659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CatenulisporaAcidiphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catenulispora acidiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatenulisporaAcidiphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "479433.protein.sequences.v11.5.fa",
		        "enrichment_path": "479433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "479433.protein.info.v11.5.txt",
		        "node_list_path": "479433.protein.complete.v11.5.txt"
		    }
		]
    )()

def CatagonusWagneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Catagonus wagneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CatagonusWagneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "51154.protein.sequences.v11.5.fa",
		        "enrichment_path": "51154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "51154.protein.info.v11.5.txt",
		        "node_list_path": "51154.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusOmnitrophicaBacteriumCg1024015Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_40_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024015Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805284.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805284.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805284.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805284.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805284.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805284.protein.info.v11.5.txt",
		        "node_list_path": "1805284.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805284.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAtcc27244Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ATCC27244 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAtcc27244Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "525244.clusters.info.v11.5.txt",
		        "cluster_tree_path": "525244.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "525244.clusters.proteins.v11.5.txt",
		        "sequence_path": "525244.protein.sequences.v11.5.fa",
		        "enrichment_path": "525244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "525244.protein.info.v11.5.txt",
		        "node_list_path": "525244.cluster.nodes.v11.5.txt",
		        "edge_list_path": "525244.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrococcalesBacterium7315Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 73-15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrococcalesBacterium7315Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895792.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895792.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895792.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895792.protein.info.v11.5.txt",
		        "node_list_path": "1895792.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895792.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeglectaTimonensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Neglecta timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeglectaTimonensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776382.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776382.protein.info.v11.5.txt",
		        "node_list_path": "1776382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GelidibacterMesophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gelidibacter mesophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GelidibacterMesophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121912.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121912.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121912.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121912.protein.info.v11.5.txt",
		        "node_list_path": "1121912.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121912.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SynechococcusSpWh8016(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SynechococcusSpWh8016", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "166318.protein.sequences.v11.5.fa",
		        "enrichment_path": "166318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "166318.protein.info.v11.5.txt",
		        "node_list_path": "166318.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArenimonasMetalliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas metalli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenimonasMetalliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1384056.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1384056.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1384056.clusters.proteins.v11.5.txt",
		        "sequence_path": "1384056.protein.sequences.v11.5.fa",
		        "enrichment_path": "1384056.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1384056.protein.info.v11.5.txt",
		        "node_list_path": "1384056.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1384056.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeisingeraSpAngVpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leisingera sp. ANG-Vp Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeisingeraSpAngVpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577896.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577896.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577896.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577896.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577896.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577896.protein.info.v11.5.txt",
		        "node_list_path": "1577896.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577896.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodobacterCapsulatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter capsulatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterCapsulatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272942.protein.sequences.v11.5.fa",
		        "enrichment_path": "272942.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272942.protein.info.v11.5.txt",
		        "node_list_path": "272942.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusSpF0407(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0407 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpF0407", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "861455.protein.sequences.v11.5.fa",
		        "enrichment_path": "861455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861455.protein.info.v11.5.txt",
		        "node_list_path": "861455.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanktothricoidesSpSr001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planktothricoides sp. SR001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktothricoidesSpSr001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1705388.protein.sequences.v11.5.fa",
		        "enrichment_path": "1705388.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1705388.protein.info.v11.5.txt",
		        "node_list_path": "1705388.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPelagibacterSpRs40Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. RS40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPelagibacterSpRs40Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1977865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1977865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1977865.clusters.proteins.v11.5.txt",
		        "sequence_path": "1977865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1977865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1977865.protein.info.v11.5.txt",
		        "node_list_path": "1977865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1977865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChloroflexiBacteriumGwb24920(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWB2_49_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChloroflexiBacteriumGwb24920", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797612.protein.info.v11.5.txt",
		        "node_list_path": "1797612.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasFluorescensNcimb11764(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens NCIMB11764 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFluorescensNcimb11764", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1221522.protein.sequences.v11.5.fa",
		        "enrichment_path": "1221522.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1221522.protein.info.v11.5.txt",
		        "node_list_path": "1221522.protein.complete.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumRifoxyc2Full3825Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYC2_FULL_38_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyc2Full3825Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798453.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798453.protein.info.v11.5.txt",
		        "node_list_path": "1798453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisSpH115(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H115 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisSpH115", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1759073.protein.sequences.v11.5.fa",
		        "enrichment_path": "1759073.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1759073.protein.info.v11.5.txt",
		        "node_list_path": "1759073.protein.complete.v11.5.txt"
		    }
		]
    )()

def CalidrisPugnax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Calidris pugnax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalidrisPugnax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "198806.protein.sequences.v11.5.fa",
		        "enrichment_path": "198806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198806.protein.info.v11.5.txt",
		        "node_list_path": "198806.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpBgeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Bge Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpBgeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "331104.clusters.info.v11.5.txt",
		        "cluster_tree_path": "331104.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "331104.clusters.proteins.v11.5.txt",
		        "sequence_path": "331104.protein.sequences.v11.5.fa",
		        "enrichment_path": "331104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331104.protein.info.v11.5.txt",
		        "node_list_path": "331104.cluster.nodes.v11.5.txt",
		        "edge_list_path": "331104.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesNeuiiBvs029a5Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces neuii BVS029A5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesNeuiiBvs029a5Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888439.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888439.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888439.clusters.proteins.v11.5.txt",
		        "sequence_path": "888439.protein.sequences.v11.5.fa",
		        "enrichment_path": "888439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888439.protein.info.v11.5.txt",
		        "node_list_path": "888439.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888439.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolyangiaceaeBacteriumUtpro1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polyangiaceae bacterium UTPRO1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolyangiaceaeBacteriumUtpro1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1961108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961108.protein.info.v11.5.txt",
		        "node_list_path": "1961108.protein.complete.v11.5.txt"
		    }
		]
    )()

def EscherichiaAlbertiiKf1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia albertii KF1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EscherichiaAlbertiiKf1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1440052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1440052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1440052.clusters.proteins.v11.5.txt",
		        "sequence_path": "1440052.protein.sequences.v11.5.fa",
		        "enrichment_path": "1440052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1440052.protein.info.v11.5.txt",
		        "node_list_path": "1440052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1440052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4432Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_12_FULL_44_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4432Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798366.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798366.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798366.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798366.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798366.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798366.protein.info.v11.5.txt",
		        "node_list_path": "1798366.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798366.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JanthinobacteriumSpB98(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. B9-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanthinobacteriumSpB98", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236179.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236179.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236179.protein.info.v11.5.txt",
		        "node_list_path": "1236179.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichococcusPasteurii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichococcus pasteurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichococcusPasteurii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43064.protein.sequences.v11.5.fa",
		        "enrichment_path": "43064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43064.protein.info.v11.5.txt",
		        "node_list_path": "43064.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaAutotrophicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia autotrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaAutotrophicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2074.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2074.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2074.clusters.proteins.v11.5.txt",
		        "sequence_path": "2074.protein.sequences.v11.5.fa",
		        "enrichment_path": "2074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2074.protein.info.v11.5.txt",
		        "node_list_path": "2074.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2074.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ZunongwangiaAtlantica22ii1410f7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zunongwangia atlantica 22II14-10F7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZunongwangiaAtlantica22ii1410f7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1185767.protein.sequences.v11.5.fa",
		        "enrichment_path": "1185767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1185767.protein.info.v11.5.txt",
		        "node_list_path": "1185767.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoykebacteriaBacteriumRifcsplowo201Full4314Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RIFCSPLOWO2_01_FULL_43_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRifcsplowo201Full4314Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802605.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802605.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802605.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802605.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802605.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802605.protein.info.v11.5.txt",
		        "node_list_path": "1802605.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802605.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSp1m11Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 1M-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSp1m11Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1529006.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1529006.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1529006.clusters.proteins.v11.5.txt",
		        "sequence_path": "1529006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1529006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1529006.protein.info.v11.5.txt",
		        "node_list_path": "1529006.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1529006.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraCactorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora cactorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraCactorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29920.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29920.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29920.clusters.proteins.v11.5.txt",
		        "sequence_path": "29920.protein.sequences.v11.5.fa",
		        "enrichment_path": "29920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29920.protein.info.v11.5.txt",
		        "node_list_path": "29920.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29920.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SchistosomaMargrebowiei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Schistosoma margrebowiei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SchistosomaMargrebowiei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "48269.protein.sequences.v11.5.fa",
		        "enrichment_path": "48269.protein.enrichment.terms.v11.5.txt",
		        "info_path": "48269.protein.info.v11.5.txt",
		        "node_list_path": "48269.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudovibrioSpFobeg1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. FOBEG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioSpFobeg1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "911045.protein.sequences.v11.5.fa",
		        "enrichment_path": "911045.protein.enrichment.terms.v11.5.txt",
		        "info_path": "911045.protein.info.v11.5.txt",
		        "node_list_path": "911045.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioSpLb2011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. LB2011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioSpLb2011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408312.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408312.protein.info.v11.5.txt",
		        "node_list_path": "1408312.protein.complete.v11.5.txt"
		    }
		]
    )()

def EisenibacterElegansDsm3317(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eisenibacter elegans DSM 3317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EisenibacterElegansDsm3317", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121902.protein.info.v11.5.txt",
		        "node_list_path": "1121902.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCoagulans36d1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coagulans 36D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCoagulans36d1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "345219.clusters.info.v11.5.txt",
		        "cluster_tree_path": "345219.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "345219.clusters.proteins.v11.5.txt",
		        "sequence_path": "345219.protein.sequences.v11.5.fa",
		        "enrichment_path": "345219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "345219.protein.info.v11.5.txt",
		        "node_list_path": "345219.cluster.nodes.v11.5.txt",
		        "edge_list_path": "345219.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoprobacterFastidiosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprobacter fastidiosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoprobacterFastidiosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1349822.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1349822.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1349822.clusters.proteins.v11.5.txt",
		        "sequence_path": "1349822.protein.sequences.v11.5.fa",
		        "enrichment_path": "1349822.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1349822.protein.info.v11.5.txt",
		        "node_list_path": "1349822.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1349822.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalogeometricumRufum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halogeometricum rufum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalogeometricumRufum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553469.protein.sequences.v11.5.fa",
		        "enrichment_path": "553469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553469.protein.info.v11.5.txt",
		        "node_list_path": "553469.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterNecessariusAsymbioticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius asymbioticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterNecessariusAsymbioticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "312153.clusters.info.v11.5.txt",
		        "cluster_tree_path": "312153.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "312153.clusters.proteins.v11.5.txt",
		        "sequence_path": "312153.protein.sequences.v11.5.fa",
		        "enrichment_path": "312153.protein.enrichment.terms.v11.5.txt",
		        "info_path": "312153.protein.info.v11.5.txt",
		        "node_list_path": "312153.cluster.nodes.v11.5.txt",
		        "edge_list_path": "312153.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichinellaBritoviCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichinella britovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaBritoviCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "45882.clusters.info.v11.5.txt",
		        "cluster_tree_path": "45882.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "45882.clusters.proteins.v11.5.txt",
		        "sequence_path": "45882.protein.sequences.v11.5.fa",
		        "enrichment_path": "45882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45882.protein.info.v11.5.txt",
		        "node_list_path": "45882.cluster.nodes.v11.5.txt",
		        "edge_list_path": "45882.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AllosalinactinosporaLopnorensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Allosalinactinospora lopnorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllosalinactinosporaLopnorensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1352348.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1352348.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1352348.clusters.proteins.v11.5.txt",
		        "sequence_path": "1352348.protein.sequences.v11.5.fa",
		        "enrichment_path": "1352348.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1352348.protein.info.v11.5.txt",
		        "node_list_path": "1352348.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1352348.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumGw2011Gwa23836(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWA2_38_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwa23836", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619055.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619055.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619055.protein.info.v11.5.txt",
		        "node_list_path": "1619055.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusPeregrinibacteriaBacteriumGw2011Gwf23917Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_39_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf23917Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1619067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1619067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1619067.clusters.proteins.v11.5.txt",
		        "sequence_path": "1619067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619067.protein.info.v11.5.txt",
		        "node_list_path": "1619067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1619067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesPurpeofuscus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces purpeofuscus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesPurpeofuscus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "67352.protein.sequences.v11.5.fa",
		        "enrichment_path": "67352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "67352.protein.info.v11.5.txt",
		        "node_list_path": "67352.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag628(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:628 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag628", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262829.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262829.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262829.protein.info.v11.5.txt",
		        "node_list_path": "1262829.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumGwf24014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_40_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumGwf24014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797347.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797347.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797347.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797347.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797347.protein.info.v11.5.txt",
		        "node_list_path": "1797347.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797347.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterCloacaeEcwsu1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae EcWSU1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterCloacaeEcwsu1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1045856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1045856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1045856.clusters.proteins.v11.5.txt",
		        "sequence_path": "1045856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1045856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1045856.protein.info.v11.5.txt",
		        "node_list_path": "1045856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1045856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpRoot4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpRoot4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736525.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736525.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736525.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736525.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736525.protein.info.v11.5.txt",
		        "node_list_path": "1736525.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736525.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhormidiumTenueNies30(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phormidium tenue NIES-30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhormidiumTenueNies30", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "549789.protein.sequences.v11.5.fa",
		        "enrichment_path": "549789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "549789.protein.info.v11.5.txt",
		        "node_list_path": "549789.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisGanjiahuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis ganjiahuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisGanjiahuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1237500.protein.sequences.v11.5.fa",
		        "enrichment_path": "1237500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1237500.protein.info.v11.5.txt",
		        "node_list_path": "1237500.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiopsisAlba(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiopsisAlba", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1205910.protein.sequences.v11.5.fa",
		        "enrichment_path": "1205910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1205910.protein.info.v11.5.txt",
		        "node_list_path": "1205910.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalanaeroarchaeumSulfurireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halanaeroarchaeum sulfurireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalanaeroarchaeumSulfurireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1604004.protein.sequences.v11.5.fa",
		        "enrichment_path": "1604004.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1604004.protein.info.v11.5.txt",
		        "node_list_path": "1604004.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterInsulaenigraeNctc12927(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter insulaenigrae NCTC 12927 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterInsulaenigraeNctc12927", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1031564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1031564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1031564.protein.info.v11.5.txt",
		        "node_list_path": "1031564.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavihumibacterSpCaciam22h1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavihumibacter sp. CACIAM 22H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavihumibacterSpCaciam22h1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1812911.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1812911.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1812911.clusters.proteins.v11.5.txt",
		        "sequence_path": "1812911.protein.sequences.v11.5.fa",
		        "enrichment_path": "1812911.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1812911.protein.info.v11.5.txt",
		        "node_list_path": "1812911.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1812911.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PochoniaChlamydosporia123Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pochonia chlamydosporia 123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PochoniaChlamydosporia123Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1052797.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1052797.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1052797.clusters.proteins.v11.5.txt",
		        "sequence_path": "1052797.protein.sequences.v11.5.fa",
		        "enrichment_path": "1052797.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1052797.protein.info.v11.5.txt",
		        "node_list_path": "1052797.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1052797.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaSanticrucis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Legionella santicrucis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaSanticrucis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "45074.protein.sequences.v11.5.fa",
		        "enrichment_path": "45074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "45074.protein.info.v11.5.txt",
		        "node_list_path": "45074.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermogladiusCellulolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermogladius cellulolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermogladiusCellulolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1184251.protein.sequences.v11.5.fa",
		        "enrichment_path": "1184251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1184251.protein.info.v11.5.txt",
		        "node_list_path": "1184251.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesFulvissimus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces fulvissimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesFulvissimus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1303692.protein.sequences.v11.5.fa",
		        "enrichment_path": "1303692.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1303692.protein.info.v11.5.txt",
		        "node_list_path": "1303692.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldilineaAerophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldilinea aerophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldilineaAerophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "926550.clusters.info.v11.5.txt",
		        "cluster_tree_path": "926550.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "926550.clusters.proteins.v11.5.txt",
		        "sequence_path": "926550.protein.sequences.v11.5.fa",
		        "enrichment_path": "926550.protein.enrichment.terms.v11.5.txt",
		        "info_path": "926550.protein.info.v11.5.txt",
		        "node_list_path": "926550.cluster.nodes.v11.5.txt",
		        "edge_list_path": "926550.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HerbaspirillumSpGw103Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. GW103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbaspirillumSpGw103Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1175306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1175306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1175306.clusters.proteins.v11.5.txt",
		        "sequence_path": "1175306.protein.sequences.v11.5.fa",
		        "enrichment_path": "1175306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1175306.protein.info.v11.5.txt",
		        "node_list_path": "1175306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1175306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidaGlabrataCbs138Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Candida] glabrata CBS 138 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaGlabrataCbs138Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "284593.clusters.info.v11.5.txt",
		        "cluster_tree_path": "284593.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "284593.clusters.proteins.v11.5.txt",
		        "sequence_path": "284593.protein.sequences.v11.5.fa",
		        "enrichment_path": "284593.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284593.protein.info.v11.5.txt",
		        "node_list_path": "284593.cluster.nodes.v11.5.txt",
		        "edge_list_path": "284593.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasTaxi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas taxi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasTaxi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1549858.protein.sequences.v11.5.fa",
		        "enrichment_path": "1549858.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1549858.protein.info.v11.5.txt",
		        "node_list_path": "1549858.protein.complete.v11.5.txt"
		    }
		]
    )()

def GymnopilusDilepisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gymnopilus dilepis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GymnopilusDilepisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "231916.clusters.info.v11.5.txt",
		        "cluster_tree_path": "231916.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "231916.clusters.proteins.v11.5.txt",
		        "sequence_path": "231916.protein.sequences.v11.5.fa",
		        "enrichment_path": "231916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "231916.protein.info.v11.5.txt",
		        "node_list_path": "231916.cluster.nodes.v11.5.txt",
		        "edge_list_path": "231916.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumNeworleansense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium neworleansense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumNeworleansense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "146018.protein.sequences.v11.5.fa",
		        "enrichment_path": "146018.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146018.protein.info.v11.5.txt",
		        "node_list_path": "146018.protein.complete.v11.5.txt"
		    }
		]
    )()

def MariniblastusFucicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mariniblastus fucicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MariniblastusFucicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "980251.clusters.info.v11.5.txt",
		        "cluster_tree_path": "980251.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "980251.clusters.proteins.v11.5.txt",
		        "sequence_path": "980251.protein.sequences.v11.5.fa",
		        "enrichment_path": "980251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "980251.protein.info.v11.5.txt",
		        "node_list_path": "980251.cluster.nodes.v11.5.txt",
		        "edge_list_path": "980251.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterAilurogastricusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter ailurogastricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterAilurogastricusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1578720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1578720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1578720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1578720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1578720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1578720.protein.info.v11.5.txt",
		        "node_list_path": "1578720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1578720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumAkiainvivensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium akiainvivens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumAkiainvivensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1202724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1202724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1202724.clusters.proteins.v11.5.txt",
		        "sequence_path": "1202724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202724.protein.info.v11.5.txt",
		        "node_list_path": "1202724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1202724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeferribacteralesBacteriumDeferri01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Deferribacterales bacterium Deferri_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeferribacteralesBacteriumDeferri01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674894.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674894.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674894.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674894.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674894.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674894.protein.info.v11.5.txt",
		        "node_list_path": "1674894.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674894.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThalassobiumSpR2a62Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassobium sp. R2A62 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThalassobiumSpR2a62Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "633131.clusters.info.v11.5.txt",
		        "cluster_tree_path": "633131.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "633131.clusters.proteins.v11.5.txt",
		        "sequence_path": "633131.protein.sequences.v11.5.fa",
		        "enrichment_path": "633131.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633131.protein.info.v11.5.txt",
		        "node_list_path": "633131.cluster.nodes.v11.5.txt",
		        "edge_list_path": "633131.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SciscionellaMarinaDsm45152(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sciscionella marina DSM 45152 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SciscionellaMarinaDsm45152", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123244.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123244.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123244.protein.info.v11.5.txt",
		        "node_list_path": "1123244.protein.complete.v11.5.txt"
		    }
		]
    )()

def PediococcusStilesiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus stilesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PediococcusStilesiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "331679.clusters.info.v11.5.txt",
		        "cluster_tree_path": "331679.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "331679.clusters.proteins.v11.5.txt",
		        "sequence_path": "331679.protein.sequences.v11.5.fa",
		        "enrichment_path": "331679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331679.protein.info.v11.5.txt",
		        "node_list_path": "331679.cluster.nodes.v11.5.txt",
		        "edge_list_path": "331679.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VignaRadiataVarRadiata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vigna radiata var. radiata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VignaRadiataVarRadiata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3916.protein.sequences.v11.5.fa",
		        "enrichment_path": "3916.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3916.protein.info.v11.5.txt",
		        "node_list_path": "3916.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumPusillum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium pusillum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumPusillum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "69373.protein.sequences.v11.5.fa",
		        "enrichment_path": "69373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "69373.protein.info.v11.5.txt",
		        "node_list_path": "69373.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenisporosarcinaIndica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenisporosarcina indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenisporosarcinaIndica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "650093.protein.sequences.v11.5.fa",
		        "enrichment_path": "650093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "650093.protein.info.v11.5.txt",
		        "node_list_path": "650093.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpOk091Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. OK091 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpOk091Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881037.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881037.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881037.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881037.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881037.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881037.protein.info.v11.5.txt",
		        "node_list_path": "1881037.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881037.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MassiliaSpNr41(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Massilia sp. NR 4-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MassiliaSpNr41", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1678028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1678028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1678028.protein.info.v11.5.txt",
		        "node_list_path": "1678028.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegamonasFuniformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megamonas funiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegamonasFuniformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "437897.protein.sequences.v11.5.fa",
		        "enrichment_path": "437897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "437897.protein.info.v11.5.txt",
		        "node_list_path": "437897.protein.complete.v11.5.txt"
		    }
		]
    )()

def BranchiostomaFloridae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Branchiostoma floridae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BranchiostomaFloridae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "7739.protein.sequences.v11.5.fa",
		        "enrichment_path": "7739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7739.protein.info.v11.5.txt",
		        "node_list_path": "7739.protein.complete.v11.5.txt"
		    }
		]
    )()

def FacklamiaSourekiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Facklamia sourekii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FacklamiaSourekiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408438.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408438.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408438.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408438.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408438.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408438.protein.info.v11.5.txt",
		        "node_list_path": "1408438.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408438.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaPeanutWitchesbroomCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma peanut witchesbroom Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaPeanutWitchesbroomCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163385.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1163385.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1163385.clusters.proteins.v11.0.txt",
		        "sequence_path": "1163385.protein.sequences.v11.0.fa",
		        "enrichment_path": "1163385.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1163385.protein.info.v11.0.txt",
		        "node_list_path": "1163385.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1163385.protein.cluster.v11.0.txt"
		    }
		]
    )()

def StreptococcusSpF0407Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0407 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSpF0407Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "861455.clusters.info.v11.5.txt",
		        "cluster_tree_path": "861455.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "861455.clusters.proteins.v11.5.txt",
		        "sequence_path": "861455.protein.sequences.v11.5.fa",
		        "enrichment_path": "861455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861455.protein.info.v11.5.txt",
		        "node_list_path": "861455.cluster.nodes.v11.5.txt",
		        "edge_list_path": "861455.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CommensalibacterSpMx01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Commensalibacter sp. MX01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CommensalibacterSpMx01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1208583.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1208583.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1208583.clusters.proteins.v11.5.txt",
		        "sequence_path": "1208583.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208583.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208583.protein.info.v11.5.txt",
		        "node_list_path": "1208583.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1208583.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPoaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas poae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPoaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1282356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1282356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1282356.clusters.proteins.v11.5.txt",
		        "sequence_path": "1282356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282356.protein.info.v11.5.txt",
		        "node_list_path": "1282356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1282356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NicotianaAttenuata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nicotiana attenuata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NicotianaAttenuata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "49451.protein.sequences.v11.5.fa",
		        "enrichment_path": "49451.protein.enrichment.terms.v11.5.txt",
		        "info_path": "49451.protein.info.v11.5.txt",
		        "node_list_path": "49451.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4515Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFCSPLOWO2_02_FULL_45_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4515Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797988.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797988.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797988.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797988.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797988.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797988.protein.info.v11.5.txt",
		        "node_list_path": "1797988.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797988.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XenophilusAzovorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xenophilus azovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenophilusAzovorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123504.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123504.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123504.protein.info.v11.5.txt",
		        "node_list_path": "1123504.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharothrixSyringaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharothrix syringae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharothrixSyringaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "103733.clusters.info.v11.5.txt",
		        "cluster_tree_path": "103733.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "103733.clusters.proteins.v11.5.txt",
		        "sequence_path": "103733.protein.sequences.v11.5.fa",
		        "enrichment_path": "103733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "103733.protein.info.v11.5.txt",
		        "node_list_path": "103733.cluster.nodes.v11.5.txt",
		        "edge_list_path": "103733.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpSjs(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. SJS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpSjs", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423321.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423321.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423321.protein.info.v11.5.txt",
		        "node_list_path": "1423321.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumSpCp1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium sp. CP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumSpCp1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1564681.protein.sequences.v11.5.fa",
		        "enrichment_path": "1564681.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1564681.protein.info.v11.5.txt",
		        "node_list_path": "1564681.protein.complete.v11.5.txt"
		    }
		]
    )()

def RudanellaLuteaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rudanella lutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RudanellaLuteaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1089547.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1089547.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1089547.clusters.proteins.v11.5.txt",
		        "sequence_path": "1089547.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089547.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089547.protein.info.v11.5.txt",
		        "node_list_path": "1089547.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1089547.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichinellaPatagoniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichinella patagoniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichinellaPatagoniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "990121.clusters.info.v11.5.txt",
		        "cluster_tree_path": "990121.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "990121.clusters.proteins.v11.5.txt",
		        "sequence_path": "990121.protein.sequences.v11.5.fa",
		        "enrichment_path": "990121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "990121.protein.info.v11.5.txt",
		        "node_list_path": "990121.cluster.nodes.v11.5.txt",
		        "edge_list_path": "990121.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CarnobacteriumGallinarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarnobacteriumGallinarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1449338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1449338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1449338.clusters.proteins.v11.5.txt",
		        "sequence_path": "1449338.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449338.protein.info.v11.5.txt",
		        "node_list_path": "1449338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1449338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobacteriumCongolense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium congolense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobacteriumCongolense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "118062.protein.sequences.v11.5.fa",
		        "enrichment_path": "118062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118062.protein.info.v11.5.txt",
		        "node_list_path": "118062.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaBacteriumBbfl7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium BBFL7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaBacteriumBbfl7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "156586.protein.sequences.v11.5.fa",
		        "enrichment_path": "156586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156586.protein.info.v11.5.txt",
		        "node_list_path": "156586.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlkalibacteriumSubtropicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacterium subtropicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkalibacteriumSubtropicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "753702.protein.sequences.v11.5.fa",
		        "enrichment_path": "753702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "753702.protein.info.v11.5.txt",
		        "node_list_path": "753702.protein.complete.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsplowo201Full4510(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO2_01_FULL_45_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo201Full4510", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801826.protein.info.v11.5.txt",
		        "node_list_path": "1801826.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusMundtiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus mundtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusMundtiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1300150.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1300150.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1300150.clusters.proteins.v11.5.txt",
		        "sequence_path": "1300150.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300150.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300150.protein.info.v11.5.txt",
		        "node_list_path": "1300150.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1300150.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BifidobacteriumAngulatumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium angulatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BifidobacteriumAngulatumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "518635.clusters.info.v11.5.txt",
		        "cluster_tree_path": "518635.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "518635.clusters.proteins.v11.5.txt",
		        "sequence_path": "518635.protein.sequences.v11.5.fa",
		        "enrichment_path": "518635.protein.enrichment.terms.v11.5.txt",
		        "info_path": "518635.protein.info.v11.5.txt",
		        "node_list_path": "518635.cluster.nodes.v11.5.txt",
		        "edge_list_path": "518635.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhanerochaeteCarnosaHhb10118SpCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phanerochaete carnosa HHB-10118-sp Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhanerochaeteCarnosaHhb10118SpCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "650164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "650164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "650164.clusters.proteins.v11.5.txt",
		        "sequence_path": "650164.protein.sequences.v11.5.fa",
		        "enrichment_path": "650164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "650164.protein.info.v11.5.txt",
		        "node_list_path": "650164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "650164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusAcidominimusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus acidominimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAcidominimusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1326.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1326.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1326.clusters.proteins.v11.5.txt",
		        "sequence_path": "1326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1326.protein.info.v11.5.txt",
		        "node_list_path": "1326.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1326.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycoplasmaGallisepticumFCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum F Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaGallisepticumFCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "708616.clusters.info.v11.5.txt",
		        "cluster_tree_path": "708616.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "708616.clusters.proteins.v11.5.txt",
		        "sequence_path": "708616.protein.sequences.v11.5.fa",
		        "enrichment_path": "708616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "708616.protein.info.v11.5.txt",
		        "node_list_path": "708616.cluster.nodes.v11.5.txt",
		        "edge_list_path": "708616.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RenibacteriumSalmoninarumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Renibacterium salmoninarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RenibacteriumSalmoninarumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "288705.clusters.info.v11.5.txt",
		        "cluster_tree_path": "288705.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "288705.clusters.proteins.v11.5.txt",
		        "sequence_path": "288705.protein.sequences.v11.5.fa",
		        "enrichment_path": "288705.protein.enrichment.terms.v11.5.txt",
		        "info_path": "288705.protein.info.v11.5.txt",
		        "node_list_path": "288705.cluster.nodes.v11.5.txt",
		        "edge_list_path": "288705.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSp263Sspc(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. 263_SSPC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSp263Sspc", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1579343.protein.sequences.v11.5.fa",
		        "enrichment_path": "1579343.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1579343.protein.info.v11.5.txt",
		        "node_list_path": "1579343.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusObscurusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus obscurus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusObscurusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "526225.clusters.info.v11.5.txt",
		        "cluster_tree_path": "526225.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "526225.clusters.proteins.v11.5.txt",
		        "sequence_path": "526225.protein.sequences.v11.5.fa",
		        "enrichment_path": "526225.protein.enrichment.terms.v11.5.txt",
		        "info_path": "526225.protein.info.v11.5.txt",
		        "node_list_path": "526225.cluster.nodes.v11.5.txt",
		        "edge_list_path": "526225.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LegionellaErythraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella erythra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaErythraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "448.clusters.info.v11.5.txt",
		        "cluster_tree_path": "448.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "448.clusters.proteins.v11.5.txt",
		        "sequence_path": "448.protein.sequences.v11.5.fa",
		        "enrichment_path": "448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "448.protein.info.v11.5.txt",
		        "node_list_path": "448.cluster.nodes.v11.5.txt",
		        "edge_list_path": "448.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AllochromatiumWarmingiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Allochromatium warmingii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllochromatiumWarmingiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "61595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "61595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "61595.clusters.proteins.v11.5.txt",
		        "sequence_path": "61595.protein.sequences.v11.5.fa",
		        "enrichment_path": "61595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "61595.protein.info.v11.5.txt",
		        "node_list_path": "61595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "61595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPseudoalcaligenesAd6(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes AD6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPseudoalcaligenesAd6", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1453503.protein.sequences.v11.5.fa",
		        "enrichment_path": "1453503.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1453503.protein.info.v11.5.txt",
		        "node_list_path": "1453503.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonasOceanitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas oceanitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonasOceanitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280953.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280953.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280953.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280953.protein.info.v11.5.txt",
		        "node_list_path": "1280953.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280953.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpAb57Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB57 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpAb57Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1841860.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1841860.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1841860.clusters.proteins.v11.5.txt",
		        "sequence_path": "1841860.protein.sequences.v11.5.fa",
		        "enrichment_path": "1841860.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1841860.protein.info.v11.5.txt",
		        "node_list_path": "1841860.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1841860.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusUliginisN3975(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus uliginis N3/975 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusUliginisN3975", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1313296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1313296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1313296.protein.info.v11.5.txt",
		        "node_list_path": "1313296.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3710(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_37_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3710", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797783.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797783.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797783.protein.info.v11.5.txt",
		        "node_list_path": "1797783.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaeroarcusBurkinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaeroarcus burkinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaeroarcusBurkinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120985.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120985.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120985.protein.info.v11.5.txt",
		        "node_list_path": "1120985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag273(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:273 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag273", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262789.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262789.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262789.protein.info.v11.5.txt",
		        "node_list_path": "1262789.protein.complete.v11.5.txt"
		    }
		]
    )()

def DaucusCarotaSubspSativusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Daucus carota subsp. sativus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DaucusCarotaSubspSativusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "79200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "79200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "79200.clusters.proteins.v11.5.txt",
		        "sequence_path": "79200.protein.sequences.v11.5.fa",
		        "enrichment_path": "79200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "79200.protein.info.v11.5.txt",
		        "node_list_path": "79200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "79200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteriumCg2304012(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return bacterium CG2_30_40_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriumCg2304012", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805402.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805402.protein.info.v11.5.txt",
		        "node_list_path": "1805402.protein.complete.v11.5.txt"
		    }
		]
    )()

def CordycepsSpRao2017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps sp. RAO-2017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CordycepsSpRao2017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2004951.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2004951.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2004951.clusters.proteins.v11.5.txt",
		        "sequence_path": "2004951.protein.sequences.v11.5.fa",
		        "enrichment_path": "2004951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2004951.protein.info.v11.5.txt",
		        "node_list_path": "2004951.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2004951.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanibulbusIndolifexCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanibulbus indolifex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanibulbusIndolifexCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391624.clusters.proteins.v11.5.txt",
		        "sequence_path": "391624.protein.sequences.v11.5.fa",
		        "enrichment_path": "391624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391624.protein.info.v11.5.txt",
		        "node_list_path": "391624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudarthrobacterSulfonivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudarthrobacter sulfonivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudarthrobacterSulfonivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "121292.protein.sequences.v11.5.fa",
		        "enrichment_path": "121292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "121292.protein.info.v11.5.txt",
		        "node_list_path": "121292.protein.complete.v11.5.txt"
		    }
		]
    )()

def PapilioMachaon(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Papilio machaon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PapilioMachaon", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "76193.protein.sequences.v11.5.fa",
		        "enrichment_path": "76193.protein.enrichment.terms.v11.5.txt",
		        "info_path": "76193.protein.info.v11.5.txt",
		        "node_list_path": "76193.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanohalophilusSp2Gbenrich(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus sp. 2-GBenrich graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanohalophilusSp2Gbenrich", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884871.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884871.protein.info.v11.5.txt",
		        "node_list_path": "1884871.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanktotaleaArcticaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planktotalea arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktotaleaArcticaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1481893.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1481893.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1481893.clusters.proteins.v11.5.txt",
		        "sequence_path": "1481893.protein.sequences.v11.5.fa",
		        "enrichment_path": "1481893.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1481893.protein.info.v11.5.txt",
		        "node_list_path": "1481893.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1481893.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumGwa25511(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_55_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumGwa25511", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798421.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798421.protein.info.v11.5.txt",
		        "node_list_path": "1798421.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3917(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_39_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3917", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801770.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801770.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801770.protein.info.v11.5.txt",
		        "node_list_path": "1801770.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquidulcibacterPaucihalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquidulcibacter paucihalophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquidulcibacterPaucihalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1978549.protein.sequences.v11.5.fa",
		        "enrichment_path": "1978549.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1978549.protein.info.v11.5.txt",
		        "node_list_path": "1978549.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusCanisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusCanisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "482234.clusters.info.v11.5.txt",
		        "cluster_tree_path": "482234.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "482234.clusters.proteins.v11.5.txt",
		        "sequence_path": "482234.protein.sequences.v11.5.fa",
		        "enrichment_path": "482234.protein.enrichment.terms.v11.5.txt",
		        "info_path": "482234.protein.info.v11.5.txt",
		        "node_list_path": "482234.cluster.nodes.v11.5.txt",
		        "edge_list_path": "482234.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaladaptatusPaucihalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haladaptatus paucihalophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaladaptatusPaucihalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "797209.clusters.info.v11.5.txt",
		        "cluster_tree_path": "797209.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "797209.clusters.proteins.v11.5.txt",
		        "sequence_path": "797209.protein.sequences.v11.5.fa",
		        "enrichment_path": "797209.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797209.protein.info.v11.5.txt",
		        "node_list_path": "797209.cluster.nodes.v11.5.txt",
		        "edge_list_path": "797209.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodovulumSpPh10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. PH10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodovulumSpPh10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1187851.protein.sequences.v11.5.fa",
		        "enrichment_path": "1187851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1187851.protein.info.v11.5.txt",
		        "node_list_path": "1187851.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpOrs278(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. ORS278 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpOrs278", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "114615.protein.sequences.v11.5.fa",
		        "enrichment_path": "114615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "114615.protein.info.v11.5.txt",
		        "node_list_path": "114615.protein.complete.v11.5.txt"
		    }
		]
    )()

def TersicoccusSpBi70Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tersicoccus sp. Bi-70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TersicoccusSpBi70Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1897634.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1897634.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1897634.clusters.proteins.v11.5.txt",
		        "sequence_path": "1897634.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897634.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897634.protein.info.v11.5.txt",
		        "node_list_path": "1897634.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1897634.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusFrumentiDsm13145Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus frumenti DSM 13145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFrumentiDsm13145Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423746.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423746.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423746.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423746.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423746.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423746.protein.info.v11.5.txt",
		        "node_list_path": "1423746.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423746.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumRifcsplowo202Full5016(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPLOWO2_02_FULL_50_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumRifcsplowo202Full5016", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801981.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801981.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801981.protein.info.v11.5.txt",
		        "node_list_path": "1801981.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpDsm4029(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. DSM 4029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpDsm4029", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1882754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1882754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1882754.protein.info.v11.5.txt",
		        "node_list_path": "1882754.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRhodobacterLobularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rhodobacter lobularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRhodobacterLobularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1675527.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1675527.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1675527.clusters.proteins.v11.5.txt",
		        "sequence_path": "1675527.protein.sequences.v11.5.fa",
		        "enrichment_path": "1675527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1675527.protein.info.v11.5.txt",
		        "node_list_path": "1675527.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1675527.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OreochromisAureusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oreochromis aureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OreochromisAureusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "47969.clusters.info.v11.5.txt",
		        "cluster_tree_path": "47969.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "47969.clusters.proteins.v11.5.txt",
		        "sequence_path": "47969.protein.sequences.v11.5.fa",
		        "enrichment_path": "47969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47969.protein.info.v11.5.txt",
		        "node_list_path": "47969.cluster.nodes.v11.5.txt",
		        "edge_list_path": "47969.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriKos6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri KOS6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriKos6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1218352.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1218352.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1218352.clusters.proteins.v11.5.txt",
		        "sequence_path": "1218352.protein.sequences.v11.5.fa",
		        "enrichment_path": "1218352.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1218352.protein.info.v11.5.txt",
		        "node_list_path": "1218352.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1218352.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpHys(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. HYS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpHys", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1163398.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163398.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163398.protein.info.v11.5.txt",
		        "node_list_path": "1163398.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanoregulaFormicica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanoregula formicica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanoregulaFormicica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "593750.protein.sequences.v11.5.fa",
		        "enrichment_path": "593750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "593750.protein.info.v11.5.txt",
		        "node_list_path": "593750.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusFirmusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus firmus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusFirmusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1307436.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1307436.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1307436.clusters.proteins.v11.5.txt",
		        "sequence_path": "1307436.protein.sequences.v11.5.fa",
		        "enrichment_path": "1307436.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1307436.protein.info.v11.5.txt",
		        "node_list_path": "1307436.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1307436.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BilophilaWadsworthia316(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia 316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BilophilaWadsworthia316", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "563192.protein.sequences.v11.5.fa",
		        "enrichment_path": "563192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563192.protein.info.v11.5.txt",
		        "node_list_path": "563192.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobulbusSpTolSr(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus sp. Tol-SR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobulbusSpTolSr", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1536652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1536652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1536652.protein.info.v11.5.txt",
		        "node_list_path": "1536652.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpGhvi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ghvi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpGhvi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855319.protein.info.v11.5.txt",
		        "node_list_path": "1855319.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaVacciniiNbrc15922(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia vaccinii NBRC 15922 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaVacciniiNbrc15922", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210098.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210098.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210098.protein.info.v11.5.txt",
		        "node_list_path": "1210098.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusSp7f3Div0205(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus sp. 7F3_DIV0205 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusSp7f3Div0205", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834189.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834189.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834189.protein.info.v11.5.txt",
		        "node_list_path": "1834189.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerminephrobacterEiseniae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Verminephrobacter eiseniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerminephrobacterEiseniae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391735.protein.sequences.v11.5.fa",
		        "enrichment_path": "391735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391735.protein.info.v11.5.txt",
		        "node_list_path": "391735.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMegateriumQmB1551(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus megaterium QM B1551 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMegateriumQmB1551", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "545693.protein.sequences.v11.5.fa",
		        "enrichment_path": "545693.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545693.protein.info.v11.5.txt",
		        "node_list_path": "545693.protein.complete.v11.5.txt"
		    }
		]
    )()

def AquimarinaLaterculaDsm2041(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina latercula DSM 2041 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AquimarinaLaterculaDsm2041", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121006.protein.info.v11.5.txt",
		        "node_list_path": "1121006.protein.complete.v11.5.txt"
		    }
		]
    )()

def NosocomiicoccusAmpullae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nosocomiicoccus ampullae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NosocomiicoccusAmpullae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "489910.protein.sequences.v11.5.fa",
		        "enrichment_path": "489910.protein.enrichment.terms.v11.5.txt",
		        "info_path": "489910.protein.info.v11.5.txt",
		        "node_list_path": "489910.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanibaculumIndicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanibaculum indicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanibaculumIndicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1207063.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1207063.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1207063.clusters.proteins.v11.5.txt",
		        "sequence_path": "1207063.protein.sequences.v11.5.fa",
		        "enrichment_path": "1207063.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1207063.protein.info.v11.5.txt",
		        "node_list_path": "1207063.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1207063.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobaccaAcetoxidansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacca acetoxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobaccaAcetoxidansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "880072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "880072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "880072.clusters.proteins.v11.5.txt",
		        "sequence_path": "880072.protein.sequences.v11.5.fa",
		        "enrichment_path": "880072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880072.protein.info.v11.5.txt",
		        "node_list_path": "880072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "880072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NocardioidesSzechwanensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides szechwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardioidesSzechwanensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1005944.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005944.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005944.protein.info.v11.5.txt",
		        "node_list_path": "1005944.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalorubrumSpSd626r(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum sp. SD626R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalorubrumSpSd626r", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1419722.protein.sequences.v11.5.fa",
		        "enrichment_path": "1419722.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1419722.protein.info.v11.5.txt",
		        "node_list_path": "1419722.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioOxyclinaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio oxyclinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioOxyclinaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121459.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121459.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121459.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121459.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121459.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121459.protein.info.v11.5.txt",
		        "node_list_path": "1121459.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121459.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobiumChlorophenolicumL1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium chlorophenolicum L-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobiumChlorophenolicumL1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "690566.protein.sequences.v11.5.fa",
		        "enrichment_path": "690566.protein.enrichment.terms.v11.5.txt",
		        "info_path": "690566.protein.info.v11.5.txt",
		        "node_list_path": "690566.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcetobacterMalorumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter malorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterMalorumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "178901.clusters.info.v11.5.txt",
		        "cluster_tree_path": "178901.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "178901.clusters.proteins.v11.5.txt",
		        "sequence_path": "178901.protein.sequences.v11.5.fa",
		        "enrichment_path": "178901.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178901.protein.info.v11.5.txt",
		        "node_list_path": "178901.cluster.nodes.v11.5.txt",
		        "edge_list_path": "178901.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KnoelliaSpSoil729(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Knoellia sp. Soil729 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KnoelliaSpSoil729", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736394.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736394.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736394.protein.info.v11.5.txt",
		        "node_list_path": "1736394.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerobaculumMobileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobaculum mobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerobaculumMobileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "891968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "891968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "891968.clusters.proteins.v11.5.txt",
		        "sequence_path": "891968.protein.sequences.v11.5.fa",
		        "enrichment_path": "891968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "891968.protein.info.v11.5.txt",
		        "node_list_path": "891968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "891968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesRoseoverticillatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces roseoverticillatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesRoseoverticillatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66429.protein.sequences.v11.5.fa",
		        "enrichment_path": "66429.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66429.protein.info.v11.5.txt",
		        "node_list_path": "66429.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumBoenickeiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium boenickei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumBoenickeiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "146017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "146017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "146017.clusters.proteins.v11.5.txt",
		        "sequence_path": "146017.protein.sequences.v11.5.fa",
		        "enrichment_path": "146017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "146017.protein.info.v11.5.txt",
		        "node_list_path": "146017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "146017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRu36dCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. RU36D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRu36dCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1907415.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1907415.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1907415.clusters.proteins.v11.5.txt",
		        "sequence_path": "1907415.protein.sequences.v11.5.fa",
		        "enrichment_path": "1907415.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1907415.protein.info.v11.5.txt",
		        "node_list_path": "1907415.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1907415.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrobacterVulgaris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrobacter vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrobacterVulgaris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29421.protein.sequences.v11.5.fa",
		        "enrichment_path": "29421.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29421.protein.info.v11.5.txt",
		        "node_list_path": "29421.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesCoprophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides coprophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesCoprophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "547042.clusters.info.v11.5.txt",
		        "cluster_tree_path": "547042.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "547042.clusters.proteins.v11.5.txt",
		        "sequence_path": "547042.protein.sequences.v11.5.fa",
		        "enrichment_path": "547042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "547042.protein.info.v11.5.txt",
		        "node_list_path": "547042.cluster.nodes.v11.5.txt",
		        "edge_list_path": "547042.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpC561Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. C561 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpC561Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "563031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "563031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "563031.clusters.proteins.v11.5.txt",
		        "sequence_path": "563031.protein.sequences.v11.5.fa",
		        "enrichment_path": "563031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "563031.protein.info.v11.5.txt",
		        "node_list_path": "563031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "563031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusSucicolaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sucicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSucicolaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423806.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423806.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423806.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423806.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423806.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423806.protein.info.v11.5.txt",
		        "node_list_path": "1423806.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423806.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodospirillumSpUnkMgs17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillum sp. UNK.MGS-17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodospirillumSpUnkMgs17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1638782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1638782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1638782.clusters.proteins.v11.5.txt",
		        "sequence_path": "1638782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1638782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1638782.protein.info.v11.5.txt",
		        "node_list_path": "1638782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1638782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CavenderiaFasciculataSh3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cavenderia fasciculata SH3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CavenderiaFasciculataSh3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1054147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1054147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1054147.protein.info.v11.5.txt",
		        "node_list_path": "1054147.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidaGlabrataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida glabrata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidaGlabrataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5478.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5478.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5478.clusters.proteins.v11.5.txt",
		        "sequence_path": "5478.protein.sequences.v11.5.fa",
		        "enrichment_path": "5478.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5478.protein.info.v11.5.txt",
		        "node_list_path": "5478.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5478.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnsiferSojae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sojae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnsiferSojae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "716928.protein.sequences.v11.5.fa",
		        "enrichment_path": "716928.protein.enrichment.terms.v11.5.txt",
		        "info_path": "716928.protein.info.v11.5.txt",
		        "node_list_path": "716928.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterSpRm8964(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM8964 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterSpRm8964", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660074.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660074.protein.info.v11.5.txt",
		        "node_list_path": "1660074.protein.complete.v11.5.txt"
		    }
		]
    )()

def SecondaryEndosymbiontOfTrabutinaManniparaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Trabutina mannipara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SecondaryEndosymbiontOfTrabutinaManniparaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1835721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1835721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1835721.clusters.proteins.v11.5.txt",
		        "sequence_path": "1835721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1835721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1835721.protein.info.v11.5.txt",
		        "node_list_path": "1835721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1835721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TamlanaNanhaiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tamlana nanhaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TamlanaNanhaiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1382798.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1382798.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1382798.clusters.proteins.v11.5.txt",
		        "sequence_path": "1382798.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382798.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382798.protein.info.v11.5.txt",
		        "node_list_path": "1382798.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1382798.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHtcc7214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC7214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHtcc7214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1400524.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1400524.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1400524.clusters.proteins.v11.5.txt",
		        "sequence_path": "1400524.protein.sequences.v11.5.fa",
		        "enrichment_path": "1400524.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1400524.protein.info.v11.5.txt",
		        "node_list_path": "1400524.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1400524.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterBrisouiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter brisouii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterBrisouiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1217652.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1217652.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1217652.clusters.proteins.v11.5.txt",
		        "sequence_path": "1217652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1217652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1217652.protein.info.v11.5.txt",
		        "node_list_path": "1217652.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1217652.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FirmicutesBacteriumAsf500Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Firmicutes bacterium ASF500 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FirmicutesBacteriumAsf500Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1378168.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1378168.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1378168.clusters.proteins.v11.5.txt",
		        "sequence_path": "1378168.protein.sequences.v11.5.fa",
		        "enrichment_path": "1378168.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1378168.protein.info.v11.5.txt",
		        "node_list_path": "1378168.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1378168.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanomicrobiumMobileCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanomicrobium mobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomicrobiumMobileCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "694440.clusters.info.v11.5.txt",
		        "cluster_tree_path": "694440.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "694440.clusters.proteins.v11.5.txt",
		        "sequence_path": "694440.protein.sequences.v11.5.fa",
		        "enrichment_path": "694440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "694440.protein.info.v11.5.txt",
		        "node_list_path": "694440.cluster.nodes.v11.5.txt",
		        "edge_list_path": "694440.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MegasphaeraMicronuciformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera micronuciformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraMicronuciformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "706434.protein.sequences.v11.5.fa",
		        "enrichment_path": "706434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706434.protein.info.v11.5.txt",
		        "node_list_path": "706434.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpUmwgj(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UMWGJ graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpUmwgj", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1370120.protein.sequences.v11.5.fa",
		        "enrichment_path": "1370120.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1370120.protein.info.v11.5.txt",
		        "node_list_path": "1370120.protein.complete.v11.5.txt"
		    }
		]
    )()

def FriedmanniellaSagamiharensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Friedmanniella sagamiharensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FriedmanniellaSagamiharensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "546874.protein.sequences.v11.5.fa",
		        "enrichment_path": "546874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "546874.protein.info.v11.5.txt",
		        "node_list_path": "546874.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterSpMwhAdlerW8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. MWH-Adler-W8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterSpMwhAdlerW8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1819727.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1819727.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1819727.clusters.proteins.v11.5.txt",
		        "sequence_path": "1819727.protein.sequences.v11.5.fa",
		        "enrichment_path": "1819727.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1819727.protein.info.v11.5.txt",
		        "node_list_path": "1819727.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1819727.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacteriumRhizophilumDsm18822(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium rhizophilum DSM 18822 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacteriumRhizophilumDsm18822", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122202.protein.info.v11.5.txt",
		        "node_list_path": "1122202.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaMexicanaNbrc108244(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia mexicana NBRC 108244 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaMexicanaNbrc108244", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1210089.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210089.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210089.protein.info.v11.5.txt",
		        "node_list_path": "1210089.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4515b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_01_FULL_45_15b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4515b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802319.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802319.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802319.protein.info.v11.5.txt",
		        "node_list_path": "1802319.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobiformaNitratireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobiforma nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobiformaNitratireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227454.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227454.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227454.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227454.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227454.protein.info.v11.5.txt",
		        "node_list_path": "1227454.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227454.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeltaproteobacteriaBacteriumCg2304315(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CG2_30_43_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeltaproteobacteriaBacteriumCg2304315", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805125.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805125.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805125.protein.info.v11.5.txt",
		        "node_list_path": "1805125.protein.complete.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumSpCcbau05631Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. CCBAU05631 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumSpCcbau05631Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "794846.clusters.info.v11.5.txt",
		        "cluster_tree_path": "794846.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "794846.clusters.proteins.v11.5.txt",
		        "sequence_path": "794846.protein.sequences.v11.5.fa",
		        "enrichment_path": "794846.protein.enrichment.terms.v11.5.txt",
		        "info_path": "794846.protein.info.v11.5.txt",
		        "node_list_path": "794846.cluster.nodes.v11.5.txt",
		        "edge_list_path": "794846.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloarculaJaponicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloarculaJaponicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1227453.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1227453.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1227453.clusters.proteins.v11.5.txt",
		        "sequence_path": "1227453.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227453.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227453.protein.info.v11.5.txt",
		        "node_list_path": "1227453.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1227453.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirosomaRigui(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma rigui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaRigui", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "564064.protein.sequences.v11.5.fa",
		        "enrichment_path": "564064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "564064.protein.info.v11.5.txt",
		        "node_list_path": "564064.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4113(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_41_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4113", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802702.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802702.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802702.protein.info.v11.5.txt",
		        "node_list_path": "1802702.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoccidioidesPosadasiiStrSilveiraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides posadasii str. Silveira Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesPosadasiiStrSilveiraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "443226.clusters.info.v11.5.txt",
		        "cluster_tree_path": "443226.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "443226.clusters.proteins.v11.5.txt",
		        "sequence_path": "443226.protein.sequences.v11.5.fa",
		        "enrichment_path": "443226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443226.protein.info.v11.5.txt",
		        "node_list_path": "443226.cluster.nodes.v11.5.txt",
		        "edge_list_path": "443226.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSp719(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. 71-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSp719", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1895934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895934.protein.info.v11.5.txt",
		        "node_list_path": "1895934.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrovirgaMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microvirga massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrovirgaMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033741.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033741.protein.info.v11.5.txt",
		        "node_list_path": "1033741.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChlamydiaAvium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia avium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlamydiaAvium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1229831.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229831.protein.info.v11.5.txt",
		        "node_list_path": "1229831.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterSpRoot604(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root604 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterSpRoot604", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736568.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736568.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736568.protein.info.v11.5.txt",
		        "node_list_path": "1736568.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodohalobacterHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodohalobacter halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodohalobacterHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1812810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1812810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1812810.protein.info.v11.5.txt",
		        "node_list_path": "1812810.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusSpKgw1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus sp. KGW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusSpKgw1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1793726.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1793726.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1793726.clusters.proteins.v11.5.txt",
		        "sequence_path": "1793726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1793726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1793726.protein.info.v11.5.txt",
		        "node_list_path": "1793726.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1793726.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusSuisEa183292(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis EA183292 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusSuisEa183292", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321372.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321372.protein.info.v11.5.txt",
		        "node_list_path": "1321372.protein.complete.v11.5.txt"
		    }
		]
    )()

def PyrenochaetaSpDs3say3aCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrenochaeta sp. DS3sAY3a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrenochaetaSpDs3say3aCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "765867.clusters.info.v11.5.txt",
		        "cluster_tree_path": "765867.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "765867.clusters.proteins.v11.5.txt",
		        "sequence_path": "765867.protein.sequences.v11.5.fa",
		        "enrichment_path": "765867.protein.enrichment.terms.v11.5.txt",
		        "info_path": "765867.protein.info.v11.5.txt",
		        "node_list_path": "765867.cluster.nodes.v11.5.txt",
		        "edge_list_path": "765867.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MeiothermusCerbereusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus cerbereus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MeiothermusCerbereusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122221.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122221.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122221.protein.info.v11.5.txt",
		        "node_list_path": "1122221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClohesyomycesAquaticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clohesyomyces aquaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClohesyomycesAquaticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231657.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231657.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231657.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231657.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231657.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231657.protein.info.v11.5.txt",
		        "node_list_path": "1231657.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231657.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichodermaArundinaceum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma arundinaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichodermaArundinaceum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "490622.protein.sequences.v11.5.fa",
		        "enrichment_path": "490622.protein.enrichment.terms.v11.5.txt",
		        "info_path": "490622.protein.info.v11.5.txt",
		        "node_list_path": "490622.protein.complete.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSpL294(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. L294 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSpL294", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1643920.protein.sequences.v11.5.fa",
		        "enrichment_path": "1643920.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1643920.protein.info.v11.5.txt",
		        "node_list_path": "1643920.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumOrchidophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum orchidophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumOrchidophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1209926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1209926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1209926.protein.info.v11.5.txt",
		        "node_list_path": "1209926.protein.complete.v11.5.txt"
		    }
		]
    )()

def VerrucomicrobiaBacteriumGwf25119Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium GWF2_51_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VerrucomicrobiaBacteriumGwf25119Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802431.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802431.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802431.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802431.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802431.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802431.protein.info.v11.5.txt",
		        "node_list_path": "1802431.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802431.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSp12Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSp12Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1163671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1163671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1163671.clusters.proteins.v11.5.txt",
		        "sequence_path": "1163671.protein.sequences.v11.5.fa",
		        "enrichment_path": "1163671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1163671.protein.info.v11.5.txt",
		        "node_list_path": "1163671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1163671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcanobacteriumUrinimassilienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcanobacterium urinimassiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcanobacteriumUrinimassilienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871014.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871014.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871014.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871014.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871014.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871014.protein.info.v11.5.txt",
		        "node_list_path": "1871014.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871014.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CampylobacterShowaeCsunswcd(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter showae CSUNSWCD graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterShowaeCsunswcd", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1244083.protein.sequences.v11.5.fa",
		        "enrichment_path": "1244083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1244083.protein.info.v11.5.txt",
		        "node_list_path": "1244083.protein.complete.v11.5.txt"
		    }
		]
    )()

def EubacteriumNodatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium nodatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumNodatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1161902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1161902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1161902.protein.info.v11.5.txt",
		        "node_list_path": "1161902.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaWheatBlueCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma wheat blue Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaWheatBlueCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321961.clusters.info.v11.0.txt",
		        "cluster_tree_path": "321961.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "321961.clusters.proteins.v11.0.txt",
		        "sequence_path": "321961.protein.sequences.v11.0.fa",
		        "enrichment_path": "321961.protein.enrichment.terms.v11.0.txt",
		        "info_path": "321961.protein.info.v11.0.txt",
		        "node_list_path": "321961.cluster.nodes.v11.0.txt",
		        "edge_list_path": "321961.protein.cluster.v11.0.txt"
		    }
		]
    )()

def CaedibacterSp3749Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caedibacter sp. 37-49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaedibacterSp3749Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895735.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895735.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895735.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895735.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895735.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895735.protein.info.v11.5.txt",
		        "node_list_path": "1895735.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895735.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalopigerXanaduensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halopiger xanaduensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalopigerXanaduensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "797210.protein.sequences.v11.5.fa",
		        "enrichment_path": "797210.protein.enrichment.terms.v11.5.txt",
		        "info_path": "797210.protein.info.v11.5.txt",
		        "node_list_path": "797210.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusAlveiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Paenibacillus alvei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusAlveiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117108.clusters.info.v11.0.txt",
		        "cluster_tree_path": "1117108.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "1117108.clusters.proteins.v11.0.txt",
		        "sequence_path": "1117108.protein.sequences.v11.0.fa",
		        "enrichment_path": "1117108.protein.enrichment.terms.v11.0.txt",
		        "info_path": "1117108.protein.info.v11.0.txt",
		        "node_list_path": "1117108.cluster.nodes.v11.0.txt",
		        "edge_list_path": "1117108.protein.cluster.v11.0.txt"
		    }
		]
    )()

def AcinetobacterTowneriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter towneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterTowneriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "202956.clusters.info.v11.5.txt",
		        "cluster_tree_path": "202956.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "202956.clusters.proteins.v11.5.txt",
		        "sequence_path": "202956.protein.sequences.v11.5.fa",
		        "enrichment_path": "202956.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202956.protein.info.v11.5.txt",
		        "node_list_path": "202956.cluster.nodes.v11.5.txt",
		        "edge_list_path": "202956.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpX15166b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. X15-166B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpX15166b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1897620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1897620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1897620.protein.info.v11.5.txt",
		        "node_list_path": "1897620.protein.complete.v11.5.txt"
		    }
		]
    )()

def TetrasphaeraElongata(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera elongata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TetrasphaeraElongata", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1193181.protein.sequences.v11.5.fa",
		        "enrichment_path": "1193181.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1193181.protein.info.v11.5.txt",
		        "node_list_path": "1193181.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaimiriBoliviensisBoliviensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saimiri boliviensis boliviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaimiriBoliviensisBoliviensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "39432.clusters.info.v11.5.txt",
		        "cluster_tree_path": "39432.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "39432.clusters.proteins.v11.5.txt",
		        "sequence_path": "39432.protein.sequences.v11.5.fa",
		        "enrichment_path": "39432.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39432.protein.info.v11.5.txt",
		        "node_list_path": "39432.cluster.nodes.v11.5.txt",
		        "edge_list_path": "39432.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MegasphaeraPaucivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera paucivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraPaucivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349095.clusters.proteins.v11.5.txt",
		        "sequence_path": "349095.protein.sequences.v11.5.fa",
		        "enrichment_path": "349095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349095.protein.info.v11.5.txt",
		        "node_list_path": "349095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlaciibacterSuperstes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glaciibacter superstes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlaciibacterSuperstes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121924.protein.info.v11.5.txt",
		        "node_list_path": "1121924.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlammeovirgaceaeBacteriumBbd199112Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flammeovirgaceae bacterium BBD 1991-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlammeovirgaceaeBacteriumBbd199112Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852619.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852619.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852619.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852619.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852619.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852619.protein.info.v11.5.txt",
		        "node_list_path": "1852619.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852619.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryptococcusAmylolentusCbs6039Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus amylolentus CBS 6039 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptococcusAmylolentusCbs6039Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1295533.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1295533.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1295533.clusters.proteins.v11.5.txt",
		        "sequence_path": "1295533.protein.sequences.v11.5.fa",
		        "enrichment_path": "1295533.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1295533.protein.info.v11.5.txt",
		        "node_list_path": "1295533.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1295533.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalobacillusAidingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus aidingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusAidingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "240303.protein.sequences.v11.5.fa",
		        "enrichment_path": "240303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240303.protein.info.v11.5.txt",
		        "node_list_path": "240303.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsplowo202Full4511cCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_02_FULL_45_11c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo202Full4511cCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802128.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802128.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802128.protein.info.v11.5.txt",
		        "node_list_path": "1802128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DefluviitaleaPhaphyphila(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Defluviitalea phaphyphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DefluviitaleaPhaphyphila", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1473580.protein.sequences.v11.5.fa",
		        "enrichment_path": "1473580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1473580.protein.info.v11.5.txt",
		        "node_list_path": "1473580.protein.complete.v11.5.txt"
		    }
		]
    )()

def KutzneriaAlbida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kutzneria albida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KutzneriaAlbida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449976.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449976.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449976.protein.info.v11.5.txt",
		        "node_list_path": "1449976.protein.complete.v11.5.txt"
		    }
		]
    )()

def SclerodermaCitrinumFougA(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Scleroderma citrinum Foug A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SclerodermaCitrinumFougA", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1036808.protein.sequences.v11.5.fa",
		        "enrichment_path": "1036808.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1036808.protein.info.v11.5.txt",
		        "node_list_path": "1036808.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelobacterSpSfb93Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter sp. SFB93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelobacterSpSfb93Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1842532.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1842532.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1842532.clusters.proteins.v11.5.txt",
		        "sequence_path": "1842532.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842532.protein.info.v11.5.txt",
		        "node_list_path": "1842532.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1842532.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfitibacterAlkalitoleransDsm16504Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfitibacter alkalitolerans DSM 16504 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitibacterAlkalitoleransDsm16504Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304884.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304884.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304884.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304884.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304884.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304884.protein.info.v11.5.txt",
		        "node_list_path": "1304884.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304884.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DeinococcusSwuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus swuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DeinococcusSwuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1182571.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182571.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182571.protein.info.v11.5.txt",
		        "node_list_path": "1182571.protein.complete.v11.5.txt"
		    }
		]
    )()

def DethiosulfovibrioSalsuginisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dethiosulfovibrio salsuginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DethiosulfovibrioSalsuginisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "561720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "561720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "561720.clusters.proteins.v11.5.txt",
		        "sequence_path": "561720.protein.sequences.v11.5.fa",
		        "enrichment_path": "561720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "561720.protein.info.v11.5.txt",
		        "node_list_path": "561720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "561720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldithrixSpRbg13449Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldithrix sp. RBG_13_44_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldithrixSpRbg13449Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797576.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797576.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797576.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797576.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797576.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797576.protein.info.v11.5.txt",
		        "node_list_path": "1797576.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797576.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DietziaMarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dietzia maris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DietziaMarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "37915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "37915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "37915.clusters.proteins.v11.5.txt",
		        "sequence_path": "37915.protein.sequences.v11.5.fa",
		        "enrichment_path": "37915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "37915.protein.info.v11.5.txt",
		        "node_list_path": "37915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "37915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpEs333(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ES3-33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpEs333", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1628833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1628833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1628833.protein.info.v11.5.txt",
		        "node_list_path": "1628833.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpYr485Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR485 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpYr485Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500294.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500294.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500294.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500294.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500294.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500294.protein.info.v11.5.txt",
		        "node_list_path": "1500294.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500294.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronococcusJeotgaliDsm18795(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronococcus jeotgali DSM 18795 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronococcusJeotgaliDsm18795", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227498.protein.info.v11.5.txt",
		        "node_list_path": "1227498.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrospiraeBacteriumGwa24611(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWA2_46_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrospiraeBacteriumGwa24611", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801691.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801691.protein.info.v11.5.txt",
		        "node_list_path": "1801691.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesAcidiscabies(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces acidiscabies graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesAcidiscabies", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1116232.protein.sequences.v11.5.fa",
		        "enrichment_path": "1116232.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1116232.protein.info.v11.5.txt",
		        "node_list_path": "1116232.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasAlienaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas aliena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasAlienaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "247523.clusters.info.v11.5.txt",
		        "cluster_tree_path": "247523.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "247523.clusters.proteins.v11.5.txt",
		        "sequence_path": "247523.protein.sequences.v11.5.fa",
		        "enrichment_path": "247523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "247523.protein.info.v11.5.txt",
		        "node_list_path": "247523.cluster.nodes.v11.5.txt",
		        "edge_list_path": "247523.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MaribacterForsetiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter forsetii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaribacterForsetiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392498.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392498.protein.info.v11.5.txt",
		        "node_list_path": "1392498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusPolymyxaM1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusPolymyxaM1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1052684.protein.sequences.v11.5.fa",
		        "enrichment_path": "1052684.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1052684.protein.info.v11.5.txt",
		        "node_list_path": "1052684.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpRoot268Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root268 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpRoot268Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736506.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736506.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736506.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736506.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736506.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736506.protein.info.v11.5.txt",
		        "node_list_path": "1736506.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736506.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusTermitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus termitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusTermitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "332950.protein.sequences.v11.5.fa",
		        "enrichment_path": "332950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332950.protein.info.v11.5.txt",
		        "node_list_path": "332950.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaldicellulosiruptorMorganii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor morganii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicellulosiruptorMorganii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1387555.protein.sequences.v11.5.fa",
		        "enrichment_path": "1387555.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1387555.protein.info.v11.5.txt",
		        "node_list_path": "1387555.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegamonasFuniformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megamonas funiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegamonasFuniformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "437897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "437897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "437897.clusters.proteins.v11.5.txt",
		        "sequence_path": "437897.protein.sequences.v11.5.fa",
		        "enrichment_path": "437897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "437897.protein.info.v11.5.txt",
		        "node_list_path": "437897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "437897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpRd62Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. RD6.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpRd62Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "260936.clusters.info.v11.5.txt",
		        "cluster_tree_path": "260936.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "260936.clusters.proteins.v11.5.txt",
		        "sequence_path": "260936.protein.sequences.v11.5.fa",
		        "enrichment_path": "260936.protein.enrichment.terms.v11.5.txt",
		        "info_path": "260936.protein.info.v11.5.txt",
		        "node_list_path": "260936.cluster.nodes.v11.5.txt",
		        "edge_list_path": "260936.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMidichloriaMitochondriiIricva(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Midichloria mitochondrii IricVA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMidichloriaMitochondriiIricva", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "696127.protein.sequences.v11.5.fa",
		        "enrichment_path": "696127.protein.enrichment.terms.v11.5.txt",
		        "info_path": "696127.protein.info.v11.5.txt",
		        "node_list_path": "696127.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfonauticusSp384375(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonauticus sp. 38_4375 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonauticusSp384375", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1635258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635258.protein.info.v11.5.txt",
		        "node_list_path": "1635258.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumTepidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tepidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumTepidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1962263.protein.sequences.v11.5.fa",
		        "enrichment_path": "1962263.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1962263.protein.info.v11.5.txt",
		        "node_list_path": "1962263.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusGastranaerophilusPhascolarctosicola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilus phascolarctosicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGastranaerophilusPhascolarctosicola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906137.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906137.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906137.protein.info.v11.5.txt",
		        "node_list_path": "1906137.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterAdhaerensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter adhaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterAdhaerensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "225937.clusters.info.v11.5.txt",
		        "cluster_tree_path": "225937.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "225937.clusters.proteins.v11.5.txt",
		        "sequence_path": "225937.protein.sequences.v11.5.fa",
		        "enrichment_path": "225937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "225937.protein.info.v11.5.txt",
		        "node_list_path": "225937.cluster.nodes.v11.5.txt",
		        "edge_list_path": "225937.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmanitaMuscariaKoideBx008Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amanita muscaria Koide BX008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmanitaMuscariaKoideBx008Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "946122.clusters.info.v11.5.txt",
		        "cluster_tree_path": "946122.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "946122.clusters.proteins.v11.5.txt",
		        "sequence_path": "946122.protein.sequences.v11.5.fa",
		        "enrichment_path": "946122.protein.enrichment.terms.v11.5.txt",
		        "info_path": "946122.protein.info.v11.5.txt",
		        "node_list_path": "946122.cluster.nodes.v11.5.txt",
		        "edge_list_path": "946122.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasKuykendalliiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas kuykendallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasKuykendalliiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1007099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1007099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1007099.clusters.proteins.v11.5.txt",
		        "sequence_path": "1007099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1007099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1007099.protein.info.v11.5.txt",
		        "node_list_path": "1007099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1007099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaSpH567(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella sp. H567 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaSpH567", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1697043.protein.sequences.v11.5.fa",
		        "enrichment_path": "1697043.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1697043.protein.info.v11.5.txt",
		        "node_list_path": "1697043.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirosomaAerolatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma aerolatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaAerolatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211326.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211326.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211326.protein.info.v11.5.txt",
		        "node_list_path": "1211326.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseovariusMucosusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius mucosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusMucosusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1288298.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1288298.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1288298.clusters.proteins.v11.5.txt",
		        "sequence_path": "1288298.protein.sequences.v11.5.fa",
		        "enrichment_path": "1288298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1288298.protein.info.v11.5.txt",
		        "node_list_path": "1288298.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1288298.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRyanbacteriaBacteriumRifcsplowo201Full4826(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_01_FULL_48_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo201Full4826", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802126.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802126.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802126.protein.info.v11.5.txt",
		        "node_list_path": "1802126.protein.complete.v11.5.txt"
		    }
		]
    )()

def JonquetellaAnthropiDsm22815Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jonquetella anthropi DSM22815 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JonquetellaAnthropiDsm22815Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "885272.clusters.info.v11.5.txt",
		        "cluster_tree_path": "885272.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "885272.clusters.proteins.v11.5.txt",
		        "sequence_path": "885272.protein.sequences.v11.5.fa",
		        "enrichment_path": "885272.protein.enrichment.terms.v11.5.txt",
		        "info_path": "885272.protein.info.v11.5.txt",
		        "node_list_path": "885272.cluster.nodes.v11.5.txt",
		        "edge_list_path": "885272.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CapsellaGrandifloraCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Capsella grandiflora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CapsellaGrandifloraCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "264402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "264402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "264402.clusters.proteins.v11.5.txt",
		        "sequence_path": "264402.protein.sequences.v11.5.fa",
		        "enrichment_path": "264402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "264402.protein.info.v11.5.txt",
		        "node_list_path": "264402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "264402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasRuminantiumAb3002Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium AB3002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasRuminantiumAb3002Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1392502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1392502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1392502.clusters.proteins.v11.5.txt",
		        "sequence_path": "1392502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1392502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1392502.protein.info.v11.5.txt",
		        "node_list_path": "1392502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1392502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinomonasPosidonicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas posidonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinomonasPosidonicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "491952.clusters.info.v11.5.txt",
		        "cluster_tree_path": "491952.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "491952.clusters.proteins.v11.5.txt",
		        "sequence_path": "491952.protein.sequences.v11.5.fa",
		        "enrichment_path": "491952.protein.enrichment.terms.v11.5.txt",
		        "info_path": "491952.protein.info.v11.5.txt",
		        "node_list_path": "491952.cluster.nodes.v11.5.txt",
		        "edge_list_path": "491952.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterPsychrophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter psychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterPsychrophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1826909.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1826909.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1826909.clusters.proteins.v11.5.txt",
		        "sequence_path": "1826909.protein.sequences.v11.5.fa",
		        "enrichment_path": "1826909.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1826909.protein.info.v11.5.txt",
		        "node_list_path": "1826909.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1826909.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlycomycesArizonensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glycomyces arizonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlycomycesArizonensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121926.protein.info.v11.5.txt",
		        "node_list_path": "1121926.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterAlimentariusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter alimentarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterAlimentariusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "261164.clusters.info.v11.5.txt",
		        "cluster_tree_path": "261164.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "261164.clusters.proteins.v11.5.txt",
		        "sequence_path": "261164.protein.sequences.v11.5.fa",
		        "enrichment_path": "261164.protein.enrichment.terms.v11.5.txt",
		        "info_path": "261164.protein.info.v11.5.txt",
		        "node_list_path": "261164.cluster.nodes.v11.5.txt",
		        "edge_list_path": "261164.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YamadazymaTenuisAtcc10573(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yamadazyma tenuis ATCC 10573 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YamadazymaTenuisAtcc10573", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "590646.protein.sequences.v11.5.fa",
		        "enrichment_path": "590646.protein.enrichment.terms.v11.5.txt",
		        "info_path": "590646.protein.info.v11.5.txt",
		        "node_list_path": "590646.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylacidiphilumFumariolicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylacidiphilum fumariolicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylacidiphilumFumariolicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1156937.protein.sequences.v11.5.fa",
		        "enrichment_path": "1156937.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1156937.protein.info.v11.5.txt",
		        "node_list_path": "1156937.protein.complete.v11.5.txt"
		    }
		]
    )()

def CurtobacteriumSpBh211Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium sp. BH-2-1-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CurtobacteriumSpBh211Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1905847.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1905847.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1905847.clusters.proteins.v11.5.txt",
		        "sequence_path": "1905847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1905847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1905847.protein.info.v11.5.txt",
		        "node_list_path": "1905847.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1905847.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidateDivisionWwe3BacteriumRifoxyb1Full4324Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYB1_FULL_43_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyb1Full4324Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802640.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802640.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802640.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802640.protein.info.v11.5.txt",
		        "node_list_path": "1802640.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802640.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgibacterAquaticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algibacter aquaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgibacterAquaticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1849968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1849968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1849968.clusters.proteins.v11.5.txt",
		        "sequence_path": "1849968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1849968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1849968.protein.info.v11.5.txt",
		        "node_list_path": "1849968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1849968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnabasTestudineusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anabas testudineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnabasTestudineusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "64144.clusters.info.v11.5.txt",
		        "cluster_tree_path": "64144.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "64144.clusters.proteins.v11.5.txt",
		        "sequence_path": "64144.protein.sequences.v11.5.fa",
		        "enrichment_path": "64144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64144.protein.info.v11.5.txt",
		        "node_list_path": "64144.cluster.nodes.v11.5.txt",
		        "edge_list_path": "64144.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusBasilensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus basilensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusBasilensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "68895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "68895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "68895.clusters.proteins.v11.5.txt",
		        "sequence_path": "68895.protein.sequences.v11.5.fa",
		        "enrichment_path": "68895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "68895.protein.info.v11.5.txt",
		        "node_list_path": "68895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "68895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacillusSubterraneusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusSubterraneusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "129338.clusters.info.v11.5.txt",
		        "cluster_tree_path": "129338.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "129338.clusters.proteins.v11.5.txt",
		        "sequence_path": "129338.protein.sequences.v11.5.fa",
		        "enrichment_path": "129338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "129338.protein.info.v11.5.txt",
		        "node_list_path": "129338.cluster.nodes.v11.5.txt",
		        "edge_list_path": "129338.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusCoprophilusNbrc100603Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus coprophilus NBRC 100603 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusCoprophilusNbrc100603Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219011.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219011.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219011.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219011.protein.info.v11.5.txt",
		        "node_list_path": "1219011.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219011.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterobacterSpKpr6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter sp. kpr-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterobacterSpKpr6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1761782.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1761782.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1761782.clusters.proteins.v11.5.txt",
		        "sequence_path": "1761782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1761782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1761782.protein.info.v11.5.txt",
		        "node_list_path": "1761782.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1761782.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirulinaSubsalsa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirulina subsalsa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirulinaSubsalsa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1173029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173029.protein.info.v11.5.txt",
		        "node_list_path": "1173029.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliaAfzelii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia afzelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliaAfzelii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "390236.protein.sequences.v11.5.fa",
		        "enrichment_path": "390236.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390236.protein.info.v11.5.txt",
		        "node_list_path": "390236.protein.complete.v11.5.txt"
		    }
		]
    )()

def MegasphaeraMicronuciformisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera micronuciformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraMicronuciformisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "706434.clusters.info.v11.5.txt",
		        "cluster_tree_path": "706434.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "706434.clusters.proteins.v11.5.txt",
		        "sequence_path": "706434.protein.sequences.v11.5.fa",
		        "enrichment_path": "706434.protein.enrichment.terms.v11.5.txt",
		        "info_path": "706434.protein.info.v11.5.txt",
		        "node_list_path": "706434.cluster.nodes.v11.5.txt",
		        "edge_list_path": "706434.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpLeaf336Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf336 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpLeaf336Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736341.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736341.protein.info.v11.5.txt",
		        "node_list_path": "1736341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChlorobiumTepidum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium tepidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChlorobiumTepidum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "194439.protein.sequences.v11.5.fa",
		        "enrichment_path": "194439.protein.enrichment.terms.v11.5.txt",
		        "info_path": "194439.protein.info.v11.5.txt",
		        "node_list_path": "194439.protein.complete.v11.5.txt"
		    }
		]
    )()

def BorreliellaGarinii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Borreliella garinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BorreliellaGarinii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "29519.protein.sequences.v11.5.fa",
		        "enrichment_path": "29519.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29519.protein.info.v11.5.txt",
		        "node_list_path": "29519.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterCalcoaceticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter calcoaceticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterCalcoaceticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "871585.protein.sequences.v11.5.fa",
		        "enrichment_path": "871585.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871585.protein.info.v11.5.txt",
		        "node_list_path": "871585.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterUpsaliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter upsaliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterUpsaliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "306264.clusters.info.v11.5.txt",
		        "cluster_tree_path": "306264.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "306264.clusters.proteins.v11.5.txt",
		        "sequence_path": "306264.protein.sequences.v11.5.fa",
		        "enrichment_path": "306264.protein.enrichment.terms.v11.5.txt",
		        "info_path": "306264.protein.info.v11.5.txt",
		        "node_list_path": "306264.cluster.nodes.v11.5.txt",
		        "edge_list_path": "306264.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ButyrivibrioSpLc3010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. LC3010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ButyrivibrioSpLc3010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1280680.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1280680.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1280680.clusters.proteins.v11.5.txt",
		        "sequence_path": "1280680.protein.sequences.v11.5.fa",
		        "enrichment_path": "1280680.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1280680.protein.info.v11.5.txt",
		        "node_list_path": "1280680.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1280680.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusCampbellbacteriaBacteriumRifcsplowo201Full3415(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFCSPLOWO2_01_FULL_34_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifcsplowo201Full3415", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797579.protein.info.v11.5.txt",
		        "node_list_path": "1797579.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudobutyrivibrioSpAcv2(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. ACV-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudobutyrivibrioSpAcv2", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1520801.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520801.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520801.protein.info.v11.5.txt",
		        "node_list_path": "1520801.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobacteriumAutotrophicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterium autotrophicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteriumAutotrophicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "177437.protein.sequences.v11.5.fa",
		        "enrichment_path": "177437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "177437.protein.info.v11.5.txt",
		        "node_list_path": "177437.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3734Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_37_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3734Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798277.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798277.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798277.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798277.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798277.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798277.protein.info.v11.5.txt",
		        "node_list_path": "1798277.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798277.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpCf097(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF097 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpCf097", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1500301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500301.protein.info.v11.5.txt",
		        "node_list_path": "1500301.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharothrixSpCb00851Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharothrix sp. CB00851 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharothrixSpCb00851Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1835005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1835005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1835005.clusters.proteins.v11.5.txt",
		        "sequence_path": "1835005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1835005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1835005.protein.info.v11.5.txt",
		        "node_list_path": "1835005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1835005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OceanobacillusIheyensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus iheyensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacillusIheyensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "221109.protein.sequences.v11.5.fa",
		        "enrichment_path": "221109.protein.enrichment.terms.v11.5.txt",
		        "info_path": "221109.protein.info.v11.5.txt",
		        "node_list_path": "221109.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpiroplasmaCitri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma citri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpiroplasmaCitri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2133.protein.sequences.v11.5.fa",
		        "enrichment_path": "2133.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2133.protein.info.v11.5.txt",
		        "node_list_path": "2133.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaloterrigenaMahii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloterrigena mahii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloterrigenaMahii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1416969.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416969.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416969.protein.info.v11.5.txt",
		        "node_list_path": "1416969.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCollierbacteriaBacteriumGw2011Gwb24422Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_44_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24422Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618387.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618387.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618387.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618387.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618387.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618387.protein.info.v11.5.txt",
		        "node_list_path": "1618387.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618387.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpHr7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. HR7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpHr7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1509403.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1509403.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1509403.clusters.proteins.v11.5.txt",
		        "sequence_path": "1509403.protein.sequences.v11.5.fa",
		        "enrichment_path": "1509403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1509403.protein.info.v11.5.txt",
		        "node_list_path": "1509403.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1509403.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LeucoagaricusSpSymcCosCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucoagaricus sp. SymC.cos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeucoagaricusSpSymcCosCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1714833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1714833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1714833.clusters.proteins.v11.5.txt",
		        "sequence_path": "1714833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714833.protein.info.v11.5.txt",
		        "node_list_path": "1714833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1714833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WinogradskyellaPsychrotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Winogradskyella psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WinogradskyellaPsychrotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "641526.protein.sequences.v11.5.fa",
		        "enrichment_path": "641526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641526.protein.info.v11.5.txt",
		        "node_list_path": "641526.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCrudilactisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium crudilactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCrudilactisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1652495.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1652495.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1652495.clusters.proteins.v11.5.txt",
		        "sequence_path": "1652495.protein.sequences.v11.5.fa",
		        "enrichment_path": "1652495.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1652495.protein.info.v11.5.txt",
		        "node_list_path": "1652495.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1652495.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumRutilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium rutilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumRutilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "370526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "370526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "370526.clusters.proteins.v11.5.txt",
		        "sequence_path": "370526.protein.sequences.v11.5.fa",
		        "enrichment_path": "370526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "370526.protein.info.v11.5.txt",
		        "node_list_path": "370526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "370526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumMortiferum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium mortiferum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumMortiferum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "469616.protein.sequences.v11.5.fa",
		        "enrichment_path": "469616.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469616.protein.info.v11.5.txt",
		        "node_list_path": "469616.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumJaponicumIn8p8Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum in8p8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumJaponicumIn8p8Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1304878.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1304878.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1304878.clusters.proteins.v11.5.txt",
		        "sequence_path": "1304878.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304878.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304878.protein.info.v11.5.txt",
		        "node_list_path": "1304878.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1304878.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MurdochiellaVaginalisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Murdochiella vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MurdochiellaVaginalisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852373.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852373.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852373.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852373.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852373.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852373.protein.info.v11.5.txt",
		        "node_list_path": "1852373.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852373.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermusFiliformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermus filiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermusFiliformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "276.protein.sequences.v11.5.fa",
		        "enrichment_path": "276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "276.protein.info.v11.5.txt",
		        "node_list_path": "276.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThiovulumSpEsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiovulum sp. ES Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiovulumSpEsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1177931.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1177931.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1177931.clusters.proteins.v11.5.txt",
		        "sequence_path": "1177931.protein.sequences.v11.5.fa",
		        "enrichment_path": "1177931.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1177931.protein.info.v11.5.txt",
		        "node_list_path": "1177931.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1177931.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrocoleusVaginatusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microcoleus vaginatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrocoleusVaginatusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "756067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "756067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "756067.clusters.proteins.v11.5.txt",
		        "sequence_path": "756067.protein.sequences.v11.5.fa",
		        "enrichment_path": "756067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "756067.protein.info.v11.5.txt",
		        "node_list_path": "756067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "756067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DomibacillusIocasaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Domibacillus iocasae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DomibacillusIocasaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1714016.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1714016.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1714016.clusters.proteins.v11.5.txt",
		        "sequence_path": "1714016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714016.protein.info.v11.5.txt",
		        "node_list_path": "1714016.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1714016.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasFloridensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas floridensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasFloridensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1958950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1958950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1958950.clusters.proteins.v11.5.txt",
		        "sequence_path": "1958950.protein.sequences.v11.5.fa",
		        "enrichment_path": "1958950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1958950.protein.info.v11.5.txt",
		        "node_list_path": "1958950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1958950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NosemaBombycisCq1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nosema bombycis CQ1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NosemaBombycisCq1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "578461.clusters.info.v11.5.txt",
		        "cluster_tree_path": "578461.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "578461.clusters.proteins.v11.5.txt",
		        "sequence_path": "578461.protein.sequences.v11.5.fa",
		        "enrichment_path": "578461.protein.enrichment.terms.v11.5.txt",
		        "info_path": "578461.protein.info.v11.5.txt",
		        "node_list_path": "578461.cluster.nodes.v11.5.txt",
		        "edge_list_path": "578461.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FerrithrixThermotoleransDsm19514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrithrix thermotolerans DSM 19514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FerrithrixThermotoleransDsm19514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121881.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121881.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121881.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121881.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121881.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121881.protein.info.v11.5.txt",
		        "node_list_path": "1121881.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121881.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumFournieriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium fournierii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumFournieriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1852390.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1852390.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1852390.clusters.proteins.v11.5.txt",
		        "sequence_path": "1852390.protein.sequences.v11.5.fa",
		        "enrichment_path": "1852390.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1852390.protein.info.v11.5.txt",
		        "node_list_path": "1852390.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1852390.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElusimicrobiaBacteriumGwa26618Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_66_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElusimicrobiaBacteriumGwa26618Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797926.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797926.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797926.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797926.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797926.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797926.protein.info.v11.5.txt",
		        "node_list_path": "1797926.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797926.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KluyveraCryocrescensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kluyvera cryocrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KluyveraCryocrescensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "580.clusters.info.v11.5.txt",
		        "cluster_tree_path": "580.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "580.clusters.proteins.v11.5.txt",
		        "sequence_path": "580.protein.sequences.v11.5.fa",
		        "enrichment_path": "580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "580.protein.info.v11.5.txt",
		        "node_list_path": "580.cluster.nodes.v11.5.txt",
		        "edge_list_path": "580.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermoproteusSpJchs4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermoproteus sp. JCHS_4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermoproteusSpJchs4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1714258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1714258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1714258.protein.info.v11.5.txt",
		        "node_list_path": "1714258.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChaetomiumGlobosumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium globosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChaetomiumGlobosumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "38033.clusters.info.v11.5.txt",
		        "cluster_tree_path": "38033.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "38033.clusters.proteins.v11.5.txt",
		        "sequence_path": "38033.protein.sequences.v11.5.fa",
		        "enrichment_path": "38033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "38033.protein.info.v11.5.txt",
		        "node_list_path": "38033.cluster.nodes.v11.5.txt",
		        "edge_list_path": "38033.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnaerolineaeBacteriumUtcfx1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium UTCFX1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerolineaeBacteriumUtcfx1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1961100.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1961100.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1961100.clusters.proteins.v11.5.txt",
		        "sequence_path": "1961100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961100.protein.info.v11.5.txt",
		        "node_list_path": "1961100.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1961100.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiomonasArsenitoxydans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas arsenitoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiomonasArsenitoxydans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426114.protein.sequences.v11.5.fa",
		        "enrichment_path": "426114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426114.protein.info.v11.5.txt",
		        "node_list_path": "426114.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanktothrixTepidaPcc9214Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planktothrix tepida PCC 9214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanktothrixTepidaPcc9214Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "671072.clusters.info.v11.5.txt",
		        "cluster_tree_path": "671072.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "671072.clusters.proteins.v11.5.txt",
		        "sequence_path": "671072.protein.sequences.v11.5.fa",
		        "enrichment_path": "671072.protein.enrichment.terms.v11.5.txt",
		        "info_path": "671072.protein.info.v11.5.txt",
		        "node_list_path": "671072.cluster.nodes.v11.5.txt",
		        "edge_list_path": "671072.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShinellaSpHzn7Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shinella sp. HZN7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShinellaSpHzn7Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "879274.clusters.info.v11.5.txt",
		        "cluster_tree_path": "879274.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "879274.clusters.proteins.v11.5.txt",
		        "sequence_path": "879274.protein.sequences.v11.5.fa",
		        "enrichment_path": "879274.protein.enrichment.terms.v11.5.txt",
		        "info_path": "879274.protein.info.v11.5.txt",
		        "node_list_path": "879274.cluster.nodes.v11.5.txt",
		        "edge_list_path": "879274.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporosarcinaSpZbg7a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina sp. ZBG7A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaSpZbg7a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1582223.protein.sequences.v11.5.fa",
		        "enrichment_path": "1582223.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1582223.protein.info.v11.5.txt",
		        "node_list_path": "1582223.protein.complete.v11.5.txt"
		    }
		]
    )()

def BordetellaGenomosp9Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaGenomosp9Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1416803.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1416803.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1416803.clusters.proteins.v11.5.txt",
		        "sequence_path": "1416803.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416803.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416803.protein.info.v11.5.txt",
		        "node_list_path": "1416803.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1416803.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpAntimn1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. AntiMn-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpAntimn1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1720344.protein.sequences.v11.5.fa",
		        "enrichment_path": "1720344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1720344.protein.info.v11.5.txt",
		        "node_list_path": "1720344.protein.complete.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpScb245a518a17Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_518A17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpScb245a518a17Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1471501.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1471501.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1471501.clusters.proteins.v11.5.txt",
		        "sequence_path": "1471501.protein.sequences.v11.5.fa",
		        "enrichment_path": "1471501.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1471501.protein.info.v11.5.txt",
		        "node_list_path": "1471501.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1471501.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumEtliMimosaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli mimosae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumEtliMimosaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1432050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1432050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1432050.clusters.proteins.v11.5.txt",
		        "sequence_path": "1432050.protein.sequences.v11.5.fa",
		        "enrichment_path": "1432050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1432050.protein.info.v11.5.txt",
		        "node_list_path": "1432050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1432050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArcobacterAnaerophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter anaerophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArcobacterAnaerophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "877500.protein.sequences.v11.5.fa",
		        "enrichment_path": "877500.protein.enrichment.terms.v11.5.txt",
		        "info_path": "877500.protein.info.v11.5.txt",
		        "node_list_path": "877500.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastochlorisViridis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastochloris viridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastochlorisViridis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1079.protein.sequences.v11.5.fa",
		        "enrichment_path": "1079.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1079.protein.info.v11.5.txt",
		        "node_list_path": "1079.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumParaoxydansDh1bCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium paraoxydans DH1b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumParaoxydansDh1bCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1416752.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1416752.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1416752.clusters.proteins.v11.5.txt",
		        "sequence_path": "1416752.protein.sequences.v11.5.fa",
		        "enrichment_path": "1416752.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1416752.protein.info.v11.5.txt",
		        "node_list_path": "1416752.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1416752.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MyroidesInjenensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Myroides injenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyroidesInjenensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1008457.protein.sequences.v11.5.fa",
		        "enrichment_path": "1008457.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1008457.protein.info.v11.5.txt",
		        "node_list_path": "1008457.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisGranuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis granuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisGranuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "267128.clusters.info.v11.5.txt",
		        "cluster_tree_path": "267128.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "267128.clusters.proteins.v11.5.txt",
		        "sequence_path": "267128.protein.sequences.v11.5.fa",
		        "enrichment_path": "267128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267128.protein.info.v11.5.txt",
		        "node_list_path": "267128.cluster.nodes.v11.5.txt",
		        "edge_list_path": "267128.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PlanctomycetesBacteriumRifcsphigho202Full4012Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPHIGHO2_02_FULL_40_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanctomycetesBacteriumRifcsphigho202Full4012Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801974.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801974.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801974.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801974.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801974.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801974.protein.info.v11.5.txt",
		        "node_list_path": "1801974.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801974.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpCh12iCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CH12i Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpCh12iCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1479651.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1479651.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1479651.clusters.proteins.v11.5.txt",
		        "sequence_path": "1479651.protein.sequences.v11.5.fa",
		        "enrichment_path": "1479651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1479651.protein.info.v11.5.txt",
		        "node_list_path": "1479651.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1479651.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaceaeBacteriumFsla50281(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeriaceae bacterium FSLA50281 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaceaeBacteriumFsla50281", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1552123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1552123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1552123.protein.info.v11.5.txt",
		        "node_list_path": "1552123.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumLablabi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium lablabi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumLablabi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "722472.protein.sequences.v11.5.fa",
		        "enrichment_path": "722472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "722472.protein.info.v11.5.txt",
		        "node_list_path": "722472.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryobacteriumPsychrotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cryobacterium psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryobacteriumPsychrotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "386301.protein.sequences.v11.5.fa",
		        "enrichment_path": "386301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "386301.protein.info.v11.5.txt",
		        "node_list_path": "386301.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenophagaSpRac07Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. RAC07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenophagaSpRac07Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1842537.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1842537.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1842537.clusters.proteins.v11.5.txt",
		        "sequence_path": "1842537.protein.sequences.v11.5.fa",
		        "enrichment_path": "1842537.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1842537.protein.info.v11.5.txt",
		        "node_list_path": "1842537.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1842537.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinosynnemaMirum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinosynnema mirum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinosynnemaMirum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "446462.protein.sequences.v11.5.fa",
		        "enrichment_path": "446462.protein.enrichment.terms.v11.5.txt",
		        "info_path": "446462.protein.info.v11.5.txt",
		        "node_list_path": "446462.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobotryumSilenesDioicaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbotryum silenes-dioicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobotryumSilenesDioicaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "796604.clusters.info.v11.5.txt",
		        "cluster_tree_path": "796604.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "796604.clusters.proteins.v11.5.txt",
		        "sequence_path": "796604.protein.sequences.v11.5.fa",
		        "enrichment_path": "796604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796604.protein.info.v11.5.txt",
		        "node_list_path": "796604.cluster.nodes.v11.5.txt",
		        "edge_list_path": "796604.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasMaltophiliaS028Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia S028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasMaltophiliaS028Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210005.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210005.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210005.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210005.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210005.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210005.protein.info.v11.5.txt",
		        "node_list_path": "1210005.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210005.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumMangenotii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium mangenotii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumMangenotii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408823.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408823.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408823.protein.info.v11.5.txt",
		        "node_list_path": "1408823.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpNdb2meth1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. NDB2Meth1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpNdb2meth1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1892847.protein.sequences.v11.5.fa",
		        "enrichment_path": "1892847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1892847.protein.info.v11.5.txt",
		        "node_list_path": "1892847.protein.complete.v11.5.txt"
		    }
		]
    )()

def FragariaVesca(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fragaria vesca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FragariaVesca", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "57918.protein.sequences.v11.5.fa",
		        "enrichment_path": "57918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "57918.protein.info.v11.5.txt",
		        "node_list_path": "57918.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalonotiusSpJ07hn4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halonotius sp. J07HN4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalonotiusSpJ07hn4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1070774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1070774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1070774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1070774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1070774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1070774.protein.info.v11.5.txt",
		        "node_list_path": "1070774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1070774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfocapsaSulfexigens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfocapsa sulfexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfocapsaSulfexigens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1167006.protein.sequences.v11.5.fa",
		        "enrichment_path": "1167006.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1167006.protein.info.v11.5.txt",
		        "node_list_path": "1167006.protein.complete.v11.5.txt"
		    }
		]
    )()

def PedobacterBorealis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter borealis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterBorealis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1454007.protein.sequences.v11.5.fa",
		        "enrichment_path": "1454007.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1454007.protein.info.v11.5.txt",
		        "node_list_path": "1454007.protein.complete.v11.5.txt"
		    }
		]
    )()

def ApteryxOwenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Apteryx owenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ApteryxOwenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "8824.protein.sequences.v11.5.fa",
		        "enrichment_path": "8824.protein.enrichment.terms.v11.5.txt",
		        "info_path": "8824.protein.info.v11.5.txt",
		        "node_list_path": "8824.protein.complete.v11.5.txt"
		    }
		]
    )()

def Sar324ClusterBacteriumRedseaS27B3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return SAR324 cluster bacterium REDSEA-S27_B3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar324ClusterBacteriumRedseaS27B3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1811637.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1811637.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1811637.clusters.proteins.v11.5.txt",
		        "sequence_path": "1811637.protein.sequences.v11.5.fa",
		        "enrichment_path": "1811637.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1811637.protein.info.v11.5.txt",
		        "node_list_path": "1811637.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1811637.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisMethanolicaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis methanolica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisMethanolicaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1068978.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1068978.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1068978.clusters.proteins.v11.5.txt",
		        "sequence_path": "1068978.protein.sequences.v11.5.fa",
		        "enrichment_path": "1068978.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1068978.protein.info.v11.5.txt",
		        "node_list_path": "1068978.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1068978.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VanderwaltozymaPolyspora(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vanderwaltozyma polyspora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VanderwaltozymaPolyspora", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36033.protein.sequences.v11.5.fa",
		        "enrichment_path": "36033.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36033.protein.info.v11.5.txt",
		        "node_list_path": "36033.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp22311(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2231.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp22311", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855347.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855347.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855347.protein.info.v11.5.txt",
		        "node_list_path": "1855347.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpTca20(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. TCA20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpTca20", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1499968.protein.sequences.v11.5.fa",
		        "enrichment_path": "1499968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1499968.protein.info.v11.5.txt",
		        "node_list_path": "1499968.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200251057Sch5723018(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-51057_SCH5723018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200251057Sch5723018", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1834094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834094.protein.info.v11.5.txt",
		        "node_list_path": "1834094.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacterialesBacteriumBrhC54(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriales bacterium BRH_c54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacterialesBacteriumBrhC54", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629721.protein.info.v11.5.txt",
		        "node_list_path": "1629721.protein.complete.v11.5.txt"
		    }
		]
    )()

def SelenihalanaerobacterShriftiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenihalanaerobacter shriftii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenihalanaerobacterShriftiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "142842.clusters.info.v11.5.txt",
		        "cluster_tree_path": "142842.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "142842.clusters.proteins.v11.5.txt",
		        "sequence_path": "142842.protein.sequences.v11.5.fa",
		        "enrichment_path": "142842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "142842.protein.info.v11.5.txt",
		        "node_list_path": "142842.cluster.nodes.v11.5.txt",
		        "edge_list_path": "142842.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CladophialophoraPsammophilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora psammophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CladophialophoraPsammophilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1182553.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1182553.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1182553.clusters.proteins.v11.5.txt",
		        "sequence_path": "1182553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1182553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1182553.protein.info.v11.5.txt",
		        "node_list_path": "1182553.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1182553.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LimnobacterSpMed105Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnobacter sp. MED105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LimnobacterSpMed105Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "391597.clusters.info.v11.5.txt",
		        "cluster_tree_path": "391597.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "391597.clusters.proteins.v11.5.txt",
		        "sequence_path": "391597.protein.sequences.v11.5.fa",
		        "enrichment_path": "391597.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391597.protein.info.v11.5.txt",
		        "node_list_path": "391597.cluster.nodes.v11.5.txt",
		        "edge_list_path": "391597.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeptuniibacterMarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neptuniibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeptuniibacterMarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1806670.protein.sequences.v11.5.fa",
		        "enrichment_path": "1806670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1806670.protein.info.v11.5.txt",
		        "node_list_path": "1806670.protein.complete.v11.5.txt"
		    }
		]
    )()

def CoccidioidesImmitisRsCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis RS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoccidioidesImmitisRsCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "246410.clusters.info.v11.5.txt",
		        "cluster_tree_path": "246410.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "246410.clusters.proteins.v11.5.txt",
		        "sequence_path": "246410.protein.sequences.v11.5.fa",
		        "enrichment_path": "246410.protein.enrichment.terms.v11.5.txt",
		        "info_path": "246410.protein.info.v11.5.txt",
		        "node_list_path": "246410.cluster.nodes.v11.5.txt",
		        "edge_list_path": "246410.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NonlabensSpHel13355Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens sp. Hel1_33_55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonlabensSpHel13355Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336802.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336802.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336802.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336802.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336802.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336802.protein.info.v11.5.txt",
		        "node_list_path": "1336802.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336802.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesNeuiiDsm8576(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces neuii DSM8576 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesNeuiiDsm8576", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1120945.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120945.protein.info.v11.5.txt",
		        "node_list_path": "1120945.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSolaniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus solani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSolaniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1637975.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1637975.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1637975.clusters.proteins.v11.5.txt",
		        "sequence_path": "1637975.protein.sequences.v11.5.fa",
		        "enrichment_path": "1637975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1637975.protein.info.v11.5.txt",
		        "node_list_path": "1637975.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1637975.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpCcge1001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpCcge1001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "640510.protein.sequences.v11.5.fa",
		        "enrichment_path": "640510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "640510.protein.info.v11.5.txt",
		        "node_list_path": "640510.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZunongwangiaProfunda(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zunongwangia profunda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZunongwangiaProfunda", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "655815.protein.sequences.v11.5.fa",
		        "enrichment_path": "655815.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655815.protein.info.v11.5.txt",
		        "node_list_path": "655815.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpJha19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. JHA19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpJha19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577588.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577588.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577588.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577588.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577588.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577588.protein.info.v11.5.txt",
		        "node_list_path": "1577588.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577588.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwp2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWP2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwp2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1896216.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1896216.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1896216.clusters.proteins.v11.5.txt",
		        "sequence_path": "1896216.protein.sequences.v11.5.fa",
		        "enrichment_path": "1896216.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1896216.protein.info.v11.5.txt",
		        "node_list_path": "1896216.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1896216.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioFluvialis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio fluvialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioFluvialis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "676.protein.sequences.v11.5.fa",
		        "enrichment_path": "676.protein.enrichment.terms.v11.5.txt",
		        "info_path": "676.protein.info.v11.5.txt",
		        "node_list_path": "676.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5313(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_53_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5313", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802389.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802389.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802389.protein.info.v11.5.txt",
		        "node_list_path": "1802389.protein.complete.v11.5.txt"
		    }
		]
    )()

def TardibacterChloracetimidivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tardibacter chloracetimidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TardibacterChloracetimidivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1921510.protein.sequences.v11.5.fa",
		        "enrichment_path": "1921510.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1921510.protein.info.v11.5.txt",
		        "node_list_path": "1921510.protein.complete.v11.5.txt"
		    }
		]
    )()

def KitasatosporaArboriphilaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora arboriphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KitasatosporaArboriphilaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "258052.clusters.info.v11.5.txt",
		        "cluster_tree_path": "258052.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "258052.clusters.proteins.v11.5.txt",
		        "sequence_path": "258052.protein.sequences.v11.5.fa",
		        "enrichment_path": "258052.protein.enrichment.terms.v11.5.txt",
		        "info_path": "258052.protein.info.v11.5.txt",
		        "node_list_path": "258052.cluster.nodes.v11.5.txt",
		        "edge_list_path": "258052.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaBacteriumRifcsplowo202Full4516(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO2_02_FULL_45_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo202Full4516", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1801831.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801831.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801831.protein.info.v11.5.txt",
		        "node_list_path": "1801831.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusGelatiniCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus gelatini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGelatiniCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121091.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121091.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121091.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121091.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121091.protein.info.v11.5.txt",
		        "node_list_path": "1121091.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121091.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrlwc3742(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3742 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrlwc3742", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1463934.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463934.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463934.protein.info.v11.5.txt",
		        "node_list_path": "1463934.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterUreolyticusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter ureolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterUreolyticusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "827.clusters.info.v11.5.txt",
		        "cluster_tree_path": "827.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "827.clusters.proteins.v11.5.txt",
		        "sequence_path": "827.protein.sequences.v11.5.fa",
		        "enrichment_path": "827.protein.enrichment.terms.v11.5.txt",
		        "info_path": "827.protein.info.v11.5.txt",
		        "node_list_path": "827.cluster.nodes.v11.5.txt",
		        "edge_list_path": "827.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BordetellaPetriiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella petrii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BordetellaPetriiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "94624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "94624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "94624.clusters.proteins.v11.5.txt",
		        "sequence_path": "94624.protein.sequences.v11.5.fa",
		        "enrichment_path": "94624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94624.protein.info.v11.5.txt",
		        "node_list_path": "94624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "94624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyphellophoraEuropaeaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyphellophora europaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyphellophoraEuropaeaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "293227.clusters.info.v11.5.txt",
		        "cluster_tree_path": "293227.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "293227.clusters.proteins.v11.5.txt",
		        "sequence_path": "293227.protein.sequences.v11.5.fa",
		        "enrichment_path": "293227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "293227.protein.info.v11.5.txt",
		        "node_list_path": "293227.cluster.nodes.v11.5.txt",
		        "edge_list_path": "293227.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusGinsengihumiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ginsengihumi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusGinsengihumiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122919.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122919.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122919.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122919.protein.info.v11.5.txt",
		        "node_list_path": "1122919.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122919.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasResinovoransNbrc106553Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas resinovorans NBRC106553 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasResinovoransNbrc106553Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1245471.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1245471.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1245471.clusters.proteins.v11.5.txt",
		        "sequence_path": "1245471.protein.sequences.v11.5.fa",
		        "enrichment_path": "1245471.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1245471.protein.info.v11.5.txt",
		        "node_list_path": "1245471.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1245471.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasAgariciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas agarici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasAgariciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "46677.clusters.info.v11.5.txt",
		        "cluster_tree_path": "46677.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "46677.clusters.proteins.v11.5.txt",
		        "sequence_path": "46677.protein.sequences.v11.5.fa",
		        "enrichment_path": "46677.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46677.protein.info.v11.5.txt",
		        "node_list_path": "46677.cluster.nodes.v11.5.txt",
		        "edge_list_path": "46677.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FrancisellaUliginis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella uliginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaUliginis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "573570.protein.sequences.v11.5.fa",
		        "enrichment_path": "573570.protein.enrichment.terms.v11.5.txt",
		        "info_path": "573570.protein.info.v11.5.txt",
		        "node_list_path": "573570.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaAobensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia aobensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaAobensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1206720.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1206720.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1206720.clusters.proteins.v11.5.txt",
		        "sequence_path": "1206720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1206720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1206720.protein.info.v11.5.txt",
		        "node_list_path": "1206720.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1206720.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacteriumGwa27023Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium GWA2_70_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacteriumGwa27023Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802095.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802095.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802095.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802095.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802095.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802095.protein.info.v11.5.txt",
		        "node_list_path": "1802095.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802095.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AnophelesColuzzii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anopheles coluzzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnophelesColuzzii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1518534.protein.sequences.v11.5.fa",
		        "enrichment_path": "1518534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1518534.protein.info.v11.5.txt",
		        "node_list_path": "1518534.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusRokubacteriaBacterium13220cm27011(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_2_20CM_2_70_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusRokubacteriaBacterium13220cm27011", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805370.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805370.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805370.protein.info.v11.5.txt",
		        "node_list_path": "1805370.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolyporusArculariusHhb13444(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polyporus arcularius HHB13444 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolyporusArculariusHhb13444", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1314778.protein.sequences.v11.5.fa",
		        "enrichment_path": "1314778.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1314778.protein.info.v11.5.txt",
		        "node_list_path": "1314778.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrobacterSpS77Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sp. S77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterSpS77Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1080067.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1080067.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1080067.clusters.proteins.v11.5.txt",
		        "sequence_path": "1080067.protein.sequences.v11.5.fa",
		        "enrichment_path": "1080067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1080067.protein.info.v11.5.txt",
		        "node_list_path": "1080067.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1080067.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EubacteriumRuminantiumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium ruminantium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EubacteriumRuminantiumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42322.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42322.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42322.clusters.proteins.v11.5.txt",
		        "sequence_path": "42322.protein.sequences.v11.5.fa",
		        "enrichment_path": "42322.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42322.protein.info.v11.5.txt",
		        "node_list_path": "42322.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42322.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidesDorei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides dorei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesDorei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "357276.protein.sequences.v11.5.fa",
		        "enrichment_path": "357276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357276.protein.info.v11.5.txt",
		        "node_list_path": "357276.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterPiechaudii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter piechaudii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterPiechaudii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1945521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945521.protein.info.v11.5.txt",
		        "node_list_path": "1945521.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusMassilionigeriensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus massilionigeriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusMassilionigeriensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805475.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805475.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805475.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805475.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805475.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805475.protein.info.v11.5.txt",
		        "node_list_path": "1805475.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805475.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpP6wCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. P6W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpP6wCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1609758.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1609758.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1609758.clusters.proteins.v11.5.txt",
		        "sequence_path": "1609758.protein.sequences.v11.5.fa",
		        "enrichment_path": "1609758.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1609758.protein.info.v11.5.txt",
		        "node_list_path": "1609758.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1609758.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusHarbinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus harbinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusHarbinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1122147.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1122147.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1122147.clusters.proteins.v11.5.txt",
		        "sequence_path": "1122147.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122147.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122147.protein.info.v11.5.txt",
		        "node_list_path": "1122147.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1122147.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrincolaNitratireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrincola nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrincolaNitratireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229521.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229521.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229521.protein.info.v11.5.txt",
		        "node_list_path": "1229521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidimicrobiiaBacteriumBacl6Mag120910Bin40(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium BACL6 MAG-120910-bin40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidimicrobiiaBacteriumBacl6Mag120910Bin40", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1655586.protein.sequences.v11.5.fa",
		        "enrichment_path": "1655586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1655586.protein.info.v11.5.txt",
		        "node_list_path": "1655586.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlteromonasStellipolarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas stellipolaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlteromonasStellipolarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "233316.clusters.info.v11.5.txt",
		        "cluster_tree_path": "233316.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "233316.clusters.proteins.v11.5.txt",
		        "sequence_path": "233316.protein.sequences.v11.5.fa",
		        "enrichment_path": "233316.protein.enrichment.terms.v11.5.txt",
		        "info_path": "233316.protein.info.v11.5.txt",
		        "node_list_path": "233316.cluster.nodes.v11.5.txt",
		        "edge_list_path": "233316.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlycineMax(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Glycine max graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlycineMax", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3847.protein.sequences.v11.5.fa",
		        "enrichment_path": "3847.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3847.protein.info.v11.5.txt",
		        "node_list_path": "3847.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacterSpJcm18900(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. JCM18900 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacterSpJcm18900", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1298608.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298608.protein.info.v11.5.txt",
		        "node_list_path": "1298608.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "226505.clusters.info.v11.5.txt",
		        "cluster_tree_path": "226505.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "226505.clusters.proteins.v11.5.txt",
		        "sequence_path": "226505.protein.sequences.v11.5.fa",
		        "enrichment_path": "226505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "226505.protein.info.v11.5.txt",
		        "node_list_path": "226505.cluster.nodes.v11.5.txt",
		        "edge_list_path": "226505.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AmmonifexDegensii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ammonifex degensii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmmonifexDegensii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "429009.protein.sequences.v11.5.fa",
		        "enrichment_path": "429009.protein.enrichment.terms.v11.5.txt",
		        "info_path": "429009.protein.info.v11.5.txt",
		        "node_list_path": "429009.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanibaculumNanhaienseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanibaculum nanhaiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanibaculumNanhaienseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1909734.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1909734.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1909734.clusters.proteins.v11.5.txt",
		        "sequence_path": "1909734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1909734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1909734.protein.info.v11.5.txt",
		        "node_list_path": "1909734.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1909734.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OstreococcusTauri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ostreococcus tauri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OstreococcusTauri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "70448.protein.sequences.v11.5.fa",
		        "enrichment_path": "70448.protein.enrichment.terms.v11.5.txt",
		        "info_path": "70448.protein.info.v11.5.txt",
		        "node_list_path": "70448.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingopyxisFribergensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis fribergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisFribergensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1515612.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1515612.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1515612.clusters.proteins.v11.5.txt",
		        "sequence_path": "1515612.protein.sequences.v11.5.fa",
		        "enrichment_path": "1515612.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1515612.protein.info.v11.5.txt",
		        "node_list_path": "1515612.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1515612.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NitrincolaLacisaponensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nitrincola lacisaponensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrincolaLacisaponensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "267850.protein.sequences.v11.5.fa",
		        "enrichment_path": "267850.protein.enrichment.terms.v11.5.txt",
		        "info_path": "267850.protein.info.v11.5.txt",
		        "node_list_path": "267850.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterTerraeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterTerraeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1788.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1788.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1788.clusters.proteins.v11.5.txt",
		        "sequence_path": "1788.protein.sequences.v11.5.fa",
		        "enrichment_path": "1788.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1788.protein.info.v11.5.txt",
		        "node_list_path": "1788.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1788.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiellaGrylliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsiella grylli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiellaGrylliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "59196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "59196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "59196.clusters.proteins.v11.5.txt",
		        "sequence_path": "59196.protein.sequences.v11.5.fa",
		        "enrichment_path": "59196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59196.protein.info.v11.5.txt",
		        "node_list_path": "59196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "59196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumSpCf284Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. CF284 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumSpCf284Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500281.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500281.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500281.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500281.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500281.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500281.protein.info.v11.5.txt",
		        "node_list_path": "1500281.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500281.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoclavibacterSoli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoclavibacter soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoclavibacterSoli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123013.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123013.protein.info.v11.5.txt",
		        "node_list_path": "1123013.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfotomaculumCarboxydivoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum carboxydivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfotomaculumCarboxydivoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "868595.clusters.info.v11.5.txt",
		        "cluster_tree_path": "868595.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "868595.clusters.proteins.v11.5.txt",
		        "sequence_path": "868595.protein.sequences.v11.5.fa",
		        "enrichment_path": "868595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "868595.protein.info.v11.5.txt",
		        "node_list_path": "868595.cluster.nodes.v11.5.txt",
		        "edge_list_path": "868595.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AspergillusWelwitschiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus welwitschiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AspergillusWelwitschiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1341132.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1341132.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1341132.clusters.proteins.v11.5.txt",
		        "sequence_path": "1341132.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341132.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341132.protein.info.v11.5.txt",
		        "node_list_path": "1341132.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1341132.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfonatronumThioautotrophicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronum thioautotrophicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfonatronumThioautotrophicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "617001.clusters.info.v11.5.txt",
		        "cluster_tree_path": "617001.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "617001.clusters.proteins.v11.5.txt",
		        "sequence_path": "617001.protein.sequences.v11.5.fa",
		        "enrichment_path": "617001.protein.enrichment.terms.v11.5.txt",
		        "info_path": "617001.protein.info.v11.5.txt",
		        "node_list_path": "617001.cluster.nodes.v11.5.txt",
		        "edge_list_path": "617001.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HelicobacterSpMit016451Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT016451 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HelicobacterSpMit016451Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "425400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "425400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "425400.clusters.proteins.v11.5.txt",
		        "sequence_path": "425400.protein.sequences.v11.5.fa",
		        "enrichment_path": "425400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "425400.protein.info.v11.5.txt",
		        "node_list_path": "425400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "425400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TalaromycesAmestolkiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces amestolkiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TalaromycesAmestolkiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1196081.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1196081.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1196081.clusters.proteins.v11.5.txt",
		        "sequence_path": "1196081.protein.sequences.v11.5.fa",
		        "enrichment_path": "1196081.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1196081.protein.info.v11.5.txt",
		        "node_list_path": "1196081.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1196081.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LentibacillusJuripiscariusJcm12147Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus juripiscarius JCM 12147 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LentibacillusJuripiscariusJcm12147Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1293599.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1293599.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1293599.clusters.proteins.v11.5.txt",
		        "sequence_path": "1293599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1293599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1293599.protein.info.v11.5.txt",
		        "node_list_path": "1293599.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1293599.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlastococcusSpDsm44205(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 44205 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusSpDsm44205", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1550233.protein.sequences.v11.5.fa",
		        "enrichment_path": "1550233.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1550233.protein.info.v11.5.txt",
		        "node_list_path": "1550233.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full379Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_37_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full379Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797724.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797724.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797724.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797724.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797724.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797724.protein.info.v11.5.txt",
		        "node_list_path": "1797724.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797724.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxSpJs42(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax sp. JS42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxSpJs42", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "232721.protein.sequences.v11.5.fa",
		        "enrichment_path": "232721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "232721.protein.info.v11.5.txt",
		        "node_list_path": "232721.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumSpNk2b42Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. NK2B42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumSpNk2b42Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "689781.clusters.info.v11.5.txt",
		        "cluster_tree_path": "689781.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "689781.clusters.proteins.v11.5.txt",
		        "sequence_path": "689781.protein.sequences.v11.5.fa",
		        "enrichment_path": "689781.protein.enrichment.terms.v11.5.txt",
		        "info_path": "689781.protein.info.v11.5.txt",
		        "node_list_path": "689781.cluster.nodes.v11.5.txt",
		        "edge_list_path": "689781.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwb14014Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWB1_40_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwb14014Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618865.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618865.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618865.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618865.protein.info.v11.5.txt",
		        "node_list_path": "1618865.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618865.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudovibrioHongkongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioHongkongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1647556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1647556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1647556.protein.info.v11.5.txt",
		        "node_list_path": "1647556.protein.complete.v11.5.txt"
		    }
		]
    )()

def RuminiclostridiumThermocellum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ruminiclostridium thermocellum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminiclostridiumThermocellum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "203119.protein.sequences.v11.5.fa",
		        "enrichment_path": "203119.protein.enrichment.terms.v11.5.txt",
		        "info_path": "203119.protein.info.v11.5.txt",
		        "node_list_path": "203119.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycolicibacterEngbaekiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter engbaekii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterEngbaekiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "188915.clusters.info.v11.5.txt",
		        "cluster_tree_path": "188915.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "188915.clusters.proteins.v11.5.txt",
		        "sequence_path": "188915.protein.sequences.v11.5.fa",
		        "enrichment_path": "188915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "188915.protein.info.v11.5.txt",
		        "node_list_path": "188915.cluster.nodes.v11.5.txt",
		        "edge_list_path": "188915.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumSpBv3ac4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. BV3Ac4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumSpBv3ac4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111121.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111121.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111121.protein.info.v11.5.txt",
		        "node_list_path": "1111121.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronococcusAmylolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronococcus amylolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronococcusAmylolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1227497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1227497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1227497.protein.info.v11.5.txt",
		        "node_list_path": "1227497.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytoplasmaSpVc33(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytoplasma sp. Vc33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytoplasmaSpVc33", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1836886.protein.sequences.v11.5.fa",
		        "enrichment_path": "1836886.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1836886.protein.info.v11.5.txt",
		        "node_list_path": "1836886.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsplowo212Full4712Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPLOWO2_12_FULL_47_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsplowo212Full4712Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817849.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817849.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817849.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817849.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817849.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817849.protein.info.v11.5.txt",
		        "node_list_path": "1817849.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817849.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VeillonellaAtypicaKon(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella atypica KON graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VeillonellaAtypicaKon", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1128111.protein.sequences.v11.5.fa",
		        "enrichment_path": "1128111.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1128111.protein.info.v11.5.txt",
		        "node_list_path": "1128111.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioNatriegens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio natriegens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioNatriegens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "691.protein.sequences.v11.5.fa",
		        "enrichment_path": "691.protein.enrichment.terms.v11.5.txt",
		        "info_path": "691.protein.info.v11.5.txt",
		        "node_list_path": "691.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumGelidilacusDsm15343(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium gelidilacus DSM 15343 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumGelidilacusDsm15343", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121891.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121891.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121891.protein.info.v11.5.txt",
		        "node_list_path": "1121891.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaBenthicaKt99(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella benthica KT99 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaBenthicaKt99", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "314608.protein.sequences.v11.5.fa",
		        "enrichment_path": "314608.protein.enrichment.terms.v11.5.txt",
		        "info_path": "314608.protein.info.v11.5.txt",
		        "node_list_path": "314608.protein.complete.v11.5.txt"
		    }
		]
    )()

def HerbidosporaMongoliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Herbidospora mongoliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HerbidosporaMongoliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "688067.protein.sequences.v11.5.fa",
		        "enrichment_path": "688067.protein.enrichment.terms.v11.5.txt",
		        "info_path": "688067.protein.info.v11.5.txt",
		        "node_list_path": "688067.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaBarkeri3(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri 3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaBarkeri3", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434107.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434107.protein.info.v11.5.txt",
		        "node_list_path": "1434107.protein.complete.v11.5.txt"
		    }
		]
    )()

def AcinetobacterTjernbergiae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter tjernbergiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterTjernbergiae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "202955.protein.sequences.v11.5.fa",
		        "enrichment_path": "202955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "202955.protein.info.v11.5.txt",
		        "node_list_path": "202955.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumMarinumDsm44953Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium marinum DSM 44953 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumMarinumDsm44953Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1224162.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1224162.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1224162.clusters.proteins.v11.5.txt",
		        "sequence_path": "1224162.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224162.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224162.protein.info.v11.5.txt",
		        "node_list_path": "1224162.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1224162.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobotrysOligosporaAtcc24927(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobotrys oligospora ATCC 24927 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobotrysOligosporaAtcc24927", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "756982.protein.sequences.v11.5.fa",
		        "enrichment_path": "756982.protein.enrichment.terms.v11.5.txt",
		        "info_path": "756982.protein.info.v11.5.txt",
		        "node_list_path": "756982.protein.complete.v11.5.txt"
		    }
		]
    )()

def XenorhabdusDoucetiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus doucetiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XenorhabdusDoucetiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "351671.clusters.info.v11.5.txt",
		        "cluster_tree_path": "351671.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "351671.clusters.proteins.v11.5.txt",
		        "sequence_path": "351671.protein.sequences.v11.5.fa",
		        "enrichment_path": "351671.protein.enrichment.terms.v11.5.txt",
		        "info_path": "351671.protein.info.v11.5.txt",
		        "node_list_path": "351671.cluster.nodes.v11.5.txt",
		        "edge_list_path": "351671.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WolbachiaSpOocCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Ooc Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaSpOocCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "100901.clusters.info.v11.0.txt",
		        "cluster_tree_path": "100901.clusters.tree.v11.0.txt",
		        "cluster_to_proteins_path": "100901.clusters.proteins.v11.0.txt",
		        "sequence_path": "100901.protein.sequences.v11.0.fa",
		        "enrichment_path": "100901.protein.enrichment.terms.v11.0.txt",
		        "info_path": "100901.protein.info.v11.0.txt",
		        "node_list_path": "100901.cluster.nodes.v11.0.txt",
		        "edge_list_path": "100901.protein.cluster.v11.0.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium3146faaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 3146FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium3146faaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "665950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "665950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "665950.clusters.proteins.v11.5.txt",
		        "sequence_path": "665950.protein.sequences.v11.5.fa",
		        "enrichment_path": "665950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665950.protein.info.v11.5.txt",
		        "node_list_path": "665950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "665950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ShewanellaJaponica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaJaponica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93973.protein.sequences.v11.5.fa",
		        "enrichment_path": "93973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93973.protein.info.v11.5.txt",
		        "node_list_path": "93973.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasMucidolens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mucidolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMucidolens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "46679.protein.sequences.v11.5.fa",
		        "enrichment_path": "46679.protein.enrichment.terms.v11.5.txt",
		        "info_path": "46679.protein.info.v11.5.txt",
		        "node_list_path": "46679.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumSpGxf4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. GXF4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumSpGxf4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1096546.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1096546.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1096546.clusters.proteins.v11.5.txt",
		        "sequence_path": "1096546.protein.sequences.v11.5.fa",
		        "enrichment_path": "1096546.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1096546.protein.info.v11.5.txt",
		        "node_list_path": "1096546.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1096546.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanobrevibacterCuticularis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter cuticularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanobrevibacterCuticularis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "47311.protein.sequences.v11.5.fa",
		        "enrichment_path": "47311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "47311.protein.info.v11.5.txt",
		        "node_list_path": "47311.protein.complete.v11.5.txt"
		    }
		]
    )()

def WohlfahrtiimonasLarvae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas larvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WohlfahrtiimonasLarvae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1157986.protein.sequences.v11.5.fa",
		        "enrichment_path": "1157986.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1157986.protein.info.v11.5.txt",
		        "node_list_path": "1157986.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMoranbacteriaBacteriumCg2304514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium CG2_30_45_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMoranbacteriaBacteriumCg2304514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805255.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805255.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805255.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805255.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805255.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805255.protein.info.v11.5.txt",
		        "node_list_path": "1805255.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805255.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HaloferaxMediterranei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Haloferax mediterranei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaloferaxMediterranei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "523841.protein.sequences.v11.5.fa",
		        "enrichment_path": "523841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523841.protein.info.v11.5.txt",
		        "node_list_path": "523841.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParabacteroidesSpMarseilleP3160(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides sp. Marseille-P3160 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParabacteroidesSpMarseilleP3160", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1917887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1917887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1917887.protein.info.v11.5.txt",
		        "node_list_path": "1917887.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumT5Br10B2g0(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium T5-Br10_B2g0 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumT5Br10B2g0", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729469.protein.info.v11.5.txt",
		        "node_list_path": "1729469.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusMalodoratus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus malodoratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusMalodoratus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1158601.protein.sequences.v11.5.fa",
		        "enrichment_path": "1158601.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1158601.protein.info.v11.5.txt",
		        "node_list_path": "1158601.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasMoraviensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas moraviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasMoraviensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1395516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1395516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1395516.protein.info.v11.5.txt",
		        "node_list_path": "1395516.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelagibacterUbiqueHtcc8051(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC8051 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelagibacterUbiqueHtcc8051", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "466038.protein.sequences.v11.5.fa",
		        "enrichment_path": "466038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "466038.protein.info.v11.5.txt",
		        "node_list_path": "466038.protein.complete.v11.5.txt"
		    }
		]
    )()

def TheileriaEquiStrainWa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Theileria equi strain WA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TheileriaEquiStrainWa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1537102.protein.sequences.v11.5.fa",
		        "enrichment_path": "1537102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1537102.protein.info.v11.5.txt",
		        "node_list_path": "1537102.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4624(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_46_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4624", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1817825.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817825.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817825.protein.info.v11.5.txt",
		        "node_list_path": "1817825.protein.complete.v11.5.txt"
		    }
		]
    )()

def EpulopisciumSpNuni2hMbin001(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nuni2H_MBin001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EpulopisciumSpNuni2hMbin001", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884656.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884656.protein.info.v11.5.txt",
		        "node_list_path": "1884656.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSediminisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSediminisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "904291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "904291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "904291.clusters.proteins.v11.5.txt",
		        "sequence_path": "904291.protein.sequences.v11.5.fa",
		        "enrichment_path": "904291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904291.protein.info.v11.5.txt",
		        "node_list_path": "904291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "904291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AtopobiumSpF0209Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. F0209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtopobiumSpF0209Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321773.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321773.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321773.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321773.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321773.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321773.protein.info.v11.5.txt",
		        "node_list_path": "1321773.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321773.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyrobacterSanguineusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter sanguineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyrobacterSanguineusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "198312.clusters.info.v11.5.txt",
		        "cluster_tree_path": "198312.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "198312.clusters.proteins.v11.5.txt",
		        "sequence_path": "198312.protein.sequences.v11.5.fa",
		        "enrichment_path": "198312.protein.enrichment.terms.v11.5.txt",
		        "info_path": "198312.protein.info.v11.5.txt",
		        "node_list_path": "198312.cluster.nodes.v11.5.txt",
		        "edge_list_path": "198312.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PostiaPlacentaMad698RSb12(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Postia placenta MAD-698-R-SB12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PostiaPlacentaMad698RSb12", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "670580.protein.sequences.v11.5.fa",
		        "enrichment_path": "670580.protein.enrichment.terms.v11.5.txt",
		        "info_path": "670580.protein.info.v11.5.txt",
		        "node_list_path": "670580.protein.complete.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumJicamaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium jicamae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumJicamaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "280332.clusters.info.v11.5.txt",
		        "cluster_tree_path": "280332.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "280332.clusters.proteins.v11.5.txt",
		        "sequence_path": "280332.protein.sequences.v11.5.fa",
		        "enrichment_path": "280332.protein.enrichment.terms.v11.5.txt",
		        "info_path": "280332.protein.info.v11.5.txt",
		        "node_list_path": "280332.cluster.nodes.v11.5.txt",
		        "edge_list_path": "280332.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IgnavibacteriaBacteriumRbg163414(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RBG_16_34_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IgnavibacteriaBacteriumRbg163414", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798433.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798433.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798433.protein.info.v11.5.txt",
		        "node_list_path": "1798433.protein.complete.v11.5.txt"
		    }
		]
    )()

def KocuriaRhizophilaDc2201Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Kocuria rhizophila DC2201 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KocuriaRhizophilaDc2201Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "378753.clusters.info.v11.5.txt",
		        "cluster_tree_path": "378753.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "378753.clusters.proteins.v11.5.txt",
		        "sequence_path": "378753.protein.sequences.v11.5.fa",
		        "enrichment_path": "378753.protein.enrichment.terms.v11.5.txt",
		        "info_path": "378753.protein.info.v11.5.txt",
		        "node_list_path": "378753.cluster.nodes.v11.5.txt",
		        "edge_list_path": "378753.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PanTroglodytes(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pan troglodytes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PanTroglodytes", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "9598.protein.sequences.v11.5.fa",
		        "enrichment_path": "9598.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9598.protein.info.v11.5.txt",
		        "node_list_path": "9598.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumLuteum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium luteum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumLuteum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "421531.protein.sequences.v11.5.fa",
		        "enrichment_path": "421531.protein.enrichment.terms.v11.5.txt",
		        "info_path": "421531.protein.info.v11.5.txt",
		        "node_list_path": "421531.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronorubrumSulfidifaciens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronorubrum sulfidifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronorubrumSulfidifaciens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1230460.protein.sequences.v11.5.fa",
		        "enrichment_path": "1230460.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1230460.protein.info.v11.5.txt",
		        "node_list_path": "1230460.protein.complete.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAmycolatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium amycolatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAmycolatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553204.protein.sequences.v11.5.fa",
		        "enrichment_path": "553204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553204.protein.info.v11.5.txt",
		        "node_list_path": "553204.protein.complete.v11.5.txt"
		    }
		]
    )()

def MaricaulisMarisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Maricaulis maris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MaricaulisMarisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "394221.clusters.info.v11.5.txt",
		        "cluster_tree_path": "394221.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "394221.clusters.proteins.v11.5.txt",
		        "sequence_path": "394221.protein.sequences.v11.5.fa",
		        "enrichment_path": "394221.protein.enrichment.terms.v11.5.txt",
		        "info_path": "394221.protein.info.v11.5.txt",
		        "node_list_path": "394221.cluster.nodes.v11.5.txt",
		        "edge_list_path": "394221.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaldicoprobacterOshimai(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caldicoprobacter oshimai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaldicoprobacterOshimai", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1304880.protein.sequences.v11.5.fa",
		        "enrichment_path": "1304880.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1304880.protein.info.v11.5.txt",
		        "node_list_path": "1304880.protein.complete.v11.5.txt"
		    }
		]
    )()

def DermacoccusSpPe3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dermacoccus sp. PE3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DermacoccusSpPe3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1641401.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1641401.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1641401.clusters.proteins.v11.5.txt",
		        "sequence_path": "1641401.protein.sequences.v11.5.fa",
		        "enrichment_path": "1641401.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1641401.protein.info.v11.5.txt",
		        "node_list_path": "1641401.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1641401.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusSenegalensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusSenegalensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1033744.protein.sequences.v11.5.fa",
		        "enrichment_path": "1033744.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1033744.protein.info.v11.5.txt",
		        "node_list_path": "1033744.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaBarkeriMs(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri MS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaBarkeriMs", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434108.protein.info.v11.5.txt",
		        "node_list_path": "1434108.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasMaltophiliaR5513(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia R5513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasMaltophiliaR5513", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391008.protein.sequences.v11.5.fa",
		        "enrichment_path": "391008.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391008.protein.info.v11.5.txt",
		        "node_list_path": "391008.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpDlviiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. DLVIII Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpDlviiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "641107.clusters.info.v11.5.txt",
		        "cluster_tree_path": "641107.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "641107.clusters.proteins.v11.5.txt",
		        "sequence_path": "641107.protein.sequences.v11.5.fa",
		        "enrichment_path": "641107.protein.enrichment.terms.v11.5.txt",
		        "info_path": "641107.protein.info.v11.5.txt",
		        "node_list_path": "641107.cluster.nodes.v11.5.txt",
		        "edge_list_path": "641107.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSpUnccl10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. UNCCL10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSpUnccl10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449058.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449058.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449058.protein.info.v11.5.txt",
		        "node_list_path": "1449058.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaPipientis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia pipientis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaPipientis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "955.protein.sequences.v11.5.fa",
		        "enrichment_path": "955.protein.enrichment.terms.v11.5.txt",
		        "info_path": "955.protein.info.v11.5.txt",
		        "node_list_path": "955.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumMarinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumMarinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1159016.protein.sequences.v11.5.fa",
		        "enrichment_path": "1159016.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1159016.protein.info.v11.5.txt",
		        "node_list_path": "1159016.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSelangorensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus selangorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSelangorensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "81857.protein.sequences.v11.5.fa",
		        "enrichment_path": "81857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "81857.protein.info.v11.5.txt",
		        "node_list_path": "81857.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaSpJs23(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. JS23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaSpJs23", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1770053.protein.sequences.v11.5.fa",
		        "enrichment_path": "1770053.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1770053.protein.info.v11.5.txt",
		        "node_list_path": "1770053.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrichophytonEquinum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton equinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichophytonEquinum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "63418.protein.sequences.v11.5.fa",
		        "enrichment_path": "63418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "63418.protein.info.v11.5.txt",
		        "node_list_path": "63418.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSp32oW(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 32O-W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSp32oW", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1695218.protein.sequences.v11.5.fa",
		        "enrichment_path": "1695218.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1695218.protein.info.v11.5.txt",
		        "node_list_path": "1695218.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemmatimonadetesBacteriumScn7022(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium SCN 70-22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonadetesBacteriumScn7022", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1660163.protein.sequences.v11.5.fa",
		        "enrichment_path": "1660163.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1660163.protein.info.v11.5.txt",
		        "node_list_path": "1660163.protein.complete.v11.5.txt"
		    }
		]
    )()

def GillisiaSpJm1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gillisia sp. JM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GillisiaSpJm1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1283286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1283286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1283286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1283286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1283286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1283286.protein.info.v11.5.txt",
		        "node_list_path": "1283286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1283286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumSpWsm1743(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM1743 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumSpWsm1743", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "318996.protein.sequences.v11.5.fa",
		        "enrichment_path": "318996.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318996.protein.info.v11.5.txt",
		        "node_list_path": "318996.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterCapsiciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter capsici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterCapsiciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "435897.clusters.info.v11.5.txt",
		        "cluster_tree_path": "435897.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "435897.clusters.proteins.v11.5.txt",
		        "sequence_path": "435897.protein.sequences.v11.5.fa",
		        "enrichment_path": "435897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "435897.protein.info.v11.5.txt",
		        "node_list_path": "435897.cluster.nodes.v11.5.txt",
		        "edge_list_path": "435897.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlr1721(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALR1721 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlr1721", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1269813.protein.sequences.v11.5.fa",
		        "enrichment_path": "1269813.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1269813.protein.info.v11.5.txt",
		        "node_list_path": "1269813.protein.complete.v11.5.txt"
		    }
		]
    )()

def CryptobacteriumCurtumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptobacterium curtum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryptobacteriumCurtumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469378.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469378.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469378.clusters.proteins.v11.5.txt",
		        "sequence_path": "469378.protein.sequences.v11.5.fa",
		        "enrichment_path": "469378.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469378.protein.info.v11.5.txt",
		        "node_list_path": "469378.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469378.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodohalobacterHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodohalobacter halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodohalobacterHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1812810.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1812810.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1812810.clusters.proteins.v11.5.txt",
		        "sequence_path": "1812810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1812810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1812810.protein.info.v11.5.txt",
		        "node_list_path": "1812810.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1812810.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TerribacillusAidingensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Terribacillus aidingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerribacillusAidingensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "586416.protein.sequences.v11.5.fa",
		        "enrichment_path": "586416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "586416.protein.info.v11.5.txt",
		        "node_list_path": "586416.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfitobacteriumDichloroeliminans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium dichloroeliminans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfitobacteriumDichloroeliminans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "871963.protein.sequences.v11.5.fa",
		        "enrichment_path": "871963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "871963.protein.info.v11.5.txt",
		        "node_list_path": "871963.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSyringaePvTagetisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae pv. tagetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSyringaePvTagetisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "129140.clusters.info.v11.5.txt",
		        "cluster_tree_path": "129140.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "129140.clusters.proteins.v11.5.txt",
		        "sequence_path": "129140.protein.sequences.v11.5.fa",
		        "enrichment_path": "129140.protein.enrichment.terms.v11.5.txt",
		        "info_path": "129140.protein.info.v11.5.txt",
		        "node_list_path": "129140.cluster.nodes.v11.5.txt",
		        "edge_list_path": "129140.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriaceaeBacteriumS85(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium S85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriaceaeBacteriumS85", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1042376.protein.sequences.v11.5.fa",
		        "enrichment_path": "1042376.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1042376.protein.info.v11.5.txt",
		        "node_list_path": "1042376.protein.complete.v11.5.txt"
		    }
		]
    )()

def CollinsellaStercorisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Collinsella stercoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CollinsellaStercorisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "445975.clusters.info.v11.5.txt",
		        "cluster_tree_path": "445975.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "445975.clusters.proteins.v11.5.txt",
		        "sequence_path": "445975.protein.sequences.v11.5.fa",
		        "enrichment_path": "445975.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445975.protein.info.v11.5.txt",
		        "node_list_path": "445975.cluster.nodes.v11.5.txt",
		        "edge_list_path": "445975.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusMacrosporangiidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus macrosporangiidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusMacrosporangiidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1382304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1382304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1382304.clusters.proteins.v11.5.txt",
		        "sequence_path": "1382304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1382304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1382304.protein.info.v11.5.txt",
		        "node_list_path": "1382304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1382304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryobacteriumLevicorallinumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryobacterium levicorallinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryobacteriumLevicorallinumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "995038.clusters.info.v11.5.txt",
		        "cluster_tree_path": "995038.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "995038.clusters.proteins.v11.5.txt",
		        "sequence_path": "995038.protein.sequences.v11.5.fa",
		        "enrichment_path": "995038.protein.enrichment.terms.v11.5.txt",
		        "info_path": "995038.protein.info.v11.5.txt",
		        "node_list_path": "995038.cluster.nodes.v11.5.txt",
		        "edge_list_path": "995038.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArchaeoglobusSulfaticallidusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobus sulfaticallidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArchaeoglobusSulfaticallidusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "387631.clusters.info.v11.5.txt",
		        "cluster_tree_path": "387631.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "387631.clusters.proteins.v11.5.txt",
		        "sequence_path": "387631.protein.sequences.v11.5.fa",
		        "enrichment_path": "387631.protein.enrichment.terms.v11.5.txt",
		        "info_path": "387631.protein.info.v11.5.txt",
		        "node_list_path": "387631.cluster.nodes.v11.5.txt",
		        "edge_list_path": "387631.protein.cluster.v11.5.txt"
		    }
		]
    )()

def IsoptericolaVariabilis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Isoptericola variabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "IsoptericolaVariabilis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "743718.protein.sequences.v11.5.fa",
		        "enrichment_path": "743718.protein.enrichment.terms.v11.5.txt",
		        "info_path": "743718.protein.info.v11.5.txt",
		        "node_list_path": "743718.protein.complete.v11.5.txt"
		    }
		]
    )()

def AchlyaHypogyna(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Achlya hypogyna graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AchlyaHypogyna", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1202772.protein.sequences.v11.5.fa",
		        "enrichment_path": "1202772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1202772.protein.info.v11.5.txt",
		        "node_list_path": "1202772.protein.complete.v11.5.txt"
		    }
		]
    )()

def KingellaDenitrificansAtcc33394(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kingella denitrificans ATCC 33394 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KingellaDenitrificansAtcc33394", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "888741.protein.sequences.v11.5.fa",
		        "enrichment_path": "888741.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888741.protein.info.v11.5.txt",
		        "node_list_path": "888741.protein.complete.v11.5.txt"
		    }
		]
    )()

def FungalSpNo11243Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return fungal sp. No.11243 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FungalSpNo11243Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1603295.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1603295.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1603295.clusters.proteins.v11.5.txt",
		        "sequence_path": "1603295.protein.sequences.v11.5.fa",
		        "enrichment_path": "1603295.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1603295.protein.info.v11.5.txt",
		        "node_list_path": "1603295.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1603295.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumPhragmitis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium phragmitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumPhragmitis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "739143.protein.sequences.v11.5.fa",
		        "enrichment_path": "739143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "739143.protein.info.v11.5.txt",
		        "node_list_path": "739143.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumYanniciiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium yannicii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumYanniciiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1194165.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1194165.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1194165.clusters.proteins.v11.5.txt",
		        "sequence_path": "1194165.protein.sequences.v11.5.fa",
		        "enrichment_path": "1194165.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1194165.protein.info.v11.5.txt",
		        "node_list_path": "1194165.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1194165.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanomassiliicoccusLuminyensisB10(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanomassiliicoccus luminyensis B10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomassiliicoccusLuminyensisB10", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1175296.protein.sequences.v11.5.fa",
		        "enrichment_path": "1175296.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1175296.protein.info.v11.5.txt",
		        "node_list_path": "1175296.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanomethylophilusAlvus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanomethylophilus alvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanomethylophilusAlvus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1236689.protein.sequences.v11.5.fa",
		        "enrichment_path": "1236689.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1236689.protein.info.v11.5.txt",
		        "node_list_path": "1236689.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaFalloniiLlap10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella fallonii LLAP-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaFalloniiLlap10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1212491.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1212491.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1212491.clusters.proteins.v11.5.txt",
		        "sequence_path": "1212491.protein.sequences.v11.5.fa",
		        "enrichment_path": "1212491.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1212491.protein.info.v11.5.txt",
		        "node_list_path": "1212491.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1212491.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronorubrumTibetense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronorubrum tibetense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronorubrumTibetense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1114856.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114856.protein.info.v11.5.txt",
		        "node_list_path": "1114856.protein.complete.v11.5.txt"
		    }
		]
    )()

def SporosarcinaNewyorkensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporosarcina newyorkensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporosarcinaNewyorkensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1027292.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1027292.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1027292.clusters.proteins.v11.5.txt",
		        "sequence_path": "1027292.protein.sequences.v11.5.fa",
		        "enrichment_path": "1027292.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1027292.protein.info.v11.5.txt",
		        "node_list_path": "1027292.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1027292.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SpirosomaRadiotolerans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spirosoma radiotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirosomaRadiotolerans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1379870.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379870.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379870.protein.info.v11.5.txt",
		        "node_list_path": "1379870.protein.complete.v11.5.txt"
		    }
		]
    )()

def CercosporaBerteroae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cercospora berteroae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CercosporaBerteroae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "357750.protein.sequences.v11.5.fa",
		        "enrichment_path": "357750.protein.enrichment.terms.v11.5.txt",
		        "info_path": "357750.protein.info.v11.5.txt",
		        "node_list_path": "357750.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriumScgcAaa278O22(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA278-O22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriumScgcAaa278O22", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "932044.protein.sequences.v11.5.fa",
		        "enrichment_path": "932044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "932044.protein.info.v11.5.txt",
		        "node_list_path": "932044.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpLsjc280b00Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LSJC280B00 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpLsjc280b00Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1287336.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1287336.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1287336.clusters.proteins.v11.5.txt",
		        "sequence_path": "1287336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287336.protein.info.v11.5.txt",
		        "node_list_path": "1287336.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1287336.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PsychromonasOssibalaenae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas ossibalaenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychromonasOssibalaenae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1278307.protein.sequences.v11.5.fa",
		        "enrichment_path": "1278307.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1278307.protein.info.v11.5.txt",
		        "node_list_path": "1278307.protein.complete.v11.5.txt"
		    }
		]
    )()

def HyphomonadaceaeBacteriumBrhC29(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonadaceae bacterium BRH_c29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HyphomonadaceaeBacteriumBrhC29", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1629720.protein.sequences.v11.5.fa",
		        "enrichment_path": "1629720.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1629720.protein.info.v11.5.txt",
		        "node_list_path": "1629720.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusHydrothermaeBacteriumJdfr72Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrothermae bacterium JdFR-72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusHydrothermaeBacteriumJdfr72Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1935123.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1935123.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1935123.clusters.proteins.v11.5.txt",
		        "sequence_path": "1935123.protein.sequences.v11.5.fa",
		        "enrichment_path": "1935123.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1935123.protein.info.v11.5.txt",
		        "node_list_path": "1935123.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1935123.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodomicrobiumUdaipurenseJa643Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodomicrobium udaipurense JA643 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodomicrobiumUdaipurenseJa643Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "858455.clusters.info.v11.5.txt",
		        "cluster_tree_path": "858455.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "858455.clusters.proteins.v11.5.txt",
		        "sequence_path": "858455.protein.sequences.v11.5.fa",
		        "enrichment_path": "858455.protein.enrichment.terms.v11.5.txt",
		        "info_path": "858455.protein.info.v11.5.txt",
		        "node_list_path": "858455.cluster.nodes.v11.5.txt",
		        "edge_list_path": "858455.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusLugdunensisHku0901(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis HKU0901 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusLugdunensisHku0901", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "698737.protein.sequences.v11.5.fa",
		        "enrichment_path": "698737.protein.enrichment.terms.v11.5.txt",
		        "info_path": "698737.protein.info.v11.5.txt",
		        "node_list_path": "698737.protein.complete.v11.5.txt"
		    }
		]
    )()

def GemellaBergeriaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella bergeriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaBergeriaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1321820.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1321820.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1321820.clusters.proteins.v11.5.txt",
		        "sequence_path": "1321820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321820.protein.info.v11.5.txt",
		        "node_list_path": "1321820.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1321820.protein.cluster.v11.5.txt"
		    }
		]
    )()

def VibrioRuberDsm16370(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ruber DSM 16370 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioRuberDsm16370", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123498.protein.info.v11.5.txt",
		        "node_list_path": "1123498.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArenibacterNanhaiticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arenibacter nanhaiticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArenibacterNanhaiticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "558155.protein.sequences.v11.5.fa",
		        "enrichment_path": "558155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "558155.protein.info.v11.5.txt",
		        "node_list_path": "558155.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSp21331Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2133.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSp21331Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881021.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881021.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881021.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881021.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881021.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881021.protein.info.v11.5.txt",
		        "node_list_path": "1881021.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881021.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FusobacteriumNucleatumAtcc25586Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum ATCC25586 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FusobacteriumNucleatumAtcc25586Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "190304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "190304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "190304.clusters.proteins.v11.5.txt",
		        "sequence_path": "190304.protein.sequences.v11.5.fa",
		        "enrichment_path": "190304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190304.protein.info.v11.5.txt",
		        "node_list_path": "190304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "190304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BombyxMoriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bombyx mori Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BombyxMoriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "7091.clusters.info.v11.5.txt",
		        "cluster_tree_path": "7091.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "7091.clusters.proteins.v11.5.txt",
		        "sequence_path": "7091.protein.sequences.v11.5.fa",
		        "enrichment_path": "7091.protein.enrichment.terms.v11.5.txt",
		        "info_path": "7091.protein.info.v11.5.txt",
		        "node_list_path": "7091.cluster.nodes.v11.5.txt",
		        "edge_list_path": "7091.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBlackburnbacteriaBacteriumRifcsphigho202Full4420(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_02_FULL_44_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho202Full4420", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797516.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797516.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797516.protein.info.v11.5.txt",
		        "node_list_path": "1797516.protein.complete.v11.5.txt"
		    }
		]
    )()

def EuryarchaeotaArchaeonRbg166727Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_16_67_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EuryarchaeotaArchaeonRbg166727Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797980.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797980.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797980.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797980.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797980.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797980.protein.info.v11.5.txt",
		        "node_list_path": "1797980.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797980.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RuminococcusFlavefaciensMa2007Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens MA2007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RuminococcusFlavefaciensMa2007Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1410670.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1410670.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1410670.clusters.proteins.v11.5.txt",
		        "sequence_path": "1410670.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410670.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410670.protein.info.v11.5.txt",
		        "node_list_path": "1410670.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1410670.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumSpHmsc28b08(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC28B08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumSpHmsc28b08", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1581066.protein.sequences.v11.5.fa",
		        "enrichment_path": "1581066.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1581066.protein.info.v11.5.txt",
		        "node_list_path": "1581066.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhytophthoraInfestans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora infestans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraInfestans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4787.protein.sequences.v11.5.fa",
		        "enrichment_path": "4787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4787.protein.info.v11.5.txt",
		        "node_list_path": "4787.protein.complete.v11.5.txt"
		    }
		]
    )()

def OscillatoriaSpPcc10802Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoria sp. PCC10802 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillatoriaSpPcc10802Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173028.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173028.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173028.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173028.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173028.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173028.protein.info.v11.5.txt",
		        "node_list_path": "1173028.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173028.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumPropinquumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium propinquum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumPropinquumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121367.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121367.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121367.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121367.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121367.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121367.protein.info.v11.5.txt",
		        "node_list_path": "1121367.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121367.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumViride(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium viride graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumViride", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121344.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121344.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121344.protein.info.v11.5.txt",
		        "node_list_path": "1121344.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiaBacteriumDtu030(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU030 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiaBacteriumDtu030", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1671640.protein.sequences.v11.5.fa",
		        "enrichment_path": "1671640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1671640.protein.info.v11.5.txt",
		        "node_list_path": "1671640.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusGottheilii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus gottheilii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusGottheilii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "859144.protein.sequences.v11.5.fa",
		        "enrichment_path": "859144.protein.enrichment.terms.v11.5.txt",
		        "info_path": "859144.protein.info.v11.5.txt",
		        "node_list_path": "859144.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesocestoidesCortiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesocestoides corti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesocestoidesCortiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "53468.clusters.info.v11.5.txt",
		        "cluster_tree_path": "53468.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "53468.clusters.proteins.v11.5.txt",
		        "sequence_path": "53468.protein.sequences.v11.5.fa",
		        "enrichment_path": "53468.protein.enrichment.terms.v11.5.txt",
		        "info_path": "53468.protein.info.v11.5.txt",
		        "node_list_path": "53468.cluster.nodes.v11.5.txt",
		        "edge_list_path": "53468.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermincolaPotensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermincola potens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermincolaPotensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "635013.clusters.info.v11.5.txt",
		        "cluster_tree_path": "635013.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "635013.clusters.proteins.v11.5.txt",
		        "sequence_path": "635013.protein.sequences.v11.5.fa",
		        "enrichment_path": "635013.protein.enrichment.terms.v11.5.txt",
		        "info_path": "635013.protein.info.v11.5.txt",
		        "node_list_path": "635013.cluster.nodes.v11.5.txt",
		        "edge_list_path": "635013.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PorphyromonasCangingivalis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas cangingivalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PorphyromonasCangingivalis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36874.protein.sequences.v11.5.fa",
		        "enrichment_path": "36874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36874.protein.info.v11.5.txt",
		        "node_list_path": "36874.protein.complete.v11.5.txt"
		    }
		]
    )()

def TropilaelapsMercedesaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tropilaelaps mercedesae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TropilaelapsMercedesaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "418985.clusters.info.v11.5.txt",
		        "cluster_tree_path": "418985.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "418985.clusters.proteins.v11.5.txt",
		        "sequence_path": "418985.protein.sequences.v11.5.fa",
		        "enrichment_path": "418985.protein.enrichment.terms.v11.5.txt",
		        "info_path": "418985.protein.info.v11.5.txt",
		        "node_list_path": "418985.cluster.nodes.v11.5.txt",
		        "edge_list_path": "418985.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AuxenochlorellaProtothecoides(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Auxenochlorella protothecoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AuxenochlorellaProtothecoides", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "3075.protein.sequences.v11.5.fa",
		        "enrichment_path": "3075.protein.enrichment.terms.v11.5.txt",
		        "info_path": "3075.protein.info.v11.5.txt",
		        "node_list_path": "3075.protein.complete.v11.5.txt"
		    }
		]
    )()

def PericoniaMacrospinosa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Periconia macrospinosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PericoniaMacrospinosa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "97972.protein.sequences.v11.5.fa",
		        "enrichment_path": "97972.protein.enrichment.terms.v11.5.txt",
		        "info_path": "97972.protein.info.v11.5.txt",
		        "node_list_path": "97972.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaBirminghamensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella birminghamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaBirminghamensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28083.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28083.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28083.clusters.proteins.v11.5.txt",
		        "sequence_path": "28083.protein.sequences.v11.5.fa",
		        "enrichment_path": "28083.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28083.protein.info.v11.5.txt",
		        "node_list_path": "28083.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28083.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacterSpS108Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter sp. S10-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacterSpS108Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797110.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797110.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797110.protein.info.v11.5.txt",
		        "node_list_path": "1797110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpUnc362mftsu51(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UNC362MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpUnc362mftsu51", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449044.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449044.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449044.protein.info.v11.5.txt",
		        "node_list_path": "1449044.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpChol1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Chol1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpChol1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "440512.protein.sequences.v11.5.fa",
		        "enrichment_path": "440512.protein.enrichment.terms.v11.5.txt",
		        "info_path": "440512.protein.info.v11.5.txt",
		        "node_list_path": "440512.protein.complete.v11.5.txt"
		    }
		]
    )()

def NocardiaYamanashiensisNbrc100130Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia yamanashiensis NBRC 100130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NocardiaYamanashiensisNbrc100130Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1210099.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1210099.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1210099.clusters.proteins.v11.5.txt",
		        "sequence_path": "1210099.protein.sequences.v11.5.fa",
		        "enrichment_path": "1210099.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1210099.protein.info.v11.5.txt",
		        "node_list_path": "1210099.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1210099.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpMadarCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. MADAR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpMadarCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1074889.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1074889.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1074889.clusters.proteins.v11.5.txt",
		        "sequence_path": "1074889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1074889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1074889.protein.info.v11.5.txt",
		        "node_list_path": "1074889.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1074889.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BhargavaeaCecembensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bhargavaea cecembensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BhargavaeaCecembensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235279.protein.info.v11.5.txt",
		        "node_list_path": "1235279.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterSinensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterSinensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1743157.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1743157.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1743157.clusters.proteins.v11.5.txt",
		        "sequence_path": "1743157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743157.protein.info.v11.5.txt",
		        "node_list_path": "1743157.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1743157.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumGwe23716Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWE2_37_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumGwe23716Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798261.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798261.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798261.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798261.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798261.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798261.protein.info.v11.5.txt",
		        "node_list_path": "1798261.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798261.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumErythrophlei(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium erythrophlei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumErythrophlei", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437360.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437360.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437360.protein.info.v11.5.txt",
		        "node_list_path": "1437360.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlattabacteriumSpBge(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Bge graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlattabacteriumSpBge", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "331104.protein.sequences.v11.5.fa",
		        "enrichment_path": "331104.protein.enrichment.terms.v11.5.txt",
		        "info_path": "331104.protein.info.v11.5.txt",
		        "node_list_path": "331104.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChitinophagaNiabensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga niabensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaNiabensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "536979.protein.sequences.v11.5.fa",
		        "enrichment_path": "536979.protein.enrichment.terms.v11.5.txt",
		        "info_path": "536979.protein.info.v11.5.txt",
		        "node_list_path": "536979.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParacoccusContaminansCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus contaminans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParacoccusContaminansCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945662.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945662.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945662.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945662.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945662.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945662.protein.info.v11.5.txt",
		        "node_list_path": "1945662.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945662.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSelenitireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium selenitireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSelenitireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1336235.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336235.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336235.protein.info.v11.5.txt",
		        "node_list_path": "1336235.protein.complete.v11.5.txt"
		    }
		]
    )()

def WolbachiaSpBma(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Bma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return AutomaticallyRetrievedGraph(
        "WolbachiaSpBma", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "292805.protein.sequences.v11.0.fa",
		        "enrichment_path": "292805.protein.enrichment.terms.v11.0.txt",
		        "info_path": "292805.protein.info.v11.0.txt",
		        "node_list_path": "292805.protein.complete.v11.0.txt"
		    }
		]
    )()

def MycobacteroidesFrankliniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacteroides franklinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteroidesFrankliniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "948102.clusters.info.v11.5.txt",
		        "cluster_tree_path": "948102.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "948102.clusters.proteins.v11.5.txt",
		        "sequence_path": "948102.protein.sequences.v11.5.fa",
		        "enrichment_path": "948102.protein.enrichment.terms.v11.5.txt",
		        "info_path": "948102.protein.info.v11.5.txt",
		        "node_list_path": "948102.cluster.nodes.v11.5.txt",
		        "edge_list_path": "948102.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PhytophthoraNicotianaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora nicotianae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhytophthoraNicotianaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "4790.clusters.info.v11.5.txt",
		        "cluster_tree_path": "4790.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "4790.clusters.proteins.v11.5.txt",
		        "sequence_path": "4790.protein.sequences.v11.5.fa",
		        "enrichment_path": "4790.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4790.protein.info.v11.5.txt",
		        "node_list_path": "4790.cluster.nodes.v11.5.txt",
		        "edge_list_path": "4790.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudocercosporaMusae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudocercospora musae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudocercosporaMusae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "113226.protein.sequences.v11.5.fa",
		        "enrichment_path": "113226.protein.enrichment.terms.v11.5.txt",
		        "info_path": "113226.protein.info.v11.5.txt",
		        "node_list_path": "113226.protein.complete.v11.5.txt"
		    }
		]
    )()

def DerxiaLacustris(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Derxia lacustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DerxiaLacustris", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "764842.protein.sequences.v11.5.fa",
		        "enrichment_path": "764842.protein.enrichment.terms.v11.5.txt",
		        "info_path": "764842.protein.info.v11.5.txt",
		        "node_list_path": "764842.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaGlumipatula(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryza glumipatula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaGlumipatula", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "40148.protein.sequences.v11.5.fa",
		        "enrichment_path": "40148.protein.enrichment.terms.v11.5.txt",
		        "info_path": "40148.protein.info.v11.5.txt",
		        "node_list_path": "40148.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpUrha0033Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. URHA0033 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpUrha0033Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298862.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298862.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298862.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298862.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298862.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298862.protein.info.v11.5.txt",
		        "node_list_path": "1298862.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298862.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasSpGr602(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. GR 6-02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasSpGr602", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1659194.protein.sequences.v11.5.fa",
		        "enrichment_path": "1659194.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1659194.protein.info.v11.5.txt",
		        "node_list_path": "1659194.protein.complete.v11.5.txt"
		    }
		]
    )()

def TatumellaPtyseosCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tatumella ptyseos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TatumellaPtyseosCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1005995.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1005995.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1005995.clusters.proteins.v11.5.txt",
		        "sequence_path": "1005995.protein.sequences.v11.5.fa",
		        "enrichment_path": "1005995.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1005995.protein.info.v11.5.txt",
		        "node_list_path": "1005995.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1005995.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiaSibirica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia sibirica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaSibirica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272951.protein.sequences.v11.5.fa",
		        "enrichment_path": "272951.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272951.protein.info.v11.5.txt",
		        "node_list_path": "272951.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhodobacterSpCacia14h1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacter sp. CACIA14H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodobacterSpCacia14h1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408890.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408890.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408890.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408890.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408890.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408890.protein.info.v11.5.txt",
		        "node_list_path": "1408890.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408890.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFf9(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FF9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFf9", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1527293.protein.sequences.v11.5.fa",
		        "enrichment_path": "1527293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1527293.protein.info.v11.5.txt",
		        "node_list_path": "1527293.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastococcusSpUrhd0036Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastococcus sp. URHD0036 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastococcusSpUrhd0036Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380356.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380356.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380356.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380356.protein.info.v11.5.txt",
		        "node_list_path": "1380356.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380356.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XylariaFlabelliformis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xylaria flabelliformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XylariaFlabelliformis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2512241.protein.sequences.v11.5.fa",
		        "enrichment_path": "2512241.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2512241.protein.info.v11.5.txt",
		        "node_list_path": "2512241.protein.complete.v11.5.txt"
		    }
		]
    )()

def TarenayaHasslerianaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tarenaya hassleriana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TarenayaHasslerianaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28532.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28532.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28532.clusters.proteins.v11.5.txt",
		        "sequence_path": "28532.protein.sequences.v11.5.fa",
		        "enrichment_path": "28532.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28532.protein.info.v11.5.txt",
		        "node_list_path": "28532.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28532.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumCallunae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium callunae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumCallunae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121353.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121353.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121353.protein.info.v11.5.txt",
		        "node_list_path": "1121353.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrotetrasporaMalaysiensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microtetraspora malaysiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrotetrasporaMalaysiensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "161358.protein.sequences.v11.5.fa",
		        "enrichment_path": "161358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161358.protein.info.v11.5.txt",
		        "node_list_path": "161358.protein.complete.v11.5.txt"
		    }
		]
    )()

def StenotrophomonasNitritireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas nitritireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StenotrophomonasNitritireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "83617.protein.sequences.v11.5.fa",
		        "enrichment_path": "83617.protein.enrichment.terms.v11.5.txt",
		        "info_path": "83617.protein.info.v11.5.txt",
		        "node_list_path": "83617.protein.complete.v11.5.txt"
		    }
		]
    )()

def RoseiflexusCastenholziiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseiflexus castenholzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseiflexusCastenholziiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "383372.clusters.info.v11.5.txt",
		        "cluster_tree_path": "383372.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "383372.clusters.proteins.v11.5.txt",
		        "sequence_path": "383372.protein.sequences.v11.5.fa",
		        "enrichment_path": "383372.protein.enrichment.terms.v11.5.txt",
		        "info_path": "383372.protein.info.v11.5.txt",
		        "node_list_path": "383372.cluster.nodes.v11.5.txt",
		        "edge_list_path": "383372.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AuraticoccusMonumenti(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Auraticoccus monumenti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AuraticoccusMonumenti", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "675864.protein.sequences.v11.5.fa",
		        "enrichment_path": "675864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "675864.protein.info.v11.5.txt",
		        "node_list_path": "675864.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhenylobacteriumZucineum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium zucineum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhenylobacteriumZucineum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "450851.protein.sequences.v11.5.fa",
		        "enrichment_path": "450851.protein.enrichment.terms.v11.5.txt",
		        "info_path": "450851.protein.info.v11.5.txt",
		        "node_list_path": "450851.protein.complete.v11.5.txt"
		    }
		]
    )()

def PolaribacterVadiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter vadi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterVadiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1774273.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1774273.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1774273.clusters.proteins.v11.5.txt",
		        "sequence_path": "1774273.protein.sequences.v11.5.fa",
		        "enrichment_path": "1774273.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1774273.protein.info.v11.5.txt",
		        "node_list_path": "1774273.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1774273.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfobacteriumVacuolatumDsm3385Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterium vacuolatum DSM 3385 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobacteriumVacuolatumDsm3385Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121400.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121400.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121400.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121400.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121400.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121400.protein.info.v11.5.txt",
		        "node_list_path": "1121400.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121400.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumTibeticumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium tibeticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumTibeticumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "501024.clusters.info.v11.5.txt",
		        "cluster_tree_path": "501024.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "501024.clusters.proteins.v11.5.txt",
		        "sequence_path": "501024.protein.sequences.v11.5.fa",
		        "enrichment_path": "501024.protein.enrichment.terms.v11.5.txt",
		        "info_path": "501024.protein.info.v11.5.txt",
		        "node_list_path": "501024.cluster.nodes.v11.5.txt",
		        "edge_list_path": "501024.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlphaproteobacteriaBacteriumGwf25820(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium GWF2_58_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlphaproteobacteriaBacteriumGwf25820", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797213.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797213.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797213.protein.info.v11.5.txt",
		        "node_list_path": "1797213.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusAlveiTs15Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alvei TS15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusAlveiTs15Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1117108.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1117108.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1117108.clusters.proteins.v11.5.txt",
		        "sequence_path": "1117108.protein.sequences.v11.5.fa",
		        "enrichment_path": "1117108.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1117108.protein.info.v11.5.txt",
		        "node_list_path": "1117108.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1117108.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo212Full6423(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_12_FULL_64_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212Full6423", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797499.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797499.protein.info.v11.5.txt",
		        "node_list_path": "1797499.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalogeometricumBorinquenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halogeometricum borinquense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalogeometricumBorinquenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "469382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "469382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "469382.clusters.proteins.v11.5.txt",
		        "sequence_path": "469382.protein.sequences.v11.5.fa",
		        "enrichment_path": "469382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "469382.protein.info.v11.5.txt",
		        "node_list_path": "469382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "469382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarininemaMesophilum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marininema mesophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarininemaMesophilum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1048340.protein.sequences.v11.5.fa",
		        "enrichment_path": "1048340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1048340.protein.info.v11.5.txt",
		        "node_list_path": "1048340.protein.complete.v11.5.txt"
		    }
		]
    )()

def MetschnikowiaSpJcm33374Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Metschnikowia sp. JCM 33374 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MetschnikowiaSpJcm33374Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2562755.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2562755.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2562755.clusters.proteins.v11.5.txt",
		        "sequence_path": "2562755.protein.sequences.v11.5.fa",
		        "enrichment_path": "2562755.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2562755.protein.info.v11.5.txt",
		        "node_list_path": "2562755.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2562755.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacteriumAurumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium aurum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacteriumAurumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1791.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1791.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1791.clusters.proteins.v11.5.txt",
		        "sequence_path": "1791.protein.sequences.v11.5.fa",
		        "enrichment_path": "1791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1791.protein.info.v11.5.txt",
		        "node_list_path": "1791.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1791.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusSaccharimonasAalborgensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharimonas aalborgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSaccharimonasAalborgensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1332188.protein.sequences.v11.5.fa",
		        "enrichment_path": "1332188.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1332188.protein.info.v11.5.txt",
		        "node_list_path": "1332188.protein.complete.v11.5.txt"
		    }
		]
    )()

def GordoniaMalaquae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia malaquae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GordoniaMalaquae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1223542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223542.protein.info.v11.5.txt",
		        "node_list_path": "1223542.protein.complete.v11.5.txt"
		    }
		]
    )()

def PlanomonosporaSphaericaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Planomonospora sphaerica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PlanomonosporaSphaericaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "161355.clusters.info.v11.5.txt",
		        "cluster_tree_path": "161355.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "161355.clusters.proteins.v11.5.txt",
		        "sequence_path": "161355.protein.sequences.v11.5.fa",
		        "enrichment_path": "161355.protein.enrichment.terms.v11.5.txt",
		        "info_path": "161355.protein.info.v11.5.txt",
		        "node_list_path": "161355.cluster.nodes.v11.5.txt",
		        "edge_list_path": "161355.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CryobacteriumFlavumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryobacterium flavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CryobacteriumFlavumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1424659.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1424659.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1424659.clusters.proteins.v11.5.txt",
		        "sequence_path": "1424659.protein.sequences.v11.5.fa",
		        "enrichment_path": "1424659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1424659.protein.info.v11.5.txt",
		        "node_list_path": "1424659.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1424659.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KinetoplastibacteriumDesouzaii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium desouzaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KinetoplastibacteriumDesouzaii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208919.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208919.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208919.protein.info.v11.5.txt",
		        "node_list_path": "1208919.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeodermatophilusRuber(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geodermatophilus ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeodermatophilusRuber", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "504800.protein.sequences.v11.5.fa",
		        "enrichment_path": "504800.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504800.protein.info.v11.5.txt",
		        "node_list_path": "504800.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumRufum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rufum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumRufum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "318424.protein.sequences.v11.5.fa",
		        "enrichment_path": "318424.protein.enrichment.terms.v11.5.txt",
		        "info_path": "318424.protein.info.v11.5.txt",
		        "node_list_path": "318424.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusSpJcm19058(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpJcm19058", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1460652.protein.sequences.v11.5.fa",
		        "enrichment_path": "1460652.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1460652.protein.info.v11.5.txt",
		        "node_list_path": "1460652.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumMc2017Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MC2017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumMc2017Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1408324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1408324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1408324.clusters.proteins.v11.5.txt",
		        "sequence_path": "1408324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408324.protein.info.v11.5.txt",
		        "node_list_path": "1408324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1408324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BartonellaSpRaccoon60(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. Raccoon60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BartonellaSpRaccoon60", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1933912.protein.sequences.v11.5.fa",
		        "enrichment_path": "1933912.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1933912.protein.info.v11.5.txt",
		        "node_list_path": "1933912.protein.complete.v11.5.txt"
		    }
		]
    )()

def HydrogenobacterThermophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenobacter thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrogenobacterThermophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "608538.protein.sequences.v11.5.fa",
		        "enrichment_path": "608538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "608538.protein.info.v11.5.txt",
		        "node_list_path": "608538.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1640685.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640685.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640685.protein.info.v11.5.txt",
		        "node_list_path": "1640685.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumBaratiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium baratii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumBaratiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1415775.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1415775.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1415775.clusters.proteins.v11.5.txt",
		        "sequence_path": "1415775.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415775.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415775.protein.info.v11.5.txt",
		        "node_list_path": "1415775.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1415775.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcidovoraxRadicisN35Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax radicis N35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcidovoraxRadicisN35Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "999386.clusters.info.v11.5.txt",
		        "cluster_tree_path": "999386.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "999386.clusters.proteins.v11.5.txt",
		        "sequence_path": "999386.protein.sequences.v11.5.fa",
		        "enrichment_path": "999386.protein.enrichment.terms.v11.5.txt",
		        "info_path": "999386.protein.info.v11.5.txt",
		        "node_list_path": "999386.cluster.nodes.v11.5.txt",
		        "edge_list_path": "999386.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NatronincolaPeptidivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Natronincola peptidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronincolaPeptidivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "426128.protein.sequences.v11.5.fa",
		        "enrichment_path": "426128.protein.enrichment.terms.v11.5.txt",
		        "info_path": "426128.protein.info.v11.5.txt",
		        "node_list_path": "426128.protein.complete.v11.5.txt"
		    }
		]
    )()

def MesorhizobiumSpLnhc252b00(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LNHC252B00 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MesorhizobiumSpLnhc252b00", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1287252.protein.sequences.v11.5.fa",
		        "enrichment_path": "1287252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1287252.protein.info.v11.5.txt",
		        "node_list_path": "1287252.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumGa0077560(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium Ga0077560 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumGa0077560", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1752190.protein.sequences.v11.5.fa",
		        "enrichment_path": "1752190.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1752190.protein.info.v11.5.txt",
		        "node_list_path": "1752190.protein.complete.v11.5.txt"
		    }
		]
    )()

def PleurotusOstreatusPc15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pleurotus ostreatus PC15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PleurotusOstreatusPc15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1137138.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137138.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137138.protein.info.v11.5.txt",
		        "node_list_path": "1137138.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlicyclobacillusPohliaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus pohliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlicyclobacillusPohliaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120973.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120973.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120973.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120973.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120973.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120973.protein.info.v11.5.txt",
		        "node_list_path": "1120973.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120973.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusMethanomethylicusMesodigestumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomethylicus mesodigestum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMethanomethylicusMesodigestumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1867258.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1867258.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1867258.clusters.proteins.v11.5.txt",
		        "sequence_path": "1867258.protein.sequences.v11.5.fa",
		        "enrichment_path": "1867258.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1867258.protein.info.v11.5.txt",
		        "node_list_path": "1867258.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1867258.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DaphniaPulex(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Daphnia pulex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DaphniaPulex", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "6669.protein.sequences.v11.5.fa",
		        "enrichment_path": "6669.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6669.protein.info.v11.5.txt",
		        "node_list_path": "6669.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpSw1Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpSw1Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1920889.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1920889.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1920889.clusters.proteins.v11.5.txt",
		        "sequence_path": "1920889.protein.sequences.v11.5.fa",
		        "enrichment_path": "1920889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1920889.protein.info.v11.5.txt",
		        "node_list_path": "1920889.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1920889.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinokineosporaSpEg49Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora sp. EG49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinokineosporaSpEg49Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "909613.clusters.info.v11.5.txt",
		        "cluster_tree_path": "909613.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "909613.clusters.proteins.v11.5.txt",
		        "sequence_path": "909613.protein.sequences.v11.5.fa",
		        "enrichment_path": "909613.protein.enrichment.terms.v11.5.txt",
		        "info_path": "909613.protein.info.v11.5.txt",
		        "node_list_path": "909613.cluster.nodes.v11.5.txt",
		        "edge_list_path": "909613.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumVitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium vitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumVitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "311402.clusters.info.v11.5.txt",
		        "cluster_tree_path": "311402.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "311402.clusters.proteins.v11.5.txt",
		        "sequence_path": "311402.protein.sequences.v11.5.fa",
		        "enrichment_path": "311402.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311402.protein.info.v11.5.txt",
		        "node_list_path": "311402.cluster.nodes.v11.5.txt",
		        "edge_list_path": "311402.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SilvibacteriumBohemicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Silvibacterium bohemicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SilvibacteriumBohemicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1577686.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577686.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577686.protein.info.v11.5.txt",
		        "node_list_path": "1577686.protein.complete.v11.5.txt"
		    }
		]
    )()

def UrinicoccusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Urinicoccus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "UrinicoccusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1723382.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1723382.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1723382.clusters.proteins.v11.5.txt",
		        "sequence_path": "1723382.protein.sequences.v11.5.fa",
		        "enrichment_path": "1723382.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1723382.protein.info.v11.5.txt",
		        "node_list_path": "1723382.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1723382.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpAnc5600Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 5600 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpAnc5600Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1960940.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1960940.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1960940.clusters.proteins.v11.5.txt",
		        "sequence_path": "1960940.protein.sequences.v11.5.fa",
		        "enrichment_path": "1960940.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1960940.protein.info.v11.5.txt",
		        "node_list_path": "1960940.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1960940.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfurispirillumIndicum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurispirillum indicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurispirillumIndicum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "653733.protein.sequences.v11.5.fa",
		        "enrichment_path": "653733.protein.enrichment.terms.v11.5.txt",
		        "info_path": "653733.protein.info.v11.5.txt",
		        "node_list_path": "653733.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasByunsanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas byunsanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasByunsanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "327939.clusters.info.v11.5.txt",
		        "cluster_tree_path": "327939.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "327939.clusters.proteins.v11.5.txt",
		        "sequence_path": "327939.protein.sequences.v11.5.fa",
		        "enrichment_path": "327939.protein.enrichment.terms.v11.5.txt",
		        "info_path": "327939.protein.info.v11.5.txt",
		        "node_list_path": "327939.cluster.nodes.v11.5.txt",
		        "edge_list_path": "327939.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoxiellaBurnetii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coxiella burnetii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoxiellaBurnetii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "227377.protein.sequences.v11.5.fa",
		        "enrichment_path": "227377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "227377.protein.info.v11.5.txt",
		        "node_list_path": "227377.protein.complete.v11.5.txt"
		    }
		]
    )()

def MolaMola(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mola mola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MolaMola", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "94237.protein.sequences.v11.5.fa",
		        "enrichment_path": "94237.protein.enrichment.terms.v11.5.txt",
		        "info_path": "94237.protein.info.v11.5.txt",
		        "node_list_path": "94237.protein.complete.v11.5.txt"
		    }
		]
    )()

def NatronomonasPharaonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronomonas pharaonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NatronomonasPharaonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "348780.clusters.info.v11.5.txt",
		        "cluster_tree_path": "348780.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "348780.clusters.proteins.v11.5.txt",
		        "sequence_path": "348780.protein.sequences.v11.5.fa",
		        "enrichment_path": "348780.protein.enrichment.terms.v11.5.txt",
		        "info_path": "348780.protein.info.v11.5.txt",
		        "node_list_path": "348780.cluster.nodes.v11.5.txt",
		        "edge_list_path": "348780.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumAurum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium aurum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumAurum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36805.protein.sequences.v11.5.fa",
		        "enrichment_path": "36805.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36805.protein.info.v11.5.txt",
		        "node_list_path": "36805.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteriovoraxSpMedpeSwde(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. MedPE-SWde graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteriovoraxSpMedpeSwde", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1860085.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860085.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860085.protein.info.v11.5.txt",
		        "node_list_path": "1860085.protein.complete.v11.5.txt"
		    }
		]
    )()

def DongiaSpUrhe0060Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dongia sp. URHE0060 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DongiaSpUrhe0060Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1380391.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1380391.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1380391.clusters.proteins.v11.5.txt",
		        "sequence_path": "1380391.protein.sequences.v11.5.fa",
		        "enrichment_path": "1380391.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1380391.protein.info.v11.5.txt",
		        "node_list_path": "1380391.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1380391.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CoxiellaLikeEndosymbiont(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Coxiella-like endosymbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CoxiellaLikeEndosymbiont", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1592897.protein.sequences.v11.5.fa",
		        "enrichment_path": "1592897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1592897.protein.info.v11.5.txt",
		        "node_list_path": "1592897.protein.complete.v11.5.txt"
		    }
		]
    )()

def OceanobacterKriegiiDsm6294(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacter kriegii DSM 6294 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OceanobacterKriegiiDsm6294", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1122615.protein.sequences.v11.5.fa",
		        "enrichment_path": "1122615.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1122615.protein.info.v11.5.txt",
		        "node_list_path": "1122615.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtelocyanobacteriumThalassaSio64986(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Atelocyanobacterium thalassa SIO64986 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtelocyanobacteriumThalassaSio64986", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1527444.protein.sequences.v11.5.fa",
		        "enrichment_path": "1527444.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1527444.protein.info.v11.5.txt",
		        "node_list_path": "1527444.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsilocybeCyanescens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psilocybe cyanescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsilocybeCyanescens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "93625.protein.sequences.v11.5.fa",
		        "enrichment_path": "93625.protein.enrichment.terms.v11.5.txt",
		        "info_path": "93625.protein.info.v11.5.txt",
		        "node_list_path": "93625.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWolfebacteriaBacteriumRifcsplowo201Full4519(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPLOWO2_01_FULL_45_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsplowo201Full4519", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802557.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802557.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802557.protein.info.v11.5.txt",
		        "node_list_path": "1802557.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalophilicArchaeonDl31(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return halophilic archaeon DL31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalophilicArchaeonDl31", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "756883.protein.sequences.v11.5.fa",
		        "enrichment_path": "756883.protein.enrichment.terms.v11.5.txt",
		        "info_path": "756883.protein.info.v11.5.txt",
		        "node_list_path": "756883.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErwiniaSp9145Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia sp. 9145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErwiniaSp9145Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500895.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500895.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500895.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500895.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500895.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500895.protein.info.v11.5.txt",
		        "node_list_path": "1500895.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500895.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusHoagii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus hoagii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusHoagii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "43767.protein.sequences.v11.5.fa",
		        "enrichment_path": "43767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "43767.protein.info.v11.5.txt",
		        "node_list_path": "43767.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusChisholmbacteriaBacteriumRifcsphigho201Full4812(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPHIGHO2_01_FULL_48_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsphigho201Full4812", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797589.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797589.protein.info.v11.5.txt",
		        "node_list_path": "1797589.protein.complete.v11.5.txt"
		    }
		]
    )()

def VibrioAzureusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio azureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "VibrioAzureusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1219077.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1219077.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1219077.clusters.proteins.v11.5.txt",
		        "sequence_path": "1219077.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219077.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219077.protein.info.v11.5.txt",
		        "node_list_path": "1219077.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1219077.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NanoarchaeotaArchaeonScgcAaa011G17(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Nanoarchaeota archaeon SCGC AAA011-G17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NanoarchaeotaArchaeonScgcAaa011G17", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1104577.protein.sequences.v11.5.fa",
		        "enrichment_path": "1104577.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1104577.protein.info.v11.5.txt",
		        "node_list_path": "1104577.protein.complete.v11.5.txt"
		    }
		]
    )()

def ExiguobacteriumSpZwu0009(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. ZWU0009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ExiguobacteriumSpZwu0009", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1224749.protein.sequences.v11.5.fa",
		        "enrichment_path": "1224749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1224749.protein.info.v11.5.txt",
		        "node_list_path": "1224749.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotorhabdusHeterorhabditis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Photorhabdus heterorhabditis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotorhabdusHeterorhabditis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "880156.protein.sequences.v11.5.fa",
		        "enrichment_path": "880156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "880156.protein.info.v11.5.txt",
		        "node_list_path": "880156.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumLavalenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] lavalense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumLavalenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "460384.clusters.info.v11.5.txt",
		        "cluster_tree_path": "460384.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "460384.clusters.proteins.v11.5.txt",
		        "sequence_path": "460384.protein.sequences.v11.5.fa",
		        "enrichment_path": "460384.protein.enrichment.terms.v11.5.txt",
		        "info_path": "460384.protein.info.v11.5.txt",
		        "node_list_path": "460384.cluster.nodes.v11.5.txt",
		        "edge_list_path": "460384.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethylobacterLuteusImvB3098(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacter luteus IMV-B-3098 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacterLuteusImvB3098", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1095552.protein.sequences.v11.5.fa",
		        "enrichment_path": "1095552.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1095552.protein.info.v11.5.txt",
		        "node_list_path": "1095552.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesVaccimaxillaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces vaccimaxillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesVaccimaxillaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1120947.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1120947.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1120947.clusters.proteins.v11.5.txt",
		        "sequence_path": "1120947.protein.sequences.v11.5.fa",
		        "enrichment_path": "1120947.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1120947.protein.info.v11.5.txt",
		        "node_list_path": "1120947.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1120947.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OscillatorialesCyanobacteriumCg2304061Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium CG2_30_40_61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OscillatorialesCyanobacteriumCg2304061Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1805291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1805291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1805291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1805291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805291.protein.info.v11.5.txt",
		        "node_list_path": "1805291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1805291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PyrobaculumAerophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum aerophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PyrobaculumAerophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "178306.clusters.info.v11.5.txt",
		        "cluster_tree_path": "178306.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "178306.clusters.proteins.v11.5.txt",
		        "sequence_path": "178306.protein.sequences.v11.5.fa",
		        "enrichment_path": "178306.protein.enrichment.terms.v11.5.txt",
		        "info_path": "178306.protein.info.v11.5.txt",
		        "node_list_path": "178306.cluster.nodes.v11.5.txt",
		        "edge_list_path": "178306.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BeauveriaBassianaArsef2860Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Beauveria bassiana ARSEF 2860 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BeauveriaBassianaArsef2860Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655819.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655819.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655819.clusters.proteins.v11.5.txt",
		        "sequence_path": "655819.protein.sequences.v11.5.fa",
		        "enrichment_path": "655819.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655819.protein.info.v11.5.txt",
		        "node_list_path": "655819.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655819.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RickettsiellaGrylli(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsiella grylli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiellaGrylli", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "59196.protein.sequences.v11.5.fa",
		        "enrichment_path": "59196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "59196.protein.info.v11.5.txt",
		        "node_list_path": "59196.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusCampbellbacteriaBacteriumRifcsplowo201Full3415Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFCSPLOWO2_01_FULL_34_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifcsplowo201Full3415Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797579.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797579.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797579.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797579.protein.info.v11.5.txt",
		        "node_list_path": "1797579.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797579.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfurobacteriumThermolithotrophum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurobacterium thermolithotrophum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfurobacteriumThermolithotrophum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "868864.protein.sequences.v11.5.fa",
		        "enrichment_path": "868864.protein.enrichment.terms.v11.5.txt",
		        "info_path": "868864.protein.info.v11.5.txt",
		        "node_list_path": "868864.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioThiocyanodenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanodenitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioThiocyanodenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "713586.protein.sequences.v11.5.fa",
		        "enrichment_path": "713586.protein.enrichment.terms.v11.5.txt",
		        "info_path": "713586.protein.info.v11.5.txt",
		        "node_list_path": "713586.protein.complete.v11.5.txt"
		    }
		]
    )()

def FrancisellaPersicaAtccVr331(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Francisella persica ATCC VR-331 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FrancisellaPersicaAtccVr331", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1086726.protein.sequences.v11.5.fa",
		        "enrichment_path": "1086726.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1086726.protein.info.v11.5.txt",
		        "node_list_path": "1086726.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidesSpCag1060(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:1060 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidesSpCag1060", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262734.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262734.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262734.protein.info.v11.5.txt",
		        "node_list_path": "1262734.protein.complete.v11.5.txt"
		    }
		]
    )()

def MacacaFascicularisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Macaca fascicularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MacacaFascicularisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9541.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9541.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9541.clusters.proteins.v11.5.txt",
		        "sequence_path": "9541.protein.sequences.v11.5.fa",
		        "enrichment_path": "9541.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9541.protein.info.v11.5.txt",
		        "node_list_path": "9541.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9541.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TatumellaSpUcdDSuzukii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tatumella sp. UCD-D_suzukii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TatumellaSpUcdDSuzukii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408192.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408192.protein.info.v11.5.txt",
		        "node_list_path": "1408192.protein.complete.v11.5.txt"
		    }
		]
    )()

def CellulophagaLytica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga lytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CellulophagaLytica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "867900.protein.sequences.v11.5.fa",
		        "enrichment_path": "867900.protein.enrichment.terms.v11.5.txt",
		        "info_path": "867900.protein.info.v11.5.txt",
		        "node_list_path": "867900.protein.complete.v11.5.txt"
		    }
		]
    )()

def PaenibacillusSpFjat26967(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FJAT-26967 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusSpFjat26967", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1729690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1729690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1729690.protein.info.v11.5.txt",
		        "node_list_path": "1729690.protein.complete.v11.5.txt"
		    }
		]
    )()

def MelioribacterRoseusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Melioribacter roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MelioribacterRoseusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1191523.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1191523.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1191523.clusters.proteins.v11.5.txt",
		        "sequence_path": "1191523.protein.sequences.v11.5.fa",
		        "enrichment_path": "1191523.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1191523.protein.info.v11.5.txt",
		        "node_list_path": "1191523.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1191523.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PaenibacillusDurusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus durus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PaenibacillusDurusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "44251.clusters.info.v11.5.txt",
		        "cluster_tree_path": "44251.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "44251.clusters.proteins.v11.5.txt",
		        "sequence_path": "44251.protein.sequences.v11.5.fa",
		        "enrichment_path": "44251.protein.enrichment.terms.v11.5.txt",
		        "info_path": "44251.protein.info.v11.5.txt",
		        "node_list_path": "44251.cluster.nodes.v11.5.txt",
		        "edge_list_path": "44251.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetanaerobacteriumElongatum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acetanaerobacterium elongatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetanaerobacteriumElongatum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "258515.protein.sequences.v11.5.fa",
		        "enrichment_path": "258515.protein.enrichment.terms.v11.5.txt",
		        "info_path": "258515.protein.info.v11.5.txt",
		        "node_list_path": "258515.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaSpHn41Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. HN-41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSpHn41Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "327275.clusters.info.v11.5.txt",
		        "cluster_tree_path": "327275.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "327275.clusters.proteins.v11.5.txt",
		        "sequence_path": "327275.protein.sequences.v11.5.fa",
		        "enrichment_path": "327275.protein.enrichment.terms.v11.5.txt",
		        "info_path": "327275.protein.info.v11.5.txt",
		        "node_list_path": "327275.cluster.nodes.v11.5.txt",
		        "edge_list_path": "327275.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudodesulfovibrioIndicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudodesulfovibrio indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudodesulfovibrioIndicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1716143.protein.sequences.v11.5.fa",
		        "enrichment_path": "1716143.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1716143.protein.info.v11.5.txt",
		        "node_list_path": "1716143.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrevibacillusBorstelensisAk1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus borstelensis AK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevibacillusBorstelensisAk1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1300222.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300222.protein.info.v11.5.txt",
		        "node_list_path": "1300222.protein.complete.v11.5.txt"
		    }
		]
    )()

def SyntrophaceaeBacteriumCg2304912(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophaceae bacterium CG2_30_49_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SyntrophaceaeBacteriumCg2304912", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805377.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805377.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805377.protein.info.v11.5.txt",
		        "node_list_path": "1805377.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioGracilisDsm16080Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio gracilis DSM 16080 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioGracilisDsm16080Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121449.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121449.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121449.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121449.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121449.protein.info.v11.5.txt",
		        "node_list_path": "1121449.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121449.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MucilaginibacterSpPpcgb2223Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. PPCGB 2223 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MucilaginibacterSpPpcgb2223Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1886027.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1886027.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1886027.clusters.proteins.v11.5.txt",
		        "sequence_path": "1886027.protein.sequences.v11.5.fa",
		        "enrichment_path": "1886027.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1886027.protein.info.v11.5.txt",
		        "node_list_path": "1886027.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1886027.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacteroidalesBacteriumBact19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidalesBacteriumBact19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1674833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1674833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1674833.clusters.proteins.v11.5.txt",
		        "sequence_path": "1674833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1674833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1674833.protein.info.v11.5.txt",
		        "node_list_path": "1674833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1674833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacteriumXbb2008Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBB2008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacteriumXbb2008Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1520826.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1520826.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1520826.clusters.proteins.v11.5.txt",
		        "sequence_path": "1520826.protein.sequences.v11.5.fa",
		        "enrichment_path": "1520826.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1520826.protein.info.v11.5.txt",
		        "node_list_path": "1520826.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1520826.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GlobisporangiumUltimumDaomBr144(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Globisporangium ultimum DAOM BR144 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlobisporangiumUltimumDaomBr144", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "431595.protein.sequences.v11.5.fa",
		        "enrichment_path": "431595.protein.enrichment.terms.v11.5.txt",
		        "info_path": "431595.protein.info.v11.5.txt",
		        "node_list_path": "431595.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterLipolyticusSm19Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter lipolyticus SM19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterLipolyticusSm19Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1318628.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1318628.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1318628.clusters.proteins.v11.5.txt",
		        "sequence_path": "1318628.protein.sequences.v11.5.fa",
		        "enrichment_path": "1318628.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1318628.protein.info.v11.5.txt",
		        "node_list_path": "1318628.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1318628.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlkaliphilusOremlandiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkaliphilus oremlandii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlkaliphilusOremlandiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "350688.clusters.info.v11.5.txt",
		        "cluster_tree_path": "350688.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "350688.clusters.proteins.v11.5.txt",
		        "sequence_path": "350688.protein.sequences.v11.5.fa",
		        "enrichment_path": "350688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "350688.protein.info.v11.5.txt",
		        "node_list_path": "350688.cluster.nodes.v11.5.txt",
		        "edge_list_path": "350688.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpUnc23mfcrub11(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. UNC23MFCrub11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpUnc23mfcrub11", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1449068.protein.sequences.v11.5.fa",
		        "enrichment_path": "1449068.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1449068.protein.info.v11.5.txt",
		        "node_list_path": "1449068.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylobacteriumPlatani(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium platani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylobacteriumPlatani", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "427683.protein.sequences.v11.5.fa",
		        "enrichment_path": "427683.protein.enrichment.terms.v11.5.txt",
		        "info_path": "427683.protein.info.v11.5.txt",
		        "node_list_path": "427683.protein.complete.v11.5.txt"
		    }
		]
    )()

def SagittulaStellataCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sagittula stellata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SagittulaStellataCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "388399.clusters.info.v11.5.txt",
		        "cluster_tree_path": "388399.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "388399.clusters.proteins.v11.5.txt",
		        "sequence_path": "388399.protein.sequences.v11.5.fa",
		        "enrichment_path": "388399.protein.enrichment.terms.v11.5.txt",
		        "info_path": "388399.protein.info.v11.5.txt",
		        "node_list_path": "388399.cluster.nodes.v11.5.txt",
		        "edge_list_path": "388399.protein.cluster.v11.5.txt"
		    }
		]
    )()

def OmnitrophicaWor2BacteriumRifcsplowo212Full6316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RIFCSPLOWO2_12_FULL_63_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212Full6316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1801871.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1801871.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1801871.clusters.proteins.v11.5.txt",
		        "sequence_path": "1801871.protein.sequences.v11.5.fa",
		        "enrichment_path": "1801871.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1801871.protein.info.v11.5.txt",
		        "node_list_path": "1801871.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1801871.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FulvivirgaImtechensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Fulvivirga imtechensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FulvivirgaImtechensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1237149.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1237149.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1237149.clusters.proteins.v11.5.txt",
		        "sequence_path": "1237149.protein.sequences.v11.5.fa",
		        "enrichment_path": "1237149.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1237149.protein.info.v11.5.txt",
		        "node_list_path": "1237149.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1237149.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StappiaIndica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Stappia indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StappiaIndica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "538381.protein.sequences.v11.5.fa",
		        "enrichment_path": "538381.protein.enrichment.terms.v11.5.txt",
		        "info_path": "538381.protein.info.v11.5.txt",
		        "node_list_path": "538381.protein.complete.v11.5.txt"
		    }
		]
    )()

def Sar86ClusterBacteriumSar86a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium SAR86A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "Sar86ClusterBacteriumSar86a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123866.protein.info.v11.5.txt",
		        "node_list_path": "1123866.protein.complete.v11.5.txt"
		    }
		]
    )()

def TreponemaSpCetp13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Treponema sp. CETP13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaSpCetp13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1908540.protein.sequences.v11.5.fa",
		        "enrichment_path": "1908540.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1908540.protein.info.v11.5.txt",
		        "node_list_path": "1908540.protein.complete.v11.5.txt"
		    }
		]
    )()

def NiastellaViciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Niastella vici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NiastellaViciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703345.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703345.protein.info.v11.5.txt",
		        "node_list_path": "1703345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24721Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_47_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24721Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618843.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618843.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618843.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618843.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618843.protein.info.v11.5.txt",
		        "node_list_path": "1618843.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618843.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WilliamwhitmaniaTaraxaciCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Williamwhitmania taraxaci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WilliamwhitmaniaTaraxaciCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1640674.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1640674.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1640674.clusters.proteins.v11.5.txt",
		        "sequence_path": "1640674.protein.sequences.v11.5.fa",
		        "enrichment_path": "1640674.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1640674.protein.info.v11.5.txt",
		        "node_list_path": "1640674.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1640674.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TreponemaBrennaborenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema brennaborense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TreponemaBrennaborenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "906968.clusters.info.v11.5.txt",
		        "cluster_tree_path": "906968.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "906968.clusters.proteins.v11.5.txt",
		        "sequence_path": "906968.protein.sequences.v11.5.fa",
		        "enrichment_path": "906968.protein.enrichment.terms.v11.5.txt",
		        "info_path": "906968.protein.info.v11.5.txt",
		        "node_list_path": "906968.cluster.nodes.v11.5.txt",
		        "edge_list_path": "906968.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DesulfovibrioLongusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio longus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfovibrioLongusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121456.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121456.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121456.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121456.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121456.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121456.protein.info.v11.5.txt",
		        "node_list_path": "1121456.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121456.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedobacterSpR2019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter sp. R2019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedobacterSpR2019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1270196.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1270196.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1270196.clusters.proteins.v11.5.txt",
		        "sequence_path": "1270196.protein.sequences.v11.5.fa",
		        "enrichment_path": "1270196.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1270196.protein.info.v11.5.txt",
		        "node_list_path": "1270196.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1270196.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingobacterialesBacterium5039Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 50-39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacterialesBacterium5039Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1895841.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1895841.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1895841.clusters.proteins.v11.5.txt",
		        "sequence_path": "1895841.protein.sequences.v11.5.fa",
		        "enrichment_path": "1895841.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1895841.protein.info.v11.5.txt",
		        "node_list_path": "1895841.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1895841.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasPoae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas poae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasPoae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1282356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1282356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1282356.protein.info.v11.5.txt",
		        "node_list_path": "1282356.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanopyrusKandleriAv19(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanopyrus kandleri AV19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanopyrusKandleriAv19", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "190192.protein.sequences.v11.5.fa",
		        "enrichment_path": "190192.protein.enrichment.terms.v11.5.txt",
		        "info_path": "190192.protein.info.v11.5.txt",
		        "node_list_path": "190192.protein.complete.v11.5.txt"
		    }
		]
    )()

def CroceitaleaDokdonensisDokdo023Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Croceitalea dokdonensis DOKDO 023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CroceitaleaDokdonensisDokdo023Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1300341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1300341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1300341.clusters.proteins.v11.5.txt",
		        "sequence_path": "1300341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300341.protein.info.v11.5.txt",
		        "node_list_path": "1300341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1300341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthobacterSp126(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthobacter sp. 126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthobacterSp126", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1131814.protein.sequences.v11.5.fa",
		        "enrichment_path": "1131814.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1131814.protein.info.v11.5.txt",
		        "node_list_path": "1131814.protein.complete.v11.5.txt"
		    }
		]
    )()

def ZetaproteobacteriaBacteriumCg10255237(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_55_237 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ZetaproteobacteriaBacteriumCg10255237", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805428.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805428.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805428.protein.info.v11.5.txt",
		        "node_list_path": "1805428.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumMedpe(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MedPE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumMedpe", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1860093.protein.sequences.v11.5.fa",
		        "enrichment_path": "1860093.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1860093.protein.info.v11.5.txt",
		        "node_list_path": "1860093.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitrobacterKoseriAtccBaa895(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter koseri ATCC BAA-895 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitrobacterKoseriAtccBaa895", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "290338.protein.sequences.v11.5.fa",
		        "enrichment_path": "290338.protein.enrichment.terms.v11.5.txt",
		        "info_path": "290338.protein.info.v11.5.txt",
		        "node_list_path": "290338.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalmonellaEntericaSubspSalamaeSerovar56Z10ENXStr136973(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. salamae serovar 56:z10:e,n,x str. 1369-73 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalmonellaEntericaSubspSalamaeSerovar56Z10ENXStr136973", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1243604.protein.sequences.v11.5.fa",
		        "enrichment_path": "1243604.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1243604.protein.info.v11.5.txt",
		        "node_list_path": "1243604.protein.complete.v11.5.txt"
		    }
		]
    )()

def AerococcusViridansAtcc11563Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus viridans ATCC11563 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AerococcusViridansAtcc11563Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "655812.clusters.info.v11.5.txt",
		        "cluster_tree_path": "655812.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "655812.clusters.proteins.v11.5.txt",
		        "sequence_path": "655812.protein.sequences.v11.5.fa",
		        "enrichment_path": "655812.protein.enrichment.terms.v11.5.txt",
		        "info_path": "655812.protein.info.v11.5.txt",
		        "node_list_path": "655812.cluster.nodes.v11.5.txt",
		        "edge_list_path": "655812.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethyloteneraMobilisJlw8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera mobilis JLW8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethyloteneraMobilisJlw8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "583345.protein.sequences.v11.5.fa",
		        "enrichment_path": "583345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "583345.protein.info.v11.5.txt",
		        "node_list_path": "583345.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptococcusAnginosusC1051(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus C1051 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAnginosusC1051", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "862970.protein.sequences.v11.5.fa",
		        "enrichment_path": "862970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "862970.protein.info.v11.5.txt",
		        "node_list_path": "862970.protein.complete.v11.5.txt"
		    }
		]
    )()

def CycloclasticusSpSymbiontOfPoeciloscleridaSpNCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Poecilosclerida sp. N Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CycloclasticusSpSymbiontOfPoeciloscleridaSpNCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1840472.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1840472.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1840472.clusters.proteins.v11.5.txt",
		        "sequence_path": "1840472.protein.sequences.v11.5.fa",
		        "enrichment_path": "1840472.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1840472.protein.info.v11.5.txt",
		        "node_list_path": "1840472.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1840472.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ProchlorococcusSpRs01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. RS01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ProchlorococcusSpRs01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1924286.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1924286.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1924286.clusters.proteins.v11.5.txt",
		        "sequence_path": "1924286.protein.sequences.v11.5.fa",
		        "enrichment_path": "1924286.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1924286.protein.info.v11.5.txt",
		        "node_list_path": "1924286.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1924286.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpNfr07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpNfr07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566262.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566262.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566262.protein.info.v11.5.txt",
		        "node_list_path": "1566262.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuricibacterSanguinisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Turicibacter sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuricibacterSanguinisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "702450.clusters.info.v11.5.txt",
		        "cluster_tree_path": "702450.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "702450.clusters.proteins.v11.5.txt",
		        "sequence_path": "702450.protein.sequences.v11.5.fa",
		        "enrichment_path": "702450.protein.enrichment.terms.v11.5.txt",
		        "info_path": "702450.protein.info.v11.5.txt",
		        "node_list_path": "702450.cluster.nodes.v11.5.txt",
		        "edge_list_path": "702450.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycolicibacterMinnesotensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacter minnesotensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycolicibacterMinnesotensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118379.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118379.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118379.protein.info.v11.5.txt",
		        "node_list_path": "1118379.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingobacteriumSpAccc05744Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. ACCC05744 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingobacteriumSpAccc05744Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1229276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1229276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1229276.clusters.proteins.v11.5.txt",
		        "sequence_path": "1229276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1229276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1229276.protein.info.v11.5.txt",
		        "node_list_path": "1229276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1229276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudonocardiaAutotrophica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia autotrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudonocardiaAutotrophica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "2074.protein.sequences.v11.5.fa",
		        "enrichment_path": "2074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2074.protein.info.v11.5.txt",
		        "node_list_path": "2074.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethylophagaFrappieriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophaga frappieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethylophagaFrappieriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "754477.clusters.info.v11.5.txt",
		        "cluster_tree_path": "754477.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "754477.clusters.proteins.v11.5.txt",
		        "sequence_path": "754477.protein.sequences.v11.5.fa",
		        "enrichment_path": "754477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "754477.protein.info.v11.5.txt",
		        "node_list_path": "754477.cluster.nodes.v11.5.txt",
		        "edge_list_path": "754477.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichurisTrichiura(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Trichuris trichiura graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichurisTrichiura", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "36087.protein.sequences.v11.5.fa",
		        "enrichment_path": "36087.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36087.protein.info.v11.5.txt",
		        "node_list_path": "36087.protein.complete.v11.5.txt"
		    }
		]
    )()

def HaliangiumOchraceumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Haliangium ochraceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HaliangiumOchraceumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "502025.clusters.info.v11.5.txt",
		        "cluster_tree_path": "502025.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "502025.clusters.proteins.v11.5.txt",
		        "sequence_path": "502025.protein.sequences.v11.5.fa",
		        "enrichment_path": "502025.protein.enrichment.terms.v11.5.txt",
		        "info_path": "502025.protein.info.v11.5.txt",
		        "node_list_path": "502025.cluster.nodes.v11.5.txt",
		        "edge_list_path": "502025.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SelenomonasArtemidisF0399(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas artemidis F0399 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SelenomonasArtemidisF0399", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "749551.protein.sequences.v11.5.fa",
		        "enrichment_path": "749551.protein.enrichment.terms.v11.5.txt",
		        "info_path": "749551.protein.info.v11.5.txt",
		        "node_list_path": "749551.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThaueraButanivoransNbrc103042(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thauera butanivorans NBRC 103042 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraButanivoransNbrc103042", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1219356.protein.sequences.v11.5.fa",
		        "enrichment_path": "1219356.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1219356.protein.info.v11.5.txt",
		        "node_list_path": "1219356.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParapedobacterIndicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parapedobacter indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParapedobacterIndicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1477437.protein.sequences.v11.5.fa",
		        "enrichment_path": "1477437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1477437.protein.info.v11.5.txt",
		        "node_list_path": "1477437.protein.complete.v11.5.txt"
		    }
		]
    )()

def LachnospiraceaeBacterium2146faa(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 2146FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LachnospiraceaeBacterium2146faa", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "742723.protein.sequences.v11.5.fa",
		        "enrichment_path": "742723.protein.enrichment.terms.v11.5.txt",
		        "info_path": "742723.protein.info.v11.5.txt",
		        "node_list_path": "742723.protein.complete.v11.5.txt"
		    }
		]
    )()

def LegionellaRubrilucensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella rubrilucens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LegionellaRubrilucensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "458.clusters.info.v11.5.txt",
		        "cluster_tree_path": "458.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "458.clusters.proteins.v11.5.txt",
		        "sequence_path": "458.protein.sequences.v11.5.fa",
		        "enrichment_path": "458.protein.enrichment.terms.v11.5.txt",
		        "info_path": "458.protein.info.v11.5.txt",
		        "node_list_path": "458.cluster.nodes.v11.5.txt",
		        "edge_list_path": "458.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusKoreensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusKoreensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "284581.protein.sequences.v11.5.fa",
		        "enrichment_path": "284581.protein.enrichment.terms.v11.5.txt",
		        "info_path": "284581.protein.info.v11.5.txt",
		        "node_list_path": "284581.protein.complete.v11.5.txt"
		    }
		]
    )()

def AtribacteriaBacterium34128Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Atribacteria bacterium 34_128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AtribacteriaBacterium34128Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1635291.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1635291.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1635291.clusters.proteins.v11.5.txt",
		        "sequence_path": "1635291.protein.sequences.v11.5.fa",
		        "enrichment_path": "1635291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1635291.protein.info.v11.5.txt",
		        "node_list_path": "1635291.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1635291.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumCg23050142Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium CG2_30_50_142 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumCg23050142Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803498.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803498.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803498.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803498.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803498.protein.info.v11.5.txt",
		        "node_list_path": "1803498.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803498.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusBrocadiaSpUtamx2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sp. UTAMX2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusBrocadiaSpUtamx2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1961114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1961114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1961114.clusters.proteins.v11.5.txt",
		        "sequence_path": "1961114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1961114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1961114.protein.info.v11.5.txt",
		        "node_list_path": "1961114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1961114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumCavendishiiDsm21758(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cavendishii DSM 21758 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumCavendishiiDsm21758", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121302.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121302.protein.info.v11.5.txt",
		        "node_list_path": "1121302.protein.complete.v11.5.txt"
		    }
		]
    )()

def DipodomysOrdiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dipodomys ordii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DipodomysOrdiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "10020.clusters.info.v11.5.txt",
		        "cluster_tree_path": "10020.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "10020.clusters.proteins.v11.5.txt",
		        "sequence_path": "10020.protein.sequences.v11.5.fa",
		        "enrichment_path": "10020.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10020.protein.info.v11.5.txt",
		        "node_list_path": "10020.cluster.nodes.v11.5.txt",
		        "edge_list_path": "10020.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DevosiaGeojensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Devosia geojensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DevosiaGeojensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "443610.protein.sequences.v11.5.fa",
		        "enrichment_path": "443610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "443610.protein.info.v11.5.txt",
		        "node_list_path": "443610.protein.complete.v11.5.txt"
		    }
		]
    )()

def HahellaChejuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hahella chejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HahellaChejuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "349521.clusters.info.v11.5.txt",
		        "cluster_tree_path": "349521.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "349521.clusters.proteins.v11.5.txt",
		        "sequence_path": "349521.protein.sequences.v11.5.fa",
		        "enrichment_path": "349521.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349521.protein.info.v11.5.txt",
		        "node_list_path": "349521.cluster.nodes.v11.5.txt",
		        "edge_list_path": "349521.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TessaracoccusOleiagriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus oleiagri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusOleiagriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "686624.clusters.info.v11.5.txt",
		        "cluster_tree_path": "686624.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "686624.clusters.proteins.v11.5.txt",
		        "sequence_path": "686624.protein.sequences.v11.5.fa",
		        "enrichment_path": "686624.protein.enrichment.terms.v11.5.txt",
		        "info_path": "686624.protein.info.v11.5.txt",
		        "node_list_path": "686624.cluster.nodes.v11.5.txt",
		        "edge_list_path": "686624.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumKetosireducensCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium ketosireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumKetosireducensCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "92835.clusters.info.v11.5.txt",
		        "cluster_tree_path": "92835.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "92835.clusters.proteins.v11.5.txt",
		        "sequence_path": "92835.protein.sequences.v11.5.fa",
		        "enrichment_path": "92835.protein.enrichment.terms.v11.5.txt",
		        "info_path": "92835.protein.info.v11.5.txt",
		        "node_list_path": "92835.cluster.nodes.v11.5.txt",
		        "edge_list_path": "92835.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterMedellinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter medellinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterMedellinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "634177.protein.sequences.v11.5.fa",
		        "enrichment_path": "634177.protein.enrichment.terms.v11.5.txt",
		        "info_path": "634177.protein.info.v11.5.txt",
		        "node_list_path": "634177.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinomycesCardiffensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces cardiffensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesCardiffensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888050.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888050.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888050.clusters.proteins.v11.5.txt",
		        "sequence_path": "888050.protein.sequences.v11.5.fa",
		        "enrichment_path": "888050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888050.protein.info.v11.5.txt",
		        "node_list_path": "888050.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888050.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSaccharophilumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium saccharophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSaccharophilumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "29534.clusters.info.v11.5.txt",
		        "cluster_tree_path": "29534.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "29534.clusters.proteins.v11.5.txt",
		        "sequence_path": "29534.protein.sequences.v11.5.fa",
		        "enrichment_path": "29534.protein.enrichment.terms.v11.5.txt",
		        "info_path": "29534.protein.info.v11.5.txt",
		        "node_list_path": "29534.cluster.nodes.v11.5.txt",
		        "edge_list_path": "29534.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumSg830Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium SG8_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumSg830Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1703404.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1703404.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1703404.clusters.proteins.v11.5.txt",
		        "sequence_path": "1703404.protein.sequences.v11.5.fa",
		        "enrichment_path": "1703404.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1703404.protein.info.v11.5.txt",
		        "node_list_path": "1703404.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1703404.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5520(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_55_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5520", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1798497.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798497.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798497.protein.info.v11.5.txt",
		        "node_list_path": "1798497.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls1777Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS1777 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls1777Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463887.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463887.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463887.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463887.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463887.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463887.protein.info.v11.5.txt",
		        "node_list_path": "1463887.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463887.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpKc8(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. KC8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpKc8", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1030157.protein.sequences.v11.5.fa",
		        "enrichment_path": "1030157.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1030157.protein.info.v11.5.txt",
		        "node_list_path": "1030157.protein.complete.v11.5.txt"
		    }
		]
    )()

def CruoricaptorIgnavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cruoricaptor ignavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CruoricaptorIgnavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118202.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118202.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118202.protein.info.v11.5.txt",
		        "node_list_path": "1118202.protein.complete.v11.5.txt"
		    }
		]
    )()

def TessaracoccusMassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusMassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1522311.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1522311.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1522311.clusters.proteins.v11.5.txt",
		        "sequence_path": "1522311.protein.sequences.v11.5.fa",
		        "enrichment_path": "1522311.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1522311.protein.info.v11.5.txt",
		        "node_list_path": "1522311.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1522311.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TepidiphilusMargaritifer(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tepidiphilus margaritifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TepidiphilusMargaritifer", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123354.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123354.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123354.protein.info.v11.5.txt",
		        "node_list_path": "1123354.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusNomurabacteriaBacteriumGw2011Gwc23941(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWC2_39_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwc23941", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618754.protein.info.v11.5.txt",
		        "node_list_path": "1618754.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuberMelanosporum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Tuber melanosporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuberMelanosporum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "39416.protein.sequences.v11.5.fa",
		        "enrichment_path": "39416.protein.enrichment.terms.v11.5.txt",
		        "info_path": "39416.protein.info.v11.5.txt",
		        "node_list_path": "39416.protein.complete.v11.5.txt"
		    }
		]
    )()

def NitrosococcusHalophilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosococcus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NitrosococcusHalophilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "472759.clusters.info.v11.5.txt",
		        "cluster_tree_path": "472759.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "472759.clusters.proteins.v11.5.txt",
		        "sequence_path": "472759.protein.sequences.v11.5.fa",
		        "enrichment_path": "472759.protein.enrichment.terms.v11.5.txt",
		        "info_path": "472759.protein.info.v11.5.txt",
		        "node_list_path": "472759.cluster.nodes.v11.5.txt",
		        "edge_list_path": "472759.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlgoriphagusSpA40Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus sp. A40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlgoriphagusSpA40Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1945863.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1945863.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1945863.clusters.proteins.v11.5.txt",
		        "sequence_path": "1945863.protein.sequences.v11.5.fa",
		        "enrichment_path": "1945863.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1945863.protein.info.v11.5.txt",
		        "node_list_path": "1945863.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1945863.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StaphylococcusEpidermidisAtcc12228(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis ATCC12228 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StaphylococcusEpidermidisAtcc12228", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "176280.protein.sequences.v11.5.fa",
		        "enrichment_path": "176280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "176280.protein.info.v11.5.txt",
		        "node_list_path": "176280.protein.complete.v11.5.txt"
		    }
		]
    )()

def PiromycesFinnis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Piromyces finnis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PiromycesFinnis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1754191.protein.sequences.v11.5.fa",
		        "enrichment_path": "1754191.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1754191.protein.info.v11.5.txt",
		        "node_list_path": "1754191.protein.complete.v11.5.txt"
		    }
		]
    )()

def GeobacillusJurassicusNbrc107829Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus jurassicus NBRC 107829 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacillusJurassicusNbrc107829Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1223502.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1223502.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1223502.clusters.proteins.v11.5.txt",
		        "sequence_path": "1223502.protein.sequences.v11.5.fa",
		        "enrichment_path": "1223502.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1223502.protein.info.v11.5.txt",
		        "node_list_path": "1223502.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1223502.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GeobacterLovleyi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter lovleyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GeobacterLovleyi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398767.protein.sequences.v11.5.fa",
		        "enrichment_path": "398767.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398767.protein.info.v11.5.txt",
		        "node_list_path": "398767.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusVarians(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus varians graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusVarians", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1145276.protein.sequences.v11.5.fa",
		        "enrichment_path": "1145276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1145276.protein.info.v11.5.txt",
		        "node_list_path": "1145276.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpongiibacterTropicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Spongiibacter tropicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpongiibacterTropicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123279.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123279.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123279.protein.info.v11.5.txt",
		        "node_list_path": "1123279.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSp85200251057Sch5723018Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 852002-51057_SCH5723018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSp85200251057Sch5723018Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1834094.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1834094.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1834094.clusters.proteins.v11.5.txt",
		        "sequence_path": "1834094.protein.sequences.v11.5.fa",
		        "enrichment_path": "1834094.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1834094.protein.info.v11.5.txt",
		        "node_list_path": "1834094.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1834094.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BrevundimonasSpGw460121014Lb2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas sp. GW460-12-10-14-LB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrevundimonasSpGw460121014Lb2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1827469.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1827469.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1827469.clusters.proteins.v11.5.txt",
		        "sequence_path": "1827469.protein.sequences.v11.5.fa",
		        "enrichment_path": "1827469.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1827469.protein.info.v11.5.txt",
		        "node_list_path": "1827469.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1827469.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CorynebacteriumAtypicumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium atypicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CorynebacteriumAtypicumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "191610.clusters.info.v11.5.txt",
		        "cluster_tree_path": "191610.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "191610.clusters.proteins.v11.5.txt",
		        "sequence_path": "191610.protein.sequences.v11.5.fa",
		        "enrichment_path": "191610.protein.enrichment.terms.v11.5.txt",
		        "info_path": "191610.protein.info.v11.5.txt",
		        "node_list_path": "191610.cluster.nodes.v11.5.txt",
		        "edge_list_path": "191610.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ElizabethkingiaAnophelis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Elizabethkingia anophelis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ElizabethkingiaAnophelis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1338011.protein.sequences.v11.5.fa",
		        "enrichment_path": "1338011.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1338011.protein.info.v11.5.txt",
		        "node_list_path": "1338011.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSpNrrls646Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS646 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSpNrrls646Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1463917.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1463917.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1463917.clusters.proteins.v11.5.txt",
		        "sequence_path": "1463917.protein.sequences.v11.5.fa",
		        "enrichment_path": "1463917.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1463917.protein.info.v11.5.txt",
		        "node_list_path": "1463917.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1463917.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanidioschyzonMerolaeStrain10d(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanidioschyzon merolae strain 10D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanidioschyzonMerolaeStrain10d", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "280699.protein.sequences.v11.5.fa",
		        "enrichment_path": "280699.protein.enrichment.terms.v11.5.txt",
		        "info_path": "280699.protein.info.v11.5.txt",
		        "node_list_path": "280699.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalogranumRubrum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halogranum rubrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalogranumRubrum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553466.protein.sequences.v11.5.fa",
		        "enrichment_path": "553466.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553466.protein.info.v11.5.txt",
		        "node_list_path": "553466.protein.complete.v11.5.txt"
		    }
		]
    )()

def PantoeaSpSc1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. Sc1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PantoeaSpSc1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "593105.protein.sequences.v11.5.fa",
		        "enrichment_path": "593105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "593105.protein.info.v11.5.txt",
		        "node_list_path": "593105.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpCf394Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF394 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpCf394Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1500304.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1500304.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1500304.clusters.proteins.v11.5.txt",
		        "sequence_path": "1500304.protein.sequences.v11.5.fa",
		        "enrichment_path": "1500304.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1500304.protein.info.v11.5.txt",
		        "node_list_path": "1500304.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1500304.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TrichoplaxSpH2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoplax sp. H2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrichoplaxSpH2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "287889.clusters.info.v11.5.txt",
		        "cluster_tree_path": "287889.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "287889.clusters.proteins.v11.5.txt",
		        "sequence_path": "287889.protein.sequences.v11.5.fa",
		        "enrichment_path": "287889.protein.enrichment.terms.v11.5.txt",
		        "info_path": "287889.protein.info.v11.5.txt",
		        "node_list_path": "287889.cluster.nodes.v11.5.txt",
		        "edge_list_path": "287889.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterHaemolyticus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter haemolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterHaemolyticus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1331660.protein.sequences.v11.5.fa",
		        "enrichment_path": "1331660.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1331660.protein.info.v11.5.txt",
		        "node_list_path": "1331660.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArachidicoccusSpBs20Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Arachidicoccus sp. BS20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArachidicoccusSpBs20Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1850526.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1850526.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1850526.clusters.proteins.v11.5.txt",
		        "sequence_path": "1850526.protein.sequences.v11.5.fa",
		        "enrichment_path": "1850526.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1850526.protein.info.v11.5.txt",
		        "node_list_path": "1850526.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1850526.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriNf13Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri NF13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriNf13Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1212548.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1212548.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1212548.clusters.proteins.v11.5.txt",
		        "sequence_path": "1212548.protein.sequences.v11.5.fa",
		        "enrichment_path": "1212548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1212548.protein.info.v11.5.txt",
		        "node_list_path": "1212548.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1212548.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumGinsengisoliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumGinsengisoliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "400772.clusters.info.v11.5.txt",
		        "cluster_tree_path": "400772.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "400772.clusters.proteins.v11.5.txt",
		        "sequence_path": "400772.protein.sequences.v11.5.fa",
		        "enrichment_path": "400772.protein.enrichment.terms.v11.5.txt",
		        "info_path": "400772.protein.info.v11.5.txt",
		        "node_list_path": "400772.cluster.nodes.v11.5.txt",
		        "edge_list_path": "400772.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DiaphorobacterSpJ551(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Diaphorobacter sp. J5-51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DiaphorobacterSpJ551", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "680496.protein.sequences.v11.5.fa",
		        "enrichment_path": "680496.protein.enrichment.terms.v11.5.txt",
		        "info_path": "680496.protein.info.v11.5.txt",
		        "node_list_path": "680496.protein.complete.v11.5.txt"
		    }
		]
    )()

def BavariicoccusSeileriCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bavariicoccus seileri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BavariicoccusSeileriCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121105.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121105.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121105.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121105.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121105.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121105.protein.info.v11.5.txt",
		        "node_list_path": "1121105.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121105.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusThoraltensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus thoraltensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusThoraltensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1123318.protein.sequences.v11.5.fa",
		        "enrichment_path": "1123318.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1123318.protein.info.v11.5.txt",
		        "node_list_path": "1123318.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusSpWkb10Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sp. wkB10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusSpWkb10Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1545701.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1545701.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1545701.clusters.proteins.v11.5.txt",
		        "sequence_path": "1545701.protein.sequences.v11.5.fa",
		        "enrichment_path": "1545701.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1545701.protein.info.v11.5.txt",
		        "node_list_path": "1545701.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1545701.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MegasphaeraSpBv3c161(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. BV3C161 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MegasphaeraSpBv3c161", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1111454.protein.sequences.v11.5.fa",
		        "enrichment_path": "1111454.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1111454.protein.info.v11.5.txt",
		        "node_list_path": "1111454.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumFimetarium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] fimetarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumFimetarium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "99656.protein.sequences.v11.5.fa",
		        "enrichment_path": "99656.protein.enrichment.terms.v11.5.txt",
		        "info_path": "99656.protein.info.v11.5.txt",
		        "node_list_path": "99656.protein.complete.v11.5.txt"
		    }
		]
    )()

def BurkholderiaMalleiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia mallei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderiaMalleiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "243160.clusters.info.v11.5.txt",
		        "cluster_tree_path": "243160.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "243160.clusters.proteins.v11.5.txt",
		        "sequence_path": "243160.protein.sequences.v11.5.fa",
		        "enrichment_path": "243160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "243160.protein.info.v11.5.txt",
		        "node_list_path": "243160.cluster.nodes.v11.5.txt",
		        "edge_list_path": "243160.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThermacetogeniumPhaeum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermacetogenium phaeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermacetogeniumPhaeum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1089553.protein.sequences.v11.5.fa",
		        "enrichment_path": "1089553.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1089553.protein.info.v11.5.txt",
		        "node_list_path": "1089553.protein.complete.v11.5.txt"
		    }
		]
    )()

def PelobacterCarbinolicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter carbinolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PelobacterCarbinolicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "338963.protein.sequences.v11.5.fa",
		        "enrichment_path": "338963.protein.enrichment.terms.v11.5.txt",
		        "info_path": "338963.protein.info.v11.5.txt",
		        "node_list_path": "338963.protein.complete.v11.5.txt"
		    }
		]
    )()

def KnoelliaFlavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Knoellia flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KnoelliaFlavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1385518.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1385518.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1385518.clusters.proteins.v11.5.txt",
		        "sequence_path": "1385518.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385518.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385518.protein.info.v11.5.txt",
		        "node_list_path": "1385518.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1385518.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusJorgensenbacteriaBacteriumGw2011Gwb15010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GW2011_GWB1_50_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGw2011Gwb15010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1618665.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1618665.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1618665.clusters.proteins.v11.5.txt",
		        "sequence_path": "1618665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618665.protein.info.v11.5.txt",
		        "node_list_path": "1618665.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1618665.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PontibacillusChungwhensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacillus chungwhensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PontibacillusChungwhensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1385513.protein.sequences.v11.5.fa",
		        "enrichment_path": "1385513.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1385513.protein.info.v11.5.txt",
		        "node_list_path": "1385513.protein.complete.v11.5.txt"
		    }
		]
    )()

def MollicutesBacteriumHr2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mollicutes bacterium HR2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MollicutesBacteriumHr2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1541960.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1541960.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1541960.clusters.proteins.v11.5.txt",
		        "sequence_path": "1541960.protein.sequences.v11.5.fa",
		        "enrichment_path": "1541960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1541960.protein.info.v11.5.txt",
		        "node_list_path": "1541960.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1541960.protein.cluster.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumCauenseR2a7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium cauense R2A-7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumCauenseR2a7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1341154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1341154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1341154.protein.info.v11.5.txt",
		        "node_list_path": "1341154.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerocolumnaAminovalerica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerocolumna aminovalerica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerocolumnaAminovalerica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1527.protein.sequences.v11.5.fa",
		        "enrichment_path": "1527.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1527.protein.info.v11.5.txt",
		        "node_list_path": "1527.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterSpUrha0019Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter sp. URHA0019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterSpUrha0019Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1298861.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1298861.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1298861.clusters.proteins.v11.5.txt",
		        "sequence_path": "1298861.protein.sequences.v11.5.fa",
		        "enrichment_path": "1298861.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1298861.protein.info.v11.5.txt",
		        "node_list_path": "1298861.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1298861.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusAquimarinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus aquimarinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusAquimarinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "328396.protein.sequences.v11.5.fa",
		        "enrichment_path": "328396.protein.enrichment.terms.v11.5.txt",
		        "info_path": "328396.protein.info.v11.5.txt",
		        "node_list_path": "328396.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarivitaCryptomonadis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marivita cryptomonadis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarivitaCryptomonadis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "505252.protein.sequences.v11.5.fa",
		        "enrichment_path": "505252.protein.enrichment.terms.v11.5.txt",
		        "info_path": "505252.protein.info.v11.5.txt",
		        "node_list_path": "505252.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfococcusMultivorans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfococcus multivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfococcusMultivorans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121405.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121405.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121405.protein.info.v11.5.txt",
		        "node_list_path": "1121405.protein.complete.v11.5.txt"
		    }
		]
    )()

def BrugiaTimori(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Brugia timori graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BrugiaTimori", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "42155.protein.sequences.v11.5.fa",
		        "enrichment_path": "42155.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42155.protein.info.v11.5.txt",
		        "node_list_path": "42155.protein.complete.v11.5.txt"
		    }
		]
    )()

def CupriavidusNantongensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus nantongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusNantongensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1796606.protein.sequences.v11.5.fa",
		        "enrichment_path": "1796606.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1796606.protein.info.v11.5.txt",
		        "node_list_path": "1796606.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumSpEm1321Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. EM1321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumSpEm1321Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1492738.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1492738.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1492738.clusters.proteins.v11.5.txt",
		        "sequence_path": "1492738.protein.sequences.v11.5.fa",
		        "enrichment_path": "1492738.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1492738.protein.info.v11.5.txt",
		        "node_list_path": "1492738.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1492738.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JannaschiaDonghaensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jannaschia donghaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JannaschiaDonghaensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "420998.protein.sequences.v11.5.fa",
		        "enrichment_path": "420998.protein.enrichment.terms.v11.5.txt",
		        "info_path": "420998.protein.info.v11.5.txt",
		        "node_list_path": "420998.protein.complete.v11.5.txt"
		    }
		]
    )()

def FormosaSpHel133131Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Formosa sp. Hel1_33_131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FormosaSpHel133131Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1336794.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1336794.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1336794.clusters.proteins.v11.5.txt",
		        "sequence_path": "1336794.protein.sequences.v11.5.fa",
		        "enrichment_path": "1336794.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1336794.protein.info.v11.5.txt",
		        "node_list_path": "1336794.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1336794.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BradyrhizobiumElkaniiUsda76(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii USDA76 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BradyrhizobiumElkaniiUsda76", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "398525.protein.sequences.v11.5.fa",
		        "enrichment_path": "398525.protein.enrichment.terms.v11.5.txt",
		        "info_path": "398525.protein.info.v11.5.txt",
		        "node_list_path": "398525.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycoplasmaYeatsiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma yeatsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycoplasmaYeatsiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1188240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1188240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1188240.clusters.proteins.v11.5.txt",
		        "sequence_path": "1188240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1188240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1188240.protein.info.v11.5.txt",
		        "node_list_path": "1188240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1188240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingopyxisMacrogoltabida(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis macrogoltabida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingopyxisMacrogoltabida", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "33050.protein.sequences.v11.5.fa",
		        "enrichment_path": "33050.protein.enrichment.terms.v11.5.txt",
		        "info_path": "33050.protein.info.v11.5.txt",
		        "node_list_path": "33050.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSpIs1742(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1742 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSpIs1742", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1772285.protein.sequences.v11.5.fa",
		        "enrichment_path": "1772285.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1772285.protein.info.v11.5.txt",
		        "node_list_path": "1772285.protein.complete.v11.5.txt"
		    }
		]
    )()

def ActinobacteriaBacteriumRbg166821(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_16_68_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinobacteriaBacteriumRbg166821", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797204.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797204.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797204.protein.info.v11.5.txt",
		        "node_list_path": "1797204.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusSpechtbacteriaBacteriumRifcsphigho212Full3830(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPHIGHO2_12_FULL_38_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsphigho212Full3830", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802160.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802160.protein.info.v11.5.txt",
		        "node_list_path": "1802160.protein.complete.v11.5.txt"
		    }
		]
    )()

def ShewanellaSpEcsmb14101(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. ECSMB14101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ShewanellaSpEcsmb14101", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1565129.protein.sequences.v11.5.fa",
		        "enrichment_path": "1565129.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1565129.protein.info.v11.5.txt",
		        "node_list_path": "1565129.protein.complete.v11.5.txt"
		    }
		]
    )()

def DuganellaSpCf458Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Duganella sp. CF458 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DuganellaSpCf458Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1884368.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1884368.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1884368.clusters.proteins.v11.5.txt",
		        "sequence_path": "1884368.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884368.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884368.protein.info.v11.5.txt",
		        "node_list_path": "1884368.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1884368.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusZambryskibacteriaBacteriumRifoxyd2Full4310(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFOXYD2_FULL_43_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifoxyd2Full4310", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1802782.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802782.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802782.protein.info.v11.5.txt",
		        "node_list_path": "1802782.protein.complete.v11.5.txt"
		    }
		]
    )()

def BlastomycesGilchristiiSlh14081Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces gilchristii SLH14081 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BlastomycesGilchristiiSlh14081Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "559298.clusters.info.v11.5.txt",
		        "cluster_tree_path": "559298.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "559298.clusters.proteins.v11.5.txt",
		        "sequence_path": "559298.protein.sequences.v11.5.fa",
		        "enrichment_path": "559298.protein.enrichment.terms.v11.5.txt",
		        "info_path": "559298.protein.info.v11.5.txt",
		        "node_list_path": "559298.cluster.nodes.v11.5.txt",
		        "edge_list_path": "559298.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PedosphaeraParvulaEllin514Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedosphaera parvula Ellin514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PedosphaeraParvulaEllin514Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "320771.clusters.info.v11.5.txt",
		        "cluster_tree_path": "320771.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "320771.clusters.proteins.v11.5.txt",
		        "sequence_path": "320771.protein.sequences.v11.5.fa",
		        "enrichment_path": "320771.protein.enrichment.terms.v11.5.txt",
		        "info_path": "320771.protein.info.v11.5.txt",
		        "node_list_path": "320771.cluster.nodes.v11.5.txt",
		        "edge_list_path": "320771.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CeleribacterIndicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Celeribacter indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CeleribacterIndicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208324.protein.info.v11.5.txt",
		        "node_list_path": "1208324.protein.complete.v11.5.txt"
		    }
		]
    )()

def WuchereriaBancroftiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wuchereria bancrofti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WuchereriaBancroftiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "6293.clusters.info.v11.5.txt",
		        "cluster_tree_path": "6293.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "6293.clusters.proteins.v11.5.txt",
		        "sequence_path": "6293.protein.sequences.v11.5.fa",
		        "enrichment_path": "6293.protein.enrichment.terms.v11.5.txt",
		        "info_path": "6293.protein.info.v11.5.txt",
		        "node_list_path": "6293.cluster.nodes.v11.5.txt",
		        "edge_list_path": "6293.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HadesarchaeaArchaeonYnp45Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Hadesarchaea archaeon YNP_45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HadesarchaeaArchaeonYnp45Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1776334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1776334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1776334.clusters.proteins.v11.5.txt",
		        "sequence_path": "1776334.protein.sequences.v11.5.fa",
		        "enrichment_path": "1776334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1776334.protein.info.v11.5.txt",
		        "node_list_path": "1776334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1776334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NeisseriaShayeganii871(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria shayeganii 871 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NeisseriaShayeganii871", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1032488.protein.sequences.v11.5.fa",
		        "enrichment_path": "1032488.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1032488.protein.info.v11.5.txt",
		        "node_list_path": "1032488.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysobacterSpA03(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter sp. A03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysobacterSpA03", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1199154.protein.sequences.v11.5.fa",
		        "enrichment_path": "1199154.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1199154.protein.info.v11.5.txt",
		        "node_list_path": "1199154.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacillusCihuensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cihuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusCihuensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1208599.protein.sequences.v11.5.fa",
		        "enrichment_path": "1208599.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1208599.protein.info.v11.5.txt",
		        "node_list_path": "1208599.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobaculaSpTs(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacula sp. TS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobaculaSpTs", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1232437.protein.sequences.v11.5.fa",
		        "enrichment_path": "1232437.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1232437.protein.info.v11.5.txt",
		        "node_list_path": "1232437.protein.complete.v11.5.txt"
		    }
		]
    )()

def LactobacillusFlorumDsm22689Jcm16035(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus florum DSM 22689 JCM 16035 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusFlorumDsm22689Jcm16035", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1423745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423745.protein.info.v11.5.txt",
		        "node_list_path": "1423745.protein.complete.v11.5.txt"
		    }
		]
    )()

def TerrisporobacterOthiniensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Terrisporobacter othiniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TerrisporobacterOthiniensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1577792.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1577792.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1577792.clusters.proteins.v11.5.txt",
		        "sequence_path": "1577792.protein.sequences.v11.5.fa",
		        "enrichment_path": "1577792.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1577792.protein.info.v11.5.txt",
		        "node_list_path": "1577792.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1577792.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YangiaPacificaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Yangia pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YangiaPacificaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "311180.clusters.info.v11.5.txt",
		        "cluster_tree_path": "311180.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "311180.clusters.proteins.v11.5.txt",
		        "sequence_path": "311180.protein.sequences.v11.5.fa",
		        "enrichment_path": "311180.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311180.protein.info.v11.5.txt",
		        "node_list_path": "311180.cluster.nodes.v11.5.txt",
		        "edge_list_path": "311180.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaSpCnq490Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. CNQ490 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaSpCnq490Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1137271.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1137271.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1137271.clusters.proteins.v11.5.txt",
		        "sequence_path": "1137271.protein.sequences.v11.5.fa",
		        "enrichment_path": "1137271.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1137271.protein.info.v11.5.txt",
		        "node_list_path": "1137271.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1137271.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ListeriaAquaticaFslS101188(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria aquatica FSL S10-1188 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaAquaticaFslS101188", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265818.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265818.protein.info.v11.5.txt",
		        "node_list_path": "1265818.protein.complete.v11.5.txt"
		    }
		]
    )()

def OryzaGlaberrima(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oryza glaberrima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OryzaGlaberrima", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "4538.protein.sequences.v11.5.fa",
		        "enrichment_path": "4538.protein.enrichment.terms.v11.5.txt",
		        "info_path": "4538.protein.info.v11.5.txt",
		        "node_list_path": "4538.protein.complete.v11.5.txt"
		    }
		]
    )()

def MycobacteriumSzulgai(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium szulgai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumSzulgai", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1787.protein.sequences.v11.5.fa",
		        "enrichment_path": "1787.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1787.protein.info.v11.5.txt",
		        "node_list_path": "1787.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeifsoniaSpRoot60Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeifsoniaSpRoot60Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736567.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736567.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736567.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736567.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736567.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736567.protein.info.v11.5.txt",
		        "node_list_path": "1736567.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736567.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptococcusAgalactiaeNem316Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae NEM316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptococcusAgalactiaeNem316Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "211110.clusters.info.v11.5.txt",
		        "cluster_tree_path": "211110.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "211110.clusters.proteins.v11.5.txt",
		        "sequence_path": "211110.protein.sequences.v11.5.fa",
		        "enrichment_path": "211110.protein.enrichment.terms.v11.5.txt",
		        "info_path": "211110.protein.info.v11.5.txt",
		        "node_list_path": "211110.cluster.nodes.v11.5.txt",
		        "edge_list_path": "211110.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolaribacterSpKt25b(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. KT25b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolaribacterSpKt25b", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1855336.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855336.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855336.protein.info.v11.5.txt",
		        "node_list_path": "1855336.protein.complete.v11.5.txt"
		    }
		]
    )()

def AnaerostipesHadrus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Anaerostipes hadrus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AnaerostipesHadrus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "649756.protein.sequences.v11.5.fa",
		        "enrichment_path": "649756.protein.enrichment.terms.v11.5.txt",
		        "info_path": "649756.protein.info.v11.5.txt",
		        "node_list_path": "649756.protein.complete.v11.5.txt"
		    }
		]
    )()

def ColletotrichumOrbiculareCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum orbiculare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ColletotrichumOrbiculareCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "5465.clusters.info.v11.5.txt",
		        "cluster_tree_path": "5465.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "5465.clusters.proteins.v11.5.txt",
		        "sequence_path": "5465.protein.sequences.v11.5.fa",
		        "enrichment_path": "5465.protein.enrichment.terms.v11.5.txt",
		        "info_path": "5465.protein.info.v11.5.txt",
		        "node_list_path": "5465.cluster.nodes.v11.5.txt",
		        "edge_list_path": "5465.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudoalteromonasSpOcn003(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. OCN003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudoalteromonasSpOcn003", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1348114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348114.protein.info.v11.5.txt",
		        "node_list_path": "1348114.protein.complete.v11.5.txt"
		    }
		]
    )()

def SpirulinaSubsalsaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirulina subsalsa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SpirulinaSubsalsaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1173029.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1173029.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1173029.clusters.proteins.v11.5.txt",
		        "sequence_path": "1173029.protein.sequences.v11.5.fa",
		        "enrichment_path": "1173029.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1173029.protein.info.v11.5.txt",
		        "node_list_path": "1173029.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1173029.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MicrobacteriumSediminis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobacteriumSediminis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "904291.protein.sequences.v11.5.fa",
		        "enrichment_path": "904291.protein.enrichment.terms.v11.5.txt",
		        "info_path": "904291.protein.info.v11.5.txt",
		        "node_list_path": "904291.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24017(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_40_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24017", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1619047.protein.sequences.v11.5.fa",
		        "enrichment_path": "1619047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1619047.protein.info.v11.5.txt",
		        "node_list_path": "1619047.protein.complete.v11.5.txt"
		    }
		]
    )()

def LitomosoidesSigmodontisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Litomosoides sigmodontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LitomosoidesSigmodontisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "42156.clusters.info.v11.5.txt",
		        "cluster_tree_path": "42156.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "42156.clusters.proteins.v11.5.txt",
		        "sequence_path": "42156.protein.sequences.v11.5.fa",
		        "enrichment_path": "42156.protein.enrichment.terms.v11.5.txt",
		        "info_path": "42156.protein.info.v11.5.txt",
		        "node_list_path": "42156.cluster.nodes.v11.5.txt",
		        "edge_list_path": "42156.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemmatimonadetesBacteriumKbs708(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium KBS708 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemmatimonadetesBacteriumKbs708", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "861299.protein.sequences.v11.5.fa",
		        "enrichment_path": "861299.protein.enrichment.terms.v11.5.txt",
		        "info_path": "861299.protein.info.v11.5.txt",
		        "node_list_path": "861299.protein.complete.v11.5.txt"
		    }
		]
    )()

def LeptospiraAlstoniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira alstonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LeptospiraAlstoniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "28452.clusters.info.v11.5.txt",
		        "cluster_tree_path": "28452.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "28452.clusters.proteins.v11.5.txt",
		        "sequence_path": "28452.protein.sequences.v11.5.fa",
		        "enrichment_path": "28452.protein.enrichment.terms.v11.5.txt",
		        "info_path": "28452.protein.info.v11.5.txt",
		        "node_list_path": "28452.cluster.nodes.v11.5.txt",
		        "edge_list_path": "28452.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThiohalomonasDenitrificans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thiohalomonas denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThiohalomonasDenitrificans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "415747.protein.sequences.v11.5.fa",
		        "enrichment_path": "415747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "415747.protein.info.v11.5.txt",
		        "node_list_path": "415747.protein.complete.v11.5.txt"
		    }
		]
    )()

def BetaproteobacteriaBacteriumRifcsplowo212Full6820(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO2_12_FULL_68_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212Full6820", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797505.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797505.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797505.protein.info.v11.5.txt",
		        "node_list_path": "1797505.protein.complete.v11.5.txt"
		    }
		]
    )()

def PsychrobacillusSpOk028(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacillus sp. OK028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PsychrobacillusSpOk028", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1884359.protein.sequences.v11.5.fa",
		        "enrichment_path": "1884359.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1884359.protein.info.v11.5.txt",
		        "node_list_path": "1884359.protein.complete.v11.5.txt"
		    }
		]
    )()

def TrachymyrmexZetekiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Trachymyrmex zeteki Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TrachymyrmexZetekiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "64791.clusters.info.v11.5.txt",
		        "cluster_tree_path": "64791.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "64791.clusters.proteins.v11.5.txt",
		        "sequence_path": "64791.protein.sequences.v11.5.fa",
		        "enrichment_path": "64791.protein.enrichment.terms.v11.5.txt",
		        "info_path": "64791.protein.info.v11.5.txt",
		        "node_list_path": "64791.cluster.nodes.v11.5.txt",
		        "edge_list_path": "64791.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ErythrobacterCitreusLama915Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter citreus LAMA 915 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErythrobacterCitreusLama915Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1306953.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1306953.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1306953.clusters.proteins.v11.5.txt",
		        "sequence_path": "1306953.protein.sequences.v11.5.fa",
		        "enrichment_path": "1306953.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1306953.protein.info.v11.5.txt",
		        "node_list_path": "1306953.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1306953.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusGastranaerophilalesBacteriumZag111(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium Zag_111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumZag111", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1906167.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906167.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906167.protein.info.v11.5.txt",
		        "node_list_path": "1906167.protein.complete.v11.5.txt"
		    }
		]
    )()

def RhizobiumSpLeaf384(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf384 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhizobiumSpLeaf384", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736358.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736358.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736358.protein.info.v11.5.txt",
		        "node_list_path": "1736358.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarmoricolaAequoreusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marmoricola aequoreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarmoricolaAequoreusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "397278.clusters.info.v11.5.txt",
		        "cluster_tree_path": "397278.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "397278.clusters.proteins.v11.5.txt",
		        "sequence_path": "397278.protein.sequences.v11.5.fa",
		        "enrichment_path": "397278.protein.enrichment.terms.v11.5.txt",
		        "info_path": "397278.protein.info.v11.5.txt",
		        "node_list_path": "397278.cluster.nodes.v11.5.txt",
		        "edge_list_path": "397278.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MethanosarcinaSpMtp4(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina sp. MTP4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanosarcinaSpMtp4", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1434100.protein.sequences.v11.5.fa",
		        "enrichment_path": "1434100.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1434100.protein.info.v11.5.txt",
		        "node_list_path": "1434100.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArsenicicoccusBolidensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arsenicicoccus bolidensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArsenicicoccusBolidensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121017.protein.info.v11.5.txt",
		        "node_list_path": "1121017.protein.complete.v11.5.txt"
		    }
		]
    )()

def MethanohalophilusPortucalensisFdf1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus portucalensis FDF-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MethanohalophilusPortucalensisFdf1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "523843.protein.sequences.v11.5.fa",
		        "enrichment_path": "523843.protein.enrichment.terms.v11.5.txt",
		        "info_path": "523843.protein.info.v11.5.txt",
		        "node_list_path": "523843.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasStutzeriNf13(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri NF13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasStutzeriNf13", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1212548.protein.sequences.v11.5.fa",
		        "enrichment_path": "1212548.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1212548.protein.info.v11.5.txt",
		        "node_list_path": "1212548.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfosporosinusLacusDsm15449Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus lacus DSM 15449 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfosporosinusLacusDsm15449Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121420.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121420.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121420.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121420.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121420.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121420.protein.info.v11.5.txt",
		        "node_list_path": "1121420.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121420.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DyellaJiangningensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyella jiangningensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DyellaJiangningensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1379159.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1379159.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1379159.clusters.proteins.v11.5.txt",
		        "sequence_path": "1379159.protein.sequences.v11.5.fa",
		        "enrichment_path": "1379159.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1379159.protein.info.v11.5.txt",
		        "node_list_path": "1379159.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1379159.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesSpHpa0247Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. HPA0247 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesSpHpa0247Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1203556.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1203556.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1203556.clusters.proteins.v11.5.txt",
		        "sequence_path": "1203556.protein.sequences.v11.5.fa",
		        "enrichment_path": "1203556.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1203556.protein.info.v11.5.txt",
		        "node_list_path": "1203556.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1203556.protein.cluster.v11.5.txt"
		    }
		]
    )()

def XanthomonasBromi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas bromi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasBromi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "56449.protein.sequences.v11.5.fa",
		        "enrichment_path": "56449.protein.enrichment.terms.v11.5.txt",
		        "info_path": "56449.protein.info.v11.5.txt",
		        "node_list_path": "56449.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusWoesebacteriaBacteriumRbg164224Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_42_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164224Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802485.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802485.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802485.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802485.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802485.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802485.protein.info.v11.5.txt",
		        "node_list_path": "1802485.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802485.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusKuenenbacteriaBacteriumRifcsplowo202Full4216Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium RIFCSPLOWO2_02_FULL_42_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumRifcsplowo202Full4216Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798564.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798564.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798564.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798564.protein.info.v11.5.txt",
		        "node_list_path": "1798564.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798564.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanistesCaeruleusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanistes caeruleus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanistesCaeruleusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "156563.clusters.info.v11.5.txt",
		        "cluster_tree_path": "156563.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "156563.clusters.proteins.v11.5.txt",
		        "sequence_path": "156563.protein.sequences.v11.5.fa",
		        "enrichment_path": "156563.protein.enrichment.terms.v11.5.txt",
		        "info_path": "156563.protein.info.v11.5.txt",
		        "node_list_path": "156563.cluster.nodes.v11.5.txt",
		        "edge_list_path": "156563.protein.cluster.v11.5.txt"
		    }
		]
    )()

def KomagataeibacterXylinus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "KomagataeibacterXylinus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1296990.protein.sequences.v11.5.fa",
		        "enrichment_path": "1296990.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1296990.protein.info.v11.5.txt",
		        "node_list_path": "1296990.protein.complete.v11.5.txt"
		    }
		]
    )()

def CampylobacterShowaeRm3277Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter showae RM3277 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CampylobacterShowaeRm3277Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553219.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553219.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553219.clusters.proteins.v11.5.txt",
		        "sequence_path": "553219.protein.sequences.v11.5.fa",
		        "enrichment_path": "553219.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553219.protein.info.v11.5.txt",
		        "node_list_path": "553219.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553219.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusLatescibacterAnaerobiusScgcAaa252E07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Latescibacter anaerobius SCGC AAA252-E07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusLatescibacterAnaerobiusScgcAaa252E07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "910047.protein.sequences.v11.5.fa",
		        "enrichment_path": "910047.protein.enrichment.terms.v11.5.txt",
		        "info_path": "910047.protein.info.v11.5.txt",
		        "node_list_path": "910047.protein.complete.v11.5.txt"
		    }
		]
    )()

def AlbimonasPacificaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Albimonas pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlbimonasPacificaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1114924.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1114924.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1114924.clusters.proteins.v11.5.txt",
		        "sequence_path": "1114924.protein.sequences.v11.5.fa",
		        "enrichment_path": "1114924.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1114924.protein.info.v11.5.txt",
		        "node_list_path": "1114924.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1114924.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GluconobacterMorbifer(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter morbifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GluconobacterMorbifer", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1088869.protein.sequences.v11.5.fa",
		        "enrichment_path": "1088869.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1088869.protein.info.v11.5.txt",
		        "node_list_path": "1088869.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumRifcsplowo212Full4010Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPLOWO2_12_FULL_40_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsplowo212Full4010Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1817745.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1817745.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1817745.clusters.proteins.v11.5.txt",
		        "sequence_path": "1817745.protein.sequences.v11.5.fa",
		        "enrichment_path": "1817745.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1817745.protein.info.v11.5.txt",
		        "node_list_path": "1817745.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1817745.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusSpBJeddCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. B-jedd Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusSpBJeddCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1476857.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1476857.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1476857.clusters.proteins.v11.5.txt",
		        "sequence_path": "1476857.protein.sequences.v11.5.fa",
		        "enrichment_path": "1476857.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1476857.protein.info.v11.5.txt",
		        "node_list_path": "1476857.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1476857.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalococcusHamelinensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halococcus hamelinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalococcusHamelinensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1132509.protein.sequences.v11.5.fa",
		        "enrichment_path": "1132509.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1132509.protein.info.v11.5.txt",
		        "node_list_path": "1132509.protein.complete.v11.5.txt"
		    }
		]
    )()

def NonomuraeaJiangxiensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea jiangxiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NonomuraeaJiangxiensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "633440.clusters.info.v11.5.txt",
		        "cluster_tree_path": "633440.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "633440.clusters.proteins.v11.5.txt",
		        "sequence_path": "633440.protein.sequences.v11.5.fa",
		        "enrichment_path": "633440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "633440.protein.info.v11.5.txt",
		        "node_list_path": "633440.cluster.nodes.v11.5.txt",
		        "edge_list_path": "633440.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MycobacteriumFragae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium fragae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MycobacteriumFragae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1260918.protein.sequences.v11.5.fa",
		        "enrichment_path": "1260918.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1260918.protein.info.v11.5.txt",
		        "node_list_path": "1260918.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasWittichiiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas wittichii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasWittichiiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "392499.clusters.info.v11.5.txt",
		        "cluster_tree_path": "392499.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "392499.clusters.proteins.v11.5.txt",
		        "sequence_path": "392499.protein.sequences.v11.5.fa",
		        "enrichment_path": "392499.protein.enrichment.terms.v11.5.txt",
		        "info_path": "392499.protein.info.v11.5.txt",
		        "node_list_path": "392499.cluster.nodes.v11.5.txt",
		        "edge_list_path": "392499.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SinorhizobiumSaheliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium saheli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SinorhizobiumSaheliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36856.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36856.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36856.clusters.proteins.v11.5.txt",
		        "sequence_path": "36856.protein.sequences.v11.5.fa",
		        "enrichment_path": "36856.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36856.protein.info.v11.5.txt",
		        "node_list_path": "36856.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36856.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsplowo2124711Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO2_12_47_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo2124711Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798301.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798301.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798301.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798301.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798301.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798301.protein.info.v11.5.txt",
		        "node_list_path": "1798301.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798301.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CandidatusUhrbacteriaBacteriumRifoxyb12Full5810Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYB12_FULL_58_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyb12Full5810Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1802418.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1802418.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1802418.clusters.proteins.v11.5.txt",
		        "sequence_path": "1802418.protein.sequences.v11.5.fa",
		        "enrichment_path": "1802418.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1802418.protein.info.v11.5.txt",
		        "node_list_path": "1802418.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1802418.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ActinomycesTangfeifanii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces tangfeifanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ActinomycesTangfeifanii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1912795.protein.sequences.v11.5.fa",
		        "enrichment_path": "1912795.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1912795.protein.info.v11.5.txt",
		        "node_list_path": "1912795.protein.complete.v11.5.txt"
		    }
		]
    )()

def RahnellaAquatilisHx2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rahnella aquatilis HX2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RahnellaAquatilisHx2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1151116.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1151116.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1151116.clusters.proteins.v11.5.txt",
		        "sequence_path": "1151116.protein.sequences.v11.5.fa",
		        "enrichment_path": "1151116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1151116.protein.info.v11.5.txt",
		        "node_list_path": "1151116.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1151116.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpMctg268(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. MCTG268 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpMctg268", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1415754.protein.sequences.v11.5.fa",
		        "enrichment_path": "1415754.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1415754.protein.info.v11.5.txt",
		        "node_list_path": "1415754.protein.complete.v11.5.txt"
		    }
		]
    )()

def CaenorhabditisBrenneri(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Caenorhabditis brenneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaenorhabditisBrenneri", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "135651.protein.sequences.v11.5.fa",
		        "enrichment_path": "135651.protein.enrichment.terms.v11.5.txt",
		        "info_path": "135651.protein.info.v11.5.txt",
		        "node_list_path": "135651.protein.complete.v11.5.txt"
		    }
		]
    )()

def MangrovimonasSpTpbh4Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. TPBH4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MangrovimonasSpTpbh4Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1645914.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1645914.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1645914.clusters.proteins.v11.5.txt",
		        "sequence_path": "1645914.protein.sequences.v11.5.fa",
		        "enrichment_path": "1645914.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1645914.protein.info.v11.5.txt",
		        "node_list_path": "1645914.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1645914.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag964Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:964 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag964Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262848.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262848.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262848.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262848.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262848.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262848.protein.info.v11.5.txt",
		        "node_list_path": "1262848.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262848.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MitsuariaSp7(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mitsuaria sp. 7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MitsuariaSp7", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1658665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1658665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1658665.protein.info.v11.5.txt",
		        "node_list_path": "1658665.protein.complete.v11.5.txt"
		    }
		]
    )()

def PhotobacteriumJeaniiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium jeanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PhotobacteriumJeaniiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "858640.clusters.info.v11.5.txt",
		        "cluster_tree_path": "858640.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "858640.clusters.proteins.v11.5.txt",
		        "sequence_path": "858640.protein.sequences.v11.5.fa",
		        "enrichment_path": "858640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "858640.protein.info.v11.5.txt",
		        "node_list_path": "858640.cluster.nodes.v11.5.txt",
		        "edge_list_path": "858640.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CupriavidusGilardiiCr3Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus gilardii CR3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CupriavidusGilardiiCr3Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1267562.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1267562.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1267562.clusters.proteins.v11.5.txt",
		        "sequence_path": "1267562.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267562.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267562.protein.info.v11.5.txt",
		        "node_list_path": "1267562.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1267562.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AlloactinosynnemaSpL07(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Alloactinosynnema sp. L-07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AlloactinosynnemaSpL07", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1653480.protein.sequences.v11.5.fa",
		        "enrichment_path": "1653480.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1653480.protein.info.v11.5.txt",
		        "node_list_path": "1653480.protein.complete.v11.5.txt"
		    }
		]
    )()

def JanibacterLimosusNbrc16128(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Janibacter limosus NBRC 16128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JanibacterLimosusNbrc16128", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1216970.protein.sequences.v11.5.fa",
		        "enrichment_path": "1216970.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1216970.protein.info.v11.5.txt",
		        "node_list_path": "1216970.protein.complete.v11.5.txt"
		    }
		]
    )()

def ErpetoichthysCalabaricus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Erpetoichthys calabaricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ErpetoichthysCalabaricus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "27687.protein.sequences.v11.5.fa",
		        "enrichment_path": "27687.protein.enrichment.terms.v11.5.txt",
		        "info_path": "27687.protein.info.v11.5.txt",
		        "node_list_path": "27687.protein.complete.v11.5.txt"
		    }
		]
    )()

def TuricellaOtitidis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Turicella otitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TuricellaOtitidis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "883169.protein.sequences.v11.5.fa",
		        "enrichment_path": "883169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "883169.protein.info.v11.5.txt",
		        "node_list_path": "883169.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThioalkalivibrioSpAlj24Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThioalkalivibrioSpAlj24Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "545276.clusters.info.v11.5.txt",
		        "cluster_tree_path": "545276.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "545276.clusters.proteins.v11.5.txt",
		        "sequence_path": "545276.protein.sequences.v11.5.fa",
		        "enrichment_path": "545276.protein.enrichment.terms.v11.5.txt",
		        "info_path": "545276.protein.info.v11.5.txt",
		        "node_list_path": "545276.cluster.nodes.v11.5.txt",
		        "edge_list_path": "545276.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AphanizomenonFlosAquaeUkl13PbCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Aphanizomenon flos-aquae UKL13-PB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AphanizomenonFlosAquaeUkl13PbCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1803587.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1803587.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1803587.clusters.proteins.v11.5.txt",
		        "sequence_path": "1803587.protein.sequences.v11.5.fa",
		        "enrichment_path": "1803587.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1803587.protein.info.v11.5.txt",
		        "node_list_path": "1803587.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1803587.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag710Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag710Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1262833.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1262833.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1262833.clusters.proteins.v11.5.txt",
		        "sequence_path": "1262833.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262833.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262833.protein.info.v11.5.txt",
		        "node_list_path": "1262833.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1262833.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PrevotellaSpKh2c16Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. KH2C16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaSpKh2c16Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1855325.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1855325.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1855325.clusters.proteins.v11.5.txt",
		        "sequence_path": "1855325.protein.sequences.v11.5.fa",
		        "enrichment_path": "1855325.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1855325.protein.info.v11.5.txt",
		        "node_list_path": "1855325.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1855325.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseobacterSpGai101(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. GAI101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseobacterSpGai101", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "391589.protein.sequences.v11.5.fa",
		        "enrichment_path": "391589.protein.enrichment.terms.v11.5.txt",
		        "info_path": "391589.protein.info.v11.5.txt",
		        "node_list_path": "391589.protein.complete.v11.5.txt"
		    }
		]
    )()

def FlavobacteriumDenitrificansDsm15936Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium denitrificans DSM 15936 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FlavobacteriumDenitrificansDsm15936Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121888.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121888.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121888.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121888.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121888.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121888.protein.info.v11.5.txt",
		        "node_list_path": "1121888.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121888.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BacillusTuaregiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus tuaregi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacillusTuaregiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1816695.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1816695.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1816695.clusters.proteins.v11.5.txt",
		        "sequence_path": "1816695.protein.sequences.v11.5.fa",
		        "enrichment_path": "1816695.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1816695.protein.info.v11.5.txt",
		        "node_list_path": "1816695.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1816695.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumGregarium(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium gregarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumGregarium", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1121287.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121287.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121287.protein.info.v11.5.txt",
		        "node_list_path": "1121287.protein.complete.v11.5.txt"
		    }
		]
    )()

def CarlitoSyrichta(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Carlito syrichta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CarlitoSyrichta", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1868482.protein.sequences.v11.5.fa",
		        "enrichment_path": "1868482.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1868482.protein.info.v11.5.txt",
		        "node_list_path": "1868482.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacterium13220cm6619(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 13_2_20CM_66_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacterium13220cm6619", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1805166.protein.sequences.v11.5.fa",
		        "enrichment_path": "1805166.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1805166.protein.info.v11.5.txt",
		        "node_list_path": "1805166.protein.complete.v11.5.txt"
		    }
		]
    )()

def DokdonellaKoreensisDs123(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Dokdonella koreensis DS-123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DokdonellaKoreensisDs123", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1300342.protein.sequences.v11.5.fa",
		        "enrichment_path": "1300342.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1300342.protein.info.v11.5.txt",
		        "node_list_path": "1300342.protein.complete.v11.5.txt"
		    }
		]
    )()

def TaeniaAsiatica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Taenia asiatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TaeniaAsiatica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "60517.protein.sequences.v11.5.fa",
		        "enrichment_path": "60517.protein.enrichment.terms.v11.5.txt",
		        "info_path": "60517.protein.info.v11.5.txt",
		        "node_list_path": "60517.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusItalicusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus italicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusItalicusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "888064.clusters.info.v11.5.txt",
		        "cluster_tree_path": "888064.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "888064.clusters.proteins.v11.5.txt",
		        "sequence_path": "888064.protein.sequences.v11.5.fa",
		        "enrichment_path": "888064.protein.enrichment.terms.v11.5.txt",
		        "info_path": "888064.protein.info.v11.5.txt",
		        "node_list_path": "888064.cluster.nodes.v11.5.txt",
		        "edge_list_path": "888064.protein.cluster.v11.5.txt"
		    }
		]
    )()

def WohlfahrtiimonasPopuliCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas populi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "WohlfahrtiimonasPopuliCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1940240.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1940240.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1940240.clusters.proteins.v11.5.txt",
		        "sequence_path": "1940240.protein.sequences.v11.5.fa",
		        "enrichment_path": "1940240.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1940240.protein.info.v11.5.txt",
		        "node_list_path": "1940240.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1940240.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HydrobacterPenzbergensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Hydrobacter penzbergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HydrobacterPenzbergensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1235997.protein.sequences.v11.5.fa",
		        "enrichment_path": "1235997.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1235997.protein.info.v11.5.txt",
		        "node_list_path": "1235997.protein.complete.v11.5.txt"
		    }
		]
    )()

def GammaproteobacteriaBacteriumRifcsphigho212Full3924Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO2_12_FULL_39_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212Full3924Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1798280.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1798280.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1798280.clusters.proteins.v11.5.txt",
		        "sequence_path": "1798280.protein.sequences.v11.5.fa",
		        "enrichment_path": "1798280.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1798280.protein.info.v11.5.txt",
		        "node_list_path": "1798280.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1798280.protein.cluster.v11.5.txt"
		    }
		]
    )()

def LactobacillusAmylophilusDsm20533Jcm1125Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus amylophilus DSM 20533 JCM 1125 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LactobacillusAmylophilusDsm20533Jcm1125Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1423721.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1423721.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1423721.clusters.proteins.v11.5.txt",
		        "sequence_path": "1423721.protein.sequences.v11.5.fa",
		        "enrichment_path": "1423721.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1423721.protein.info.v11.5.txt",
		        "node_list_path": "1423721.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1423721.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SporothrixSchenckiiAtcc58251(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sporothrix schenckii ATCC 58251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SporothrixSchenckiiAtcc58251", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1391915.protein.sequences.v11.5.fa",
		        "enrichment_path": "1391915.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1391915.protein.info.v11.5.txt",
		        "node_list_path": "1391915.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpLeaf32Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpLeaf32Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736214.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736214.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736214.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736214.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736214.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736214.protein.info.v11.5.txt",
		        "node_list_path": "1736214.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736214.protein.cluster.v11.5.txt"
		    }
		]
    )()

def TessaracoccusSpZs01Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus sp. ZS01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TessaracoccusSpZs01Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906324.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906324.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906324.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906324.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906324.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906324.protein.info.v11.5.txt",
		        "node_list_path": "1906324.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906324.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeromyscusManiculatus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peromyscus maniculatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeromyscusManiculatus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "10042.protein.sequences.v11.5.fa",
		        "enrichment_path": "10042.protein.enrichment.terms.v11.5.txt",
		        "info_path": "10042.protein.info.v11.5.txt",
		        "node_list_path": "10042.protein.complete.v11.5.txt"
		    }
		]
    )()

def NovosphingobiumSpRr217Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Rr 217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NovosphingobiumSpRr217Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "555793.clusters.info.v11.5.txt",
		        "cluster_tree_path": "555793.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "555793.clusters.proteins.v11.5.txt",
		        "sequence_path": "555793.protein.sequences.v11.5.fa",
		        "enrichment_path": "555793.protein.enrichment.terms.v11.5.txt",
		        "info_path": "555793.protein.info.v11.5.txt",
		        "node_list_path": "555793.cluster.nodes.v11.5.txt",
		        "edge_list_path": "555793.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PalaeococcusPacificus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Palaeococcus pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PalaeococcusPacificus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1343739.protein.sequences.v11.5.fa",
		        "enrichment_path": "1343739.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1343739.protein.info.v11.5.txt",
		        "node_list_path": "1343739.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalobacillusDabanensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus dabanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalobacillusDabanensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "240302.clusters.info.v11.5.txt",
		        "cluster_tree_path": "240302.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "240302.clusters.proteins.v11.5.txt",
		        "sequence_path": "240302.protein.sequences.v11.5.fa",
		        "enrichment_path": "240302.protein.enrichment.terms.v11.5.txt",
		        "info_path": "240302.protein.info.v11.5.txt",
		        "node_list_path": "240302.cluster.nodes.v11.5.txt",
		        "edge_list_path": "240302.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnhydrobacterAerosaccusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enhydrobacter aerosaccus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnhydrobacterAerosaccusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "553217.clusters.info.v11.5.txt",
		        "cluster_tree_path": "553217.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "553217.clusters.proteins.v11.5.txt",
		        "sequence_path": "553217.protein.sequences.v11.5.fa",
		        "enrichment_path": "553217.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553217.protein.info.v11.5.txt",
		        "node_list_path": "553217.cluster.nodes.v11.5.txt",
		        "edge_list_path": "553217.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CroceicoccusNaphthovoransCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Croceicoccus naphthovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CroceicoccusNaphthovoransCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1348774.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1348774.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1348774.clusters.proteins.v11.5.txt",
		        "sequence_path": "1348774.protein.sequences.v11.5.fa",
		        "enrichment_path": "1348774.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1348774.protein.info.v11.5.txt",
		        "node_list_path": "1348774.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1348774.protein.cluster.v11.5.txt"
		    }
		]
    )()

def HalopenitusMalekzadehii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Halopenitus malekzadehii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalopenitusMalekzadehii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1267564.protein.sequences.v11.5.fa",
		        "enrichment_path": "1267564.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1267564.protein.info.v11.5.txt",
		        "node_list_path": "1267564.protein.complete.v11.5.txt"
		    }
		]
    )()

def JohnsonellaIgnavaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Johnsonella ignava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JohnsonellaIgnavaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "679200.clusters.info.v11.5.txt",
		        "cluster_tree_path": "679200.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "679200.clusters.proteins.v11.5.txt",
		        "sequence_path": "679200.protein.sequences.v11.5.fa",
		        "enrichment_path": "679200.protein.enrichment.terms.v11.5.txt",
		        "info_path": "679200.protein.info.v11.5.txt",
		        "node_list_path": "679200.cluster.nodes.v11.5.txt",
		        "edge_list_path": "679200.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ClostridiumSpCag167(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:167 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumSpCag167", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1262777.protein.sequences.v11.5.fa",
		        "enrichment_path": "1262777.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1262777.protein.info.v11.5.txt",
		        "node_list_path": "1262777.protein.complete.v11.5.txt"
		    }
		]
    )()

def MicrobulbiferAggregans(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Microbulbifer aggregans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MicrobulbiferAggregans", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1769779.protein.sequences.v11.5.fa",
		        "enrichment_path": "1769779.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1769779.protein.info.v11.5.txt",
		        "node_list_path": "1769779.protein.complete.v11.5.txt"
		    }
		]
    )()

def RickettsiaRickettsii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia rickettsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RickettsiaRickettsii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "452659.protein.sequences.v11.5.fa",
		        "enrichment_path": "452659.protein.enrichment.terms.v11.5.txt",
		        "info_path": "452659.protein.info.v11.5.txt",
		        "node_list_path": "452659.protein.complete.v11.5.txt"
		    }
		]
    )()

def PseudomonasNitroreducensHbp1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens HBP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudomonasNitroreducensHbp1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1437882.protein.sequences.v11.5.fa",
		        "enrichment_path": "1437882.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1437882.protein.info.v11.5.txt",
		        "node_list_path": "1437882.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesGriseorubens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseorubens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesGriseorubens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "66897.protein.sequences.v11.5.fa",
		        "enrichment_path": "66897.protein.enrichment.terms.v11.5.txt",
		        "info_path": "66897.protein.info.v11.5.txt",
		        "node_list_path": "66897.protein.complete.v11.5.txt"
		    }
		]
    )()

def StarkeyaNovellaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Starkeya novella Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StarkeyaNovellaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "639283.clusters.info.v11.5.txt",
		        "cluster_tree_path": "639283.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "639283.clusters.proteins.v11.5.txt",
		        "sequence_path": "639283.protein.sequences.v11.5.fa",
		        "enrichment_path": "639283.protein.enrichment.terms.v11.5.txt",
		        "info_path": "639283.protein.info.v11.5.txt",
		        "node_list_path": "639283.cluster.nodes.v11.5.txt",
		        "edge_list_path": "639283.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PseudovibrioAxinellae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pseudovibrio axinellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PseudovibrioAxinellae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "989403.protein.sequences.v11.5.fa",
		        "enrichment_path": "989403.protein.enrichment.terms.v11.5.txt",
		        "info_path": "989403.protein.info.v11.5.txt",
		        "node_list_path": "989403.protein.complete.v11.5.txt"
		    }
		]
    )()

def LysinibacillusMassiliensis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "LysinibacillusMassiliensis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211035.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211035.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211035.protein.info.v11.5.txt",
		        "node_list_path": "1211035.protein.complete.v11.5.txt"
		    }
		]
    )()

def TatumellaMorbiroseiCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Tatumella morbirosei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "TatumellaMorbiroseiCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "642227.clusters.info.v11.5.txt",
		        "cluster_tree_path": "642227.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "642227.clusters.proteins.v11.5.txt",
		        "sequence_path": "642227.protein.sequences.v11.5.fa",
		        "enrichment_path": "642227.protein.enrichment.terms.v11.5.txt",
		        "info_path": "642227.protein.info.v11.5.txt",
		        "node_list_path": "642227.cluster.nodes.v11.5.txt",
		        "edge_list_path": "642227.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ChitinophagaTerraeKimAndJung2007(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga terrae Kim and Jung 2007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChitinophagaTerraeKimAndJung2007", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "408074.protein.sequences.v11.5.fa",
		        "enrichment_path": "408074.protein.enrichment.terms.v11.5.txt",
		        "info_path": "408074.protein.info.v11.5.txt",
		        "node_list_path": "408074.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusUrinimassiliensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus urinimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusUrinimassiliensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1871017.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1871017.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1871017.clusters.proteins.v11.5.txt",
		        "sequence_path": "1871017.protein.sequences.v11.5.fa",
		        "enrichment_path": "1871017.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1871017.protein.info.v11.5.txt",
		        "node_list_path": "1871017.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1871017.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesHumi(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesHumi", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1428620.protein.sequences.v11.5.fa",
		        "enrichment_path": "1428620.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1428620.protein.info.v11.5.txt",
		        "node_list_path": "1428620.protein.complete.v11.5.txt"
		    }
		]
    )()

def PrevotellaMelaninogenica(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella melaninogenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PrevotellaMelaninogenica", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "553174.protein.sequences.v11.5.fa",
		        "enrichment_path": "553174.protein.enrichment.terms.v11.5.txt",
		        "info_path": "553174.protein.info.v11.5.txt",
		        "node_list_path": "553174.protein.complete.v11.5.txt"
		    }
		]
    )()

def GracilibacillusHalophilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gracilibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GracilibacillusHalophilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1308866.protein.sequences.v11.5.fa",
		        "enrichment_path": "1308866.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1308866.protein.info.v11.5.txt",
		        "node_list_path": "1308866.protein.complete.v11.5.txt"
		    }
		]
    )()

def JatrophaCurcas(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Jatropha curcas graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JatrophaCurcas", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "180498.protein.sequences.v11.5.fa",
		        "enrichment_path": "180498.protein.enrichment.terms.v11.5.txt",
		        "info_path": "180498.protein.info.v11.5.txt",
		        "node_list_path": "180498.protein.complete.v11.5.txt"
		    }
		]
    )()

def ThermotogaProfundaAzm34c06(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga profunda AZM34c06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThermotogaProfundaAzm34c06", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1408160.protein.sequences.v11.5.fa",
		        "enrichment_path": "1408160.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1408160.protein.info.v11.5.txt",
		        "node_list_path": "1408160.protein.complete.v11.5.txt"
		    }
		]
    )()

def FibrobacterSpUwb15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWB15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "FibrobacterSpUwb15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1938898.protein.sequences.v11.5.fa",
		        "enrichment_path": "1938898.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1938898.protein.info.v11.5.txt",
		        "node_list_path": "1938898.protein.complete.v11.5.txt"
		    }
		]
    )()

def StreptomycesSubrutilusCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces subrutilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesSubrutilusCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "36818.clusters.info.v11.5.txt",
		        "cluster_tree_path": "36818.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "36818.clusters.proteins.v11.5.txt",
		        "sequence_path": "36818.protein.sequences.v11.5.fa",
		        "enrichment_path": "36818.protein.enrichment.terms.v11.5.txt",
		        "info_path": "36818.protein.info.v11.5.txt",
		        "node_list_path": "36818.cluster.nodes.v11.5.txt",
		        "edge_list_path": "36818.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PachysolenTannophilusNrrlY2460Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pachysolen tannophilus NRRL Y-2460 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PachysolenTannophilusNrrlY2460Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "669874.clusters.info.v11.5.txt",
		        "cluster_tree_path": "669874.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "669874.clusters.proteins.v11.5.txt",
		        "sequence_path": "669874.protein.sequences.v11.5.fa",
		        "enrichment_path": "669874.protein.enrichment.terms.v11.5.txt",
		        "info_path": "669874.protein.info.v11.5.txt",
		        "node_list_path": "669874.cluster.nodes.v11.5.txt",
		        "edge_list_path": "669874.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CalescamantesBacteriumScgcAaa471M6Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Calescamantes bacterium SCGC AAA471-M6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CalescamantesBacteriumScgcAaa471M6Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1052810.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1052810.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1052810.clusters.proteins.v11.5.txt",
		        "sequence_path": "1052810.protein.sequences.v11.5.fa",
		        "enrichment_path": "1052810.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1052810.protein.info.v11.5.txt",
		        "node_list_path": "1052810.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1052810.protein.cluster.v11.5.txt"
		    }
		]
    )()

def NostocSpMbr210Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Nostoc sp. MBR 210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "NostocSpMbr210Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1881015.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1881015.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1881015.clusters.proteins.v11.5.txt",
		        "sequence_path": "1881015.protein.sequences.v11.5.fa",
		        "enrichment_path": "1881015.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1881015.protein.info.v11.5.txt",
		        "node_list_path": "1881015.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1881015.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CaulobacterSpRoot656Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root656 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CaulobacterSpRoot656Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1736579.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1736579.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1736579.clusters.proteins.v11.5.txt",
		        "sequence_path": "1736579.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736579.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736579.protein.info.v11.5.txt",
		        "node_list_path": "1736579.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1736579.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PolynucleobacterSphagniphilus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter sphagniphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PolynucleobacterSphagniphilus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1743169.protein.sequences.v11.5.fa",
		        "enrichment_path": "1743169.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1743169.protein.info.v11.5.txt",
		        "node_list_path": "1743169.protein.complete.v11.5.txt"
		    }
		]
    )()

def EisenibacterElegansDsm3317Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Eisenibacter elegans DSM 3317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EisenibacterElegansDsm3317Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121902.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121902.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121902.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121902.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121902.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121902.protein.info.v11.5.txt",
		        "node_list_path": "1121902.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121902.protein.cluster.v11.5.txt"
		    }
		]
    )()

def MitsuokellaJalaludinii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Mitsuokella jalaludinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MitsuokellaJalaludinii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1410665.protein.sequences.v11.5.fa",
		        "enrichment_path": "1410665.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1410665.protein.info.v11.5.txt",
		        "node_list_path": "1410665.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumJejuense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium jejuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumJejuense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "445960.protein.sequences.v11.5.fa",
		        "enrichment_path": "445960.protein.enrichment.terms.v11.5.txt",
		        "info_path": "445960.protein.info.v11.5.txt",
		        "node_list_path": "445960.protein.complete.v11.5.txt"
		    }
		]
    )()

def OribacteriumParvum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium parvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "OribacteriumParvum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "796945.protein.sequences.v11.5.fa",
		        "enrichment_path": "796945.protein.enrichment.terms.v11.5.txt",
		        "info_path": "796945.protein.info.v11.5.txt",
		        "node_list_path": "796945.protein.complete.v11.5.txt"
		    }
		]
    )()

def CitreimonasSalinariaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Citreimonas salinaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CitreimonasSalinariaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "321339.clusters.info.v11.5.txt",
		        "cluster_tree_path": "321339.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "321339.clusters.proteins.v11.5.txt",
		        "sequence_path": "321339.protein.sequences.v11.5.fa",
		        "enrichment_path": "321339.protein.enrichment.terms.v11.5.txt",
		        "info_path": "321339.protein.info.v11.5.txt",
		        "node_list_path": "321339.cluster.nodes.v11.5.txt",
		        "edge_list_path": "321339.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AllochromatiumVinosum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Allochromatium vinosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AllochromatiumVinosum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "572477.protein.sequences.v11.5.fa",
		        "enrichment_path": "572477.protein.enrichment.terms.v11.5.txt",
		        "info_path": "572477.protein.info.v11.5.txt",
		        "node_list_path": "572477.protein.complete.v11.5.txt"
		    }
		]
    )()

def ListeriaInnocua(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Listeria innocua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ListeriaInnocua", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "272626.protein.sequences.v11.5.fa",
		        "enrichment_path": "272626.protein.enrichment.terms.v11.5.txt",
		        "info_path": "272626.protein.info.v11.5.txt",
		        "node_list_path": "272626.protein.complete.v11.5.txt"
		    }
		]
    )()

def ClostridiumAnorexicamassiliense(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium anorexicamassiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ClostridiumAnorexicamassiliense", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1211817.protein.sequences.v11.5.fa",
		        "enrichment_path": "1211817.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1211817.protein.info.v11.5.txt",
		        "node_list_path": "1211817.protein.complete.v11.5.txt"
		    }
		]
    )()

def BacteroidetesBacteriumUkl133Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium UKL13-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BacteroidetesBacteriumUkl133Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1690483.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1690483.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1690483.clusters.proteins.v11.5.txt",
		        "sequence_path": "1690483.protein.sequences.v11.5.fa",
		        "enrichment_path": "1690483.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1690483.protein.info.v11.5.txt",
		        "node_list_path": "1690483.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1690483.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcetobacterOrientalis21f2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter orientalis 21F-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcetobacterOrientalis21f2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1231341.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1231341.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1231341.clusters.proteins.v11.5.txt",
		        "sequence_path": "1231341.protein.sequences.v11.5.fa",
		        "enrichment_path": "1231341.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1231341.protein.info.v11.5.txt",
		        "node_list_path": "1231341.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1231341.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PleurocapsaSpPcc7319Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Pleurocapsa sp. PCC7319 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PleurocapsaSpPcc7319Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "118161.clusters.info.v11.5.txt",
		        "cluster_tree_path": "118161.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "118161.clusters.proteins.v11.5.txt",
		        "sequence_path": "118161.protein.sequences.v11.5.fa",
		        "enrichment_path": "118161.protein.enrichment.terms.v11.5.txt",
		        "info_path": "118161.protein.info.v11.5.txt",
		        "node_list_path": "118161.cluster.nodes.v11.5.txt",
		        "edge_list_path": "118161.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BurkholderialesBacteriumRifoxyd12Full5919(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFOXYD12_FULL_59_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BurkholderialesBacteriumRifoxyd12Full5919", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1797574.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797574.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797574.protein.info.v11.5.txt",
		        "node_list_path": "1797574.protein.complete.v11.5.txt"
		    }
		]
    )()

def PirellulaSpShSr6a(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Pirellula sp. SH-Sr6A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PirellulaSpShSr6a", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1632865.protein.sequences.v11.5.fa",
		        "enrichment_path": "1632865.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1632865.protein.info.v11.5.txt",
		        "node_list_path": "1632865.protein.complete.v11.5.txt"
		    }
		]
    )()

def ParcubacteriaGroupBacteriumGw2011Gwa24726(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011_GWA2_47_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011Gwa24726", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1618844.protein.sequences.v11.5.fa",
		        "enrichment_path": "1618844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1618844.protein.info.v11.5.txt",
		        "node_list_path": "1618844.protein.complete.v11.5.txt"
		    }
		]
    )()

def HalomonasLuteaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas lutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "HalomonasLuteaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1121943.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1121943.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1121943.clusters.proteins.v11.5.txt",
		        "sequence_path": "1121943.protein.sequences.v11.5.fa",
		        "enrichment_path": "1121943.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1121943.protein.info.v11.5.txt",
		        "node_list_path": "1121943.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1121943.protein.cluster.v11.5.txt"
		    }
		]
    )()

def PeromyscusManiculatusBairdii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peromyscus maniculatus bairdii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeromyscusManiculatusBairdii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "230844.protein.sequences.v11.5.fa",
		        "enrichment_path": "230844.protein.enrichment.terms.v11.5.txt",
		        "info_path": "230844.protein.info.v11.5.txt",
		        "node_list_path": "230844.protein.complete.v11.5.txt"
		    }
		]
    )()

def AgrobacteriumArsenijevicii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium arsenijevicii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AgrobacteriumArsenijevicii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1585697.protein.sequences.v11.5.fa",
		        "enrichment_path": "1585697.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1585697.protein.info.v11.5.txt",
		        "node_list_path": "1585697.protein.complete.v11.5.txt"
		    }
		]
    )()

def GlycomycesTenuisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Glycomyces tenuis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GlycomycesTenuisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "58116.clusters.info.v11.5.txt",
		        "cluster_tree_path": "58116.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "58116.clusters.proteins.v11.5.txt",
		        "sequence_path": "58116.protein.sequences.v11.5.fa",
		        "enrichment_path": "58116.protein.enrichment.terms.v11.5.txt",
		        "info_path": "58116.protein.info.v11.5.txt",
		        "node_list_path": "58116.cluster.nodes.v11.5.txt",
		        "edge_list_path": "58116.protein.cluster.v11.5.txt"
		    }
		]
    )()

def CyanobiumSpCaciam14(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Cyanobium sp. CACIAM14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CyanobiumSpCaciam14", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1496688.protein.sequences.v11.5.fa",
		        "enrichment_path": "1496688.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1496688.protein.info.v11.5.txt",
		        "node_list_path": "1496688.protein.complete.v11.5.txt"
		    }
		]
    )()

def PeptoniphilusObesiPh1(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus obesi ph1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "PeptoniphilusObesiPh1", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1118062.protein.sequences.v11.5.fa",
		        "enrichment_path": "1118062.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1118062.protein.info.v11.5.txt",
		        "node_list_path": "1118062.protein.complete.v11.5.txt"
		    }
		]
    )()

def MyroidesGuanonisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Myroides guanonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MyroidesGuanonisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1150112.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1150112.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1150112.clusters.proteins.v11.5.txt",
		        "sequence_path": "1150112.protein.sequences.v11.5.fa",
		        "enrichment_path": "1150112.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1150112.protein.info.v11.5.txt",
		        "node_list_path": "1150112.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1150112.protein.cluster.v11.5.txt"
		    }
		]
    )()

def JejuiaPallidiluteaCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Jejuia pallidilutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "JejuiaPallidiluteaCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "504487.clusters.info.v11.5.txt",
		        "cluster_tree_path": "504487.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "504487.clusters.proteins.v11.5.txt",
		        "sequence_path": "504487.protein.sequences.v11.5.fa",
		        "enrichment_path": "504487.protein.enrichment.terms.v11.5.txt",
		        "info_path": "504487.protein.info.v11.5.txt",
		        "node_list_path": "504487.cluster.nodes.v11.5.txt",
		        "edge_list_path": "504487.protein.cluster.v11.5.txt"
		    }
		]
    )()

def BuchneraAphidicolaAphisGlycines(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Aphis glycines) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BuchneraAphidicolaAphisGlycines", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1265350.protein.sequences.v11.5.fa",
		        "enrichment_path": "1265350.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1265350.protein.info.v11.5.txt",
		        "node_list_path": "1265350.protein.complete.v11.5.txt"
		    }
		]
    )()

def ArthrobacterSpLeaf234(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ArthrobacterSpLeaf234", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736303.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736303.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736303.protein.info.v11.5.txt",
		        "node_list_path": "1736303.protein.complete.v11.5.txt"
		    }
		]
    )()

def CandidatusColwellbacteriaBacteriumRifcsplowo201Full4810Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_01_FULL_48_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo201Full4810Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1797690.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1797690.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1797690.clusters.proteins.v11.5.txt",
		        "sequence_path": "1797690.protein.sequences.v11.5.fa",
		        "enrichment_path": "1797690.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1797690.protein.info.v11.5.txt",
		        "node_list_path": "1797690.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1797690.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SphingomonasSpNfr15(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. NFR15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasSpNfr15", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1566282.protein.sequences.v11.5.fa",
		        "enrichment_path": "1566282.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1566282.protein.info.v11.5.txt",
		        "node_list_path": "1566282.protein.complete.v11.5.txt"
		    }
		]
    )()

def SphingomonasPanacisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas panacis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SphingomonasPanacisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1560345.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1560345.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1560345.clusters.proteins.v11.5.txt",
		        "sequence_path": "1560345.protein.sequences.v11.5.fa",
		        "enrichment_path": "1560345.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1560345.protein.info.v11.5.txt",
		        "node_list_path": "1560345.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1560345.protein.cluster.v11.5.txt"
		    }
		]
    )()

def YersiniaFrederiksenii(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia frederiksenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "YersiniaFrederiksenii", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "349966.protein.sequences.v11.5.fa",
		        "enrichment_path": "349966.protein.enrichment.terms.v11.5.txt",
		        "info_path": "349966.protein.info.v11.5.txt",
		        "node_list_path": "349966.protein.complete.v11.5.txt"
		    }
		]
    )()

def BauldiaLitoralis(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Bauldia litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "BauldiaLitoralis", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "665467.protein.sequences.v11.5.fa",
		        "enrichment_path": "665467.protein.enrichment.terms.v11.5.txt",
		        "info_path": "665467.protein.info.v11.5.txt",
		        "node_list_path": "665467.protein.complete.v11.5.txt"
		    }
		]
    )()

def ChryseobacteriumTaeanenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium taeanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ChryseobacteriumTaeanenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "311334.clusters.info.v11.5.txt",
		        "cluster_tree_path": "311334.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "311334.clusters.proteins.v11.5.txt",
		        "sequence_path": "311334.protein.sequences.v11.5.fa",
		        "enrichment_path": "311334.protein.enrichment.terms.v11.5.txt",
		        "info_path": "311334.protein.info.v11.5.txt",
		        "node_list_path": "311334.cluster.nodes.v11.5.txt",
		        "edge_list_path": "311334.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DelphinapterusLeucasCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Delphinapterus leucas Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DelphinapterusLeucasCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "9749.clusters.info.v11.5.txt",
		        "cluster_tree_path": "9749.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "9749.clusters.proteins.v11.5.txt",
		        "sequence_path": "9749.protein.sequences.v11.5.fa",
		        "enrichment_path": "9749.protein.enrichment.terms.v11.5.txt",
		        "info_path": "9749.protein.info.v11.5.txt",
		        "node_list_path": "9749.cluster.nodes.v11.5.txt",
		        "edge_list_path": "9749.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodococcusSpB7740Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. B7740 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodococcusSpB7740Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1564114.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1564114.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1564114.clusters.proteins.v11.5.txt",
		        "sequence_path": "1564114.protein.sequences.v11.5.fa",
		        "enrichment_path": "1564114.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1564114.protein.info.v11.5.txt",
		        "node_list_path": "1564114.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1564114.protein.cluster.v11.5.txt"
		    }
		]
    )()

def AcinetobacterSpDsm11652Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. DSM 11652 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AcinetobacterSpDsm11652Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "346222.clusters.info.v11.5.txt",
		        "cluster_tree_path": "346222.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "346222.clusters.proteins.v11.5.txt",
		        "sequence_path": "346222.protein.sequences.v11.5.fa",
		        "enrichment_path": "346222.protein.enrichment.terms.v11.5.txt",
		        "info_path": "346222.protein.info.v11.5.txt",
		        "node_list_path": "346222.cluster.nodes.v11.5.txt",
		        "edge_list_path": "346222.protein.cluster.v11.5.txt"
		    }
		]
    )()

def StreptomycesFradiaeCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces fradiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "StreptomycesFradiaeCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1906.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1906.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1906.clusters.proteins.v11.5.txt",
		        "sequence_path": "1906.protein.sequences.v11.5.fa",
		        "enrichment_path": "1906.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1906.protein.info.v11.5.txt",
		        "node_list_path": "1906.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1906.protein.cluster.v11.5.txt"
		    }
		]
    )()

def EnterococcusTermitisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus termitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusTermitisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "332950.clusters.info.v11.5.txt",
		        "cluster_tree_path": "332950.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "332950.clusters.proteins.v11.5.txt",
		        "sequence_path": "332950.protein.sequences.v11.5.fa",
		        "enrichment_path": "332950.protein.enrichment.terms.v11.5.txt",
		        "info_path": "332950.protein.info.v11.5.txt",
		        "node_list_path": "332950.cluster.nodes.v11.5.txt",
		        "edge_list_path": "332950.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RhodanobacterSpRoot480(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. Root480 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RhodanobacterSpRoot480", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1736542.protein.sequences.v11.5.fa",
		        "enrichment_path": "1736542.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1736542.protein.info.v11.5.txt",
		        "node_list_path": "1736542.protein.complete.v11.5.txt"
		    }
		]
    )()

def DesulfobaculaToluolicaTol2Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacula toluolica Tol2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DesulfobaculaToluolicaTol2Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "651182.clusters.info.v11.5.txt",
		        "cluster_tree_path": "651182.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "651182.clusters.proteins.v11.5.txt",
		        "sequence_path": "651182.protein.sequences.v11.5.fa",
		        "enrichment_path": "651182.protein.enrichment.terms.v11.5.txt",
		        "info_path": "651182.protein.info.v11.5.txt",
		        "node_list_path": "651182.cluster.nodes.v11.5.txt",
		        "edge_list_path": "651182.protein.cluster.v11.5.txt"
		    }
		]
    )()

def GemellaBergeriae(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Gemella bergeriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "GemellaBergeriae", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1321820.protein.sequences.v11.5.fa",
		        "enrichment_path": "1321820.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1321820.protein.info.v11.5.txt",
		        "node_list_path": "1321820.protein.complete.v11.5.txt"
		    }
		]
    )()

def MarinobacterSpAc23Cluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. AC-23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MarinobacterSpAc23Cluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1879031.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1879031.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1879031.clusters.proteins.v11.5.txt",
		        "sequence_path": "1879031.protein.sequences.v11.5.fa",
		        "enrichment_path": "1879031.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1879031.protein.info.v11.5.txt",
		        "node_list_path": "1879031.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1879031.protein.cluster.v11.5.txt"
		    }
		]
    )()

def SolemyaVelumCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Solemya velum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SolemyaVelumCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "2340.clusters.info.v11.5.txt",
		        "cluster_tree_path": "2340.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "2340.clusters.proteins.v11.5.txt",
		        "sequence_path": "2340.protein.sequences.v11.5.fa",
		        "enrichment_path": "2340.protein.enrichment.terms.v11.5.txt",
		        "info_path": "2340.protein.info.v11.5.txt",
		        "node_list_path": "2340.cluster.nodes.v11.5.txt",
		        "edge_list_path": "2340.protein.cluster.v11.5.txt"
		    }
		]
    )()

def DraconibacteriumOrientale(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Draconibacterium orientale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "DraconibacteriumOrientale", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1168034.protein.sequences.v11.5.fa",
		        "enrichment_path": "1168034.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1168034.protein.info.v11.5.txt",
		        "node_list_path": "1168034.protein.complete.v11.5.txt"
		    }
		]
    )()

def MagnetospirillumGryphiswaldenseCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum gryphiswaldense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "MagnetospirillumGryphiswaldenseCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "1430440.clusters.info.v11.5.txt",
		        "cluster_tree_path": "1430440.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "1430440.clusters.proteins.v11.5.txt",
		        "sequence_path": "1430440.protein.sequences.v11.5.fa",
		        "enrichment_path": "1430440.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1430440.protein.info.v11.5.txt",
		        "node_list_path": "1430440.cluster.nodes.v11.5.txt",
		        "edge_list_path": "1430440.protein.cluster.v11.5.txt"
		    }
		]
    )()

def RoseovariusIndicus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "RoseovariusIndicus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "540747.protein.sequences.v11.5.fa",
		        "enrichment_path": "540747.protein.enrichment.terms.v11.5.txt",
		        "info_path": "540747.protein.info.v11.5.txt",
		        "node_list_path": "540747.protein.complete.v11.5.txt"
		    }
		]
    )()

def XanthomonasCampestrisMusacearum(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris musacearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "XanthomonasCampestrisMusacearum", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1094184.protein.sequences.v11.5.fa",
		        "enrichment_path": "1094184.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1094184.protein.info.v11.5.txt",
		        "node_list_path": "1094184.protein.complete.v11.5.txt"
		    }
		]
    )()

def SaccharomonosporaCyanea(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora cyanea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SaccharomonosporaCyanea", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "882082.protein.sequences.v11.5.fa",
		        "enrichment_path": "882082.protein.enrichment.terms.v11.5.txt",
		        "info_path": "882082.protein.info.v11.5.txt",
		        "node_list_path": "882082.protein.complete.v11.5.txt"
		    }
		]
    )()

def AmycolatopsisJejuensisCluster(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "AmycolatopsisJejuensisCluster", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "330084.clusters.info.v11.5.txt",
		        "cluster_tree_path": "330084.clusters.tree.v11.5.txt",
		        "cluster_to_proteins_path": "330084.clusters.proteins.v11.5.txt",
		        "sequence_path": "330084.protein.sequences.v11.5.fa",
		        "enrichment_path": "330084.protein.enrichment.terms.v11.5.txt",
		        "info_path": "330084.protein.info.v11.5.txt",
		        "node_list_path": "330084.cluster.nodes.v11.5.txt",
		        "edge_list_path": "330084.protein.cluster.v11.5.txt"
		    }
		]
    )()

def ThaueraHumireducens(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Thauera humireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "ThaueraHumireducens", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "1134435.protein.sequences.v11.5.fa",
		        "enrichment_path": "1134435.protein.enrichment.terms.v11.5.txt",
		        "info_path": "1134435.protein.info.v11.5.txt",
		        "node_list_path": "1134435.protein.complete.v11.5.txt"
		    }
		]
    )()

def EnterococcusCasseliflavus(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus casseliflavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- homology.v11.5
			- physical.links.v11.0
			- physical.links.v11.5
			- links.v11.0
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "EnterococcusCasseliflavus", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "565655.protein.sequences.v11.5.fa",
		        "enrichment_path": "565655.protein.enrichment.terms.v11.5.txt",
		        "info_path": "565655.protein.info.v11.5.txt",
		        "node_list_path": "565655.protein.complete.v11.5.txt"
		    }
		]
    )()

def SalinimicrobiumCatena(
    directed = False, preprocess = "auto", load_nodes = True, load_node_types = True,
    load_edge_weights = True, auto_enable_tradeoffs = True,
    sort_tmp_dir = None, verbose = 2, cache = True, cache_path = None,
    cache_sys_var = "GRAPH_CACHE_DIR", version = "links.v11.5", **kwargs
) -> Graph:
    """Return Salinimicrobium catena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    load_nodes = True
        Load node names or use numeric range
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return AutomaticallyRetrievedGraph(
        "SalinimicrobiumCatena", version, "string", directed, preprocess, load_nodes,
        load_node_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir, verbose, cache,
        cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_graph_node_list
		],
		callbacks_arguments=[
		    {
		        "sequence_path": "390640.protein.sequences.v11.5.fa",
		        "enrichment_path": "390640.protein.enrichment.terms.v11.5.txt",
		        "info_path": "390640.protein.info.v11.5.txt",
		        "node_list_path": "390640.protein.complete.v11.5.txt"
		    }
		]
    )()

"""Submodule with methods to parse and standardize STRING graphs."""
import pandas as pd
import os


def parse_string_fasta(path: str) -> pd.DataFrame:
    """Return dataframe with aminoacid fasta sequences from given path.

    Parameters
    -----------------------
    path: str
        Path to the fasta file to load.
    """
    current_protein = current_sequence = ""
    proteins = []
    sequences = []
    with open(path, "r") as f:
        for line in f.readlines():
            line = line.strip()
            if line.startswith(">"):
                if len(current_sequence) != 0:
                    proteins.append(current_protein)
                    sequences.append(current_sequence)
                current_protein = line[1:]
                current_sequence = ""
            else:
                current_sequence += line

    return pd.DataFrame({
        # We follow the notation from other STRING PPI graph files.
        "#string_protein_id": proteins,
        "sequence": sequences,
    }).set_index("#string_protein_id")


def group_annotate_string_node_list(path: str) -> pd.DataFrame:
    """Return file grouped by protein node name.

    Parameters
    -----------------------
    path: str
        Path to the annotated protein node list file to load.
    """
    df: pd.DataFrame = pd.read_csv(path, sep="\t")

    df.drop(columns="category", inplace=True)

    return df.groupby("#string_protein_id")\
        .agg(lambda x: "|".join(sorted(set(x))))



def load_string_info_node_list(path: str) -> pd.DataFrame:
    """Return loaded STRING node list with informations.

    Parameters
    -----------------------
    path: str
        Path to the protein node list with informations.
    """
    return pd.read_csv(path, sep="\t", index_col=0)


def create_species_tree_node_and_edge_list(
    tree_path: str,
    tree_metadata_path: str,
    node_list_path: str,
    edge_list_path: str
):
    """Create the node and edge lists for the species tree at given path.

    Parameters
    -------------------
    tree_path: str
        The path from where to load the tree data.
    tree_metadata_path: str
        The path from where to load the tree metadata.
    node_list_path: str
        The path where to store the tree node list.
    edge_list_path: str
        The path where to store the tree edge list.
    """
    tree = pd.read_csv(tree_path, sep="\t", index_col=0)
    metadata = pd.read_csv(tree_metadata_path, sep="\t", index_col=0)

    # Imputing the missing domains in the Species Tree.
    tree.loc[metadata.index, "domain"] = metadata.domain
    tree.loc[tree.parent_taxon_id==1, "domain"] = "Ancestral"
    tree.loc[tree.domain == "Eukaryotes", "domain"] = "Eukaryota"
    tree = pd.concat(
        [tree, pd.DataFrame(dict(parent_taxon_id=1, taxon_name="LUCA"), index=[1])]
    )

    while tree.domain.isna().any():
        child_nodes = tree[tree.loc[tree.parent_taxon_id].domain.isna().values & tree.domain.notna().values]    
        tree.loc[child_nodes.parent_taxon_id, "domain"] = child_nodes.domain.values
    
    # We drop the temporary node index 1
    tree.drop(index=1, inplace=True)

    # Making taxon names unique, so that corner cases
    # such as `Drosophila Drosophila` can be handled.
    tree.loc[tree.duplicated("taxon_name"), "taxon_name"] = [
        "{}.{}".format(taxon_name, index)
        for index, taxon_name in tree.loc[tree.duplicated("taxon_name"), "taxon_name"].iteritems()
    ]
    
    # Writing the node list
    node_list = tree[["taxon_name", "domain"]]
    node_list.to_csv(node_list_path, sep="\t", index=False)

    # We drop edges from the root node to LUCA
    tree.drop(
        index=tree[tree.parent_taxon_id == 1].index[0],
        inplace=True
    )

    # Writing the edge list
    pd.DataFrame({
        "sources": node_list.loc[tree.index].taxon_name.values,
        "destinations": node_list.loc[tree.parent_taxon_id].taxon_name.values,
        "domain": tree.domain.values
    }).to_csv(edge_list_path, sep="\t", index=False)


def build_string_graph_node_list(
    sequence_path: str,
    enrichment_path: str,
    info_path: str,
    node_list_path: str
):
    """Processes string data into node list.

    Parameters
    ----------------------
    sequence_path: str
        File from where to load sequence data.
    enrichment_path: str
        File from where to load enrichment data.
    info_path: str
        File from where to load info data.
    node_list_path: str
        Path where to write the resulting TSV.
    """

    fasta_df = parse_string_fasta(sequence_path)
    enrichment_df = group_annotate_string_node_list(enrichment_path)
    info_df = load_string_info_node_list(info_path)

    merged_df = pd.concat(
        (info_df, enrichment_df, fasta_df),
        axis=1
    )

    merged_df.to_csv(
        node_list_path,
        sep="\t",
        index=True,
        header=True
    )


def build_string_cluster_graph_node_and_edge_list(
    cluster_info_path: str,
    cluster_tree_path: str,
    cluster_to_proteins_path: str,
    sequence_path: str,
    enrichment_path: str,
    info_path: str,
    node_list_path: str,
    edge_list_path: str,
):
    """Build labeled edge and node list for cluster graphs.
    
    Parameters
    -----------------------
    cluster_info_path: str
        Path from where to load the cluster node list informations.
    cluster_tree_path: str
        Path from where to load the cluster to cluster edge list.
    cluster_to_proteins_path: str
        Path from where to load the cluster to protein edge list.
    sequence_path: str
        File from where to load sequence data.
    enrichment_path: str
        File from where to load enrichment data.
    info_path: str
        File from where to load info data.
    target_path: str
        Path where to write the resulting node list TSV.
    """
    build_string_graph_node_list(
        sequence_path=sequence_path,
        enrichment_path=enrichment_path,
        info_path=info_path,
        node_list_path=node_list_path,
    )
    cluster_only_node_list = pd.read_csv(cluster_info_path, sep="\t")
    cluster_only_node_list["term"] = "Cluster"
    cluster_only_node_list.rename(
        columns={
            "best_described_by": "description",
            "cluster_id": "node_name"
        },
        inplace=True
    )
    string_only_node_list = pd.read_csv(node_list_path, sep="\t")
    string_only_node_list.rename(
        columns={
            "#string_protein_id": "node_name"
        },
        inplace=True
    )
    node_list = pd.concat((cluster_only_node_list, string_only_node_list), axis=0)
    node_list.to_csv(node_list_path, sep="\t")

    cluster_tree_df = pd.read_csv(cluster_tree_path, sep="\t")
    cluster_to_proteins_df = pd.read_csv(cluster_to_proteins_path, sep="\t")

    cluster_tree_df.rename(
        columns={
            "child_cluster_id": "source",
            "parent_cluster_id": "destination",
        },
        inplace=True
    )

    cluster_to_proteins_df.rename(
        columns={
            "cluster_id": "source",
            "protein_id": "destination",
        },
        inplace=True
    )

    edge_list = pd.concat((
        cluster_tree_df[["source", "destination"]],
        cluster_to_proteins_df[["source", "destination"]],
    ), axis=0)

    edge_list.to_csv(edge_list_path, sep="\t", index=False)